const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./GraphView-DIFwgSix.js","./index-B-AC1E9c.js","./index-dVgcC0fG.js","./index-CldOu0q9.js","./keybindingService-BnpGhxav.js","./serverConfigStore-CjEEWpzL.js","./GraphView-C5J57RBe.css","./UserSelectView-ChoLQX6h.js","./BaseViewTemplate-BIdYJv-L.js","./ServerStartView-L7Ep7wjc.js","./ServerStartView-DpZrG3I7.css","./InstallView-DDRZa2vk.js","./index-BRQYPtiO.js","./uvMirrors-DCz2jm9P.js","./InstallView-BYs3XBHg.css","./WelcomeView-D5wE9fV3.js","./WelcomeView-aCH40CSK.css","./NotSupportedView-B5tg2lWn.js","./NotSupportedView-BiyVuLfX.css","./DownloadGitView-CywmLRmU.js","./ManualConfigurationView-B17itdXq.js","./ManualConfigurationView-DSVqox_S.css","./MetricsConsentView-faZwQDjh.js","./DesktopStartView-B36WWhTC.js","./MaintenanceView-D5_jO_ss.js","./index-CpNYS15r.js","./index-Dmpr9fqY.js","./index-CtJrT3id.js","./TerminalOutputDrawer-DO0jp0hP.js","./MaintenanceView-DFNcEErv.css","./DesktopUpdateView-snHXsIop.js","./DesktopUpdateView-CoZUcBzh.css","./KeybindingPanel-C-c9VhnA.js","./KeybindingPanel-DIbEBW8u.css","./ExtensionPanel-CPmGRZ_x.js","./ServerConfigPanel-0V5kfAZ5.js","./index-dLHBN4II.js","./index-Jyk11b1K.css"])))=>i.map(i=>d[i]);
var __defProp2 = Object.defineProperty;
var __name = (target2, value3) => __defProp2(target2, "name", { value: value3, configurable: true });
(/* @__PURE__ */ __name(function polyfill2() {
  const relList = document.createElement("link").relList;
  if (relList && relList.supports && relList.supports("modulepreload")) {
    return;
  }
  for (const link2 of document.querySelectorAll('link[rel="modulepreload"]')) {
    processPreload(link2);
  }
  new MutationObserver((mutations) => {
    for (const mutation of mutations) {
      if (mutation.type !== "childList") {
        continue;
      }
      for (const node3 of mutation.addedNodes) {
        if (node3.tagName === "LINK" && node3.rel === "modulepreload")
          processPreload(node3);
      }
    }
  }).observe(document, { childList: true, subtree: true });
  function getFetchOpts(link2) {
    const fetchOpts = {};
    if (link2.integrity) fetchOpts.integrity = link2.integrity;
    if (link2.referrerPolicy) fetchOpts.referrerPolicy = link2.referrerPolicy;
    if (link2.crossOrigin === "use-credentials")
      fetchOpts.credentials = "include";
    else if (link2.crossOrigin === "anonymous") fetchOpts.credentials = "omit";
    else fetchOpts.credentials = "same-origin";
    return fetchOpts;
  }
  __name(getFetchOpts, "getFetchOpts");
  function processPreload(link2) {
    if (link2.ep)
      return;
    link2.ep = true;
    const fetchOpts = getFetchOpts(link2);
    fetch(link2.href, fetchOpts);
  }
  __name(processPreload, "processPreload");
}, "polyfill"))();
var __defProp$7 = Object.defineProperty;
var __getOwnPropSymbols$6 = Object.getOwnPropertySymbols;
var __hasOwnProp$6 = Object.prototype.hasOwnProperty;
var __propIsEnum$6 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$7 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$7(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$7");
var __spreadValues$6 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$6.call(b2, prop2))
      __defNormalProp$7(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$6)
    for (var prop2 of __getOwnPropSymbols$6(b2)) {
      if (__propIsEnum$6.call(b2, prop2))
        __defNormalProp$7(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$6");
function isEmpty$3(value3) {
  return value3 === null || value3 === void 0 || value3 === "" || Array.isArray(value3) && value3.length === 0 || !(value3 instanceof Date) && typeof value3 === "object" && Object.keys(value3).length === 0;
}
__name(isEmpty$3, "isEmpty$3");
function compare$3(value1, value22, comparator, order = 1) {
  let result = -1;
  const emptyValue1 = isEmpty$3(value1);
  const emptyValue2 = isEmpty$3(value22);
  if (emptyValue1 && emptyValue2) result = 0;
  else if (emptyValue1) result = order;
  else if (emptyValue2) result = -order;
  else if (typeof value1 === "string" && typeof value22 === "string") result = comparator(value1, value22);
  else result = value1 < value22 ? -1 : value1 > value22 ? 1 : 0;
  return result;
}
__name(compare$3, "compare$3");
function _deepEquals$2(obj1, obj2, visited = /* @__PURE__ */ new WeakSet()) {
  if (obj1 === obj2) return true;
  if (!obj1 || !obj2 || typeof obj1 !== "object" || typeof obj2 !== "object") return false;
  if (visited.has(obj1) || visited.has(obj2)) return false;
  visited.add(obj1).add(obj2);
  let arrObj1 = Array.isArray(obj1), arrObj2 = Array.isArray(obj2), i2, length, key;
  if (arrObj1 && arrObj2) {
    length = obj1.length;
    if (length != obj2.length) return false;
    for (i2 = length; i2-- !== 0; ) if (!_deepEquals$2(obj1[i2], obj2[i2], visited)) return false;
    return true;
  }
  if (arrObj1 != arrObj2) return false;
  let dateObj1 = obj1 instanceof Date, dateObj2 = obj2 instanceof Date;
  if (dateObj1 != dateObj2) return false;
  if (dateObj1 && dateObj2) return obj1.getTime() == obj2.getTime();
  let regexpObj1 = obj1 instanceof RegExp, regexpObj2 = obj2 instanceof RegExp;
  if (regexpObj1 != regexpObj2) return false;
  if (regexpObj1 && regexpObj2) return obj1.toString() == obj2.toString();
  let keys2 = Object.keys(obj1);
  length = keys2.length;
  if (length !== Object.keys(obj2).length) return false;
  for (i2 = length; i2-- !== 0; ) if (!Object.prototype.hasOwnProperty.call(obj2, keys2[i2])) return false;
  for (i2 = length; i2-- !== 0; ) {
    key = keys2[i2];
    if (!_deepEquals$2(obj1[key], obj2[key], visited)) return false;
  }
  return true;
}
__name(_deepEquals$2, "_deepEquals$2");
function deepEquals$2(obj1, obj2) {
  return _deepEquals$2(obj1, obj2);
}
__name(deepEquals$2, "deepEquals$2");
function isFunction$d(value3) {
  return !!(value3 && value3.constructor && value3.call && value3.apply);
}
__name(isFunction$d, "isFunction$d");
function isNotEmpty$2(value3) {
  return !isEmpty$3(value3);
}
__name(isNotEmpty$2, "isNotEmpty$2");
function resolveFieldData$2(data30, field2) {
  if (!data30 || !field2) {
    return null;
  }
  try {
    const value3 = data30[field2];
    if (isNotEmpty$2(value3)) return value3;
  } catch (e2) {
  }
  if (Object.keys(data30).length) {
    if (isFunction$d(field2)) {
      return field2(data30);
    } else if (field2.indexOf(".") === -1) {
      return data30[field2];
    } else {
      let fields = field2.split(".");
      let value3 = data30;
      for (let i2 = 0, len = fields.length; i2 < len; ++i2) {
        if (value3 == null) {
          return null;
        }
        value3 = value3[fields[i2]];
      }
      return value3;
    }
  }
  return null;
}
__name(resolveFieldData$2, "resolveFieldData$2");
function equals$2(obj1, obj2, field2) {
  if (field2) return resolveFieldData$2(obj1, field2) === resolveFieldData$2(obj2, field2);
  else return deepEquals$2(obj1, obj2);
}
__name(equals$2, "equals$2");
function contains$2(value3, list2) {
  if (value3 != null && list2 && list2.length) {
    for (let val of list2) {
      if (equals$2(value3, val)) return true;
    }
  }
  return false;
}
__name(contains$2, "contains$2");
function filter$2(value3, fields, filterValue) {
  let filteredItems = [];
  if (value3) {
    for (let item3 of value3) {
      for (let field2 of fields) {
        if (String(resolveFieldData$2(item3, field2)).toLowerCase().indexOf(filterValue.toLowerCase()) > -1) {
          filteredItems.push(item3);
          break;
        }
      }
    }
  }
  return filteredItems;
}
__name(filter$2, "filter$2");
function findIndexInList$2(value3, list2) {
  let index2 = -1;
  if (list2) {
    for (let i2 = 0; i2 < list2.length; i2++) {
      if (list2[i2] === value3) {
        index2 = i2;
        break;
      }
    }
  }
  return index2;
}
__name(findIndexInList$2, "findIndexInList$2");
function findLast$3(arr, callback) {
  let item3;
  if (isNotEmpty$2(arr)) {
    try {
      item3 = arr.findLast(callback);
    } catch (e2) {
      item3 = [...arr].reverse().find(callback);
    }
  }
  return item3;
}
__name(findLast$3, "findLast$3");
function findLastIndex$2(arr, callback) {
  let index2 = -1;
  if (isNotEmpty$2(arr)) {
    try {
      index2 = arr.findLastIndex(callback);
    } catch (e2) {
      index2 = arr.lastIndexOf([...arr].reverse().find(callback));
    }
  }
  return index2;
}
__name(findLastIndex$2, "findLastIndex$2");
function isObject$g(value3, empty2 = true) {
  return value3 instanceof Object && value3.constructor === Object && (empty2 || Object.keys(value3).length !== 0);
}
__name(isObject$g, "isObject$g");
function resolve$4(obj, ...params) {
  return isFunction$d(obj) ? obj(...params) : obj;
}
__name(resolve$4, "resolve$4");
function isString$b(value3, empty2 = true) {
  return typeof value3 === "string" && (empty2 || value3 !== "");
}
__name(isString$b, "isString$b");
function toFlatCase$2(str) {
  return isString$b(str) ? str.replace(/(-|_)/g, "").toLowerCase() : str;
}
__name(toFlatCase$2, "toFlatCase$2");
function getKeyValue$2(obj, key = "", params = {}) {
  const fKeys = toFlatCase$2(key).split(".");
  const fKey = fKeys.shift();
  return fKey ? isObject$g(obj) ? getKeyValue$2(resolve$4(obj[Object.keys(obj).find((k2) => toFlatCase$2(k2) === fKey) || ""], params), fKeys.join("."), params) : void 0 : resolve$4(obj, params);
}
__name(getKeyValue$2, "getKeyValue$2");
function insertIntoOrderedArray$2(item3, index2, arr, sourceArr) {
  if (arr.length > 0) {
    let injected = false;
    for (let i2 = 0; i2 < arr.length; i2++) {
      let currentItemIndex = findIndexInList$2(arr[i2], sourceArr);
      if (currentItemIndex > index2) {
        arr.splice(i2, 0, item3);
        injected = true;
        break;
      }
    }
    if (!injected) {
      arr.push(item3);
    }
  } else {
    arr.push(item3);
  }
}
__name(insertIntoOrderedArray$2, "insertIntoOrderedArray$2");
function isArray$c(value3, empty2 = true) {
  return Array.isArray(value3) && (empty2 || value3.length !== 0);
}
__name(isArray$c, "isArray$c");
function isDate$5(value3) {
  return value3 instanceof Date && value3.constructor === Date;
}
__name(isDate$5, "isDate$5");
function isLetter$3(char) {
  return /^[a-zA-Z\u00C0-\u017F]$/.test(char);
}
__name(isLetter$3, "isLetter$3");
function isNumber$7(value3) {
  return isNotEmpty$2(value3) && !isNaN(value3);
}
__name(isNumber$7, "isNumber$7");
function isPrintableCharacter$2(char = "") {
  return isNotEmpty$2(char) && char.length === 1 && !!char.match(/\S| /);
}
__name(isPrintableCharacter$2, "isPrintableCharacter$2");
function isScalar$2(value3) {
  return value3 != null && (typeof value3 === "string" || typeof value3 === "number" || typeof value3 === "bigint" || typeof value3 === "boolean");
}
__name(isScalar$2, "isScalar$2");
function localeComparator$2() {
  return new Intl.Collator(void 0, { numeric: true }).compare;
}
__name(localeComparator$2, "localeComparator$2");
function matchRegex$2(str, regex2) {
  if (regex2) {
    const match2 = regex2.test(str);
    regex2.lastIndex = 0;
    return match2;
  }
  return false;
}
__name(matchRegex$2, "matchRegex$2");
function mergeKeys$2(...args) {
  const _mergeKeys = /* @__PURE__ */ __name((target2 = {}, source = {}) => {
    const mergedObj = __spreadValues$6({}, target2);
    Object.keys(source).forEach((key) => {
      if (isObject$g(source[key]) && key in target2 && isObject$g(target2[key])) {
        mergedObj[key] = _mergeKeys(target2[key], source[key]);
      } else {
        mergedObj[key] = source[key];
      }
    });
    return mergedObj;
  }, "_mergeKeys");
  return args.reduce((acc, obj, i2) => i2 === 0 ? obj : _mergeKeys(acc, obj), {});
}
__name(mergeKeys$2, "mergeKeys$2");
function minifyCSS$2(css4) {
  return css4 ? css4.replace(/\/\*(?:(?!\*\/)[\s\S])*\*\/|[\r\n\t]+/g, "").replace(/ {2,}/g, " ").replace(/ ([{:}]) /g, "$1").replace(/([;,]) /g, "$1").replace(/ !/g, "!").replace(/: /g, ":") : css4;
}
__name(minifyCSS$2, "minifyCSS$2");
function nestedKeys$2(obj = {}, parentKey = "") {
  return Object.entries(obj).reduce((o2, [key, value3]) => {
    const currentKey = parentKey ? `${parentKey}.${key}` : key;
    isObject$g(value3) ? o2 = o2.concat(nestedKeys$2(value3, currentKey)) : o2.push(currentKey);
    return o2;
  }, []);
}
__name(nestedKeys$2, "nestedKeys$2");
function omit$3(obj, ...keys2) {
  if (!isObject$g(obj)) return obj;
  const copy2 = __spreadValues$6({}, obj);
  keys2 == null ? void 0 : keys2.flat().forEach((key) => delete copy2[key]);
  return copy2;
}
__name(omit$3, "omit$3");
function removeAccents$2(str) {
  const accentCheckRegex = /[\xC0-\xFF\u0100-\u017E]/;
  if (str && accentCheckRegex.test(str)) {
    const accentsMap = {
      A: /[\xC0-\xC5\u0100\u0102\u0104]/g,
      AE: /[\xC6]/g,
      C: /[\xC7\u0106\u0108\u010A\u010C]/g,
      D: /[\xD0\u010E\u0110]/g,
      E: /[\xC8-\xCB\u0112\u0114\u0116\u0118\u011A]/g,
      G: /[\u011C\u011E\u0120\u0122]/g,
      H: /[\u0124\u0126]/g,
      I: /[\xCC-\xCF\u0128\u012A\u012C\u012E\u0130]/g,
      IJ: /[\u0132]/g,
      J: /[\u0134]/g,
      K: /[\u0136]/g,
      L: /[\u0139\u013B\u013D\u013F\u0141]/g,
      N: /[\xD1\u0143\u0145\u0147\u014A]/g,
      O: /[\xD2-\xD6\xD8\u014C\u014E\u0150]/g,
      OE: /[\u0152]/g,
      R: /[\u0154\u0156\u0158]/g,
      S: /[\u015A\u015C\u015E\u0160]/g,
      T: /[\u0162\u0164\u0166]/g,
      U: /[\xD9-\xDC\u0168\u016A\u016C\u016E\u0170\u0172]/g,
      W: /[\u0174]/g,
      Y: /[\xDD\u0176\u0178]/g,
      Z: /[\u0179\u017B\u017D]/g,
      a: /[\xE0-\xE5\u0101\u0103\u0105]/g,
      ae: /[\xE6]/g,
      c: /[\xE7\u0107\u0109\u010B\u010D]/g,
      d: /[\u010F\u0111]/g,
      e: /[\xE8-\xEB\u0113\u0115\u0117\u0119\u011B]/g,
      g: /[\u011D\u011F\u0121\u0123]/g,
      i: /[\xEC-\xEF\u0129\u012B\u012D\u012F\u0131]/g,
      ij: /[\u0133]/g,
      j: /[\u0135]/g,
      k: /[\u0137,\u0138]/g,
      l: /[\u013A\u013C\u013E\u0140\u0142]/g,
      n: /[\xF1\u0144\u0146\u0148\u014B]/g,
      p: /[\xFE]/g,
      o: /[\xF2-\xF6\xF8\u014D\u014F\u0151]/g,
      oe: /[\u0153]/g,
      r: /[\u0155\u0157\u0159]/g,
      s: /[\u015B\u015D\u015F\u0161]/g,
      t: /[\u0163\u0165\u0167]/g,
      u: /[\xF9-\xFC\u0169\u016B\u016D\u016F\u0171\u0173]/g,
      w: /[\u0175]/g,
      y: /[\xFD\xFF\u0177]/g,
      z: /[\u017A\u017C\u017E]/g
    };
    for (let key in accentsMap) {
      str = str.replace(accentsMap[key], key);
    }
  }
  return str;
}
__name(removeAccents$2, "removeAccents$2");
function reorderArray$2(value3, from2, to) {
  if (value3 && from2 !== to) {
    if (to >= value3.length) {
      to %= value3.length;
      from2 %= value3.length;
    }
    value3.splice(to, 0, value3.splice(from2, 1)[0]);
  }
}
__name(reorderArray$2, "reorderArray$2");
function sort$2(value1, value22, order = 1, comparator, nullSortOrder = 1) {
  const result = compare$3(value1, value22, comparator, order);
  let finalSortOrder = order;
  if (isEmpty$3(value1) || isEmpty$3(value22)) {
    finalSortOrder = nullSortOrder === 1 ? order : nullSortOrder;
  }
  return finalSortOrder * result;
}
__name(sort$2, "sort$2");
function stringify$2(value3, indent = 2, currentIndent = 0) {
  const currentIndentStr = " ".repeat(currentIndent);
  const nextIndentStr = " ".repeat(currentIndent + indent);
  if (isArray$c(value3)) {
    return "[" + value3.map((v2) => stringify$2(v2, indent, currentIndent + indent)).join(", ") + "]";
  } else if (isDate$5(value3)) {
    return value3.toISOString();
  } else if (isFunction$d(value3)) {
    return value3.toString();
  } else if (isObject$g(value3)) {
    return "{\n" + Object.entries(value3).map(([k2, v2]) => `${nextIndentStr}${k2}: ${stringify$2(v2, indent, currentIndent + indent)}`).join(",\n") + `
${currentIndentStr}}`;
  } else {
    return JSON.stringify(value3);
  }
}
__name(stringify$2, "stringify$2");
function toCapitalCase$2(str) {
  return isString$b(str, false) ? str[0].toUpperCase() + str.slice(1) : str;
}
__name(toCapitalCase$2, "toCapitalCase$2");
function toKebabCase$2(str) {
  return isString$b(str) ? str.replace(/(_)/g, "-").replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "-" + c2.toLowerCase()).toLowerCase() : str;
}
__name(toKebabCase$2, "toKebabCase$2");
function toTokenKey$4(str) {
  return isString$b(str) ? str.replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "." + c2.toLowerCase()).toLowerCase() : str;
}
__name(toTokenKey$4, "toTokenKey$4");
function toValue$6(value3) {
  if (value3 && typeof value3 === "object") {
    if (value3.hasOwnProperty("current")) {
      return value3.current;
    } else if (value3.hasOwnProperty("value")) {
      return value3.value;
    }
  }
  return resolve$4(value3);
}
__name(toValue$6, "toValue$6");
function EventBus$1() {
  const allHandlers = /* @__PURE__ */ new Map();
  return {
    on(type, handler14) {
      let handlers2 = allHandlers.get(type);
      if (!handlers2) handlers2 = [handler14];
      else handlers2.push(handler14);
      allHandlers.set(type, handlers2);
      return this;
    },
    off(type, handler14) {
      let handlers2 = allHandlers.get(type);
      if (handlers2) {
        handlers2.splice(handlers2.indexOf(handler14) >>> 0, 1);
      }
      return this;
    },
    emit(type, evt) {
      let handlers2 = allHandlers.get(type);
      if (handlers2) {
        handlers2.slice().map((handler14) => {
          handler14(evt);
        });
      }
    },
    clear() {
      allHandlers.clear();
    }
  };
}
__name(EventBus$1, "EventBus$1");
var __defProp$6 = Object.defineProperty;
var __defProps$1 = Object.defineProperties;
var __getOwnPropDescs$1 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$5 = Object.getOwnPropertySymbols;
var __hasOwnProp$5 = Object.prototype.hasOwnProperty;
var __propIsEnum$5 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$6 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$6(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$6");
var __spreadValues$5 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$5.call(b2, prop2))
      __defNormalProp$6(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$5)
    for (var prop2 of __getOwnPropSymbols$5(b2)) {
      if (__propIsEnum$5.call(b2, prop2))
        __defNormalProp$6(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$5");
var __spreadProps$1 = /* @__PURE__ */ __name((a2, b2) => __defProps$1(a2, __getOwnPropDescs$1(b2)), "__spreadProps$1");
var __objRest$1 = /* @__PURE__ */ __name((source, exclude) => {
  var target2 = {};
  for (var prop2 in source)
    if (__hasOwnProp$5.call(source, prop2) && exclude.indexOf(prop2) < 0)
      target2[prop2] = source[prop2];
  if (source != null && __getOwnPropSymbols$5)
    for (var prop2 of __getOwnPropSymbols$5(source)) {
      if (exclude.indexOf(prop2) < 0 && __propIsEnum$5.call(source, prop2))
        target2[prop2] = source[prop2];
    }
  return target2;
}, "__objRest$1");
function definePreset$1(...presets) {
  return mergeKeys$2(...presets);
}
__name(definePreset$1, "definePreset$1");
var ThemeService$1 = EventBus$1();
var service_default$1 = ThemeService$1;
function toTokenKey$3(str) {
  return isString$b(str) ? str.replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "." + c2.toLowerCase()).toLowerCase() : str;
}
__name(toTokenKey$3, "toTokenKey$3");
function merge$3(value1, value22) {
  if (isArray$c(value1)) {
    value1.push(...value22 || []);
  } else if (isObject$g(value1)) {
    Object.assign(value1, value22);
  }
}
__name(merge$3, "merge$3");
function toValue$5(value3) {
  return isObject$g(value3) && value3.hasOwnProperty("value") && value3.hasOwnProperty("type") ? value3.value : value3;
}
__name(toValue$5, "toValue$5");
function toUnit$1(value3, variable = "") {
  const excludedProperties = ["opacity", "z-index", "line-height", "font-weight", "flex", "flex-grow", "flex-shrink", "order"];
  if (!excludedProperties.some((property) => variable.endsWith(property))) {
    const val = `${value3}`.trim();
    const valArr = val.split(" ");
    return valArr.map((v2) => isNumber$7(v2) ? `${v2}px` : v2).join(" ");
  }
  return value3;
}
__name(toUnit$1, "toUnit$1");
function toNormalizePrefix$1(prefix2) {
  return prefix2.replaceAll(/ /g, "").replace(/[^\w]/g, "-");
}
__name(toNormalizePrefix$1, "toNormalizePrefix$1");
function toNormalizeVariable$1(prefix2 = "", variable = "") {
  return toNormalizePrefix$1(`${isString$b(prefix2, false) && isString$b(variable, false) ? `${prefix2}-` : prefix2}${variable}`);
}
__name(toNormalizeVariable$1, "toNormalizeVariable$1");
function getVariableName$1(prefix2 = "", variable = "") {
  return `--${toNormalizeVariable$1(prefix2, variable)}`;
}
__name(getVariableName$1, "getVariableName$1");
function hasOddBraces$1(str = "") {
  const openBraces = (str.match(/{/g) || []).length;
  const closeBraces = (str.match(/}/g) || []).length;
  return (openBraces + closeBraces) % 2 !== 0;
}
__name(hasOddBraces$1, "hasOddBraces$1");
function getVariableValue$1(value3, variable = "", prefix2 = "", excludedKeyRegexes = [], fallback) {
  if (isString$b(value3)) {
    const regex2 = /{([^}]*)}/g;
    const val = value3.trim();
    if (hasOddBraces$1(val)) {
      return void 0;
    } else if (matchRegex$2(val, regex2)) {
      const _val = val.replaceAll(regex2, (v2) => {
        const path = v2.replace(/{|}/g, "");
        const keys2 = path.split(".").filter((_v) => !excludedKeyRegexes.some((_r) => matchRegex$2(_v, _r)));
        return `var(${getVariableName$1(prefix2, toKebabCase$2(keys2.join("-")))}${isNotEmpty$2(fallback) ? `, ${fallback}` : ""})`;
      });
      const calculationRegex = /(\d+\s+[\+\-\*\/]\s+\d+)/g;
      const cleanedVarRegex = /var\([^)]+\)/g;
      return matchRegex$2(_val.replace(cleanedVarRegex, "0"), calculationRegex) ? `calc(${_val})` : _val;
    }
    return val;
  } else if (isNumber$7(value3)) {
    return value3;
  }
  return void 0;
}
__name(getVariableValue$1, "getVariableValue$1");
function getComputedValue$1(obj = {}, value3) {
  if (isString$b(value3)) {
    const regex2 = /{([^}]*)}/g;
    const val = value3.trim();
    return matchRegex$2(val, regex2) ? val.replaceAll(regex2, (v2) => getKeyValue$2(obj, v2.replace(/{|}/g, ""))) : val;
  } else if (isNumber$7(value3)) {
    return value3;
  }
  return void 0;
}
__name(getComputedValue$1, "getComputedValue$1");
function setProperty$1(properties, key, value3) {
  if (isString$b(key, false)) {
    properties.push(`${key}:${value3};`);
  }
}
__name(setProperty$1, "setProperty$1");
function getRule$1(selector, properties) {
  if (selector) {
    return `${selector}{${properties}}`;
  }
  return "";
}
__name(getRule$1, "getRule$1");
function normalizeColor$1(color2) {
  if (color2.length === 4) {
    return `#${color2[1]}${color2[1]}${color2[2]}${color2[2]}${color2[3]}${color2[3]}`;
  }
  return color2;
}
__name(normalizeColor$1, "normalizeColor$1");
function hexToRgb$2(hex) {
  var bigint = parseInt(hex.substring(1), 16);
  var r2 = bigint >> 16 & 255;
  var g2 = bigint >> 8 & 255;
  var b2 = bigint & 255;
  return { r: r2, g: g2, b: b2 };
}
__name(hexToRgb$2, "hexToRgb$2");
function rgbToHex$1(r2, g2, b2) {
  return `#${r2.toString(16).padStart(2, "0")}${g2.toString(16).padStart(2, "0")}${b2.toString(16).padStart(2, "0")}`;
}
__name(rgbToHex$1, "rgbToHex$1");
var mix_default$1 = /* @__PURE__ */ __name((color1, color2, weight) => {
  color1 = normalizeColor$1(color1);
  color2 = normalizeColor$1(color2);
  var p2 = weight / 100;
  var w2 = p2 * 2 - 1;
  var w1 = (w2 + 1) / 2;
  var w22 = 1 - w1;
  var rgb1 = hexToRgb$2(color1);
  var rgb2 = hexToRgb$2(color2);
  var r2 = Math.round(rgb1.r * w1 + rgb2.r * w22);
  var g2 = Math.round(rgb1.g * w1 + rgb2.g * w22);
  var b2 = Math.round(rgb1.b * w1 + rgb2.b * w22);
  return rgbToHex$1(r2, g2, b2);
}, "mix_default$1");
var shade_default$1 = /* @__PURE__ */ __name((color2, percent) => mix_default$1("#000000", color2, percent), "shade_default$1");
var tint_default$1 = /* @__PURE__ */ __name((color2, percent) => mix_default$1("#ffffff", color2, percent), "tint_default$1");
var scales$1 = [50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 950];
var palette_default$1 = /* @__PURE__ */ __name((color2) => {
  if (/{([^}]*)}/g.test(color2)) {
    const token = color2.replace(/{|}/g, "");
    return scales$1.reduce((acc, scale) => (acc[scale] = `{${token}.${scale}}`, acc), {});
  }
  return typeof color2 === "string" ? scales$1.reduce((acc, scale, i2) => (acc[scale] = i2 <= 5 ? tint_default$1(color2, (5 - i2) * 19) : shade_default$1(color2, (i2 - 5) * 15), acc), {}) : color2;
}, "palette_default$1");
var $dt$1 = /* @__PURE__ */ __name((tokenPath) => {
  var _a2;
  const theme47 = config_default$1.getTheme();
  const variable = dtwt$1(theme47, tokenPath, void 0, "variable");
  const name2 = (_a2 = variable == null ? void 0 : variable.match(/--[\w-]+/g)) == null ? void 0 : _a2[0];
  const value3 = dtwt$1(theme47, tokenPath, void 0, "value");
  return {
    name: name2,
    variable,
    value: value3
  };
}, "$dt$1");
var dt$1 = /* @__PURE__ */ __name((...args) => {
  return dtwt$1(config_default$1.getTheme(), ...args);
}, "dt$1");
var dtwt$1 = /* @__PURE__ */ __name((theme47 = {}, tokenPath, fallback, type) => {
  if (tokenPath) {
    const { variable: VARIABLE, options: OPTIONS } = config_default$1.defaults || {};
    const { prefix: prefix2, transform: transform2 } = (theme47 == null ? void 0 : theme47.options) || OPTIONS || {};
    const regex2 = /{([^}]*)}/g;
    const token = matchRegex$2(tokenPath, regex2) ? tokenPath : `{${tokenPath}}`;
    const isStrictTransform = type === "value" || isEmpty$3(type) && transform2 === "strict";
    return isStrictTransform ? config_default$1.getTokenValue(tokenPath) : getVariableValue$1(token, void 0, prefix2, [VARIABLE.excludedKeyRegex], fallback);
  }
  return "";
}, "dtwt$1");
function css$5(style2) {
  return resolve$4(style2, { dt: dt$1 });
}
__name(css$5, "css$5");
var $t$1 = /* @__PURE__ */ __name((theme47 = {}) => {
  let { preset: _preset, options: _options } = theme47;
  return {
    preset(value3) {
      _preset = _preset ? mergeKeys$2(_preset, value3) : value3;
      return this;
    },
    options(value3) {
      _options = _options ? __spreadValues$5(__spreadValues$5({}, _options), value3) : value3;
      return this;
    },
    // features
    primaryPalette(primary) {
      const { semantic } = _preset || {};
      _preset = __spreadProps$1(__spreadValues$5({}, _preset), { semantic: __spreadProps$1(__spreadValues$5({}, semantic), { primary }) });
      return this;
    },
    surfacePalette(surface) {
      var _a2, _b;
      const { semantic } = _preset || {};
      const lightSurface = (surface == null ? void 0 : surface.hasOwnProperty("light")) ? surface == null ? void 0 : surface.light : surface;
      const darkSurface = (surface == null ? void 0 : surface.hasOwnProperty("dark")) ? surface == null ? void 0 : surface.dark : surface;
      const newColorScheme = {
        colorScheme: {
          light: __spreadValues$5(__spreadValues$5({}, (_a2 = semantic == null ? void 0 : semantic.colorScheme) == null ? void 0 : _a2.light), !!lightSurface && { surface: lightSurface }),
          dark: __spreadValues$5(__spreadValues$5({}, (_b = semantic == null ? void 0 : semantic.colorScheme) == null ? void 0 : _b.dark), !!darkSurface && { surface: darkSurface })
        }
      };
      _preset = __spreadProps$1(__spreadValues$5({}, _preset), { semantic: __spreadValues$5(__spreadValues$5({}, semantic), newColorScheme) });
      return this;
    },
    // actions
    define({ useDefaultPreset = false, useDefaultOptions = false } = {}) {
      return {
        preset: useDefaultPreset ? config_default$1.getPreset() : _preset,
        options: useDefaultOptions ? config_default$1.getOptions() : _options
      };
    },
    update({ mergePresets = true, mergeOptions: mergeOptions2 = true } = {}) {
      const newTheme = {
        preset: mergePresets ? mergeKeys$2(config_default$1.getPreset(), _preset) : _preset,
        options: mergeOptions2 ? __spreadValues$5(__spreadValues$5({}, config_default$1.getOptions()), _options) : _options
      };
      config_default$1.setTheme(newTheme);
      return newTheme;
    },
    use(options5) {
      const newTheme = this.define(options5);
      config_default$1.setTheme(newTheme);
      return newTheme;
    }
  };
}, "$t$1");
function toVariables_default$1(theme47, options5 = {}) {
  const VARIABLE = config_default$1.defaults.variable;
  const { prefix: prefix2 = VARIABLE.prefix, selector = VARIABLE.selector, excludedKeyRegex = VARIABLE.excludedKeyRegex } = options5;
  const _toVariables = /* @__PURE__ */ __name((_theme, _prefix = "") => {
    return Object.entries(_theme).reduce(
      (acc, [key, value3]) => {
        const px = matchRegex$2(key, excludedKeyRegex) ? toNormalizeVariable$1(_prefix) : toNormalizeVariable$1(_prefix, toKebabCase$2(key));
        const v2 = toValue$5(value3);
        if (isObject$g(v2)) {
          const { variables: variables2, tokens: tokens2 } = _toVariables(v2, px);
          merge$3(acc["tokens"], tokens2);
          merge$3(acc["variables"], variables2);
        } else {
          acc["tokens"].push((prefix2 ? px.replace(`${prefix2}-`, "") : px).replaceAll("-", "."));
          setProperty$1(acc["variables"], getVariableName$1(px), getVariableValue$1(v2, px, prefix2, [excludedKeyRegex]));
        }
        return acc;
      },
      { variables: [], tokens: [] }
    );
  }, "_toVariables");
  const { variables, tokens } = _toVariables(theme47, prefix2);
  return {
    value: variables,
    tokens,
    declarations: variables.join(""),
    css: getRule$1(selector, variables.join(""))
  };
}
__name(toVariables_default$1, "toVariables_default$1");
var themeUtils_default$1 = {
  regex: {
    rules: {
      class: {
        pattern: /^\.([a-zA-Z][\w-]*)$/,
        resolve(value3) {
          return { type: "class", selector: value3, matched: this.pattern.test(value3.trim()) };
        }
      },
      attr: {
        pattern: /^\[(.*)\]$/,
        resolve(value3) {
          return { type: "attr", selector: `:root${value3}`, matched: this.pattern.test(value3.trim()) };
        }
      },
      media: {
        pattern: /^@media (.*)$/,
        resolve(value3) {
          return { type: "media", selector: `${value3}{:root{[CSS]}}`, matched: this.pattern.test(value3.trim()) };
        }
      },
      system: {
        pattern: /^system$/,
        resolve(value3) {
          return { type: "system", selector: "@media (prefers-color-scheme: dark){:root{[CSS]}}", matched: this.pattern.test(value3.trim()) };
        }
      },
      custom: {
        resolve(value3) {
          return { type: "custom", selector: value3, matched: true };
        }
      }
    },
    resolve(value3) {
      const rules = Object.keys(this.rules).filter((k2) => k2 !== "custom").map((r2) => this.rules[r2]);
      return [value3].flat().map((v2) => {
        var _a2;
        return (_a2 = rules.map((r2) => r2.resolve(v2)).find((rr) => rr.matched)) != null ? _a2 : this.rules.custom.resolve(v2);
      });
    }
  },
  _toVariables(theme47, options5) {
    return toVariables_default$1(theme47, { prefix: options5 == null ? void 0 : options5.prefix });
  },
  getCommon({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _e, _f, _g, _h, _i, _j, _k;
    const { preset, options: options5 } = theme47;
    let primitive_css, primitive_tokens, semantic_css, semantic_tokens, global_css, global_tokens, style2;
    if (isNotEmpty$2(preset) && options5.transform !== "strict") {
      const { primitive, semantic, extend: extend5 } = preset;
      const _a2 = semantic || {}, { colorScheme } = _a2, sRest = __objRest$1(_a2, ["colorScheme"]);
      const _b = extend5 || {}, { colorScheme: eColorScheme } = _b, eRest = __objRest$1(_b, ["colorScheme"]);
      const _c = colorScheme || {}, { dark: dark2 } = _c, csRest = __objRest$1(_c, ["dark"]);
      const _d = eColorScheme || {}, { dark: eDark } = _d, ecsRest = __objRest$1(_d, ["dark"]);
      const prim_var = isNotEmpty$2(primitive) ? this._toVariables({ primitive }, options5) : {};
      const sRest_var = isNotEmpty$2(sRest) ? this._toVariables({ semantic: sRest }, options5) : {};
      const csRest_var = isNotEmpty$2(csRest) ? this._toVariables({ light: csRest }, options5) : {};
      const csDark_var = isNotEmpty$2(dark2) ? this._toVariables({ dark: dark2 }, options5) : {};
      const eRest_var = isNotEmpty$2(eRest) ? this._toVariables({ semantic: eRest }, options5) : {};
      const ecsRest_var = isNotEmpty$2(ecsRest) ? this._toVariables({ light: ecsRest }, options5) : {};
      const ecsDark_var = isNotEmpty$2(eDark) ? this._toVariables({ dark: eDark }, options5) : {};
      const [prim_css, prim_tokens] = [(_e = prim_var.declarations) != null ? _e : "", prim_var.tokens];
      const [sRest_css, sRest_tokens] = [(_f = sRest_var.declarations) != null ? _f : "", sRest_var.tokens || []];
      const [csRest_css, csRest_tokens] = [(_g = csRest_var.declarations) != null ? _g : "", csRest_var.tokens || []];
      const [csDark_css, csDark_tokens] = [(_h = csDark_var.declarations) != null ? _h : "", csDark_var.tokens || []];
      const [eRest_css, eRest_tokens] = [(_i = eRest_var.declarations) != null ? _i : "", eRest_var.tokens || []];
      const [ecsRest_css, ecsRest_tokens] = [(_j = ecsRest_var.declarations) != null ? _j : "", ecsRest_var.tokens || []];
      const [ecsDark_css, ecsDark_tokens] = [(_k = ecsDark_var.declarations) != null ? _k : "", ecsDark_var.tokens || []];
      primitive_css = this.transformCSS(name2, prim_css, "light", "variable", options5, set3, defaults2);
      primitive_tokens = prim_tokens;
      const semantic_light_css = this.transformCSS(name2, `${sRest_css}${csRest_css}`, "light", "variable", options5, set3, defaults2);
      const semantic_dark_css = this.transformCSS(name2, `${csDark_css}`, "dark", "variable", options5, set3, defaults2);
      semantic_css = `${semantic_light_css}${semantic_dark_css}`;
      semantic_tokens = [.../* @__PURE__ */ new Set([...sRest_tokens, ...csRest_tokens, ...csDark_tokens])];
      const global_light_css = this.transformCSS(name2, `${eRest_css}${ecsRest_css}color-scheme:light`, "light", "variable", options5, set3, defaults2);
      const global_dark_css = this.transformCSS(name2, `${ecsDark_css}color-scheme:dark`, "dark", "variable", options5, set3, defaults2);
      global_css = `${global_light_css}${global_dark_css}`;
      global_tokens = [.../* @__PURE__ */ new Set([...eRest_tokens, ...ecsRest_tokens, ...ecsDark_tokens])];
      style2 = resolve$4(preset.css, { dt: dt$1 });
    }
    return {
      primitive: {
        css: primitive_css,
        tokens: primitive_tokens
      },
      semantic: {
        css: semantic_css,
        tokens: semantic_tokens
      },
      global: {
        css: global_css,
        tokens: global_tokens
      },
      style: style2
    };
  },
  getPreset({ name: name2 = "", preset = {}, options: options5, params, set: set3, defaults: defaults2, selector }) {
    var _e, _f, _g;
    let p_css, p_tokens, p_style;
    if (isNotEmpty$2(preset) && options5.transform !== "strict") {
      const _name = name2.replace("-directive", "");
      const _a2 = preset, { colorScheme, extend: extend5, css: css22 } = _a2, vRest = __objRest$1(_a2, ["colorScheme", "extend", "css"]);
      const _b = extend5 || {}, { colorScheme: eColorScheme } = _b, evRest = __objRest$1(_b, ["colorScheme"]);
      const _c = colorScheme || {}, { dark: dark2 } = _c, csRest = __objRest$1(_c, ["dark"]);
      const _d = eColorScheme || {}, { dark: ecsDark } = _d, ecsRest = __objRest$1(_d, ["dark"]);
      const vRest_var = isNotEmpty$2(vRest) ? this._toVariables({ [_name]: __spreadValues$5(__spreadValues$5({}, vRest), evRest) }, options5) : {};
      const csRest_var = isNotEmpty$2(csRest) ? this._toVariables({ [_name]: __spreadValues$5(__spreadValues$5({}, csRest), ecsRest) }, options5) : {};
      const csDark_var = isNotEmpty$2(dark2) ? this._toVariables({ [_name]: __spreadValues$5(__spreadValues$5({}, dark2), ecsDark) }, options5) : {};
      const [vRest_css, vRest_tokens] = [(_e = vRest_var.declarations) != null ? _e : "", vRest_var.tokens || []];
      const [csRest_css, csRest_tokens] = [(_f = csRest_var.declarations) != null ? _f : "", csRest_var.tokens || []];
      const [csDark_css, csDark_tokens] = [(_g = csDark_var.declarations) != null ? _g : "", csDark_var.tokens || []];
      const light_variable_css = this.transformCSS(_name, `${vRest_css}${csRest_css}`, "light", "variable", options5, set3, defaults2, selector);
      const dark_variable_css = this.transformCSS(_name, csDark_css, "dark", "variable", options5, set3, defaults2, selector);
      p_css = `${light_variable_css}${dark_variable_css}`;
      p_tokens = [.../* @__PURE__ */ new Set([...vRest_tokens, ...csRest_tokens, ...csDark_tokens])];
      p_style = resolve$4(css22, { dt: dt$1 });
    }
    return {
      css: p_css,
      tokens: p_tokens,
      style: p_style
    };
  },
  getPresetC({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _a2;
    const { preset, options: options5 } = theme47;
    const cPreset = (_a2 = preset == null ? void 0 : preset.components) == null ? void 0 : _a2[name2];
    return this.getPreset({ name: name2, preset: cPreset, options: options5, params, set: set3, defaults: defaults2 });
  },
  getPresetD({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _a2;
    const dName = name2.replace("-directive", "");
    const { preset, options: options5 } = theme47;
    const dPreset = (_a2 = preset == null ? void 0 : preset.directives) == null ? void 0 : _a2[dName];
    return this.getPreset({ name: dName, preset: dPreset, options: options5, params, set: set3, defaults: defaults2 });
  },
  applyDarkColorScheme(options5) {
    return !(options5.darkModeSelector === "none" || options5.darkModeSelector === false);
  },
  getColorSchemeOption(options5, defaults2) {
    var _a2;
    return this.applyDarkColorScheme(options5) ? this.regex.resolve(options5.darkModeSelector === true ? defaults2.options.darkModeSelector : (_a2 = options5.darkModeSelector) != null ? _a2 : defaults2.options.darkModeSelector) : [];
  },
  getLayerOrder(name2, options5 = {}, params, defaults2) {
    const { cssLayer } = options5;
    if (cssLayer) {
      const order = resolve$4(cssLayer.order || "primeui", params);
      return `@layer ${order}`;
    }
    return "";
  },
  getCommonStyleSheet({ name: name2 = "", theme: theme47 = {}, params, props = {}, set: set3, defaults: defaults2 }) {
    const common = this.getCommon({ name: name2, theme: theme47, params, set: set3, defaults: defaults2 });
    const _props = Object.entries(props).reduce((acc, [k2, v2]) => acc.push(`${k2}="${v2}"`) && acc, []).join(" ");
    return Object.entries(common || {}).reduce((acc, [key, value3]) => {
      if (value3 == null ? void 0 : value3.css) {
        const _css = minifyCSS$2(value3 == null ? void 0 : value3.css);
        const id4 = `${key}-variables`;
        acc.push(`<style type="text/css" data-primevue-style-id="${id4}" ${_props}>${_css}</style>`);
      }
      return acc;
    }, []).join("");
  },
  getStyleSheet({ name: name2 = "", theme: theme47 = {}, params, props = {}, set: set3, defaults: defaults2 }) {
    var _a2;
    const options5 = { name: name2, theme: theme47, params, set: set3, defaults: defaults2 };
    const preset_css = (_a2 = name2.includes("-directive") ? this.getPresetD(options5) : this.getPresetC(options5)) == null ? void 0 : _a2.css;
    const _props = Object.entries(props).reduce((acc, [k2, v2]) => acc.push(`${k2}="${v2}"`) && acc, []).join(" ");
    return preset_css ? `<style type="text/css" data-primevue-style-id="${name2}-variables" ${_props}>${minifyCSS$2(preset_css)}</style>` : "";
  },
  createTokens(obj = {}, defaults2, parentKey = "", parentPath = "", tokens = {}) {
    Object.entries(obj).forEach(([key, value3]) => {
      const currentKey = matchRegex$2(key, defaults2.variable.excludedKeyRegex) ? parentKey : parentKey ? `${parentKey}.${toTokenKey$4(key)}` : toTokenKey$4(key);
      const currentPath = parentPath ? `${parentPath}.${key}` : key;
      if (isObject$g(value3)) {
        this.createTokens(value3, defaults2, currentKey, currentPath, tokens);
      } else {
        tokens[currentKey] || (tokens[currentKey] = {
          paths: [],
          computed(colorScheme, tokenPathMap = {}) {
            var _a2, _b;
            if (this.paths.length === 1) {
              return (_a2 = this.paths[0]) == null ? void 0 : _a2.computed(this.paths[0].scheme, tokenPathMap["binding"]);
            } else if (colorScheme && colorScheme !== "none") {
              return (_b = this.paths.find((p2) => p2.scheme === colorScheme)) == null ? void 0 : _b.computed(colorScheme, tokenPathMap["binding"]);
            }
            return this.paths.map((p2) => p2.computed(p2.scheme, tokenPathMap[p2.scheme]));
          }
        });
        tokens[currentKey].paths.push({
          path: currentPath,
          value: value3,
          scheme: currentPath.includes("colorScheme.light") ? "light" : currentPath.includes("colorScheme.dark") ? "dark" : "none",
          computed(colorScheme, tokenPathMap = {}) {
            const regex2 = /{([^}]*)}/g;
            let computedValue = value3;
            tokenPathMap["name"] = this.path;
            tokenPathMap["binding"] || (tokenPathMap["binding"] = {});
            if (matchRegex$2(value3, regex2)) {
              const val = value3.trim();
              const _val = val.replaceAll(regex2, (v2) => {
                var _a2;
                const path = v2.replace(/{|}/g, "");
                const computed2 = (_a2 = tokens[path]) == null ? void 0 : _a2.computed(colorScheme, tokenPathMap);
                return isArray$c(computed2) && computed2.length === 2 ? `light-dark(${computed2[0].value},${computed2[1].value})` : computed2 == null ? void 0 : computed2.value;
              });
              const calculationRegex = /(\d+\w*\s+[\+\-\*\/]\s+\d+\w*)/g;
              const cleanedVarRegex = /var\([^)]+\)/g;
              computedValue = matchRegex$2(_val.replace(cleanedVarRegex, "0"), calculationRegex) ? `calc(${_val})` : _val;
            }
            isEmpty$3(tokenPathMap["binding"]) && delete tokenPathMap["binding"];
            return {
              colorScheme,
              path: this.path,
              paths: tokenPathMap,
              value: computedValue.includes("undefined") ? void 0 : computedValue
            };
          }
        });
      }
    });
    return tokens;
  },
  getTokenValue(tokens, path, defaults2) {
    var _a2;
    const normalizePath2 = /* @__PURE__ */ __name((str) => {
      const strArr = str.split(".");
      return strArr.filter((s2) => !matchRegex$2(s2.toLowerCase(), defaults2.variable.excludedKeyRegex)).join(".");
    }, "normalizePath");
    const token = normalizePath2(path);
    const colorScheme = path.includes("colorScheme.light") ? "light" : path.includes("colorScheme.dark") ? "dark" : void 0;
    const computedValues = [(_a2 = tokens[token]) == null ? void 0 : _a2.computed(colorScheme)].flat().filter((computed2) => computed2);
    return computedValues.length === 1 ? computedValues[0].value : computedValues.reduce((acc = {}, computed2) => {
      const _a22 = computed2, { colorScheme: cs } = _a22, rest = __objRest$1(_a22, ["colorScheme"]);
      acc[cs] = rest;
      return acc;
    }, void 0);
  },
  getSelectorRule(selector1, selector2, type, css22) {
    return type === "class" || type === "attr" ? getRule$1(isNotEmpty$2(selector2) ? `${selector1}${selector2},${selector1} ${selector2}` : selector1, css22) : getRule$1(selector1, isNotEmpty$2(selector2) ? getRule$1(selector2, css22) : css22);
  },
  transformCSS(name2, css22, mode2, type, options5 = {}, set3, defaults2, selector) {
    if (isNotEmpty$2(css22)) {
      const { cssLayer } = options5;
      if (type !== "style") {
        const colorSchemeOption = this.getColorSchemeOption(options5, defaults2);
        css22 = mode2 === "dark" ? colorSchemeOption.reduce((acc, { type: type2, selector: _selector }) => {
          if (isNotEmpty$2(_selector)) {
            acc += _selector.includes("[CSS]") ? _selector.replace("[CSS]", css22) : this.getSelectorRule(_selector, selector, type2, css22);
          }
          return acc;
        }, "") : getRule$1(selector != null ? selector : ":root", css22);
      }
      if (cssLayer) {
        const layerOptions = {
          name: "primeui",
          order: "primeui"
        };
        isObject$g(cssLayer) && (layerOptions.name = resolve$4(cssLayer.name, { name: name2, type }));
        if (isNotEmpty$2(layerOptions.name)) {
          css22 = getRule$1(`@layer ${layerOptions.name}`, css22);
          set3 == null ? void 0 : set3.layerNames(layerOptions.name);
        }
      }
      return css22;
    }
    return "";
  }
};
var config_default$1 = {
  defaults: {
    variable: {
      prefix: "p",
      selector: ":root",
      excludedKeyRegex: /^(primitive|semantic|components|directives|variables|colorscheme|light|dark|common|root|states|extend|css)$/gi
    },
    options: {
      prefix: "p",
      darkModeSelector: "system",
      cssLayer: false
    }
  },
  _theme: void 0,
  _layerNames: /* @__PURE__ */ new Set(),
  _loadedStyleNames: /* @__PURE__ */ new Set(),
  _loadingStyles: /* @__PURE__ */ new Set(),
  _tokens: {},
  update(newValues = {}) {
    const { theme: theme47 } = newValues;
    if (theme47) {
      this._theme = __spreadProps$1(__spreadValues$5({}, theme47), {
        options: __spreadValues$5(__spreadValues$5({}, this.defaults.options), theme47.options)
      });
      this._tokens = themeUtils_default$1.createTokens(this.preset, this.defaults);
      this.clearLoadedStyleNames();
    }
  },
  get theme() {
    return this._theme;
  },
  get preset() {
    var _a2;
    return ((_a2 = this.theme) == null ? void 0 : _a2.preset) || {};
  },
  get options() {
    var _a2;
    return ((_a2 = this.theme) == null ? void 0 : _a2.options) || {};
  },
  get tokens() {
    return this._tokens;
  },
  getTheme() {
    return this.theme;
  },
  setTheme(newValue2) {
    this.update({ theme: newValue2 });
    service_default$1.emit("theme:change", newValue2);
  },
  getPreset() {
    return this.preset;
  },
  setPreset(newValue2) {
    this._theme = __spreadProps$1(__spreadValues$5({}, this.theme), { preset: newValue2 });
    this._tokens = themeUtils_default$1.createTokens(newValue2, this.defaults);
    this.clearLoadedStyleNames();
    service_default$1.emit("preset:change", newValue2);
    service_default$1.emit("theme:change", this.theme);
  },
  getOptions() {
    return this.options;
  },
  setOptions(newValue2) {
    this._theme = __spreadProps$1(__spreadValues$5({}, this.theme), { options: newValue2 });
    this.clearLoadedStyleNames();
    service_default$1.emit("options:change", newValue2);
    service_default$1.emit("theme:change", this.theme);
  },
  getLayerNames() {
    return [...this._layerNames];
  },
  setLayerNames(layerName) {
    this._layerNames.add(layerName);
  },
  getLoadedStyleNames() {
    return this._loadedStyleNames;
  },
  isStyleNameLoaded(name2) {
    return this._loadedStyleNames.has(name2);
  },
  setLoadedStyleName(name2) {
    this._loadedStyleNames.add(name2);
  },
  deleteLoadedStyleName(name2) {
    this._loadedStyleNames.delete(name2);
  },
  clearLoadedStyleNames() {
    this._loadedStyleNames.clear();
  },
  getTokenValue(tokenPath) {
    return themeUtils_default$1.getTokenValue(this.tokens, tokenPath, this.defaults);
  },
  getCommon(name2 = "", params) {
    return themeUtils_default$1.getCommon({ name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  getComponent(name2 = "", params) {
    const options5 = { name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default$1.getPresetC(options5);
  },
  getDirective(name2 = "", params) {
    const options5 = { name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default$1.getPresetD(options5);
  },
  getCustomPreset(name2 = "", preset, selector, params) {
    const options5 = { name: name2, preset, options: this.options, selector, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default$1.getPreset(options5);
  },
  getLayerOrderCSS(name2 = "") {
    return themeUtils_default$1.getLayerOrder(name2, this.options, { names: this.getLayerNames() }, this.defaults);
  },
  transformCSS(name2 = "", css22, type = "style", mode2) {
    return themeUtils_default$1.transformCSS(name2, css22, mode2, type, this.options, { layerNames: this.setLayerNames.bind(this) }, this.defaults);
  },
  getCommonStyleSheet(name2 = "", params, props = {}) {
    return themeUtils_default$1.getCommonStyleSheet({ name: name2, theme: this.theme, params, props, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  getStyleSheet(name2, params, props = {}) {
    return themeUtils_default$1.getStyleSheet({ name: name2, theme: this.theme, params, props, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  onStyleMounted(name2) {
    this._loadingStyles.add(name2);
  },
  onStyleUpdated(name2) {
    this._loadingStyles.add(name2);
  },
  onStyleLoaded(event, { name: name2 }) {
    if (this._loadingStyles.size) {
      this._loadingStyles.delete(name2);
      service_default$1.emit(`theme:${name2}:load`, event);
      !this._loadingStyles.size && service_default$1.emit("theme:load");
    }
  }
};
function updatePreset$1(...presets) {
  const newPreset = mergeKeys$2(config_default$1.getPreset(), ...presets);
  config_default$1.setPreset(newPreset);
  return newPreset;
}
__name(updatePreset$1, "updatePreset$1");
function updatePrimaryPalette$1(primary) {
  return $t$1().primaryPalette(primary).update().preset;
}
__name(updatePrimaryPalette$1, "updatePrimaryPalette$1");
function updateSurfacePalette$1(palette) {
  return $t$1().surfacePalette(palette).update().preset;
}
__name(updateSurfacePalette$1, "updateSurfacePalette$1");
function usePreset$1(...presets) {
  const newPreset = mergeKeys$2(...presets);
  config_default$1.setPreset(newPreset);
  return newPreset;
}
__name(usePreset$1, "usePreset$1");
function useTheme$1(theme47) {
  return $t$1(theme47).update({ mergePresets: false });
}
__name(useTheme$1, "useTheme$1");
var index$1r = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  panel: {
    borderWidth: "0 0 1px 0",
    borderColor: "{content.border.color}"
  },
  header: {
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{text.color}",
    padding: "1.125rem",
    fontWeight: "600",
    borderRadius: "0",
    borderWidth: "0",
    borderColor: "{content.border.color}",
    background: "{content.background}",
    hoverBackground: "{content.background}",
    activeBackground: "{content.background}",
    activeHoverBackground: "{content.background}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    },
    toggleIcon: {
      color: "{text.muted.color}",
      hoverColor: "{text.color}",
      activeColor: "{text.color}",
      activeHoverColor: "{text.color}"
    },
    first: {
      topBorderRadius: "{content.border.radius}",
      borderWidth: "0"
    },
    last: {
      bottomBorderRadius: "{content.border.radius}",
      activeBottomBorderRadius: "0"
    }
  },
  content: {
    borderWidth: "0",
    borderColor: "{content.border.color}",
    background: "{content.background}",
    color: "{text.color}",
    padding: "0 1.125rem 1.125rem 1.125rem"
  }
};
var index$1q = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}"
  },
  list: {
    padding: "{list.padding}",
    gap: "{list.gap}"
  },
  option: {
    focusBackground: "{list.option.focus.background}",
    selectedBackground: "{list.option.selected.background}",
    selectedFocusBackground: "{list.option.selected.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    selectedColor: "{list.option.selected.color}",
    selectedFocusColor: "{list.option.selected.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}"
  },
  optionGroup: {
    background: "{list.option.group.background}",
    color: "{list.option.group.color}",
    fontWeight: "{list.option.group.font.weight}",
    padding: "{list.option.group.padding}"
  },
  dropdown: {
    width: "2.5rem",
    sm: {
      width: "2rem"
    },
    lg: {
      width: "3rem"
    },
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.border.color}",
    activeBorderColor: "{form.field.border.color}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  chip: {
    borderRadius: "{border.radius.sm}"
  },
  emptyMessage: {
    padding: "{list.option.padding}"
  },
  colorScheme: {
    light: {
      chip: {
        focusBackground: "{surface.200}",
        focusColor: "{surface.800}"
      },
      dropdown: {
        background: "{surface.100}",
        hoverBackground: "{surface.200}",
        activeBackground: "{surface.300}",
        color: "{surface.600}",
        hoverColor: "{surface.700}",
        activeColor: "{surface.800}"
      }
    },
    dark: {
      chip: {
        focusBackground: "{surface.700}",
        focusColor: "{surface.0}"
      },
      dropdown: {
        background: "{surface.800}",
        hoverBackground: "{surface.700}",
        activeBackground: "{surface.600}",
        color: "{surface.300}",
        hoverColor: "{surface.200}",
        activeColor: "{surface.100}"
      }
    }
  }
};
var index$1p = {
  root: {
    width: "2rem",
    height: "2rem",
    fontSize: "1rem",
    background: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}"
  },
  icon: {
    size: "1rem"
  },
  group: {
    borderColor: "{content.background}",
    offset: "-0.75rem"
  },
  lg: {
    width: "3rem",
    height: "3rem",
    fontSize: "1.5rem",
    icon: {
      size: "1.5rem"
    },
    group: {
      offset: "-1rem"
    }
  },
  xl: {
    width: "4rem",
    height: "4rem",
    fontSize: "2rem",
    icon: {
      size: "2rem"
    },
    group: {
      offset: "-1.5rem"
    }
  }
};
var index$1o = {
  root: {
    borderRadius: "{border.radius.md}",
    padding: "0 0.5rem",
    fontSize: "0.75rem",
    fontWeight: "700",
    minWidth: "1.5rem",
    height: "1.5rem"
  },
  dot: {
    size: "0.5rem"
  },
  sm: {
    fontSize: "0.625rem",
    minWidth: "1.25rem",
    height: "1.25rem"
  },
  lg: {
    fontSize: "0.875rem",
    minWidth: "1.75rem",
    height: "1.75rem"
  },
  xl: {
    fontSize: "1rem",
    minWidth: "2rem",
    height: "2rem"
  },
  colorScheme: {
    light: {
      primary: {
        background: "{primary.color}",
        color: "{primary.contrast.color}"
      },
      secondary: {
        background: "{surface.100}",
        color: "{surface.600}"
      },
      success: {
        background: "{green.500}",
        color: "{surface.0}"
      },
      info: {
        background: "{sky.500}",
        color: "{surface.0}"
      },
      warn: {
        background: "{orange.500}",
        color: "{surface.0}"
      },
      danger: {
        background: "{red.500}",
        color: "{surface.0}"
      },
      contrast: {
        background: "{surface.950}",
        color: "{surface.0}"
      }
    },
    dark: {
      primary: {
        background: "{primary.color}",
        color: "{primary.contrast.color}"
      },
      secondary: {
        background: "{surface.800}",
        color: "{surface.300}"
      },
      success: {
        background: "{green.400}",
        color: "{green.950}"
      },
      info: {
        background: "{sky.400}",
        color: "{sky.950}"
      },
      warn: {
        background: "{orange.400}",
        color: "{orange.950}"
      },
      danger: {
        background: "{red.400}",
        color: "{red.950}"
      },
      contrast: {
        background: "{surface.0}",
        color: "{surface.950}"
      }
    }
  }
};
var index$1n = {
  primitive: {
    borderRadius: {
      none: "0",
      xs: "2px",
      sm: "4px",
      md: "6px",
      lg: "8px",
      xl: "12px"
    },
    emerald: {
      50: "#ecfdf5",
      100: "#d1fae5",
      200: "#a7f3d0",
      300: "#6ee7b7",
      400: "#34d399",
      500: "#10b981",
      600: "#059669",
      700: "#047857",
      800: "#065f46",
      900: "#064e3b",
      950: "#022c22"
    },
    green: {
      50: "#f0fdf4",
      100: "#dcfce7",
      200: "#bbf7d0",
      300: "#86efac",
      400: "#4ade80",
      500: "#22c55e",
      600: "#16a34a",
      700: "#15803d",
      800: "#166534",
      900: "#14532d",
      950: "#052e16"
    },
    lime: {
      50: "#f7fee7",
      100: "#ecfccb",
      200: "#d9f99d",
      300: "#bef264",
      400: "#a3e635",
      500: "#84cc16",
      600: "#65a30d",
      700: "#4d7c0f",
      800: "#3f6212",
      900: "#365314",
      950: "#1a2e05"
    },
    red: {
      50: "#fef2f2",
      100: "#fee2e2",
      200: "#fecaca",
      300: "#fca5a5",
      400: "#f87171",
      500: "#ef4444",
      600: "#dc2626",
      700: "#b91c1c",
      800: "#991b1b",
      900: "#7f1d1d",
      950: "#450a0a"
    },
    orange: {
      50: "#fff7ed",
      100: "#ffedd5",
      200: "#fed7aa",
      300: "#fdba74",
      400: "#fb923c",
      500: "#f97316",
      600: "#ea580c",
      700: "#c2410c",
      800: "#9a3412",
      900: "#7c2d12",
      950: "#431407"
    },
    amber: {
      50: "#fffbeb",
      100: "#fef3c7",
      200: "#fde68a",
      300: "#fcd34d",
      400: "#fbbf24",
      500: "#f59e0b",
      600: "#d97706",
      700: "#b45309",
      800: "#92400e",
      900: "#78350f",
      950: "#451a03"
    },
    yellow: {
      50: "#fefce8",
      100: "#fef9c3",
      200: "#fef08a",
      300: "#fde047",
      400: "#facc15",
      500: "#eab308",
      600: "#ca8a04",
      700: "#a16207",
      800: "#854d0e",
      900: "#713f12",
      950: "#422006"
    },
    teal: {
      50: "#f0fdfa",
      100: "#ccfbf1",
      200: "#99f6e4",
      300: "#5eead4",
      400: "#2dd4bf",
      500: "#14b8a6",
      600: "#0d9488",
      700: "#0f766e",
      800: "#115e59",
      900: "#134e4a",
      950: "#042f2e"
    },
    cyan: {
      50: "#ecfeff",
      100: "#cffafe",
      200: "#a5f3fc",
      300: "#67e8f9",
      400: "#22d3ee",
      500: "#06b6d4",
      600: "#0891b2",
      700: "#0e7490",
      800: "#155e75",
      900: "#164e63",
      950: "#083344"
    },
    sky: {
      50: "#f0f9ff",
      100: "#e0f2fe",
      200: "#bae6fd",
      300: "#7dd3fc",
      400: "#38bdf8",
      500: "#0ea5e9",
      600: "#0284c7",
      700: "#0369a1",
      800: "#075985",
      900: "#0c4a6e",
      950: "#082f49"
    },
    blue: {
      50: "#eff6ff",
      100: "#dbeafe",
      200: "#bfdbfe",
      300: "#93c5fd",
      400: "#60a5fa",
      500: "#3b82f6",
      600: "#2563eb",
      700: "#1d4ed8",
      800: "#1e40af",
      900: "#1e3a8a",
      950: "#172554"
    },
    indigo: {
      50: "#eef2ff",
      100: "#e0e7ff",
      200: "#c7d2fe",
      300: "#a5b4fc",
      400: "#818cf8",
      500: "#6366f1",
      600: "#4f46e5",
      700: "#4338ca",
      800: "#3730a3",
      900: "#312e81",
      950: "#1e1b4b"
    },
    violet: {
      50: "#f5f3ff",
      100: "#ede9fe",
      200: "#ddd6fe",
      300: "#c4b5fd",
      400: "#a78bfa",
      500: "#8b5cf6",
      600: "#7c3aed",
      700: "#6d28d9",
      800: "#5b21b6",
      900: "#4c1d95",
      950: "#2e1065"
    },
    purple: {
      50: "#faf5ff",
      100: "#f3e8ff",
      200: "#e9d5ff",
      300: "#d8b4fe",
      400: "#c084fc",
      500: "#a855f7",
      600: "#9333ea",
      700: "#7e22ce",
      800: "#6b21a8",
      900: "#581c87",
      950: "#3b0764"
    },
    fuchsia: {
      50: "#fdf4ff",
      100: "#fae8ff",
      200: "#f5d0fe",
      300: "#f0abfc",
      400: "#e879f9",
      500: "#d946ef",
      600: "#c026d3",
      700: "#a21caf",
      800: "#86198f",
      900: "#701a75",
      950: "#4a044e"
    },
    pink: {
      50: "#fdf2f8",
      100: "#fce7f3",
      200: "#fbcfe8",
      300: "#f9a8d4",
      400: "#f472b6",
      500: "#ec4899",
      600: "#db2777",
      700: "#be185d",
      800: "#9d174d",
      900: "#831843",
      950: "#500724"
    },
    rose: {
      50: "#fff1f2",
      100: "#ffe4e6",
      200: "#fecdd3",
      300: "#fda4af",
      400: "#fb7185",
      500: "#f43f5e",
      600: "#e11d48",
      700: "#be123c",
      800: "#9f1239",
      900: "#881337",
      950: "#4c0519"
    },
    slate: {
      50: "#f8fafc",
      100: "#f1f5f9",
      200: "#e2e8f0",
      300: "#cbd5e1",
      400: "#94a3b8",
      500: "#64748b",
      600: "#475569",
      700: "#334155",
      800: "#1e293b",
      900: "#0f172a",
      950: "#020617"
    },
    gray: {
      50: "#f9fafb",
      100: "#f3f4f6",
      200: "#e5e7eb",
      300: "#d1d5db",
      400: "#9ca3af",
      500: "#6b7280",
      600: "#4b5563",
      700: "#374151",
      800: "#1f2937",
      900: "#111827",
      950: "#030712"
    },
    zinc: {
      50: "#fafafa",
      100: "#f4f4f5",
      200: "#e4e4e7",
      300: "#d4d4d8",
      400: "#a1a1aa",
      500: "#71717a",
      600: "#52525b",
      700: "#3f3f46",
      800: "#27272a",
      900: "#18181b",
      950: "#09090b"
    },
    neutral: {
      50: "#fafafa",
      100: "#f5f5f5",
      200: "#e5e5e5",
      300: "#d4d4d4",
      400: "#a3a3a3",
      500: "#737373",
      600: "#525252",
      700: "#404040",
      800: "#262626",
      900: "#171717",
      950: "#0a0a0a"
    },
    stone: {
      50: "#fafaf9",
      100: "#f5f5f4",
      200: "#e7e5e4",
      300: "#d6d3d1",
      400: "#a8a29e",
      500: "#78716c",
      600: "#57534e",
      700: "#44403c",
      800: "#292524",
      900: "#1c1917",
      950: "#0c0a09"
    }
  },
  semantic: {
    transitionDuration: "0.2s",
    focusRing: {
      width: "1px",
      style: "solid",
      color: "{primary.color}",
      offset: "2px",
      shadow: "none"
    },
    disabledOpacity: "0.6",
    iconSize: "1rem",
    anchorGutter: "2px",
    primary: {
      50: "{emerald.50}",
      100: "{emerald.100}",
      200: "{emerald.200}",
      300: "{emerald.300}",
      400: "{emerald.400}",
      500: "{emerald.500}",
      600: "{emerald.600}",
      700: "{emerald.700}",
      800: "{emerald.800}",
      900: "{emerald.900}",
      950: "{emerald.950}"
    },
    formField: {
      paddingX: "0.75rem",
      paddingY: "0.5rem",
      sm: {
        fontSize: "0.875rem",
        paddingX: "0.625rem",
        paddingY: "0.375rem"
      },
      lg: {
        fontSize: "1.125rem",
        paddingX: "0.875rem",
        paddingY: "0.625rem"
      },
      borderRadius: "{border.radius.md}",
      focusRing: {
        width: "0",
        style: "none",
        color: "transparent",
        offset: "0",
        shadow: "none"
      },
      transitionDuration: "{transition.duration}"
    },
    list: {
      padding: "0.25rem 0.25rem",
      gap: "2px",
      header: {
        padding: "0.5rem 1rem 0.25rem 1rem"
      },
      option: {
        padding: "0.5rem 0.75rem",
        borderRadius: "{border.radius.sm}"
      },
      optionGroup: {
        padding: "0.5rem 0.75rem",
        fontWeight: "600"
      }
    },
    content: {
      borderRadius: "{border.radius.md}"
    },
    mask: {
      transitionDuration: "0.15s"
    },
    navigation: {
      list: {
        padding: "0.25rem 0.25rem",
        gap: "2px"
      },
      item: {
        padding: "0.5rem 0.75rem",
        borderRadius: "{border.radius.sm}",
        gap: "0.5rem"
      },
      submenuLabel: {
        padding: "0.5rem 0.75rem",
        fontWeight: "600"
      },
      submenuIcon: {
        size: "0.875rem"
      }
    },
    overlay: {
      select: {
        borderRadius: "{border.radius.md}",
        shadow: "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -2px rgba(0, 0, 0, 0.1)"
      },
      popover: {
        borderRadius: "{border.radius.md}",
        padding: "0.75rem",
        shadow: "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -2px rgba(0, 0, 0, 0.1)"
      },
      modal: {
        borderRadius: "{border.radius.xl}",
        padding: "1.25rem",
        shadow: "0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 8px 10px -6px rgba(0, 0, 0, 0.1)"
      },
      navigation: {
        shadow: "0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -2px rgba(0, 0, 0, 0.1)"
      }
    },
    colorScheme: {
      light: {
        surface: {
          0: "#ffffff",
          50: "{slate.50}",
          100: "{slate.100}",
          200: "{slate.200}",
          300: "{slate.300}",
          400: "{slate.400}",
          500: "{slate.500}",
          600: "{slate.600}",
          700: "{slate.700}",
          800: "{slate.800}",
          900: "{slate.900}",
          950: "{slate.950}"
        },
        primary: {
          color: "{primary.500}",
          contrastColor: "#ffffff",
          hoverColor: "{primary.600}",
          activeColor: "{primary.700}"
        },
        highlight: {
          background: "{primary.50}",
          focusBackground: "{primary.100}",
          color: "{primary.700}",
          focusColor: "{primary.800}"
        },
        mask: {
          background: "rgba(0,0,0,0.4)",
          color: "{surface.200}"
        },
        formField: {
          background: "{surface.0}",
          disabledBackground: "{surface.200}",
          filledBackground: "{surface.50}",
          filledHoverBackground: "{surface.50}",
          filledFocusBackground: "{surface.50}",
          borderColor: "{surface.300}",
          hoverBorderColor: "{surface.400}",
          focusBorderColor: "{primary.color}",
          invalidBorderColor: "{red.400}",
          color: "{surface.700}",
          disabledColor: "{surface.500}",
          placeholderColor: "{surface.500}",
          invalidPlaceholderColor: "{red.600}",
          floatLabelColor: "{surface.500}",
          floatLabelFocusColor: "{primary.600}",
          floatLabelActiveColor: "{surface.500}",
          floatLabelInvalidColor: "{form.field.invalid.placeholder.color}",
          iconColor: "{surface.400}",
          shadow: "0 0 #0000, 0 0 #0000, 0 1px 2px 0 rgba(18, 18, 23, 0.05)"
        },
        text: {
          color: "{surface.700}",
          hoverColor: "{surface.800}",
          mutedColor: "{surface.500}",
          hoverMutedColor: "{surface.600}"
        },
        content: {
          background: "{surface.0}",
          hoverBackground: "{surface.100}",
          borderColor: "{surface.200}",
          color: "{text.color}",
          hoverColor: "{text.hover.color}"
        },
        overlay: {
          select: {
            background: "{surface.0}",
            borderColor: "{surface.200}",
            color: "{text.color}"
          },
          popover: {
            background: "{surface.0}",
            borderColor: "{surface.200}",
            color: "{text.color}"
          },
          modal: {
            background: "{surface.0}",
            borderColor: "{surface.200}",
            color: "{text.color}"
          }
        },
        list: {
          option: {
            focusBackground: "{surface.100}",
            selectedBackground: "{highlight.background}",
            selectedFocusBackground: "{highlight.focus.background}",
            color: "{text.color}",
            focusColor: "{text.hover.color}",
            selectedColor: "{highlight.color}",
            selectedFocusColor: "{highlight.focus.color}",
            icon: {
              color: "{surface.400}",
              focusColor: "{surface.500}"
            }
          },
          optionGroup: {
            background: "transparent",
            color: "{text.muted.color}"
          }
        },
        navigation: {
          item: {
            focusBackground: "{surface.100}",
            activeBackground: "{surface.100}",
            color: "{text.color}",
            focusColor: "{text.hover.color}",
            activeColor: "{text.hover.color}",
            icon: {
              color: "{surface.400}",
              focusColor: "{surface.500}",
              activeColor: "{surface.500}"
            }
          },
          submenuLabel: {
            background: "transparent",
            color: "{text.muted.color}"
          },
          submenuIcon: {
            color: "{surface.400}",
            focusColor: "{surface.500}",
            activeColor: "{surface.500}"
          }
        }
      },
      dark: {
        surface: {
          0: "#ffffff",
          50: "{zinc.50}",
          100: "{zinc.100}",
          200: "{zinc.200}",
          300: "{zinc.300}",
          400: "{zinc.400}",
          500: "{zinc.500}",
          600: "{zinc.600}",
          700: "{zinc.700}",
          800: "{zinc.800}",
          900: "{zinc.900}",
          950: "{zinc.950}"
        },
        primary: {
          color: "{primary.400}",
          contrastColor: "{surface.900}",
          hoverColor: "{primary.300}",
          activeColor: "{primary.200}"
        },
        highlight: {
          background: "color-mix(in srgb, {primary.400}, transparent 84%)",
          focusBackground: "color-mix(in srgb, {primary.400}, transparent 76%)",
          color: "rgba(255,255,255,.87)",
          focusColor: "rgba(255,255,255,.87)"
        },
        mask: {
          background: "rgba(0,0,0,0.6)",
          color: "{surface.200}"
        },
        formField: {
          background: "{surface.950}",
          disabledBackground: "{surface.700}",
          filledBackground: "{surface.800}",
          filledHoverBackground: "{surface.800}",
          filledFocusBackground: "{surface.800}",
          borderColor: "{surface.600}",
          hoverBorderColor: "{surface.500}",
          focusBorderColor: "{primary.color}",
          invalidBorderColor: "{red.300}",
          color: "{surface.0}",
          disabledColor: "{surface.400}",
          placeholderColor: "{surface.400}",
          invalidPlaceholderColor: "{red.400}",
          floatLabelColor: "{surface.400}",
          floatLabelFocusColor: "{primary.color}",
          floatLabelActiveColor: "{surface.400}",
          floatLabelInvalidColor: "{form.field.invalid.placeholder.color}",
          iconColor: "{surface.400}",
          shadow: "0 0 #0000, 0 0 #0000, 0 1px 2px 0 rgba(18, 18, 23, 0.05)"
        },
        text: {
          color: "{surface.0}",
          hoverColor: "{surface.0}",
          mutedColor: "{surface.400}",
          hoverMutedColor: "{surface.300}"
        },
        content: {
          background: "{surface.900}",
          hoverBackground: "{surface.800}",
          borderColor: "{surface.700}",
          color: "{text.color}",
          hoverColor: "{text.hover.color}"
        },
        overlay: {
          select: {
            background: "{surface.900}",
            borderColor: "{surface.700}",
            color: "{text.color}"
          },
          popover: {
            background: "{surface.900}",
            borderColor: "{surface.700}",
            color: "{text.color}"
          },
          modal: {
            background: "{surface.900}",
            borderColor: "{surface.700}",
            color: "{text.color}"
          }
        },
        list: {
          option: {
            focusBackground: "{surface.800}",
            selectedBackground: "{highlight.background}",
            selectedFocusBackground: "{highlight.focus.background}",
            color: "{text.color}",
            focusColor: "{text.hover.color}",
            selectedColor: "{highlight.color}",
            selectedFocusColor: "{highlight.focus.color}",
            icon: {
              color: "{surface.500}",
              focusColor: "{surface.400}"
            }
          },
          optionGroup: {
            background: "transparent",
            color: "{text.muted.color}"
          }
        },
        navigation: {
          item: {
            focusBackground: "{surface.800}",
            activeBackground: "{surface.800}",
            color: "{text.color}",
            focusColor: "{text.hover.color}",
            activeColor: "{text.hover.color}",
            icon: {
              color: "{surface.500}",
              focusColor: "{surface.400}",
              activeColor: "{surface.400}"
            }
          },
          submenuLabel: {
            background: "transparent",
            color: "{text.muted.color}"
          },
          submenuIcon: {
            color: "{surface.500}",
            focusColor: "{surface.400}",
            activeColor: "{surface.400}"
          }
        }
      }
    }
  }
};
var index$1m = {
  root: {
    borderRadius: "{content.border.radius}"
  }
};
var index$1l = {
  root: {
    padding: "1rem",
    background: "{content.background}",
    gap: "0.5rem",
    transitionDuration: "{transition.duration}"
  },
  item: {
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    borderRadius: "{content.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      hoverColor: "{navigation.item.icon.focus.color}"
    },
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  separator: {
    color: "{navigation.item.icon.color}"
  }
};
var index$1k = {
  root: {
    borderRadius: "{form.field.border.radius}",
    roundedBorderRadius: "2rem",
    gap: "0.5rem",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    iconOnlyWidth: "2.5rem",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    },
    label: {
      fontWeight: "500"
    },
    raisedShadow: "0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12)",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      offset: "{focus.ring.offset}"
    },
    badgeSize: "1rem",
    transitionDuration: "{form.field.transition.duration}"
  },
  colorScheme: {
    light: {
      root: {
        primary: {
          background: "{primary.color}",
          hoverBackground: "{primary.hover.color}",
          activeBackground: "{primary.active.color}",
          borderColor: "{primary.color}",
          hoverBorderColor: "{primary.hover.color}",
          activeBorderColor: "{primary.active.color}",
          color: "{primary.contrast.color}",
          hoverColor: "{primary.contrast.color}",
          activeColor: "{primary.contrast.color}",
          focusRing: {
            color: "{primary.color}",
            shadow: "none"
          }
        },
        secondary: {
          background: "{surface.100}",
          hoverBackground: "{surface.200}",
          activeBackground: "{surface.300}",
          borderColor: "{surface.100}",
          hoverBorderColor: "{surface.200}",
          activeBorderColor: "{surface.300}",
          color: "{surface.600}",
          hoverColor: "{surface.700}",
          activeColor: "{surface.800}",
          focusRing: {
            color: "{surface.600}",
            shadow: "none"
          }
        },
        info: {
          background: "{sky.500}",
          hoverBackground: "{sky.600}",
          activeBackground: "{sky.700}",
          borderColor: "{sky.500}",
          hoverBorderColor: "{sky.600}",
          activeBorderColor: "{sky.700}",
          color: "#ffffff",
          hoverColor: "#ffffff",
          activeColor: "#ffffff",
          focusRing: {
            color: "{sky.500}",
            shadow: "none"
          }
        },
        success: {
          background: "{green.500}",
          hoverBackground: "{green.600}",
          activeBackground: "{green.700}",
          borderColor: "{green.500}",
          hoverBorderColor: "{green.600}",
          activeBorderColor: "{green.700}",
          color: "#ffffff",
          hoverColor: "#ffffff",
          activeColor: "#ffffff",
          focusRing: {
            color: "{green.500}",
            shadow: "none"
          }
        },
        warn: {
          background: "{orange.500}",
          hoverBackground: "{orange.600}",
          activeBackground: "{orange.700}",
          borderColor: "{orange.500}",
          hoverBorderColor: "{orange.600}",
          activeBorderColor: "{orange.700}",
          color: "#ffffff",
          hoverColor: "#ffffff",
          activeColor: "#ffffff",
          focusRing: {
            color: "{orange.500}",
            shadow: "none"
          }
        },
        help: {
          background: "{purple.500}",
          hoverBackground: "{purple.600}",
          activeBackground: "{purple.700}",
          borderColor: "{purple.500}",
          hoverBorderColor: "{purple.600}",
          activeBorderColor: "{purple.700}",
          color: "#ffffff",
          hoverColor: "#ffffff",
          activeColor: "#ffffff",
          focusRing: {
            color: "{purple.500}",
            shadow: "none"
          }
        },
        danger: {
          background: "{red.500}",
          hoverBackground: "{red.600}",
          activeBackground: "{red.700}",
          borderColor: "{red.500}",
          hoverBorderColor: "{red.600}",
          activeBorderColor: "{red.700}",
          color: "#ffffff",
          hoverColor: "#ffffff",
          activeColor: "#ffffff",
          focusRing: {
            color: "{red.500}",
            shadow: "none"
          }
        },
        contrast: {
          background: "{surface.950}",
          hoverBackground: "{surface.900}",
          activeBackground: "{surface.800}",
          borderColor: "{surface.950}",
          hoverBorderColor: "{surface.900}",
          activeBorderColor: "{surface.800}",
          color: "{surface.0}",
          hoverColor: "{surface.0}",
          activeColor: "{surface.0}",
          focusRing: {
            color: "{surface.950}",
            shadow: "none"
          }
        }
      },
      outlined: {
        primary: {
          hoverBackground: "{primary.50}",
          activeBackground: "{primary.100}",
          borderColor: "{primary.200}",
          color: "{primary.color}"
        },
        secondary: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          borderColor: "{surface.200}",
          color: "{surface.500}"
        },
        success: {
          hoverBackground: "{green.50}",
          activeBackground: "{green.100}",
          borderColor: "{green.200}",
          color: "{green.500}"
        },
        info: {
          hoverBackground: "{sky.50}",
          activeBackground: "{sky.100}",
          borderColor: "{sky.200}",
          color: "{sky.500}"
        },
        warn: {
          hoverBackground: "{orange.50}",
          activeBackground: "{orange.100}",
          borderColor: "{orange.200}",
          color: "{orange.500}"
        },
        help: {
          hoverBackground: "{purple.50}",
          activeBackground: "{purple.100}",
          borderColor: "{purple.200}",
          color: "{purple.500}"
        },
        danger: {
          hoverBackground: "{red.50}",
          activeBackground: "{red.100}",
          borderColor: "{red.200}",
          color: "{red.500}"
        },
        contrast: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          borderColor: "{surface.700}",
          color: "{surface.950}"
        },
        plain: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          borderColor: "{surface.200}",
          color: "{surface.700}"
        }
      },
      text: {
        primary: {
          hoverBackground: "{primary.50}",
          activeBackground: "{primary.100}",
          color: "{primary.color}"
        },
        secondary: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          color: "{surface.500}"
        },
        success: {
          hoverBackground: "{green.50}",
          activeBackground: "{green.100}",
          color: "{green.500}"
        },
        info: {
          hoverBackground: "{sky.50}",
          activeBackground: "{sky.100}",
          color: "{sky.500}"
        },
        warn: {
          hoverBackground: "{orange.50}",
          activeBackground: "{orange.100}",
          color: "{orange.500}"
        },
        help: {
          hoverBackground: "{purple.50}",
          activeBackground: "{purple.100}",
          color: "{purple.500}"
        },
        danger: {
          hoverBackground: "{red.50}",
          activeBackground: "{red.100}",
          color: "{red.500}"
        },
        contrast: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          color: "{surface.950}"
        },
        plain: {
          hoverBackground: "{surface.50}",
          activeBackground: "{surface.100}",
          color: "{surface.700}"
        }
      },
      link: {
        color: "{primary.color}",
        hoverColor: "{primary.color}",
        activeColor: "{primary.color}"
      }
    },
    dark: {
      root: {
        primary: {
          background: "{primary.color}",
          hoverBackground: "{primary.hover.color}",
          activeBackground: "{primary.active.color}",
          borderColor: "{primary.color}",
          hoverBorderColor: "{primary.hover.color}",
          activeBorderColor: "{primary.active.color}",
          color: "{primary.contrast.color}",
          hoverColor: "{primary.contrast.color}",
          activeColor: "{primary.contrast.color}",
          focusRing: {
            color: "{primary.color}",
            shadow: "none"
          }
        },
        secondary: {
          background: "{surface.800}",
          hoverBackground: "{surface.700}",
          activeBackground: "{surface.600}",
          borderColor: "{surface.800}",
          hoverBorderColor: "{surface.700}",
          activeBorderColor: "{surface.600}",
          color: "{surface.300}",
          hoverColor: "{surface.200}",
          activeColor: "{surface.100}",
          focusRing: {
            color: "{surface.300}",
            shadow: "none"
          }
        },
        info: {
          background: "{sky.400}",
          hoverBackground: "{sky.300}",
          activeBackground: "{sky.200}",
          borderColor: "{sky.400}",
          hoverBorderColor: "{sky.300}",
          activeBorderColor: "{sky.200}",
          color: "{sky.950}",
          hoverColor: "{sky.950}",
          activeColor: "{sky.950}",
          focusRing: {
            color: "{sky.400}",
            shadow: "none"
          }
        },
        success: {
          background: "{green.400}",
          hoverBackground: "{green.300}",
          activeBackground: "{green.200}",
          borderColor: "{green.400}",
          hoverBorderColor: "{green.300}",
          activeBorderColor: "{green.200}",
          color: "{green.950}",
          hoverColor: "{green.950}",
          activeColor: "{green.950}",
          focusRing: {
            color: "{green.400}",
            shadow: "none"
          }
        },
        warn: {
          background: "{orange.400}",
          hoverBackground: "{orange.300}",
          activeBackground: "{orange.200}",
          borderColor: "{orange.400}",
          hoverBorderColor: "{orange.300}",
          activeBorderColor: "{orange.200}",
          color: "{orange.950}",
          hoverColor: "{orange.950}",
          activeColor: "{orange.950}",
          focusRing: {
            color: "{orange.400}",
            shadow: "none"
          }
        },
        help: {
          background: "{purple.400}",
          hoverBackground: "{purple.300}",
          activeBackground: "{purple.200}",
          borderColor: "{purple.400}",
          hoverBorderColor: "{purple.300}",
          activeBorderColor: "{purple.200}",
          color: "{purple.950}",
          hoverColor: "{purple.950}",
          activeColor: "{purple.950}",
          focusRing: {
            color: "{purple.400}",
            shadow: "none"
          }
        },
        danger: {
          background: "{red.400}",
          hoverBackground: "{red.300}",
          activeBackground: "{red.200}",
          borderColor: "{red.400}",
          hoverBorderColor: "{red.300}",
          activeBorderColor: "{red.200}",
          color: "{red.950}",
          hoverColor: "{red.950}",
          activeColor: "{red.950}",
          focusRing: {
            color: "{red.400}",
            shadow: "none"
          }
        },
        contrast: {
          background: "{surface.0}",
          hoverBackground: "{surface.100}",
          activeBackground: "{surface.200}",
          borderColor: "{surface.0}",
          hoverBorderColor: "{surface.100}",
          activeBorderColor: "{surface.200}",
          color: "{surface.950}",
          hoverColor: "{surface.950}",
          activeColor: "{surface.950}",
          focusRing: {
            color: "{surface.0}",
            shadow: "none"
          }
        }
      },
      outlined: {
        primary: {
          hoverBackground: "color-mix(in srgb, {primary.color}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {primary.color}, transparent 84%)",
          borderColor: "{primary.700}",
          color: "{primary.color}"
        },
        secondary: {
          hoverBackground: "rgba(255,255,255,0.04)",
          activeBackground: "rgba(255,255,255,0.16)",
          borderColor: "{surface.700}",
          color: "{surface.400}"
        },
        success: {
          hoverBackground: "color-mix(in srgb, {green.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {green.400}, transparent 84%)",
          borderColor: "{green.700}",
          color: "{green.400}"
        },
        info: {
          hoverBackground: "color-mix(in srgb, {sky.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {sky.400}, transparent 84%)",
          borderColor: "{sky.700}",
          color: "{sky.400}"
        },
        warn: {
          hoverBackground: "color-mix(in srgb, {orange.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {orange.400}, transparent 84%)",
          borderColor: "{orange.700}",
          color: "{orange.400}"
        },
        help: {
          hoverBackground: "color-mix(in srgb, {purple.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {purple.400}, transparent 84%)",
          borderColor: "{purple.700}",
          color: "{purple.400}"
        },
        danger: {
          hoverBackground: "color-mix(in srgb, {red.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {red.400}, transparent 84%)",
          borderColor: "{red.700}",
          color: "{red.400}"
        },
        contrast: {
          hoverBackground: "{surface.800}",
          activeBackground: "{surface.700}",
          borderColor: "{surface.500}",
          color: "{surface.0}"
        },
        plain: {
          hoverBackground: "{surface.800}",
          activeBackground: "{surface.700}",
          borderColor: "{surface.600}",
          color: "{surface.0}"
        }
      },
      text: {
        primary: {
          hoverBackground: "color-mix(in srgb, {primary.color}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {primary.color}, transparent 84%)",
          color: "{primary.color}"
        },
        secondary: {
          hoverBackground: "{surface.800}",
          activeBackground: "{surface.700}",
          color: "{surface.400}"
        },
        success: {
          hoverBackground: "color-mix(in srgb, {green.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {green.400}, transparent 84%)",
          color: "{green.400}"
        },
        info: {
          hoverBackground: "color-mix(in srgb, {sky.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {sky.400}, transparent 84%)",
          color: "{sky.400}"
        },
        warn: {
          hoverBackground: "color-mix(in srgb, {orange.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {orange.400}, transparent 84%)",
          color: "{orange.400}"
        },
        help: {
          hoverBackground: "color-mix(in srgb, {purple.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {purple.400}, transparent 84%)",
          color: "{purple.400}"
        },
        danger: {
          hoverBackground: "color-mix(in srgb, {red.400}, transparent 96%)",
          activeBackground: "color-mix(in srgb, {red.400}, transparent 84%)",
          color: "{red.400}"
        },
        contrast: {
          hoverBackground: "{surface.800}",
          activeBackground: "{surface.700}",
          color: "{surface.0}"
        },
        plain: {
          hoverBackground: "{surface.800}",
          activeBackground: "{surface.700}",
          color: "{surface.0}"
        }
      },
      link: {
        color: "{primary.color}",
        hoverColor: "{primary.color}",
        activeColor: "{primary.color}"
      }
    }
  }
};
var index$1j = {
  root: {
    background: "{content.background}",
    borderRadius: "{border.radius.xl}",
    color: "{content.color}",
    shadow: "0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px -1px rgba(0, 0, 0, 0.1)"
  },
  body: {
    padding: "1.25rem",
    gap: "0.5rem"
  },
  caption: {
    gap: "0.5rem"
  },
  title: {
    fontSize: "1.25rem",
    fontWeight: "500"
  },
  subtitle: {
    color: "{text.muted.color}"
  }
};
var index$1i = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  content: {
    gap: "0.25rem"
  },
  indicatorList: {
    padding: "1rem",
    gap: "0.5rem"
  },
  indicator: {
    width: "2rem",
    height: "0.5rem",
    borderRadius: "{content.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  colorScheme: {
    light: {
      indicator: {
        background: "{surface.200}",
        hoverBackground: "{surface.300}",
        activeBackground: "{primary.color}"
      }
    },
    dark: {
      indicator: {
        background: "{surface.700}",
        hoverBackground: "{surface.600}",
        activeBackground: "{primary.color}"
      }
    }
  }
};
var index$1h = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  },
  dropdown: {
    width: "2.5rem",
    color: "{form.field.icon.color}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}"
  },
  list: {
    padding: "{list.padding}",
    gap: "{list.gap}",
    mobileIndent: "1rem"
  },
  option: {
    focusBackground: "{list.option.focus.background}",
    selectedBackground: "{list.option.selected.background}",
    selectedFocusBackground: "{list.option.selected.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    selectedColor: "{list.option.selected.color}",
    selectedFocusColor: "{list.option.selected.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}",
    icon: {
      color: "{list.option.icon.color}",
      focusColor: "{list.option.icon.focus.color}",
      size: "0.875rem"
    }
  },
  clearIcon: {
    color: "{form.field.icon.color}"
  }
};
var index$1g = {
  root: {
    borderRadius: "{border.radius.sm}",
    width: "1.25rem",
    height: "1.25rem",
    background: "{form.field.background}",
    checkedBackground: "{primary.color}",
    checkedHoverBackground: "{primary.hover.color}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.border.color}",
    checkedBorderColor: "{primary.color}",
    checkedHoverBorderColor: "{primary.hover.color}",
    checkedFocusBorderColor: "{primary.color}",
    checkedDisabledBorderColor: "{form.field.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    shadow: "{form.field.shadow}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      width: "1rem",
      height: "1rem"
    },
    lg: {
      width: "1.5rem",
      height: "1.5rem"
    }
  },
  icon: {
    size: "0.875rem",
    color: "{form.field.color}",
    checkedColor: "{primary.contrast.color}",
    checkedHoverColor: "{primary.contrast.color}",
    disabledColor: "{form.field.disabled.color}",
    sm: {
      size: "0.75rem"
    },
    lg: {
      size: "1rem"
    }
  }
};
var index$1f = {
  root: {
    borderRadius: "16px",
    paddingX: "0.75rem",
    paddingY: "0.5rem",
    gap: "0.5rem",
    transitionDuration: "{transition.duration}"
  },
  image: {
    width: "2rem",
    height: "2rem"
  },
  icon: {
    size: "1rem"
  },
  removeIcon: {
    size: "1rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    }
  },
  colorScheme: {
    light: {
      root: {
        background: "{surface.100}",
        color: "{surface.800}"
      },
      icon: {
        color: "{surface.800}"
      },
      removeIcon: {
        color: "{surface.800}"
      }
    },
    dark: {
      root: {
        background: "{surface.800}",
        color: "{surface.0}"
      },
      icon: {
        color: "{surface.0}"
      },
      removeIcon: {
        color: "{surface.0}"
      }
    }
  }
};
var index$1e = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  preview: {
    width: "1.5rem",
    height: "1.5rem",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  panel: {
    shadow: "{overlay.popover.shadow}",
    borderRadius: "{overlay.popover.borderRadius}"
  },
  colorScheme: {
    light: {
      panel: {
        background: "{surface.800}",
        borderColor: "{surface.900}"
      },
      handle: {
        color: "{surface.0}"
      }
    },
    dark: {
      panel: {
        background: "{surface.900}",
        borderColor: "{surface.700}"
      },
      handle: {
        color: "{surface.0}"
      }
    }
  }
};
var index$1d = {
  icon: {
    size: "2rem",
    color: "{overlay.modal.color}"
  },
  content: {
    gap: "1rem"
  }
};
var index$1c = {
  root: {
    background: "{overlay.popover.background}",
    borderColor: "{overlay.popover.border.color}",
    color: "{overlay.popover.color}",
    borderRadius: "{overlay.popover.border.radius}",
    shadow: "{overlay.popover.shadow}",
    gutter: "10px",
    arrowOffset: "1.25rem"
  },
  content: {
    padding: "{overlay.popover.padding}",
    gap: "1rem"
  },
  icon: {
    size: "1.5rem",
    color: "{overlay.popover.color}"
  },
  footer: {
    gap: "0.5rem",
    padding: "0 {overlay.popover.padding} {overlay.popover.padding} {overlay.popover.padding}"
  }
};
var index$1b = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}",
    shadow: "{overlay.navigation.shadow}",
    transitionDuration: "{transition.duration}"
  },
  list: {
    padding: "{navigation.list.padding}",
    gap: "{navigation.list.gap}"
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    activeBackground: "{navigation.item.active.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    activeColor: "{navigation.item.active.color}",
    padding: "{navigation.item.padding}",
    borderRadius: "{navigation.item.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}",
      activeColor: "{navigation.item.icon.active.color}"
    }
  },
  submenu: {
    mobileIndent: "1rem"
  },
  submenuIcon: {
    size: "{navigation.submenu.icon.size}",
    color: "{navigation.submenu.icon.color}",
    focusColor: "{navigation.submenu.icon.focus.color}",
    activeColor: "{navigation.submenu.icon.active.color}"
  },
  separator: {
    borderColor: "{content.border.color}"
  }
};
var index$1a = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  header: {
    background: "{content.background}",
    borderColor: "{datatable.border.color}",
    color: "{content.color}",
    borderWidth: "0 0 1px 0",
    padding: "0.75rem 1rem"
  },
  headerCell: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    borderColor: "{datatable.border.color}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    selectedColor: "{highlight.color}",
    gap: "0.5rem",
    padding: "0.75rem 1rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  columnTitle: {
    fontWeight: "600"
  },
  row: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    selectedColor: "{highlight.color}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  bodyCell: {
    borderColor: "{datatable.border.color}",
    padding: "0.75rem 1rem"
  },
  footerCell: {
    background: "{content.background}",
    borderColor: "{datatable.border.color}",
    color: "{content.color}",
    padding: "0.75rem 1rem"
  },
  columnFooter: {
    fontWeight: "600"
  },
  footer: {
    background: "{content.background}",
    borderColor: "{datatable.border.color}",
    color: "{content.color}",
    borderWidth: "0 0 1px 0",
    padding: "0.75rem 1rem"
  },
  dropPoint: {
    color: "{primary.color}"
  },
  columnResizerWidth: "0.5rem",
  resizeIndicator: {
    width: "1px",
    color: "{primary.color}"
  },
  sortIcon: {
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    size: "0.875rem"
  },
  loadingIcon: {
    size: "2rem"
  },
  rowToggleButton: {
    hoverBackground: "{content.hover.background}",
    selectedHoverBackground: "{content.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    selectedHoverColor: "{primary.color}",
    size: "1.75rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  filter: {
    inlineGap: "0.5rem",
    overlaySelect: {
      background: "{overlay.select.background}",
      borderColor: "{overlay.select.border.color}",
      borderRadius: "{overlay.select.border.radius}",
      color: "{overlay.select.color}",
      shadow: "{overlay.select.shadow}"
    },
    overlayPopover: {
      background: "{overlay.popover.background}",
      borderColor: "{overlay.popover.border.color}",
      borderRadius: "{overlay.popover.border.radius}",
      color: "{overlay.popover.color}",
      shadow: "{overlay.popover.shadow}",
      padding: "{overlay.popover.padding}",
      gap: "0.5rem"
    },
    rule: {
      borderColor: "{content.border.color}"
    },
    constraintList: {
      padding: "{list.padding}",
      gap: "{list.gap}"
    },
    constraint: {
      focusBackground: "{list.option.focus.background}",
      selectedBackground: "{list.option.selected.background}",
      selectedFocusBackground: "{list.option.selected.focus.background}",
      color: "{list.option.color}",
      focusColor: "{list.option.focus.color}",
      selectedColor: "{list.option.selected.color}",
      selectedFocusColor: "{list.option.selected.focus.color}",
      separator: {
        borderColor: "{content.border.color}"
      },
      padding: "{list.option.padding}",
      borderRadius: "{list.option.border.radius}"
    }
  },
  paginatorTop: {
    borderColor: "{datatable.border.color}",
    borderWidth: "0 0 1px 0"
  },
  paginatorBottom: {
    borderColor: "{datatable.border.color}",
    borderWidth: "0 0 1px 0"
  },
  colorScheme: {
    light: {
      root: {
        borderColor: "{content.border.color}"
      },
      row: {
        stripedBackground: "{surface.50}"
      },
      bodyCell: {
        selectedBorderColor: "{primary.100}"
      }
    },
    dark: {
      root: {
        borderColor: "{surface.800}"
      },
      row: {
        stripedBackground: "{surface.950}"
      },
      bodyCell: {
        selectedBorderColor: "{primary.900}"
      }
    }
  }
};
var index$19 = {
  root: {
    borderColor: "transparent",
    borderWidth: "0",
    borderRadius: "0",
    padding: "0"
  },
  header: {
    background: "{content.background}",
    color: "{content.color}",
    borderColor: "{content.border.color}",
    borderWidth: "0 0 1px 0",
    padding: "0.75rem 1rem",
    borderRadius: "0"
  },
  content: {
    background: "{content.background}",
    color: "{content.color}",
    borderColor: "transparent",
    borderWidth: "0",
    padding: "0",
    borderRadius: "0"
  },
  footer: {
    background: "{content.background}",
    color: "{content.color}",
    borderColor: "{content.border.color}",
    borderWidth: "1px 0 0 0",
    padding: "0.75rem 1rem",
    borderRadius: "0"
  },
  paginatorTop: {
    borderColor: "{content.border.color}",
    borderWidth: "0 0 1px 0"
  },
  paginatorBottom: {
    borderColor: "{content.border.color}",
    borderWidth: "1px 0 0 0"
  }
};
var index$18 = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  panel: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}",
    shadow: "{overlay.popover.shadow}",
    padding: "{overlay.popover.padding}"
  },
  header: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    padding: "0 0 0.5rem 0"
  },
  title: {
    gap: "0.5rem",
    fontWeight: "500"
  },
  dropdown: {
    width: "2.5rem",
    sm: {
      width: "2rem"
    },
    lg: {
      width: "3rem"
    },
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.border.color}",
    activeBorderColor: "{form.field.border.color}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  inputIcon: {
    color: "{form.field.icon.color}"
  },
  selectMonth: {
    hoverBackground: "{content.hover.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    padding: "0.25rem 0.5rem",
    borderRadius: "{content.border.radius}"
  },
  selectYear: {
    hoverBackground: "{content.hover.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    padding: "0.25rem 0.5rem",
    borderRadius: "{content.border.radius}"
  },
  group: {
    borderColor: "{content.border.color}",
    gap: "{overlay.popover.padding}"
  },
  dayView: {
    margin: "0.5rem 0 0 0"
  },
  weekDay: {
    padding: "0.25rem",
    fontWeight: "500",
    color: "{content.color}"
  },
  date: {
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{primary.color}",
    rangeSelectedBackground: "{highlight.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    selectedColor: "{primary.contrast.color}",
    rangeSelectedColor: "{highlight.color}",
    width: "2rem",
    height: "2rem",
    borderRadius: "50%",
    padding: "0.25rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  monthView: {
    margin: "0.5rem 0 0 0"
  },
  month: {
    padding: "0.375rem",
    borderRadius: "{content.border.radius}"
  },
  yearView: {
    margin: "0.5rem 0 0 0"
  },
  year: {
    padding: "0.375rem",
    borderRadius: "{content.border.radius}"
  },
  buttonbar: {
    padding: "0.5rem 0 0 0",
    borderColor: "{content.border.color}"
  },
  timePicker: {
    padding: "0.5rem 0 0 0",
    borderColor: "{content.border.color}",
    gap: "0.5rem",
    buttonGap: "0.25rem"
  },
  colorScheme: {
    light: {
      dropdown: {
        background: "{surface.100}",
        hoverBackground: "{surface.200}",
        activeBackground: "{surface.300}",
        color: "{surface.600}",
        hoverColor: "{surface.700}",
        activeColor: "{surface.800}"
      },
      today: {
        background: "{surface.200}",
        color: "{surface.900}"
      }
    },
    dark: {
      dropdown: {
        background: "{surface.800}",
        hoverBackground: "{surface.700}",
        activeBackground: "{surface.600}",
        color: "{surface.300}",
        hoverColor: "{surface.200}",
        activeColor: "{surface.100}"
      },
      today: {
        background: "{surface.700}",
        color: "{surface.0}"
      }
    }
  }
};
var index$17 = {
  root: {
    background: "{overlay.modal.background}",
    borderColor: "{overlay.modal.border.color}",
    color: "{overlay.modal.color}",
    borderRadius: "{overlay.modal.border.radius}",
    shadow: "{overlay.modal.shadow}"
  },
  header: {
    padding: "{overlay.modal.padding}",
    gap: "0.5rem"
  },
  title: {
    fontSize: "1.25rem",
    fontWeight: "600"
  },
  content: {
    padding: "0 {overlay.modal.padding} {overlay.modal.padding} {overlay.modal.padding}"
  },
  footer: {
    padding: "0 {overlay.modal.padding} {overlay.modal.padding} {overlay.modal.padding}",
    gap: "0.5rem"
  }
};
var index$16 = {
  root: {
    borderColor: "{content.border.color}"
  },
  content: {
    background: "{content.background}",
    color: "{text.color}"
  },
  horizontal: {
    margin: "1rem 0",
    padding: "0 1rem",
    content: {
      padding: "0 0.5rem"
    }
  },
  vertical: {
    margin: "0 1rem",
    padding: "0.5rem 0",
    content: {
      padding: "0.5rem 0"
    }
  }
};
var index$15 = {
  root: {
    background: "rgba(255, 255, 255, 0.1)",
    borderColor: "rgba(255, 255, 255, 0.2)",
    padding: "0.5rem",
    borderRadius: "{border.radius.xl}"
  },
  item: {
    borderRadius: "{content.border.radius}",
    padding: "0.5rem",
    size: "3rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$14 = {
  root: {
    background: "{overlay.modal.background}",
    borderColor: "{overlay.modal.border.color}",
    color: "{overlay.modal.color}",
    shadow: "{overlay.modal.shadow}"
  },
  header: {
    padding: "{overlay.modal.padding}"
  },
  title: {
    fontSize: "1.5rem",
    fontWeight: "600"
  },
  content: {
    padding: "0 {overlay.modal.padding} {overlay.modal.padding} {overlay.modal.padding}"
  },
  footer: {
    padding: "{overlay.modal.padding}"
  }
};
var index$13 = {
  toolbar: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}"
  },
  toolbarItem: {
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{primary.color}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}",
    padding: "{list.padding}"
  },
  overlayOption: {
    focusBackground: "{list.option.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}"
  },
  content: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}"
  }
};
var index$12 = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    color: "{content.color}",
    padding: "0 1.125rem 1.125rem 1.125rem",
    transitionDuration: "{transition.duration}"
  },
  legend: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    borderRadius: "{content.border.radius}",
    borderWidth: "1px",
    borderColor: "transparent",
    padding: "0.5rem 0.75rem",
    gap: "0.5rem",
    fontWeight: "600",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  toggleIcon: {
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}"
  },
  content: {
    padding: "0"
  }
};
var index$11 = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}",
    transitionDuration: "{transition.duration}"
  },
  header: {
    background: "transparent",
    color: "{text.color}",
    padding: "1.125rem",
    borderColor: "unset",
    borderWidth: "0",
    borderRadius: "0",
    gap: "0.5rem"
  },
  content: {
    highlightBorderColor: "{primary.color}",
    padding: "0 1.125rem 1.125rem 1.125rem",
    gap: "1rem"
  },
  file: {
    padding: "1rem",
    gap: "1rem",
    borderColor: "{content.border.color}",
    info: {
      gap: "0.5rem"
    }
  },
  fileList: {
    gap: "0.5rem"
  },
  progressbar: {
    height: "0.25rem"
  },
  basic: {
    gap: "0.5rem"
  }
};
var index$10 = {
  root: {
    color: "{form.field.float.label.color}",
    focusColor: "{form.field.float.label.focus.color}",
    activeColor: "{form.field.float.label.active.color}",
    invalidColor: "{form.field.float.label.invalid.color}",
    transitionDuration: "0.2s",
    positionX: "{form.field.padding.x}",
    positionY: "{form.field.padding.y}",
    fontWeight: "500",
    active: {
      fontSize: "0.75rem",
      fontWeight: "400"
    }
  },
  over: {
    active: {
      top: "-1.25rem"
    }
  },
  "in": {
    input: {
      paddingTop: "1.5rem",
      paddingBottom: "{form.field.padding.y}"
    },
    active: {
      top: "{form.field.padding.y}"
    }
  },
  on: {
    borderRadius: "{border.radius.xs}",
    active: {
      background: "{form.field.background}",
      padding: "0 0.125rem"
    }
  }
};
var index$$ = {
  root: {
    borderWidth: "1px",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    transitionDuration: "{transition.duration}"
  },
  navButton: {
    background: "rgba(255, 255, 255, 0.1)",
    hoverBackground: "rgba(255, 255, 255, 0.2)",
    color: "{surface.100}",
    hoverColor: "{surface.0}",
    size: "3rem",
    gutter: "0.5rem",
    prev: {
      borderRadius: "50%"
    },
    next: {
      borderRadius: "50%"
    },
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  navIcon: {
    size: "1.5rem"
  },
  thumbnailsContent: {
    background: "{content.background}",
    padding: "1rem 0.25rem"
  },
  thumbnailNavButton: {
    size: "2rem",
    borderRadius: "{content.border.radius}",
    gutter: "0.5rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  thumbnailNavButtonIcon: {
    size: "1rem"
  },
  caption: {
    background: "rgba(0, 0, 0, 0.5)",
    color: "{surface.100}",
    padding: "1rem"
  },
  indicatorList: {
    gap: "0.5rem",
    padding: "1rem"
  },
  indicatorButton: {
    width: "1rem",
    height: "1rem",
    activeBackground: "{primary.color}",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  insetIndicatorList: {
    background: "rgba(0, 0, 0, 0.5)"
  },
  insetIndicatorButton: {
    background: "rgba(255, 255, 255, 0.4)",
    hoverBackground: "rgba(255, 255, 255, 0.6)",
    activeBackground: "rgba(255, 255, 255, 0.9)"
  },
  closeButton: {
    size: "3rem",
    gutter: "0.5rem",
    background: "rgba(255, 255, 255, 0.1)",
    hoverBackground: "rgba(255, 255, 255, 0.2)",
    color: "{surface.50}",
    hoverColor: "{surface.0}",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  closeButtonIcon: {
    size: "1.5rem"
  },
  colorScheme: {
    light: {
      thumbnailNavButton: {
        hoverBackground: "{surface.100}",
        color: "{surface.600}",
        hoverColor: "{surface.700}"
      },
      indicatorButton: {
        background: "{surface.200}",
        hoverBackground: "{surface.300}"
      }
    },
    dark: {
      thumbnailNavButton: {
        hoverBackground: "{surface.700}",
        color: "{surface.400}",
        hoverColor: "{surface.0}"
      },
      indicatorButton: {
        background: "{surface.700}",
        hoverBackground: "{surface.600}"
      }
    }
  }
};
var index$_ = {
  icon: {
    color: "{form.field.icon.color}"
  }
};
var index$Z = {
  root: {
    color: "{form.field.float.label.color}",
    focusColor: "{form.field.float.label.focus.color}",
    invalidColor: "{form.field.float.label.invalid.color}",
    transitionDuration: "0.2s",
    positionX: "{form.field.padding.x}",
    top: "{form.field.padding.y}",
    fontSize: "0.75rem",
    fontWeight: "400"
  },
  input: {
    paddingTop: "1.5rem",
    paddingBottom: "{form.field.padding.y}"
  }
};
var index$Y = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  preview: {
    icon: {
      size: "1.5rem"
    },
    mask: {
      background: "{mask.background}",
      color: "{mask.color}"
    }
  },
  toolbar: {
    position: {
      left: "auto",
      right: "1rem",
      top: "1rem",
      bottom: "auto"
    },
    blur: "8px",
    background: "rgba(255,255,255,0.1)",
    borderColor: "rgba(255,255,255,0.2)",
    borderWidth: "1px",
    borderRadius: "30px",
    padding: ".5rem",
    gap: "0.5rem"
  },
  action: {
    hoverBackground: "rgba(255,255,255,0.1)",
    color: "{surface.50}",
    hoverColor: "{surface.0}",
    size: "3rem",
    iconSize: "1.5rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$X = {
  handle: {
    size: "15px",
    hoverSize: "30px",
    background: "rgba(255,255,255,0.3)",
    hoverBackground: "rgba(255,255,255,0.3)",
    borderColor: "unset",
    hoverBorderColor: "unset",
    borderWidth: "0",
    borderRadius: "50%",
    transitionDuration: "{transition.duration}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "rgba(255,255,255,0.3)",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$W = {
  root: {
    padding: "{form.field.padding.y} {form.field.padding.x}",
    borderRadius: "{content.border.radius}",
    gap: "0.5rem"
  },
  text: {
    fontWeight: "500"
  },
  icon: {
    size: "1rem"
  },
  colorScheme: {
    light: {
      info: {
        background: "color-mix(in srgb, {blue.50}, transparent 5%)",
        borderColor: "{blue.200}",
        color: "{blue.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)"
      },
      success: {
        background: "color-mix(in srgb, {green.50}, transparent 5%)",
        borderColor: "{green.200}",
        color: "{green.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)"
      },
      warn: {
        background: "color-mix(in srgb,{yellow.50}, transparent 5%)",
        borderColor: "{yellow.200}",
        color: "{yellow.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)"
      },
      error: {
        background: "color-mix(in srgb, {red.50}, transparent 5%)",
        borderColor: "{red.200}",
        color: "{red.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)"
      },
      secondary: {
        background: "{surface.100}",
        borderColor: "{surface.200}",
        color: "{surface.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)"
      },
      contrast: {
        background: "{surface.900}",
        borderColor: "{surface.950}",
        color: "{surface.50}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)"
      }
    },
    dark: {
      info: {
        background: "color-mix(in srgb, {blue.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {blue.700}, transparent 64%)",
        color: "{blue.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)"
      },
      success: {
        background: "color-mix(in srgb, {green.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {green.700}, transparent 64%)",
        color: "{green.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)"
      },
      warn: {
        background: "color-mix(in srgb, {yellow.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {yellow.700}, transparent 64%)",
        color: "{yellow.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)"
      },
      error: {
        background: "color-mix(in srgb, {red.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {red.700}, transparent 64%)",
        color: "{red.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)"
      },
      secondary: {
        background: "{surface.800}",
        borderColor: "{surface.700}",
        color: "{surface.300}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)"
      },
      contrast: {
        background: "{surface.0}",
        borderColor: "{surface.100}",
        color: "{surface.950}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)"
      }
    }
  }
};
var index$V = {
  root: {
    padding: "{form.field.padding.y} {form.field.padding.x}",
    borderRadius: "{content.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    transitionDuration: "{transition.duration}"
  },
  display: {
    hoverBackground: "{content.hover.background}",
    hoverColor: "{content.hover.color}"
  }
};
var index$U = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}"
  },
  chip: {
    borderRadius: "{border.radius.sm}"
  },
  colorScheme: {
    light: {
      chip: {
        focusBackground: "{surface.200}",
        color: "{surface.800}"
      }
    },
    dark: {
      chip: {
        focusBackground: "{surface.700}",
        color: "{surface.0}"
      }
    }
  }
};
var index$T = {
  addon: {
    background: "{form.field.background}",
    borderColor: "{form.field.border.color}",
    color: "{form.field.icon.color}",
    borderRadius: "{form.field.border.radius}",
    padding: "0.5rem",
    minWidth: "2.5rem"
  }
};
var index$S = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  button: {
    width: "2.5rem",
    borderRadius: "{form.field.border.radius}",
    verticalPadding: "{form.field.padding.y}"
  },
  colorScheme: {
    light: {
      button: {
        background: "transparent",
        hoverBackground: "{surface.100}",
        activeBackground: "{surface.200}",
        borderColor: "{form.field.border.color}",
        hoverBorderColor: "{form.field.border.color}",
        activeBorderColor: "{form.field.border.color}",
        color: "{surface.400}",
        hoverColor: "{surface.500}",
        activeColor: "{surface.600}"
      }
    },
    dark: {
      button: {
        background: "transparent",
        hoverBackground: "{surface.800}",
        activeBackground: "{surface.700}",
        borderColor: "{form.field.border.color}",
        hoverBorderColor: "{form.field.border.color}",
        activeBorderColor: "{form.field.border.color}",
        color: "{surface.400}",
        hoverColor: "{surface.300}",
        activeColor: "{surface.200}"
      }
    }
  }
};
var index$R = {
  root: {
    gap: "0.5rem"
  },
  input: {
    width: "2.5rem",
    sm: {
      width: "2rem"
    },
    lg: {
      width: "3rem"
    }
  }
};
var index$Q = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  }
};
var index$P = {
  root: {
    transitionDuration: "{transition.duration}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  value: {
    background: "{primary.color}"
  },
  range: {
    background: "{content.border.color}"
  },
  text: {
    color: "{text.muted.color}"
  }
};
var index$O = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    borderColor: "{form.field.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    shadow: "{form.field.shadow}",
    borderRadius: "{form.field.border.radius}",
    transitionDuration: "{form.field.transition.duration}"
  },
  list: {
    padding: "{list.padding}",
    gap: "{list.gap}",
    header: {
      padding: "{list.header.padding}"
    }
  },
  option: {
    focusBackground: "{list.option.focus.background}",
    selectedBackground: "{list.option.selected.background}",
    selectedFocusBackground: "{list.option.selected.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    selectedColor: "{list.option.selected.color}",
    selectedFocusColor: "{list.option.selected.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}"
  },
  optionGroup: {
    background: "{list.option.group.background}",
    color: "{list.option.group.color}",
    fontWeight: "{list.option.group.font.weight}",
    padding: "{list.option.group.padding}"
  },
  checkmark: {
    color: "{list.option.color}",
    gutterStart: "-0.375rem",
    gutterEnd: "0.375rem"
  },
  emptyMessage: {
    padding: "{list.option.padding}"
  },
  colorScheme: {
    light: {
      option: {
        stripedBackground: "{surface.50}"
      }
    },
    dark: {
      option: {
        stripedBackground: "{surface.900}"
      }
    }
  }
};
var index$N = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    color: "{content.color}",
    gap: "0.5rem",
    verticalOrientation: {
      padding: "{navigation.list.padding}",
      gap: "{navigation.list.gap}"
    },
    horizontalOrientation: {
      padding: "0.5rem 0.75rem",
      gap: "0.5rem"
    },
    transitionDuration: "{transition.duration}"
  },
  baseItem: {
    borderRadius: "{content.border.radius}",
    padding: "{navigation.item.padding}"
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    activeBackground: "{navigation.item.active.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    activeColor: "{navigation.item.active.color}",
    padding: "{navigation.item.padding}",
    borderRadius: "{navigation.item.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}",
      activeColor: "{navigation.item.icon.active.color}"
    }
  },
  overlay: {
    padding: "0",
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    color: "{content.color}",
    shadow: "{overlay.navigation.shadow}",
    gap: "0.5rem"
  },
  submenu: {
    padding: "{navigation.list.padding}",
    gap: "{navigation.list.gap}"
  },
  submenuLabel: {
    padding: "{navigation.submenu.label.padding}",
    fontWeight: "{navigation.submenu.label.font.weight}",
    background: "{navigation.submenu.label.background.}",
    color: "{navigation.submenu.label.color}"
  },
  submenuIcon: {
    size: "{navigation.submenu.icon.size}",
    color: "{navigation.submenu.icon.color}",
    focusColor: "{navigation.submenu.icon.focus.color}",
    activeColor: "{navigation.submenu.icon.active.color}"
  },
  separator: {
    borderColor: "{content.border.color}"
  },
  mobileButton: {
    borderRadius: "50%",
    size: "1.75rem",
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    hoverBackground: "{content.hover.background}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$M = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}",
    shadow: "{overlay.navigation.shadow}",
    transitionDuration: "{transition.duration}"
  },
  list: {
    padding: "{navigation.list.padding}",
    gap: "{navigation.list.gap}"
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    padding: "{navigation.item.padding}",
    borderRadius: "{navigation.item.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}"
    }
  },
  submenuLabel: {
    padding: "{navigation.submenu.label.padding}",
    fontWeight: "{navigation.submenu.label.font.weight}",
    background: "{navigation.submenu.label.background}",
    color: "{navigation.submenu.label.color}"
  },
  separator: {
    borderColor: "{content.border.color}"
  }
};
var index$L = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    color: "{content.color}",
    gap: "0.5rem",
    padding: "0.5rem 0.75rem",
    transitionDuration: "{transition.duration}"
  },
  baseItem: {
    borderRadius: "{content.border.radius}",
    padding: "{navigation.item.padding}"
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    activeBackground: "{navigation.item.active.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    activeColor: "{navigation.item.active.color}",
    padding: "{navigation.item.padding}",
    borderRadius: "{navigation.item.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}",
      activeColor: "{navigation.item.icon.active.color}"
    }
  },
  submenu: {
    padding: "{navigation.list.padding}",
    gap: "{navigation.list.gap}",
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    shadow: "{overlay.navigation.shadow}",
    mobileIndent: "1rem",
    icon: {
      size: "{navigation.submenu.icon.size}",
      color: "{navigation.submenu.icon.color}",
      focusColor: "{navigation.submenu.icon.focus.color}",
      activeColor: "{navigation.submenu.icon.active.color}"
    }
  },
  separator: {
    borderColor: "{content.border.color}"
  },
  mobileButton: {
    borderRadius: "50%",
    size: "1.75rem",
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    hoverBackground: "{content.hover.background}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$K = {
  root: {
    borderRadius: "{content.border.radius}",
    borderWidth: "1px",
    transitionDuration: "{transition.duration}"
  },
  content: {
    padding: "0.5rem 0.75rem",
    gap: "0.5rem",
    sm: {
      padding: "0.375rem 0.625rem"
    },
    lg: {
      padding: "0.625rem 0.875rem"
    }
  },
  text: {
    fontSize: "1rem",
    fontWeight: "500",
    sm: {
      fontSize: "0.875rem"
    },
    lg: {
      fontSize: "1.125rem"
    }
  },
  icon: {
    size: "1.125rem",
    sm: {
      size: "1rem"
    },
    lg: {
      size: "1.25rem"
    }
  },
  closeButton: {
    width: "1.75rem",
    height: "1.75rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      offset: "{focus.ring.offset}"
    }
  },
  closeIcon: {
    size: "1rem",
    sm: {
      size: "0.875rem"
    },
    lg: {
      size: "1.125rem"
    }
  },
  outlined: {
    root: {
      borderWidth: "1px"
    }
  },
  simple: {
    content: {
      padding: "0"
    }
  },
  colorScheme: {
    light: {
      info: {
        background: "color-mix(in srgb, {blue.50}, transparent 5%)",
        borderColor: "{blue.200}",
        color: "{blue.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{blue.100}",
          focusRing: {
            color: "{blue.600}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{blue.600}",
          borderColor: "{blue.600}"
        },
        simple: {
          color: "{blue.600}"
        }
      },
      success: {
        background: "color-mix(in srgb, {green.50}, transparent 5%)",
        borderColor: "{green.200}",
        color: "{green.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{green.100}",
          focusRing: {
            color: "{green.600}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{green.600}",
          borderColor: "{green.600}"
        },
        simple: {
          color: "{green.600}"
        }
      },
      warn: {
        background: "color-mix(in srgb,{yellow.50}, transparent 5%)",
        borderColor: "{yellow.200}",
        color: "{yellow.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{yellow.100}",
          focusRing: {
            color: "{yellow.600}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{yellow.600}",
          borderColor: "{yellow.600}"
        },
        simple: {
          color: "{yellow.600}"
        }
      },
      error: {
        background: "color-mix(in srgb, {red.50}, transparent 5%)",
        borderColor: "{red.200}",
        color: "{red.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{red.100}",
          focusRing: {
            color: "{red.600}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{red.600}",
          borderColor: "{red.600}"
        },
        simple: {
          color: "{red.600}"
        }
      },
      secondary: {
        background: "{surface.100}",
        borderColor: "{surface.200}",
        color: "{surface.600}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.200}",
          focusRing: {
            color: "{surface.600}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{surface.500}",
          borderColor: "{surface.500}"
        },
        simple: {
          color: "{surface.500}"
        }
      },
      contrast: {
        background: "{surface.900}",
        borderColor: "{surface.950}",
        color: "{surface.50}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.800}",
          focusRing: {
            color: "{surface.50}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{surface.950}",
          borderColor: "{surface.950}"
        },
        simple: {
          color: "{surface.950}"
        }
      }
    },
    dark: {
      info: {
        background: "color-mix(in srgb, {blue.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {blue.700}, transparent 64%)",
        color: "{blue.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{blue.500}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{blue.500}",
          borderColor: "{blue.500}"
        },
        simple: {
          color: "{blue.500}"
        }
      },
      success: {
        background: "color-mix(in srgb, {green.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {green.700}, transparent 64%)",
        color: "{green.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{green.500}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{green.500}",
          borderColor: "{green.500}"
        },
        simple: {
          color: "{green.500}"
        }
      },
      warn: {
        background: "color-mix(in srgb, {yellow.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {yellow.700}, transparent 64%)",
        color: "{yellow.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{yellow.500}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{yellow.500}",
          borderColor: "{yellow.500}"
        },
        simple: {
          color: "{yellow.500}"
        }
      },
      error: {
        background: "color-mix(in srgb, {red.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {red.700}, transparent 64%)",
        color: "{red.500}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{red.500}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{red.500}",
          borderColor: "{red.500}"
        },
        simple: {
          color: "{red.500}"
        }
      },
      secondary: {
        background: "{surface.800}",
        borderColor: "{surface.700}",
        color: "{surface.300}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.700}",
          focusRing: {
            color: "{surface.300}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{surface.400}",
          borderColor: "{surface.400}"
        },
        simple: {
          color: "{surface.400}"
        }
      },
      contrast: {
        background: "{surface.0}",
        borderColor: "{surface.100}",
        color: "{surface.950}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.100}",
          focusRing: {
            color: "{surface.950}",
            shadow: "none"
          }
        },
        outlined: {
          color: "{surface.0}",
          borderColor: "{surface.0}"
        },
        simple: {
          color: "{surface.0}"
        }
      }
    }
  }
};
var index$J = {
  root: {
    borderRadius: "{content.border.radius}",
    gap: "1rem"
  },
  meters: {
    background: "{content.border.color}",
    size: "0.5rem"
  },
  label: {
    gap: "0.5rem"
  },
  labelMarker: {
    size: "0.5rem"
  },
  labelIcon: {
    size: "1rem"
  },
  labelList: {
    verticalGap: "0.5rem",
    horizontalGap: "1rem"
  }
};
var index$I = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  },
  dropdown: {
    width: "2.5rem",
    color: "{form.field.icon.color}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}"
  },
  list: {
    padding: "{list.padding}",
    gap: "{list.gap}",
    header: {
      padding: "{list.header.padding}"
    }
  },
  option: {
    focusBackground: "{list.option.focus.background}",
    selectedBackground: "{list.option.selected.background}",
    selectedFocusBackground: "{list.option.selected.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    selectedColor: "{list.option.selected.color}",
    selectedFocusColor: "{list.option.selected.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}",
    gap: "0.5rem"
  },
  optionGroup: {
    background: "{list.option.group.background}",
    color: "{list.option.group.color}",
    fontWeight: "{list.option.group.font.weight}",
    padding: "{list.option.group.padding}"
  },
  clearIcon: {
    color: "{form.field.icon.color}"
  },
  chip: {
    borderRadius: "{border.radius.sm}"
  },
  emptyMessage: {
    padding: "{list.option.padding}"
  }
};
var index$H = {
  root: {
    gap: "1.125rem"
  },
  controls: {
    gap: "0.5rem"
  }
};
var index$G = {
  root: {
    gutter: "0.75rem",
    transitionDuration: "{transition.duration}"
  },
  node: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    selectedColor: "{highlight.color}",
    hoverColor: "{content.hover.color}",
    padding: "0.75rem 1rem",
    toggleablePadding: "0.75rem 1rem 1.25rem 1rem",
    borderRadius: "{content.border.radius}"
  },
  nodeToggleButton: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    borderColor: "{content.border.color}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    size: "1.5rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  connector: {
    color: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    height: "24px"
  }
};
var index$F = {
  root: {
    outline: {
      width: "2px",
      color: "{content.background}"
    }
  }
};
var index$E = {
  root: {
    padding: "0.5rem 1rem",
    gap: "0.25rem",
    borderRadius: "{content.border.radius}",
    background: "{content.background}",
    color: "{content.color}",
    transitionDuration: "{transition.duration}"
  },
  navButton: {
    background: "transparent",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    selectedColor: "{highlight.color}",
    width: "2.5rem",
    height: "2.5rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  currentPageReport: {
    color: "{text.muted.color}"
  },
  jumpToPageInput: {
    maxWidth: "2.5rem"
  }
};
var index$D = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}"
  },
  header: {
    background: "transparent",
    color: "{text.color}",
    padding: "1.125rem",
    borderColor: "{content.border.color}",
    borderWidth: "0",
    borderRadius: "0"
  },
  toggleableHeader: {
    padding: "0.375rem 1.125rem"
  },
  title: {
    fontWeight: "600"
  },
  content: {
    padding: "0 1.125rem 1.125rem 1.125rem"
  },
  footer: {
    padding: "0 1.125rem 1.125rem 1.125rem"
  }
};
var index$C = {
  root: {
    gap: "0.5rem",
    transitionDuration: "{transition.duration}"
  },
  panel: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderWidth: "1px",
    color: "{content.color}",
    padding: "0.25rem 0.25rem",
    borderRadius: "{content.border.radius}",
    first: {
      borderWidth: "1px",
      topBorderRadius: "{content.border.radius}"
    },
    last: {
      borderWidth: "1px",
      bottomBorderRadius: "{content.border.radius}"
    }
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    gap: "0.5rem",
    padding: "{navigation.item.padding}",
    borderRadius: "{content.border.radius}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}"
    }
  },
  submenu: {
    indent: "1rem"
  },
  submenuIcon: {
    color: "{navigation.submenu.icon.color}",
    focusColor: "{navigation.submenu.icon.focus.color}"
  }
};
var index$B = {
  meter: {
    background: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    height: ".75rem"
  },
  icon: {
    color: "{form.field.icon.color}"
  },
  overlay: {
    background: "{overlay.popover.background}",
    borderColor: "{overlay.popover.border.color}",
    borderRadius: "{overlay.popover.border.radius}",
    color: "{overlay.popover.color}",
    padding: "{overlay.popover.padding}",
    shadow: "{overlay.popover.shadow}"
  },
  content: {
    gap: "0.5rem"
  },
  colorScheme: {
    light: {
      strength: {
        weakBackground: "{red.500}",
        mediumBackground: "{amber.500}",
        strongBackground: "{green.500}"
      }
    },
    dark: {
      strength: {
        weakBackground: "{red.400}",
        mediumBackground: "{amber.400}",
        strongBackground: "{green.400}"
      }
    }
  }
};
var index$A = {
  root: {
    gap: "1.125rem"
  },
  controls: {
    gap: "0.5rem"
  }
};
var index$z = {
  root: {
    background: "{overlay.popover.background}",
    borderColor: "{overlay.popover.border.color}",
    color: "{overlay.popover.color}",
    borderRadius: "{overlay.popover.border.radius}",
    shadow: "{overlay.popover.shadow}",
    gutter: "10px",
    arrowOffset: "1.25rem"
  },
  content: {
    padding: "{overlay.popover.padding}"
  }
};
var index$y = {
  root: {
    background: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    height: "1.25rem"
  },
  value: {
    background: "{primary.color}"
  },
  label: {
    color: "{primary.contrast.color}",
    fontSize: "0.75rem",
    fontWeight: "600"
  }
};
var index$x = {
  colorScheme: {
    light: {
      root: {
        "color.1": "{red.500}",
        "color.2": "{blue.500}",
        "color.3": "{green.500}",
        "color.4": "{yellow.500}"
      }
    },
    dark: {
      root: {
        "color.1": "{red.400}",
        "color.2": "{blue.400}",
        "color.3": "{green.400}",
        "color.4": "{yellow.400}"
      }
    }
  }
};
var index$w = {
  root: {
    width: "1.25rem",
    height: "1.25rem",
    background: "{form.field.background}",
    checkedBackground: "{primary.color}",
    checkedHoverBackground: "{primary.hover.color}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.border.color}",
    checkedBorderColor: "{primary.color}",
    checkedHoverBorderColor: "{primary.hover.color}",
    checkedFocusBorderColor: "{primary.color}",
    checkedDisabledBorderColor: "{form.field.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    shadow: "{form.field.shadow}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      width: "1rem",
      height: "1rem"
    },
    lg: {
      width: "1.5rem",
      height: "1.5rem"
    }
  },
  icon: {
    size: "0.75rem",
    checkedColor: "{primary.contrast.color}",
    checkedHoverColor: "{primary.contrast.color}",
    disabledColor: "{form.field.disabled.color}",
    sm: {
      size: "0.5rem"
    },
    lg: {
      size: "1rem"
    }
  }
};
var index$v = {
  root: {
    gap: "0.25rem",
    transitionDuration: "{transition.duration}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  icon: {
    size: "1rem",
    color: "{text.muted.color}",
    hoverColor: "{primary.color}",
    activeColor: "{primary.color}"
  }
};
var index$u = {
  colorScheme: {
    light: {
      root: {
        background: "rgba(0,0,0,0.1)"
      }
    },
    dark: {
      root: {
        background: "rgba(255,255,255,0.3)"
      }
    }
  }
};
var index$t = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  bar: {
    size: "9px",
    borderRadius: "{border.radius.sm}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  colorScheme: {
    light: {
      bar: {
        background: "{surface.100}"
      }
    },
    dark: {
      bar: {
        background: "{surface.800}"
      }
    }
  }
};
var index$s = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  },
  dropdown: {
    width: "2.5rem",
    color: "{form.field.icon.color}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}"
  },
  list: {
    padding: "{list.padding}",
    gap: "{list.gap}",
    header: {
      padding: "{list.header.padding}"
    }
  },
  option: {
    focusBackground: "{list.option.focus.background}",
    selectedBackground: "{list.option.selected.background}",
    selectedFocusBackground: "{list.option.selected.focus.background}",
    color: "{list.option.color}",
    focusColor: "{list.option.focus.color}",
    selectedColor: "{list.option.selected.color}",
    selectedFocusColor: "{list.option.selected.focus.color}",
    padding: "{list.option.padding}",
    borderRadius: "{list.option.border.radius}"
  },
  optionGroup: {
    background: "{list.option.group.background}",
    color: "{list.option.group.color}",
    fontWeight: "{list.option.group.font.weight}",
    padding: "{list.option.group.padding}"
  },
  clearIcon: {
    color: "{form.field.icon.color}"
  },
  checkmark: {
    color: "{list.option.color}",
    gutterStart: "-0.375rem",
    gutterEnd: "0.375rem"
  },
  emptyMessage: {
    padding: "{list.option.padding}"
  }
};
var index$r = {
  root: {
    borderRadius: "{form.field.border.radius}"
  },
  colorScheme: {
    light: {
      root: {
        invalidBorderColor: "{form.field.invalid.border.color}"
      }
    },
    dark: {
      root: {
        invalidBorderColor: "{form.field.invalid.border.color}"
      }
    }
  }
};
var index$q = {
  root: {
    borderRadius: "{content.border.radius}"
  },
  colorScheme: {
    light: {
      root: {
        background: "{surface.200}",
        animationBackground: "rgba(255,255,255,0.4)"
      }
    },
    dark: {
      root: {
        background: "rgba(255, 255, 255, 0.06)",
        animationBackground: "rgba(255, 255, 255, 0.04)"
      }
    }
  }
};
var index$p = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  track: {
    background: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    size: "3px"
  },
  range: {
    background: "{primary.color}"
  },
  handle: {
    width: "20px",
    height: "20px",
    borderRadius: "50%",
    background: "{content.border.color}",
    hoverBackground: "{content.border.color}",
    content: {
      borderRadius: "50%",
      hoverBackground: "{content.background}",
      width: "16px",
      height: "16px",
      shadow: "0px 0.5px 0px 0px rgba(0, 0, 0, 0.08), 0px 1px 1px 0px rgba(0, 0, 0, 0.14)"
    },
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  colorScheme: {
    light: {
      handle: {
        contentBackground: "{surface.0}"
      }
    },
    dark: {
      handle: {
        contentBackground: "{surface.950}"
      }
    }
  }
};
var index$o = {
  root: {
    gap: "0.5rem",
    transitionDuration: "{transition.duration}"
  }
};
var index$n = {
  root: {
    borderRadius: "{form.field.border.radius}",
    roundedBorderRadius: "2rem",
    raisedShadow: "0 3px 1px -2px rgba(0, 0, 0, 0.2), 0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12)"
  }
};
var index$m = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    transitionDuration: "{transition.duration}"
  },
  gutter: {
    background: "{content.border.color}"
  },
  handle: {
    size: "24px",
    background: "transparent",
    borderRadius: "{content.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  }
};
var index$l = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  separator: {
    background: "{content.border.color}",
    activeBackground: "{primary.color}",
    margin: "0 0 0 1.625rem",
    size: "2px"
  },
  step: {
    padding: "0.5rem",
    gap: "1rem"
  },
  stepHeader: {
    padding: "0",
    borderRadius: "{content.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    gap: "0.5rem"
  },
  stepTitle: {
    color: "{text.muted.color}",
    activeColor: "{primary.color}",
    fontWeight: "500"
  },
  stepNumber: {
    background: "{content.background}",
    activeBackground: "{content.background}",
    borderColor: "{content.border.color}",
    activeBorderColor: "{content.border.color}",
    color: "{text.muted.color}",
    activeColor: "{primary.color}",
    size: "2rem",
    fontSize: "1.143rem",
    fontWeight: "500",
    borderRadius: "50%",
    shadow: "0px 0.5px 0px 0px rgba(0, 0, 0, 0.06), 0px 1px 1px 0px rgba(0, 0, 0, 0.12)"
  },
  steppanels: {
    padding: "0.875rem 0.5rem 1.125rem 0.5rem"
  },
  steppanel: {
    background: "{content.background}",
    color: "{content.color}",
    padding: "0",
    indent: "1rem"
  }
};
var index$k = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  separator: {
    background: "{content.border.color}"
  },
  itemLink: {
    borderRadius: "{content.border.radius}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    gap: "0.5rem"
  },
  itemLabel: {
    color: "{text.muted.color}",
    activeColor: "{primary.color}",
    fontWeight: "500"
  },
  itemNumber: {
    background: "{content.background}",
    activeBackground: "{content.background}",
    borderColor: "{content.border.color}",
    activeBorderColor: "{content.border.color}",
    color: "{text.muted.color}",
    activeColor: "{primary.color}",
    size: "2rem",
    fontSize: "1.143rem",
    fontWeight: "500",
    borderRadius: "50%",
    shadow: "0px 0.5px 0px 0px rgba(0, 0, 0, 0.06), 0px 1px 1px 0px rgba(0, 0, 0, 0.12)"
  }
};
var index$j = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  tablist: {
    borderWidth: "0 0 1px 0",
    background: "{content.background}",
    borderColor: "{content.border.color}"
  },
  item: {
    background: "transparent",
    hoverBackground: "transparent",
    activeBackground: "transparent",
    borderWidth: "0 0 1px 0",
    borderColor: "{content.border.color}",
    hoverBorderColor: "{content.border.color}",
    activeBorderColor: "{primary.color}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{primary.color}",
    padding: "1rem 1.125rem",
    fontWeight: "600",
    margin: "0 0 -1px 0",
    gap: "0.5rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  itemIcon: {
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{primary.color}"
  },
  activeBar: {
    height: "1px",
    bottom: "-1px",
    background: "{primary.color}"
  }
};
var index$i = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  tablist: {
    borderWidth: "0 0 1px 0",
    background: "{content.background}",
    borderColor: "{content.border.color}"
  },
  tab: {
    background: "transparent",
    hoverBackground: "transparent",
    activeBackground: "transparent",
    borderWidth: "0 0 1px 0",
    borderColor: "{content.border.color}",
    hoverBorderColor: "{content.border.color}",
    activeBorderColor: "{primary.color}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{primary.color}",
    padding: "1rem 1.125rem",
    fontWeight: "600",
    margin: "0 0 -1px 0",
    gap: "0.5rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  tabpanel: {
    background: "{content.background}",
    color: "{content.color}",
    padding: "0.875rem 1.125rem 1.125rem 1.125rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "inset {focus.ring.shadow}"
    }
  },
  navButton: {
    background: "{content.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    width: "2.5rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  activeBar: {
    height: "1px",
    bottom: "-1px",
    background: "{primary.color}"
  },
  colorScheme: {
    light: {
      navButton: {
        shadow: "0px 0px 10px 50px rgba(255, 255, 255, 0.6)"
      }
    },
    dark: {
      navButton: {
        shadow: "0px 0px 10px 50px color-mix(in srgb, {content.background}, transparent 50%)"
      }
    }
  }
};
var index$h = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  tabList: {
    background: "{content.background}",
    borderColor: "{content.border.color}"
  },
  tab: {
    borderColor: "{content.border.color}",
    activeBorderColor: "{primary.color}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    activeColor: "{primary.color}"
  },
  tabPanel: {
    background: "{content.background}",
    color: "{content.color}"
  },
  navButton: {
    background: "{content.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}"
  },
  colorScheme: {
    light: {
      navButton: {
        shadow: "0px 0px 10px 50px rgba(255, 255, 255, 0.6)"
      }
    },
    dark: {
      navButton: {
        shadow: "0px 0px 10px 50px color-mix(in srgb, {content.background}, transparent 50%)"
      }
    }
  }
};
var index$g = {
  root: {
    fontSize: "0.875rem",
    fontWeight: "700",
    padding: "0.25rem 0.5rem",
    gap: "0.25rem",
    borderRadius: "{content.border.radius}",
    roundedBorderRadius: "{border.radius.xl}"
  },
  icon: {
    size: "0.75rem"
  },
  colorScheme: {
    light: {
      primary: {
        background: "{primary.100}",
        color: "{primary.700}"
      },
      secondary: {
        background: "{surface.100}",
        color: "{surface.600}"
      },
      success: {
        background: "{green.100}",
        color: "{green.700}"
      },
      info: {
        background: "{sky.100}",
        color: "{sky.700}"
      },
      warn: {
        background: "{orange.100}",
        color: "{orange.700}"
      },
      danger: {
        background: "{red.100}",
        color: "{red.700}"
      },
      contrast: {
        background: "{surface.950}",
        color: "{surface.0}"
      }
    },
    dark: {
      primary: {
        background: "color-mix(in srgb, {primary.500}, transparent 84%)",
        color: "{primary.300}"
      },
      secondary: {
        background: "{surface.800}",
        color: "{surface.300}"
      },
      success: {
        background: "color-mix(in srgb, {green.500}, transparent 84%)",
        color: "{green.300}"
      },
      info: {
        background: "color-mix(in srgb, {sky.500}, transparent 84%)",
        color: "{sky.300}"
      },
      warn: {
        background: "color-mix(in srgb, {orange.500}, transparent 84%)",
        color: "{orange.300}"
      },
      danger: {
        background: "color-mix(in srgb, {red.500}, transparent 84%)",
        color: "{red.300}"
      },
      contrast: {
        background: "{surface.0}",
        color: "{surface.950}"
      }
    }
  }
};
var index$f = {
  root: {
    background: "{form.field.background}",
    borderColor: "{form.field.border.color}",
    color: "{form.field.color}",
    height: "18rem",
    padding: "{form.field.padding.y} {form.field.padding.x}",
    borderRadius: "{form.field.border.radius}"
  },
  prompt: {
    gap: "0.25rem"
  },
  commandResponse: {
    margin: "2px 0"
  }
};
var index$e = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  }
};
var index$d = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    color: "{content.color}",
    borderRadius: "{content.border.radius}",
    shadow: "{overlay.navigation.shadow}",
    transitionDuration: "{transition.duration}"
  },
  list: {
    padding: "{navigation.list.padding}",
    gap: "{navigation.list.gap}"
  },
  item: {
    focusBackground: "{navigation.item.focus.background}",
    activeBackground: "{navigation.item.active.background}",
    color: "{navigation.item.color}",
    focusColor: "{navigation.item.focus.color}",
    activeColor: "{navigation.item.active.color}",
    padding: "{navigation.item.padding}",
    borderRadius: "{navigation.item.border.radius}",
    gap: "{navigation.item.gap}",
    icon: {
      color: "{navigation.item.icon.color}",
      focusColor: "{navigation.item.icon.focus.color}",
      activeColor: "{navigation.item.icon.active.color}"
    }
  },
  submenu: {
    mobileIndent: "1rem"
  },
  submenuIcon: {
    size: "{navigation.submenu.icon.size}",
    color: "{navigation.submenu.icon.color}",
    focusColor: "{navigation.submenu.icon.focus.color}",
    activeColor: "{navigation.submenu.icon.active.color}"
  },
  separator: {
    borderColor: "{content.border.color}"
  }
};
var index$c = {
  event: {
    minHeight: "5rem"
  },
  horizontal: {
    eventContent: {
      padding: "1rem 0"
    }
  },
  vertical: {
    eventContent: {
      padding: "0 1rem"
    }
  },
  eventMarker: {
    size: "1.125rem",
    borderRadius: "50%",
    borderWidth: "2px",
    background: "{content.background}",
    borderColor: "{content.border.color}",
    content: {
      borderRadius: "50%",
      size: "0.375rem",
      background: "{primary.color}",
      insetShadow: "0px 0.5px 0px 0px rgba(0, 0, 0, 0.06), 0px 1px 1px 0px rgba(0, 0, 0, 0.12)"
    }
  },
  eventConnector: {
    color: "{content.border.color}",
    size: "2px"
  }
};
var index$b = {
  root: {
    width: "25rem",
    borderRadius: "{content.border.radius}",
    borderWidth: "1px",
    transitionDuration: "{transition.duration}"
  },
  icon: {
    size: "1.125rem"
  },
  content: {
    padding: "{overlay.popover.padding}",
    gap: "0.5rem"
  },
  text: {
    gap: "0.5rem"
  },
  summary: {
    fontWeight: "500",
    fontSize: "1rem"
  },
  detail: {
    fontWeight: "500",
    fontSize: "0.875rem"
  },
  closeButton: {
    width: "1.75rem",
    height: "1.75rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      offset: "{focus.ring.offset}"
    }
  },
  closeIcon: {
    size: "1rem"
  },
  colorScheme: {
    light: {
      blur: "1.5px",
      info: {
        background: "color-mix(in srgb, {blue.50}, transparent 5%)",
        borderColor: "{blue.200}",
        color: "{blue.600}",
        detailColor: "{surface.700}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{blue.100}",
          focusRing: {
            color: "{blue.600}",
            shadow: "none"
          }
        }
      },
      success: {
        background: "color-mix(in srgb, {green.50}, transparent 5%)",
        borderColor: "{green.200}",
        color: "{green.600}",
        detailColor: "{surface.700}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{green.100}",
          focusRing: {
            color: "{green.600}",
            shadow: "none"
          }
        }
      },
      warn: {
        background: "color-mix(in srgb,{yellow.50}, transparent 5%)",
        borderColor: "{yellow.200}",
        color: "{yellow.600}",
        detailColor: "{surface.700}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{yellow.100}",
          focusRing: {
            color: "{yellow.600}",
            shadow: "none"
          }
        }
      },
      error: {
        background: "color-mix(in srgb, {red.50}, transparent 5%)",
        borderColor: "{red.200}",
        color: "{red.600}",
        detailColor: "{surface.700}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{red.100}",
          focusRing: {
            color: "{red.600}",
            shadow: "none"
          }
        }
      },
      secondary: {
        background: "{surface.100}",
        borderColor: "{surface.200}",
        color: "{surface.600}",
        detailColor: "{surface.700}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.200}",
          focusRing: {
            color: "{surface.600}",
            shadow: "none"
          }
        }
      },
      contrast: {
        background: "{surface.900}",
        borderColor: "{surface.950}",
        color: "{surface.50}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.800}",
          focusRing: {
            color: "{surface.50}",
            shadow: "none"
          }
        }
      }
    },
    dark: {
      blur: "10px",
      info: {
        background: "color-mix(in srgb, {blue.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {blue.700}, transparent 64%)",
        color: "{blue.500}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {blue.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{blue.500}",
            shadow: "none"
          }
        }
      },
      success: {
        background: "color-mix(in srgb, {green.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {green.700}, transparent 64%)",
        color: "{green.500}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {green.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{green.500}",
            shadow: "none"
          }
        }
      },
      warn: {
        background: "color-mix(in srgb, {yellow.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {yellow.700}, transparent 64%)",
        color: "{yellow.500}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {yellow.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{yellow.500}",
            shadow: "none"
          }
        }
      },
      error: {
        background: "color-mix(in srgb, {red.500}, transparent 84%)",
        borderColor: "color-mix(in srgb, {red.700}, transparent 64%)",
        color: "{red.500}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {red.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "rgba(255, 255, 255, 0.05)",
          focusRing: {
            color: "{red.500}",
            shadow: "none"
          }
        }
      },
      secondary: {
        background: "{surface.800}",
        borderColor: "{surface.700}",
        color: "{surface.300}",
        detailColor: "{surface.0}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.500}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.700}",
          focusRing: {
            color: "{surface.300}",
            shadow: "none"
          }
        }
      },
      contrast: {
        background: "{surface.0}",
        borderColor: "{surface.100}",
        color: "{surface.950}",
        detailColor: "{surface.950}",
        shadow: "0px 4px 8px 0px color-mix(in srgb, {surface.950}, transparent 96%)",
        closeButton: {
          hoverBackground: "{surface.100}",
          focusRing: {
            color: "{surface.950}",
            shadow: "none"
          }
        }
      }
    }
  }
};
var index$a = {
  root: {
    padding: "0.5rem 1rem",
    borderRadius: "{content.border.radius}",
    gap: "0.5rem",
    fontWeight: "500",
    disabledBackground: "{form.field.disabled.background}",
    disabledBorderColor: "{form.field.disabled.background}",
    disabledColor: "{form.field.disabled.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      padding: "0.375rem 0.75rem"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      padding: "0.625rem 1.25rem"
    }
  },
  icon: {
    disabledColor: "{form.field.disabled.color}"
  },
  content: {
    left: "0.25rem",
    top: "0.25rem",
    checkedShadow: "0px 1px 2px 0px rgba(0, 0, 0, 0.02), 0px 1px 2px 0px rgba(0, 0, 0, 0.04)"
  },
  colorScheme: {
    light: {
      root: {
        background: "{surface.100}",
        checkedBackground: "{surface.100}",
        hoverBackground: "{surface.100}",
        borderColor: "{surface.100}",
        color: "{surface.500}",
        hoverColor: "{surface.700}",
        checkedColor: "{surface.900}",
        checkedBorderColor: "{surface.100}"
      },
      content: {
        checkedBackground: "{surface.0}"
      },
      icon: {
        color: "{surface.500}",
        hoverColor: "{surface.700}",
        checkedColor: "{surface.900}"
      }
    },
    dark: {
      root: {
        background: "{surface.950}",
        checkedBackground: "{surface.950}",
        hoverBackground: "{surface.950}",
        borderColor: "{surface.950}",
        color: "{surface.400}",
        hoverColor: "{surface.300}",
        checkedColor: "{surface.0}",
        checkedBorderColor: "{surface.950}"
      },
      content: {
        checkedBackground: "{surface.800}"
      },
      icon: {
        color: "{surface.400}",
        hoverColor: "{surface.300}",
        checkedColor: "{surface.0}"
      }
    }
  }
};
var index$9 = {
  root: {
    width: "2.5rem",
    height: "1.5rem",
    borderRadius: "30px",
    gap: "0.25rem",
    shadow: "{form.field.shadow}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    },
    borderWidth: "1px",
    borderColor: "transparent",
    hoverBorderColor: "transparent",
    checkedBorderColor: "transparent",
    checkedHoverBorderColor: "transparent",
    invalidBorderColor: "{form.field.invalid.border.color}",
    transitionDuration: "{form.field.transition.duration}",
    slideDuration: "0.2s"
  },
  handle: {
    borderRadius: "50%",
    size: "1rem"
  },
  colorScheme: {
    light: {
      root: {
        background: "{surface.300}",
        disabledBackground: "{form.field.disabled.background}",
        hoverBackground: "{surface.400}",
        checkedBackground: "{primary.color}",
        checkedHoverBackground: "{primary.hover.color}"
      },
      handle: {
        background: "{surface.0}",
        disabledBackground: "{form.field.disabled.color}",
        hoverBackground: "{surface.0}",
        checkedBackground: "{surface.0}",
        checkedHoverBackground: "{surface.0}",
        color: "{text.muted.color}",
        hoverColor: "{text.color}",
        checkedColor: "{primary.color}",
        checkedHoverColor: "{primary.hover.color}"
      }
    },
    dark: {
      root: {
        background: "{surface.700}",
        disabledBackground: "{surface.600}",
        hoverBackground: "{surface.600}",
        checkedBackground: "{primary.color}",
        checkedHoverBackground: "{primary.hover.color}"
      },
      handle: {
        background: "{surface.400}",
        disabledBackground: "{surface.900}",
        hoverBackground: "{surface.300}",
        checkedBackground: "{surface.900}",
        checkedHoverBackground: "{surface.900}",
        color: "{surface.900}",
        hoverColor: "{surface.800}",
        checkedColor: "{primary.color}",
        checkedHoverColor: "{primary.hover.color}"
      }
    }
  }
};
var index$8 = {
  root: {
    background: "{content.background}",
    borderColor: "{content.border.color}",
    borderRadius: "{content.border.radius}",
    color: "{content.color}",
    gap: "0.5rem",
    padding: "0.75rem"
  }
};
var index$7 = {
  root: {
    maxWidth: "12.5rem",
    gutter: "0.25rem",
    shadow: "{overlay.popover.shadow}",
    padding: "0.5rem 0.75rem",
    borderRadius: "{overlay.popover.border.radius}"
  },
  colorScheme: {
    light: {
      root: {
        background: "{surface.700}",
        color: "{surface.0}"
      }
    },
    dark: {
      root: {
        background: "{surface.700}",
        color: "{surface.0}"
      }
    }
  }
};
var index$6 = {
  root: {
    background: "{content.background}",
    color: "{content.color}",
    padding: "1rem",
    gap: "2px",
    indent: "1rem",
    transitionDuration: "{transition.duration}"
  },
  node: {
    padding: "0.25rem 0.5rem",
    borderRadius: "{content.border.radius}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    color: "{text.color}",
    hoverColor: "{text.hover.color}",
    selectedColor: "{highlight.color}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    },
    gap: "0.25rem"
  },
  nodeIcon: {
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    selectedColor: "{highlight.color}"
  },
  nodeToggleButton: {
    borderRadius: "50%",
    size: "1.75rem",
    hoverBackground: "{content.hover.background}",
    selectedHoverBackground: "{content.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    selectedHoverColor: "{primary.color}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  loadingIcon: {
    size: "2rem"
  },
  filter: {
    margin: "0 0 0.5rem 0"
  }
};
var index$5 = {
  root: {
    background: "{form.field.background}",
    disabledBackground: "{form.field.disabled.background}",
    filledBackground: "{form.field.filled.background}",
    filledHoverBackground: "{form.field.filled.hover.background}",
    filledFocusBackground: "{form.field.filled.focus.background}",
    borderColor: "{form.field.border.color}",
    hoverBorderColor: "{form.field.hover.border.color}",
    focusBorderColor: "{form.field.focus.border.color}",
    invalidBorderColor: "{form.field.invalid.border.color}",
    color: "{form.field.color}",
    disabledColor: "{form.field.disabled.color}",
    placeholderColor: "{form.field.placeholder.color}",
    invalidPlaceholderColor: "{form.field.invalid.placeholder.color}",
    shadow: "{form.field.shadow}",
    paddingX: "{form.field.padding.x}",
    paddingY: "{form.field.padding.y}",
    borderRadius: "{form.field.border.radius}",
    focusRing: {
      width: "{form.field.focus.ring.width}",
      style: "{form.field.focus.ring.style}",
      color: "{form.field.focus.ring.color}",
      offset: "{form.field.focus.ring.offset}",
      shadow: "{form.field.focus.ring.shadow}"
    },
    transitionDuration: "{form.field.transition.duration}",
    sm: {
      fontSize: "{form.field.sm.font.size}",
      paddingX: "{form.field.sm.padding.x}",
      paddingY: "{form.field.sm.padding.y}"
    },
    lg: {
      fontSize: "{form.field.lg.font.size}",
      paddingX: "{form.field.lg.padding.x}",
      paddingY: "{form.field.lg.padding.y}"
    }
  },
  dropdown: {
    width: "2.5rem",
    color: "{form.field.icon.color}"
  },
  overlay: {
    background: "{overlay.select.background}",
    borderColor: "{overlay.select.border.color}",
    borderRadius: "{overlay.select.border.radius}",
    color: "{overlay.select.color}",
    shadow: "{overlay.select.shadow}"
  },
  tree: {
    padding: "{list.padding}"
  },
  clearIcon: {
    color: "{form.field.icon.color}"
  },
  emptyMessage: {
    padding: "{list.option.padding}"
  },
  chip: {
    borderRadius: "{border.radius.sm}"
  }
};
var index$4 = {
  root: {
    transitionDuration: "{transition.duration}"
  },
  header: {
    background: "{content.background}",
    borderColor: "{treetable.border.color}",
    color: "{content.color}",
    borderWidth: "0 0 1px 0",
    padding: "0.75rem 1rem"
  },
  headerCell: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    borderColor: "{treetable.border.color}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    selectedColor: "{highlight.color}",
    gap: "0.5rem",
    padding: "0.75rem 1rem",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  columnTitle: {
    fontWeight: "600"
  },
  row: {
    background: "{content.background}",
    hoverBackground: "{content.hover.background}",
    selectedBackground: "{highlight.background}",
    color: "{content.color}",
    hoverColor: "{content.hover.color}",
    selectedColor: "{highlight.color}",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "-1px",
      shadow: "{focus.ring.shadow}"
    }
  },
  bodyCell: {
    borderColor: "{treetable.border.color}",
    padding: "0.75rem 1rem",
    gap: "0.5rem"
  },
  footerCell: {
    background: "{content.background}",
    borderColor: "{treetable.border.color}",
    color: "{content.color}",
    padding: "0.75rem 1rem"
  },
  columnFooter: {
    fontWeight: "600"
  },
  footer: {
    background: "{content.background}",
    borderColor: "{treetable.border.color}",
    color: "{content.color}",
    borderWidth: "0 0 1px 0",
    padding: "0.75rem 1rem"
  },
  columnResizerWidth: "0.5rem",
  resizeIndicator: {
    width: "1px",
    color: "{primary.color}"
  },
  sortIcon: {
    color: "{text.muted.color}",
    hoverColor: "{text.hover.muted.color}",
    size: "0.875rem"
  },
  loadingIcon: {
    size: "2rem"
  },
  nodeToggleButton: {
    hoverBackground: "{content.hover.background}",
    selectedHoverBackground: "{content.background}",
    color: "{text.muted.color}",
    hoverColor: "{text.color}",
    selectedHoverColor: "{primary.color}",
    size: "1.75rem",
    borderRadius: "50%",
    focusRing: {
      width: "{focus.ring.width}",
      style: "{focus.ring.style}",
      color: "{focus.ring.color}",
      offset: "{focus.ring.offset}",
      shadow: "{focus.ring.shadow}"
    }
  },
  paginatorTop: {
    borderColor: "{content.border.color}",
    borderWidth: "0 0 1px 0"
  },
  paginatorBottom: {
    borderColor: "{content.border.color}",
    borderWidth: "0 0 1px 0"
  },
  colorScheme: {
    light: {
      root: {
        borderColor: "{content.border.color}"
      },
      bodyCell: {
        selectedBorderColor: "{primary.100}"
      }
    },
    dark: {
      root: {
        borderColor: "{surface.800}"
      },
      bodyCell: {
        selectedBorderColor: "{primary.900}"
      }
    }
  }
};
var index$3 = {
  loader: {
    mask: {
      background: "{content.background}",
      color: "{text.muted.color}"
    },
    icon: {
      size: "2rem"
    }
  }
};
function _typeof$v(o2) {
  "@babel/helpers - typeof";
  return _typeof$v = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$v(o2);
}
__name(_typeof$v, "_typeof$v");
function ownKeys$t(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$t, "ownKeys$t");
function _objectSpread$t(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$t(Object(t2), true).forEach(function(r3) {
      _defineProperty$x(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$t(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$t, "_objectSpread$t");
function _defineProperty$x(e2, r2, t2) {
  return (r2 = _toPropertyKey$u(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$x, "_defineProperty$x");
function _toPropertyKey$u(t2) {
  var i2 = _toPrimitive$u(t2, "string");
  return "symbol" == _typeof$v(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$u, "_toPropertyKey$u");
function _toPrimitive$u(t2, r2) {
  if ("object" != _typeof$v(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$v(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$u, "_toPrimitive$u");
var index$2 = _objectSpread$t(_objectSpread$t({}, index$1n), {}, {
  components: {
    accordion: index$1r,
    autocomplete: index$1q,
    avatar: index$1p,
    badge: index$1o,
    blockui: index$1m,
    breadcrumb: index$1l,
    button: index$1k,
    datepicker: index$18,
    card: index$1j,
    carousel: index$1i,
    cascadeselect: index$1h,
    checkbox: index$1g,
    chip: index$1f,
    colorpicker: index$1e,
    confirmdialog: index$1d,
    confirmpopup: index$1c,
    contextmenu: index$1b,
    dataview: index$19,
    datatable: index$1a,
    dialog: index$17,
    divider: index$16,
    dock: index$15,
    drawer: index$14,
    editor: index$13,
    fieldset: index$12,
    fileupload: index$11,
    iftalabel: index$Z,
    floatlabel: index$10,
    galleria: index$$,
    iconfield: index$_,
    image: index$Y,
    imagecompare: index$X,
    inlinemessage: index$W,
    inplace: index$V,
    inputchips: index$U,
    inputgroup: index$T,
    inputnumber: index$S,
    inputotp: index$R,
    inputtext: index$Q,
    knob: index$P,
    listbox: index$O,
    megamenu: index$N,
    menu: index$M,
    menubar: index$L,
    message: index$K,
    metergroup: index$J,
    multiselect: index$I,
    orderlist: index$H,
    organizationchart: index$G,
    overlaybadge: index$F,
    popover: index$z,
    paginator: index$E,
    password: index$B,
    panel: index$D,
    panelmenu: index$C,
    picklist: index$A,
    progressbar: index$y,
    progressspinner: index$x,
    radiobutton: index$w,
    rating: index$v,
    scrollpanel: index$t,
    select: index$s,
    selectbutton: index$r,
    skeleton: index$q,
    slider: index$p,
    speeddial: index$o,
    splitter: index$m,
    splitbutton: index$n,
    stepper: index$l,
    steps: index$k,
    tabmenu: index$j,
    tabs: index$i,
    tabview: index$h,
    textarea: index$e,
    tieredmenu: index$d,
    tag: index$g,
    terminal: index$f,
    timeline: index$c,
    togglebutton: index$a,
    toggleswitch: index$9,
    tree: index$6,
    treeselect: index$5,
    treetable: index$4,
    toast: index$b,
    toolbar: index$8,
    virtualscroller: index$3
  },
  directives: {
    tooltip: index$7,
    ripple: index$u
  }
});
const DEBUG_BUILD$6 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
const SDK_VERSION = "8.48.0";
const GLOBAL_OBJ = globalThis;
function getGlobalSingleton(name2, creator, obj) {
  const gbl = obj || GLOBAL_OBJ;
  const __SENTRY__ = gbl.__SENTRY__ = gbl.__SENTRY__ || {};
  const versionedCarrier = __SENTRY__[SDK_VERSION] = __SENTRY__[SDK_VERSION] || {};
  return versionedCarrier[name2] || (versionedCarrier[name2] = creator());
}
__name(getGlobalSingleton, "getGlobalSingleton");
const DEBUG_BUILD$5 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
const PREFIX$2 = "Sentry Logger ";
const CONSOLE_LEVELS$1 = [
  "debug",
  "info",
  "warn",
  "error",
  "log",
  "assert",
  "trace"
];
const originalConsoleMethods = {};
function consoleSandbox(callback) {
  if (!("console" in GLOBAL_OBJ)) {
    return callback();
  }
  const console2 = GLOBAL_OBJ.console;
  const wrappedFuncs = {};
  const wrappedLevels = Object.keys(originalConsoleMethods);
  wrappedLevels.forEach((level) => {
    const originalConsoleMethod = originalConsoleMethods[level];
    wrappedFuncs[level] = console2[level];
    console2[level] = originalConsoleMethod;
  });
  try {
    return callback();
  } finally {
    wrappedLevels.forEach((level) => {
      console2[level] = wrappedFuncs[level];
    });
  }
}
__name(consoleSandbox, "consoleSandbox");
function makeLogger() {
  let enabled = false;
  const logger2 = {
    enable: /* @__PURE__ */ __name(() => {
      enabled = true;
    }, "enable"),
    disable: /* @__PURE__ */ __name(() => {
      enabled = false;
    }, "disable"),
    isEnabled: /* @__PURE__ */ __name(() => enabled, "isEnabled")
  };
  if (DEBUG_BUILD$5) {
    CONSOLE_LEVELS$1.forEach((name2) => {
      logger2[name2] = (...args) => {
        if (enabled) {
          consoleSandbox(() => {
            GLOBAL_OBJ.console[name2](`${PREFIX$2}[${name2}]:`, ...args);
          });
        }
      };
    });
  } else {
    CONSOLE_LEVELS$1.forEach((name2) => {
      logger2[name2] = () => void 0;
    });
  }
  return logger2;
}
__name(makeLogger, "makeLogger");
const logger$2 = getGlobalSingleton("logger", makeLogger);
const STACKTRACE_FRAME_LIMIT = 50;
const UNKNOWN_FUNCTION = "?";
const WEBPACK_ERROR_REGEXP = /\(error: (.*)\)/;
const STRIP_FRAME_REGEXP = /captureMessage|captureException/;
function createStackParser(...parsers) {
  const sortedParsers = parsers.sort((a2, b2) => a2[0] - b2[0]).map((p2) => p2[1]);
  return (stack2, skipFirstLines = 0, framesToPop = 0) => {
    const frames = [];
    const lines = stack2.split("\n");
    for (let i2 = skipFirstLines; i2 < lines.length; i2++) {
      const line = lines[i2];
      if (line.length > 1024) {
        continue;
      }
      const cleanedLine = WEBPACK_ERROR_REGEXP.test(line) ? line.replace(WEBPACK_ERROR_REGEXP, "$1") : line;
      if (cleanedLine.match(/\S*Error: /)) {
        continue;
      }
      for (const parser of sortedParsers) {
        const frame = parser(cleanedLine);
        if (frame) {
          frames.push(frame);
          break;
        }
      }
      if (frames.length >= STACKTRACE_FRAME_LIMIT + framesToPop) {
        break;
      }
    }
    return stripSentryFramesAndReverse(frames.slice(framesToPop));
  };
}
__name(createStackParser, "createStackParser");
function stackParserFromStackParserOptions(stackParser) {
  if (Array.isArray(stackParser)) {
    return createStackParser(...stackParser);
  }
  return stackParser;
}
__name(stackParserFromStackParserOptions, "stackParserFromStackParserOptions");
function stripSentryFramesAndReverse(stack2) {
  if (!stack2.length) {
    return [];
  }
  const localStack = Array.from(stack2);
  if (/sentryWrapped/.test(getLastStackFrame(localStack).function || "")) {
    localStack.pop();
  }
  localStack.reverse();
  if (STRIP_FRAME_REGEXP.test(getLastStackFrame(localStack).function || "")) {
    localStack.pop();
    if (STRIP_FRAME_REGEXP.test(getLastStackFrame(localStack).function || "")) {
      localStack.pop();
    }
  }
  return localStack.slice(0, STACKTRACE_FRAME_LIMIT).map((frame) => ({
    ...frame,
    filename: frame.filename || getLastStackFrame(localStack).filename,
    function: frame.function || UNKNOWN_FUNCTION
  }));
}
__name(stripSentryFramesAndReverse, "stripSentryFramesAndReverse");
function getLastStackFrame(arr) {
  return arr[arr.length - 1] || {};
}
__name(getLastStackFrame, "getLastStackFrame");
const defaultFunctionName = "<anonymous>";
function getFunctionName(fn) {
  try {
    if (!fn || typeof fn !== "function") {
      return defaultFunctionName;
    }
    return fn.name || defaultFunctionName;
  } catch (e2) {
    return defaultFunctionName;
  }
}
__name(getFunctionName, "getFunctionName");
function getFramesFromEvent(event) {
  const exception = event.exception;
  if (exception) {
    const frames = [];
    try {
      exception.values.forEach((value3) => {
        if (value3.stacktrace.frames) {
          frames.push(...value3.stacktrace.frames);
        }
      });
      return frames;
    } catch (_oO) {
      return void 0;
    }
  }
  return void 0;
}
__name(getFramesFromEvent, "getFramesFromEvent");
const handlers$4 = {};
const instrumented$1 = {};
function addHandler$1(type, handler14) {
  handlers$4[type] = handlers$4[type] || [];
  handlers$4[type].push(handler14);
}
__name(addHandler$1, "addHandler$1");
function resetInstrumentationHandlers() {
  Object.keys(handlers$4).forEach((key) => {
    handlers$4[key] = void 0;
  });
}
__name(resetInstrumentationHandlers, "resetInstrumentationHandlers");
function maybeInstrument(type, instrumentFn) {
  if (!instrumented$1[type]) {
    instrumented$1[type] = true;
    try {
      instrumentFn();
    } catch (e2) {
      DEBUG_BUILD$5 && logger$2.error(`Error while instrumenting ${type}`, e2);
    }
  }
}
__name(maybeInstrument, "maybeInstrument");
function triggerHandlers$1(type, data30) {
  const typeHandlers = type && handlers$4[type];
  if (!typeHandlers) {
    return;
  }
  for (const handler14 of typeHandlers) {
    try {
      handler14(data30);
    } catch (e2) {
      DEBUG_BUILD$5 && logger$2.error(
        `Error while triggering instrumentation handler.
Type: ${type}
Name: ${getFunctionName(handler14)}
Error:`,
        e2
      );
    }
  }
}
__name(triggerHandlers$1, "triggerHandlers$1");
let _oldOnErrorHandler = null;
function addGlobalErrorInstrumentationHandler(handler14) {
  const type = "error";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentError);
}
__name(addGlobalErrorInstrumentationHandler, "addGlobalErrorInstrumentationHandler");
function instrumentError() {
  _oldOnErrorHandler = GLOBAL_OBJ.onerror;
  GLOBAL_OBJ.onerror = function(msg, url, line, column, error2) {
    const handlerData = {
      column,
      error: error2,
      line,
      msg,
      url
    };
    triggerHandlers$1("error", handlerData);
    if (_oldOnErrorHandler) {
      return _oldOnErrorHandler.apply(this, arguments);
    }
    return false;
  };
  GLOBAL_OBJ.onerror.__SENTRY_INSTRUMENTED__ = true;
}
__name(instrumentError, "instrumentError");
let _oldOnUnhandledRejectionHandler = null;
function addGlobalUnhandledRejectionInstrumentationHandler(handler14) {
  const type = "unhandledrejection";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentUnhandledRejection);
}
__name(addGlobalUnhandledRejectionInstrumentationHandler, "addGlobalUnhandledRejectionInstrumentationHandler");
function instrumentUnhandledRejection() {
  _oldOnUnhandledRejectionHandler = GLOBAL_OBJ.onunhandledrejection;
  GLOBAL_OBJ.onunhandledrejection = function(e2) {
    const handlerData = e2;
    triggerHandlers$1("unhandledrejection", handlerData);
    if (_oldOnUnhandledRejectionHandler) {
      return _oldOnUnhandledRejectionHandler.apply(this, arguments);
    }
    return true;
  };
  GLOBAL_OBJ.onunhandledrejection.__SENTRY_INSTRUMENTED__ = true;
}
__name(instrumentUnhandledRejection, "instrumentUnhandledRejection");
function getMainCarrier() {
  getSentryCarrier(GLOBAL_OBJ);
  return GLOBAL_OBJ;
}
__name(getMainCarrier, "getMainCarrier");
function getSentryCarrier(carrier) {
  const __SENTRY__ = carrier.__SENTRY__ = carrier.__SENTRY__ || {};
  __SENTRY__.version = __SENTRY__.version || SDK_VERSION;
  return __SENTRY__[SDK_VERSION] = __SENTRY__[SDK_VERSION] || {};
}
__name(getSentryCarrier, "getSentryCarrier");
const objectToString$4 = Object.prototype.toString;
function isError(wat) {
  switch (objectToString$4.call(wat)) {
    case "[object Error]":
    case "[object Exception]":
    case "[object DOMException]":
    case "[object WebAssembly.Exception]":
      return true;
    default:
      return isInstanceOf(wat, Error);
  }
}
__name(isError, "isError");
function isBuiltin(wat, className) {
  return objectToString$4.call(wat) === `[object ${className}]`;
}
__name(isBuiltin, "isBuiltin");
function isErrorEvent$2(wat) {
  return isBuiltin(wat, "ErrorEvent");
}
__name(isErrorEvent$2, "isErrorEvent$2");
function isDOMError(wat) {
  return isBuiltin(wat, "DOMError");
}
__name(isDOMError, "isDOMError");
function isDOMException(wat) {
  return isBuiltin(wat, "DOMException");
}
__name(isDOMException, "isDOMException");
function isString$a(wat) {
  return isBuiltin(wat, "String");
}
__name(isString$a, "isString$a");
function isParameterizedString(wat) {
  return typeof wat === "object" && wat !== null && "__sentry_template_string__" in wat && "__sentry_template_values__" in wat;
}
__name(isParameterizedString, "isParameterizedString");
function isPrimitive(wat) {
  return wat === null || isParameterizedString(wat) || typeof wat !== "object" && typeof wat !== "function";
}
__name(isPrimitive, "isPrimitive");
function isPlainObject$5(wat) {
  return isBuiltin(wat, "Object");
}
__name(isPlainObject$5, "isPlainObject$5");
function isEvent(wat) {
  return typeof Event !== "undefined" && isInstanceOf(wat, Event);
}
__name(isEvent, "isEvent");
function isElement$3(wat) {
  return typeof Element !== "undefined" && isInstanceOf(wat, Element);
}
__name(isElement$3, "isElement$3");
function isRegExp$5(wat) {
  return isBuiltin(wat, "RegExp");
}
__name(isRegExp$5, "isRegExp$5");
function isThenable$1(wat) {
  return Boolean(wat && wat.then && typeof wat.then === "function");
}
__name(isThenable$1, "isThenable$1");
function isSyntheticEvent(wat) {
  return isPlainObject$5(wat) && "nativeEvent" in wat && "preventDefault" in wat && "stopPropagation" in wat;
}
__name(isSyntheticEvent, "isSyntheticEvent");
function isInstanceOf(wat, base2) {
  try {
    return wat instanceof base2;
  } catch (_e) {
    return false;
  }
}
__name(isInstanceOf, "isInstanceOf");
function isVueViewModel(wat) {
  return !!(typeof wat === "object" && wat !== null && (wat.__isVue || wat._isVue));
}
__name(isVueViewModel, "isVueViewModel");
const WINDOW$8 = GLOBAL_OBJ;
const DEFAULT_MAX_STRING_LENGTH = 80;
function htmlTreeAsString(elem, options5 = {}) {
  if (!elem) {
    return "<unknown>";
  }
  try {
    let currentElem = elem;
    const MAX_TRAVERSE_HEIGHT = 5;
    const out = [];
    let height = 0;
    let len = 0;
    const separator = " > ";
    const sepLength = separator.length;
    let nextStr;
    const keyAttrs = Array.isArray(options5) ? options5 : options5.keyAttrs;
    const maxStringLength = !Array.isArray(options5) && options5.maxStringLength || DEFAULT_MAX_STRING_LENGTH;
    while (currentElem && height++ < MAX_TRAVERSE_HEIGHT) {
      nextStr = _htmlElementAsString(currentElem, keyAttrs);
      if (nextStr === "html" || height > 1 && len + out.length * sepLength + nextStr.length >= maxStringLength) {
        break;
      }
      out.push(nextStr);
      len += nextStr.length;
      currentElem = currentElem.parentNode;
    }
    return out.reverse().join(separator);
  } catch (_oO) {
    return "<unknown>";
  }
}
__name(htmlTreeAsString, "htmlTreeAsString");
function _htmlElementAsString(el, keyAttrs) {
  const elem = el;
  const out = [];
  if (!elem || !elem.tagName) {
    return "";
  }
  if (WINDOW$8.HTMLElement) {
    if (elem instanceof HTMLElement && elem.dataset) {
      if (elem.dataset["sentryComponent"]) {
        return elem.dataset["sentryComponent"];
      }
      if (elem.dataset["sentryElement"]) {
        return elem.dataset["sentryElement"];
      }
    }
  }
  out.push(elem.tagName.toLowerCase());
  const keyAttrPairs = keyAttrs && keyAttrs.length ? keyAttrs.filter((keyAttr) => elem.getAttribute(keyAttr)).map((keyAttr) => [keyAttr, elem.getAttribute(keyAttr)]) : null;
  if (keyAttrPairs && keyAttrPairs.length) {
    keyAttrPairs.forEach((keyAttrPair) => {
      out.push(`[${keyAttrPair[0]}="${keyAttrPair[1]}"]`);
    });
  } else {
    if (elem.id) {
      out.push(`#${elem.id}`);
    }
    const className = elem.className;
    if (className && isString$a(className)) {
      const classes2 = className.split(/\s+/);
      for (const c2 of classes2) {
        out.push(`.${c2}`);
      }
    }
  }
  const allowedAttrs = ["aria-label", "type", "name", "title", "alt"];
  for (const k2 of allowedAttrs) {
    const attr = elem.getAttribute(k2);
    if (attr) {
      out.push(`[${k2}="${attr}"]`);
    }
  }
  return out.join("");
}
__name(_htmlElementAsString, "_htmlElementAsString");
function getLocationHref() {
  try {
    return WINDOW$8.document.location.href;
  } catch (oO) {
    return "";
  }
}
__name(getLocationHref, "getLocationHref");
function getDomElement(selector) {
  if (WINDOW$8.document && WINDOW$8.document.querySelector) {
    return WINDOW$8.document.querySelector(selector);
  }
  return null;
}
__name(getDomElement, "getDomElement");
function getComponentName$1(elem) {
  if (!WINDOW$8.HTMLElement) {
    return null;
  }
  let currentElem = elem;
  const MAX_TRAVERSE_HEIGHT = 5;
  for (let i2 = 0; i2 < MAX_TRAVERSE_HEIGHT; i2++) {
    if (!currentElem) {
      return null;
    }
    if (currentElem instanceof HTMLElement) {
      if (currentElem.dataset["sentryComponent"]) {
        return currentElem.dataset["sentryComponent"];
      }
      if (currentElem.dataset["sentryElement"]) {
        return currentElem.dataset["sentryElement"];
      }
    }
    currentElem = currentElem.parentNode;
  }
  return null;
}
__name(getComponentName$1, "getComponentName$1");
function truncate(str, max = 0) {
  if (typeof str !== "string" || max === 0) {
    return str;
  }
  return str.length <= max ? str : `${str.slice(0, max)}...`;
}
__name(truncate, "truncate");
function snipLine(line, colno) {
  let newLine = line;
  const lineLength = newLine.length;
  if (lineLength <= 150) {
    return newLine;
  }
  if (colno > lineLength) {
    colno = lineLength;
  }
  let start2 = Math.max(colno - 60, 0);
  if (start2 < 5) {
    start2 = 0;
  }
  let end = Math.min(start2 + 140, lineLength);
  if (end > lineLength - 5) {
    end = lineLength;
  }
  if (end === lineLength) {
    start2 = Math.max(end - 140, 0);
  }
  newLine = newLine.slice(start2, end);
  if (start2 > 0) {
    newLine = `'{snip} ${newLine}`;
  }
  if (end < lineLength) {
    newLine += " {snip}";
  }
  return newLine;
}
__name(snipLine, "snipLine");
function safeJoin(input, delimiter2) {
  if (!Array.isArray(input)) {
    return "";
  }
  const output = [];
  for (let i2 = 0; i2 < input.length; i2++) {
    const value3 = input[i2];
    try {
      if (isVueViewModel(value3)) {
        output.push("[VueViewModel]");
      } else {
        output.push(String(value3));
      }
    } catch (e2) {
      output.push("[value cannot be serialized]");
    }
  }
  return output.join(delimiter2);
}
__name(safeJoin, "safeJoin");
function isMatchingPattern(value3, pattern, requireExactStringMatch = false) {
  if (!isString$a(value3)) {
    return false;
  }
  if (isRegExp$5(pattern)) {
    return pattern.test(value3);
  }
  if (isString$a(pattern)) {
    return requireExactStringMatch ? value3 === pattern : value3.includes(pattern);
  }
  return false;
}
__name(isMatchingPattern, "isMatchingPattern");
function stringMatchesSomePattern(testString, patterns = [], requireExactStringMatch = false) {
  return patterns.some((pattern) => isMatchingPattern(testString, pattern, requireExactStringMatch));
}
__name(stringMatchesSomePattern, "stringMatchesSomePattern");
function fill(source, name2, replacementFactory) {
  if (!(name2 in source)) {
    return;
  }
  const original = source[name2];
  const wrapped = replacementFactory(original);
  if (typeof wrapped === "function") {
    markFunctionWrapped(wrapped, original);
  }
  try {
    source[name2] = wrapped;
  } catch (e2) {
    DEBUG_BUILD$5 && logger$2.log(`Failed to replace method "${name2}" in object`, source);
  }
}
__name(fill, "fill");
function addNonEnumerableProperty(obj, name2, value3) {
  try {
    Object.defineProperty(obj, name2, {
      // enumerable: false, // the default, so we can save on bundle size by not explicitly setting it
      value: value3,
      writable: true,
      configurable: true
    });
  } catch (o_O) {
    DEBUG_BUILD$5 && logger$2.log(`Failed to add non-enumerable property "${name2}" to object`, obj);
  }
}
__name(addNonEnumerableProperty, "addNonEnumerableProperty");
function markFunctionWrapped(wrapped, original) {
  try {
    const proto = original.prototype || {};
    wrapped.prototype = original.prototype = proto;
    addNonEnumerableProperty(wrapped, "__sentry_original__", original);
  } catch (o_O) {
  }
}
__name(markFunctionWrapped, "markFunctionWrapped");
function getOriginalFunction(func) {
  return func.__sentry_original__;
}
__name(getOriginalFunction, "getOriginalFunction");
function urlEncode(object) {
  return Object.entries(object).map(([key, value3]) => `${encodeURIComponent(key)}=${encodeURIComponent(value3)}`).join("&");
}
__name(urlEncode, "urlEncode");
function convertToPlainObject(value3) {
  if (isError(value3)) {
    return {
      message: value3.message,
      name: value3.name,
      stack: value3.stack,
      ...getOwnProperties(value3)
    };
  } else if (isEvent(value3)) {
    const newObj = {
      type: value3.type,
      target: serializeEventTarget(value3.target),
      currentTarget: serializeEventTarget(value3.currentTarget),
      ...getOwnProperties(value3)
    };
    if (typeof CustomEvent !== "undefined" && isInstanceOf(value3, CustomEvent)) {
      newObj.detail = value3.detail;
    }
    return newObj;
  } else {
    return value3;
  }
}
__name(convertToPlainObject, "convertToPlainObject");
function serializeEventTarget(target2) {
  try {
    return isElement$3(target2) ? htmlTreeAsString(target2) : Object.prototype.toString.call(target2);
  } catch (_oO) {
    return "<unknown>";
  }
}
__name(serializeEventTarget, "serializeEventTarget");
function getOwnProperties(obj) {
  if (typeof obj === "object" && obj !== null) {
    const extractedProps = {};
    for (const property in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, property)) {
        extractedProps[property] = obj[property];
      }
    }
    return extractedProps;
  } else {
    return {};
  }
}
__name(getOwnProperties, "getOwnProperties");
function extractExceptionKeysForMessage(exception, maxLength = 40) {
  const keys2 = Object.keys(convertToPlainObject(exception));
  keys2.sort();
  const firstKey = keys2[0];
  if (!firstKey) {
    return "[object has no keys]";
  }
  if (firstKey.length >= maxLength) {
    return truncate(firstKey, maxLength);
  }
  for (let includedKeys = keys2.length; includedKeys > 0; includedKeys--) {
    const serialized = keys2.slice(0, includedKeys).join(", ");
    if (serialized.length > maxLength) {
      continue;
    }
    if (includedKeys === keys2.length) {
      return serialized;
    }
    return truncate(serialized, maxLength);
  }
  return "";
}
__name(extractExceptionKeysForMessage, "extractExceptionKeysForMessage");
function dropUndefinedKeys(inputValue2) {
  const memoizationMap = /* @__PURE__ */ new Map();
  return _dropUndefinedKeys(inputValue2, memoizationMap);
}
__name(dropUndefinedKeys, "dropUndefinedKeys");
function _dropUndefinedKeys(inputValue2, memoizationMap) {
  if (isPojo(inputValue2)) {
    const memoVal = memoizationMap.get(inputValue2);
    if (memoVal !== void 0) {
      return memoVal;
    }
    const returnValue = {};
    memoizationMap.set(inputValue2, returnValue);
    for (const key of Object.getOwnPropertyNames(inputValue2)) {
      if (typeof inputValue2[key] !== "undefined") {
        returnValue[key] = _dropUndefinedKeys(inputValue2[key], memoizationMap);
      }
    }
    return returnValue;
  }
  if (Array.isArray(inputValue2)) {
    const memoVal = memoizationMap.get(inputValue2);
    if (memoVal !== void 0) {
      return memoVal;
    }
    const returnValue = [];
    memoizationMap.set(inputValue2, returnValue);
    inputValue2.forEach((item3) => {
      returnValue.push(_dropUndefinedKeys(item3, memoizationMap));
    });
    return returnValue;
  }
  return inputValue2;
}
__name(_dropUndefinedKeys, "_dropUndefinedKeys");
function isPojo(input) {
  if (!isPlainObject$5(input)) {
    return false;
  }
  try {
    const name2 = Object.getPrototypeOf(input).constructor.name;
    return !name2 || name2 === "Object";
  } catch (e2) {
    return true;
  }
}
__name(isPojo, "isPojo");
function objectify(wat) {
  let objectified;
  switch (true) {
    case wat == void 0:
      objectified = new String(wat);
      break;
    case (typeof wat === "symbol" || typeof wat === "bigint"):
      objectified = Object(wat);
      break;
    case isPrimitive(wat):
      objectified = new wat.constructor(wat);
      break;
    default:
      objectified = wat;
      break;
  }
  return objectified;
}
__name(objectify, "objectify");
const ONE_SECOND_IN_MS = 1e3;
function dateTimestampInSeconds() {
  return Date.now() / ONE_SECOND_IN_MS;
}
__name(dateTimestampInSeconds, "dateTimestampInSeconds");
function createUnixTimestampInSecondsFunc() {
  const { performance: performance2 } = GLOBAL_OBJ;
  if (!performance2 || !performance2.now) {
    return dateTimestampInSeconds;
  }
  const approxStartingTimeOrigin = Date.now() - performance2.now();
  const timeOrigin = performance2.timeOrigin == void 0 ? approxStartingTimeOrigin : performance2.timeOrigin;
  return () => {
    return (timeOrigin + performance2.now()) / ONE_SECOND_IN_MS;
  };
}
__name(createUnixTimestampInSecondsFunc, "createUnixTimestampInSecondsFunc");
const timestampInSeconds = createUnixTimestampInSecondsFunc();
let _browserPerformanceTimeOriginMode;
const browserPerformanceTimeOrigin = (() => {
  const { performance: performance2 } = GLOBAL_OBJ;
  if (!performance2 || !performance2.now) {
    _browserPerformanceTimeOriginMode = "none";
    return void 0;
  }
  const threshold = 3600 * 1e3;
  const performanceNow = performance2.now();
  const dateNow = Date.now();
  const timeOriginDelta = performance2.timeOrigin ? Math.abs(performance2.timeOrigin + performanceNow - dateNow) : threshold;
  const timeOriginIsReliable = timeOriginDelta < threshold;
  const navigationStart = performance2.timing && performance2.timing.navigationStart;
  const hasNavigationStart = typeof navigationStart === "number";
  const navigationStartDelta = hasNavigationStart ? Math.abs(navigationStart + performanceNow - dateNow) : threshold;
  const navigationStartIsReliable = navigationStartDelta < threshold;
  if (timeOriginIsReliable || navigationStartIsReliable) {
    if (timeOriginDelta <= navigationStartDelta) {
      _browserPerformanceTimeOriginMode = "timeOrigin";
      return performance2.timeOrigin;
    } else {
      _browserPerformanceTimeOriginMode = "navigationStart";
      return navigationStart;
    }
  }
  _browserPerformanceTimeOriginMode = "dateNow";
  return dateNow;
})();
function uuid4() {
  const gbl = GLOBAL_OBJ;
  const crypto2 = gbl.crypto || gbl.msCrypto;
  let getRandomByte = /* @__PURE__ */ __name(() => Math.random() * 16, "getRandomByte");
  try {
    if (crypto2 && crypto2.randomUUID) {
      return crypto2.randomUUID().replace(/-/g, "");
    }
    if (crypto2 && crypto2.getRandomValues) {
      getRandomByte = /* @__PURE__ */ __name(() => {
        const typedArray = new Uint8Array(1);
        crypto2.getRandomValues(typedArray);
        return typedArray[0];
      }, "getRandomByte");
    }
  } catch (_2) {
  }
  return ("10000000100040008000" + 1e11).replace(
    /[018]/g,
    (c2) => (
      // eslint-disable-next-line no-bitwise
      (c2 ^ (getRandomByte() & 15) >> c2 / 4).toString(16)
    )
  );
}
__name(uuid4, "uuid4");
function getFirstException(event) {
  return event.exception && event.exception.values ? event.exception.values[0] : void 0;
}
__name(getFirstException, "getFirstException");
function getEventDescription(event) {
  const { message: message3, event_id: eventId } = event;
  if (message3) {
    return message3;
  }
  const firstException = getFirstException(event);
  if (firstException) {
    if (firstException.type && firstException.value) {
      return `${firstException.type}: ${firstException.value}`;
    }
    return firstException.type || firstException.value || eventId || "<unknown>";
  }
  return eventId || "<unknown>";
}
__name(getEventDescription, "getEventDescription");
function addExceptionTypeValue(event, value3, type) {
  const exception = event.exception = event.exception || {};
  const values = exception.values = exception.values || [];
  const firstException = values[0] = values[0] || {};
  if (!firstException.value) {
    firstException.value = value3 || "";
  }
  if (!firstException.type) {
    firstException.type = type || "Error";
  }
}
__name(addExceptionTypeValue, "addExceptionTypeValue");
function addExceptionMechanism(event, newMechanism) {
  const firstException = getFirstException(event);
  if (!firstException) {
    return;
  }
  const defaultMechanism = { type: "generic", handled: true };
  const currentMechanism = firstException.mechanism;
  firstException.mechanism = { ...defaultMechanism, ...currentMechanism, ...newMechanism };
  if (newMechanism && "data" in newMechanism) {
    const mergedData = { ...currentMechanism && currentMechanism.data, ...newMechanism.data };
    firstException.mechanism.data = mergedData;
  }
}
__name(addExceptionMechanism, "addExceptionMechanism");
const SEMVER_REGEXP = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-((?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+([0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?$/;
function _parseInt(input) {
  return parseInt(input || "", 10);
}
__name(_parseInt, "_parseInt");
function parseSemver(input) {
  const match2 = input.match(SEMVER_REGEXP) || [];
  const major = _parseInt(match2[1]);
  const minor = _parseInt(match2[2]);
  const patch2 = _parseInt(match2[3]);
  return {
    buildmetadata: match2[5],
    major: isNaN(major) ? void 0 : major,
    minor: isNaN(minor) ? void 0 : minor,
    patch: isNaN(patch2) ? void 0 : patch2,
    prerelease: match2[4]
  };
}
__name(parseSemver, "parseSemver");
function addContextToFrame(lines, frame, linesOfContext = 5) {
  if (frame.lineno === void 0) {
    return;
  }
  const maxLines = lines.length;
  const sourceLine = Math.max(Math.min(maxLines - 1, frame.lineno - 1), 0);
  frame.pre_context = lines.slice(Math.max(0, sourceLine - linesOfContext), sourceLine).map((line) => snipLine(line, 0));
  const lineIndex = Math.min(maxLines - 1, sourceLine);
  frame.context_line = snipLine(lines[lineIndex], frame.colno || 0);
  frame.post_context = lines.slice(Math.min(sourceLine + 1, maxLines), sourceLine + 1 + linesOfContext).map((line) => snipLine(line, 0));
}
__name(addContextToFrame, "addContextToFrame");
function checkOrSetAlreadyCaught(exception) {
  if (isAlreadyCaptured(exception)) {
    return true;
  }
  try {
    addNonEnumerableProperty(exception, "__sentry_captured__", true);
  } catch (err) {
  }
  return false;
}
__name(checkOrSetAlreadyCaught, "checkOrSetAlreadyCaught");
function isAlreadyCaptured(exception) {
  try {
    return exception.__sentry_captured__;
  } catch (e2) {
  }
}
__name(isAlreadyCaptured, "isAlreadyCaptured");
function arrayify(maybeArray) {
  return Array.isArray(maybeArray) ? maybeArray : [maybeArray];
}
__name(arrayify, "arrayify");
var States;
(function(States2) {
  const PENDING = 0;
  States2[States2["PENDING"] = PENDING] = "PENDING";
  const RESOLVED = 1;
  States2[States2["RESOLVED"] = RESOLVED] = "RESOLVED";
  const REJECTED = 2;
  States2[States2["REJECTED"] = REJECTED] = "REJECTED";
})(States || (States = {}));
function resolvedSyncPromise(value3) {
  return new SyncPromise((resolve2) => {
    resolve2(value3);
  });
}
__name(resolvedSyncPromise, "resolvedSyncPromise");
function rejectedSyncPromise(reason) {
  return new SyncPromise((_2, reject3) => {
    reject3(reason);
  });
}
__name(rejectedSyncPromise, "rejectedSyncPromise");
class SyncPromise {
  static {
    __name(this, "SyncPromise");
  }
  constructor(executor) {
    SyncPromise.prototype.__init.call(this);
    SyncPromise.prototype.__init2.call(this);
    SyncPromise.prototype.__init3.call(this);
    SyncPromise.prototype.__init4.call(this);
    this._state = States.PENDING;
    this._handlers = [];
    try {
      executor(this._resolve, this._reject);
    } catch (e2) {
      this._reject(e2);
    }
  }
  /** JSDoc */
  then(onfulfilled, onrejected) {
    return new SyncPromise((resolve2, reject3) => {
      this._handlers.push([
        false,
        (result) => {
          if (!onfulfilled) {
            resolve2(result);
          } else {
            try {
              resolve2(onfulfilled(result));
            } catch (e2) {
              reject3(e2);
            }
          }
        },
        (reason) => {
          if (!onrejected) {
            reject3(reason);
          } else {
            try {
              resolve2(onrejected(reason));
            } catch (e2) {
              reject3(e2);
            }
          }
        }
      ]);
      this._executeHandlers();
    });
  }
  /** JSDoc */
  catch(onrejected) {
    return this.then((val) => val, onrejected);
  }
  /** JSDoc */
  finally(onfinally) {
    return new SyncPromise((resolve2, reject3) => {
      let val;
      let isRejected;
      return this.then(
        (value3) => {
          isRejected = false;
          val = value3;
          if (onfinally) {
            onfinally();
          }
        },
        (reason) => {
          isRejected = true;
          val = reason;
          if (onfinally) {
            onfinally();
          }
        }
      ).then(() => {
        if (isRejected) {
          reject3(val);
          return;
        }
        resolve2(val);
      });
    });
  }
  /** JSDoc */
  __init() {
    this._resolve = (value3) => {
      this._setResult(States.RESOLVED, value3);
    };
  }
  /** JSDoc */
  __init2() {
    this._reject = (reason) => {
      this._setResult(States.REJECTED, reason);
    };
  }
  /** JSDoc */
  __init3() {
    this._setResult = (state, value3) => {
      if (this._state !== States.PENDING) {
        return;
      }
      if (isThenable$1(value3)) {
        void value3.then(this._resolve, this._reject);
        return;
      }
      this._state = state;
      this._value = value3;
      this._executeHandlers();
    };
  }
  /** JSDoc */
  __init4() {
    this._executeHandlers = () => {
      if (this._state === States.PENDING) {
        return;
      }
      const cachedHandlers = this._handlers.slice();
      this._handlers = [];
      cachedHandlers.forEach((handler14) => {
        if (handler14[0]) {
          return;
        }
        if (this._state === States.RESOLVED) {
          handler14[1](this._value);
        }
        if (this._state === States.REJECTED) {
          handler14[2](this._value);
        }
        handler14[0] = true;
      });
    };
  }
}
function makeSession$1(context) {
  const startingTime = timestampInSeconds();
  const session = {
    sid: uuid4(),
    init: true,
    timestamp: startingTime,
    started: startingTime,
    duration: 0,
    status: "ok",
    errors: 0,
    ignoreDuration: false,
    toJSON: /* @__PURE__ */ __name(() => sessionToJSON(session), "toJSON")
  };
  if (context) {
    updateSession(session, context);
  }
  return session;
}
__name(makeSession$1, "makeSession$1");
function updateSession(session, context = {}) {
  if (context.user) {
    if (!session.ipAddress && context.user.ip_address) {
      session.ipAddress = context.user.ip_address;
    }
    if (!session.did && !context.did) {
      session.did = context.user.id || context.user.email || context.user.username;
    }
  }
  session.timestamp = context.timestamp || timestampInSeconds();
  if (context.abnormal_mechanism) {
    session.abnormal_mechanism = context.abnormal_mechanism;
  }
  if (context.ignoreDuration) {
    session.ignoreDuration = context.ignoreDuration;
  }
  if (context.sid) {
    session.sid = context.sid.length === 32 ? context.sid : uuid4();
  }
  if (context.init !== void 0) {
    session.init = context.init;
  }
  if (!session.did && context.did) {
    session.did = `${context.did}`;
  }
  if (typeof context.started === "number") {
    session.started = context.started;
  }
  if (session.ignoreDuration) {
    session.duration = void 0;
  } else if (typeof context.duration === "number") {
    session.duration = context.duration;
  } else {
    const duration = session.timestamp - session.started;
    session.duration = duration >= 0 ? duration : 0;
  }
  if (context.release) {
    session.release = context.release;
  }
  if (context.environment) {
    session.environment = context.environment;
  }
  if (!session.ipAddress && context.ipAddress) {
    session.ipAddress = context.ipAddress;
  }
  if (!session.userAgent && context.userAgent) {
    session.userAgent = context.userAgent;
  }
  if (typeof context.errors === "number") {
    session.errors = context.errors;
  }
  if (context.status) {
    session.status = context.status;
  }
}
__name(updateSession, "updateSession");
function closeSession(session, status) {
  let context = {};
  if (status) {
    context = { status };
  } else if (session.status === "ok") {
    context = { status: "exited" };
  }
  updateSession(session, context);
}
__name(closeSession, "closeSession");
function sessionToJSON(session) {
  return dropUndefinedKeys({
    sid: `${session.sid}`,
    init: session.init,
    // Make sure that sec is converted to ms for date constructor
    started: new Date(session.started * 1e3).toISOString(),
    timestamp: new Date(session.timestamp * 1e3).toISOString(),
    status: session.status,
    errors: session.errors,
    did: typeof session.did === "number" || typeof session.did === "string" ? `${session.did}` : void 0,
    duration: session.duration,
    abnormal_mechanism: session.abnormal_mechanism,
    attrs: {
      release: session.release,
      environment: session.environment,
      ip_address: session.ipAddress,
      user_agent: session.userAgent
    }
  });
}
__name(sessionToJSON, "sessionToJSON");
function generatePropagationContext() {
  return {
    traceId: generateTraceId(),
    spanId: generateSpanId()
  };
}
__name(generatePropagationContext, "generatePropagationContext");
function generateTraceId() {
  return uuid4();
}
__name(generateTraceId, "generateTraceId");
function generateSpanId() {
  return uuid4().substring(16);
}
__name(generateSpanId, "generateSpanId");
function merge$2(initialObj, mergeObj, levels = 2) {
  if (!mergeObj || typeof mergeObj !== "object" || levels <= 0) {
    return mergeObj;
  }
  if (initialObj && mergeObj && Object.keys(mergeObj).length === 0) {
    return initialObj;
  }
  const output = { ...initialObj };
  for (const key in mergeObj) {
    if (Object.prototype.hasOwnProperty.call(mergeObj, key)) {
      output[key] = merge$2(output[key], mergeObj[key], levels - 1);
    }
  }
  return output;
}
__name(merge$2, "merge$2");
const SCOPE_SPAN_FIELD = "_sentrySpan";
function _setSpanForScope(scope, span) {
  if (span) {
    addNonEnumerableProperty(scope, SCOPE_SPAN_FIELD, span);
  } else {
    delete scope[SCOPE_SPAN_FIELD];
  }
}
__name(_setSpanForScope, "_setSpanForScope");
function _getSpanForScope(scope) {
  return scope[SCOPE_SPAN_FIELD];
}
__name(_getSpanForScope, "_getSpanForScope");
const DEFAULT_MAX_BREADCRUMBS = 100;
class ScopeClass {
  static {
    __name(this, "ScopeClass");
  }
  /** Flag if notifying is happening. */
  /** Callback for client to receive scope changes. */
  /** Callback list that will be called during event processing. */
  /** Array of breadcrumbs. */
  /** User */
  /** Tags */
  /** Extra */
  /** Contexts */
  /** Attachments */
  /** Propagation Context for distributed tracing */
  /**
   * A place to stash data which is needed at some point in the SDK's event processing pipeline but which shouldn't get
   * sent to Sentry
   */
  /** Fingerprint */
  /** Severity */
  /**
   * Transaction Name
   *
   * IMPORTANT: The transaction name on the scope has nothing to do with root spans/transaction objects.
   * It's purpose is to assign a transaction to the scope that's added to non-transaction events.
   */
  /** Session */
  /** Request Mode Session Status */
  // eslint-disable-next-line deprecation/deprecation
  /** The client on this scope */
  /** Contains the last event id of a captured event.  */
  // NOTE: Any field which gets added here should get added not only to the constructor but also to the `clone` method.
  constructor() {
    this._notifyingListeners = false;
    this._scopeListeners = [];
    this._eventProcessors = [];
    this._breadcrumbs = [];
    this._attachments = [];
    this._user = {};
    this._tags = {};
    this._extra = {};
    this._contexts = {};
    this._sdkProcessingMetadata = {};
    this._propagationContext = {
      traceId: generateTraceId(),
      spanId: generateSpanId()
    };
  }
  /**
   * @inheritDoc
   */
  clone() {
    const newScope = new ScopeClass();
    newScope._breadcrumbs = [...this._breadcrumbs];
    newScope._tags = { ...this._tags };
    newScope._extra = { ...this._extra };
    newScope._contexts = { ...this._contexts };
    if (this._contexts.flags) {
      newScope._contexts.flags = {
        values: [...this._contexts.flags.values]
      };
    }
    newScope._user = this._user;
    newScope._level = this._level;
    newScope._session = this._session;
    newScope._transactionName = this._transactionName;
    newScope._fingerprint = this._fingerprint;
    newScope._eventProcessors = [...this._eventProcessors];
    newScope._requestSession = this._requestSession;
    newScope._attachments = [...this._attachments];
    newScope._sdkProcessingMetadata = { ...this._sdkProcessingMetadata };
    newScope._propagationContext = { ...this._propagationContext };
    newScope._client = this._client;
    newScope._lastEventId = this._lastEventId;
    _setSpanForScope(newScope, _getSpanForScope(this));
    return newScope;
  }
  /**
   * @inheritDoc
   */
  setClient(client) {
    this._client = client;
  }
  /**
   * @inheritDoc
   */
  setLastEventId(lastEventId2) {
    this._lastEventId = lastEventId2;
  }
  /**
   * @inheritDoc
   */
  getClient() {
    return this._client;
  }
  /**
   * @inheritDoc
   */
  lastEventId() {
    return this._lastEventId;
  }
  /**
   * @inheritDoc
   */
  addScopeListener(callback) {
    this._scopeListeners.push(callback);
  }
  /**
   * @inheritDoc
   */
  addEventProcessor(callback) {
    this._eventProcessors.push(callback);
    return this;
  }
  /**
   * @inheritDoc
   */
  setUser(user) {
    this._user = user || {
      email: void 0,
      id: void 0,
      ip_address: void 0,
      username: void 0
    };
    if (this._session) {
      updateSession(this._session, { user });
    }
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  getUser() {
    return this._user;
  }
  /**
   * @inheritDoc
   */
  // eslint-disable-next-line deprecation/deprecation
  getRequestSession() {
    return this._requestSession;
  }
  /**
   * @inheritDoc
   */
  // eslint-disable-next-line deprecation/deprecation
  setRequestSession(requestSession) {
    this._requestSession = requestSession;
    return this;
  }
  /**
   * @inheritDoc
   */
  setTags(tags) {
    this._tags = {
      ...this._tags,
      ...tags
    };
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setTag(key, value3) {
    this._tags = { ...this._tags, [key]: value3 };
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setExtras(extras) {
    this._extra = {
      ...this._extra,
      ...extras
    };
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setExtra(key, extra) {
    this._extra = { ...this._extra, [key]: extra };
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setFingerprint(fingerprint) {
    this._fingerprint = fingerprint;
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setLevel(level) {
    this._level = level;
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setTransactionName(name2) {
    this._transactionName = name2;
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setContext(key, context) {
    if (context === null) {
      delete this._contexts[key];
    } else {
      this._contexts[key] = context;
    }
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  setSession(session) {
    if (!session) {
      delete this._session;
    } else {
      this._session = session;
    }
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  getSession() {
    return this._session;
  }
  /**
   * @inheritDoc
   */
  update(captureContext) {
    if (!captureContext) {
      return this;
    }
    const scopeToMerge = typeof captureContext === "function" ? captureContext(this) : captureContext;
    const [scopeInstance, requestSession] = scopeToMerge instanceof Scope ? (
      // eslint-disable-next-line deprecation/deprecation
      [scopeToMerge.getScopeData(), scopeToMerge.getRequestSession()]
    ) : isPlainObject$5(scopeToMerge) ? [captureContext, captureContext.requestSession] : [];
    const { tags, extra, user, contexts, level, fingerprint = [], propagationContext } = scopeInstance || {};
    this._tags = { ...this._tags, ...tags };
    this._extra = { ...this._extra, ...extra };
    this._contexts = { ...this._contexts, ...contexts };
    if (user && Object.keys(user).length) {
      this._user = user;
    }
    if (level) {
      this._level = level;
    }
    if (fingerprint.length) {
      this._fingerprint = fingerprint;
    }
    if (propagationContext) {
      this._propagationContext = propagationContext;
    }
    if (requestSession) {
      this._requestSession = requestSession;
    }
    return this;
  }
  /**
   * @inheritDoc
   */
  clear() {
    this._breadcrumbs = [];
    this._tags = {};
    this._extra = {};
    this._user = {};
    this._contexts = {};
    this._level = void 0;
    this._transactionName = void 0;
    this._fingerprint = void 0;
    this._requestSession = void 0;
    this._session = void 0;
    _setSpanForScope(this, void 0);
    this._attachments = [];
    this.setPropagationContext({ traceId: generateTraceId() });
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  addBreadcrumb(breadcrumb, maxBreadcrumbs) {
    const maxCrumbs = typeof maxBreadcrumbs === "number" ? maxBreadcrumbs : DEFAULT_MAX_BREADCRUMBS;
    if (maxCrumbs <= 0) {
      return this;
    }
    const mergedBreadcrumb = {
      timestamp: dateTimestampInSeconds(),
      ...breadcrumb
    };
    const breadcrumbs = this._breadcrumbs;
    breadcrumbs.push(mergedBreadcrumb);
    this._breadcrumbs = breadcrumbs.length > maxCrumbs ? breadcrumbs.slice(-maxCrumbs) : breadcrumbs;
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  getLastBreadcrumb() {
    return this._breadcrumbs[this._breadcrumbs.length - 1];
  }
  /**
   * @inheritDoc
   */
  clearBreadcrumbs() {
    this._breadcrumbs = [];
    this._notifyScopeListeners();
    return this;
  }
  /**
   * @inheritDoc
   */
  addAttachment(attachment) {
    this._attachments.push(attachment);
    return this;
  }
  /**
   * @inheritDoc
   */
  clearAttachments() {
    this._attachments = [];
    return this;
  }
  /** @inheritDoc */
  getScopeData() {
    return {
      breadcrumbs: this._breadcrumbs,
      attachments: this._attachments,
      contexts: this._contexts,
      tags: this._tags,
      extra: this._extra,
      user: this._user,
      level: this._level,
      fingerprint: this._fingerprint || [],
      eventProcessors: this._eventProcessors,
      propagationContext: this._propagationContext,
      sdkProcessingMetadata: this._sdkProcessingMetadata,
      transactionName: this._transactionName,
      span: _getSpanForScope(this)
    };
  }
  /**
   * @inheritDoc
   */
  setSDKProcessingMetadata(newData) {
    this._sdkProcessingMetadata = merge$2(this._sdkProcessingMetadata, newData, 2);
    return this;
  }
  /**
   * @inheritDoc
   */
  setPropagationContext(context) {
    this._propagationContext = {
      // eslint-disable-next-line deprecation/deprecation
      spanId: generateSpanId(),
      ...context
    };
    return this;
  }
  /**
   * @inheritDoc
   */
  getPropagationContext() {
    return this._propagationContext;
  }
  /**
   * @inheritDoc
   */
  captureException(exception, hint) {
    const eventId = hint && hint.event_id ? hint.event_id : uuid4();
    if (!this._client) {
      logger$2.warn("No client configured on scope - will not capture exception!");
      return eventId;
    }
    const syntheticException = new Error("Sentry syntheticException");
    this._client.captureException(
      exception,
      {
        originalException: exception,
        syntheticException,
        ...hint,
        event_id: eventId
      },
      this
    );
    return eventId;
  }
  /**
   * @inheritDoc
   */
  captureMessage(message3, level, hint) {
    const eventId = hint && hint.event_id ? hint.event_id : uuid4();
    if (!this._client) {
      logger$2.warn("No client configured on scope - will not capture message!");
      return eventId;
    }
    const syntheticException = new Error(message3);
    this._client.captureMessage(
      message3,
      level,
      {
        originalException: message3,
        syntheticException,
        ...hint,
        event_id: eventId
      },
      this
    );
    return eventId;
  }
  /**
   * @inheritDoc
   */
  captureEvent(event, hint) {
    const eventId = hint && hint.event_id ? hint.event_id : uuid4();
    if (!this._client) {
      logger$2.warn("No client configured on scope - will not capture event!");
      return eventId;
    }
    this._client.captureEvent(event, { ...hint, event_id: eventId }, this);
    return eventId;
  }
  /**
   * This will be called on every set call.
   */
  _notifyScopeListeners() {
    if (!this._notifyingListeners) {
      this._notifyingListeners = true;
      this._scopeListeners.forEach((callback) => {
        callback(this);
      });
      this._notifyingListeners = false;
    }
  }
}
const Scope = ScopeClass;
function getDefaultCurrentScope() {
  return getGlobalSingleton("defaultCurrentScope", () => new Scope());
}
__name(getDefaultCurrentScope, "getDefaultCurrentScope");
function getDefaultIsolationScope() {
  return getGlobalSingleton("defaultIsolationScope", () => new Scope());
}
__name(getDefaultIsolationScope, "getDefaultIsolationScope");
class AsyncContextStack {
  static {
    __name(this, "AsyncContextStack");
  }
  constructor(scope, isolationScope) {
    let assignedScope;
    if (!scope) {
      assignedScope = new Scope();
    } else {
      assignedScope = scope;
    }
    let assignedIsolationScope;
    if (!isolationScope) {
      assignedIsolationScope = new Scope();
    } else {
      assignedIsolationScope = isolationScope;
    }
    this._stack = [{ scope: assignedScope }];
    this._isolationScope = assignedIsolationScope;
  }
  /**
   * Fork a scope for the stack.
   */
  withScope(callback) {
    const scope = this._pushScope();
    let maybePromiseResult;
    try {
      maybePromiseResult = callback(scope);
    } catch (e2) {
      this._popScope();
      throw e2;
    }
    if (isThenable$1(maybePromiseResult)) {
      return maybePromiseResult.then(
        (res) => {
          this._popScope();
          return res;
        },
        (e2) => {
          this._popScope();
          throw e2;
        }
      );
    }
    this._popScope();
    return maybePromiseResult;
  }
  /**
   * Get the client of the stack.
   */
  getClient() {
    return this.getStackTop().client;
  }
  /**
   * Returns the scope of the top stack.
   */
  getScope() {
    return this.getStackTop().scope;
  }
  /**
   * Get the isolation scope for the stack.
   */
  getIsolationScope() {
    return this._isolationScope;
  }
  /**
   * Returns the topmost scope layer in the order domain > local > process.
   */
  getStackTop() {
    return this._stack[this._stack.length - 1];
  }
  /**
   * Push a scope to the stack.
   */
  _pushScope() {
    const scope = this.getScope().clone();
    this._stack.push({
      client: this.getClient(),
      scope
    });
    return scope;
  }
  /**
   * Pop a scope from the stack.
   */
  _popScope() {
    if (this._stack.length <= 1) return false;
    return !!this._stack.pop();
  }
}
function getAsyncContextStack() {
  const registry = getMainCarrier();
  const sentry = getSentryCarrier(registry);
  return sentry.stack = sentry.stack || new AsyncContextStack(getDefaultCurrentScope(), getDefaultIsolationScope());
}
__name(getAsyncContextStack, "getAsyncContextStack");
function withScope$1(callback) {
  return getAsyncContextStack().withScope(callback);
}
__name(withScope$1, "withScope$1");
function withSetScope(scope, callback) {
  const stack2 = getAsyncContextStack();
  return stack2.withScope(() => {
    stack2.getStackTop().scope = scope;
    return callback(scope);
  });
}
__name(withSetScope, "withSetScope");
function withIsolationScope$1(callback) {
  return getAsyncContextStack().withScope(() => {
    return callback(getAsyncContextStack().getIsolationScope());
  });
}
__name(withIsolationScope$1, "withIsolationScope$1");
function getStackAsyncContextStrategy() {
  return {
    withIsolationScope: withIsolationScope$1,
    withScope: withScope$1,
    withSetScope,
    withSetIsolationScope: /* @__PURE__ */ __name((_isolationScope, callback) => {
      return withIsolationScope$1(callback);
    }, "withSetIsolationScope"),
    getCurrentScope: /* @__PURE__ */ __name(() => getAsyncContextStack().getScope(), "getCurrentScope"),
    getIsolationScope: /* @__PURE__ */ __name(() => getAsyncContextStack().getIsolationScope(), "getIsolationScope")
  };
}
__name(getStackAsyncContextStrategy, "getStackAsyncContextStrategy");
function setAsyncContextStrategy(strategy) {
  const registry = getMainCarrier();
  const sentry = getSentryCarrier(registry);
  sentry.acs = strategy;
}
__name(setAsyncContextStrategy, "setAsyncContextStrategy");
function getAsyncContextStrategy(carrier) {
  const sentry = getSentryCarrier(carrier);
  if (sentry.acs) {
    return sentry.acs;
  }
  return getStackAsyncContextStrategy();
}
__name(getAsyncContextStrategy, "getAsyncContextStrategy");
function getCurrentScope$1() {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  return acs.getCurrentScope();
}
__name(getCurrentScope$1, "getCurrentScope$1");
function getIsolationScope() {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  return acs.getIsolationScope();
}
__name(getIsolationScope, "getIsolationScope");
function getGlobalScope() {
  return getGlobalSingleton("globalScope", () => new Scope());
}
__name(getGlobalScope, "getGlobalScope");
function withScope(...rest) {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  if (rest.length === 2) {
    const [scope, callback] = rest;
    if (!scope) {
      return acs.withScope(callback);
    }
    return acs.withSetScope(scope, callback);
  }
  return acs.withScope(rest[0]);
}
__name(withScope, "withScope");
function withIsolationScope(...rest) {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  if (rest.length === 2) {
    const [isolationScope, callback] = rest;
    if (!isolationScope) {
      return acs.withIsolationScope(callback);
    }
    return acs.withSetIsolationScope(isolationScope, callback);
  }
  return acs.withIsolationScope(rest[0]);
}
__name(withIsolationScope, "withIsolationScope");
function getClient() {
  return getCurrentScope$1().getClient();
}
__name(getClient, "getClient");
function getTraceContextFromScope(scope) {
  const propagationContext = scope.getPropagationContext();
  const { traceId, spanId, parentSpanId } = propagationContext;
  const traceContext = dropUndefinedKeys({
    trace_id: traceId,
    span_id: spanId,
    parent_span_id: parentSpanId
  });
  return traceContext;
}
__name(getTraceContextFromScope, "getTraceContextFromScope");
const METRICS_SPAN_FIELD = "_sentryMetrics";
function getMetricSummaryJsonForSpan(span) {
  const storage = span[METRICS_SPAN_FIELD];
  if (!storage) {
    return void 0;
  }
  const output = {};
  for (const [, [exportKey, summary]] of storage) {
    const arr = output[exportKey] || (output[exportKey] = []);
    arr.push(dropUndefinedKeys(summary));
  }
  return output;
}
__name(getMetricSummaryJsonForSpan, "getMetricSummaryJsonForSpan");
function updateMetricSummaryOnSpan(span, metricType, sanitizedName, value3, unit, tags, bucketKey) {
  const existingStorage = span[METRICS_SPAN_FIELD];
  const storage = existingStorage || (span[METRICS_SPAN_FIELD] = /* @__PURE__ */ new Map());
  const exportKey = `${metricType}:${sanitizedName}@${unit}`;
  const bucketItem = storage.get(bucketKey);
  if (bucketItem) {
    const [, summary] = bucketItem;
    storage.set(bucketKey, [
      exportKey,
      {
        min: Math.min(summary.min, value3),
        max: Math.max(summary.max, value3),
        count: summary.count += 1,
        sum: summary.sum += value3,
        tags: summary.tags
      }
    ]);
  } else {
    storage.set(bucketKey, [
      exportKey,
      {
        min: value3,
        max: value3,
        count: 1,
        sum: value3,
        tags
      }
    ]);
  }
}
__name(updateMetricSummaryOnSpan, "updateMetricSummaryOnSpan");
const SEMANTIC_ATTRIBUTE_SENTRY_SOURCE = "sentry.source";
const SEMANTIC_ATTRIBUTE_SENTRY_SAMPLE_RATE = "sentry.sample_rate";
const SEMANTIC_ATTRIBUTE_SENTRY_OP = "sentry.op";
const SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN = "sentry.origin";
const SEMANTIC_ATTRIBUTE_SENTRY_IDLE_SPAN_FINISH_REASON = "sentry.idle_span_finish_reason";
const SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_UNIT = "sentry.measurement_unit";
const SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_VALUE = "sentry.measurement_value";
const SEMANTIC_ATTRIBUTE_SENTRY_CUSTOM_SPAN_NAME = "sentry.custom_span_name";
const SEMANTIC_ATTRIBUTE_PROFILE_ID = "sentry.profile_id";
const SEMANTIC_ATTRIBUTE_EXCLUSIVE_TIME = "sentry.exclusive_time";
const SEMANTIC_ATTRIBUTE_CACHE_HIT = "cache.hit";
const SEMANTIC_ATTRIBUTE_CACHE_KEY = "cache.key";
const SEMANTIC_ATTRIBUTE_CACHE_ITEM_SIZE = "cache.item_size";
const SEMANTIC_ATTRIBUTE_HTTP_REQUEST_METHOD = "http.request.method";
const SEMANTIC_ATTRIBUTE_URL_FULL = "url.full";
const SPAN_STATUS_UNSET = 0;
const SPAN_STATUS_OK = 1;
const SPAN_STATUS_ERROR = 2;
function getSpanStatusFromHttpCode(httpStatus) {
  if (httpStatus < 400 && httpStatus >= 100) {
    return { code: SPAN_STATUS_OK };
  }
  if (httpStatus >= 400 && httpStatus < 500) {
    switch (httpStatus) {
      case 401:
        return { code: SPAN_STATUS_ERROR, message: "unauthenticated" };
      case 403:
        return { code: SPAN_STATUS_ERROR, message: "permission_denied" };
      case 404:
        return { code: SPAN_STATUS_ERROR, message: "not_found" };
      case 409:
        return { code: SPAN_STATUS_ERROR, message: "already_exists" };
      case 413:
        return { code: SPAN_STATUS_ERROR, message: "failed_precondition" };
      case 429:
        return { code: SPAN_STATUS_ERROR, message: "resource_exhausted" };
      case 499:
        return { code: SPAN_STATUS_ERROR, message: "cancelled" };
      default:
        return { code: SPAN_STATUS_ERROR, message: "invalid_argument" };
    }
  }
  if (httpStatus >= 500 && httpStatus < 600) {
    switch (httpStatus) {
      case 501:
        return { code: SPAN_STATUS_ERROR, message: "unimplemented" };
      case 503:
        return { code: SPAN_STATUS_ERROR, message: "unavailable" };
      case 504:
        return { code: SPAN_STATUS_ERROR, message: "deadline_exceeded" };
      default:
        return { code: SPAN_STATUS_ERROR, message: "internal_error" };
    }
  }
  return { code: SPAN_STATUS_ERROR, message: "unknown_error" };
}
__name(getSpanStatusFromHttpCode, "getSpanStatusFromHttpCode");
function setHttpStatus(span, httpStatus) {
  span.setAttribute("http.response.status_code", httpStatus);
  const spanStatus = getSpanStatusFromHttpCode(httpStatus);
  if (spanStatus.message !== "unknown_error") {
    span.setStatus(spanStatus);
  }
}
__name(setHttpStatus, "setHttpStatus");
const BAGGAGE_HEADER_NAME = "baggage";
const SENTRY_BAGGAGE_KEY_PREFIX = "sentry-";
const SENTRY_BAGGAGE_KEY_PREFIX_REGEX = /^sentry-/;
const MAX_BAGGAGE_STRING_LENGTH = 8192;
function baggageHeaderToDynamicSamplingContext(baggageHeader) {
  const baggageObject = parseBaggageHeader(baggageHeader);
  if (!baggageObject) {
    return void 0;
  }
  const dynamicSamplingContext = Object.entries(baggageObject).reduce((acc, [key, value3]) => {
    if (key.match(SENTRY_BAGGAGE_KEY_PREFIX_REGEX)) {
      const nonPrefixedKey = key.slice(SENTRY_BAGGAGE_KEY_PREFIX.length);
      acc[nonPrefixedKey] = value3;
    }
    return acc;
  }, {});
  if (Object.keys(dynamicSamplingContext).length > 0) {
    return dynamicSamplingContext;
  } else {
    return void 0;
  }
}
__name(baggageHeaderToDynamicSamplingContext, "baggageHeaderToDynamicSamplingContext");
function dynamicSamplingContextToSentryBaggageHeader(dynamicSamplingContext) {
  if (!dynamicSamplingContext) {
    return void 0;
  }
  const sentryPrefixedDSC = Object.entries(dynamicSamplingContext).reduce(
    (acc, [dscKey, dscValue]) => {
      if (dscValue) {
        acc[`${SENTRY_BAGGAGE_KEY_PREFIX}${dscKey}`] = dscValue;
      }
      return acc;
    },
    {}
  );
  return objectToBaggageHeader(sentryPrefixedDSC);
}
__name(dynamicSamplingContextToSentryBaggageHeader, "dynamicSamplingContextToSentryBaggageHeader");
function parseBaggageHeader(baggageHeader) {
  if (!baggageHeader || !isString$a(baggageHeader) && !Array.isArray(baggageHeader)) {
    return void 0;
  }
  if (Array.isArray(baggageHeader)) {
    return baggageHeader.reduce((acc, curr) => {
      const currBaggageObject = baggageHeaderToObject(curr);
      Object.entries(currBaggageObject).forEach(([key, value3]) => {
        acc[key] = value3;
      });
      return acc;
    }, {});
  }
  return baggageHeaderToObject(baggageHeader);
}
__name(parseBaggageHeader, "parseBaggageHeader");
function baggageHeaderToObject(baggageHeader) {
  return baggageHeader.split(",").map((baggageEntry) => baggageEntry.split("=").map((keyOrValue) => decodeURIComponent(keyOrValue.trim()))).reduce((acc, [key, value3]) => {
    if (key && value3) {
      acc[key] = value3;
    }
    return acc;
  }, {});
}
__name(baggageHeaderToObject, "baggageHeaderToObject");
function objectToBaggageHeader(object) {
  if (Object.keys(object).length === 0) {
    return void 0;
  }
  return Object.entries(object).reduce((baggageHeader, [objectKey, objectValue], currentIndex) => {
    const baggageEntry = `${encodeURIComponent(objectKey)}=${encodeURIComponent(objectValue)}`;
    const newBaggageHeader = currentIndex === 0 ? baggageEntry : `${baggageHeader},${baggageEntry}`;
    if (newBaggageHeader.length > MAX_BAGGAGE_STRING_LENGTH) {
      DEBUG_BUILD$5 && logger$2.warn(
        `Not adding key: ${objectKey} with val: ${objectValue} to baggage header due to exceeding baggage size limits.`
      );
      return baggageHeader;
    } else {
      return newBaggageHeader;
    }
  }, "");
}
__name(objectToBaggageHeader, "objectToBaggageHeader");
const TRACEPARENT_REGEXP = new RegExp(
  "^[ \\t]*([0-9a-f]{32})?-?([0-9a-f]{16})?-?([01])?[ \\t]*$"
  // whitespace
);
function extractTraceparentData(traceparent) {
  if (!traceparent) {
    return void 0;
  }
  const matches2 = traceparent.match(TRACEPARENT_REGEXP);
  if (!matches2) {
    return void 0;
  }
  let parentSampled;
  if (matches2[3] === "1") {
    parentSampled = true;
  } else if (matches2[3] === "0") {
    parentSampled = false;
  }
  return {
    traceId: matches2[1],
    parentSampled,
    parentSpanId: matches2[2]
  };
}
__name(extractTraceparentData, "extractTraceparentData");
function propagationContextFromHeaders(sentryTrace, baggage) {
  const traceparentData = extractTraceparentData(sentryTrace);
  const dynamicSamplingContext = baggageHeaderToDynamicSamplingContext(baggage);
  if (!traceparentData || !traceparentData.traceId) {
    return { traceId: generateTraceId(), spanId: generateSpanId() };
  }
  const { traceId, parentSpanId, parentSampled } = traceparentData;
  const virtualSpanId = generateSpanId();
  return {
    traceId,
    parentSpanId,
    spanId: virtualSpanId,
    sampled: parentSampled,
    dsc: dynamicSamplingContext || {}
    // If we have traceparent data but no DSC it means we are not head of trace and we must freeze it
  };
}
__name(propagationContextFromHeaders, "propagationContextFromHeaders");
function generateSentryTraceHeader(traceId = generateTraceId(), spanId = generateSpanId(), sampled) {
  let sampledString = "";
  if (sampled !== void 0) {
    sampledString = sampled ? "-1" : "-0";
  }
  return `${traceId}-${spanId}${sampledString}`;
}
__name(generateSentryTraceHeader, "generateSentryTraceHeader");
const TRACE_FLAG_NONE = 0;
const TRACE_FLAG_SAMPLED = 1;
let hasShownSpanDropWarning = false;
function spanToTransactionTraceContext(span) {
  const { spanId: span_id, traceId: trace_id } = span.spanContext();
  const { data: data30, op, parent_span_id, status, origin: origin2 } = spanToJSON(span);
  return dropUndefinedKeys({
    parent_span_id,
    span_id,
    trace_id,
    data: data30,
    op,
    status,
    origin: origin2
  });
}
__name(spanToTransactionTraceContext, "spanToTransactionTraceContext");
function spanToTraceContext(span) {
  const { spanId, traceId: trace_id, isRemote } = span.spanContext();
  const parent_span_id = isRemote ? spanId : spanToJSON(span).parent_span_id;
  const span_id = isRemote ? generateSpanId() : spanId;
  return dropUndefinedKeys({
    parent_span_id,
    span_id,
    trace_id
  });
}
__name(spanToTraceContext, "spanToTraceContext");
function spanToTraceHeader(span) {
  const { traceId, spanId } = span.spanContext();
  const sampled = spanIsSampled(span);
  return generateSentryTraceHeader(traceId, spanId, sampled);
}
__name(spanToTraceHeader, "spanToTraceHeader");
function spanTimeInputToSeconds(input) {
  if (typeof input === "number") {
    return ensureTimestampInSeconds(input);
  }
  if (Array.isArray(input)) {
    return input[0] + input[1] / 1e9;
  }
  if (input instanceof Date) {
    return ensureTimestampInSeconds(input.getTime());
  }
  return timestampInSeconds();
}
__name(spanTimeInputToSeconds, "spanTimeInputToSeconds");
function ensureTimestampInSeconds(timestamp2) {
  const isMs = timestamp2 > 9999999999;
  return isMs ? timestamp2 / 1e3 : timestamp2;
}
__name(ensureTimestampInSeconds, "ensureTimestampInSeconds");
function spanToJSON(span) {
  if (spanIsSentrySpan(span)) {
    return span.getSpanJSON();
  }
  try {
    const { spanId: span_id, traceId: trace_id } = span.spanContext();
    if (spanIsOpenTelemetrySdkTraceBaseSpan(span)) {
      const { attributes, startTime, name: name2, endTime, parentSpanId, status } = span;
      return dropUndefinedKeys({
        span_id,
        trace_id,
        data: attributes,
        description: name2,
        parent_span_id: parentSpanId,
        start_timestamp: spanTimeInputToSeconds(startTime),
        // This is [0,0] by default in OTEL, in which case we want to interpret this as no end time
        timestamp: spanTimeInputToSeconds(endTime) || void 0,
        status: getStatusMessage(status),
        op: attributes[SEMANTIC_ATTRIBUTE_SENTRY_OP],
        origin: attributes[SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN],
        _metrics_summary: getMetricSummaryJsonForSpan(span)
      });
    }
    return {
      span_id,
      trace_id
    };
  } catch (e2) {
    return {};
  }
}
__name(spanToJSON, "spanToJSON");
function spanIsOpenTelemetrySdkTraceBaseSpan(span) {
  const castSpan = span;
  return !!castSpan.attributes && !!castSpan.startTime && !!castSpan.name && !!castSpan.endTime && !!castSpan.status;
}
__name(spanIsOpenTelemetrySdkTraceBaseSpan, "spanIsOpenTelemetrySdkTraceBaseSpan");
function spanIsSentrySpan(span) {
  return typeof span.getSpanJSON === "function";
}
__name(spanIsSentrySpan, "spanIsSentrySpan");
function spanIsSampled(span) {
  const { traceFlags } = span.spanContext();
  return traceFlags === TRACE_FLAG_SAMPLED;
}
__name(spanIsSampled, "spanIsSampled");
function getStatusMessage(status) {
  if (!status || status.code === SPAN_STATUS_UNSET) {
    return void 0;
  }
  if (status.code === SPAN_STATUS_OK) {
    return "ok";
  }
  return status.message || "unknown_error";
}
__name(getStatusMessage, "getStatusMessage");
const CHILD_SPANS_FIELD = "_sentryChildSpans";
const ROOT_SPAN_FIELD = "_sentryRootSpan";
function addChildSpanToSpan(span, childSpan) {
  const rootSpan = span[ROOT_SPAN_FIELD] || span;
  addNonEnumerableProperty(childSpan, ROOT_SPAN_FIELD, rootSpan);
  if (span[CHILD_SPANS_FIELD]) {
    span[CHILD_SPANS_FIELD].add(childSpan);
  } else {
    addNonEnumerableProperty(span, CHILD_SPANS_FIELD, /* @__PURE__ */ new Set([childSpan]));
  }
}
__name(addChildSpanToSpan, "addChildSpanToSpan");
function removeChildSpanFromSpan(span, childSpan) {
  if (span[CHILD_SPANS_FIELD]) {
    span[CHILD_SPANS_FIELD].delete(childSpan);
  }
}
__name(removeChildSpanFromSpan, "removeChildSpanFromSpan");
function getSpanDescendants(span) {
  const resultSet = /* @__PURE__ */ new Set();
  function addSpanChildren(span2) {
    if (resultSet.has(span2)) {
      return;
    } else if (spanIsSampled(span2)) {
      resultSet.add(span2);
      const childSpans = span2[CHILD_SPANS_FIELD] ? Array.from(span2[CHILD_SPANS_FIELD]) : [];
      for (const childSpan of childSpans) {
        addSpanChildren(childSpan);
      }
    }
  }
  __name(addSpanChildren, "addSpanChildren");
  addSpanChildren(span);
  return Array.from(resultSet);
}
__name(getSpanDescendants, "getSpanDescendants");
function getRootSpan(span) {
  return span[ROOT_SPAN_FIELD] || span;
}
__name(getRootSpan, "getRootSpan");
function getActiveSpan() {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  if (acs.getActiveSpan) {
    return acs.getActiveSpan();
  }
  return _getSpanForScope(getCurrentScope$1());
}
__name(getActiveSpan, "getActiveSpan");
function updateMetricSummaryOnActiveSpan(metricType, sanitizedName, value3, unit, tags, bucketKey) {
  const span = getActiveSpan();
  if (span) {
    updateMetricSummaryOnSpan(span, metricType, sanitizedName, value3, unit, tags, bucketKey);
  }
}
__name(updateMetricSummaryOnActiveSpan, "updateMetricSummaryOnActiveSpan");
function showSpanDropWarning() {
  if (!hasShownSpanDropWarning) {
    consoleSandbox(() => {
      console.warn(
        "[Sentry] Deprecation warning: Returning null from `beforeSendSpan` will be disallowed from SDK version 9.0.0 onwards. The callback will only support mutating spans. To drop certain spans, configure the respective integrations directly."
      );
    });
    hasShownSpanDropWarning = true;
  }
}
__name(showSpanDropWarning, "showSpanDropWarning");
function updateSpanName(span, name2) {
  span.updateName(name2);
  span.setAttributes({
    [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "custom",
    [SEMANTIC_ATTRIBUTE_SENTRY_CUSTOM_SPAN_NAME]: name2
  });
}
__name(updateSpanName, "updateSpanName");
let errorsInstrumented = false;
function registerSpanErrorInstrumentation() {
  if (errorsInstrumented) {
    return;
  }
  errorsInstrumented = true;
  addGlobalErrorInstrumentationHandler(errorCallback);
  addGlobalUnhandledRejectionInstrumentationHandler(errorCallback);
}
__name(registerSpanErrorInstrumentation, "registerSpanErrorInstrumentation");
function errorCallback() {
  const activeSpan = getActiveSpan();
  const rootSpan = activeSpan && getRootSpan(activeSpan);
  if (rootSpan) {
    const message3 = "internal_error";
    DEBUG_BUILD$6 && logger$2.log(`[Tracing] Root span: ${message3} -> Global error occurred`);
    rootSpan.setStatus({ code: SPAN_STATUS_ERROR, message: message3 });
  }
}
__name(errorCallback, "errorCallback");
errorCallback.tag = "sentry_tracingErrorCallback";
const SCOPE_ON_START_SPAN_FIELD = "_sentryScope";
const ISOLATION_SCOPE_ON_START_SPAN_FIELD = "_sentryIsolationScope";
function setCapturedScopesOnSpan(span, scope, isolationScope) {
  if (span) {
    addNonEnumerableProperty(span, ISOLATION_SCOPE_ON_START_SPAN_FIELD, isolationScope);
    addNonEnumerableProperty(span, SCOPE_ON_START_SPAN_FIELD, scope);
  }
}
__name(setCapturedScopesOnSpan, "setCapturedScopesOnSpan");
function getCapturedScopesOnSpan(span) {
  return {
    scope: span[SCOPE_ON_START_SPAN_FIELD],
    isolationScope: span[ISOLATION_SCOPE_ON_START_SPAN_FIELD]
  };
}
__name(getCapturedScopesOnSpan, "getCapturedScopesOnSpan");
function addTracingExtensions() {
  registerSpanErrorInstrumentation();
}
__name(addTracingExtensions, "addTracingExtensions");
function hasTracingEnabled(maybeOptions) {
  if (typeof __SENTRY_TRACING__ === "boolean" && !__SENTRY_TRACING__) {
    return false;
  }
  const client = getClient();
  const options5 = maybeOptions || client && client.getOptions();
  return !!options5 && (options5.enableTracing || "tracesSampleRate" in options5 || "tracesSampler" in options5);
}
__name(hasTracingEnabled, "hasTracingEnabled");
class SentryNonRecordingSpan {
  static {
    __name(this, "SentryNonRecordingSpan");
  }
  constructor(spanContext = {}) {
    this._traceId = spanContext.traceId || generateTraceId();
    this._spanId = spanContext.spanId || generateSpanId();
  }
  /** @inheritdoc */
  spanContext() {
    return {
      spanId: this._spanId,
      traceId: this._traceId,
      traceFlags: TRACE_FLAG_NONE
    };
  }
  /** @inheritdoc */
  // eslint-disable-next-line @typescript-eslint/no-empty-function
  end(_timestamp) {
  }
  /** @inheritdoc */
  setAttribute(_key, _value) {
    return this;
  }
  /** @inheritdoc */
  setAttributes(_values) {
    return this;
  }
  /** @inheritdoc */
  setStatus(_status) {
    return this;
  }
  /** @inheritdoc */
  updateName(_name) {
    return this;
  }
  /** @inheritdoc */
  isRecording() {
    return false;
  }
  /** @inheritdoc */
  addEvent(_name, _attributesOrStartTime, _startTime) {
    return this;
  }
  /**
   * This should generally not be used,
   * but we need it for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  addLink(_link) {
    return this;
  }
  /**
   * This should generally not be used,
   * but we need it for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  addLinks(_links) {
    return this;
  }
  /**
   * This should generally not be used,
   * but we need it for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  recordException(_exception, _time) {
  }
}
function handleCallbackErrors(fn, onError, onFinally = () => {
}) {
  let maybePromiseResult;
  try {
    maybePromiseResult = fn();
  } catch (e2) {
    onError(e2);
    onFinally();
    throw e2;
  }
  return maybeHandlePromiseRejection(maybePromiseResult, onError, onFinally);
}
__name(handleCallbackErrors, "handleCallbackErrors");
function maybeHandlePromiseRejection(value3, onError, onFinally) {
  if (isThenable$1(value3)) {
    return value3.then(
      (res) => {
        onFinally();
        return res;
      },
      (e2) => {
        onError(e2);
        onFinally();
        throw e2;
      }
    );
  }
  onFinally();
  return value3;
}
__name(maybeHandlePromiseRejection, "maybeHandlePromiseRejection");
const DEFAULT_ENVIRONMENT = "production";
const FROZEN_DSC_FIELD = "_frozenDsc";
function freezeDscOnSpan(span, dsc) {
  const spanWithMaybeDsc = span;
  addNonEnumerableProperty(spanWithMaybeDsc, FROZEN_DSC_FIELD, dsc);
}
__name(freezeDscOnSpan, "freezeDscOnSpan");
function getDynamicSamplingContextFromClient(trace_id, client) {
  const options5 = client.getOptions();
  const { publicKey: public_key } = client.getDsn() || {};
  const dsc = dropUndefinedKeys({
    environment: options5.environment || DEFAULT_ENVIRONMENT,
    release: options5.release,
    public_key,
    trace_id
  });
  client.emit("createDsc", dsc);
  return dsc;
}
__name(getDynamicSamplingContextFromClient, "getDynamicSamplingContextFromClient");
function getDynamicSamplingContextFromScope(client, scope) {
  const propagationContext = scope.getPropagationContext();
  return propagationContext.dsc || getDynamicSamplingContextFromClient(propagationContext.traceId, client);
}
__name(getDynamicSamplingContextFromScope, "getDynamicSamplingContextFromScope");
function getDynamicSamplingContextFromSpan(span) {
  const client = getClient();
  if (!client) {
    return {};
  }
  const rootSpan = getRootSpan(span);
  const frozenDsc = rootSpan[FROZEN_DSC_FIELD];
  if (frozenDsc) {
    return frozenDsc;
  }
  const traceState = rootSpan.spanContext().traceState;
  const traceStateDsc = traceState && traceState.get("sentry.dsc");
  const dscOnTraceState = traceStateDsc && baggageHeaderToDynamicSamplingContext(traceStateDsc);
  if (dscOnTraceState) {
    return dscOnTraceState;
  }
  const dsc = getDynamicSamplingContextFromClient(span.spanContext().traceId, client);
  const jsonSpan = spanToJSON(rootSpan);
  const attributes = jsonSpan.data || {};
  const maybeSampleRate = attributes[SEMANTIC_ATTRIBUTE_SENTRY_SAMPLE_RATE];
  if (maybeSampleRate != null) {
    dsc.sample_rate = `${maybeSampleRate}`;
  }
  const source = attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE];
  const name2 = jsonSpan.description;
  if (source !== "url" && name2) {
    dsc.transaction = name2;
  }
  if (hasTracingEnabled()) {
    dsc.sampled = String(spanIsSampled(rootSpan));
  }
  client.emit("createDsc", dsc, rootSpan);
  return dsc;
}
__name(getDynamicSamplingContextFromSpan, "getDynamicSamplingContextFromSpan");
function spanToBaggageHeader(span) {
  const dsc = getDynamicSamplingContextFromSpan(span);
  return dynamicSamplingContextToSentryBaggageHeader(dsc);
}
__name(spanToBaggageHeader, "spanToBaggageHeader");
function logSpanStart(span) {
  if (!DEBUG_BUILD$6) return;
  const { description = "< unknown name >", op = "< unknown op >", parent_span_id: parentSpanId } = spanToJSON(span);
  const { spanId } = span.spanContext();
  const sampled = spanIsSampled(span);
  const rootSpan = getRootSpan(span);
  const isRootSpan = rootSpan === span;
  const header3 = `[Tracing] Starting ${sampled ? "sampled" : "unsampled"} ${isRootSpan ? "root " : ""}span`;
  const infoParts = [`op: ${op}`, `name: ${description}`, `ID: ${spanId}`];
  if (parentSpanId) {
    infoParts.push(`parent ID: ${parentSpanId}`);
  }
  if (!isRootSpan) {
    const { op: op2, description: description2 } = spanToJSON(rootSpan);
    infoParts.push(`root ID: ${rootSpan.spanContext().spanId}`);
    if (op2) {
      infoParts.push(`root op: ${op2}`);
    }
    if (description2) {
      infoParts.push(`root description: ${description2}`);
    }
  }
  logger$2.log(`${header3}
  ${infoParts.join("\n  ")}`);
}
__name(logSpanStart, "logSpanStart");
function logSpanEnd(span) {
  if (!DEBUG_BUILD$6) return;
  const { description = "< unknown name >", op = "< unknown op >" } = spanToJSON(span);
  const { spanId } = span.spanContext();
  const rootSpan = getRootSpan(span);
  const isRootSpan = rootSpan === span;
  const msg = `[Tracing] Finishing "${op}" ${isRootSpan ? "root " : ""}span "${description}" with ID ${spanId}`;
  logger$2.log(msg);
}
__name(logSpanEnd, "logSpanEnd");
function parseSampleRate(sampleRate) {
  if (typeof sampleRate === "boolean") {
    return Number(sampleRate);
  }
  const rate = typeof sampleRate === "string" ? parseFloat(sampleRate) : sampleRate;
  if (typeof rate !== "number" || isNaN(rate) || rate < 0 || rate > 1) {
    DEBUG_BUILD$6 && logger$2.warn(
      `[Tracing] Given sample rate is invalid. Sample rate must be a boolean or a number between 0 and 1. Got ${JSON.stringify(
        sampleRate
      )} of type ${JSON.stringify(typeof sampleRate)}.`
    );
    return void 0;
  }
  return rate;
}
__name(parseSampleRate, "parseSampleRate");
function sampleSpan(options5, samplingContext) {
  if (!hasTracingEnabled(options5)) {
    return [false];
  }
  const normalizedRequest = getIsolationScope().getScopeData().sdkProcessingMetadata.normalizedRequest;
  const enhancedSamplingContext = {
    ...samplingContext,
    normalizedRequest: samplingContext.normalizedRequest || normalizedRequest
  };
  let sampleRate;
  if (typeof options5.tracesSampler === "function") {
    sampleRate = options5.tracesSampler(enhancedSamplingContext);
  } else if (enhancedSamplingContext.parentSampled !== void 0) {
    sampleRate = enhancedSamplingContext.parentSampled;
  } else if (typeof options5.tracesSampleRate !== "undefined") {
    sampleRate = options5.tracesSampleRate;
  } else {
    sampleRate = 1;
  }
  const parsedSampleRate = parseSampleRate(sampleRate);
  if (parsedSampleRate === void 0) {
    DEBUG_BUILD$6 && logger$2.warn("[Tracing] Discarding transaction because of invalid sample rate.");
    return [false];
  }
  if (!parsedSampleRate) {
    DEBUG_BUILD$6 && logger$2.log(
      `[Tracing] Discarding transaction because ${typeof options5.tracesSampler === "function" ? "tracesSampler returned 0 or false" : "a negative sampling decision was inherited or tracesSampleRate is set to 0"}`
    );
    return [false, parsedSampleRate];
  }
  const shouldSample = Math.random() < parsedSampleRate;
  if (!shouldSample) {
    DEBUG_BUILD$6 && logger$2.log(
      `[Tracing] Discarding transaction because it's not included in the random sample (sampling rate = ${Number(
        sampleRate
      )})`
    );
    return [false, parsedSampleRate];
  }
  return [true, parsedSampleRate];
}
__name(sampleSpan, "sampleSpan");
const DSN_REGEX = /^(?:(\w+):)\/\/(?:(\w+)(?::(\w+)?)?@)([\w.-]+)(?::(\d+))?\/(.+)/;
function isValidProtocol(protocol) {
  return protocol === "http" || protocol === "https";
}
__name(isValidProtocol, "isValidProtocol");
function dsnToString(dsn, withPassword = false) {
  const { host, path, pass, port, projectId, protocol, publicKey } = dsn;
  return `${protocol}://${publicKey}${withPassword && pass ? `:${pass}` : ""}@${host}${port ? `:${port}` : ""}/${path ? `${path}/` : path}${projectId}`;
}
__name(dsnToString, "dsnToString");
function dsnFromString(str) {
  const match2 = DSN_REGEX.exec(str);
  if (!match2) {
    consoleSandbox(() => {
      console.error(`Invalid Sentry Dsn: ${str}`);
    });
    return void 0;
  }
  const [protocol, publicKey, pass = "", host = "", port = "", lastPath = ""] = match2.slice(1);
  let path = "";
  let projectId = lastPath;
  const split2 = projectId.split("/");
  if (split2.length > 1) {
    path = split2.slice(0, -1).join("/");
    projectId = split2.pop();
  }
  if (projectId) {
    const projectMatch = projectId.match(/^\d+/);
    if (projectMatch) {
      projectId = projectMatch[0];
    }
  }
  return dsnFromComponents({ host, pass, path, projectId, port, protocol, publicKey });
}
__name(dsnFromString, "dsnFromString");
function dsnFromComponents(components) {
  return {
    protocol: components.protocol,
    publicKey: components.publicKey || "",
    pass: components.pass || "",
    host: components.host,
    port: components.port || "",
    path: components.path || "",
    projectId: components.projectId
  };
}
__name(dsnFromComponents, "dsnFromComponents");
function validateDsn(dsn) {
  if (!DEBUG_BUILD$5) {
    return true;
  }
  const { port, projectId, protocol } = dsn;
  const requiredComponents = ["protocol", "publicKey", "host", "projectId"];
  const hasMissingRequiredComponent = requiredComponents.find((component) => {
    if (!dsn[component]) {
      logger$2.error(`Invalid Sentry Dsn: ${component} missing`);
      return true;
    }
    return false;
  });
  if (hasMissingRequiredComponent) {
    return false;
  }
  if (!projectId.match(/^\d+$/)) {
    logger$2.error(`Invalid Sentry Dsn: Invalid projectId ${projectId}`);
    return false;
  }
  if (!isValidProtocol(protocol)) {
    logger$2.error(`Invalid Sentry Dsn: Invalid protocol ${protocol}`);
    return false;
  }
  if (port && isNaN(parseInt(port, 10))) {
    logger$2.error(`Invalid Sentry Dsn: Invalid port ${port}`);
    return false;
  }
  return true;
}
__name(validateDsn, "validateDsn");
function makeDsn(from2) {
  const components = typeof from2 === "string" ? dsnFromString(from2) : dsnFromComponents(from2);
  if (!components || !validateDsn(components)) {
    return void 0;
  }
  return components;
}
__name(makeDsn, "makeDsn");
function memoBuilder() {
  const hasWeakSet = typeof WeakSet === "function";
  const inner = hasWeakSet ? /* @__PURE__ */ new WeakSet() : [];
  function memoize(obj) {
    if (hasWeakSet) {
      if (inner.has(obj)) {
        return true;
      }
      inner.add(obj);
      return false;
    }
    for (let i2 = 0; i2 < inner.length; i2++) {
      const value3 = inner[i2];
      if (value3 === obj) {
        return true;
      }
    }
    inner.push(obj);
    return false;
  }
  __name(memoize, "memoize");
  function unmemoize(obj) {
    if (hasWeakSet) {
      inner.delete(obj);
    } else {
      for (let i2 = 0; i2 < inner.length; i2++) {
        if (inner[i2] === obj) {
          inner.splice(i2, 1);
          break;
        }
      }
    }
  }
  __name(unmemoize, "unmemoize");
  return [memoize, unmemoize];
}
__name(memoBuilder, "memoBuilder");
function normalize$2(input, depth = 100, maxProperties = Infinity) {
  try {
    return visit("", input, depth, maxProperties);
  } catch (err) {
    return { ERROR: `**non-serializable** (${err})` };
  }
}
__name(normalize$2, "normalize$2");
function normalizeToSize(object, depth = 3, maxSize = 100 * 1024) {
  const normalized = normalize$2(object, depth);
  if (jsonSize(normalized) > maxSize) {
    return normalizeToSize(object, depth - 1, maxSize);
  }
  return normalized;
}
__name(normalizeToSize, "normalizeToSize");
function visit(key, value3, depth = Infinity, maxProperties = Infinity, memo = memoBuilder()) {
  const [memoize, unmemoize] = memo;
  if (value3 == null || // this matches null and undefined -> eqeq not eqeqeq
  ["boolean", "string"].includes(typeof value3) || typeof value3 === "number" && Number.isFinite(value3)) {
    return value3;
  }
  const stringified = stringifyValue(key, value3);
  if (!stringified.startsWith("[object ")) {
    return stringified;
  }
  if (value3["__sentry_skip_normalization__"]) {
    return value3;
  }
  const remainingDepth = typeof value3["__sentry_override_normalization_depth__"] === "number" ? value3["__sentry_override_normalization_depth__"] : depth;
  if (remainingDepth === 0) {
    return stringified.replace("object ", "");
  }
  if (memoize(value3)) {
    return "[Circular ~]";
  }
  const valueWithToJSON = value3;
  if (valueWithToJSON && typeof valueWithToJSON.toJSON === "function") {
    try {
      const jsonValue = valueWithToJSON.toJSON();
      return visit("", jsonValue, remainingDepth - 1, maxProperties, memo);
    } catch (err) {
    }
  }
  const normalized = Array.isArray(value3) ? [] : {};
  let numAdded = 0;
  const visitable = convertToPlainObject(value3);
  for (const visitKey in visitable) {
    if (!Object.prototype.hasOwnProperty.call(visitable, visitKey)) {
      continue;
    }
    if (numAdded >= maxProperties) {
      normalized[visitKey] = "[MaxProperties ~]";
      break;
    }
    const visitValue = visitable[visitKey];
    normalized[visitKey] = visit(visitKey, visitValue, remainingDepth - 1, maxProperties, memo);
    numAdded++;
  }
  unmemoize(value3);
  return normalized;
}
__name(visit, "visit");
function stringifyValue(key, value3) {
  try {
    if (key === "domain" && value3 && typeof value3 === "object" && value3._events) {
      return "[Domain]";
    }
    if (key === "domainEmitter") {
      return "[DomainEmitter]";
    }
    if (typeof global !== "undefined" && value3 === global) {
      return "[Global]";
    }
    if (typeof window !== "undefined" && value3 === window) {
      return "[Window]";
    }
    if (typeof document !== "undefined" && value3 === document) {
      return "[Document]";
    }
    if (isVueViewModel(value3)) {
      return "[VueViewModel]";
    }
    if (isSyntheticEvent(value3)) {
      return "[SyntheticEvent]";
    }
    if (typeof value3 === "number" && !Number.isFinite(value3)) {
      return `[${value3}]`;
    }
    if (typeof value3 === "function") {
      return `[Function: ${getFunctionName(value3)}]`;
    }
    if (typeof value3 === "symbol") {
      return `[${String(value3)}]`;
    }
    if (typeof value3 === "bigint") {
      return `[BigInt: ${String(value3)}]`;
    }
    const objName = getConstructorName(value3);
    if (/^HTML(\w*)Element$/.test(objName)) {
      return `[HTMLElement: ${objName}]`;
    }
    return `[object ${objName}]`;
  } catch (err) {
    return `**non-serializable** (${err})`;
  }
}
__name(stringifyValue, "stringifyValue");
function getConstructorName(value3) {
  const prototype2 = Object.getPrototypeOf(value3);
  return prototype2 ? prototype2.constructor.name : "null prototype";
}
__name(getConstructorName, "getConstructorName");
function utf8Length(value3) {
  return ~-encodeURI(value3).split(/%..|./).length;
}
__name(utf8Length, "utf8Length");
function jsonSize(value3) {
  return utf8Length(JSON.stringify(value3));
}
__name(jsonSize, "jsonSize");
function normalizeUrlToBase(url, basePath2) {
  const escapedBase = basePath2.replace(/\\/g, "/").replace(/[|\\{}()[\]^$+*?.]/g, "\\$&");
  let newUrl = url;
  try {
    newUrl = decodeURI(url);
  } catch (_Oo) {
  }
  return newUrl.replace(/\\/g, "/").replace(/webpack:\/?/g, "").replace(new RegExp(`(file://)?/*${escapedBase}/*`, "ig"), "app:///");
}
__name(normalizeUrlToBase, "normalizeUrlToBase");
function createEnvelope(headers, items2 = []) {
  return [headers, items2];
}
__name(createEnvelope, "createEnvelope");
function addItemToEnvelope(envelope, newItem) {
  const [headers, items2] = envelope;
  return [headers, [...items2, newItem]];
}
__name(addItemToEnvelope, "addItemToEnvelope");
function forEachEnvelopeItem(envelope, callback) {
  const envelopeItems = envelope[1];
  for (const envelopeItem of envelopeItems) {
    const envelopeItemType = envelopeItem[0].type;
    const result = callback(envelopeItem, envelopeItemType);
    if (result) {
      return true;
    }
  }
  return false;
}
__name(forEachEnvelopeItem, "forEachEnvelopeItem");
function envelopeContainsItemType(envelope, types) {
  return forEachEnvelopeItem(envelope, (_2, type) => types.includes(type));
}
__name(envelopeContainsItemType, "envelopeContainsItemType");
function encodeUTF8(input) {
  return GLOBAL_OBJ.__SENTRY__ && GLOBAL_OBJ.__SENTRY__.encodePolyfill ? GLOBAL_OBJ.__SENTRY__.encodePolyfill(input) : new TextEncoder().encode(input);
}
__name(encodeUTF8, "encodeUTF8");
function decodeUTF8(input) {
  return GLOBAL_OBJ.__SENTRY__ && GLOBAL_OBJ.__SENTRY__.decodePolyfill ? GLOBAL_OBJ.__SENTRY__.decodePolyfill(input) : new TextDecoder().decode(input);
}
__name(decodeUTF8, "decodeUTF8");
function serializeEnvelope(envelope) {
  const [envHeaders, items2] = envelope;
  let parts2 = JSON.stringify(envHeaders);
  function append3(next2) {
    if (typeof parts2 === "string") {
      parts2 = typeof next2 === "string" ? parts2 + next2 : [encodeUTF8(parts2), next2];
    } else {
      parts2.push(typeof next2 === "string" ? encodeUTF8(next2) : next2);
    }
  }
  __name(append3, "append");
  for (const item3 of items2) {
    const [itemHeaders, payload] = item3;
    append3(`
${JSON.stringify(itemHeaders)}
`);
    if (typeof payload === "string" || payload instanceof Uint8Array) {
      append3(payload);
    } else {
      let stringifiedPayload;
      try {
        stringifiedPayload = JSON.stringify(payload);
      } catch (e2) {
        stringifiedPayload = JSON.stringify(normalize$2(payload));
      }
      append3(stringifiedPayload);
    }
  }
  return typeof parts2 === "string" ? parts2 : concatBuffers(parts2);
}
__name(serializeEnvelope, "serializeEnvelope");
function concatBuffers(buffers) {
  const totalLength = buffers.reduce((acc, buf) => acc + buf.length, 0);
  const merged = new Uint8Array(totalLength);
  let offset = 0;
  for (const buffer2 of buffers) {
    merged.set(buffer2, offset);
    offset += buffer2.length;
  }
  return merged;
}
__name(concatBuffers, "concatBuffers");
function parseEnvelope(env) {
  let buffer2 = typeof env === "string" ? encodeUTF8(env) : env;
  function readBinary(length) {
    const bin = buffer2.subarray(0, length);
    buffer2 = buffer2.subarray(length + 1);
    return bin;
  }
  __name(readBinary, "readBinary");
  function readJson2() {
    let i2 = buffer2.indexOf(10);
    if (i2 < 0) {
      i2 = buffer2.length;
    }
    return JSON.parse(decodeUTF8(readBinary(i2)));
  }
  __name(readJson2, "readJson");
  const envelopeHeader = readJson2();
  const items2 = [];
  while (buffer2.length) {
    const itemHeader = readJson2();
    const binaryLength = typeof itemHeader.length === "number" ? itemHeader.length : void 0;
    items2.push([itemHeader, binaryLength ? readBinary(binaryLength) : readJson2()]);
  }
  return [envelopeHeader, items2];
}
__name(parseEnvelope, "parseEnvelope");
function createSpanEnvelopeItem(spanJson) {
  const spanHeaders = {
    type: "span"
  };
  return [spanHeaders, spanJson];
}
__name(createSpanEnvelopeItem, "createSpanEnvelopeItem");
function createAttachmentEnvelopeItem(attachment) {
  const buffer2 = typeof attachment.data === "string" ? encodeUTF8(attachment.data) : attachment.data;
  return [
    dropUndefinedKeys({
      type: "attachment",
      length: buffer2.length,
      filename: attachment.filename,
      content_type: attachment.contentType,
      attachment_type: attachment.attachmentType
    }),
    buffer2
  ];
}
__name(createAttachmentEnvelopeItem, "createAttachmentEnvelopeItem");
const ITEM_TYPE_TO_DATA_CATEGORY_MAP = {
  session: "session",
  sessions: "session",
  attachment: "attachment",
  transaction: "transaction",
  event: "error",
  client_report: "internal",
  user_report: "default",
  profile: "profile",
  profile_chunk: "profile",
  replay_event: "replay",
  replay_recording: "replay",
  check_in: "monitor",
  feedback: "feedback",
  span: "span",
  statsd: "metric_bucket",
  raw_security: "security"
};
function envelopeItemTypeToDataCategory(type) {
  return ITEM_TYPE_TO_DATA_CATEGORY_MAP[type];
}
__name(envelopeItemTypeToDataCategory, "envelopeItemTypeToDataCategory");
function getSdkMetadataForEnvelopeHeader(metadataOrEvent) {
  if (!metadataOrEvent || !metadataOrEvent.sdk) {
    return;
  }
  const { name: name2, version: version2 } = metadataOrEvent.sdk;
  return { name: name2, version: version2 };
}
__name(getSdkMetadataForEnvelopeHeader, "getSdkMetadataForEnvelopeHeader");
function createEventEnvelopeHeaders(event, sdkInfo, tunnel, dsn) {
  const dynamicSamplingContext = event.sdkProcessingMetadata && event.sdkProcessingMetadata.dynamicSamplingContext;
  return {
    event_id: event.event_id,
    sent_at: (/* @__PURE__ */ new Date()).toISOString(),
    ...sdkInfo && { sdk: sdkInfo },
    ...!!tunnel && dsn && { dsn: dsnToString(dsn) },
    ...dynamicSamplingContext && {
      trace: dropUndefinedKeys({ ...dynamicSamplingContext })
    }
  };
}
__name(createEventEnvelopeHeaders, "createEventEnvelopeHeaders");
function enhanceEventWithSdkInfo(event, sdkInfo) {
  if (!sdkInfo) {
    return event;
  }
  event.sdk = event.sdk || {};
  event.sdk.name = event.sdk.name || sdkInfo.name;
  event.sdk.version = event.sdk.version || sdkInfo.version;
  event.sdk.integrations = [...event.sdk.integrations || [], ...sdkInfo.integrations || []];
  event.sdk.packages = [...event.sdk.packages || [], ...sdkInfo.packages || []];
  return event;
}
__name(enhanceEventWithSdkInfo, "enhanceEventWithSdkInfo");
function createSessionEnvelope(session, dsn, metadata, tunnel) {
  const sdkInfo = getSdkMetadataForEnvelopeHeader(metadata);
  const envelopeHeaders = {
    sent_at: (/* @__PURE__ */ new Date()).toISOString(),
    ...sdkInfo && { sdk: sdkInfo },
    ...!!tunnel && dsn && { dsn: dsnToString(dsn) }
  };
  const envelopeItem = "aggregates" in session ? [{ type: "sessions" }, session] : [{ type: "session" }, session.toJSON()];
  return createEnvelope(envelopeHeaders, [envelopeItem]);
}
__name(createSessionEnvelope, "createSessionEnvelope");
function createEventEnvelope(event, dsn, metadata, tunnel) {
  const sdkInfo = getSdkMetadataForEnvelopeHeader(metadata);
  const eventType = event.type && event.type !== "replay_event" ? event.type : "event";
  enhanceEventWithSdkInfo(event, metadata && metadata.sdk);
  const envelopeHeaders = createEventEnvelopeHeaders(event, sdkInfo, tunnel, dsn);
  delete event.sdkProcessingMetadata;
  const eventItem = [{ type: eventType }, event];
  return createEnvelope(envelopeHeaders, [eventItem]);
}
__name(createEventEnvelope, "createEventEnvelope");
function createSpanEnvelope(spans, client) {
  function dscHasRequiredProps(dsc2) {
    return !!dsc2.trace_id && !!dsc2.public_key;
  }
  __name(dscHasRequiredProps, "dscHasRequiredProps");
  const dsc = getDynamicSamplingContextFromSpan(spans[0]);
  const dsn = client && client.getDsn();
  const tunnel = client && client.getOptions().tunnel;
  const headers = {
    sent_at: (/* @__PURE__ */ new Date()).toISOString(),
    ...dscHasRequiredProps(dsc) && { trace: dsc },
    ...!!tunnel && dsn && { dsn: dsnToString(dsn) }
  };
  const beforeSendSpan = client && client.getOptions().beforeSendSpan;
  const convertToSpanJSON = beforeSendSpan ? (span) => {
    const spanJson = beforeSendSpan(spanToJSON(span));
    if (!spanJson) {
      showSpanDropWarning();
    }
    return spanJson;
  } : (span) => spanToJSON(span);
  const items2 = [];
  for (const span of spans) {
    const spanJson = convertToSpanJSON(span);
    if (spanJson) {
      items2.push(createSpanEnvelopeItem(spanJson));
    }
  }
  return createEnvelope(headers, items2);
}
__name(createSpanEnvelope, "createSpanEnvelope");
function setMeasurement(name2, value3, unit, activeSpan = getActiveSpan()) {
  const rootSpan = activeSpan && getRootSpan(activeSpan);
  if (rootSpan) {
    DEBUG_BUILD$6 && logger$2.log(`[Measurement] Setting measurement on root span: ${name2} = ${value3} ${unit}`);
    rootSpan.addEvent(name2, {
      [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_VALUE]: value3,
      [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_UNIT]: unit
    });
  }
}
__name(setMeasurement, "setMeasurement");
function timedEventsToMeasurements(events2) {
  if (!events2 || events2.length === 0) {
    return void 0;
  }
  const measurements = {};
  events2.forEach((event) => {
    const attributes = event.attributes || {};
    const unit = attributes[SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_UNIT];
    const value3 = attributes[SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_VALUE];
    if (typeof unit === "string" && typeof value3 === "number") {
      measurements[event.name] = { value: value3, unit };
    }
  });
  return measurements;
}
__name(timedEventsToMeasurements, "timedEventsToMeasurements");
const MAX_SPAN_COUNT = 1e3;
class SentrySpan {
  static {
    __name(this, "SentrySpan");
  }
  /** Epoch timestamp in seconds when the span started. */
  /** Epoch timestamp in seconds when the span ended. */
  /** Internal keeper of the status */
  /** The timed events added to this span. */
  /** if true, treat span as a standalone span (not part of a transaction) */
  /**
   * You should never call the constructor manually, always use `Sentry.startSpan()`
   * or other span methods.
   * @internal
   * @hideconstructor
   * @hidden
   */
  constructor(spanContext = {}) {
    this._traceId = spanContext.traceId || generateTraceId();
    this._spanId = spanContext.spanId || generateSpanId();
    this._startTime = spanContext.startTimestamp || timestampInSeconds();
    this._attributes = {};
    this.setAttributes({
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "manual",
      [SEMANTIC_ATTRIBUTE_SENTRY_OP]: spanContext.op,
      ...spanContext.attributes
    });
    this._name = spanContext.name;
    if (spanContext.parentSpanId) {
      this._parentSpanId = spanContext.parentSpanId;
    }
    if ("sampled" in spanContext) {
      this._sampled = spanContext.sampled;
    }
    if (spanContext.endTimestamp) {
      this._endTime = spanContext.endTimestamp;
    }
    this._events = [];
    this._isStandaloneSpan = spanContext.isStandalone;
    if (this._endTime) {
      this._onSpanEnded();
    }
  }
  /**
   * This should generally not be used,
   * but it is needed for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  addLink(_link) {
    return this;
  }
  /**
   * This should generally not be used,
   * but it is needed for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  addLinks(_links) {
    return this;
  }
  /**
   * This should generally not be used,
   * but it is needed for being compliant with the OTEL Span interface.
   *
   * @hidden
   * @internal
   */
  recordException(_exception, _time) {
  }
  /** @inheritdoc */
  spanContext() {
    const { _spanId: spanId, _traceId: traceId, _sampled: sampled } = this;
    return {
      spanId,
      traceId,
      traceFlags: sampled ? TRACE_FLAG_SAMPLED : TRACE_FLAG_NONE
    };
  }
  /** @inheritdoc */
  setAttribute(key, value3) {
    if (value3 === void 0) {
      delete this._attributes[key];
    } else {
      this._attributes[key] = value3;
    }
    return this;
  }
  /** @inheritdoc */
  setAttributes(attributes) {
    Object.keys(attributes).forEach((key) => this.setAttribute(key, attributes[key]));
    return this;
  }
  /**
   * This should generally not be used,
   * but we need it for browser tracing where we want to adjust the start time afterwards.
   * USE THIS WITH CAUTION!
   *
   * @hidden
   * @internal
   */
  updateStartTime(timeInput) {
    this._startTime = spanTimeInputToSeconds(timeInput);
  }
  /**
   * @inheritDoc
   */
  setStatus(value3) {
    this._status = value3;
    return this;
  }
  /**
   * @inheritDoc
   */
  updateName(name2) {
    this._name = name2;
    this.setAttribute(SEMANTIC_ATTRIBUTE_SENTRY_SOURCE, "custom");
    return this;
  }
  /** @inheritdoc */
  end(endTimestamp) {
    if (this._endTime) {
      return;
    }
    this._endTime = spanTimeInputToSeconds(endTimestamp);
    logSpanEnd(this);
    this._onSpanEnded();
  }
  /**
   * Get JSON representation of this span.
   *
   * @hidden
   * @internal This method is purely for internal purposes and should not be used outside
   * of SDK code. If you need to get a JSON representation of a span,
   * use `spanToJSON(span)` instead.
   */
  getSpanJSON() {
    return dropUndefinedKeys({
      data: this._attributes,
      description: this._name,
      op: this._attributes[SEMANTIC_ATTRIBUTE_SENTRY_OP],
      parent_span_id: this._parentSpanId,
      span_id: this._spanId,
      start_timestamp: this._startTime,
      status: getStatusMessage(this._status),
      timestamp: this._endTime,
      trace_id: this._traceId,
      origin: this._attributes[SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN],
      _metrics_summary: getMetricSummaryJsonForSpan(this),
      profile_id: this._attributes[SEMANTIC_ATTRIBUTE_PROFILE_ID],
      exclusive_time: this._attributes[SEMANTIC_ATTRIBUTE_EXCLUSIVE_TIME],
      measurements: timedEventsToMeasurements(this._events),
      is_segment: this._isStandaloneSpan && getRootSpan(this) === this || void 0,
      segment_id: this._isStandaloneSpan ? getRootSpan(this).spanContext().spanId : void 0
    });
  }
  /** @inheritdoc */
  isRecording() {
    return !this._endTime && !!this._sampled;
  }
  /**
   * @inheritdoc
   */
  addEvent(name2, attributesOrStartTime, startTime) {
    DEBUG_BUILD$6 && logger$2.log("[Tracing] Adding an event to span:", name2);
    const time = isSpanTimeInput(attributesOrStartTime) ? attributesOrStartTime : startTime || timestampInSeconds();
    const attributes = isSpanTimeInput(attributesOrStartTime) ? {} : attributesOrStartTime || {};
    const event = {
      name: name2,
      time: spanTimeInputToSeconds(time),
      attributes
    };
    this._events.push(event);
    return this;
  }
  /**
   * This method should generally not be used,
   * but for now we need a way to publicly check if the `_isStandaloneSpan` flag is set.
   * USE THIS WITH CAUTION!
   * @internal
   * @hidden
   * @experimental
   */
  isStandaloneSpan() {
    return !!this._isStandaloneSpan;
  }
  /** Emit `spanEnd` when the span is ended. */
  _onSpanEnded() {
    const client = getClient();
    if (client) {
      client.emit("spanEnd", this);
    }
    const isSegmentSpan = this._isStandaloneSpan || this === getRootSpan(this);
    if (!isSegmentSpan) {
      return;
    }
    if (this._isStandaloneSpan) {
      if (this._sampled) {
        sendSpanEnvelope(createSpanEnvelope([this], client));
      } else {
        DEBUG_BUILD$6 && logger$2.log("[Tracing] Discarding standalone span because its trace was not chosen to be sampled.");
        if (client) {
          client.recordDroppedEvent("sample_rate", "span");
        }
      }
      return;
    }
    const transactionEvent = this._convertSpanToTransaction();
    if (transactionEvent) {
      const scope = getCapturedScopesOnSpan(this).scope || getCurrentScope$1();
      scope.captureEvent(transactionEvent);
    }
  }
  /**
   * Finish the transaction & prepare the event to send to Sentry.
   */
  _convertSpanToTransaction() {
    if (!isFullFinishedSpan(spanToJSON(this))) {
      return void 0;
    }
    if (!this._name) {
      DEBUG_BUILD$6 && logger$2.warn("Transaction has no name, falling back to `<unlabeled transaction>`.");
      this._name = "<unlabeled transaction>";
    }
    const { scope: capturedSpanScope, isolationScope: capturedSpanIsolationScope } = getCapturedScopesOnSpan(this);
    const scope = capturedSpanScope || getCurrentScope$1();
    const client = scope.getClient() || getClient();
    if (this._sampled !== true) {
      DEBUG_BUILD$6 && logger$2.log("[Tracing] Discarding transaction because its trace was not chosen to be sampled.");
      if (client) {
        client.recordDroppedEvent("sample_rate", "transaction");
      }
      return void 0;
    }
    const finishedSpans = getSpanDescendants(this).filter((span) => span !== this && !isStandaloneSpan(span));
    const spans = finishedSpans.map((span) => spanToJSON(span)).filter(isFullFinishedSpan);
    const source = this._attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE];
    delete this._attributes[SEMANTIC_ATTRIBUTE_SENTRY_CUSTOM_SPAN_NAME];
    spans.forEach((span) => {
      span.data && delete span.data[SEMANTIC_ATTRIBUTE_SENTRY_CUSTOM_SPAN_NAME];
    });
    const transaction = {
      contexts: {
        trace: spanToTransactionTraceContext(this)
      },
      spans: (
        // spans.sort() mutates the array, but `spans` is already a copy so we can safely do this here
        // we do not use spans anymore after this point
        spans.length > MAX_SPAN_COUNT ? spans.sort((a2, b2) => a2.start_timestamp - b2.start_timestamp).slice(0, MAX_SPAN_COUNT) : spans
      ),
      start_timestamp: this._startTime,
      timestamp: this._endTime,
      transaction: this._name,
      type: "transaction",
      sdkProcessingMetadata: {
        capturedSpanScope,
        capturedSpanIsolationScope,
        ...dropUndefinedKeys({
          dynamicSamplingContext: getDynamicSamplingContextFromSpan(this)
        })
      },
      _metrics_summary: getMetricSummaryJsonForSpan(this),
      ...source && {
        transaction_info: {
          source
        }
      }
    };
    const measurements = timedEventsToMeasurements(this._events);
    const hasMeasurements = measurements && Object.keys(measurements).length;
    if (hasMeasurements) {
      DEBUG_BUILD$6 && logger$2.log(
        "[Measurements] Adding measurements to transaction event",
        JSON.stringify(measurements, void 0, 2)
      );
      transaction.measurements = measurements;
    }
    return transaction;
  }
}
function isSpanTimeInput(value3) {
  return value3 && typeof value3 === "number" || value3 instanceof Date || Array.isArray(value3);
}
__name(isSpanTimeInput, "isSpanTimeInput");
function isFullFinishedSpan(input) {
  return !!input.start_timestamp && !!input.timestamp && !!input.span_id && !!input.trace_id;
}
__name(isFullFinishedSpan, "isFullFinishedSpan");
function isStandaloneSpan(span) {
  return span instanceof SentrySpan && span.isStandaloneSpan();
}
__name(isStandaloneSpan, "isStandaloneSpan");
function sendSpanEnvelope(envelope) {
  const client = getClient();
  if (!client) {
    return;
  }
  const spanItems = envelope[1];
  if (!spanItems || spanItems.length === 0) {
    client.recordDroppedEvent("before_send", "span");
    return;
  }
  client.sendEnvelope(envelope);
}
__name(sendSpanEnvelope, "sendSpanEnvelope");
const SUPPRESS_TRACING_KEY = "__SENTRY_SUPPRESS_TRACING__";
function startSpan(options5, callback) {
  const acs = getAcs();
  if (acs.startSpan) {
    return acs.startSpan(options5, callback);
  }
  const spanArguments = parseSentrySpanArguments(options5);
  const { forceTransaction, parentSpan: customParentSpan } = options5;
  return withScope(options5.scope, () => {
    const wrapper = getActiveSpanWrapper(customParentSpan);
    return wrapper(() => {
      const scope = getCurrentScope$1();
      const parentSpan = getParentSpan(scope);
      const shouldSkipSpan = options5.onlyIfParent && !parentSpan;
      const activeSpan = shouldSkipSpan ? new SentryNonRecordingSpan() : createChildOrRootSpan({
        parentSpan,
        spanArguments,
        forceTransaction,
        scope
      });
      _setSpanForScope(scope, activeSpan);
      return handleCallbackErrors(
        () => callback(activeSpan),
        () => {
          const { status } = spanToJSON(activeSpan);
          if (activeSpan.isRecording() && (!status || status === "ok")) {
            activeSpan.setStatus({ code: SPAN_STATUS_ERROR, message: "internal_error" });
          }
        },
        () => activeSpan.end()
      );
    });
  });
}
__name(startSpan, "startSpan");
function startSpanManual(options5, callback) {
  const acs = getAcs();
  if (acs.startSpanManual) {
    return acs.startSpanManual(options5, callback);
  }
  const spanArguments = parseSentrySpanArguments(options5);
  const { forceTransaction, parentSpan: customParentSpan } = options5;
  return withScope(options5.scope, () => {
    const wrapper = getActiveSpanWrapper(customParentSpan);
    return wrapper(() => {
      const scope = getCurrentScope$1();
      const parentSpan = getParentSpan(scope);
      const shouldSkipSpan = options5.onlyIfParent && !parentSpan;
      const activeSpan = shouldSkipSpan ? new SentryNonRecordingSpan() : createChildOrRootSpan({
        parentSpan,
        spanArguments,
        forceTransaction,
        scope
      });
      _setSpanForScope(scope, activeSpan);
      function finishAndSetSpan() {
        activeSpan.end();
      }
      __name(finishAndSetSpan, "finishAndSetSpan");
      return handleCallbackErrors(
        () => callback(activeSpan, finishAndSetSpan),
        () => {
          const { status } = spanToJSON(activeSpan);
          if (activeSpan.isRecording() && (!status || status === "ok")) {
            activeSpan.setStatus({ code: SPAN_STATUS_ERROR, message: "internal_error" });
          }
        }
      );
    });
  });
}
__name(startSpanManual, "startSpanManual");
function startInactiveSpan(options5) {
  const acs = getAcs();
  if (acs.startInactiveSpan) {
    return acs.startInactiveSpan(options5);
  }
  const spanArguments = parseSentrySpanArguments(options5);
  const { forceTransaction, parentSpan: customParentSpan } = options5;
  const wrapper = options5.scope ? (callback) => withScope(options5.scope, callback) : customParentSpan !== void 0 ? (callback) => withActiveSpan(customParentSpan, callback) : (callback) => callback();
  return wrapper(() => {
    const scope = getCurrentScope$1();
    const parentSpan = getParentSpan(scope);
    const shouldSkipSpan = options5.onlyIfParent && !parentSpan;
    if (shouldSkipSpan) {
      return new SentryNonRecordingSpan();
    }
    return createChildOrRootSpan({
      parentSpan,
      spanArguments,
      forceTransaction,
      scope
    });
  });
}
__name(startInactiveSpan, "startInactiveSpan");
const continueTrace = /* @__PURE__ */ __name((options5, callback) => {
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  if (acs.continueTrace) {
    return acs.continueTrace(options5, callback);
  }
  const { sentryTrace, baggage } = options5;
  return withScope((scope) => {
    const propagationContext = propagationContextFromHeaders(sentryTrace, baggage);
    scope.setPropagationContext(propagationContext);
    return callback();
  });
}, "continueTrace");
function withActiveSpan(span, callback) {
  const acs = getAcs();
  if (acs.withActiveSpan) {
    return acs.withActiveSpan(span, callback);
  }
  return withScope((scope) => {
    _setSpanForScope(scope, span || void 0);
    return callback(scope);
  });
}
__name(withActiveSpan, "withActiveSpan");
function suppressTracing(callback) {
  const acs = getAcs();
  if (acs.suppressTracing) {
    return acs.suppressTracing(callback);
  }
  return withScope((scope) => {
    scope.setSDKProcessingMetadata({ [SUPPRESS_TRACING_KEY]: true });
    return callback();
  });
}
__name(suppressTracing, "suppressTracing");
function startNewTrace(callback) {
  return withScope((scope) => {
    scope.setPropagationContext({ traceId: generateTraceId() });
    DEBUG_BUILD$6 && logger$2.info(`Starting a new trace with id ${scope.getPropagationContext().traceId}`);
    return withActiveSpan(null, callback);
  });
}
__name(startNewTrace, "startNewTrace");
function createChildOrRootSpan({
  parentSpan,
  spanArguments,
  forceTransaction,
  scope
}) {
  if (!hasTracingEnabled()) {
    return new SentryNonRecordingSpan();
  }
  const isolationScope = getIsolationScope();
  let span;
  if (parentSpan && !forceTransaction) {
    span = _startChildSpan(parentSpan, scope, spanArguments);
    addChildSpanToSpan(parentSpan, span);
  } else if (parentSpan) {
    const dsc = getDynamicSamplingContextFromSpan(parentSpan);
    const { traceId, spanId: parentSpanId } = parentSpan.spanContext();
    const parentSampled = spanIsSampled(parentSpan);
    span = _startRootSpan(
      {
        traceId,
        parentSpanId,
        ...spanArguments
      },
      scope,
      parentSampled
    );
    freezeDscOnSpan(span, dsc);
  } else {
    const {
      traceId,
      dsc,
      parentSpanId,
      sampled: parentSampled
    } = {
      ...isolationScope.getPropagationContext(),
      ...scope.getPropagationContext()
    };
    span = _startRootSpan(
      {
        traceId,
        parentSpanId,
        ...spanArguments
      },
      scope,
      parentSampled
    );
    if (dsc) {
      freezeDscOnSpan(span, dsc);
    }
  }
  logSpanStart(span);
  setCapturedScopesOnSpan(span, scope, isolationScope);
  return span;
}
__name(createChildOrRootSpan, "createChildOrRootSpan");
function parseSentrySpanArguments(options5) {
  const exp = options5.experimental || {};
  const initialCtx = {
    isStandalone: exp.standalone,
    ...options5
  };
  if (options5.startTime) {
    const ctx = { ...initialCtx };
    ctx.startTimestamp = spanTimeInputToSeconds(options5.startTime);
    delete ctx.startTime;
    return ctx;
  }
  return initialCtx;
}
__name(parseSentrySpanArguments, "parseSentrySpanArguments");
function getAcs() {
  const carrier = getMainCarrier();
  return getAsyncContextStrategy(carrier);
}
__name(getAcs, "getAcs");
function _startRootSpan(spanArguments, scope, parentSampled) {
  const client = getClient();
  const options5 = client && client.getOptions() || {};
  const { name: name2 = "", attributes } = spanArguments;
  const [sampled, sampleRate] = scope.getScopeData().sdkProcessingMetadata[SUPPRESS_TRACING_KEY] ? [false] : sampleSpan(options5, {
    name: name2,
    parentSampled,
    attributes,
    transactionContext: {
      name: name2,
      parentSampled
    }
  });
  const rootSpan = new SentrySpan({
    ...spanArguments,
    attributes: {
      [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "custom",
      ...spanArguments.attributes
    },
    sampled
  });
  if (sampleRate !== void 0) {
    rootSpan.setAttribute(SEMANTIC_ATTRIBUTE_SENTRY_SAMPLE_RATE, sampleRate);
  }
  if (client) {
    client.emit("spanStart", rootSpan);
  }
  return rootSpan;
}
__name(_startRootSpan, "_startRootSpan");
function _startChildSpan(parentSpan, scope, spanArguments) {
  const { spanId, traceId } = parentSpan.spanContext();
  const sampled = scope.getScopeData().sdkProcessingMetadata[SUPPRESS_TRACING_KEY] ? false : spanIsSampled(parentSpan);
  const childSpan = sampled ? new SentrySpan({
    ...spanArguments,
    parentSpanId: spanId,
    traceId,
    sampled
  }) : new SentryNonRecordingSpan({ traceId });
  addChildSpanToSpan(parentSpan, childSpan);
  const client = getClient();
  if (client) {
    client.emit("spanStart", childSpan);
    if (spanArguments.endTimestamp) {
      client.emit("spanEnd", childSpan);
    }
  }
  return childSpan;
}
__name(_startChildSpan, "_startChildSpan");
function getParentSpan(scope) {
  const span = _getSpanForScope(scope);
  if (!span) {
    return void 0;
  }
  const client = getClient();
  const options5 = client ? client.getOptions() : {};
  if (options5.parentSpanIsAlwaysRootSpan) {
    return getRootSpan(span);
  }
  return span;
}
__name(getParentSpan, "getParentSpan");
function getActiveSpanWrapper(parentSpan) {
  return parentSpan !== void 0 ? (callback) => {
    return withActiveSpan(parentSpan, callback);
  } : (callback) => callback();
}
__name(getActiveSpanWrapper, "getActiveSpanWrapper");
const TRACING_DEFAULTS = {
  idleTimeout: 1e3,
  finalTimeout: 3e4,
  childSpanTimeout: 15e3
};
const FINISH_REASON_HEARTBEAT_FAILED = "heartbeatFailed";
const FINISH_REASON_IDLE_TIMEOUT = "idleTimeout";
const FINISH_REASON_FINAL_TIMEOUT = "finalTimeout";
const FINISH_REASON_EXTERNAL_FINISH = "externalFinish";
function startIdleSpan(startSpanOptions, options5 = {}) {
  const activities = /* @__PURE__ */ new Map();
  let _finished = false;
  let _idleTimeoutID;
  let _finishReason = FINISH_REASON_EXTERNAL_FINISH;
  let _autoFinishAllowed = !options5.disableAutoFinish;
  const _cleanupHooks = [];
  const {
    idleTimeout = TRACING_DEFAULTS.idleTimeout,
    finalTimeout = TRACING_DEFAULTS.finalTimeout,
    childSpanTimeout = TRACING_DEFAULTS.childSpanTimeout,
    beforeSpanEnd
  } = options5;
  const client = getClient();
  if (!client || !hasTracingEnabled()) {
    return new SentryNonRecordingSpan();
  }
  const scope = getCurrentScope$1();
  const previousActiveSpan = getActiveSpan();
  const span = _startIdleSpan(startSpanOptions);
  span.end = new Proxy(span.end, {
    apply(target2, thisArg, args) {
      if (beforeSpanEnd) {
        beforeSpanEnd(span);
      }
      const [definedEndTimestamp, ...rest] = args;
      const timestamp2 = definedEndTimestamp || timestampInSeconds();
      const spanEndTimestamp = spanTimeInputToSeconds(timestamp2);
      const spans = getSpanDescendants(span).filter((child) => child !== span);
      if (!spans.length) {
        onIdleSpanEnded(spanEndTimestamp);
        return Reflect.apply(target2, thisArg, [spanEndTimestamp, ...rest]);
      }
      const childEndTimestamps = spans.map((span2) => spanToJSON(span2).timestamp).filter((timestamp3) => !!timestamp3);
      const latestSpanEndTimestamp = childEndTimestamps.length ? Math.max(...childEndTimestamps) : void 0;
      const spanStartTimestamp = spanToJSON(span).start_timestamp;
      const endTimestamp = Math.min(
        spanStartTimestamp ? spanStartTimestamp + finalTimeout / 1e3 : Infinity,
        Math.max(spanStartTimestamp || -Infinity, Math.min(spanEndTimestamp, latestSpanEndTimestamp || Infinity))
      );
      onIdleSpanEnded(endTimestamp);
      return Reflect.apply(target2, thisArg, [endTimestamp, ...rest]);
    }
  });
  function _cancelIdleTimeout() {
    if (_idleTimeoutID) {
      clearTimeout(_idleTimeoutID);
      _idleTimeoutID = void 0;
    }
  }
  __name(_cancelIdleTimeout, "_cancelIdleTimeout");
  function _restartIdleTimeout(endTimestamp) {
    _cancelIdleTimeout();
    _idleTimeoutID = setTimeout(() => {
      if (!_finished && activities.size === 0 && _autoFinishAllowed) {
        _finishReason = FINISH_REASON_IDLE_TIMEOUT;
        span.end(endTimestamp);
      }
    }, idleTimeout);
  }
  __name(_restartIdleTimeout, "_restartIdleTimeout");
  function _restartChildSpanTimeout(endTimestamp) {
    _idleTimeoutID = setTimeout(() => {
      if (!_finished && _autoFinishAllowed) {
        _finishReason = FINISH_REASON_HEARTBEAT_FAILED;
        span.end(endTimestamp);
      }
    }, childSpanTimeout);
  }
  __name(_restartChildSpanTimeout, "_restartChildSpanTimeout");
  function _pushActivity(spanId) {
    _cancelIdleTimeout();
    activities.set(spanId, true);
    const endTimestamp = timestampInSeconds();
    _restartChildSpanTimeout(endTimestamp + childSpanTimeout / 1e3);
  }
  __name(_pushActivity, "_pushActivity");
  function _popActivity(spanId) {
    if (activities.has(spanId)) {
      activities.delete(spanId);
    }
    if (activities.size === 0) {
      const endTimestamp = timestampInSeconds();
      _restartIdleTimeout(endTimestamp + idleTimeout / 1e3);
    }
  }
  __name(_popActivity, "_popActivity");
  function onIdleSpanEnded(endTimestamp) {
    _finished = true;
    activities.clear();
    _cleanupHooks.forEach((cleanup) => cleanup());
    _setSpanForScope(scope, previousActiveSpan);
    const spanJSON = spanToJSON(span);
    const { start_timestamp: startTimestamp } = spanJSON;
    if (!startTimestamp) {
      return;
    }
    const attributes = spanJSON.data || {};
    if (!attributes[SEMANTIC_ATTRIBUTE_SENTRY_IDLE_SPAN_FINISH_REASON]) {
      span.setAttribute(SEMANTIC_ATTRIBUTE_SENTRY_IDLE_SPAN_FINISH_REASON, _finishReason);
    }
    logger$2.log(`[Tracing] Idle span "${spanJSON.op}" finished`);
    const childSpans = getSpanDescendants(span).filter((child) => child !== span);
    let discardedSpans = 0;
    childSpans.forEach((childSpan) => {
      if (childSpan.isRecording()) {
        childSpan.setStatus({ code: SPAN_STATUS_ERROR, message: "cancelled" });
        childSpan.end(endTimestamp);
        DEBUG_BUILD$6 && logger$2.log("[Tracing] Cancelling span since span ended early", JSON.stringify(childSpan, void 0, 2));
      }
      const childSpanJSON = spanToJSON(childSpan);
      const { timestamp: childEndTimestamp = 0, start_timestamp: childStartTimestamp = 0 } = childSpanJSON;
      const spanStartedBeforeIdleSpanEnd = childStartTimestamp <= endTimestamp;
      const timeoutWithMarginOfError = (finalTimeout + idleTimeout) / 1e3;
      const spanEndedBeforeFinalTimeout = childEndTimestamp - childStartTimestamp <= timeoutWithMarginOfError;
      if (DEBUG_BUILD$6) {
        const stringifiedSpan = JSON.stringify(childSpan, void 0, 2);
        if (!spanStartedBeforeIdleSpanEnd) {
          logger$2.log("[Tracing] Discarding span since it happened after idle span was finished", stringifiedSpan);
        } else if (!spanEndedBeforeFinalTimeout) {
          logger$2.log("[Tracing] Discarding span since it finished after idle span final timeout", stringifiedSpan);
        }
      }
      if (!spanEndedBeforeFinalTimeout || !spanStartedBeforeIdleSpanEnd) {
        removeChildSpanFromSpan(span, childSpan);
        discardedSpans++;
      }
    });
    if (discardedSpans > 0) {
      span.setAttribute("sentry.idle_span_discarded_spans", discardedSpans);
    }
  }
  __name(onIdleSpanEnded, "onIdleSpanEnded");
  _cleanupHooks.push(
    client.on("spanStart", (startedSpan) => {
      if (_finished || startedSpan === span || !!spanToJSON(startedSpan).timestamp) {
        return;
      }
      const allSpans = getSpanDescendants(span);
      if (allSpans.includes(startedSpan)) {
        _pushActivity(startedSpan.spanContext().spanId);
      }
    })
  );
  _cleanupHooks.push(
    client.on("spanEnd", (endedSpan) => {
      if (_finished) {
        return;
      }
      _popActivity(endedSpan.spanContext().spanId);
    })
  );
  _cleanupHooks.push(
    client.on("idleSpanEnableAutoFinish", (spanToAllowAutoFinish) => {
      if (spanToAllowAutoFinish === span) {
        _autoFinishAllowed = true;
        _restartIdleTimeout();
        if (activities.size) {
          _restartChildSpanTimeout();
        }
      }
    })
  );
  if (!options5.disableAutoFinish) {
    _restartIdleTimeout();
  }
  setTimeout(() => {
    if (!_finished) {
      span.setStatus({ code: SPAN_STATUS_ERROR, message: "deadline_exceeded" });
      _finishReason = FINISH_REASON_FINAL_TIMEOUT;
      span.end();
    }
  }, finalTimeout);
  return span;
}
__name(startIdleSpan, "startIdleSpan");
function _startIdleSpan(options5) {
  const span = startInactiveSpan(options5);
  _setSpanForScope(getCurrentScope$1(), span);
  DEBUG_BUILD$6 && logger$2.log("[Tracing] Started span is an idle span");
  return span;
}
__name(_startIdleSpan, "_startIdleSpan");
function notifyEventProcessors(processors, event, hint, index2 = 0) {
  return new SyncPromise((resolve2, reject3) => {
    const processor = processors[index2];
    if (event === null || typeof processor !== "function") {
      resolve2(event);
    } else {
      const result = processor({ ...event }, hint);
      DEBUG_BUILD$6 && processor.id && result === null && logger$2.log(`Event processor "${processor.id}" dropped event`);
      if (isThenable$1(result)) {
        void result.then((final) => notifyEventProcessors(processors, final, hint, index2 + 1).then(resolve2)).then(null, reject3);
      } else {
        void notifyEventProcessors(processors, result, hint, index2 + 1).then(resolve2).then(null, reject3);
      }
    }
  });
}
__name(notifyEventProcessors, "notifyEventProcessors");
let parsedStackResults;
let lastKeysCount;
let cachedFilenameDebugIds;
function getFilenameToDebugIdMap(stackParser) {
  const debugIdMap = GLOBAL_OBJ._sentryDebugIds;
  if (!debugIdMap) {
    return {};
  }
  const debugIdKeys = Object.keys(debugIdMap);
  if (cachedFilenameDebugIds && debugIdKeys.length === lastKeysCount) {
    return cachedFilenameDebugIds;
  }
  lastKeysCount = debugIdKeys.length;
  cachedFilenameDebugIds = debugIdKeys.reduce((acc, stackKey) => {
    if (!parsedStackResults) {
      parsedStackResults = {};
    }
    const result = parsedStackResults[stackKey];
    if (result) {
      acc[result[0]] = result[1];
    } else {
      const parsedStack = stackParser(stackKey);
      for (let i2 = parsedStack.length - 1; i2 >= 0; i2--) {
        const stackFrame = parsedStack[i2];
        const filename = stackFrame && stackFrame.filename;
        const debugId = debugIdMap[stackKey];
        if (filename && debugId) {
          acc[filename] = debugId;
          parsedStackResults[stackKey] = [filename, debugId];
          break;
        }
      }
    }
    return acc;
  }, {});
  return cachedFilenameDebugIds;
}
__name(getFilenameToDebugIdMap, "getFilenameToDebugIdMap");
function getDebugImagesForResources(stackParser, resource_paths) {
  const filenameDebugIdMap = getFilenameToDebugIdMap(stackParser);
  if (!filenameDebugIdMap) {
    return [];
  }
  const images = [];
  for (const path of resource_paths) {
    if (path && filenameDebugIdMap[path]) {
      images.push({
        type: "sourcemap",
        code_file: path,
        debug_id: filenameDebugIdMap[path]
      });
    }
  }
  return images;
}
__name(getDebugImagesForResources, "getDebugImagesForResources");
function applyScopeDataToEvent(event, data30) {
  const { fingerprint, span, breadcrumbs, sdkProcessingMetadata } = data30;
  applyDataToEvent(event, data30);
  if (span) {
    applySpanToEvent(event, span);
  }
  applyFingerprintToEvent(event, fingerprint);
  applyBreadcrumbsToEvent(event, breadcrumbs);
  applySdkMetadataToEvent(event, sdkProcessingMetadata);
}
__name(applyScopeDataToEvent, "applyScopeDataToEvent");
function mergeScopeData(data30, mergeData) {
  const {
    extra,
    tags,
    user,
    contexts,
    level,
    sdkProcessingMetadata,
    breadcrumbs,
    fingerprint,
    eventProcessors,
    attachments,
    propagationContext,
    transactionName,
    span
  } = mergeData;
  mergeAndOverwriteScopeData(data30, "extra", extra);
  mergeAndOverwriteScopeData(data30, "tags", tags);
  mergeAndOverwriteScopeData(data30, "user", user);
  mergeAndOverwriteScopeData(data30, "contexts", contexts);
  data30.sdkProcessingMetadata = merge$2(data30.sdkProcessingMetadata, sdkProcessingMetadata, 2);
  if (level) {
    data30.level = level;
  }
  if (transactionName) {
    data30.transactionName = transactionName;
  }
  if (span) {
    data30.span = span;
  }
  if (breadcrumbs.length) {
    data30.breadcrumbs = [...data30.breadcrumbs, ...breadcrumbs];
  }
  if (fingerprint.length) {
    data30.fingerprint = [...data30.fingerprint, ...fingerprint];
  }
  if (eventProcessors.length) {
    data30.eventProcessors = [...data30.eventProcessors, ...eventProcessors];
  }
  if (attachments.length) {
    data30.attachments = [...data30.attachments, ...attachments];
  }
  data30.propagationContext = { ...data30.propagationContext, ...propagationContext };
}
__name(mergeScopeData, "mergeScopeData");
function mergeAndOverwriteScopeData(data30, prop2, mergeVal) {
  data30[prop2] = merge$2(data30[prop2], mergeVal, 1);
}
__name(mergeAndOverwriteScopeData, "mergeAndOverwriteScopeData");
function applyDataToEvent(event, data30) {
  const { extra, tags, user, contexts, level, transactionName } = data30;
  const cleanedExtra = dropUndefinedKeys(extra);
  if (cleanedExtra && Object.keys(cleanedExtra).length) {
    event.extra = { ...cleanedExtra, ...event.extra };
  }
  const cleanedTags = dropUndefinedKeys(tags);
  if (cleanedTags && Object.keys(cleanedTags).length) {
    event.tags = { ...cleanedTags, ...event.tags };
  }
  const cleanedUser = dropUndefinedKeys(user);
  if (cleanedUser && Object.keys(cleanedUser).length) {
    event.user = { ...cleanedUser, ...event.user };
  }
  const cleanedContexts = dropUndefinedKeys(contexts);
  if (cleanedContexts && Object.keys(cleanedContexts).length) {
    event.contexts = { ...cleanedContexts, ...event.contexts };
  }
  if (level) {
    event.level = level;
  }
  if (transactionName && event.type !== "transaction") {
    event.transaction = transactionName;
  }
}
__name(applyDataToEvent, "applyDataToEvent");
function applyBreadcrumbsToEvent(event, breadcrumbs) {
  const mergedBreadcrumbs = [...event.breadcrumbs || [], ...breadcrumbs];
  event.breadcrumbs = mergedBreadcrumbs.length ? mergedBreadcrumbs : void 0;
}
__name(applyBreadcrumbsToEvent, "applyBreadcrumbsToEvent");
function applySdkMetadataToEvent(event, sdkProcessingMetadata) {
  event.sdkProcessingMetadata = {
    ...event.sdkProcessingMetadata,
    ...sdkProcessingMetadata
  };
}
__name(applySdkMetadataToEvent, "applySdkMetadataToEvent");
function applySpanToEvent(event, span) {
  event.contexts = {
    trace: spanToTraceContext(span),
    ...event.contexts
  };
  event.sdkProcessingMetadata = {
    dynamicSamplingContext: getDynamicSamplingContextFromSpan(span),
    ...event.sdkProcessingMetadata
  };
  const rootSpan = getRootSpan(span);
  const transactionName = spanToJSON(rootSpan).description;
  if (transactionName && !event.transaction && event.type === "transaction") {
    event.transaction = transactionName;
  }
}
__name(applySpanToEvent, "applySpanToEvent");
function applyFingerprintToEvent(event, fingerprint) {
  event.fingerprint = event.fingerprint ? Array.isArray(event.fingerprint) ? event.fingerprint : [event.fingerprint] : [];
  if (fingerprint) {
    event.fingerprint = event.fingerprint.concat(fingerprint);
  }
  if (event.fingerprint && !event.fingerprint.length) {
    delete event.fingerprint;
  }
}
__name(applyFingerprintToEvent, "applyFingerprintToEvent");
function prepareEvent(options5, event, hint, scope, client, isolationScope) {
  const { normalizeDepth = 3, normalizeMaxBreadth = 1e3 } = options5;
  const prepared = {
    ...event,
    event_id: event.event_id || hint.event_id || uuid4(),
    timestamp: event.timestamp || dateTimestampInSeconds()
  };
  const integrations = hint.integrations || options5.integrations.map((i2) => i2.name);
  applyClientOptions(prepared, options5);
  applyIntegrationsMetadata(prepared, integrations);
  if (client) {
    client.emit("applyFrameMetadata", event);
  }
  if (event.type === void 0) {
    applyDebugIds(prepared, options5.stackParser);
  }
  const finalScope = getFinalScope(scope, hint.captureContext);
  if (hint.mechanism) {
    addExceptionMechanism(prepared, hint.mechanism);
  }
  const clientEventProcessors = client ? client.getEventProcessors() : [];
  const data30 = getGlobalScope().getScopeData();
  if (isolationScope) {
    const isolationData = isolationScope.getScopeData();
    mergeScopeData(data30, isolationData);
  }
  if (finalScope) {
    const finalScopeData = finalScope.getScopeData();
    mergeScopeData(data30, finalScopeData);
  }
  const attachments = [...hint.attachments || [], ...data30.attachments];
  if (attachments.length) {
    hint.attachments = attachments;
  }
  applyScopeDataToEvent(prepared, data30);
  const eventProcessors = [
    ...clientEventProcessors,
    // Run scope event processors _after_ all other processors
    ...data30.eventProcessors
  ];
  const result = notifyEventProcessors(eventProcessors, prepared, hint);
  return result.then((evt) => {
    if (evt) {
      applyDebugMeta(evt);
    }
    if (typeof normalizeDepth === "number" && normalizeDepth > 0) {
      return normalizeEvent(evt, normalizeDepth, normalizeMaxBreadth);
    }
    return evt;
  });
}
__name(prepareEvent, "prepareEvent");
function applyClientOptions(event, options5) {
  const { environment, release, dist: dist3, maxValueLength = 250 } = options5;
  event.environment = event.environment || environment || DEFAULT_ENVIRONMENT;
  if (!event.release && release) {
    event.release = release;
  }
  if (!event.dist && dist3) {
    event.dist = dist3;
  }
  if (event.message) {
    event.message = truncate(event.message, maxValueLength);
  }
  const exception = event.exception && event.exception.values && event.exception.values[0];
  if (exception && exception.value) {
    exception.value = truncate(exception.value, maxValueLength);
  }
  const request = event.request;
  if (request && request.url) {
    request.url = truncate(request.url, maxValueLength);
  }
}
__name(applyClientOptions, "applyClientOptions");
function applyDebugIds(event, stackParser) {
  const filenameDebugIdMap = getFilenameToDebugIdMap(stackParser);
  try {
    event.exception.values.forEach((exception) => {
      exception.stacktrace.frames.forEach((frame) => {
        if (filenameDebugIdMap && frame.filename) {
          frame.debug_id = filenameDebugIdMap[frame.filename];
        }
      });
    });
  } catch (e2) {
  }
}
__name(applyDebugIds, "applyDebugIds");
function applyDebugMeta(event) {
  const filenameDebugIdMap = {};
  try {
    event.exception.values.forEach((exception) => {
      exception.stacktrace.frames.forEach((frame) => {
        if (frame.debug_id) {
          if (frame.abs_path) {
            filenameDebugIdMap[frame.abs_path] = frame.debug_id;
          } else if (frame.filename) {
            filenameDebugIdMap[frame.filename] = frame.debug_id;
          }
          delete frame.debug_id;
        }
      });
    });
  } catch (e2) {
  }
  if (Object.keys(filenameDebugIdMap).length === 0) {
    return;
  }
  event.debug_meta = event.debug_meta || {};
  event.debug_meta.images = event.debug_meta.images || [];
  const images = event.debug_meta.images;
  Object.entries(filenameDebugIdMap).forEach(([filename, debug_id]) => {
    images.push({
      type: "sourcemap",
      code_file: filename,
      debug_id
    });
  });
}
__name(applyDebugMeta, "applyDebugMeta");
function applyIntegrationsMetadata(event, integrationNames) {
  if (integrationNames.length > 0) {
    event.sdk = event.sdk || {};
    event.sdk.integrations = [...event.sdk.integrations || [], ...integrationNames];
  }
}
__name(applyIntegrationsMetadata, "applyIntegrationsMetadata");
function normalizeEvent(event, depth, maxBreadth) {
  if (!event) {
    return null;
  }
  const normalized = {
    ...event,
    ...event.breadcrumbs && {
      breadcrumbs: event.breadcrumbs.map((b2) => ({
        ...b2,
        ...b2.data && {
          data: normalize$2(b2.data, depth, maxBreadth)
        }
      }))
    },
    ...event.user && {
      user: normalize$2(event.user, depth, maxBreadth)
    },
    ...event.contexts && {
      contexts: normalize$2(event.contexts, depth, maxBreadth)
    },
    ...event.extra && {
      extra: normalize$2(event.extra, depth, maxBreadth)
    }
  };
  if (event.contexts && event.contexts.trace && normalized.contexts) {
    normalized.contexts.trace = event.contexts.trace;
    if (event.contexts.trace.data) {
      normalized.contexts.trace.data = normalize$2(event.contexts.trace.data, depth, maxBreadth);
    }
  }
  if (event.spans) {
    normalized.spans = event.spans.map((span) => {
      return {
        ...span,
        ...span.data && {
          data: normalize$2(span.data, depth, maxBreadth)
        }
      };
    });
  }
  if (event.contexts && event.contexts.flags && normalized.contexts) {
    normalized.contexts.flags = normalize$2(event.contexts.flags, 3, maxBreadth);
  }
  return normalized;
}
__name(normalizeEvent, "normalizeEvent");
function getFinalScope(scope, captureContext) {
  if (!captureContext) {
    return scope;
  }
  const finalScope = scope ? scope.clone() : new Scope();
  finalScope.update(captureContext);
  return finalScope;
}
__name(getFinalScope, "getFinalScope");
function parseEventHintOrCaptureContext(hint) {
  if (!hint) {
    return void 0;
  }
  if (hintIsScopeOrFunction(hint)) {
    return { captureContext: hint };
  }
  if (hintIsScopeContext(hint)) {
    return {
      captureContext: hint
    };
  }
  return hint;
}
__name(parseEventHintOrCaptureContext, "parseEventHintOrCaptureContext");
function hintIsScopeOrFunction(hint) {
  return hint instanceof Scope || typeof hint === "function";
}
__name(hintIsScopeOrFunction, "hintIsScopeOrFunction");
const captureContextKeys = [
  "user",
  "level",
  "extra",
  "contexts",
  "tags",
  "fingerprint",
  "requestSession",
  "propagationContext"
];
function hintIsScopeContext(hint) {
  return Object.keys(hint).some((key) => captureContextKeys.includes(key));
}
__name(hintIsScopeContext, "hintIsScopeContext");
function captureException(exception, hint) {
  return getCurrentScope$1().captureException(exception, parseEventHintOrCaptureContext(hint));
}
__name(captureException, "captureException");
function captureMessage(message3, captureContext) {
  const level = typeof captureContext === "string" ? captureContext : void 0;
  const context = typeof captureContext !== "string" ? { captureContext } : void 0;
  return getCurrentScope$1().captureMessage(message3, level, context);
}
__name(captureMessage, "captureMessage");
function captureEvent(event, hint) {
  return getCurrentScope$1().captureEvent(event, hint);
}
__name(captureEvent, "captureEvent");
function setContext(name2, context) {
  getIsolationScope().setContext(name2, context);
}
__name(setContext, "setContext");
function setExtras(extras) {
  getIsolationScope().setExtras(extras);
}
__name(setExtras, "setExtras");
function setExtra(key, extra) {
  getIsolationScope().setExtra(key, extra);
}
__name(setExtra, "setExtra");
function setTags(tags) {
  getIsolationScope().setTags(tags);
}
__name(setTags, "setTags");
function setTag$5(key, value3) {
  getIsolationScope().setTag(key, value3);
}
__name(setTag$5, "setTag$5");
function setUser(user) {
  getIsolationScope().setUser(user);
}
__name(setUser, "setUser");
function lastEventId() {
  return getIsolationScope().lastEventId();
}
__name(lastEventId, "lastEventId");
function captureCheckIn(checkIn, upsertMonitorConfig) {
  const scope = getCurrentScope$1();
  const client = getClient();
  if (!client) {
    DEBUG_BUILD$6 && logger$2.warn("Cannot capture check-in. No client defined.");
  } else if (!client.captureCheckIn) {
    DEBUG_BUILD$6 && logger$2.warn("Cannot capture check-in. Client does not support sending check-ins.");
  } else {
    return client.captureCheckIn(checkIn, upsertMonitorConfig, scope);
  }
  return uuid4();
}
__name(captureCheckIn, "captureCheckIn");
function withMonitor(monitorSlug, callback, upsertMonitorConfig) {
  const checkInId = captureCheckIn({ monitorSlug, status: "in_progress" }, upsertMonitorConfig);
  const now2 = timestampInSeconds();
  function finishCheckIn(status) {
    captureCheckIn({ monitorSlug, status, checkInId, duration: timestampInSeconds() - now2 });
  }
  __name(finishCheckIn, "finishCheckIn");
  return withIsolationScope(() => {
    let maybePromiseResult;
    try {
      maybePromiseResult = callback();
    } catch (e2) {
      finishCheckIn("error");
      throw e2;
    }
    if (isThenable$1(maybePromiseResult)) {
      Promise.resolve(maybePromiseResult).then(
        () => {
          finishCheckIn("ok");
        },
        (e2) => {
          finishCheckIn("error");
          throw e2;
        }
      );
    } else {
      finishCheckIn("ok");
    }
    return maybePromiseResult;
  });
}
__name(withMonitor, "withMonitor");
async function flush(timeout) {
  const client = getClient();
  if (client) {
    return client.flush(timeout);
  }
  DEBUG_BUILD$6 && logger$2.warn("Cannot flush events. No client defined.");
  return Promise.resolve(false);
}
__name(flush, "flush");
async function close$1(timeout) {
  const client = getClient();
  if (client) {
    return client.close(timeout);
  }
  DEBUG_BUILD$6 && logger$2.warn("Cannot flush events and disable SDK. No client defined.");
  return Promise.resolve(false);
}
__name(close$1, "close$1");
function isInitialized$1() {
  return !!getClient();
}
__name(isInitialized$1, "isInitialized$1");
function isEnabled() {
  const client = getClient();
  return !!client && client.getOptions().enabled !== false && !!client.getTransport();
}
__name(isEnabled, "isEnabled");
function addEventProcessor(callback) {
  getIsolationScope().addEventProcessor(callback);
}
__name(addEventProcessor, "addEventProcessor");
function startSession(context) {
  const client = getClient();
  const isolationScope = getIsolationScope();
  const currentScope = getCurrentScope$1();
  const { release, environment = DEFAULT_ENVIRONMENT } = client && client.getOptions() || {};
  const { userAgent } = GLOBAL_OBJ.navigator || {};
  const session = makeSession$1({
    release,
    environment,
    user: currentScope.getUser() || isolationScope.getUser(),
    ...userAgent && { userAgent },
    ...context
  });
  const currentSession = isolationScope.getSession();
  if (currentSession && currentSession.status === "ok") {
    updateSession(currentSession, { status: "exited" });
  }
  endSession();
  isolationScope.setSession(session);
  currentScope.setSession(session);
  return session;
}
__name(startSession, "startSession");
function endSession() {
  const isolationScope = getIsolationScope();
  const currentScope = getCurrentScope$1();
  const session = currentScope.getSession() || isolationScope.getSession();
  if (session) {
    closeSession(session);
  }
  _sendSessionUpdate$1();
  isolationScope.setSession();
  currentScope.setSession();
}
__name(endSession, "endSession");
function _sendSessionUpdate$1() {
  const isolationScope = getIsolationScope();
  const currentScope = getCurrentScope$1();
  const client = getClient();
  const session = currentScope.getSession() || isolationScope.getSession();
  if (session && client) {
    client.captureSession(session);
  }
}
__name(_sendSessionUpdate$1, "_sendSessionUpdate$1");
function captureSession(end = false) {
  if (end) {
    endSession();
    return;
  }
  _sendSessionUpdate$1();
}
__name(captureSession, "captureSession");
class SessionFlusher {
  static {
    __name(this, "SessionFlusher");
  }
  // We adjust the type here to add the `unref()` part, as setInterval can technically return a number or a NodeJS.Timer
  constructor(client, attrs7) {
    this._client = client;
    this.flushTimeout = 60;
    this._pendingAggregates = /* @__PURE__ */ new Map();
    this._isEnabled = true;
    this._intervalId = setInterval(() => this.flush(), this.flushTimeout * 1e3);
    if (this._intervalId.unref) {
      this._intervalId.unref();
    }
    this._sessionAttrs = attrs7;
  }
  /** Checks if `pendingAggregates` has entries, and if it does flushes them by calling `sendSession` */
  flush() {
    const sessionAggregates = this.getSessionAggregates();
    if (sessionAggregates.aggregates.length === 0) {
      return;
    }
    this._pendingAggregates = /* @__PURE__ */ new Map();
    this._client.sendSession(sessionAggregates);
  }
  /** Massages the entries in `pendingAggregates` and returns aggregated sessions */
  getSessionAggregates() {
    const aggregates = Array.from(this._pendingAggregates.values());
    const sessionAggregates = {
      attrs: this._sessionAttrs,
      aggregates
    };
    return dropUndefinedKeys(sessionAggregates);
  }
  /** JSDoc */
  close() {
    clearInterval(this._intervalId);
    this._isEnabled = false;
    this.flush();
  }
  /**
   * Wrapper function for _incrementSessionStatusCount that checks if the instance of SessionFlusher is enabled then
   * fetches the session status of the request from `Scope.getRequestSession().status` on the scope and passes them to
   * `_incrementSessionStatusCount` along with the start date
   */
  incrementSessionStatusCount() {
    if (!this._isEnabled) {
      return;
    }
    const isolationScope = getIsolationScope();
    const requestSession = isolationScope.getRequestSession();
    if (requestSession && requestSession.status) {
      this._incrementSessionStatusCount(requestSession.status, /* @__PURE__ */ new Date());
      isolationScope.setRequestSession(void 0);
    }
  }
  /**
   * Increments status bucket in pendingAggregates buffer (internal state) corresponding to status of
   * the session received
   */
  // eslint-disable-next-line deprecation/deprecation
  _incrementSessionStatusCount(status, date) {
    const sessionStartedTrunc = new Date(date).setSeconds(0, 0);
    let aggregationCounts = this._pendingAggregates.get(sessionStartedTrunc);
    if (!aggregationCounts) {
      aggregationCounts = { started: new Date(sessionStartedTrunc).toISOString() };
      this._pendingAggregates.set(sessionStartedTrunc, aggregationCounts);
    }
    switch (status) {
      case "errored":
        aggregationCounts.errored = (aggregationCounts.errored || 0) + 1;
        return aggregationCounts.errored;
      case "ok":
        aggregationCounts.exited = (aggregationCounts.exited || 0) + 1;
        return aggregationCounts.exited;
      default:
        aggregationCounts.crashed = (aggregationCounts.crashed || 0) + 1;
        return aggregationCounts.crashed;
    }
  }
}
const SENTRY_API_VERSION = "7";
function getBaseApiEndpoint(dsn) {
  const protocol = dsn.protocol ? `${dsn.protocol}:` : "";
  const port = dsn.port ? `:${dsn.port}` : "";
  return `${protocol}//${dsn.host}${port}${dsn.path ? `/${dsn.path}` : ""}/api/`;
}
__name(getBaseApiEndpoint, "getBaseApiEndpoint");
function _getIngestEndpoint(dsn) {
  return `${getBaseApiEndpoint(dsn)}${dsn.projectId}/envelope/`;
}
__name(_getIngestEndpoint, "_getIngestEndpoint");
function _encodedAuth(dsn, sdkInfo) {
  const params = {
    sentry_version: SENTRY_API_VERSION
  };
  if (dsn.publicKey) {
    params.sentry_key = dsn.publicKey;
  }
  if (sdkInfo) {
    params.sentry_client = `${sdkInfo.name}/${sdkInfo.version}`;
  }
  return new URLSearchParams(params).toString();
}
__name(_encodedAuth, "_encodedAuth");
function getEnvelopeEndpointWithUrlEncodedAuth(dsn, tunnel, sdkInfo) {
  return tunnel ? tunnel : `${_getIngestEndpoint(dsn)}?${_encodedAuth(dsn, sdkInfo)}`;
}
__name(getEnvelopeEndpointWithUrlEncodedAuth, "getEnvelopeEndpointWithUrlEncodedAuth");
function getReportDialogEndpoint(dsnLike, dialogOptions) {
  const dsn = makeDsn(dsnLike);
  if (!dsn) {
    return "";
  }
  const endpoint = `${getBaseApiEndpoint(dsn)}embed/error-page/`;
  let encodedOptions = `dsn=${dsnToString(dsn)}`;
  for (const key in dialogOptions) {
    if (key === "dsn") {
      continue;
    }
    if (key === "onClose") {
      continue;
    }
    if (key === "user") {
      const user = dialogOptions.user;
      if (!user) {
        continue;
      }
      if (user.name) {
        encodedOptions += `&name=${encodeURIComponent(user.name)}`;
      }
      if (user.email) {
        encodedOptions += `&email=${encodeURIComponent(user.email)}`;
      }
    } else {
      encodedOptions += `&${encodeURIComponent(key)}=${encodeURIComponent(dialogOptions[key])}`;
    }
  }
  return `${endpoint}?${encodedOptions}`;
}
__name(getReportDialogEndpoint, "getReportDialogEndpoint");
const installedIntegrations = [];
function filterDuplicates(integrations) {
  const integrationsByName = {};
  integrations.forEach((currentInstance2) => {
    const { name: name2 } = currentInstance2;
    const existingInstance = integrationsByName[name2];
    if (existingInstance && !existingInstance.isDefaultInstance && currentInstance2.isDefaultInstance) {
      return;
    }
    integrationsByName[name2] = currentInstance2;
  });
  return Object.values(integrationsByName);
}
__name(filterDuplicates, "filterDuplicates");
function getIntegrationsToSetup(options5) {
  const defaultIntegrations = options5.defaultIntegrations || [];
  const userIntegrations = options5.integrations;
  defaultIntegrations.forEach((integration) => {
    integration.isDefaultInstance = true;
  });
  let integrations;
  if (Array.isArray(userIntegrations)) {
    integrations = [...defaultIntegrations, ...userIntegrations];
  } else if (typeof userIntegrations === "function") {
    const resolvedUserIntegrations = userIntegrations(defaultIntegrations);
    integrations = Array.isArray(resolvedUserIntegrations) ? resolvedUserIntegrations : [resolvedUserIntegrations];
  } else {
    integrations = defaultIntegrations;
  }
  const finalIntegrations = filterDuplicates(integrations);
  const debugIndex = finalIntegrations.findIndex((integration) => integration.name === "Debug");
  if (debugIndex > -1) {
    const [debugInstance] = finalIntegrations.splice(debugIndex, 1);
    finalIntegrations.push(debugInstance);
  }
  return finalIntegrations;
}
__name(getIntegrationsToSetup, "getIntegrationsToSetup");
function setupIntegrations(client, integrations) {
  const integrationIndex = {};
  integrations.forEach((integration) => {
    if (integration) {
      setupIntegration(client, integration, integrationIndex);
    }
  });
  return integrationIndex;
}
__name(setupIntegrations, "setupIntegrations");
function afterSetupIntegrations(client, integrations) {
  for (const integration of integrations) {
    if (integration && integration.afterAllSetup) {
      integration.afterAllSetup(client);
    }
  }
}
__name(afterSetupIntegrations, "afterSetupIntegrations");
function setupIntegration(client, integration, integrationIndex) {
  if (integrationIndex[integration.name]) {
    DEBUG_BUILD$6 && logger$2.log(`Integration skipped because it was already installed: ${integration.name}`);
    return;
  }
  integrationIndex[integration.name] = integration;
  if (installedIntegrations.indexOf(integration.name) === -1 && typeof integration.setupOnce === "function") {
    integration.setupOnce();
    installedIntegrations.push(integration.name);
  }
  if (integration.setup && typeof integration.setup === "function") {
    integration.setup(client);
  }
  if (typeof integration.preprocessEvent === "function") {
    const callback = integration.preprocessEvent.bind(integration);
    client.on("preprocessEvent", (event, hint) => callback(event, hint, client));
  }
  if (typeof integration.processEvent === "function") {
    const callback = integration.processEvent.bind(integration);
    const processor = Object.assign((event, hint) => callback(event, hint, client), {
      id: integration.name
    });
    client.addEventProcessor(processor);
  }
  DEBUG_BUILD$6 && logger$2.log(`Integration installed: ${integration.name}`);
}
__name(setupIntegration, "setupIntegration");
function addIntegration(integration) {
  const client = getClient();
  if (!client) {
    DEBUG_BUILD$6 && logger$2.warn(`Cannot add integration "${integration.name}" because no SDK Client is available.`);
    return;
  }
  client.addIntegration(integration);
}
__name(addIntegration, "addIntegration");
function defineIntegration(fn) {
  return fn;
}
__name(defineIntegration, "defineIntegration");
function createClientReportEnvelope(discarded_events, dsn, timestamp2) {
  const clientReportItem = [
    { type: "client_report" },
    {
      timestamp: timestamp2 || dateTimestampInSeconds(),
      discarded_events
    }
  ];
  return createEnvelope(dsn ? { dsn } : {}, [clientReportItem]);
}
__name(createClientReportEnvelope, "createClientReportEnvelope");
class SentryError extends Error {
  static {
    __name(this, "SentryError");
  }
  /** Display name of this error instance. */
  constructor(message3, logLevel = "warn") {
    super(message3);
    this.message = message3;
    this.name = new.target.prototype.constructor.name;
    Object.setPrototypeOf(this, new.target.prototype);
    this.logLevel = logLevel;
  }
}
const ALREADY_SEEN_ERROR = "Not capturing exception because it's already been captured.";
class BaseClient {
  static {
    __name(this, "BaseClient");
  }
  /** Options passed to the SDK. */
  /** The client Dsn, if specified in options. Without this Dsn, the SDK will be disabled. */
  /** Array of set up integrations. */
  /** Number of calls being processed */
  /** Holds flushable  */
  // eslint-disable-next-line @typescript-eslint/ban-types
  /**
   * Initializes this client instance.
   *
   * @param options Options for the client.
   */
  constructor(options5) {
    this._options = options5;
    this._integrations = {};
    this._numProcessing = 0;
    this._outcomes = {};
    this._hooks = {};
    this._eventProcessors = [];
    if (options5.dsn) {
      this._dsn = makeDsn(options5.dsn);
    } else {
      DEBUG_BUILD$6 && logger$2.warn("No DSN provided, client will not send events.");
    }
    if (this._dsn) {
      const url = getEnvelopeEndpointWithUrlEncodedAuth(
        this._dsn,
        options5.tunnel,
        options5._metadata ? options5._metadata.sdk : void 0
      );
      this._transport = options5.transport({
        tunnel: this._options.tunnel,
        recordDroppedEvent: this.recordDroppedEvent.bind(this),
        ...options5.transportOptions,
        url
      });
    }
    const tracingOptions = ["enableTracing", "tracesSampleRate", "tracesSampler"];
    const undefinedOption = tracingOptions.find((option5) => option5 in options5 && options5[option5] == void 0);
    if (undefinedOption) {
      consoleSandbox(() => {
        console.warn(
          `[Sentry] Deprecation warning: \`${undefinedOption}\` is set to undefined, which leads to tracing being enabled. In v9, a value of \`undefined\` will result in tracing being disabled.`
        );
      });
    }
  }
  /**
   * @inheritDoc
   */
  captureException(exception, hint, scope) {
    const eventId = uuid4();
    if (checkOrSetAlreadyCaught(exception)) {
      DEBUG_BUILD$6 && logger$2.log(ALREADY_SEEN_ERROR);
      return eventId;
    }
    const hintWithEventId = {
      event_id: eventId,
      ...hint
    };
    this._process(
      this.eventFromException(exception, hintWithEventId).then(
        (event) => this._captureEvent(event, hintWithEventId, scope)
      )
    );
    return hintWithEventId.event_id;
  }
  /**
   * @inheritDoc
   */
  captureMessage(message3, level, hint, currentScope) {
    const hintWithEventId = {
      event_id: uuid4(),
      ...hint
    };
    const eventMessage = isParameterizedString(message3) ? message3 : String(message3);
    const promisedEvent = isPrimitive(message3) ? this.eventFromMessage(eventMessage, level, hintWithEventId) : this.eventFromException(message3, hintWithEventId);
    this._process(promisedEvent.then((event) => this._captureEvent(event, hintWithEventId, currentScope)));
    return hintWithEventId.event_id;
  }
  /**
   * @inheritDoc
   */
  captureEvent(event, hint, currentScope) {
    const eventId = uuid4();
    if (hint && hint.originalException && checkOrSetAlreadyCaught(hint.originalException)) {
      DEBUG_BUILD$6 && logger$2.log(ALREADY_SEEN_ERROR);
      return eventId;
    }
    const hintWithEventId = {
      event_id: eventId,
      ...hint
    };
    const sdkProcessingMetadata = event.sdkProcessingMetadata || {};
    const capturedSpanScope = sdkProcessingMetadata.capturedSpanScope;
    this._process(this._captureEvent(event, hintWithEventId, capturedSpanScope || currentScope));
    return hintWithEventId.event_id;
  }
  /**
   * @inheritDoc
   */
  captureSession(session) {
    if (!(typeof session.release === "string")) {
      DEBUG_BUILD$6 && logger$2.warn("Discarded session because of missing or non-string release");
    } else {
      this.sendSession(session);
      updateSession(session, { init: false });
    }
  }
  /**
   * @inheritDoc
   */
  getDsn() {
    return this._dsn;
  }
  /**
   * @inheritDoc
   */
  getOptions() {
    return this._options;
  }
  /**
   * @see SdkMetadata
   *
   * @return The metadata of the SDK
   */
  getSdkMetadata() {
    return this._options._metadata;
  }
  /**
   * @inheritDoc
   */
  getTransport() {
    return this._transport;
  }
  /**
   * @inheritDoc
   */
  flush(timeout) {
    const transport = this._transport;
    if (transport) {
      this.emit("flush");
      return this._isClientDoneProcessing(timeout).then((clientFinished) => {
        return transport.flush(timeout).then((transportFlushed) => clientFinished && transportFlushed);
      });
    } else {
      return resolvedSyncPromise(true);
    }
  }
  /**
   * @inheritDoc
   */
  close(timeout) {
    return this.flush(timeout).then((result) => {
      this.getOptions().enabled = false;
      this.emit("close");
      return result;
    });
  }
  /** Get all installed event processors. */
  getEventProcessors() {
    return this._eventProcessors;
  }
  /** @inheritDoc */
  addEventProcessor(eventProcessor) {
    this._eventProcessors.push(eventProcessor);
  }
  /** @inheritdoc */
  init() {
    if (this._isEnabled() || // Force integrations to be setup even if no DSN was set when we have
    // Spotlight enabled. This is particularly important for browser as we
    // don't support the `spotlight` option there and rely on the users
    // adding the `spotlightBrowserIntegration()` to their integrations which
    // wouldn't get initialized with the check below when there's no DSN set.
    this._options.integrations.some(({ name: name2 }) => name2.startsWith("Spotlight"))) {
      this._setupIntegrations();
    }
  }
  /**
   * Gets an installed integration by its name.
   *
   * @returns The installed integration or `undefined` if no integration with that `name` was installed.
   */
  getIntegrationByName(integrationName) {
    return this._integrations[integrationName];
  }
  /**
   * @inheritDoc
   */
  addIntegration(integration) {
    const isAlreadyInstalled = this._integrations[integration.name];
    setupIntegration(this, integration, this._integrations);
    if (!isAlreadyInstalled) {
      afterSetupIntegrations(this, [integration]);
    }
  }
  /**
   * @inheritDoc
   */
  sendEvent(event, hint = {}) {
    this.emit("beforeSendEvent", event, hint);
    let env = createEventEnvelope(event, this._dsn, this._options._metadata, this._options.tunnel);
    for (const attachment of hint.attachments || []) {
      env = addItemToEnvelope(env, createAttachmentEnvelopeItem(attachment));
    }
    const promise = this.sendEnvelope(env);
    if (promise) {
      promise.then((sendResponse) => this.emit("afterSendEvent", event, sendResponse), null);
    }
  }
  /**
   * @inheritDoc
   */
  sendSession(session) {
    const env = createSessionEnvelope(session, this._dsn, this._options._metadata, this._options.tunnel);
    this.sendEnvelope(env);
  }
  /**
   * @inheritDoc
   */
  recordDroppedEvent(reason, category, eventOrCount) {
    if (this._options.sendClientReports) {
      const count = typeof eventOrCount === "number" ? eventOrCount : 1;
      const key = `${reason}:${category}`;
      DEBUG_BUILD$6 && logger$2.log(`Recording outcome: "${key}"${count > 1 ? ` (${count} times)` : ""}`);
      this._outcomes[key] = (this._outcomes[key] || 0) + count;
    }
  }
  // Keep on() & emit() signatures in sync with types' client.ts interface
  /* eslint-disable @typescript-eslint/unified-signatures */
  /** @inheritdoc */
  /** @inheritdoc */
  on(hook, callback) {
    const hooks2 = this._hooks[hook] = this._hooks[hook] || [];
    hooks2.push(callback);
    return () => {
      const cbIndex = hooks2.indexOf(callback);
      if (cbIndex > -1) {
        hooks2.splice(cbIndex, 1);
      }
    };
  }
  /** @inheritdoc */
  /** @inheritdoc */
  emit(hook, ...rest) {
    const callbacks = this._hooks[hook];
    if (callbacks) {
      callbacks.forEach((callback) => callback(...rest));
    }
  }
  /**
   * @inheritdoc
   */
  sendEnvelope(envelope) {
    this.emit("beforeEnvelope", envelope);
    if (this._isEnabled() && this._transport) {
      return this._transport.send(envelope).then(null, (reason) => {
        DEBUG_BUILD$6 && logger$2.error("Error while sending envelope:", reason);
        return reason;
      });
    }
    DEBUG_BUILD$6 && logger$2.error("Transport disabled");
    return resolvedSyncPromise({});
  }
  /* eslint-enable @typescript-eslint/unified-signatures */
  /** Setup integrations for this client. */
  _setupIntegrations() {
    const { integrations } = this._options;
    this._integrations = setupIntegrations(this, integrations);
    afterSetupIntegrations(this, integrations);
  }
  /** Updates existing session based on the provided event */
  _updateSessionFromEvent(session, event) {
    let crashed = false;
    let errored = false;
    const exceptions = event.exception && event.exception.values;
    if (exceptions) {
      errored = true;
      for (const ex of exceptions) {
        const mechanism = ex.mechanism;
        if (mechanism && mechanism.handled === false) {
          crashed = true;
          break;
        }
      }
    }
    const sessionNonTerminal = session.status === "ok";
    const shouldUpdateAndSend = sessionNonTerminal && session.errors === 0 || sessionNonTerminal && crashed;
    if (shouldUpdateAndSend) {
      updateSession(session, {
        ...crashed && { status: "crashed" },
        errors: session.errors || Number(errored || crashed)
      });
      this.captureSession(session);
    }
  }
  /**
   * Determine if the client is finished processing. Returns a promise because it will wait `timeout` ms before saying
   * "no" (resolving to `false`) in order to give the client a chance to potentially finish first.
   *
   * @param timeout The time, in ms, after which to resolve to `false` if the client is still busy. Passing `0` (or not
   * passing anything) will make the promise wait as long as it takes for processing to finish before resolving to
   * `true`.
   * @returns A promise which will resolve to `true` if processing is already done or finishes before the timeout, and
   * `false` otherwise
   */
  _isClientDoneProcessing(timeout) {
    return new SyncPromise((resolve2) => {
      let ticked = 0;
      const tick = 1;
      const interval = setInterval(() => {
        if (this._numProcessing == 0) {
          clearInterval(interval);
          resolve2(true);
        } else {
          ticked += tick;
          if (timeout && ticked >= timeout) {
            clearInterval(interval);
            resolve2(false);
          }
        }
      }, tick);
    });
  }
  /** Determines whether this SDK is enabled and a transport is present. */
  _isEnabled() {
    return this.getOptions().enabled !== false && this._transport !== void 0;
  }
  /**
   * Adds common information to events.
   *
   * The information includes release and environment from `options`,
   * breadcrumbs and context (extra, tags and user) from the scope.
   *
   * Information that is already present in the event is never overwritten. For
   * nested objects, such as the context, keys are merged.
   *
   * @param event The original event.
   * @param hint May contain additional information about the original exception.
   * @param currentScope A scope containing event metadata.
   * @returns A new event with more information.
   */
  _prepareEvent(event, hint, currentScope = getCurrentScope$1(), isolationScope = getIsolationScope()) {
    const options5 = this.getOptions();
    const integrations = Object.keys(this._integrations);
    if (!hint.integrations && integrations.length > 0) {
      hint.integrations = integrations;
    }
    this.emit("preprocessEvent", event, hint);
    if (!event.type) {
      isolationScope.setLastEventId(event.event_id || hint.event_id);
    }
    return prepareEvent(options5, event, hint, currentScope, this, isolationScope).then((evt) => {
      if (evt === null) {
        return evt;
      }
      evt.contexts = {
        trace: getTraceContextFromScope(currentScope),
        ...evt.contexts
      };
      const dynamicSamplingContext = getDynamicSamplingContextFromScope(this, currentScope);
      evt.sdkProcessingMetadata = {
        dynamicSamplingContext,
        ...evt.sdkProcessingMetadata
      };
      return evt;
    });
  }
  /**
   * Processes the event and logs an error in case of rejection
   * @param event
   * @param hint
   * @param scope
   */
  _captureEvent(event, hint = {}, scope) {
    return this._processEvent(event, hint, scope).then(
      (finalEvent) => {
        return finalEvent.event_id;
      },
      (reason) => {
        if (DEBUG_BUILD$6) {
          const sentryError = reason;
          if (sentryError.logLevel === "log") {
            logger$2.log(sentryError.message);
          } else {
            logger$2.warn(sentryError);
          }
        }
        return void 0;
      }
    );
  }
  /**
   * Processes an event (either error or message) and sends it to Sentry.
   *
   * This also adds breadcrumbs and context information to the event. However,
   * platform specific meta data (such as the User's IP address) must be added
   * by the SDK implementor.
   *
   *
   * @param event The event to send to Sentry.
   * @param hint May contain additional information about the original exception.
   * @param currentScope A scope containing event metadata.
   * @returns A SyncPromise that resolves with the event or rejects in case event was/will not be send.
   */
  _processEvent(event, hint, currentScope) {
    const options5 = this.getOptions();
    const { sampleRate } = options5;
    const isTransaction = isTransactionEvent$1(event);
    const isError2 = isErrorEvent$1(event);
    const eventType = event.type || "error";
    const beforeSendLabel = `before send for type \`${eventType}\``;
    const parsedSampleRate = typeof sampleRate === "undefined" ? void 0 : parseSampleRate(sampleRate);
    if (isError2 && typeof parsedSampleRate === "number" && Math.random() > parsedSampleRate) {
      this.recordDroppedEvent("sample_rate", "error", event);
      return rejectedSyncPromise(
        new SentryError(
          `Discarding event because it's not included in the random sample (sampling rate = ${sampleRate})`,
          "log"
        )
      );
    }
    const dataCategory = eventType === "replay_event" ? "replay" : eventType;
    const sdkProcessingMetadata = event.sdkProcessingMetadata || {};
    const capturedSpanIsolationScope = sdkProcessingMetadata.capturedSpanIsolationScope;
    return this._prepareEvent(event, hint, currentScope, capturedSpanIsolationScope).then((prepared) => {
      if (prepared === null) {
        this.recordDroppedEvent("event_processor", dataCategory, event);
        throw new SentryError("An event processor returned `null`, will not send event.", "log");
      }
      const isInternalException = hint.data && hint.data.__sentry__ === true;
      if (isInternalException) {
        return prepared;
      }
      const result = processBeforeSend(this, options5, prepared, hint);
      return _validateBeforeSendResult(result, beforeSendLabel);
    }).then((processedEvent) => {
      if (processedEvent === null) {
        this.recordDroppedEvent("before_send", dataCategory, event);
        if (isTransaction) {
          const spans = event.spans || [];
          const spanCount = 1 + spans.length;
          this.recordDroppedEvent("before_send", "span", spanCount);
        }
        throw new SentryError(`${beforeSendLabel} returned \`null\`, will not send event.`, "log");
      }
      const session = currentScope && currentScope.getSession();
      if (!isTransaction && session) {
        this._updateSessionFromEvent(session, processedEvent);
      }
      if (isTransaction) {
        const spanCountBefore = processedEvent.sdkProcessingMetadata && processedEvent.sdkProcessingMetadata.spanCountBeforeProcessing || 0;
        const spanCountAfter = processedEvent.spans ? processedEvent.spans.length : 0;
        const droppedSpanCount = spanCountBefore - spanCountAfter;
        if (droppedSpanCount > 0) {
          this.recordDroppedEvent("before_send", "span", droppedSpanCount);
        }
      }
      const transactionInfo = processedEvent.transaction_info;
      if (isTransaction && transactionInfo && processedEvent.transaction !== event.transaction) {
        const source = "custom";
        processedEvent.transaction_info = {
          ...transactionInfo,
          source
        };
      }
      this.sendEvent(processedEvent, hint);
      return processedEvent;
    }).then(null, (reason) => {
      if (reason instanceof SentryError) {
        throw reason;
      }
      this.captureException(reason, {
        data: {
          __sentry__: true
        },
        originalException: reason
      });
      throw new SentryError(
        `Event processing pipeline threw an error, original event will not be sent. Details have been sent as a new event.
Reason: ${reason}`
      );
    });
  }
  /**
   * Occupies the client with processing and event
   */
  _process(promise) {
    this._numProcessing++;
    void promise.then(
      (value3) => {
        this._numProcessing--;
        return value3;
      },
      (reason) => {
        this._numProcessing--;
        return reason;
      }
    );
  }
  /**
   * Clears outcomes on this client and returns them.
   */
  _clearOutcomes() {
    const outcomes = this._outcomes;
    this._outcomes = {};
    return Object.entries(outcomes).map(([key, quantity]) => {
      const [reason, category] = key.split(":");
      return {
        reason,
        category,
        quantity
      };
    });
  }
  /**
   * Sends client reports as an envelope.
   */
  _flushOutcomes() {
    DEBUG_BUILD$6 && logger$2.log("Flushing outcomes...");
    const outcomes = this._clearOutcomes();
    if (outcomes.length === 0) {
      DEBUG_BUILD$6 && logger$2.log("No outcomes to send");
      return;
    }
    if (!this._dsn) {
      DEBUG_BUILD$6 && logger$2.log("No dsn provided, will not send outcomes");
      return;
    }
    DEBUG_BUILD$6 && logger$2.log("Sending outcomes:", outcomes);
    const envelope = createClientReportEnvelope(outcomes, this._options.tunnel && dsnToString(this._dsn));
    this.sendEnvelope(envelope);
  }
  /**
   * @inheritDoc
   */
}
function _validateBeforeSendResult(beforeSendResult, beforeSendLabel) {
  const invalidValueError = `${beforeSendLabel} must return \`null\` or a valid event.`;
  if (isThenable$1(beforeSendResult)) {
    return beforeSendResult.then(
      (event) => {
        if (!isPlainObject$5(event) && event !== null) {
          throw new SentryError(invalidValueError);
        }
        return event;
      },
      (e2) => {
        throw new SentryError(`${beforeSendLabel} rejected with ${e2}`);
      }
    );
  } else if (!isPlainObject$5(beforeSendResult) && beforeSendResult !== null) {
    throw new SentryError(invalidValueError);
  }
  return beforeSendResult;
}
__name(_validateBeforeSendResult, "_validateBeforeSendResult");
function processBeforeSend(client, options5, event, hint) {
  const { beforeSend, beforeSendTransaction, beforeSendSpan } = options5;
  if (isErrorEvent$1(event) && beforeSend) {
    return beforeSend(event, hint);
  }
  if (isTransactionEvent$1(event)) {
    if (event.spans && beforeSendSpan) {
      const processedSpans = [];
      for (const span of event.spans) {
        const processedSpan = beforeSendSpan(span);
        if (processedSpan) {
          processedSpans.push(processedSpan);
        } else {
          showSpanDropWarning();
          client.recordDroppedEvent("before_send", "span");
        }
      }
      event.spans = processedSpans;
    }
    if (beforeSendTransaction) {
      if (event.spans) {
        const spanCountBefore = event.spans.length;
        event.sdkProcessingMetadata = {
          ...event.sdkProcessingMetadata,
          spanCountBeforeProcessing: spanCountBefore
        };
      }
      return beforeSendTransaction(event, hint);
    }
  }
  return event;
}
__name(processBeforeSend, "processBeforeSend");
function isErrorEvent$1(event) {
  return event.type === void 0;
}
__name(isErrorEvent$1, "isErrorEvent$1");
function isTransactionEvent$1(event) {
  return event.type === "transaction";
}
__name(isTransactionEvent$1, "isTransactionEvent$1");
function createCheckInEnvelope(checkIn, dynamicSamplingContext, metadata, tunnel, dsn) {
  const headers = {
    sent_at: (/* @__PURE__ */ new Date()).toISOString()
  };
  if (metadata && metadata.sdk) {
    headers.sdk = {
      name: metadata.sdk.name,
      version: metadata.sdk.version
    };
  }
  if (!!tunnel && !!dsn) {
    headers.dsn = dsnToString(dsn);
  }
  if (dynamicSamplingContext) {
    headers.trace = dropUndefinedKeys(dynamicSamplingContext);
  }
  const item3 = createCheckInEnvelopeItem(checkIn);
  return createEnvelope(headers, [item3]);
}
__name(createCheckInEnvelope, "createCheckInEnvelope");
function createCheckInEnvelopeItem(checkIn) {
  const checkInHeaders = {
    type: "check_in"
  };
  return [checkInHeaders, checkIn];
}
__name(createCheckInEnvelopeItem, "createCheckInEnvelopeItem");
function parseStackFrames$1(stackParser, error2) {
  return stackParser(error2.stack || "", 1);
}
__name(parseStackFrames$1, "parseStackFrames$1");
function exceptionFromError$1(stackParser, error2) {
  const exception = {
    type: error2.name || error2.constructor.name,
    value: error2.message
  };
  const frames = parseStackFrames$1(stackParser, error2);
  if (frames.length) {
    exception.stacktrace = { frames };
  }
  return exception;
}
__name(exceptionFromError$1, "exceptionFromError$1");
function getErrorPropertyFromObject$1(obj) {
  for (const prop2 in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, prop2)) {
      const value3 = obj[prop2];
      if (value3 instanceof Error) {
        return value3;
      }
    }
  }
  return void 0;
}
__name(getErrorPropertyFromObject$1, "getErrorPropertyFromObject$1");
function getMessageForObject(exception) {
  if ("name" in exception && typeof exception.name === "string") {
    let message3 = `'${exception.name}' captured as exception`;
    if ("message" in exception && typeof exception.message === "string") {
      message3 += ` with message '${exception.message}'`;
    }
    return message3;
  } else if ("message" in exception && typeof exception.message === "string") {
    return exception.message;
  }
  const keys2 = extractExceptionKeysForMessage(exception);
  if (isErrorEvent$2(exception)) {
    return `Event \`ErrorEvent\` captured as exception with message \`${exception.message}\``;
  }
  const className = getObjectClassName$1(exception);
  return `${className && className !== "Object" ? `'${className}'` : "Object"} captured as exception with keys: ${keys2}`;
}
__name(getMessageForObject, "getMessageForObject");
function getObjectClassName$1(obj) {
  try {
    const prototype2 = Object.getPrototypeOf(obj);
    return prototype2 ? prototype2.constructor.name : void 0;
  } catch (e2) {
  }
}
__name(getObjectClassName$1, "getObjectClassName$1");
function getException(client, mechanism, exception, hint) {
  if (isError(exception)) {
    return [exception, void 0];
  }
  mechanism.synthetic = true;
  if (isPlainObject$5(exception)) {
    const normalizeDepth = client && client.getOptions().normalizeDepth;
    const extras = { ["__serialized__"]: normalizeToSize(exception, normalizeDepth) };
    const errorFromProp = getErrorPropertyFromObject$1(exception);
    if (errorFromProp) {
      return [errorFromProp, extras];
    }
    const message3 = getMessageForObject(exception);
    const ex2 = hint && hint.syntheticException || new Error(message3);
    ex2.message = message3;
    return [ex2, extras];
  }
  const ex = hint && hint.syntheticException || new Error(exception);
  ex.message = `${exception}`;
  return [ex, void 0];
}
__name(getException, "getException");
function eventFromUnknownInput$1(client, stackParser, exception, hint) {
  const providedMechanism = hint && hint.data && hint.data.mechanism;
  const mechanism = providedMechanism || {
    handled: true,
    type: "generic"
  };
  const [ex, extras] = getException(client, mechanism, exception, hint);
  const event = {
    exception: {
      values: [exceptionFromError$1(stackParser, ex)]
    }
  };
  if (extras) {
    event.extra = extras;
  }
  addExceptionTypeValue(event, void 0, void 0);
  addExceptionMechanism(event, mechanism);
  return {
    ...event,
    event_id: hint && hint.event_id
  };
}
__name(eventFromUnknownInput$1, "eventFromUnknownInput$1");
function eventFromMessage$1(stackParser, message3, level = "info", hint, attachStacktrace) {
  const event = {
    event_id: hint && hint.event_id,
    level
  };
  if (attachStacktrace && hint && hint.syntheticException) {
    const frames = parseStackFrames$1(stackParser, hint.syntheticException);
    if (frames.length) {
      event.exception = {
        values: [
          {
            value: message3,
            stacktrace: { frames }
          }
        ]
      };
      addExceptionMechanism(event, { synthetic: true });
    }
  }
  if (isParameterizedString(message3)) {
    const { __sentry_template_string__, __sentry_template_values__ } = message3;
    event.logentry = {
      message: __sentry_template_string__,
      params: __sentry_template_values__
    };
    return event;
  }
  event.message = message3;
  return event;
}
__name(eventFromMessage$1, "eventFromMessage$1");
class ServerRuntimeClient extends BaseClient {
  static {
    __name(this, "ServerRuntimeClient");
  }
  // eslint-disable-next-line deprecation/deprecation
  /**
   * Creates a new Edge SDK instance.
   * @param options Configuration options for this SDK.
   */
  constructor(options5) {
    registerSpanErrorInstrumentation();
    super(options5);
  }
  /**
   * @inheritDoc
   */
  eventFromException(exception, hint) {
    const event = eventFromUnknownInput$1(this, this._options.stackParser, exception, hint);
    event.level = "error";
    return resolvedSyncPromise(event);
  }
  /**
   * @inheritDoc
   */
  eventFromMessage(message3, level = "info", hint) {
    return resolvedSyncPromise(
      eventFromMessage$1(this._options.stackParser, message3, level, hint, this._options.attachStacktrace)
    );
  }
  /**
   * @inheritDoc
   */
  captureException(exception, hint, scope) {
    if (this._options.autoSessionTracking && this._sessionFlusher) {
      const requestSession = getIsolationScope().getRequestSession();
      if (requestSession && requestSession.status === "ok") {
        requestSession.status = "errored";
      }
    }
    return super.captureException(exception, hint, scope);
  }
  /**
   * @inheritDoc
   */
  captureEvent(event, hint, scope) {
    if (this._options.autoSessionTracking && this._sessionFlusher) {
      const eventType = event.type || "exception";
      const isException = eventType === "exception" && event.exception && event.exception.values && event.exception.values.length > 0;
      if (isException) {
        const requestSession = getIsolationScope().getRequestSession();
        if (requestSession && requestSession.status === "ok") {
          requestSession.status = "errored";
        }
      }
    }
    return super.captureEvent(event, hint, scope);
  }
  /**
   *
   * @inheritdoc
   */
  close(timeout) {
    if (this._sessionFlusher) {
      this._sessionFlusher.close();
    }
    return super.close(timeout);
  }
  /**
   * Initializes an instance of SessionFlusher on the client which will aggregate and periodically flush session data.
   *
   * NOTICE: This method will implicitly create an interval that is periodically called.
   * To clean up this resources, call `.close()` when you no longer intend to use the client.
   * Not doing so will result in a memory leak.
   */
  initSessionFlusher() {
    const { release, environment } = this._options;
    if (!release) {
      DEBUG_BUILD$6 && logger$2.warn("Cannot initialize an instance of SessionFlusher if no release is provided!");
    } else {
      this._sessionFlusher = new SessionFlusher(this, {
        release,
        environment
      });
    }
  }
  /**
   * Create a cron monitor check in and send it to Sentry.
   *
   * @param checkIn An object that describes a check in.
   * @param upsertMonitorConfig An optional object that describes a monitor config. Use this if you want
   * to create a monitor automatically when sending a check in.
   */
  captureCheckIn(checkIn, monitorConfig, scope) {
    const id4 = "checkInId" in checkIn && checkIn.checkInId ? checkIn.checkInId : uuid4();
    if (!this._isEnabled()) {
      DEBUG_BUILD$6 && logger$2.warn("SDK not enabled, will not capture checkin.");
      return id4;
    }
    const options5 = this.getOptions();
    const { release, environment, tunnel } = options5;
    const serializedCheckIn = {
      check_in_id: id4,
      monitor_slug: checkIn.monitorSlug,
      status: checkIn.status,
      release,
      environment
    };
    if ("duration" in checkIn) {
      serializedCheckIn.duration = checkIn.duration;
    }
    if (monitorConfig) {
      serializedCheckIn.monitor_config = {
        schedule: monitorConfig.schedule,
        checkin_margin: monitorConfig.checkinMargin,
        max_runtime: monitorConfig.maxRuntime,
        timezone: monitorConfig.timezone,
        failure_issue_threshold: monitorConfig.failureIssueThreshold,
        recovery_threshold: monitorConfig.recoveryThreshold
      };
    }
    const [dynamicSamplingContext, traceContext] = this._getTraceInfoFromScope(scope);
    if (traceContext) {
      serializedCheckIn.contexts = {
        trace: traceContext
      };
    }
    const envelope = createCheckInEnvelope(
      serializedCheckIn,
      dynamicSamplingContext,
      this.getSdkMetadata(),
      tunnel,
      this.getDsn()
    );
    DEBUG_BUILD$6 && logger$2.info("Sending checkin:", checkIn.monitorSlug, checkIn.status);
    this.sendEnvelope(envelope);
    return id4;
  }
  /**
   * Method responsible for capturing/ending a request session by calling `incrementSessionStatusCount` to increment
   * appropriate session aggregates bucket
   *
   * @deprecated This method should not be used or extended. It's functionality will move into the `httpIntegration` and not be part of any public API.
   */
  _captureRequestSession() {
    if (!this._sessionFlusher) {
      DEBUG_BUILD$6 && logger$2.warn("Discarded request mode session because autoSessionTracking option was disabled");
    } else {
      this._sessionFlusher.incrementSessionStatusCount();
    }
  }
  /**
   * @inheritDoc
   */
  _prepareEvent(event, hint, scope, isolationScope) {
    if (this._options.platform) {
      event.platform = event.platform || this._options.platform;
    }
    if (this._options.runtime) {
      event.contexts = {
        ...event.contexts,
        runtime: (event.contexts || {}).runtime || this._options.runtime
      };
    }
    if (this._options.serverName) {
      event.server_name = event.server_name || this._options.serverName;
    }
    return super._prepareEvent(event, hint, scope, isolationScope);
  }
  /** Extract trace information from scope */
  _getTraceInfoFromScope(scope) {
    if (!scope) {
      return [void 0, void 0];
    }
    const span = _getSpanForScope(scope);
    const traceContext = span ? spanToTraceContext(span) : getTraceContextFromScope(scope);
    const dynamicSamplingContext = span ? getDynamicSamplingContextFromSpan(span) : getDynamicSamplingContextFromScope(this, scope);
    return [dynamicSamplingContext, traceContext];
  }
}
function initAndBind(clientClass, options5) {
  if (options5.debug === true) {
    if (DEBUG_BUILD$6) {
      logger$2.enable();
    } else {
      consoleSandbox(() => {
        console.warn("[Sentry] Cannot initialize SDK with `debug` option using a non-debug bundle.");
      });
    }
  }
  const scope = getCurrentScope$1();
  scope.update(options5.initialScope);
  const client = new clientClass(options5);
  setCurrentClient(client);
  client.init();
  return client;
}
__name(initAndBind, "initAndBind");
function setCurrentClient(client) {
  getCurrentScope$1().setClient(client);
}
__name(setCurrentClient, "setCurrentClient");
function makePromiseBuffer(limit) {
  const buffer2 = [];
  function isReady() {
    return limit === void 0 || buffer2.length < limit;
  }
  __name(isReady, "isReady");
  function remove4(task) {
    return buffer2.splice(buffer2.indexOf(task), 1)[0] || Promise.resolve(void 0);
  }
  __name(remove4, "remove");
  function add3(taskProducer) {
    if (!isReady()) {
      return rejectedSyncPromise(new SentryError("Not adding Promise because buffer limit was reached."));
    }
    const task = taskProducer();
    if (buffer2.indexOf(task) === -1) {
      buffer2.push(task);
    }
    void task.then(() => remove4(task)).then(
      null,
      () => remove4(task).then(null, () => {
      })
    );
    return task;
  }
  __name(add3, "add");
  function drain(timeout) {
    return new SyncPromise((resolve2, reject3) => {
      let counter = buffer2.length;
      if (!counter) {
        return resolve2(true);
      }
      const capturedSetTimeout = setTimeout(() => {
        if (timeout && timeout > 0) {
          resolve2(false);
        }
      }, timeout);
      buffer2.forEach((item3) => {
        void resolvedSyncPromise(item3).then(() => {
          if (!--counter) {
            clearTimeout(capturedSetTimeout);
            resolve2(true);
          }
        }, reject3);
      });
    });
  }
  __name(drain, "drain");
  return {
    $: buffer2,
    add: add3,
    drain
  };
}
__name(makePromiseBuffer, "makePromiseBuffer");
const DEFAULT_RETRY_AFTER = 60 * 1e3;
function parseRetryAfterHeader(header3, now2 = Date.now()) {
  const headerDelay = parseInt(`${header3}`, 10);
  if (!isNaN(headerDelay)) {
    return headerDelay * 1e3;
  }
  const headerDate = Date.parse(`${header3}`);
  if (!isNaN(headerDate)) {
    return headerDate - now2;
  }
  return DEFAULT_RETRY_AFTER;
}
__name(parseRetryAfterHeader, "parseRetryAfterHeader");
function disabledUntil(limits, dataCategory) {
  return limits[dataCategory] || limits.all || 0;
}
__name(disabledUntil, "disabledUntil");
function isRateLimited(limits, dataCategory, now2 = Date.now()) {
  return disabledUntil(limits, dataCategory) > now2;
}
__name(isRateLimited, "isRateLimited");
function updateRateLimits(limits, { statusCode, headers }, now2 = Date.now()) {
  const updatedRateLimits = {
    ...limits
  };
  const rateLimitHeader = headers && headers["x-sentry-rate-limits"];
  const retryAfterHeader = headers && headers["retry-after"];
  if (rateLimitHeader) {
    for (const limit of rateLimitHeader.trim().split(",")) {
      const [retryAfter, categories, , , namespaces] = limit.split(":", 5);
      const headerDelay = parseInt(retryAfter, 10);
      const delay = (!isNaN(headerDelay) ? headerDelay : 60) * 1e3;
      if (!categories) {
        updatedRateLimits.all = now2 + delay;
      } else {
        for (const category of categories.split(";")) {
          if (category === "metric_bucket") {
            if (!namespaces || namespaces.split(";").includes("custom")) {
              updatedRateLimits[category] = now2 + delay;
            }
          } else {
            updatedRateLimits[category] = now2 + delay;
          }
        }
      }
    }
  } else if (retryAfterHeader) {
    updatedRateLimits.all = now2 + parseRetryAfterHeader(retryAfterHeader, now2);
  } else if (statusCode === 429) {
    updatedRateLimits.all = now2 + 60 * 1e3;
  }
  return updatedRateLimits;
}
__name(updateRateLimits, "updateRateLimits");
const DEFAULT_TRANSPORT_BUFFER_SIZE = 64;
function createTransport(options5, makeRequest, buffer2 = makePromiseBuffer(
  options5.bufferSize || DEFAULT_TRANSPORT_BUFFER_SIZE
)) {
  let rateLimits = {};
  const flush2 = /* @__PURE__ */ __name((timeout) => buffer2.drain(timeout), "flush");
  function send(envelope) {
    const filteredEnvelopeItems = [];
    forEachEnvelopeItem(envelope, (item3, type) => {
      const dataCategory = envelopeItemTypeToDataCategory(type);
      if (isRateLimited(rateLimits, dataCategory)) {
        const event = getEventForEnvelopeItem(item3, type);
        options5.recordDroppedEvent("ratelimit_backoff", dataCategory, event);
      } else {
        filteredEnvelopeItems.push(item3);
      }
    });
    if (filteredEnvelopeItems.length === 0) {
      return resolvedSyncPromise({});
    }
    const filteredEnvelope = createEnvelope(envelope[0], filteredEnvelopeItems);
    const recordEnvelopeLoss = /* @__PURE__ */ __name((reason) => {
      forEachEnvelopeItem(filteredEnvelope, (item3, type) => {
        const event = getEventForEnvelopeItem(item3, type);
        options5.recordDroppedEvent(reason, envelopeItemTypeToDataCategory(type), event);
      });
    }, "recordEnvelopeLoss");
    const requestTask = /* @__PURE__ */ __name(() => makeRequest({ body: serializeEnvelope(filteredEnvelope) }).then(
      (response) => {
        if (response.statusCode !== void 0 && (response.statusCode < 200 || response.statusCode >= 300)) {
          DEBUG_BUILD$6 && logger$2.warn(`Sentry responded with status code ${response.statusCode} to sent event.`);
        }
        rateLimits = updateRateLimits(rateLimits, response);
        return response;
      },
      (error2) => {
        recordEnvelopeLoss("network_error");
        throw error2;
      }
    ), "requestTask");
    return buffer2.add(requestTask).then(
      (result) => result,
      (error2) => {
        if (error2 instanceof SentryError) {
          DEBUG_BUILD$6 && logger$2.error("Skipped sending event because buffer is full.");
          recordEnvelopeLoss("queue_overflow");
          return resolvedSyncPromise({});
        } else {
          throw error2;
        }
      }
    );
  }
  __name(send, "send");
  return {
    send,
    flush: flush2
  };
}
__name(createTransport, "createTransport");
function getEventForEnvelopeItem(item3, type) {
  if (type !== "event" && type !== "transaction") {
    return void 0;
  }
  return Array.isArray(item3) ? item3[1] : void 0;
}
__name(getEventForEnvelopeItem, "getEventForEnvelopeItem");
const MIN_DELAY = 100;
const START_DELAY = 5e3;
const MAX_DELAY = 36e5;
function makeOfflineTransport(createTransport2) {
  function log2(...args) {
    DEBUG_BUILD$6 && logger$2.info("[Offline]:", ...args);
  }
  __name(log2, "log");
  return (options5) => {
    const transport = createTransport2(options5);
    if (!options5.createStore) {
      throw new Error("No `createStore` function was provided");
    }
    const store = options5.createStore(options5);
    let retryDelay = START_DELAY;
    let flushTimer;
    function shouldQueue(env, error2, retryDelay2) {
      if (envelopeContainsItemType(env, ["client_report"])) {
        return false;
      }
      if (options5.shouldStore) {
        return options5.shouldStore(env, error2, retryDelay2);
      }
      return true;
    }
    __name(shouldQueue, "shouldQueue");
    function flushIn(delay) {
      if (flushTimer) {
        clearTimeout(flushTimer);
      }
      flushTimer = setTimeout(async () => {
        flushTimer = void 0;
        const found2 = await store.shift();
        if (found2) {
          log2("Attempting to send previously queued event");
          found2[0].sent_at = (/* @__PURE__ */ new Date()).toISOString();
          void send(found2, true).catch((e2) => {
            log2("Failed to retry sending", e2);
          });
        }
      }, delay);
      if (typeof flushTimer !== "number" && flushTimer.unref) {
        flushTimer.unref();
      }
    }
    __name(flushIn, "flushIn");
    function flushWithBackOff() {
      if (flushTimer) {
        return;
      }
      flushIn(retryDelay);
      retryDelay = Math.min(retryDelay * 2, MAX_DELAY);
    }
    __name(flushWithBackOff, "flushWithBackOff");
    async function send(envelope, isRetry = false) {
      if (!isRetry && envelopeContainsItemType(envelope, ["replay_event", "replay_recording"])) {
        await store.push(envelope);
        flushIn(MIN_DELAY);
        return {};
      }
      try {
        const result = await transport.send(envelope);
        let delay = MIN_DELAY;
        if (result) {
          if (result.headers && result.headers["retry-after"]) {
            delay = parseRetryAfterHeader(result.headers["retry-after"]);
          } else if (result.headers && result.headers["x-sentry-rate-limits"]) {
            delay = 6e4;
          } else if ((result.statusCode || 0) >= 400) {
            return result;
          }
        }
        flushIn(delay);
        retryDelay = START_DELAY;
        return result;
      } catch (e2) {
        if (await shouldQueue(envelope, e2, retryDelay)) {
          if (isRetry) {
            await store.unshift(envelope);
          } else {
            await store.push(envelope);
          }
          flushWithBackOff();
          log2("Error sending. Event queued.", e2);
          return {};
        } else {
          throw e2;
        }
      }
    }
    __name(send, "send");
    if (options5.flushAtStartup) {
      flushWithBackOff();
    }
    return {
      send,
      flush: /* @__PURE__ */ __name((t2) => transport.flush(t2), "flush")
    };
  };
}
__name(makeOfflineTransport, "makeOfflineTransport");
function eventFromEnvelope(env, types) {
  let event;
  forEachEnvelopeItem(env, (item3, type) => {
    if (types.includes(type)) {
      event = Array.isArray(item3) ? item3[1] : void 0;
    }
    return !!event;
  });
  return event;
}
__name(eventFromEnvelope, "eventFromEnvelope");
function makeOverrideReleaseTransport(createTransport2, release) {
  return (options5) => {
    const transport = createTransport2(options5);
    return {
      ...transport,
      send: /* @__PURE__ */ __name(async (envelope) => {
        const event = eventFromEnvelope(envelope, ["event", "transaction", "profile", "replay_event"]);
        if (event) {
          event.release = release;
        }
        return transport.send(envelope);
      }, "send")
    };
  };
}
__name(makeOverrideReleaseTransport, "makeOverrideReleaseTransport");
function overrideDsn(envelope, dsn) {
  return createEnvelope(
    dsn ? {
      ...envelope[0],
      dsn
    } : envelope[0],
    envelope[1]
  );
}
__name(overrideDsn, "overrideDsn");
function makeMultiplexedTransport(createTransport2, matcher) {
  return (options5) => {
    const fallbackTransport = createTransport2(options5);
    const otherTransports = /* @__PURE__ */ new Map();
    function getTransport(dsn, release) {
      const key = release ? `${dsn}:${release}` : dsn;
      let transport = otherTransports.get(key);
      if (!transport) {
        const validatedDsn = dsnFromString(dsn);
        if (!validatedDsn) {
          return void 0;
        }
        const url = getEnvelopeEndpointWithUrlEncodedAuth(validatedDsn, options5.tunnel);
        transport = release ? makeOverrideReleaseTransport(createTransport2, release)({ ...options5, url }) : createTransport2({ ...options5, url });
        otherTransports.set(key, transport);
      }
      return [dsn, transport];
    }
    __name(getTransport, "getTransport");
    async function send(envelope) {
      function getEvent(types) {
        const eventTypes = types && types.length ? types : ["event"];
        return eventFromEnvelope(envelope, eventTypes);
      }
      __name(getEvent, "getEvent");
      const transports = matcher({ envelope, getEvent }).map((result) => {
        if (typeof result === "string") {
          return getTransport(result, void 0);
        } else {
          return getTransport(result.dsn, result.release);
        }
      }).filter((t2) => !!t2);
      const transportsWithFallback = transports.length ? transports : [["", fallbackTransport]];
      const results = await Promise.all(
        transportsWithFallback.map(([dsn, transport]) => transport.send(overrideDsn(envelope, dsn)))
      );
      return results[0];
    }
    __name(send, "send");
    async function flush2(timeout) {
      const allTransports = [...otherTransports.values(), fallbackTransport];
      const results = await Promise.all(allTransports.map((transport) => transport.flush(timeout)));
      return results.every((r2) => r2);
    }
    __name(flush2, "flush");
    return {
      send,
      flush: flush2
    };
  };
}
__name(makeMultiplexedTransport, "makeMultiplexedTransport");
function isSentryRequestUrl(url, client) {
  const dsn = client && client.getDsn();
  const tunnel = client && client.getOptions().tunnel;
  return checkDsn(url, dsn) || checkTunnel(url, tunnel);
}
__name(isSentryRequestUrl, "isSentryRequestUrl");
function checkTunnel(url, tunnel) {
  if (!tunnel) {
    return false;
  }
  return removeTrailingSlash$1(url) === removeTrailingSlash$1(tunnel);
}
__name(checkTunnel, "checkTunnel");
function checkDsn(url, dsn) {
  return dsn ? url.includes(dsn.host) : false;
}
__name(checkDsn, "checkDsn");
function removeTrailingSlash$1(str) {
  return str[str.length - 1] === "/" ? str.slice(0, -1) : str;
}
__name(removeTrailingSlash$1, "removeTrailingSlash$1");
function parameterize(strings, ...values) {
  const formatted = new String(String.raw(strings, ...values));
  formatted.__sentry_template_string__ = strings.join("\0").replace(/%/g, "%%").replace(/\0/g, "%s");
  formatted.__sentry_template_values__ = values;
  return formatted;
}
__name(parameterize, "parameterize");
function applySdkMetadata(options5, name2, names = [name2], source = "npm") {
  const metadata = options5._metadata || {};
  if (!metadata.sdk) {
    metadata.sdk = {
      name: `sentry.javascript.${name2}`,
      packages: names.map((name3) => ({
        name: `${source}:@sentry/${name3}`,
        version: SDK_VERSION
      })),
      version: SDK_VERSION
    };
  }
  options5._metadata = metadata;
}
__name(applySdkMetadata, "applySdkMetadata");
function getTraceData(options5 = {}) {
  const client = getClient();
  if (!isEnabled() || !client) {
    return {};
  }
  const carrier = getMainCarrier();
  const acs = getAsyncContextStrategy(carrier);
  if (acs.getTraceData) {
    return acs.getTraceData(options5);
  }
  const scope = getCurrentScope$1();
  const span = options5.span || getActiveSpan();
  const sentryTrace = span ? spanToTraceHeader(span) : scopeToTraceHeader(scope);
  const dsc = span ? getDynamicSamplingContextFromSpan(span) : getDynamicSamplingContextFromScope(client, scope);
  const baggage = dynamicSamplingContextToSentryBaggageHeader(dsc);
  const isValidSentryTraceHeader = TRACEPARENT_REGEXP.test(sentryTrace);
  if (!isValidSentryTraceHeader) {
    logger$2.warn("Invalid sentry-trace data. Cannot generate trace data");
    return {};
  }
  return {
    "sentry-trace": sentryTrace,
    baggage
  };
}
__name(getTraceData, "getTraceData");
function scopeToTraceHeader(scope) {
  const { traceId, sampled, spanId } = scope.getPropagationContext();
  return generateSentryTraceHeader(traceId, spanId, sampled);
}
__name(scopeToTraceHeader, "scopeToTraceHeader");
function getTraceMetaTags() {
  return Object.entries(getTraceData()).map(([key, value3]) => `<meta name="${key}" content="${value3}"/>`).join("\n");
}
__name(getTraceMetaTags, "getTraceMetaTags");
const DEFAULT_BREADCRUMBS = 100;
function addBreadcrumb(breadcrumb, hint) {
  const client = getClient();
  const isolationScope = getIsolationScope();
  if (!client) return;
  const { beforeBreadcrumb = null, maxBreadcrumbs = DEFAULT_BREADCRUMBS } = client.getOptions();
  if (maxBreadcrumbs <= 0) return;
  const timestamp2 = dateTimestampInSeconds();
  const mergedBreadcrumb = { timestamp: timestamp2, ...breadcrumb };
  const finalBreadcrumb = beforeBreadcrumb ? consoleSandbox(() => beforeBreadcrumb(mergedBreadcrumb, hint)) : mergedBreadcrumb;
  if (finalBreadcrumb === null) return;
  if (client.emit) {
    client.emit("beforeAddBreadcrumb", finalBreadcrumb, hint);
  }
  isolationScope.addBreadcrumb(finalBreadcrumb, maxBreadcrumbs);
}
__name(addBreadcrumb, "addBreadcrumb");
let originalFunctionToString;
const INTEGRATION_NAME$l = "FunctionToString";
const SETUP_CLIENTS$1 = /* @__PURE__ */ new WeakMap();
const _functionToStringIntegration = /* @__PURE__ */ __name(() => {
  return {
    name: INTEGRATION_NAME$l,
    setupOnce() {
      originalFunctionToString = Function.prototype.toString;
      try {
        Function.prototype.toString = function(...args) {
          const originalFunction = getOriginalFunction(this);
          const context = SETUP_CLIENTS$1.has(getClient()) && originalFunction !== void 0 ? originalFunction : this;
          return originalFunctionToString.apply(context, args);
        };
      } catch (e2) {
      }
    },
    setup(client) {
      SETUP_CLIENTS$1.set(client, true);
    }
  };
}, "_functionToStringIntegration");
const functionToStringIntegration = defineIntegration(_functionToStringIntegration);
const DEFAULT_IGNORE_ERRORS = [
  /^Script error\.?$/,
  /^Javascript error: Script error\.? on line 0$/,
  /^ResizeObserver loop completed with undelivered notifications.$/,
  // The browser logs this when a ResizeObserver handler takes a bit longer. Usually this is not an actual issue though. It indicates slowness.
  /^Cannot redefine property: googletag$/,
  // This is thrown when google tag manager is used in combination with an ad blocker
  "undefined is not an object (evaluating 'a.L')",
  // Random error that happens but not actionable or noticeable to end-users.
  `can't redefine non-configurable property "solana"`,
  // Probably a browser extension or custom browser (Brave) throwing this error
  "vv().getRestrictions is not a function. (In 'vv().getRestrictions(1,a)', 'vv().getRestrictions' is undefined)",
  // Error thrown by GTM, seemingly not affecting end-users
  "Can't find variable: _AutofillCallbackHandler",
  // Unactionable error in instagram webview https://developers.facebook.com/community/threads/320013549791141/
  /^Non-Error promise rejection captured with value: Object Not Found Matching Id:\d+, MethodName:simulateEvent, ParamCount:\d+$/
  // unactionable error from CEFSharp, a .NET library that embeds chromium in .NET apps
];
const INTEGRATION_NAME$k = "InboundFilters";
const _inboundFiltersIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  return {
    name: INTEGRATION_NAME$k,
    processEvent(event, _hint, client) {
      const clientOptions = client.getOptions();
      const mergedOptions = _mergeOptions(options5, clientOptions);
      return _shouldDropEvent$1(event, mergedOptions) ? null : event;
    }
  };
}, "_inboundFiltersIntegration");
const inboundFiltersIntegration = defineIntegration(_inboundFiltersIntegration);
function _mergeOptions(internalOptions = {}, clientOptions = {}) {
  return {
    allowUrls: [...internalOptions.allowUrls || [], ...clientOptions.allowUrls || []],
    denyUrls: [...internalOptions.denyUrls || [], ...clientOptions.denyUrls || []],
    ignoreErrors: [
      ...internalOptions.ignoreErrors || [],
      ...clientOptions.ignoreErrors || [],
      ...internalOptions.disableErrorDefaults ? [] : DEFAULT_IGNORE_ERRORS
    ],
    ignoreTransactions: [...internalOptions.ignoreTransactions || [], ...clientOptions.ignoreTransactions || []],
    ignoreInternal: internalOptions.ignoreInternal !== void 0 ? internalOptions.ignoreInternal : true
  };
}
__name(_mergeOptions, "_mergeOptions");
function _shouldDropEvent$1(event, options5) {
  if (options5.ignoreInternal && _isSentryError(event)) {
    DEBUG_BUILD$6 && logger$2.warn(`Event dropped due to being internal Sentry Error.
Event: ${getEventDescription(event)}`);
    return true;
  }
  if (_isIgnoredError(event, options5.ignoreErrors)) {
    DEBUG_BUILD$6 && logger$2.warn(
      `Event dropped due to being matched by \`ignoreErrors\` option.
Event: ${getEventDescription(event)}`
    );
    return true;
  }
  if (_isUselessError(event)) {
    DEBUG_BUILD$6 && logger$2.warn(
      `Event dropped due to not having an error message, error type or stacktrace.
Event: ${getEventDescription(
        event
      )}`
    );
    return true;
  }
  if (_isIgnoredTransaction(event, options5.ignoreTransactions)) {
    DEBUG_BUILD$6 && logger$2.warn(
      `Event dropped due to being matched by \`ignoreTransactions\` option.
Event: ${getEventDescription(event)}`
    );
    return true;
  }
  if (_isDeniedUrl(event, options5.denyUrls)) {
    DEBUG_BUILD$6 && logger$2.warn(
      `Event dropped due to being matched by \`denyUrls\` option.
Event: ${getEventDescription(
        event
      )}.
Url: ${_getEventFilterUrl(event)}`
    );
    return true;
  }
  if (!_isAllowedUrl(event, options5.allowUrls)) {
    DEBUG_BUILD$6 && logger$2.warn(
      `Event dropped due to not being matched by \`allowUrls\` option.
Event: ${getEventDescription(
        event
      )}.
Url: ${_getEventFilterUrl(event)}`
    );
    return true;
  }
  return false;
}
__name(_shouldDropEvent$1, "_shouldDropEvent$1");
function _isIgnoredError(event, ignoreErrors) {
  if (event.type || !ignoreErrors || !ignoreErrors.length) {
    return false;
  }
  return _getPossibleEventMessages(event).some((message3) => stringMatchesSomePattern(message3, ignoreErrors));
}
__name(_isIgnoredError, "_isIgnoredError");
function _isIgnoredTransaction(event, ignoreTransactions) {
  if (event.type !== "transaction" || !ignoreTransactions || !ignoreTransactions.length) {
    return false;
  }
  const name2 = event.transaction;
  return name2 ? stringMatchesSomePattern(name2, ignoreTransactions) : false;
}
__name(_isIgnoredTransaction, "_isIgnoredTransaction");
function _isDeniedUrl(event, denyUrls) {
  if (!denyUrls || !denyUrls.length) {
    return false;
  }
  const url = _getEventFilterUrl(event);
  return !url ? false : stringMatchesSomePattern(url, denyUrls);
}
__name(_isDeniedUrl, "_isDeniedUrl");
function _isAllowedUrl(event, allowUrls) {
  if (!allowUrls || !allowUrls.length) {
    return true;
  }
  const url = _getEventFilterUrl(event);
  return !url ? true : stringMatchesSomePattern(url, allowUrls);
}
__name(_isAllowedUrl, "_isAllowedUrl");
function _getPossibleEventMessages(event) {
  const possibleMessages = [];
  if (event.message) {
    possibleMessages.push(event.message);
  }
  let lastException;
  try {
    lastException = event.exception.values[event.exception.values.length - 1];
  } catch (e2) {
  }
  if (lastException) {
    if (lastException.value) {
      possibleMessages.push(lastException.value);
      if (lastException.type) {
        possibleMessages.push(`${lastException.type}: ${lastException.value}`);
      }
    }
  }
  return possibleMessages;
}
__name(_getPossibleEventMessages, "_getPossibleEventMessages");
function _isSentryError(event) {
  try {
    return event.exception.values[0].type === "SentryError";
  } catch (e2) {
  }
  return false;
}
__name(_isSentryError, "_isSentryError");
function _getLastValidUrl(frames = []) {
  for (let i2 = frames.length - 1; i2 >= 0; i2--) {
    const frame = frames[i2];
    if (frame && frame.filename !== "<anonymous>" && frame.filename !== "[native code]") {
      return frame.filename || null;
    }
  }
  return null;
}
__name(_getLastValidUrl, "_getLastValidUrl");
function _getEventFilterUrl(event) {
  try {
    let frames;
    try {
      frames = event.exception.values[0].stacktrace.frames;
    } catch (e2) {
    }
    return frames ? _getLastValidUrl(frames) : null;
  } catch (oO) {
    DEBUG_BUILD$6 && logger$2.error(`Cannot extract url for event ${getEventDescription(event)}`);
    return null;
  }
}
__name(_getEventFilterUrl, "_getEventFilterUrl");
function _isUselessError(event) {
  if (event.type) {
    return false;
  }
  if (!event.exception || !event.exception.values || event.exception.values.length === 0) {
    return false;
  }
  return (
    // No top-level message
    !event.message && // There are no exception values that have a stacktrace, a non-generic-Error type or value
    !event.exception.values.some((value3) => value3.stacktrace || value3.type && value3.type !== "Error" || value3.value)
  );
}
__name(_isUselessError, "_isUselessError");
function applyAggregateErrorsToEvent(exceptionFromErrorImplementation, parser, maxValueLimit = 250, key, limit, event, hint) {
  if (!event.exception || !event.exception.values || !hint || !isInstanceOf(hint.originalException, Error)) {
    return;
  }
  const originalException = event.exception.values.length > 0 ? event.exception.values[event.exception.values.length - 1] : void 0;
  if (originalException) {
    event.exception.values = truncateAggregateExceptions(
      aggregateExceptionsFromError(
        exceptionFromErrorImplementation,
        parser,
        limit,
        hint.originalException,
        key,
        event.exception.values,
        originalException,
        0
      ),
      maxValueLimit
    );
  }
}
__name(applyAggregateErrorsToEvent, "applyAggregateErrorsToEvent");
function aggregateExceptionsFromError(exceptionFromErrorImplementation, parser, limit, error2, key, prevExceptions, exception, exceptionId) {
  if (prevExceptions.length >= limit + 1) {
    return prevExceptions;
  }
  let newExceptions = [...prevExceptions];
  if (isInstanceOf(error2[key], Error)) {
    applyExceptionGroupFieldsForParentException(exception, exceptionId);
    const newException = exceptionFromErrorImplementation(parser, error2[key]);
    const newExceptionId = newExceptions.length;
    applyExceptionGroupFieldsForChildException(newException, key, newExceptionId, exceptionId);
    newExceptions = aggregateExceptionsFromError(
      exceptionFromErrorImplementation,
      parser,
      limit,
      error2[key],
      key,
      [newException, ...newExceptions],
      newException,
      newExceptionId
    );
  }
  if (Array.isArray(error2.errors)) {
    error2.errors.forEach((childError, i2) => {
      if (isInstanceOf(childError, Error)) {
        applyExceptionGroupFieldsForParentException(exception, exceptionId);
        const newException = exceptionFromErrorImplementation(parser, childError);
        const newExceptionId = newExceptions.length;
        applyExceptionGroupFieldsForChildException(newException, `errors[${i2}]`, newExceptionId, exceptionId);
        newExceptions = aggregateExceptionsFromError(
          exceptionFromErrorImplementation,
          parser,
          limit,
          childError,
          key,
          [newException, ...newExceptions],
          newException,
          newExceptionId
        );
      }
    });
  }
  return newExceptions;
}
__name(aggregateExceptionsFromError, "aggregateExceptionsFromError");
function applyExceptionGroupFieldsForParentException(exception, exceptionId) {
  exception.mechanism = exception.mechanism || { type: "generic", handled: true };
  exception.mechanism = {
    ...exception.mechanism,
    ...exception.type === "AggregateError" && { is_exception_group: true },
    exception_id: exceptionId
  };
}
__name(applyExceptionGroupFieldsForParentException, "applyExceptionGroupFieldsForParentException");
function applyExceptionGroupFieldsForChildException(exception, source, exceptionId, parentId) {
  exception.mechanism = exception.mechanism || { type: "generic", handled: true };
  exception.mechanism = {
    ...exception.mechanism,
    type: "chained",
    source,
    exception_id: exceptionId,
    parent_id: parentId
  };
}
__name(applyExceptionGroupFieldsForChildException, "applyExceptionGroupFieldsForChildException");
function truncateAggregateExceptions(exceptions, maxValueLength) {
  return exceptions.map((exception) => {
    if (exception.value) {
      exception.value = truncate(exception.value, maxValueLength);
    }
    return exception;
  });
}
__name(truncateAggregateExceptions, "truncateAggregateExceptions");
const DEFAULT_KEY$1 = "cause";
const DEFAULT_LIMIT$2 = 5;
const INTEGRATION_NAME$j = "LinkedErrors";
const _linkedErrorsIntegration$1 = /* @__PURE__ */ __name((options5 = {}) => {
  const limit = options5.limit || DEFAULT_LIMIT$2;
  const key = options5.key || DEFAULT_KEY$1;
  return {
    name: INTEGRATION_NAME$j,
    preprocessEvent(event, hint, client) {
      const options6 = client.getOptions();
      applyAggregateErrorsToEvent(
        exceptionFromError$1,
        options6.stackParser,
        options6.maxValueLength,
        key,
        limit,
        event,
        hint
      );
    }
  };
}, "_linkedErrorsIntegration$1");
const linkedErrorsIntegration$1 = defineIntegration(_linkedErrorsIntegration$1);
const filenameMetadataMap = /* @__PURE__ */ new Map();
const parsedStacks = /* @__PURE__ */ new Set();
function ensureMetadataStacksAreParsed(parser) {
  if (!GLOBAL_OBJ._sentryModuleMetadata) {
    return;
  }
  for (const stack2 of Object.keys(GLOBAL_OBJ._sentryModuleMetadata)) {
    const metadata = GLOBAL_OBJ._sentryModuleMetadata[stack2];
    if (parsedStacks.has(stack2)) {
      continue;
    }
    parsedStacks.add(stack2);
    const frames = parser(stack2);
    for (const frame of frames.reverse()) {
      if (frame.filename) {
        filenameMetadataMap.set(frame.filename, metadata);
        break;
      }
    }
  }
}
__name(ensureMetadataStacksAreParsed, "ensureMetadataStacksAreParsed");
function getMetadataForUrl(parser, filename) {
  ensureMetadataStacksAreParsed(parser);
  return filenameMetadataMap.get(filename);
}
__name(getMetadataForUrl, "getMetadataForUrl");
function addMetadataToStackFrames(parser, event) {
  try {
    event.exception.values.forEach((exception) => {
      if (!exception.stacktrace) {
        return;
      }
      for (const frame of exception.stacktrace.frames || []) {
        if (!frame.filename || frame.module_metadata) {
          continue;
        }
        const metadata = getMetadataForUrl(parser, frame.filename);
        if (metadata) {
          frame.module_metadata = metadata;
        }
      }
    });
  } catch (_2) {
  }
}
__name(addMetadataToStackFrames, "addMetadataToStackFrames");
function stripMetadataFromStackFrames(event) {
  try {
    event.exception.values.forEach((exception) => {
      if (!exception.stacktrace) {
        return;
      }
      for (const frame of exception.stacktrace.frames || []) {
        delete frame.module_metadata;
      }
    });
  } catch (_2) {
  }
}
__name(stripMetadataFromStackFrames, "stripMetadataFromStackFrames");
const moduleMetadataIntegration = defineIntegration(() => {
  return {
    name: "ModuleMetadata",
    setup(client) {
      client.on("beforeEnvelope", (envelope) => {
        forEachEnvelopeItem(envelope, (item3, type) => {
          if (type === "event") {
            const event = Array.isArray(item3) ? item3[1] : void 0;
            if (event) {
              stripMetadataFromStackFrames(event);
              item3[1] = event;
            }
          }
        });
      });
      client.on("applyFrameMetadata", (event) => {
        if (event.type) {
          return;
        }
        const stackParser = client.getOptions().stackParser;
        addMetadataToStackFrames(stackParser, event);
      });
    }
  };
});
function parseCookie(str) {
  const obj = {};
  let index2 = 0;
  while (index2 < str.length) {
    const eqIdx = str.indexOf("=", index2);
    if (eqIdx === -1) {
      break;
    }
    let endIdx = str.indexOf(";", index2);
    if (endIdx === -1) {
      endIdx = str.length;
    } else if (endIdx < eqIdx) {
      index2 = str.lastIndexOf(";", eqIdx - 1) + 1;
      continue;
    }
    const key = str.slice(index2, eqIdx).trim();
    if (void 0 === obj[key]) {
      let val = str.slice(eqIdx + 1, endIdx).trim();
      if (val.charCodeAt(0) === 34) {
        val = val.slice(1, -1);
      }
      try {
        obj[key] = val.indexOf("%") !== -1 ? decodeURIComponent(val) : val;
      } catch (e2) {
        obj[key] = val;
      }
    }
    index2 = endIdx + 1;
  }
  return obj;
}
__name(parseCookie, "parseCookie");
function parseUrl$1(url) {
  if (!url) {
    return {};
  }
  const match2 = url.match(/^(([^:/?#]+):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?$/);
  if (!match2) {
    return {};
  }
  const query = match2[6] || "";
  const fragment = match2[8] || "";
  return {
    host: match2[4],
    path: match2[5],
    protocol: match2[2],
    search: query,
    hash: fragment,
    relative: match2[5] + query + fragment
    // everything minus origin
  };
}
__name(parseUrl$1, "parseUrl$1");
function stripUrlQueryAndFragment(urlPath) {
  return urlPath.split(/[?#]/, 1)[0];
}
__name(stripUrlQueryAndFragment, "stripUrlQueryAndFragment");
function getNumberOfUrlSegments(url) {
  return url.split(/\\?\//).filter((s2) => s2.length > 0 && s2 !== ",").length;
}
__name(getNumberOfUrlSegments, "getNumberOfUrlSegments");
function getSanitizedUrlString(url) {
  const { protocol, host, path } = url;
  const filteredHost = host && host.replace(/^.*@/, "[filtered]:[filtered]@").replace(/(:80)$/, "").replace(/(:443)$/, "") || "";
  return `${protocol ? `${protocol}://` : ""}${filteredHost}${path}`;
}
__name(getSanitizedUrlString, "getSanitizedUrlString");
const ipHeaderNames = [
  "X-Client-IP",
  "X-Forwarded-For",
  "Fly-Client-IP",
  "CF-Connecting-IP",
  "Fastly-Client-Ip",
  "True-Client-Ip",
  "X-Real-IP",
  "X-Cluster-Client-IP",
  "X-Forwarded",
  "Forwarded-For",
  "Forwarded",
  "X-Vercel-Forwarded-For"
];
function getClientIPAddress(headers) {
  const headerValues = ipHeaderNames.map((headerName) => {
    const rawValue = headers[headerName];
    const value3 = Array.isArray(rawValue) ? rawValue.join(";") : rawValue;
    if (headerName === "Forwarded") {
      return parseForwardedHeader(value3);
    }
    return value3 && value3.split(",").map((v2) => v2.trim());
  });
  const flattenedHeaderValues = headerValues.reduce((acc, val) => {
    if (!val) {
      return acc;
    }
    return acc.concat(val);
  }, []);
  const ipAddress = flattenedHeaderValues.find((ip) => ip !== null && isIP(ip));
  return ipAddress || null;
}
__name(getClientIPAddress, "getClientIPAddress");
function parseForwardedHeader(value3) {
  if (!value3) {
    return null;
  }
  for (const part of value3.split(";")) {
    if (part.startsWith("for=")) {
      return part.slice(4);
    }
  }
  return null;
}
__name(parseForwardedHeader, "parseForwardedHeader");
function isIP(str) {
  const regex2 = /(?:^(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}$)|(?:^(?:(?:[a-fA-F\d]{1,4}:){7}(?:[a-fA-F\d]{1,4}|:)|(?:[a-fA-F\d]{1,4}:){6}(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|:[a-fA-F\d]{1,4}|:)|(?:[a-fA-F\d]{1,4}:){5}(?::(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,2}|:)|(?:[a-fA-F\d]{1,4}:){4}(?:(?::[a-fA-F\d]{1,4}){0,1}:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,3}|:)|(?:[a-fA-F\d]{1,4}:){3}(?:(?::[a-fA-F\d]{1,4}){0,2}:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,4}|:)|(?:[a-fA-F\d]{1,4}:){2}(?:(?::[a-fA-F\d]{1,4}){0,3}:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,5}|:)|(?:[a-fA-F\d]{1,4}:){1}(?:(?::[a-fA-F\d]{1,4}){0,4}:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,6}|:)|(?::(?:(?::[a-fA-F\d]{1,4}){0,5}:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)(?:\\.(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)){3}|(?::[a-fA-F\d]{1,4}){1,7}|:)))(?:%[0-9a-zA-Z]{1,})?$)/;
  return regex2.test(str);
}
__name(isIP, "isIP");
const DEFAULT_INCLUDES = {
  ip: false,
  request: true,
  user: true
};
const DEFAULT_REQUEST_INCLUDES = ["cookies", "data", "headers", "method", "query_string", "url"];
const DEFAULT_USER_INCLUDES = ["id", "username", "email"];
function extractPathForTransaction(req, options5 = {}) {
  const method = req.method && req.method.toUpperCase();
  let path = "";
  let source = "url";
  if (options5.customRoute || req.route) {
    path = options5.customRoute || `${req.baseUrl || ""}${req.route && req.route.path}`;
    source = "route";
  } else if (req.originalUrl || req.url) {
    path = stripUrlQueryAndFragment(req.originalUrl || req.url || "");
  }
  let name2 = "";
  if (options5.method && method) {
    name2 += method;
  }
  if (options5.method && options5.path) {
    name2 += " ";
  }
  if (options5.path && path) {
    name2 += path;
  }
  return [name2, source];
}
__name(extractPathForTransaction, "extractPathForTransaction");
function extractUserData(user, keys2) {
  const extractedUser = {};
  const attributes = Array.isArray(keys2) ? keys2 : DEFAULT_USER_INCLUDES;
  attributes.forEach((key) => {
    if (user && key in user) {
      extractedUser[key] = user[key];
    }
  });
  return extractedUser;
}
__name(extractUserData, "extractUserData");
function extractRequestData(req, options5 = {}) {
  const { include = DEFAULT_REQUEST_INCLUDES } = options5;
  const requestData = {};
  const headers = req.headers || {};
  const method = req.method;
  const host = headers.host || req.hostname || req.host || "<no host>";
  const protocol = req.protocol === "https" || req.socket && req.socket.encrypted ? "https" : "http";
  const originalUrl = req.originalUrl || req.url || "";
  const absoluteUrl = originalUrl.startsWith(protocol) ? originalUrl : `${protocol}://${host}${originalUrl}`;
  include.forEach((key) => {
    switch (key) {
      case "headers": {
        requestData.headers = headers;
        if (!include.includes("cookies")) {
          delete requestData.headers.cookie;
        }
        if (!include.includes("ip")) {
          ipHeaderNames.forEach((ipHeaderName) => {
            delete requestData.headers[ipHeaderName];
          });
        }
        break;
      }
      case "method": {
        requestData.method = method;
        break;
      }
      case "url": {
        requestData.url = absoluteUrl;
        break;
      }
      case "cookies": {
        requestData.cookies = // TODO (v8 / #5257): We're only sending the empty object for backwards compatibility, so the last bit can
        // come off in v8
        req.cookies || headers.cookie && parseCookie(headers.cookie) || {};
        break;
      }
      case "query_string": {
        requestData.query_string = extractQueryParams(req);
        break;
      }
      case "data": {
        if (method === "GET" || method === "HEAD") {
          break;
        }
        const body = req.body;
        if (body !== void 0) {
          const stringBody = isString$a(body) ? body : isPlainObject$5(body) ? JSON.stringify(normalize$2(body)) : truncate(`${body}`, 1024);
          if (stringBody) {
            requestData.data = stringBody;
          }
        }
        break;
      }
      default: {
        if ({}.hasOwnProperty.call(req, key)) {
          requestData[key] = req[key];
        }
      }
    }
  });
  return requestData;
}
__name(extractRequestData, "extractRequestData");
function addNormalizedRequestDataToEvent(event, req, additionalData, options5) {
  const include = {
    ...DEFAULT_INCLUDES,
    ...options5 && options5.include
  };
  if (include.request) {
    const includeRequest = Array.isArray(include.request) ? [...include.request] : [...DEFAULT_REQUEST_INCLUDES];
    if (include.ip) {
      includeRequest.push("ip");
    }
    const extractedRequestData = extractNormalizedRequestData(req, { include: includeRequest });
    event.request = {
      ...event.request,
      ...extractedRequestData
    };
  }
  if (include.user) {
    const extractedUser = additionalData.user && isPlainObject$5(additionalData.user) ? extractUserData(additionalData.user, include.user) : {};
    if (Object.keys(extractedUser).length) {
      event.user = {
        ...extractedUser,
        ...event.user
      };
    }
  }
  if (include.ip) {
    const ip = req.headers && getClientIPAddress(req.headers) || additionalData.ipAddress;
    if (ip) {
      event.user = {
        ...event.user,
        ip_address: ip
      };
    }
  }
}
__name(addNormalizedRequestDataToEvent, "addNormalizedRequestDataToEvent");
function addRequestDataToEvent(event, req, options5) {
  const include = {
    ...DEFAULT_INCLUDES,
    ...options5 && options5.include
  };
  if (include.request) {
    const includeRequest = Array.isArray(include.request) ? [...include.request] : [...DEFAULT_REQUEST_INCLUDES];
    if (include.ip) {
      includeRequest.push("ip");
    }
    const extractedRequestData = extractRequestData(req, { include: includeRequest });
    event.request = {
      ...event.request,
      ...extractedRequestData
    };
  }
  if (include.user) {
    const extractedUser = req.user && isPlainObject$5(req.user) ? extractUserData(req.user, include.user) : {};
    if (Object.keys(extractedUser).length) {
      event.user = {
        ...event.user,
        ...extractedUser
      };
    }
  }
  if (include.ip) {
    const ip = req.headers && getClientIPAddress(req.headers) || req.ip || req.socket && req.socket.remoteAddress;
    if (ip) {
      event.user = {
        ...event.user,
        ip_address: ip
      };
    }
  }
  return event;
}
__name(addRequestDataToEvent, "addRequestDataToEvent");
function extractQueryParams(req) {
  let originalUrl = req.originalUrl || req.url || "";
  if (!originalUrl) {
    return;
  }
  if (originalUrl.startsWith("/")) {
    originalUrl = `http://dogs.are.great${originalUrl}`;
  }
  try {
    const queryParams = req.query || new URL(originalUrl).search.slice(1);
    return queryParams.length ? queryParams : void 0;
  } catch (e2) {
    return void 0;
  }
}
__name(extractQueryParams, "extractQueryParams");
function winterCGHeadersToDict(winterCGHeaders) {
  const headers = {};
  try {
    winterCGHeaders.forEach((value3, key) => {
      if (typeof value3 === "string") {
        headers[key] = value3;
      }
    });
  } catch (e2) {
    DEBUG_BUILD$5 && logger$2.warn("Sentry failed extracting headers from a request object. If you see this, please file an issue.");
  }
  return headers;
}
__name(winterCGHeadersToDict, "winterCGHeadersToDict");
function headersToDict(reqHeaders) {
  const headers = /* @__PURE__ */ Object.create(null);
  try {
    Object.entries(reqHeaders).forEach(([key, value3]) => {
      if (typeof value3 === "string") {
        headers[key] = value3;
      }
    });
  } catch (e2) {
    DEBUG_BUILD$5 && logger$2.warn("Sentry failed extracting headers from a request object. If you see this, please file an issue.");
  }
  return headers;
}
__name(headersToDict, "headersToDict");
function winterCGRequestToRequestData(req) {
  const headers = winterCGHeadersToDict(req.headers);
  return {
    method: req.method,
    url: req.url,
    query_string: extractQueryParamsFromUrl(req.url),
    headers
    // TODO: Can we extract body data from the request?
  };
}
__name(winterCGRequestToRequestData, "winterCGRequestToRequestData");
function httpRequestToRequestData(request) {
  const headers = request.headers || {};
  const host = headers.host || "<no host>";
  const protocol = request.socket && request.socket.encrypted ? "https" : "http";
  const originalUrl = request.url || "";
  const absoluteUrl = originalUrl.startsWith(protocol) ? originalUrl : `${protocol}://${host}${originalUrl}`;
  const data30 = request.body || void 0;
  const cookies2 = request.cookies;
  return dropUndefinedKeys({
    url: absoluteUrl,
    method: request.method,
    query_string: extractQueryParamsFromUrl(originalUrl),
    headers: headersToDict(headers),
    cookies: cookies2,
    data: data30
  });
}
__name(httpRequestToRequestData, "httpRequestToRequestData");
function extractQueryParamsFromUrl(url) {
  if (!url) {
    return;
  }
  try {
    const queryParams = new URL(url, "http://dogs.are.great").search.slice(1);
    return queryParams.length ? queryParams : void 0;
  } catch (e3) {
    return void 0;
  }
}
__name(extractQueryParamsFromUrl, "extractQueryParamsFromUrl");
function extractNormalizedRequestData(normalizedRequest, { include }) {
  const includeKeys = include ? Array.isArray(include) ? include : DEFAULT_REQUEST_INCLUDES : [];
  const requestData = {};
  const headers = { ...normalizedRequest.headers };
  if (includeKeys.includes("headers")) {
    requestData.headers = headers;
    if (!include.includes("cookies")) {
      delete headers.cookie;
    }
    if (!include.includes("ip")) {
      ipHeaderNames.forEach((ipHeaderName) => {
        delete headers[ipHeaderName];
      });
    }
  }
  if (includeKeys.includes("method")) {
    requestData.method = normalizedRequest.method;
  }
  if (includeKeys.includes("url")) {
    requestData.url = normalizedRequest.url;
  }
  if (includeKeys.includes("cookies")) {
    const cookies2 = normalizedRequest.cookies || (headers && headers.cookie ? parseCookie(headers.cookie) : void 0);
    requestData.cookies = cookies2 || {};
  }
  if (includeKeys.includes("query_string")) {
    requestData.query_string = normalizedRequest.query_string;
  }
  if (includeKeys.includes("data")) {
    requestData.data = normalizedRequest.data;
  }
  return requestData;
}
__name(extractNormalizedRequestData, "extractNormalizedRequestData");
const DEFAULT_OPTIONS$1 = {
  include: {
    cookies: true,
    data: true,
    headers: true,
    ip: false,
    query_string: true,
    url: true,
    user: {
      id: true,
      username: true,
      email: true
    }
  },
  transactionNamingScheme: "methodPath"
};
const INTEGRATION_NAME$i = "RequestData";
const _requestDataIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    ...DEFAULT_OPTIONS$1,
    ...options5,
    include: {
      ...DEFAULT_OPTIONS$1.include,
      ...options5.include,
      user: options5.include && typeof options5.include.user === "boolean" ? options5.include.user : {
        ...DEFAULT_OPTIONS$1.include.user,
        // Unclear why TS still thinks `options.include.user` could be a boolean at this point
        ...(options5.include || {}).user
      }
    }
  };
  return {
    name: INTEGRATION_NAME$i,
    processEvent(event) {
      const { sdkProcessingMetadata = {} } = event;
      const { request, normalizedRequest } = sdkProcessingMetadata;
      const addRequestDataOptions = convertReqDataIntegrationOptsToAddReqDataOpts(_options);
      if (normalizedRequest) {
        const ipAddress = request ? request.ip || request.socket && request.socket.remoteAddress : void 0;
        const user = request ? request.user : void 0;
        addNormalizedRequestDataToEvent(event, normalizedRequest, { ipAddress, user }, addRequestDataOptions);
        return event;
      }
      if (!request) {
        return event;
      }
      return addRequestDataToEvent(event, request, addRequestDataOptions);
    }
  };
}, "_requestDataIntegration");
const requestDataIntegration = defineIntegration(_requestDataIntegration);
function convertReqDataIntegrationOptsToAddReqDataOpts(integrationOptions) {
  const {
    // eslint-disable-next-line deprecation/deprecation
    transactionNamingScheme,
    include: { ip, user, ...requestOptions }
  } = integrationOptions;
  const requestIncludeKeys = ["method"];
  for (const [key, value3] of Object.entries(requestOptions)) {
    if (value3) {
      requestIncludeKeys.push(key);
    }
  }
  let addReqDataUserOpt;
  if (user === void 0) {
    addReqDataUserOpt = true;
  } else if (typeof user === "boolean") {
    addReqDataUserOpt = user;
  } else {
    const userIncludeKeys = [];
    for (const [key, value3] of Object.entries(user)) {
      if (value3) {
        userIncludeKeys.push(key);
      }
    }
    addReqDataUserOpt = userIncludeKeys;
  }
  return {
    include: {
      ip,
      user: addReqDataUserOpt,
      request: requestIncludeKeys.length !== 0 ? requestIncludeKeys : void 0,
      transaction: transactionNamingScheme
    }
  };
}
__name(convertReqDataIntegrationOptsToAddReqDataOpts, "convertReqDataIntegrationOptsToAddReqDataOpts");
function addConsoleInstrumentationHandler(handler14) {
  const type = "console";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentConsole);
}
__name(addConsoleInstrumentationHandler, "addConsoleInstrumentationHandler");
function instrumentConsole() {
  if (!("console" in GLOBAL_OBJ)) {
    return;
  }
  CONSOLE_LEVELS$1.forEach(function(level) {
    if (!(level in GLOBAL_OBJ.console)) {
      return;
    }
    fill(GLOBAL_OBJ.console, level, function(originalConsoleMethod) {
      originalConsoleMethods[level] = originalConsoleMethod;
      return function(...args) {
        const handlerData = { args, level };
        triggerHandlers$1("console", handlerData);
        const log2 = originalConsoleMethods[level];
        log2 && log2.apply(GLOBAL_OBJ.console, args);
      };
    });
  });
}
__name(instrumentConsole, "instrumentConsole");
const validSeverityLevels = ["fatal", "error", "warning", "log", "info", "debug"];
function severityLevelFromString(level) {
  return level === "warn" ? "warning" : ["fatal", "error", "warning", "log", "info", "debug"].includes(level) ? level : "log";
}
__name(severityLevelFromString, "severityLevelFromString");
const INTEGRATION_NAME$h = "CaptureConsole";
const _captureConsoleIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const levels = options5.levels || CONSOLE_LEVELS$1;
  const handled = !!options5.handled;
  return {
    name: INTEGRATION_NAME$h,
    setup(client) {
      if (!("console" in GLOBAL_OBJ)) {
        return;
      }
      addConsoleInstrumentationHandler(({ args, level }) => {
        if (getClient() !== client || !levels.includes(level)) {
          return;
        }
        consoleHandler(args, level, handled);
      });
    }
  };
}, "_captureConsoleIntegration");
const captureConsoleIntegration = defineIntegration(_captureConsoleIntegration);
function consoleHandler(args, level, handled) {
  const captureContext = {
    level: severityLevelFromString(level),
    extra: {
      arguments: args
    }
  };
  withScope((scope) => {
    scope.addEventProcessor((event) => {
      event.logger = "console";
      addExceptionMechanism(event, {
        handled,
        type: "console"
      });
      return event;
    });
    if (level === "assert") {
      if (!args[0]) {
        const message4 = `Assertion failed: ${safeJoin(args.slice(1), " ") || "console.assert"}`;
        scope.setExtra("arguments", args.slice(1));
        captureMessage(message4, captureContext);
      }
      return;
    }
    const error2 = args.find((arg) => arg instanceof Error);
    if (error2) {
      captureException(error2, captureContext);
      return;
    }
    const message3 = safeJoin(args, " ");
    captureMessage(message3, captureContext);
  });
}
__name(consoleHandler, "consoleHandler");
const INTEGRATION_NAME$g = "Debug";
const _debugIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    debugger: false,
    stringify: false,
    ...options5
  };
  return {
    name: INTEGRATION_NAME$g,
    setup(client) {
      client.on("beforeSendEvent", (event, hint) => {
        if (_options.debugger) {
          debugger;
        }
        consoleSandbox(() => {
          if (_options.stringify) {
            console.log(JSON.stringify(event, null, 2));
            if (hint && Object.keys(hint).length) {
              console.log(JSON.stringify(hint, null, 2));
            }
          } else {
            console.log(event);
            if (hint && Object.keys(hint).length) {
              console.log(hint);
            }
          }
        });
      });
    }
  };
}, "_debugIntegration");
const debugIntegration = defineIntegration(_debugIntegration);
const INTEGRATION_NAME$f = "Dedupe";
const _dedupeIntegration = /* @__PURE__ */ __name(() => {
  let previousEvent;
  return {
    name: INTEGRATION_NAME$f,
    processEvent(currentEvent) {
      if (currentEvent.type) {
        return currentEvent;
      }
      try {
        if (_shouldDropEvent(currentEvent, previousEvent)) {
          DEBUG_BUILD$6 && logger$2.warn("Event dropped due to being a duplicate of previously captured event.");
          return null;
        }
      } catch (_oO) {
      }
      return previousEvent = currentEvent;
    }
  };
}, "_dedupeIntegration");
const dedupeIntegration = defineIntegration(_dedupeIntegration);
function _shouldDropEvent(currentEvent, previousEvent) {
  if (!previousEvent) {
    return false;
  }
  if (_isSameMessageEvent(currentEvent, previousEvent)) {
    return true;
  }
  if (_isSameExceptionEvent(currentEvent, previousEvent)) {
    return true;
  }
  return false;
}
__name(_shouldDropEvent, "_shouldDropEvent");
function _isSameMessageEvent(currentEvent, previousEvent) {
  const currentMessage = currentEvent.message;
  const previousMessage = previousEvent.message;
  if (!currentMessage && !previousMessage) {
    return false;
  }
  if (currentMessage && !previousMessage || !currentMessage && previousMessage) {
    return false;
  }
  if (currentMessage !== previousMessage) {
    return false;
  }
  if (!_isSameFingerprint(currentEvent, previousEvent)) {
    return false;
  }
  if (!_isSameStacktrace(currentEvent, previousEvent)) {
    return false;
  }
  return true;
}
__name(_isSameMessageEvent, "_isSameMessageEvent");
function _isSameExceptionEvent(currentEvent, previousEvent) {
  const previousException = _getExceptionFromEvent(previousEvent);
  const currentException = _getExceptionFromEvent(currentEvent);
  if (!previousException || !currentException) {
    return false;
  }
  if (previousException.type !== currentException.type || previousException.value !== currentException.value) {
    return false;
  }
  if (!_isSameFingerprint(currentEvent, previousEvent)) {
    return false;
  }
  if (!_isSameStacktrace(currentEvent, previousEvent)) {
    return false;
  }
  return true;
}
__name(_isSameExceptionEvent, "_isSameExceptionEvent");
function _isSameStacktrace(currentEvent, previousEvent) {
  let currentFrames = getFramesFromEvent(currentEvent);
  let previousFrames = getFramesFromEvent(previousEvent);
  if (!currentFrames && !previousFrames) {
    return true;
  }
  if (currentFrames && !previousFrames || !currentFrames && previousFrames) {
    return false;
  }
  currentFrames = currentFrames;
  previousFrames = previousFrames;
  if (previousFrames.length !== currentFrames.length) {
    return false;
  }
  for (let i2 = 0; i2 < previousFrames.length; i2++) {
    const frameA = previousFrames[i2];
    const frameB = currentFrames[i2];
    if (frameA.filename !== frameB.filename || frameA.lineno !== frameB.lineno || frameA.colno !== frameB.colno || frameA.function !== frameB.function) {
      return false;
    }
  }
  return true;
}
__name(_isSameStacktrace, "_isSameStacktrace");
function _isSameFingerprint(currentEvent, previousEvent) {
  let currentFingerprint = currentEvent.fingerprint;
  let previousFingerprint = previousEvent.fingerprint;
  if (!currentFingerprint && !previousFingerprint) {
    return true;
  }
  if (currentFingerprint && !previousFingerprint || !currentFingerprint && previousFingerprint) {
    return false;
  }
  currentFingerprint = currentFingerprint;
  previousFingerprint = previousFingerprint;
  try {
    return !!(currentFingerprint.join("") === previousFingerprint.join(""));
  } catch (_oO) {
    return false;
  }
}
__name(_isSameFingerprint, "_isSameFingerprint");
function _getExceptionFromEvent(event) {
  return event.exception && event.exception.values && event.exception.values[0];
}
__name(_getExceptionFromEvent, "_getExceptionFromEvent");
const INTEGRATION_NAME$e = "ExtraErrorData";
const _extraErrorDataIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const { depth = 3, captureErrorCause = true } = options5;
  return {
    name: INTEGRATION_NAME$e,
    processEvent(event, hint, client) {
      const { maxValueLength = 250 } = client.getOptions();
      return _enhanceEventWithErrorData(event, hint, depth, captureErrorCause, maxValueLength);
    }
  };
}, "_extraErrorDataIntegration");
const extraErrorDataIntegration = defineIntegration(_extraErrorDataIntegration);
function _enhanceEventWithErrorData(event, hint = {}, depth, captureErrorCause, maxValueLength) {
  if (!hint.originalException || !isError(hint.originalException)) {
    return event;
  }
  const exceptionName = hint.originalException.name || hint.originalException.constructor.name;
  const errorData = _extractErrorData(hint.originalException, captureErrorCause, maxValueLength);
  if (errorData) {
    const contexts = {
      ...event.contexts
    };
    const normalizedErrorData = normalize$2(errorData, depth);
    if (isPlainObject$5(normalizedErrorData)) {
      addNonEnumerableProperty(normalizedErrorData, "__sentry_skip_normalization__", true);
      contexts[exceptionName] = normalizedErrorData;
    }
    return {
      ...event,
      contexts
    };
  }
  return event;
}
__name(_enhanceEventWithErrorData, "_enhanceEventWithErrorData");
function _extractErrorData(error2, captureErrorCause, maxValueLength) {
  try {
    const nativeKeys2 = [
      "name",
      "message",
      "stack",
      "line",
      "column",
      "fileName",
      "lineNumber",
      "columnNumber",
      "toJSON"
    ];
    const extraErrorInfo = {};
    for (const key of Object.keys(error2)) {
      if (nativeKeys2.indexOf(key) !== -1) {
        continue;
      }
      const value3 = error2[key];
      extraErrorInfo[key] = isError(value3) || typeof value3 === "string" ? truncate(`${value3}`, maxValueLength) : value3;
    }
    if (captureErrorCause && error2.cause !== void 0) {
      extraErrorInfo.cause = isError(error2.cause) ? error2.cause.toString() : error2.cause;
    }
    if (typeof error2.toJSON === "function") {
      const serializedError = error2.toJSON();
      for (const key of Object.keys(serializedError)) {
        const value3 = serializedError[key];
        extraErrorInfo[key] = isError(value3) ? value3.toString() : value3;
      }
    }
    return extraErrorInfo;
  } catch (oO) {
    DEBUG_BUILD$6 && logger$2.error("Unable to extract extra data from the Error object:", oO);
  }
  return null;
}
__name(_extractErrorData, "_extractErrorData");
function normalizeArray(parts2, allowAboveRoot) {
  let up = 0;
  for (let i2 = parts2.length - 1; i2 >= 0; i2--) {
    const last = parts2[i2];
    if (last === ".") {
      parts2.splice(i2, 1);
    } else if (last === "..") {
      parts2.splice(i2, 1);
      up++;
    } else if (up) {
      parts2.splice(i2, 1);
      up--;
    }
  }
  if (allowAboveRoot) {
    for (; up--; up) {
      parts2.unshift("..");
    }
  }
  return parts2;
}
__name(normalizeArray, "normalizeArray");
const splitPathRe = /^(\S+:\\|\/?)([\s\S]*?)((?:\.{1,2}|[^/\\]+?|)(\.[^./\\]*|))(?:[/\\]*)$/;
function splitPath(filename) {
  const truncated = filename.length > 1024 ? `<truncated>${filename.slice(-1024)}` : filename;
  const parts2 = splitPathRe.exec(truncated);
  return parts2 ? parts2.slice(1) : [];
}
__name(splitPath, "splitPath");
function resolve$3(...args) {
  let resolvedPath = "";
  let resolvedAbsolute = false;
  for (let i2 = args.length - 1; i2 >= -1 && !resolvedAbsolute; i2--) {
    const path = i2 >= 0 ? args[i2] : "/";
    if (!path) {
      continue;
    }
    resolvedPath = `${path}/${resolvedPath}`;
    resolvedAbsolute = path.charAt(0) === "/";
  }
  resolvedPath = normalizeArray(
    resolvedPath.split("/").filter((p2) => !!p2),
    !resolvedAbsolute
  ).join("/");
  return (resolvedAbsolute ? "/" : "") + resolvedPath || ".";
}
__name(resolve$3, "resolve$3");
function trim$1(arr) {
  let start2 = 0;
  for (; start2 < arr.length; start2++) {
    if (arr[start2] !== "") {
      break;
    }
  }
  let end = arr.length - 1;
  for (; end >= 0; end--) {
    if (arr[end] !== "") {
      break;
    }
  }
  if (start2 > end) {
    return [];
  }
  return arr.slice(start2, end - start2 + 1);
}
__name(trim$1, "trim$1");
function relative(from2, to) {
  from2 = resolve$3(from2).slice(1);
  to = resolve$3(to).slice(1);
  const fromParts = trim$1(from2.split("/"));
  const toParts = trim$1(to.split("/"));
  const length = Math.min(fromParts.length, toParts.length);
  let samePartsLength = length;
  for (let i2 = 0; i2 < length; i2++) {
    if (fromParts[i2] !== toParts[i2]) {
      samePartsLength = i2;
      break;
    }
  }
  let outputParts = [];
  for (let i2 = samePartsLength; i2 < fromParts.length; i2++) {
    outputParts.push("..");
  }
  outputParts = outputParts.concat(toParts.slice(samePartsLength));
  return outputParts.join("/");
}
__name(relative, "relative");
function normalizePath(path) {
  const isPathAbsolute = isAbsolute(path);
  const trailingSlash = path.slice(-1) === "/";
  let normalizedPath = normalizeArray(
    path.split("/").filter((p2) => !!p2),
    !isPathAbsolute
  ).join("/");
  if (!normalizedPath && !isPathAbsolute) {
    normalizedPath = ".";
  }
  if (normalizedPath && trailingSlash) {
    normalizedPath += "/";
  }
  return (isPathAbsolute ? "/" : "") + normalizedPath;
}
__name(normalizePath, "normalizePath");
function isAbsolute(path) {
  return path.charAt(0) === "/";
}
__name(isAbsolute, "isAbsolute");
function join$3(...args) {
  return normalizePath(args.join("/"));
}
__name(join$3, "join$3");
function dirname(path) {
  const result = splitPath(path);
  const root34 = result[0] || "";
  let dir = result[1];
  if (!root34 && !dir) {
    return ".";
  }
  if (dir) {
    dir = dir.slice(0, dir.length - 1);
  }
  return root34 + dir;
}
__name(dirname, "dirname");
function basename(path, ext) {
  let f2 = splitPath(path)[2] || "";
  if (ext && f2.slice(ext.length * -1) === ext) {
    f2 = f2.slice(0, f2.length - ext.length);
  }
  return f2;
}
__name(basename, "basename");
const INTEGRATION_NAME$d = "RewriteFrames";
const rewriteFramesIntegration = defineIntegration((options5 = {}) => {
  const root34 = options5.root;
  const prefix2 = options5.prefix || "app:///";
  const isBrowser2 = "window" in GLOBAL_OBJ && GLOBAL_OBJ.window !== void 0;
  const iteratee = options5.iteratee || generateIteratee({ isBrowser: isBrowser2, root: root34, prefix: prefix2 });
  function _processExceptionsEvent(event) {
    try {
      return {
        ...event,
        exception: {
          ...event.exception,
          // The check for this is performed inside `process` call itself, safe to skip here
          // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
          values: event.exception.values.map((value3) => ({
            ...value3,
            ...value3.stacktrace && { stacktrace: _processStacktrace(value3.stacktrace) }
          }))
        }
      };
    } catch (_oO) {
      return event;
    }
  }
  __name(_processExceptionsEvent, "_processExceptionsEvent");
  function _processStacktrace(stacktrace) {
    return {
      ...stacktrace,
      frames: stacktrace && stacktrace.frames && stacktrace.frames.map((f2) => iteratee(f2))
    };
  }
  __name(_processStacktrace, "_processStacktrace");
  return {
    name: INTEGRATION_NAME$d,
    processEvent(originalEvent) {
      let processedEvent = originalEvent;
      if (originalEvent.exception && Array.isArray(originalEvent.exception.values)) {
        processedEvent = _processExceptionsEvent(processedEvent);
      }
      return processedEvent;
    }
  };
});
function generateIteratee({
  isBrowser: isBrowser2,
  root: root34,
  prefix: prefix2
}) {
  return (frame) => {
    if (!frame.filename) {
      return frame;
    }
    const isWindowsFrame = /^[a-zA-Z]:\\/.test(frame.filename) || // or the presence of a backslash without a forward slash (which are not allowed on Windows)
    frame.filename.includes("\\") && !frame.filename.includes("/");
    const startsWithSlash = /^\//.test(frame.filename);
    if (isBrowser2) {
      if (root34) {
        const oldFilename = frame.filename;
        if (oldFilename.indexOf(root34) === 0) {
          frame.filename = oldFilename.replace(root34, prefix2);
        }
      }
    } else {
      if (isWindowsFrame || startsWithSlash) {
        const filename = isWindowsFrame ? frame.filename.replace(/^[a-zA-Z]:/, "").replace(/\\/g, "/") : frame.filename;
        const base2 = root34 ? relative(root34, filename) : basename(filename);
        frame.filename = `${prefix2}${base2}`;
      }
    }
    return frame;
  };
}
__name(generateIteratee, "generateIteratee");
const INTEGRATION_NAME$c = "SessionTiming";
const _sessionTimingIntegration = /* @__PURE__ */ __name(() => {
  const startTime = timestampInSeconds() * 1e3;
  return {
    name: INTEGRATION_NAME$c,
    processEvent(event) {
      const now2 = timestampInSeconds() * 1e3;
      return {
        ...event,
        extra: {
          ...event.extra,
          ["session:start"]: startTime,
          ["session:duration"]: now2 - startTime,
          ["session:end"]: now2
        }
      };
    }
  };
}, "_sessionTimingIntegration");
const sessionTimingIntegration = defineIntegration(_sessionTimingIntegration);
const DEFAULT_LIMIT$1 = 10;
const INTEGRATION_NAME$b = "ZodErrors";
function originalExceptionIsZodError(originalException) {
  return isError(originalException) && originalException.name === "ZodError" && Array.isArray(originalException.errors);
}
__name(originalExceptionIsZodError, "originalExceptionIsZodError");
function formatIssueTitle(issue) {
  return {
    ...issue,
    path: "path" in issue && Array.isArray(issue.path) ? issue.path.join(".") : void 0,
    keys: "keys" in issue ? JSON.stringify(issue.keys) : void 0,
    unionErrors: "unionErrors" in issue ? JSON.stringify(issue.unionErrors) : void 0
  };
}
__name(formatIssueTitle, "formatIssueTitle");
function formatIssueMessage(zodError) {
  const errorKeyMap = /* @__PURE__ */ new Set();
  for (const iss of zodError.issues) {
    if (iss.path && iss.path[0]) {
      errorKeyMap.add(iss.path[0]);
    }
  }
  const errorKeys = Array.from(errorKeyMap);
  return `Failed to validate keys: ${truncate(errorKeys.join(", "), 100)}`;
}
__name(formatIssueMessage, "formatIssueMessage");
function applyZodErrorsToEvent(limit, event, hint) {
  if (!event.exception || !event.exception.values || !hint || !hint.originalException || !originalExceptionIsZodError(hint.originalException) || hint.originalException.issues.length === 0) {
    return event;
  }
  return {
    ...event,
    exception: {
      ...event.exception,
      values: [
        {
          ...event.exception.values[0],
          value: formatIssueMessage(hint.originalException)
        },
        ...event.exception.values.slice(1)
      ]
    },
    extra: {
      ...event.extra,
      "zoderror.issues": hint.originalException.errors.slice(0, limit).map(formatIssueTitle)
    }
  };
}
__name(applyZodErrorsToEvent, "applyZodErrorsToEvent");
const _zodErrorsIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const limit = options5.limit || DEFAULT_LIMIT$1;
  return {
    name: INTEGRATION_NAME$b,
    processEvent(originalEvent, hint) {
      const processedEvent = applyZodErrorsToEvent(limit, originalEvent, hint);
      return processedEvent;
    }
  };
}, "_zodErrorsIntegration");
const zodErrorsIntegration = defineIntegration(_zodErrorsIntegration);
const thirdPartyErrorFilterIntegration = defineIntegration((options5) => {
  return {
    name: "ThirdPartyErrorsFilter",
    setup(client) {
      client.on("beforeEnvelope", (envelope) => {
        forEachEnvelopeItem(envelope, (item3, type) => {
          if (type === "event") {
            const event = Array.isArray(item3) ? item3[1] : void 0;
            if (event) {
              stripMetadataFromStackFrames(event);
              item3[1] = event;
            }
          }
        });
      });
      client.on("applyFrameMetadata", (event) => {
        if (event.type) {
          return;
        }
        const stackParser = client.getOptions().stackParser;
        addMetadataToStackFrames(stackParser, event);
      });
    },
    processEvent(event) {
      const frameKeys = getBundleKeysForAllFramesWithFilenames(event);
      if (frameKeys) {
        const arrayMethod = options5.behaviour === "drop-error-if-contains-third-party-frames" || options5.behaviour === "apply-tag-if-contains-third-party-frames" ? "some" : "every";
        const behaviourApplies = frameKeys[arrayMethod]((keys2) => !keys2.some((key) => options5.filterKeys.includes(key)));
        if (behaviourApplies) {
          const shouldDrop = options5.behaviour === "drop-error-if-contains-third-party-frames" || options5.behaviour === "drop-error-if-exclusively-contains-third-party-frames";
          if (shouldDrop) {
            return null;
          } else {
            event.tags = {
              ...event.tags,
              third_party_code: true
            };
          }
        }
      }
      return event;
    }
  };
});
function getBundleKeysForAllFramesWithFilenames(event) {
  const frames = getFramesFromEvent(event);
  if (!frames) {
    return void 0;
  }
  return frames.filter((frame) => !!frame.filename).map((frame) => {
    if (frame.module_metadata) {
      return Object.keys(frame.module_metadata).filter((key) => key.startsWith(BUNDLER_PLUGIN_APP_KEY_PREFIX)).map((key) => key.slice(BUNDLER_PLUGIN_APP_KEY_PREFIX.length));
    }
    return [];
  });
}
__name(getBundleKeysForAllFramesWithFilenames, "getBundleKeysForAllFramesWithFilenames");
const BUNDLER_PLUGIN_APP_KEY_PREFIX = "_sentryBundlerPluginAppKey:";
const COUNTER_METRIC_TYPE = "c";
const GAUGE_METRIC_TYPE = "g";
const SET_METRIC_TYPE = "s";
const DISTRIBUTION_METRIC_TYPE = "d";
const DEFAULT_BROWSER_FLUSH_INTERVAL = 5e3;
const DEFAULT_FLUSH_INTERVAL = 1e4;
const MAX_WEIGHT = 1e4;
function getMetricsAggregatorForClient$1(client, Aggregator) {
  const globalMetricsAggregators = getGlobalSingleton(
    "globalMetricsAggregators",
    () => /* @__PURE__ */ new WeakMap()
  );
  const aggregator = globalMetricsAggregators.get(client);
  if (aggregator) {
    return aggregator;
  }
  const newAggregator = new Aggregator(client);
  client.on("flush", () => newAggregator.flush());
  client.on("close", () => newAggregator.close());
  globalMetricsAggregators.set(client, newAggregator);
  return newAggregator;
}
__name(getMetricsAggregatorForClient$1, "getMetricsAggregatorForClient$1");
function addToMetricsAggregator(Aggregator, metricType, name2, value3, data30 = {}) {
  const client = data30.client || getClient();
  if (!client) {
    return;
  }
  const span = getActiveSpan();
  const rootSpan = span ? getRootSpan(span) : void 0;
  const transactionName = rootSpan && spanToJSON(rootSpan).description;
  const { unit, tags, timestamp: timestamp2 } = data30;
  const { release, environment } = client.getOptions();
  const metricTags = {};
  if (release) {
    metricTags.release = release;
  }
  if (environment) {
    metricTags.environment = environment;
  }
  if (transactionName) {
    metricTags.transaction = transactionName;
  }
  DEBUG_BUILD$6 && logger$2.log(`Adding value of ${value3} to ${metricType} metric ${name2}`);
  const aggregator = getMetricsAggregatorForClient$1(client, Aggregator);
  aggregator.add(metricType, name2, value3, unit, { ...metricTags, ...tags }, timestamp2);
}
__name(addToMetricsAggregator, "addToMetricsAggregator");
function increment$2(aggregator, name2, value3 = 1, data30) {
  addToMetricsAggregator(aggregator, COUNTER_METRIC_TYPE, name2, ensureNumber(value3), data30);
}
__name(increment$2, "increment$2");
function distribution$2(aggregator, name2, value3, data30) {
  addToMetricsAggregator(aggregator, DISTRIBUTION_METRIC_TYPE, name2, ensureNumber(value3), data30);
}
__name(distribution$2, "distribution$2");
function timing$2(aggregator, name2, value3, unit = "second", data30) {
  if (typeof value3 === "function") {
    const startTime = timestampInSeconds();
    return startSpanManual(
      {
        op: "metrics.timing",
        name: name2,
        startTime,
        onlyIfParent: true
      },
      (span) => {
        return handleCallbackErrors(
          () => value3(),
          () => {
          },
          () => {
            const endTime = timestampInSeconds();
            const timeDiff = endTime - startTime;
            distribution$2(aggregator, name2, timeDiff, { ...data30, unit: "second" });
            span.end(endTime);
          }
        );
      }
    );
  }
  distribution$2(aggregator, name2, value3, { ...data30, unit });
}
__name(timing$2, "timing$2");
function set$6(aggregator, name2, value3, data30) {
  addToMetricsAggregator(aggregator, SET_METRIC_TYPE, name2, value3, data30);
}
__name(set$6, "set$6");
function gauge$2(aggregator, name2, value3, data30) {
  addToMetricsAggregator(aggregator, GAUGE_METRIC_TYPE, name2, ensureNumber(value3), data30);
}
__name(gauge$2, "gauge$2");
const metrics$1 = {
  increment: increment$2,
  distribution: distribution$2,
  set: set$6,
  gauge: gauge$2,
  timing: timing$2,
  /**
   * @ignore This is for internal use only.
   */
  getMetricsAggregatorForClient: getMetricsAggregatorForClient$1
};
function ensureNumber(number2) {
  return typeof number2 === "string" ? parseInt(number2) : number2;
}
__name(ensureNumber, "ensureNumber");
function isProfilingIntegrationWithProfiler(integration) {
  return !!integration && typeof integration["_profiler"] !== "undefined" && typeof integration["_profiler"]["start"] === "function" && typeof integration["_profiler"]["stop"] === "function";
}
__name(isProfilingIntegrationWithProfiler, "isProfilingIntegrationWithProfiler");
function startProfiler() {
  const client = getClient();
  if (!client) {
    DEBUG_BUILD$6 && logger$2.warn("No Sentry client available, profiling is not started");
    return;
  }
  const integration = client.getIntegrationByName("ProfilingIntegration");
  if (!integration) {
    DEBUG_BUILD$6 && logger$2.warn("ProfilingIntegration is not available");
    return;
  }
  if (!isProfilingIntegrationWithProfiler(integration)) {
    DEBUG_BUILD$6 && logger$2.warn("Profiler is not available on profiling integration.");
    return;
  }
  integration._profiler.start();
}
__name(startProfiler, "startProfiler");
function stopProfiler() {
  const client = getClient();
  if (!client) {
    DEBUG_BUILD$6 && logger$2.warn("No Sentry client available, profiling is not started");
    return;
  }
  const integration = client.getIntegrationByName("ProfilingIntegration");
  if (!integration) {
    DEBUG_BUILD$6 && logger$2.warn("ProfilingIntegration is not available");
    return;
  }
  if (!isProfilingIntegrationWithProfiler(integration)) {
    DEBUG_BUILD$6 && logger$2.warn("Profiler is not available on profiling integration.");
    return;
  }
  integration._profiler.stop();
}
__name(stopProfiler, "stopProfiler");
const profiler = {
  startProfiler,
  stopProfiler
};
function getBucketKey(metricType, name2, unit, tags) {
  const stringifiedTags = Object.entries(dropUndefinedKeys(tags)).sort((a2, b2) => a2[0].localeCompare(b2[0]));
  return `${metricType}${name2}${unit}${stringifiedTags}`;
}
__name(getBucketKey, "getBucketKey");
function simpleHash(s2) {
  let rv = 0;
  for (let i2 = 0; i2 < s2.length; i2++) {
    const c2 = s2.charCodeAt(i2);
    rv = (rv << 5) - rv + c2;
    rv &= rv;
  }
  return rv >>> 0;
}
__name(simpleHash, "simpleHash");
function serializeMetricBuckets(metricBucketItems) {
  let out = "";
  for (const item3 of metricBucketItems) {
    const tagEntries = Object.entries(item3.tags);
    const maybeTags = tagEntries.length > 0 ? `|#${tagEntries.map(([key, value3]) => `${key}:${value3}`).join(",")}` : "";
    out += `${item3.name}@${item3.unit}:${item3.metric}|${item3.metricType}${maybeTags}|T${item3.timestamp}
`;
  }
  return out;
}
__name(serializeMetricBuckets, "serializeMetricBuckets");
function sanitizeUnit(unit) {
  return unit.replace(/[^\w]+/gi, "_");
}
__name(sanitizeUnit, "sanitizeUnit");
function sanitizeMetricKey(key) {
  return key.replace(/[^\w\-.]+/gi, "_");
}
__name(sanitizeMetricKey, "sanitizeMetricKey");
function sanitizeTagKey(key) {
  return key.replace(/[^\w\-./]+/gi, "");
}
__name(sanitizeTagKey, "sanitizeTagKey");
const tagValueReplacements = [
  ["\n", "\\n"],
  ["\r", "\\r"],
  ["	", "\\t"],
  ["\\", "\\\\"],
  ["|", "\\u{7c}"],
  [",", "\\u{2c}"]
];
function getCharOrReplacement(input) {
  for (const [search3, replacement] of tagValueReplacements) {
    if (input === search3) {
      return replacement;
    }
  }
  return input;
}
__name(getCharOrReplacement, "getCharOrReplacement");
function sanitizeTagValue(value3) {
  return [...value3].reduce((acc, char) => acc + getCharOrReplacement(char), "");
}
__name(sanitizeTagValue, "sanitizeTagValue");
function sanitizeTags(unsanitizedTags) {
  const tags = {};
  for (const key in unsanitizedTags) {
    if (Object.prototype.hasOwnProperty.call(unsanitizedTags, key)) {
      const sanitizedKey = sanitizeTagKey(key);
      tags[sanitizedKey] = sanitizeTagValue(String(unsanitizedTags[key]));
    }
  }
  return tags;
}
__name(sanitizeTags, "sanitizeTags");
function captureAggregateMetrics(client, metricBucketItems) {
  logger$2.log(`Flushing aggregated metrics, number of metrics: ${metricBucketItems.length}`);
  const dsn = client.getDsn();
  const metadata = client.getSdkMetadata();
  const tunnel = client.getOptions().tunnel;
  const metricsEnvelope = createMetricEnvelope(metricBucketItems, dsn, metadata, tunnel);
  client.sendEnvelope(metricsEnvelope);
}
__name(captureAggregateMetrics, "captureAggregateMetrics");
function createMetricEnvelope(metricBucketItems, dsn, metadata, tunnel) {
  const headers = {
    sent_at: (/* @__PURE__ */ new Date()).toISOString()
  };
  if (metadata && metadata.sdk) {
    headers.sdk = {
      name: metadata.sdk.name,
      version: metadata.sdk.version
    };
  }
  if (!!tunnel && dsn) {
    headers.dsn = dsnToString(dsn);
  }
  const item3 = createMetricEnvelopeItem(metricBucketItems);
  return createEnvelope(headers, [item3]);
}
__name(createMetricEnvelope, "createMetricEnvelope");
function createMetricEnvelopeItem(metricBucketItems) {
  const payload = serializeMetricBuckets(metricBucketItems);
  const metricHeaders = {
    type: "statsd",
    length: payload.length
  };
  return [metricHeaders, payload];
}
__name(createMetricEnvelopeItem, "createMetricEnvelopeItem");
class CounterMetric {
  static {
    __name(this, "CounterMetric");
  }
  constructor(_value) {
    this._value = _value;
  }
  /** @inheritDoc */
  get weight() {
    return 1;
  }
  /** @inheritdoc */
  add(value3) {
    this._value += value3;
  }
  /** @inheritdoc */
  toString() {
    return `${this._value}`;
  }
}
class GaugeMetric {
  static {
    __name(this, "GaugeMetric");
  }
  constructor(value3) {
    this._last = value3;
    this._min = value3;
    this._max = value3;
    this._sum = value3;
    this._count = 1;
  }
  /** @inheritDoc */
  get weight() {
    return 5;
  }
  /** @inheritdoc */
  add(value3) {
    this._last = value3;
    if (value3 < this._min) {
      this._min = value3;
    }
    if (value3 > this._max) {
      this._max = value3;
    }
    this._sum += value3;
    this._count++;
  }
  /** @inheritdoc */
  toString() {
    return `${this._last}:${this._min}:${this._max}:${this._sum}:${this._count}`;
  }
}
class DistributionMetric {
  static {
    __name(this, "DistributionMetric");
  }
  constructor(first2) {
    this._value = [first2];
  }
  /** @inheritDoc */
  get weight() {
    return this._value.length;
  }
  /** @inheritdoc */
  add(value3) {
    this._value.push(value3);
  }
  /** @inheritdoc */
  toString() {
    return this._value.join(":");
  }
}
class SetMetric {
  static {
    __name(this, "SetMetric");
  }
  constructor(first2) {
    this.first = first2;
    this._value = /* @__PURE__ */ new Set([first2]);
  }
  /** @inheritDoc */
  get weight() {
    return this._value.size;
  }
  /** @inheritdoc */
  add(value3) {
    this._value.add(value3);
  }
  /** @inheritdoc */
  toString() {
    return Array.from(this._value).map((val) => typeof val === "string" ? simpleHash(val) : val).join(":");
  }
}
const METRIC_MAP = {
  [COUNTER_METRIC_TYPE]: CounterMetric,
  [GAUGE_METRIC_TYPE]: GaugeMetric,
  [DISTRIBUTION_METRIC_TYPE]: DistributionMetric,
  [SET_METRIC_TYPE]: SetMetric
};
class MetricsAggregator {
  static {
    __name(this, "MetricsAggregator");
  }
  // TODO(@anonrig): Use FinalizationRegistry to have a proper way of flushing the buckets
  // when the aggregator is garbage collected.
  // Ref: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/FinalizationRegistry
  // Different metrics have different weights. We use this to limit the number of metrics
  // that we store in memory.
  // We adjust the type here to add the `unref()` part, as setInterval can technically return a number or a NodeJS.Timer
  // SDKs are required to shift the flush interval by random() * rollup_in_seconds.
  // That shift is determined once per startup to create jittering.
  // An SDK is required to perform force flushing ahead of scheduled time if the memory
  // pressure is too high. There is no rule for this other than that SDKs should be tracking
  // abstract aggregation complexity (eg: a counter only carries a single float, whereas a
  // distribution is a float per emission).
  //
  // Force flush is used on either shutdown, flush() or when we exceed the max weight.
  constructor(_client) {
    this._client = _client;
    this._buckets = /* @__PURE__ */ new Map();
    this._bucketsTotalWeight = 0;
    this._interval = setInterval(() => this._flush(), DEFAULT_FLUSH_INTERVAL);
    if (this._interval.unref) {
      this._interval.unref();
    }
    this._flushShift = Math.floor(Math.random() * DEFAULT_FLUSH_INTERVAL / 1e3);
    this._forceFlush = false;
  }
  /**
   * @inheritDoc
   */
  add(metricType, unsanitizedName, value3, unsanitizedUnit = "none", unsanitizedTags = {}, maybeFloatTimestamp = timestampInSeconds()) {
    const timestamp2 = Math.floor(maybeFloatTimestamp);
    const name2 = sanitizeMetricKey(unsanitizedName);
    const tags = sanitizeTags(unsanitizedTags);
    const unit = sanitizeUnit(unsanitizedUnit);
    const bucketKey = getBucketKey(metricType, name2, unit, tags);
    let bucketItem = this._buckets.get(bucketKey);
    const previousWeight = bucketItem && metricType === SET_METRIC_TYPE ? bucketItem.metric.weight : 0;
    if (bucketItem) {
      bucketItem.metric.add(value3);
      if (bucketItem.timestamp < timestamp2) {
        bucketItem.timestamp = timestamp2;
      }
    } else {
      bucketItem = {
        // @ts-expect-error we don't need to narrow down the type of value here, saves bundle size.
        metric: new METRIC_MAP[metricType](value3),
        timestamp: timestamp2,
        metricType,
        name: name2,
        unit,
        tags
      };
      this._buckets.set(bucketKey, bucketItem);
    }
    const val = typeof value3 === "string" ? bucketItem.metric.weight - previousWeight : value3;
    updateMetricSummaryOnActiveSpan(metricType, name2, val, unit, unsanitizedTags, bucketKey);
    this._bucketsTotalWeight += bucketItem.metric.weight;
    if (this._bucketsTotalWeight >= MAX_WEIGHT) {
      this.flush();
    }
  }
  /**
   * Flushes the current metrics to the transport via the transport.
   */
  flush() {
    this._forceFlush = true;
    this._flush();
  }
  /**
   * Shuts down metrics aggregator and clears all metrics.
   */
  close() {
    this._forceFlush = true;
    clearInterval(this._interval);
    this._flush();
  }
  /**
   * Flushes the buckets according to the internal state of the aggregator.
   * If it is a force flush, which happens on shutdown, it will flush all buckets.
   * Otherwise, it will only flush buckets that are older than the flush interval,
   * and according to the flush shift.
   *
   * This function mutates `_forceFlush` and `_bucketsTotalWeight` properties.
   */
  _flush() {
    if (this._forceFlush) {
      this._forceFlush = false;
      this._bucketsTotalWeight = 0;
      this._captureMetrics(this._buckets);
      this._buckets.clear();
      return;
    }
    const cutoffSeconds = Math.floor(timestampInSeconds()) - DEFAULT_FLUSH_INTERVAL / 1e3 - this._flushShift;
    const flushedBuckets = /* @__PURE__ */ new Map();
    for (const [key, bucket] of this._buckets) {
      if (bucket.timestamp <= cutoffSeconds) {
        flushedBuckets.set(key, bucket);
        this._bucketsTotalWeight -= bucket.metric.weight;
      }
    }
    for (const [key] of flushedBuckets) {
      this._buckets.delete(key);
    }
    this._captureMetrics(flushedBuckets);
  }
  /**
   * Only captures a subset of the buckets passed to this function.
   * @param flushedBuckets
   */
  _captureMetrics(flushedBuckets) {
    if (flushedBuckets.size > 0) {
      const buckets = Array.from(flushedBuckets).map(([, bucketItem]) => bucketItem);
      captureAggregateMetrics(this._client, buckets);
    }
  }
}
function increment$1(name2, value3 = 1, data30) {
  metrics$1.increment(MetricsAggregator, name2, value3, data30);
}
__name(increment$1, "increment$1");
function distribution$1(name2, value3, data30) {
  metrics$1.distribution(MetricsAggregator, name2, value3, data30);
}
__name(distribution$1, "distribution$1");
function set$5(name2, value3, data30) {
  metrics$1.set(MetricsAggregator, name2, value3, data30);
}
__name(set$5, "set$5");
function gauge$1(name2, value3, data30) {
  metrics$1.gauge(MetricsAggregator, name2, value3, data30);
}
__name(gauge$1, "gauge$1");
function timing$1(name2, value3, unit = "second", data30) {
  return metrics$1.timing(MetricsAggregator, name2, value3, unit, data30);
}
__name(timing$1, "timing$1");
function getMetricsAggregatorForClient(client) {
  return metrics$1.getMetricsAggregatorForClient(client, MetricsAggregator);
}
__name(getMetricsAggregatorForClient, "getMetricsAggregatorForClient");
const metricsDefault = {
  increment: increment$1,
  distribution: distribution$1,
  set: set$5,
  gauge: gauge$1,
  timing: timing$1,
  /**
   * @ignore This is for internal use only.
   */
  getMetricsAggregatorForClient
};
class BrowserMetricsAggregator {
  static {
    __name(this, "BrowserMetricsAggregator");
  }
  // TODO(@anonrig): Use FinalizationRegistry to have a proper way of flushing the buckets
  // when the aggregator is garbage collected.
  // Ref: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/FinalizationRegistry
  constructor(_client) {
    this._client = _client;
    this._buckets = /* @__PURE__ */ new Map();
    this._interval = setInterval(() => this.flush(), DEFAULT_BROWSER_FLUSH_INTERVAL);
  }
  /**
   * @inheritDoc
   */
  add(metricType, unsanitizedName, value3, unsanitizedUnit = "none", unsanitizedTags = {}, maybeFloatTimestamp = timestampInSeconds()) {
    const timestamp2 = Math.floor(maybeFloatTimestamp);
    const name2 = sanitizeMetricKey(unsanitizedName);
    const tags = sanitizeTags(unsanitizedTags);
    const unit = sanitizeUnit(unsanitizedUnit);
    const bucketKey = getBucketKey(metricType, name2, unit, tags);
    let bucketItem = this._buckets.get(bucketKey);
    const previousWeight = bucketItem && metricType === SET_METRIC_TYPE ? bucketItem.metric.weight : 0;
    if (bucketItem) {
      bucketItem.metric.add(value3);
      if (bucketItem.timestamp < timestamp2) {
        bucketItem.timestamp = timestamp2;
      }
    } else {
      bucketItem = {
        // @ts-expect-error we don't need to narrow down the type of value here, saves bundle size.
        metric: new METRIC_MAP[metricType](value3),
        timestamp: timestamp2,
        metricType,
        name: name2,
        unit,
        tags
      };
      this._buckets.set(bucketKey, bucketItem);
    }
    const val = typeof value3 === "string" ? bucketItem.metric.weight - previousWeight : value3;
    updateMetricSummaryOnActiveSpan(metricType, name2, val, unit, unsanitizedTags, bucketKey);
  }
  /**
   * @inheritDoc
   */
  flush() {
    if (this._buckets.size === 0) {
      return;
    }
    const metricBuckets = Array.from(this._buckets.values());
    captureAggregateMetrics(this._client, metricBuckets);
    this._buckets.clear();
  }
  /**
   * @inheritDoc
   */
  close() {
    clearInterval(this._interval);
    this.flush();
  }
}
function instrumentFetchRequest(handlerData, shouldCreateSpan, shouldAttachHeaders2, spans, spanOrigin = "auto.http.browser") {
  if (!handlerData.fetchData) {
    return void 0;
  }
  const shouldCreateSpanResult = hasTracingEnabled() && shouldCreateSpan(handlerData.fetchData.url);
  if (handlerData.endTimestamp && shouldCreateSpanResult) {
    const spanId = handlerData.fetchData.__span;
    if (!spanId) return;
    const span2 = spans[spanId];
    if (span2) {
      endSpan(span2, handlerData);
      delete spans[spanId];
    }
    return void 0;
  }
  const { method, url } = handlerData.fetchData;
  const fullUrl = getFullURL$1(url);
  const host = fullUrl ? parseUrl$1(fullUrl).host : void 0;
  const hasParent = !!getActiveSpan();
  const span = shouldCreateSpanResult && hasParent ? startInactiveSpan({
    name: `${method} ${url}`,
    attributes: {
      url,
      type: "fetch",
      "http.method": method,
      "http.url": fullUrl,
      "server.address": host,
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: spanOrigin,
      [SEMANTIC_ATTRIBUTE_SENTRY_OP]: "http.client"
    }
  }) : new SentryNonRecordingSpan();
  handlerData.fetchData.__span = span.spanContext().spanId;
  spans[span.spanContext().spanId] = span;
  if (shouldAttachHeaders2(handlerData.fetchData.url)) {
    const request = handlerData.args[0];
    const options5 = handlerData.args[1] || {};
    const headers = _addTracingHeadersToFetchRequest(
      request,
      options5,
      // If performance is disabled (TWP) or there's no active root span (pageload/navigation/interaction),
      // we do not want to use the span as base for the trace headers,
      // which means that the headers will be generated from the scope and the sampling decision is deferred
      hasTracingEnabled() && hasParent ? span : void 0
    );
    if (headers) {
      handlerData.args[1] = options5;
      options5.headers = headers;
    }
  }
  return span;
}
__name(instrumentFetchRequest, "instrumentFetchRequest");
function _addTracingHeadersToFetchRequest(request, fetchOptionsObj, span) {
  const traceHeaders = getTraceData({ span });
  const sentryTrace = traceHeaders["sentry-trace"];
  const baggage = traceHeaders.baggage;
  if (!sentryTrace) {
    return void 0;
  }
  const headers = fetchOptionsObj.headers || (isRequest$1(request) ? request.headers : void 0);
  if (!headers) {
    return { ...traceHeaders };
  } else if (isHeaders$1(headers)) {
    const newHeaders = new Headers(headers);
    newHeaders.set("sentry-trace", sentryTrace);
    if (baggage) {
      const prevBaggageHeader = newHeaders.get("baggage");
      if (prevBaggageHeader) {
        const prevHeaderStrippedFromSentryBaggage = stripBaggageHeaderOfSentryBaggageValues(prevBaggageHeader);
        newHeaders.set(
          "baggage",
          // If there are non-sentry entries (i.e. if the stripped string is non-empty/truthy) combine the stripped header and sentry baggage header
          // otherwise just set the sentry baggage header
          prevHeaderStrippedFromSentryBaggage ? `${prevHeaderStrippedFromSentryBaggage},${baggage}` : baggage
        );
      } else {
        newHeaders.set("baggage", baggage);
      }
    }
    return newHeaders;
  } else if (Array.isArray(headers)) {
    const newHeaders = [
      ...headers.filter((header3) => {
        return !(Array.isArray(header3) && header3[0] === "sentry-trace");
      }).map((header3) => {
        if (Array.isArray(header3) && header3[0] === "baggage" && typeof header3[1] === "string") {
          const [headerName, headerValue, ...rest] = header3;
          return [headerName, stripBaggageHeaderOfSentryBaggageValues(headerValue), ...rest];
        } else {
          return header3;
        }
      }),
      // Attach the new sentry-trace header
      ["sentry-trace", sentryTrace]
    ];
    if (baggage) {
      newHeaders.push(["baggage", baggage]);
    }
    return newHeaders;
  } else {
    const existingBaggageHeader = "baggage" in headers ? headers.baggage : void 0;
    let newBaggageHeaders = [];
    if (Array.isArray(existingBaggageHeader)) {
      newBaggageHeaders = existingBaggageHeader.map(
        (headerItem) => typeof headerItem === "string" ? stripBaggageHeaderOfSentryBaggageValues(headerItem) : headerItem
      ).filter((headerItem) => headerItem === "");
    } else if (existingBaggageHeader) {
      newBaggageHeaders.push(stripBaggageHeaderOfSentryBaggageValues(existingBaggageHeader));
    }
    if (baggage) {
      newBaggageHeaders.push(baggage);
    }
    return {
      ...headers,
      "sentry-trace": sentryTrace,
      baggage: newBaggageHeaders.length > 0 ? newBaggageHeaders.join(",") : void 0
    };
  }
}
__name(_addTracingHeadersToFetchRequest, "_addTracingHeadersToFetchRequest");
function addTracingHeadersToFetchRequest(request, _client, _scope, fetchOptionsObj, span) {
  return _addTracingHeadersToFetchRequest(request, fetchOptionsObj, span);
}
__name(addTracingHeadersToFetchRequest, "addTracingHeadersToFetchRequest");
function getFullURL$1(url) {
  try {
    const parsed = new URL(url);
    return parsed.href;
  } catch (e2) {
    return void 0;
  }
}
__name(getFullURL$1, "getFullURL$1");
function endSpan(span, handlerData) {
  if (handlerData.response) {
    setHttpStatus(span, handlerData.response.status);
    const contentLength = handlerData.response && handlerData.response.headers && handlerData.response.headers.get("content-length");
    if (contentLength) {
      const contentLengthNum = parseInt(contentLength);
      if (contentLengthNum > 0) {
        span.setAttribute("http.response_content_length", contentLengthNum);
      }
    }
  } else if (handlerData.error) {
    span.setStatus({ code: SPAN_STATUS_ERROR, message: "internal_error" });
  }
  span.end();
}
__name(endSpan, "endSpan");
function stripBaggageHeaderOfSentryBaggageValues(baggageHeader) {
  return baggageHeader.split(",").filter((baggageEntry) => !baggageEntry.split("=")[0].startsWith(SENTRY_BAGGAGE_KEY_PREFIX)).join(",");
}
__name(stripBaggageHeaderOfSentryBaggageValues, "stripBaggageHeaderOfSentryBaggageValues");
function isRequest$1(request) {
  return typeof Request !== "undefined" && isInstanceOf(request, Request);
}
__name(isRequest$1, "isRequest$1");
function isHeaders$1(headers) {
  return typeof Headers !== "undefined" && isInstanceOf(headers, Headers);
}
__name(isHeaders$1, "isHeaders$1");
const trpcCaptureContext = { mechanism: { handled: false, data: { function: "trpcMiddleware" } } };
function captureIfError(nextResult) {
  if (typeof nextResult === "object" && nextResult !== null && "ok" in nextResult && !nextResult.ok && "error" in nextResult) {
    captureException(nextResult.error, trpcCaptureContext);
  }
}
__name(captureIfError, "captureIfError");
function trpcMiddleware(options5 = {}) {
  return async function(opts) {
    const { path, type, next: next2, rawInput, getRawInput } = opts;
    const client = getClient();
    const clientOptions = client && client.getOptions();
    const trpcContext = {
      procedure_path: path,
      procedure_type: type
    };
    if (options5.attachRpcInput !== void 0 ? options5.attachRpcInput : clientOptions && clientOptions.sendDefaultPii) {
      if (rawInput !== void 0) {
        trpcContext.input = normalize$2(rawInput);
      }
      if (getRawInput !== void 0 && typeof getRawInput === "function") {
        try {
          const rawRes = await getRawInput();
          trpcContext.input = normalize$2(rawRes);
        } catch (err) {
        }
      }
    }
    return withScope((scope) => {
      scope.setContext("trpc", trpcContext);
      return startSpanManual(
        {
          name: `trpc/${path}`,
          op: "rpc.server",
          attributes: {
            [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "route",
            [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.rpc.trpc"
          }
        },
        async (span) => {
          try {
            const nextResult = await next2();
            captureIfError(nextResult);
            span.end();
            return nextResult;
          } catch (e2) {
            captureException(e2, trpcCaptureContext);
            span.end();
            throw e2;
          }
        }
      );
    });
  };
}
__name(trpcMiddleware, "trpcMiddleware");
function captureFeedback(params, hint = {}, scope = getCurrentScope$1()) {
  const { message: message3, name: name2, email, url, source, associatedEventId, tags } = params;
  const feedbackEvent = {
    contexts: {
      feedback: dropUndefinedKeys({
        contact_email: email,
        name: name2,
        message: message3,
        url,
        source,
        associated_event_id: associatedEventId
      })
    },
    type: "feedback",
    level: "info",
    tags
  };
  const client = scope && scope.getClient() || getClient();
  if (client) {
    client.emit("beforeSendFeedback", feedbackEvent, hint);
  }
  const eventId = scope.captureEvent(feedbackEvent, hint);
  return eventId;
}
__name(captureFeedback, "captureFeedback");
function getCurrentHubShim() {
  return {
    bindClient(client) {
      const scope = getCurrentScope$1();
      scope.setClient(client);
    },
    withScope,
    getClient: /* @__PURE__ */ __name(() => getClient(), "getClient"),
    getScope: getCurrentScope$1,
    getIsolationScope,
    captureException: /* @__PURE__ */ __name((exception, hint) => {
      return getCurrentScope$1().captureException(exception, hint);
    }, "captureException"),
    captureMessage: /* @__PURE__ */ __name((message3, level, hint) => {
      return getCurrentScope$1().captureMessage(message3, level, hint);
    }, "captureMessage"),
    captureEvent,
    addBreadcrumb,
    setUser,
    setTags,
    setTag: setTag$5,
    setExtra,
    setExtras,
    setContext,
    getIntegration(integration) {
      const client = getClient();
      return client && client.getIntegrationByName(integration.id) || null;
    },
    startSession,
    endSession,
    captureSession(end) {
      if (end) {
        return endSession();
      }
      _sendSessionUpdate();
    }
  };
}
__name(getCurrentHubShim, "getCurrentHubShim");
const getCurrentHub = getCurrentHubShim;
function _sendSessionUpdate() {
  const scope = getCurrentScope$1();
  const client = getClient();
  const session = scope.getSession();
  if (client && session) {
    client.captureSession(session);
  }
}
__name(_sendSessionUpdate, "_sendSessionUpdate");
function flatten(input) {
  const result = [];
  const flattenHelper = /* @__PURE__ */ __name((input2) => {
    input2.forEach((el) => {
      if (Array.isArray(el)) {
        flattenHelper(el);
      } else {
        result.push(el);
      }
    });
  }, "flattenHelper");
  flattenHelper(input);
  return result;
}
__name(flatten, "flatten");
function getBreadcrumbLogLevelFromHttpStatusCode(statusCode) {
  if (statusCode === void 0) {
    return void 0;
  } else if (statusCode >= 400 && statusCode < 500) {
    return "warning";
  } else if (statusCode >= 500) {
    return "error";
  } else {
    return void 0;
  }
}
__name(getBreadcrumbLogLevelFromHttpStatusCode, "getBreadcrumbLogLevelFromHttpStatusCode");
const WINDOW$7 = GLOBAL_OBJ;
function supportsErrorEvent() {
  try {
    new ErrorEvent("");
    return true;
  } catch (e2) {
    return false;
  }
}
__name(supportsErrorEvent, "supportsErrorEvent");
function supportsDOMError() {
  try {
    new DOMError("");
    return true;
  } catch (e2) {
    return false;
  }
}
__name(supportsDOMError, "supportsDOMError");
function supportsDOMException() {
  try {
    new DOMException("");
    return true;
  } catch (e2) {
    return false;
  }
}
__name(supportsDOMException, "supportsDOMException");
function supportsFetch() {
  if (!("fetch" in WINDOW$7)) {
    return false;
  }
  try {
    new Headers();
    new Request("http://www.example.com");
    new Response();
    return true;
  } catch (e2) {
    return false;
  }
}
__name(supportsFetch, "supportsFetch");
function isNativeFunction(func) {
  return func && /^function\s+\w+\(\)\s+\{\s+\[native code\]\s+\}$/.test(func.toString());
}
__name(isNativeFunction, "isNativeFunction");
function supportsNativeFetch() {
  if (typeof EdgeRuntime === "string") {
    return true;
  }
  if (!supportsFetch()) {
    return false;
  }
  if (isNativeFunction(WINDOW$7.fetch)) {
    return true;
  }
  let result = false;
  const doc2 = WINDOW$7.document;
  if (doc2 && typeof doc2.createElement === "function") {
    try {
      const sandbox = doc2.createElement("iframe");
      sandbox.hidden = true;
      doc2.head.appendChild(sandbox);
      if (sandbox.contentWindow && sandbox.contentWindow.fetch) {
        result = isNativeFunction(sandbox.contentWindow.fetch);
      }
      doc2.head.removeChild(sandbox);
    } catch (err) {
      DEBUG_BUILD$5 && logger$2.warn("Could not create sandbox iframe for pure fetch check, bailing to window.fetch: ", err);
    }
  }
  return result;
}
__name(supportsNativeFetch, "supportsNativeFetch");
function supportsReportingObserver() {
  return "ReportingObserver" in WINDOW$7;
}
__name(supportsReportingObserver, "supportsReportingObserver");
function supportsReferrerPolicy() {
  if (!supportsFetch()) {
    return false;
  }
  try {
    new Request("_", {
      referrerPolicy: "origin"
    });
    return true;
  } catch (e2) {
    return false;
  }
}
__name(supportsReferrerPolicy, "supportsReferrerPolicy");
function addFetchInstrumentationHandler(handler14, skipNativeFetchCheck) {
  const type = "fetch";
  addHandler$1(type, handler14);
  maybeInstrument(type, () => instrumentFetch(void 0, skipNativeFetchCheck));
}
__name(addFetchInstrumentationHandler, "addFetchInstrumentationHandler");
function addFetchEndInstrumentationHandler(handler14) {
  const type = "fetch-body-resolved";
  addHandler$1(type, handler14);
  maybeInstrument(type, () => instrumentFetch(streamHandler));
}
__name(addFetchEndInstrumentationHandler, "addFetchEndInstrumentationHandler");
function instrumentFetch(onFetchResolved, skipNativeFetchCheck = false) {
  if (skipNativeFetchCheck && !supportsNativeFetch()) {
    return;
  }
  fill(GLOBAL_OBJ, "fetch", function(originalFetch) {
    return function(...args) {
      const virtualError = new Error();
      const { method, url } = parseFetchArgs(args);
      const handlerData = {
        args,
        fetchData: {
          method,
          url
        },
        startTimestamp: timestampInSeconds() * 1e3,
        // // Adding the error to be able to fingerprint the failed fetch event in HttpClient instrumentation
        virtualError
      };
      if (!onFetchResolved) {
        triggerHandlers$1("fetch", {
          ...handlerData
        });
      }
      return originalFetch.apply(GLOBAL_OBJ, args).then(
        async (response) => {
          if (onFetchResolved) {
            onFetchResolved(response);
          } else {
            triggerHandlers$1("fetch", {
              ...handlerData,
              endTimestamp: timestampInSeconds() * 1e3,
              response
            });
          }
          return response;
        },
        (error2) => {
          triggerHandlers$1("fetch", {
            ...handlerData,
            endTimestamp: timestampInSeconds() * 1e3,
            error: error2
          });
          if (isError(error2) && error2.stack === void 0) {
            error2.stack = virtualError.stack;
            addNonEnumerableProperty(error2, "framesToPop", 1);
          }
          throw error2;
        }
      );
    };
  });
}
__name(instrumentFetch, "instrumentFetch");
async function resolveResponse(res, onFinishedResolving) {
  if (res && res.body) {
    const body = res.body;
    const responseReader = body.getReader();
    const maxFetchDurationTimeout = setTimeout(
      () => {
        body.cancel().then(null, () => {
        });
      },
      90 * 1e3
      // 90s
    );
    let readingActive = true;
    while (readingActive) {
      let chunkTimeout;
      try {
        chunkTimeout = setTimeout(() => {
          body.cancel().then(null, () => {
          });
        }, 5e3);
        const { done } = await responseReader.read();
        clearTimeout(chunkTimeout);
        if (done) {
          onFinishedResolving();
          readingActive = false;
        }
      } catch (error2) {
        readingActive = false;
      } finally {
        clearTimeout(chunkTimeout);
      }
    }
    clearTimeout(maxFetchDurationTimeout);
    responseReader.releaseLock();
    body.cancel().then(null, () => {
    });
  }
}
__name(resolveResponse, "resolveResponse");
function streamHandler(response) {
  let clonedResponseForResolving;
  try {
    clonedResponseForResolving = response.clone();
  } catch (e2) {
    return;
  }
  resolveResponse(clonedResponseForResolving, () => {
    triggerHandlers$1("fetch-body-resolved", {
      endTimestamp: timestampInSeconds() * 1e3,
      response
    });
  });
}
__name(streamHandler, "streamHandler");
function hasProp(obj, prop2) {
  return !!obj && typeof obj === "object" && !!obj[prop2];
}
__name(hasProp, "hasProp");
function getUrlFromResource(resource) {
  if (typeof resource === "string") {
    return resource;
  }
  if (!resource) {
    return "";
  }
  if (hasProp(resource, "url")) {
    return resource.url;
  }
  if (resource.toString) {
    return resource.toString();
  }
  return "";
}
__name(getUrlFromResource, "getUrlFromResource");
function parseFetchArgs(fetchArgs) {
  if (fetchArgs.length === 0) {
    return { method: "GET", url: "" };
  }
  if (fetchArgs.length === 2) {
    const [url, options5] = fetchArgs;
    return {
      url: getUrlFromResource(url),
      method: hasProp(options5, "method") ? String(options5.method).toUpperCase() : "GET"
    };
  }
  const arg = fetchArgs[0];
  return {
    url: getUrlFromResource(arg),
    method: hasProp(arg, "method") ? String(arg.method).toUpperCase() : "GET"
  };
}
__name(parseFetchArgs, "parseFetchArgs");
function isBrowserBundle() {
  return typeof __SENTRY_BROWSER_BUNDLE__ !== "undefined" && !!__SENTRY_BROWSER_BUNDLE__;
}
__name(isBrowserBundle, "isBrowserBundle");
function getSDKSource() {
  return "npm";
}
__name(getSDKSource, "getSDKSource");
function isNodeEnv() {
  return !isBrowserBundle() && Object.prototype.toString.call(typeof process !== "undefined" ? process : 0) === "[object process]";
}
__name(isNodeEnv, "isNodeEnv");
function dynamicRequire(mod, request) {
  return mod.require(request);
}
__name(dynamicRequire, "dynamicRequire");
function loadModule(moduleName) {
  let mod;
  try {
    mod = dynamicRequire(module, moduleName);
  } catch (e2) {
  }
  if (!mod) {
    try {
      const { cwd } = dynamicRequire(module, "process");
      mod = dynamicRequire(module, `${cwd()}/node_modules/${moduleName}`);
    } catch (e2) {
    }
  }
  return mod;
}
__name(loadModule, "loadModule");
function isBrowser$1() {
  return typeof window !== "undefined" && (!isNodeEnv() || isElectronNodeRenderer());
}
__name(isBrowser$1, "isBrowser$1");
function isElectronNodeRenderer() {
  const process2 = GLOBAL_OBJ.process;
  return !!process2 && process2.type === "renderer";
}
__name(isElectronNodeRenderer, "isElectronNodeRenderer");
function filenameIsInApp(filename, isNative = false) {
  const isInternal = isNative || filename && // It's not internal if it's an absolute linux path
  !filename.startsWith("/") && // It's not internal if it's an absolute windows path
  !filename.match(/^[A-Z]:/) && // It's not internal if the path is starting with a dot
  !filename.startsWith(".") && // It's not internal if the frame has a protocol. In node, this is usually the case if the file got pre-processed with a bundler like webpack
  !filename.match(/^[a-zA-Z]([a-zA-Z0-9.\-+])*:\/\//);
  return !isInternal && filename !== void 0 && !filename.includes("node_modules/");
}
__name(filenameIsInApp, "filenameIsInApp");
function node(getModule) {
  const FILENAME_MATCH = /^\s*[-]{4,}$/;
  const FULL_MATCH = /at (?:async )?(?:(.+?)\s+\()?(?:(.+):(\d+):(\d+)?|([^)]+))\)?/;
  return (line) => {
    const lineMatch = line.match(FULL_MATCH);
    if (lineMatch) {
      let object;
      let method;
      let functionName;
      let typeName;
      let methodName;
      if (lineMatch[1]) {
        functionName = lineMatch[1];
        let methodStart = functionName.lastIndexOf(".");
        if (functionName[methodStart - 1] === ".") {
          methodStart--;
        }
        if (methodStart > 0) {
          object = functionName.slice(0, methodStart);
          method = functionName.slice(methodStart + 1);
          const objectEnd = object.indexOf(".Module");
          if (objectEnd > 0) {
            functionName = functionName.slice(objectEnd + 1);
            object = object.slice(0, objectEnd);
          }
        }
        typeName = void 0;
      }
      if (method) {
        typeName = object;
        methodName = method;
      }
      if (method === "<anonymous>") {
        methodName = void 0;
        functionName = void 0;
      }
      if (functionName === void 0) {
        methodName = methodName || UNKNOWN_FUNCTION;
        functionName = typeName ? `${typeName}.${methodName}` : methodName;
      }
      let filename = lineMatch[2] && lineMatch[2].startsWith("file://") ? lineMatch[2].slice(7) : lineMatch[2];
      const isNative = lineMatch[5] === "native";
      if (filename && filename.match(/\/[A-Z]:/)) {
        filename = filename.slice(1);
      }
      if (!filename && lineMatch[5] && !isNative) {
        filename = lineMatch[5];
      }
      return {
        filename: filename ? decodeURI(filename) : void 0,
        module: getModule ? getModule(filename) : void 0,
        function: functionName,
        lineno: _parseIntOrUndefined(lineMatch[3]),
        colno: _parseIntOrUndefined(lineMatch[4]),
        in_app: filenameIsInApp(filename || "", isNative)
      };
    }
    if (line.match(FILENAME_MATCH)) {
      return {
        filename: line
      };
    }
    return void 0;
  };
}
__name(node, "node");
function nodeStackLineParser(getModule) {
  return [90, node(getModule)];
}
__name(nodeStackLineParser, "nodeStackLineParser");
function _parseIntOrUndefined(input) {
  return parseInt(input || "", 10) || void 0;
}
__name(_parseIntOrUndefined, "_parseIntOrUndefined");
function makeFifoCache(size) {
  let evictionOrder = [];
  let cache2 = {};
  return {
    add(key, value3) {
      while (evictionOrder.length >= size) {
        const evictCandidate = evictionOrder.shift();
        if (evictCandidate !== void 0) {
          delete cache2[evictCandidate];
        }
      }
      if (cache2[key]) {
        this.delete(key);
      }
      evictionOrder.push(key);
      cache2[key] = value3;
    },
    clear() {
      cache2 = {};
      evictionOrder = [];
    },
    get(key) {
      return cache2[key];
    },
    size() {
      return evictionOrder.length;
    },
    // Delete cache key and return true if it existed, false otherwise.
    delete(key) {
      if (!cache2[key]) {
        return false;
      }
      delete cache2[key];
      for (let i2 = 0; i2 < evictionOrder.length; i2++) {
        if (evictionOrder[i2] === key) {
          evictionOrder.splice(i2, 1);
          break;
        }
      }
      return true;
    }
  };
}
__name(makeFifoCache, "makeFifoCache");
function watchdogTimer(createTimer, pollInterval, anrThreshold, callback) {
  const timer = createTimer();
  let triggered = false;
  let enabled = true;
  setInterval(() => {
    const diffMs = timer.getTimeMs();
    if (triggered === false && diffMs > pollInterval + anrThreshold) {
      triggered = true;
      if (enabled) {
        callback();
      }
    }
    if (diffMs < pollInterval + anrThreshold) {
      triggered = false;
    }
  }, 20);
  return {
    poll: /* @__PURE__ */ __name(() => {
      timer.reset();
    }, "poll"),
    enabled: /* @__PURE__ */ __name((state) => {
      enabled = state;
    }, "enabled")
  };
}
__name(watchdogTimer, "watchdogTimer");
function callFrameToStackFrame(frame, url, getModuleFromFilename) {
  const filename = url ? url.replace(/^file:\/\//, "") : void 0;
  const colno = frame.location.columnNumber ? frame.location.columnNumber + 1 : void 0;
  const lineno = frame.location.lineNumber ? frame.location.lineNumber + 1 : void 0;
  return dropUndefinedKeys({
    filename,
    module: getModuleFromFilename(filename),
    function: frame.functionName || UNKNOWN_FUNCTION,
    colno,
    lineno,
    in_app: filename ? filenameIsInApp(filename) : void 0
  });
}
__name(callFrameToStackFrame, "callFrameToStackFrame");
class LRUMap {
  static {
    __name(this, "LRUMap");
  }
  constructor(_maxSize) {
    this._maxSize = _maxSize;
    this._cache = /* @__PURE__ */ new Map();
  }
  /** Get the current size of the cache */
  get size() {
    return this._cache.size;
  }
  /** Get an entry or undefined if it was not in the cache. Re-inserts to update the recently used order */
  get(key) {
    const value3 = this._cache.get(key);
    if (value3 === void 0) {
      return void 0;
    }
    this._cache.delete(key);
    this._cache.set(key, value3);
    return value3;
  }
  /** Insert an entry and evict an older entry if we've reached maxSize */
  set(key, value3) {
    if (this._cache.size >= this._maxSize) {
      this._cache.delete(this._cache.keys().next().value);
    }
    this._cache.set(key, value3);
  }
  /** Remove an entry and return the entry if it was in the cache */
  remove(key) {
    const value3 = this._cache.get(key);
    if (value3) {
      this._cache.delete(key);
    }
    return value3;
  }
  /** Clear all entries */
  clear() {
    this._cache.clear();
  }
  /** Get all the keys */
  keys() {
    return Array.from(this._cache.keys());
  }
  /** Get all the values */
  values() {
    const values = [];
    this._cache.forEach((value3) => values.push(value3));
    return values;
  }
}
function vercelWaitUntil(task) {
  const vercelRequestContextGlobal = (
    // @ts-expect-error This is not typed
    GLOBAL_OBJ[Symbol.for("@vercel/request-context")]
  );
  const ctx = vercelRequestContextGlobal && vercelRequestContextGlobal.get && vercelRequestContextGlobal.get() ? vercelRequestContextGlobal.get() : {};
  if (ctx && ctx.waitUntil) {
    ctx.waitUntil(task);
  }
}
__name(vercelWaitUntil, "vercelWaitUntil");
function escapeStringForRegex(regexString) {
  return regexString.replace(/[|\\{}()[\]^$+*?.]/g, "\\$&").replace(/-/g, "\\x2d");
}
__name(escapeStringForRegex, "escapeStringForRegex");
const WINDOW$6 = GLOBAL_OBJ;
function supportsHistory() {
  const chromeVar = WINDOW$6.chrome;
  const isChromePackagedApp = chromeVar && chromeVar.app && chromeVar.app.runtime;
  const hasHistoryApi = "history" in WINDOW$6 && !!WINDOW$6.history.pushState && !!WINDOW$6.history.replaceState;
  return !isChromePackagedApp && hasHistoryApi;
}
__name(supportsHistory, "supportsHistory");
function _nullishCoalesce(lhs, rhsFn) {
  return lhs != null ? lhs : rhsFn();
}
__name(_nullishCoalesce, "_nullishCoalesce");
async function _asyncNullishCoalesce(lhs, rhsFn) {
  return _nullishCoalesce(lhs, rhsFn);
}
__name(_asyncNullishCoalesce, "_asyncNullishCoalesce");
async function _asyncOptionalChain(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = await fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = await fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_asyncOptionalChain, "_asyncOptionalChain");
async function _asyncOptionalChainDelete(ops) {
  const result = await _asyncOptionalChain(ops);
  return result == null ? true : result;
}
__name(_asyncOptionalChainDelete, "_asyncOptionalChainDelete");
function _optionalChain(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain, "_optionalChain");
function _optionalChainDelete(ops) {
  const result = _optionalChain(ops);
  return result == null ? true : result;
}
__name(_optionalChainDelete, "_optionalChainDelete");
const WINDOW$5 = GLOBAL_OBJ;
let ignoreOnError = 0;
function shouldIgnoreOnError() {
  return ignoreOnError > 0;
}
__name(shouldIgnoreOnError, "shouldIgnoreOnError");
function ignoreNextOnError() {
  ignoreOnError++;
  setTimeout(() => {
    ignoreOnError--;
  });
}
__name(ignoreNextOnError, "ignoreNextOnError");
function wrap$1(fn, options5 = {}) {
  function isFunction2(fn2) {
    return typeof fn2 === "function";
  }
  __name(isFunction2, "isFunction");
  if (!isFunction2(fn)) {
    return fn;
  }
  try {
    const wrapper = fn.__sentry_wrapped__;
    if (wrapper) {
      if (typeof wrapper === "function") {
        return wrapper;
      } else {
        return fn;
      }
    }
    if (getOriginalFunction(fn)) {
      return fn;
    }
  } catch (e2) {
    return fn;
  }
  const sentryWrapped = /* @__PURE__ */ __name(function(...args) {
    try {
      const wrappedArguments = args.map((arg) => wrap$1(arg, options5));
      return fn.apply(this, wrappedArguments);
    } catch (ex) {
      ignoreNextOnError();
      withScope((scope) => {
        scope.addEventProcessor((event) => {
          if (options5.mechanism) {
            addExceptionTypeValue(event, void 0, void 0);
            addExceptionMechanism(event, options5.mechanism);
          }
          event.extra = {
            ...event.extra,
            arguments: args
          };
          return event;
        });
        captureException(ex);
      });
      throw ex;
    }
  }, "sentryWrapped");
  try {
    for (const property in fn) {
      if (Object.prototype.hasOwnProperty.call(fn, property)) {
        sentryWrapped[property] = fn[property];
      }
    }
  } catch (e2) {
  }
  markFunctionWrapped(sentryWrapped, fn);
  addNonEnumerableProperty(fn, "__sentry_wrapped__", sentryWrapped);
  try {
    const descriptor = Object.getOwnPropertyDescriptor(sentryWrapped, "name");
    if (descriptor.configurable) {
      Object.defineProperty(sentryWrapped, "name", {
        get() {
          return fn.name;
        }
      });
    }
  } catch (e3) {
  }
  return sentryWrapped;
}
__name(wrap$1, "wrap$1");
const DEBUG_BUILD$4 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
function exceptionFromError(stackParser, ex) {
  const frames = parseStackFrames(stackParser, ex);
  const exception = {
    type: extractType(ex),
    value: extractMessage(ex)
  };
  if (frames.length) {
    exception.stacktrace = { frames };
  }
  if (exception.type === void 0 && exception.value === "") {
    exception.value = "Unrecoverable error caught";
  }
  return exception;
}
__name(exceptionFromError, "exceptionFromError");
function eventFromPlainObject(stackParser, exception, syntheticException, isUnhandledRejection) {
  const client = getClient();
  const normalizeDepth = client && client.getOptions().normalizeDepth;
  const errorFromProp = getErrorPropertyFromObject(exception);
  const extra = {
    __serialized__: normalizeToSize(exception, normalizeDepth)
  };
  if (errorFromProp) {
    return {
      exception: {
        values: [exceptionFromError(stackParser, errorFromProp)]
      },
      extra
    };
  }
  const event = {
    exception: {
      values: [
        {
          type: isEvent(exception) ? exception.constructor.name : isUnhandledRejection ? "UnhandledRejection" : "Error",
          value: getNonErrorObjectExceptionValue(exception, { isUnhandledRejection })
        }
      ]
    },
    extra
  };
  if (syntheticException) {
    const frames = parseStackFrames(stackParser, syntheticException);
    if (frames.length) {
      event.exception.values[0].stacktrace = { frames };
    }
  }
  return event;
}
__name(eventFromPlainObject, "eventFromPlainObject");
function eventFromError(stackParser, ex) {
  return {
    exception: {
      values: [exceptionFromError(stackParser, ex)]
    }
  };
}
__name(eventFromError, "eventFromError");
function parseStackFrames(stackParser, ex) {
  const stacktrace = ex.stacktrace || ex.stack || "";
  const skipLines = getSkipFirstStackStringLines(ex);
  const framesToPop = getPopFirstTopFrames(ex);
  try {
    return stackParser(stacktrace, skipLines, framesToPop);
  } catch (e2) {
  }
  return [];
}
__name(parseStackFrames, "parseStackFrames");
const reactMinifiedRegexp = /Minified React error #\d+;/i;
function getSkipFirstStackStringLines(ex) {
  if (ex && reactMinifiedRegexp.test(ex.message)) {
    return 1;
  }
  return 0;
}
__name(getSkipFirstStackStringLines, "getSkipFirstStackStringLines");
function getPopFirstTopFrames(ex) {
  if (typeof ex.framesToPop === "number") {
    return ex.framesToPop;
  }
  return 0;
}
__name(getPopFirstTopFrames, "getPopFirstTopFrames");
function isWebAssemblyException(exception) {
  if (typeof WebAssembly !== "undefined" && typeof WebAssembly.Exception !== "undefined") {
    return exception instanceof WebAssembly.Exception;
  } else {
    return false;
  }
}
__name(isWebAssemblyException, "isWebAssemblyException");
function extractType(ex) {
  const name2 = ex && ex.name;
  if (!name2 && isWebAssemblyException(ex)) {
    const hasTypeInMessage = ex.message && Array.isArray(ex.message) && ex.message.length == 2;
    return hasTypeInMessage ? ex.message[0] : "WebAssembly.Exception";
  }
  return name2;
}
__name(extractType, "extractType");
function extractMessage(ex) {
  const message3 = ex && ex.message;
  if (!message3) {
    return "No error message";
  }
  if (message3.error && typeof message3.error.message === "string") {
    return message3.error.message;
  }
  if (isWebAssemblyException(ex) && Array.isArray(ex.message) && ex.message.length == 2) {
    return ex.message[1];
  }
  return message3;
}
__name(extractMessage, "extractMessage");
function eventFromException(stackParser, exception, hint, attachStacktrace) {
  const syntheticException = hint && hint.syntheticException || void 0;
  const event = eventFromUnknownInput(stackParser, exception, syntheticException, attachStacktrace);
  addExceptionMechanism(event);
  event.level = "error";
  if (hint && hint.event_id) {
    event.event_id = hint.event_id;
  }
  return resolvedSyncPromise(event);
}
__name(eventFromException, "eventFromException");
function eventFromMessage(stackParser, message3, level = "info", hint, attachStacktrace) {
  const syntheticException = hint && hint.syntheticException || void 0;
  const event = eventFromString(stackParser, message3, syntheticException, attachStacktrace);
  event.level = level;
  if (hint && hint.event_id) {
    event.event_id = hint.event_id;
  }
  return resolvedSyncPromise(event);
}
__name(eventFromMessage, "eventFromMessage");
function eventFromUnknownInput(stackParser, exception, syntheticException, attachStacktrace, isUnhandledRejection) {
  let event;
  if (isErrorEvent$2(exception) && exception.error) {
    const errorEvent = exception;
    return eventFromError(stackParser, errorEvent.error);
  }
  if (isDOMError(exception) || isDOMException(exception)) {
    const domException = exception;
    if ("stack" in exception) {
      event = eventFromError(stackParser, exception);
    } else {
      const name2 = domException.name || (isDOMError(domException) ? "DOMError" : "DOMException");
      const message3 = domException.message ? `${name2}: ${domException.message}` : name2;
      event = eventFromString(stackParser, message3, syntheticException, attachStacktrace);
      addExceptionTypeValue(event, message3);
    }
    if ("code" in domException) {
      event.tags = { ...event.tags, "DOMException.code": `${domException.code}` };
    }
    return event;
  }
  if (isError(exception)) {
    return eventFromError(stackParser, exception);
  }
  if (isPlainObject$5(exception) || isEvent(exception)) {
    const objectException = exception;
    event = eventFromPlainObject(stackParser, objectException, syntheticException, isUnhandledRejection);
    addExceptionMechanism(event, {
      synthetic: true
    });
    return event;
  }
  event = eventFromString(stackParser, exception, syntheticException, attachStacktrace);
  addExceptionTypeValue(event, `${exception}`, void 0);
  addExceptionMechanism(event, {
    synthetic: true
  });
  return event;
}
__name(eventFromUnknownInput, "eventFromUnknownInput");
function eventFromString(stackParser, message3, syntheticException, attachStacktrace) {
  const event = {};
  if (attachStacktrace && syntheticException) {
    const frames = parseStackFrames(stackParser, syntheticException);
    if (frames.length) {
      event.exception = {
        values: [{ value: message3, stacktrace: { frames } }]
      };
    }
    addExceptionMechanism(event, { synthetic: true });
  }
  if (isParameterizedString(message3)) {
    const { __sentry_template_string__, __sentry_template_values__ } = message3;
    event.logentry = {
      message: __sentry_template_string__,
      params: __sentry_template_values__
    };
    return event;
  }
  event.message = message3;
  return event;
}
__name(eventFromString, "eventFromString");
function getNonErrorObjectExceptionValue(exception, { isUnhandledRejection }) {
  const keys2 = extractExceptionKeysForMessage(exception);
  const captureType = isUnhandledRejection ? "promise rejection" : "exception";
  if (isErrorEvent$2(exception)) {
    return `Event \`ErrorEvent\` captured as ${captureType} with message \`${exception.message}\``;
  }
  if (isEvent(exception)) {
    const className = getObjectClassName(exception);
    return `Event \`${className}\` (type=${exception.type}) captured as ${captureType}`;
  }
  return `Object captured as ${captureType} with keys: ${keys2}`;
}
__name(getNonErrorObjectExceptionValue, "getNonErrorObjectExceptionValue");
function getObjectClassName(obj) {
  try {
    const prototype2 = Object.getPrototypeOf(obj);
    return prototype2 ? prototype2.constructor.name : void 0;
  } catch (e2) {
  }
}
__name(getObjectClassName, "getObjectClassName");
function getErrorPropertyFromObject(obj) {
  for (const prop2 in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, prop2)) {
      const value3 = obj[prop2];
      if (value3 instanceof Error) {
        return value3;
      }
    }
  }
  return void 0;
}
__name(getErrorPropertyFromObject, "getErrorPropertyFromObject");
function createUserFeedbackEnvelope(feedback, {
  metadata,
  tunnel,
  dsn
}) {
  const headers = {
    event_id: feedback.event_id,
    sent_at: (/* @__PURE__ */ new Date()).toISOString(),
    ...metadata && metadata.sdk && {
      sdk: {
        name: metadata.sdk.name,
        version: metadata.sdk.version
      }
    },
    ...!!tunnel && !!dsn && { dsn: dsnToString(dsn) }
  };
  const item3 = createUserFeedbackEnvelopeItem(feedback);
  return createEnvelope(headers, [item3]);
}
__name(createUserFeedbackEnvelope, "createUserFeedbackEnvelope");
function createUserFeedbackEnvelopeItem(feedback) {
  const feedbackHeaders = {
    type: "user_report"
  };
  return [feedbackHeaders, feedback];
}
__name(createUserFeedbackEnvelopeItem, "createUserFeedbackEnvelopeItem");
class BrowserClient extends BaseClient {
  static {
    __name(this, "BrowserClient");
  }
  /**
   * Creates a new Browser SDK instance.
   *
   * @param options Configuration options for this SDK.
   */
  constructor(options5) {
    const opts = {
      // We default this to true, as it is the safer scenario
      parentSpanIsAlwaysRootSpan: true,
      ...options5
    };
    const sdkSource = WINDOW$5.SENTRY_SDK_SOURCE || getSDKSource();
    applySdkMetadata(opts, "browser", ["browser"], sdkSource);
    super(opts);
    if (opts.sendClientReports && WINDOW$5.document) {
      WINDOW$5.document.addEventListener("visibilitychange", () => {
        if (WINDOW$5.document.visibilityState === "hidden") {
          this._flushOutcomes();
        }
      });
    }
  }
  /**
   * @inheritDoc
   */
  eventFromException(exception, hint) {
    return eventFromException(this._options.stackParser, exception, hint, this._options.attachStacktrace);
  }
  /**
   * @inheritDoc
   */
  eventFromMessage(message3, level = "info", hint) {
    return eventFromMessage(this._options.stackParser, message3, level, hint, this._options.attachStacktrace);
  }
  /**
   * Sends user feedback to Sentry.
   *
   * @deprecated Use `captureFeedback` instead.
   */
  captureUserFeedback(feedback) {
    if (!this._isEnabled()) {
      DEBUG_BUILD$4 && logger$2.warn("SDK not enabled, will not capture user feedback.");
      return;
    }
    const envelope = createUserFeedbackEnvelope(feedback, {
      metadata: this.getSdkMetadata(),
      dsn: this.getDsn(),
      tunnel: this.getOptions().tunnel
    });
    this.sendEnvelope(envelope);
  }
  /**
   * @inheritDoc
   */
  _prepareEvent(event, hint, scope) {
    event.platform = event.platform || "javascript";
    return super._prepareEvent(event, hint, scope);
  }
}
const DEBUG_BUILD$3 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
const getRating = /* @__PURE__ */ __name((value3, thresholds) => {
  if (value3 > thresholds[1]) {
    return "poor";
  }
  if (value3 > thresholds[0]) {
    return "needs-improvement";
  }
  return "good";
}, "getRating");
const bindReporter = /* @__PURE__ */ __name((callback, metric, thresholds, reportAllChanges) => {
  let prevValue;
  let delta2;
  return (forceReport) => {
    if (metric.value >= 0) {
      if (forceReport || reportAllChanges) {
        delta2 = metric.value - (prevValue || 0);
        if (delta2 || prevValue === void 0) {
          prevValue = metric.value;
          metric.delta = delta2;
          metric.rating = getRating(metric.value, thresholds);
          callback(metric);
        }
      }
    }
  };
}, "bindReporter");
const WINDOW$4 = GLOBAL_OBJ;
const generateUniqueID = /* @__PURE__ */ __name(() => {
  return `v4-${Date.now()}-${Math.floor(Math.random() * (9e12 - 1)) + 1e12}`;
}, "generateUniqueID");
const getNavigationEntry = /* @__PURE__ */ __name((checkResponseStart = true) => {
  const navigationEntry = WINDOW$4.performance && WINDOW$4.performance.getEntriesByType && WINDOW$4.performance.getEntriesByType("navigation")[0];
  if (
    // sentry-specific change:
    // We don't want to check for responseStart for our own use of `getNavigationEntry`
    !checkResponseStart || navigationEntry && navigationEntry.responseStart > 0 && navigationEntry.responseStart < performance.now()
  ) {
    return navigationEntry;
  }
}, "getNavigationEntry");
const getActivationStart = /* @__PURE__ */ __name(() => {
  const navEntry = getNavigationEntry();
  return navEntry && navEntry.activationStart || 0;
}, "getActivationStart");
const initMetric = /* @__PURE__ */ __name((name2, value3) => {
  const navEntry = getNavigationEntry();
  let navigationType = "navigate";
  if (navEntry) {
    if (WINDOW$4.document && WINDOW$4.document.prerendering || getActivationStart() > 0) {
      navigationType = "prerender";
    } else if (WINDOW$4.document && WINDOW$4.document.wasDiscarded) {
      navigationType = "restore";
    } else if (navEntry.type) {
      navigationType = navEntry.type.replace(/_/g, "-");
    }
  }
  const entries = [];
  return {
    name: name2,
    value: typeof value3 === "undefined" ? -1 : value3,
    rating: "good",
    // If needed, will be updated when reported. `const` to keep the type from widening to `string`.
    delta: 0,
    entries,
    id: generateUniqueID(),
    navigationType
  };
}, "initMetric");
const observe = /* @__PURE__ */ __name((type, callback, opts) => {
  try {
    if (PerformanceObserver.supportedEntryTypes.includes(type)) {
      const po2 = new PerformanceObserver((list2) => {
        Promise.resolve().then(() => {
          callback(list2.getEntries());
        });
      });
      po2.observe(
        Object.assign(
          {
            type,
            buffered: true
          },
          opts || {}
        )
      );
      return po2;
    }
  } catch (e2) {
  }
  return;
}, "observe");
const onHidden = /* @__PURE__ */ __name((cb) => {
  const onHiddenOrPageHide = /* @__PURE__ */ __name((event) => {
    if (event.type === "pagehide" || WINDOW$4.document && WINDOW$4.document.visibilityState === "hidden") {
      cb(event);
    }
  }, "onHiddenOrPageHide");
  if (WINDOW$4.document) {
    addEventListener("visibilitychange", onHiddenOrPageHide, true);
    addEventListener("pagehide", onHiddenOrPageHide, true);
  }
}, "onHidden");
const runOnce = /* @__PURE__ */ __name((cb) => {
  let called = false;
  return () => {
    if (!called) {
      cb();
      called = true;
    }
  };
}, "runOnce");
let firstHiddenTime = -1;
const initHiddenTime = /* @__PURE__ */ __name(() => {
  return WINDOW$4.document.visibilityState === "hidden" && !WINDOW$4.document.prerendering ? 0 : Infinity;
}, "initHiddenTime");
const onVisibilityUpdate = /* @__PURE__ */ __name((event) => {
  if (WINDOW$4.document.visibilityState === "hidden" && firstHiddenTime > -1) {
    firstHiddenTime = event.type === "visibilitychange" ? event.timeStamp : 0;
    removeChangeListeners();
  }
}, "onVisibilityUpdate");
const addChangeListeners = /* @__PURE__ */ __name(() => {
  addEventListener("visibilitychange", onVisibilityUpdate, true);
  addEventListener("prerenderingchange", onVisibilityUpdate, true);
}, "addChangeListeners");
const removeChangeListeners = /* @__PURE__ */ __name(() => {
  removeEventListener("visibilitychange", onVisibilityUpdate, true);
  removeEventListener("prerenderingchange", onVisibilityUpdate, true);
}, "removeChangeListeners");
const getVisibilityWatcher = /* @__PURE__ */ __name(() => {
  if (WINDOW$4.document && firstHiddenTime < 0) {
    firstHiddenTime = initHiddenTime();
    addChangeListeners();
  }
  return {
    get firstHiddenTime() {
      return firstHiddenTime;
    }
  };
}, "getVisibilityWatcher");
const whenActivated = /* @__PURE__ */ __name((callback) => {
  if (WINDOW$4.document && WINDOW$4.document.prerendering) {
    addEventListener("prerenderingchange", () => callback(), true);
  } else {
    callback();
  }
}, "whenActivated");
const FCPThresholds = [1800, 3e3];
const onFCP = /* @__PURE__ */ __name((onReport, opts = {}) => {
  whenActivated(() => {
    const visibilityWatcher = getVisibilityWatcher();
    const metric = initMetric("FCP");
    let report;
    const handleEntries = /* @__PURE__ */ __name((entries) => {
      entries.forEach((entry) => {
        if (entry.name === "first-contentful-paint") {
          po2.disconnect();
          if (entry.startTime < visibilityWatcher.firstHiddenTime) {
            metric.value = Math.max(entry.startTime - getActivationStart(), 0);
            metric.entries.push(entry);
            report(true);
          }
        }
      });
    }, "handleEntries");
    const po2 = observe("paint", handleEntries);
    if (po2) {
      report = bindReporter(onReport, metric, FCPThresholds, opts.reportAllChanges);
    }
  });
}, "onFCP");
const CLSThresholds = [0.1, 0.25];
const onCLS = /* @__PURE__ */ __name((onReport, opts = {}) => {
  onFCP(
    runOnce(() => {
      const metric = initMetric("CLS", 0);
      let report;
      let sessionValue = 0;
      let sessionEntries = [];
      const handleEntries = /* @__PURE__ */ __name((entries) => {
        entries.forEach((entry) => {
          if (!entry.hadRecentInput) {
            const firstSessionEntry = sessionEntries[0];
            const lastSessionEntry = sessionEntries[sessionEntries.length - 1];
            if (sessionValue && firstSessionEntry && lastSessionEntry && entry.startTime - lastSessionEntry.startTime < 1e3 && entry.startTime - firstSessionEntry.startTime < 5e3) {
              sessionValue += entry.value;
              sessionEntries.push(entry);
            } else {
              sessionValue = entry.value;
              sessionEntries = [entry];
            }
          }
        });
        if (sessionValue > metric.value) {
          metric.value = sessionValue;
          metric.entries = sessionEntries;
          report();
        }
      }, "handleEntries");
      const po2 = observe("layout-shift", handleEntries);
      if (po2) {
        report = bindReporter(onReport, metric, CLSThresholds, opts.reportAllChanges);
        onHidden(() => {
          handleEntries(po2.takeRecords());
          report(true);
        });
        setTimeout(report, 0);
      }
    })
  );
}, "onCLS");
const FIDThresholds = [100, 300];
const onFID = /* @__PURE__ */ __name((onReport, opts = {}) => {
  whenActivated(() => {
    const visibilityWatcher = getVisibilityWatcher();
    const metric = initMetric("FID");
    let report;
    const handleEntry = /* @__PURE__ */ __name((entry) => {
      if (entry.startTime < visibilityWatcher.firstHiddenTime) {
        metric.value = entry.processingStart - entry.startTime;
        metric.entries.push(entry);
        report(true);
      }
    }, "handleEntry");
    const handleEntries = /* @__PURE__ */ __name((entries) => {
      entries.forEach(handleEntry);
    }, "handleEntries");
    const po2 = observe("first-input", handleEntries);
    report = bindReporter(onReport, metric, FIDThresholds, opts.reportAllChanges);
    if (po2) {
      onHidden(
        runOnce(() => {
          handleEntries(po2.takeRecords());
          po2.disconnect();
        })
      );
    }
  });
}, "onFID");
let interactionCountEstimate = 0;
let minKnownInteractionId = Infinity;
let maxKnownInteractionId = 0;
const updateEstimate = /* @__PURE__ */ __name((entries) => {
  entries.forEach((e2) => {
    if (e2.interactionId) {
      minKnownInteractionId = Math.min(minKnownInteractionId, e2.interactionId);
      maxKnownInteractionId = Math.max(maxKnownInteractionId, e2.interactionId);
      interactionCountEstimate = maxKnownInteractionId ? (maxKnownInteractionId - minKnownInteractionId) / 7 + 1 : 0;
    }
  });
}, "updateEstimate");
let po;
const getInteractionCount = /* @__PURE__ */ __name(() => {
  return po ? interactionCountEstimate : performance.interactionCount || 0;
}, "getInteractionCount");
const initInteractionCountPolyfill = /* @__PURE__ */ __name(() => {
  if ("interactionCount" in performance || po) return;
  po = observe("event", updateEstimate, {
    type: "event",
    buffered: true,
    durationThreshold: 0
  });
}, "initInteractionCountPolyfill");
const longestInteractionList = [];
const longestInteractionMap = /* @__PURE__ */ new Map();
const DEFAULT_DURATION_THRESHOLD = 40;
let prevInteractionCount = 0;
const getInteractionCountForNavigation = /* @__PURE__ */ __name(() => {
  return getInteractionCount() - prevInteractionCount;
}, "getInteractionCountForNavigation");
const estimateP98LongestInteraction = /* @__PURE__ */ __name(() => {
  const candidateInteractionIndex = Math.min(
    longestInteractionList.length - 1,
    Math.floor(getInteractionCountForNavigation() / 50)
  );
  return longestInteractionList[candidateInteractionIndex];
}, "estimateP98LongestInteraction");
const MAX_INTERACTIONS_TO_CONSIDER = 10;
const entryPreProcessingCallbacks = [];
const processInteractionEntry = /* @__PURE__ */ __name((entry) => {
  entryPreProcessingCallbacks.forEach((cb) => cb(entry));
  if (!(entry.interactionId || entry.entryType === "first-input")) return;
  const minLongestInteraction = longestInteractionList[longestInteractionList.length - 1];
  const existingInteraction = longestInteractionMap.get(entry.interactionId);
  if (existingInteraction || longestInteractionList.length < MAX_INTERACTIONS_TO_CONSIDER || minLongestInteraction && entry.duration > minLongestInteraction.latency) {
    if (existingInteraction) {
      if (entry.duration > existingInteraction.latency) {
        existingInteraction.entries = [entry];
        existingInteraction.latency = entry.duration;
      } else if (entry.duration === existingInteraction.latency && entry.startTime === (existingInteraction.entries[0] && existingInteraction.entries[0].startTime)) {
        existingInteraction.entries.push(entry);
      }
    } else {
      const interaction = {
        id: entry.interactionId,
        latency: entry.duration,
        entries: [entry]
      };
      longestInteractionMap.set(interaction.id, interaction);
      longestInteractionList.push(interaction);
    }
    longestInteractionList.sort((a2, b2) => b2.latency - a2.latency);
    if (longestInteractionList.length > MAX_INTERACTIONS_TO_CONSIDER) {
      longestInteractionList.splice(MAX_INTERACTIONS_TO_CONSIDER).forEach((i2) => longestInteractionMap.delete(i2.id));
    }
  }
}, "processInteractionEntry");
const whenIdle = /* @__PURE__ */ __name((cb) => {
  const rIC = WINDOW$4.requestIdleCallback || WINDOW$4.setTimeout;
  let handle = -1;
  cb = runOnce(cb);
  if (WINDOW$4.document && WINDOW$4.document.visibilityState === "hidden") {
    cb();
  } else {
    handle = rIC(cb);
    onHidden(cb);
  }
  return handle;
}, "whenIdle");
const INPThresholds = [200, 500];
const onINP = /* @__PURE__ */ __name((onReport, opts = {}) => {
  if (!("PerformanceEventTiming" in WINDOW$4 && "interactionId" in PerformanceEventTiming.prototype)) {
    return;
  }
  whenActivated(() => {
    initInteractionCountPolyfill();
    const metric = initMetric("INP");
    let report;
    const handleEntries = /* @__PURE__ */ __name((entries) => {
      whenIdle(() => {
        entries.forEach(processInteractionEntry);
        const inp = estimateP98LongestInteraction();
        if (inp && inp.latency !== metric.value) {
          metric.value = inp.latency;
          metric.entries = inp.entries;
          report();
        }
      });
    }, "handleEntries");
    const po2 = observe("event", handleEntries, {
      // Event Timing entries have their durations rounded to the nearest 8ms,
      // so a duration of 40ms would be any event that spans 2.5 or more frames
      // at 60Hz. This threshold is chosen to strike a balance between usefulness
      // and performance. Running this callback for any interaction that spans
      // just one or two frames is likely not worth the insight that could be
      // gained.
      durationThreshold: opts.durationThreshold != null ? opts.durationThreshold : DEFAULT_DURATION_THRESHOLD
    });
    report = bindReporter(onReport, metric, INPThresholds, opts.reportAllChanges);
    if (po2) {
      po2.observe({ type: "first-input", buffered: true });
      onHidden(() => {
        handleEntries(po2.takeRecords());
        report(true);
      });
    }
  });
}, "onINP");
const LCPThresholds = [2500, 4e3];
const reportedMetricIDs = {};
const onLCP = /* @__PURE__ */ __name((onReport, opts = {}) => {
  whenActivated(() => {
    const visibilityWatcher = getVisibilityWatcher();
    const metric = initMetric("LCP");
    let report;
    const handleEntries = /* @__PURE__ */ __name((entries) => {
      if (!opts.reportAllChanges) {
        entries = entries.slice(-1);
      }
      entries.forEach((entry) => {
        if (entry.startTime < visibilityWatcher.firstHiddenTime) {
          metric.value = Math.max(entry.startTime - getActivationStart(), 0);
          metric.entries = [entry];
          report();
        }
      });
    }, "handleEntries");
    const po2 = observe("largest-contentful-paint", handleEntries);
    if (po2) {
      report = bindReporter(onReport, metric, LCPThresholds, opts.reportAllChanges);
      const stopListening = runOnce(() => {
        if (!reportedMetricIDs[metric.id]) {
          handleEntries(po2.takeRecords());
          po2.disconnect();
          reportedMetricIDs[metric.id] = true;
          report(true);
        }
      });
      ["keydown", "click"].forEach((type) => {
        if (WINDOW$4.document) {
          addEventListener(type, () => whenIdle(stopListening), {
            once: true,
            capture: true
          });
        }
      });
      onHidden(stopListening);
    }
  });
}, "onLCP");
const TTFBThresholds = [800, 1800];
const whenReady = /* @__PURE__ */ __name((callback) => {
  if (WINDOW$4.document && WINDOW$4.document.prerendering) {
    whenActivated(() => whenReady(callback));
  } else if (WINDOW$4.document && WINDOW$4.document.readyState !== "complete") {
    addEventListener("load", () => whenReady(callback), true);
  } else {
    setTimeout(callback, 0);
  }
}, "whenReady");
const onTTFB = /* @__PURE__ */ __name((onReport, opts = {}) => {
  const metric = initMetric("TTFB");
  const report = bindReporter(onReport, metric, TTFBThresholds, opts.reportAllChanges);
  whenReady(() => {
    const navigationEntry = getNavigationEntry();
    if (navigationEntry) {
      metric.value = Math.max(navigationEntry.responseStart - getActivationStart(), 0);
      metric.entries = [navigationEntry];
      report(true);
    }
  });
}, "onTTFB");
const handlers$3 = {};
const instrumented = {};
let _previousCls;
let _previousFid;
let _previousLcp;
let _previousTtfb;
let _previousInp;
function addClsInstrumentationHandler(callback, stopOnCallback = false) {
  return addMetricObserver("cls", callback, instrumentCls, _previousCls, stopOnCallback);
}
__name(addClsInstrumentationHandler, "addClsInstrumentationHandler");
function addLcpInstrumentationHandler(callback, stopOnCallback = false) {
  return addMetricObserver("lcp", callback, instrumentLcp, _previousLcp, stopOnCallback);
}
__name(addLcpInstrumentationHandler, "addLcpInstrumentationHandler");
function addFidInstrumentationHandler(callback) {
  return addMetricObserver("fid", callback, instrumentFid, _previousFid);
}
__name(addFidInstrumentationHandler, "addFidInstrumentationHandler");
function addTtfbInstrumentationHandler(callback) {
  return addMetricObserver("ttfb", callback, instrumentTtfb, _previousTtfb);
}
__name(addTtfbInstrumentationHandler, "addTtfbInstrumentationHandler");
function addInpInstrumentationHandler(callback) {
  return addMetricObserver("inp", callback, instrumentInp, _previousInp);
}
__name(addInpInstrumentationHandler, "addInpInstrumentationHandler");
function addPerformanceInstrumentationHandler(type, callback) {
  addHandler(type, callback);
  if (!instrumented[type]) {
    instrumentPerformanceObserver(type);
    instrumented[type] = true;
  }
  return getCleanupCallback(type, callback);
}
__name(addPerformanceInstrumentationHandler, "addPerformanceInstrumentationHandler");
function triggerHandlers(type, data30) {
  const typeHandlers = handlers$3[type];
  if (!typeHandlers || !typeHandlers.length) {
    return;
  }
  for (const handler14 of typeHandlers) {
    try {
      handler14(data30);
    } catch (e2) {
      DEBUG_BUILD$3 && logger$2.error(
        `Error while triggering instrumentation handler.
Type: ${type}
Name: ${getFunctionName(handler14)}
Error:`,
        e2
      );
    }
  }
}
__name(triggerHandlers, "triggerHandlers");
function instrumentCls() {
  return onCLS(
    (metric) => {
      triggerHandlers("cls", {
        metric
      });
      _previousCls = metric;
    },
    // We want the callback to be called whenever the CLS value updates.
    // By default, the callback is only called when the tab goes to the background.
    { reportAllChanges: true }
  );
}
__name(instrumentCls, "instrumentCls");
function instrumentFid() {
  return onFID((metric) => {
    triggerHandlers("fid", {
      metric
    });
    _previousFid = metric;
  });
}
__name(instrumentFid, "instrumentFid");
function instrumentLcp() {
  return onLCP(
    (metric) => {
      triggerHandlers("lcp", {
        metric
      });
      _previousLcp = metric;
    },
    // We want the callback to be called whenever the LCP value updates.
    // By default, the callback is only called when the tab goes to the background.
    { reportAllChanges: true }
  );
}
__name(instrumentLcp, "instrumentLcp");
function instrumentTtfb() {
  return onTTFB((metric) => {
    triggerHandlers("ttfb", {
      metric
    });
    _previousTtfb = metric;
  });
}
__name(instrumentTtfb, "instrumentTtfb");
function instrumentInp() {
  return onINP((metric) => {
    triggerHandlers("inp", {
      metric
    });
    _previousInp = metric;
  });
}
__name(instrumentInp, "instrumentInp");
function addMetricObserver(type, callback, instrumentFn, previousValue, stopOnCallback = false) {
  addHandler(type, callback);
  let stopListening;
  if (!instrumented[type]) {
    stopListening = instrumentFn();
    instrumented[type] = true;
  }
  if (previousValue) {
    callback({ metric: previousValue });
  }
  return getCleanupCallback(type, callback, stopOnCallback ? stopListening : void 0);
}
__name(addMetricObserver, "addMetricObserver");
function instrumentPerformanceObserver(type) {
  const options5 = {};
  if (type === "event") {
    options5.durationThreshold = 0;
  }
  observe(
    type,
    (entries) => {
      triggerHandlers(type, { entries });
    },
    options5
  );
}
__name(instrumentPerformanceObserver, "instrumentPerformanceObserver");
function addHandler(type, handler14) {
  handlers$3[type] = handlers$3[type] || [];
  handlers$3[type].push(handler14);
}
__name(addHandler, "addHandler");
function getCleanupCallback(type, callback, stopListening) {
  return () => {
    if (stopListening) {
      stopListening();
    }
    const typeHandlers = handlers$3[type];
    if (!typeHandlers) {
      return;
    }
    const index2 = typeHandlers.indexOf(callback);
    if (index2 !== -1) {
      typeHandlers.splice(index2, 1);
    }
  };
}
__name(getCleanupCallback, "getCleanupCallback");
function isPerformanceEventTiming(entry) {
  return "duration" in entry;
}
__name(isPerformanceEventTiming, "isPerformanceEventTiming");
function isMeasurementValue(value3) {
  return typeof value3 === "number" && isFinite(value3);
}
__name(isMeasurementValue, "isMeasurementValue");
function startAndEndSpan(parentSpan, startTimeInSeconds, endTime, { ...ctx }) {
  const parentStartTime = spanToJSON(parentSpan).start_timestamp;
  if (parentStartTime && parentStartTime > startTimeInSeconds) {
    if (typeof parentSpan.updateStartTime === "function") {
      parentSpan.updateStartTime(startTimeInSeconds);
    }
  }
  return withActiveSpan(parentSpan, () => {
    const span = startInactiveSpan({
      startTime: startTimeInSeconds,
      ...ctx
    });
    if (span) {
      span.end(endTime);
    }
    return span;
  });
}
__name(startAndEndSpan, "startAndEndSpan");
function startStandaloneWebVitalSpan(options5) {
  const client = getClient();
  if (!client) {
    return;
  }
  const { name: name2, transaction, attributes: passedAttributes, startTime } = options5;
  const { release, environment } = client.getOptions();
  const replay = client.getIntegrationByName("Replay");
  const replayId = replay && replay.getReplayId();
  const scope = getCurrentScope$1();
  const user = scope.getUser();
  const userDisplay = user !== void 0 ? user.email || user.id || user.ip_address : void 0;
  let profileId;
  try {
    profileId = scope.getScopeData().contexts.profile.profile_id;
  } catch (e2) {
  }
  const attributes = {
    release,
    environment,
    user: userDisplay || void 0,
    profile_id: profileId || void 0,
    replay_id: replayId || void 0,
    transaction,
    // Web vital score calculation relies on the user agent to account for different
    // browsers setting different thresholds for what is considered a good/meh/bad value.
    // For example: Chrome vs. Chrome Mobile
    "user_agent.original": WINDOW$4.navigator && WINDOW$4.navigator.userAgent,
    ...passedAttributes
  };
  return startInactiveSpan({
    name: name2,
    attributes,
    startTime,
    experimental: {
      standalone: true
    }
  });
}
__name(startStandaloneWebVitalSpan, "startStandaloneWebVitalSpan");
function getBrowserPerformanceAPI() {
  return WINDOW$4 && WINDOW$4.addEventListener && WINDOW$4.performance;
}
__name(getBrowserPerformanceAPI, "getBrowserPerformanceAPI");
function msToSec(time) {
  return time / 1e3;
}
__name(msToSec, "msToSec");
function trackClsAsStandaloneSpan() {
  let standaloneCLsValue = 0;
  let standaloneClsEntry;
  let pageloadSpanId;
  if (!supportsLayoutShift()) {
    return;
  }
  let sentSpan = false;
  function _collectClsOnce() {
    if (sentSpan) {
      return;
    }
    sentSpan = true;
    if (pageloadSpanId) {
      sendStandaloneClsSpan(standaloneCLsValue, standaloneClsEntry, pageloadSpanId);
    }
    cleanupClsHandler();
  }
  __name(_collectClsOnce, "_collectClsOnce");
  const cleanupClsHandler = addClsInstrumentationHandler(({ metric }) => {
    const entry = metric.entries[metric.entries.length - 1];
    if (!entry) {
      return;
    }
    standaloneCLsValue = metric.value;
    standaloneClsEntry = entry;
  }, true);
  onHidden(() => {
    _collectClsOnce();
  });
  setTimeout(() => {
    const client = getClient();
    if (!client) {
      return;
    }
    const unsubscribeStartNavigation = client.on("startNavigationSpan", () => {
      _collectClsOnce();
      unsubscribeStartNavigation && unsubscribeStartNavigation();
    });
    const activeSpan = getActiveSpan();
    const rootSpan = activeSpan && getRootSpan(activeSpan);
    const spanJSON = rootSpan && spanToJSON(rootSpan);
    if (spanJSON && spanJSON.op === "pageload") {
      pageloadSpanId = rootSpan.spanContext().spanId;
    }
  }, 0);
}
__name(trackClsAsStandaloneSpan, "trackClsAsStandaloneSpan");
function sendStandaloneClsSpan(clsValue, entry, pageloadSpanId) {
  DEBUG_BUILD$3 && logger$2.log(`Sending CLS span (${clsValue})`);
  const startTime = msToSec((browserPerformanceTimeOrigin || 0) + (entry && entry.startTime || 0));
  const routeName = getCurrentScope$1().getScopeData().transactionName;
  const name2 = entry ? htmlTreeAsString(entry.sources[0] && entry.sources[0].node) : "Layout shift";
  const attributes = dropUndefinedKeys({
    [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.http.browser.cls",
    [SEMANTIC_ATTRIBUTE_SENTRY_OP]: "ui.webvital.cls",
    [SEMANTIC_ATTRIBUTE_EXCLUSIVE_TIME]: entry && entry.duration || 0,
    // attach the pageload span id to the CLS span so that we can link them in the UI
    "sentry.pageload.span_id": pageloadSpanId
  });
  const span = startStandaloneWebVitalSpan({
    name: name2,
    transaction: routeName,
    attributes,
    startTime
  });
  if (span) {
    span.addEvent("cls", {
      [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_UNIT]: "",
      [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_VALUE]: clsValue
    });
    span.end(startTime);
  }
}
__name(sendStandaloneClsSpan, "sendStandaloneClsSpan");
function supportsLayoutShift() {
  try {
    return PerformanceObserver.supportedEntryTypes.includes("layout-shift");
  } catch (e2) {
    return false;
  }
}
__name(supportsLayoutShift, "supportsLayoutShift");
const MAX_INT_AS_BYTES = 2147483647;
let _performanceCursor = 0;
let _measurements = {};
let _lcpEntry;
let _clsEntry;
function startTrackingWebVitals({ recordClsStandaloneSpans }) {
  const performance2 = getBrowserPerformanceAPI();
  if (performance2 && browserPerformanceTimeOrigin) {
    if (performance2.mark) {
      WINDOW$4.performance.mark("sentry-tracing-init");
    }
    const fidCleanupCallback = _trackFID();
    const lcpCleanupCallback = _trackLCP();
    const ttfbCleanupCallback = _trackTtfb();
    const clsCleanupCallback = recordClsStandaloneSpans ? trackClsAsStandaloneSpan() : _trackCLS();
    return () => {
      fidCleanupCallback();
      lcpCleanupCallback();
      ttfbCleanupCallback();
      clsCleanupCallback && clsCleanupCallback();
    };
  }
  return () => void 0;
}
__name(startTrackingWebVitals, "startTrackingWebVitals");
function startTrackingLongTasks() {
  addPerformanceInstrumentationHandler("longtask", ({ entries }) => {
    const parent = getActiveSpan();
    if (!parent) {
      return;
    }
    const { op: parentOp, start_timestamp: parentStartTimestamp } = spanToJSON(parent);
    for (const entry of entries) {
      const startTime = msToSec(browserPerformanceTimeOrigin + entry.startTime);
      const duration = msToSec(entry.duration);
      if (parentOp === "navigation" && parentStartTimestamp && startTime < parentStartTimestamp) {
        continue;
      }
      startAndEndSpan(parent, startTime, startTime + duration, {
        name: "Main UI thread blocked",
        op: "ui.long-task",
        attributes: {
          [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
        }
      });
    }
  });
}
__name(startTrackingLongTasks, "startTrackingLongTasks");
function startTrackingLongAnimationFrames() {
  const observer = new PerformanceObserver((list2) => {
    const parent = getActiveSpan();
    if (!parent) {
      return;
    }
    for (const entry of list2.getEntries()) {
      if (!entry.scripts[0]) {
        continue;
      }
      const startTime = msToSec(browserPerformanceTimeOrigin + entry.startTime);
      const { start_timestamp: parentStartTimestamp, op: parentOp } = spanToJSON(parent);
      if (parentOp === "navigation" && parentStartTimestamp && startTime < parentStartTimestamp) {
        continue;
      }
      const duration = msToSec(entry.duration);
      const attributes = {
        [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
      };
      const initialScript = entry.scripts[0];
      const { invoker, invokerType, sourceURL, sourceFunctionName, sourceCharPosition } = initialScript;
      attributes["browser.script.invoker"] = invoker;
      attributes["browser.script.invoker_type"] = invokerType;
      if (sourceURL) {
        attributes["code.filepath"] = sourceURL;
      }
      if (sourceFunctionName) {
        attributes["code.function"] = sourceFunctionName;
      }
      if (sourceCharPosition !== -1) {
        attributes["browser.script.source_char_position"] = sourceCharPosition;
      }
      startAndEndSpan(parent, startTime, startTime + duration, {
        name: "Main UI thread blocked",
        op: "ui.long-animation-frame",
        attributes
      });
    }
  });
  observer.observe({ type: "long-animation-frame", buffered: true });
}
__name(startTrackingLongAnimationFrames, "startTrackingLongAnimationFrames");
function startTrackingInteractions() {
  addPerformanceInstrumentationHandler("event", ({ entries }) => {
    const parent = getActiveSpan();
    if (!parent) {
      return;
    }
    for (const entry of entries) {
      if (entry.name === "click") {
        const startTime = msToSec(browserPerformanceTimeOrigin + entry.startTime);
        const duration = msToSec(entry.duration);
        const spanOptions = {
          name: htmlTreeAsString(entry.target),
          op: `ui.interaction.${entry.name}`,
          startTime,
          attributes: {
            [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
          }
        };
        const componentName = getComponentName$1(entry.target);
        if (componentName) {
          spanOptions.attributes["ui.component_name"] = componentName;
        }
        startAndEndSpan(parent, startTime, startTime + duration, spanOptions);
      }
    }
  });
}
__name(startTrackingInteractions, "startTrackingInteractions");
function _trackCLS() {
  return addClsInstrumentationHandler(({ metric }) => {
    const entry = metric.entries[metric.entries.length - 1];
    if (!entry) {
      return;
    }
    _measurements["cls"] = { value: metric.value, unit: "" };
    _clsEntry = entry;
  }, true);
}
__name(_trackCLS, "_trackCLS");
function _trackLCP() {
  return addLcpInstrumentationHandler(({ metric }) => {
    const entry = metric.entries[metric.entries.length - 1];
    if (!entry) {
      return;
    }
    _measurements["lcp"] = { value: metric.value, unit: "millisecond" };
    _lcpEntry = entry;
  }, true);
}
__name(_trackLCP, "_trackLCP");
function _trackFID() {
  return addFidInstrumentationHandler(({ metric }) => {
    const entry = metric.entries[metric.entries.length - 1];
    if (!entry) {
      return;
    }
    const timeOrigin = msToSec(browserPerformanceTimeOrigin);
    const startTime = msToSec(entry.startTime);
    _measurements["fid"] = { value: metric.value, unit: "millisecond" };
    _measurements["mark.fid"] = { value: timeOrigin + startTime, unit: "second" };
  });
}
__name(_trackFID, "_trackFID");
function _trackTtfb() {
  return addTtfbInstrumentationHandler(({ metric }) => {
    const entry = metric.entries[metric.entries.length - 1];
    if (!entry) {
      return;
    }
    _measurements["ttfb"] = { value: metric.value, unit: "millisecond" };
  });
}
__name(_trackTtfb, "_trackTtfb");
function addPerformanceEntries(span, options5) {
  const performance2 = getBrowserPerformanceAPI();
  if (!performance2 || !performance2.getEntries || !browserPerformanceTimeOrigin) {
    return;
  }
  const timeOrigin = msToSec(browserPerformanceTimeOrigin);
  const performanceEntries = performance2.getEntries();
  const { op, start_timestamp: transactionStartTime } = spanToJSON(span);
  performanceEntries.slice(_performanceCursor).forEach((entry) => {
    const startTime = msToSec(entry.startTime);
    const duration = msToSec(
      // Inexplicably, Chrome sometimes emits a negative duration. We need to work around this.
      // There is a SO post attempting to explain this, but it leaves one with open questions: https://stackoverflow.com/questions/23191918/peformance-getentries-and-negative-duration-display
      // The way we clamp the value is probably not accurate, since we have observed this happen for things that may take a while to load, like for example the replay worker.
      // TODO: Investigate why this happens and how to properly mitigate. For now, this is a workaround to prevent transactions being dropped due to negative duration spans.
      Math.max(0, entry.duration)
    );
    if (op === "navigation" && transactionStartTime && timeOrigin + startTime < transactionStartTime) {
      return;
    }
    switch (entry.entryType) {
      case "navigation": {
        _addNavigationSpans(span, entry, timeOrigin);
        break;
      }
      case "mark":
      case "paint":
      case "measure": {
        _addMeasureSpans(span, entry, startTime, duration, timeOrigin);
        const firstHidden = getVisibilityWatcher();
        const shouldRecord = entry.startTime < firstHidden.firstHiddenTime;
        if (entry.name === "first-paint" && shouldRecord) {
          _measurements["fp"] = { value: entry.startTime, unit: "millisecond" };
        }
        if (entry.name === "first-contentful-paint" && shouldRecord) {
          _measurements["fcp"] = { value: entry.startTime, unit: "millisecond" };
        }
        break;
      }
      case "resource": {
        _addResourceSpans(span, entry, entry.name, startTime, duration, timeOrigin);
        break;
      }
    }
  });
  _performanceCursor = Math.max(performanceEntries.length - 1, 0);
  _trackNavigator(span);
  if (op === "pageload") {
    _addTtfbRequestTimeToMeasurements(_measurements);
    const fidMark = _measurements["mark.fid"];
    if (fidMark && _measurements["fid"]) {
      startAndEndSpan(span, fidMark.value, fidMark.value + msToSec(_measurements["fid"].value), {
        name: "first input delay",
        op: "ui.action",
        attributes: {
          [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
        }
      });
      delete _measurements["mark.fid"];
    }
    if (!("fcp" in _measurements) || !options5.recordClsOnPageloadSpan) {
      delete _measurements.cls;
    }
    Object.entries(_measurements).forEach(([measurementName, measurement]) => {
      setMeasurement(measurementName, measurement.value, measurement.unit);
    });
    span.setAttribute("performance.timeOrigin", timeOrigin);
    span.setAttribute("performance.activationStart", getActivationStart());
    _setWebVitalAttributes(span);
  }
  _lcpEntry = void 0;
  _clsEntry = void 0;
  _measurements = {};
}
__name(addPerformanceEntries, "addPerformanceEntries");
function _addMeasureSpans(span, entry, startTime, duration, timeOrigin) {
  const navEntry = getNavigationEntry(false);
  const requestTime = msToSec(navEntry ? navEntry.requestStart : 0);
  const measureStartTimestamp = timeOrigin + Math.max(startTime, requestTime);
  const startTimeStamp = timeOrigin + startTime;
  const measureEndTimestamp = startTimeStamp + duration;
  const attributes = {
    [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.resource.browser.metrics"
  };
  if (measureStartTimestamp !== startTimeStamp) {
    attributes["sentry.browser.measure_happened_before_request"] = true;
    attributes["sentry.browser.measure_start_time"] = measureStartTimestamp;
  }
  startAndEndSpan(span, measureStartTimestamp, measureEndTimestamp, {
    name: entry.name,
    op: entry.entryType,
    attributes
  });
  return measureStartTimestamp;
}
__name(_addMeasureSpans, "_addMeasureSpans");
function _addNavigationSpans(span, entry, timeOrigin) {
  ["unloadEvent", "redirect", "domContentLoadedEvent", "loadEvent", "connect"].forEach((event) => {
    _addPerformanceNavigationTiming(span, entry, event, timeOrigin);
  });
  _addPerformanceNavigationTiming(span, entry, "secureConnection", timeOrigin, "TLS/SSL");
  _addPerformanceNavigationTiming(span, entry, "fetch", timeOrigin, "cache");
  _addPerformanceNavigationTiming(span, entry, "domainLookup", timeOrigin, "DNS");
  _addRequest(span, entry, timeOrigin);
}
__name(_addNavigationSpans, "_addNavigationSpans");
function _addPerformanceNavigationTiming(span, entry, event, timeOrigin, name2 = event) {
  const eventEnd = _getEndPropertyNameForNavigationTiming(event);
  const end = entry[eventEnd];
  const start2 = entry[`${event}Start`];
  if (!start2 || !end) {
    return;
  }
  startAndEndSpan(span, timeOrigin + msToSec(start2), timeOrigin + msToSec(end), {
    op: `browser.${name2}`,
    name: entry.name,
    attributes: {
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
    }
  });
}
__name(_addPerformanceNavigationTiming, "_addPerformanceNavigationTiming");
function _getEndPropertyNameForNavigationTiming(event) {
  if (event === "secureConnection") {
    return "connectEnd";
  }
  if (event === "fetch") {
    return "domainLookupStart";
  }
  return `${event}End`;
}
__name(_getEndPropertyNameForNavigationTiming, "_getEndPropertyNameForNavigationTiming");
function _addRequest(span, entry, timeOrigin) {
  const requestStartTimestamp = timeOrigin + msToSec(entry.requestStart);
  const responseEndTimestamp = timeOrigin + msToSec(entry.responseEnd);
  const responseStartTimestamp = timeOrigin + msToSec(entry.responseStart);
  if (entry.responseEnd) {
    startAndEndSpan(span, requestStartTimestamp, responseEndTimestamp, {
      op: "browser.request",
      name: entry.name,
      attributes: {
        [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
      }
    });
    startAndEndSpan(span, responseStartTimestamp, responseEndTimestamp, {
      op: "browser.response",
      name: entry.name,
      attributes: {
        [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.browser.metrics"
      }
    });
  }
}
__name(_addRequest, "_addRequest");
function _addResourceSpans(span, entry, resourceUrl, startTime, duration, timeOrigin) {
  if (entry.initiatorType === "xmlhttprequest" || entry.initiatorType === "fetch") {
    return;
  }
  const parsedUrl = parseUrl$1(resourceUrl);
  const attributes = {
    [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.resource.browser.metrics"
  };
  setResourceEntrySizeData(attributes, entry, "transferSize", "http.response_transfer_size");
  setResourceEntrySizeData(attributes, entry, "encodedBodySize", "http.response_content_length");
  setResourceEntrySizeData(attributes, entry, "decodedBodySize", "http.decoded_response_content_length");
  const deliveryType = entry.deliveryType;
  if (deliveryType != null) {
    attributes["http.response_delivery_type"] = deliveryType;
  }
  const renderBlockingStatus = entry.renderBlockingStatus;
  if (renderBlockingStatus) {
    attributes["resource.render_blocking_status"] = renderBlockingStatus;
  }
  if (parsedUrl.protocol) {
    attributes["url.scheme"] = parsedUrl.protocol.split(":").pop();
  }
  if (parsedUrl.host) {
    attributes["server.address"] = parsedUrl.host;
  }
  attributes["url.same_origin"] = resourceUrl.includes(WINDOW$4.location.origin);
  const startTimestamp = timeOrigin + startTime;
  const endTimestamp = startTimestamp + duration;
  startAndEndSpan(span, startTimestamp, endTimestamp, {
    name: resourceUrl.replace(WINDOW$4.location.origin, ""),
    op: entry.initiatorType ? `resource.${entry.initiatorType}` : "resource.other",
    attributes
  });
}
__name(_addResourceSpans, "_addResourceSpans");
function _trackNavigator(span) {
  const navigator2 = WINDOW$4.navigator;
  if (!navigator2) {
    return;
  }
  const connection = navigator2.connection;
  if (connection) {
    if (connection.effectiveType) {
      span.setAttribute("effectiveConnectionType", connection.effectiveType);
    }
    if (connection.type) {
      span.setAttribute("connectionType", connection.type);
    }
    if (isMeasurementValue(connection.rtt)) {
      _measurements["connection.rtt"] = { value: connection.rtt, unit: "millisecond" };
    }
  }
  if (isMeasurementValue(navigator2.deviceMemory)) {
    span.setAttribute("deviceMemory", `${navigator2.deviceMemory} GB`);
  }
  if (isMeasurementValue(navigator2.hardwareConcurrency)) {
    span.setAttribute("hardwareConcurrency", String(navigator2.hardwareConcurrency));
  }
}
__name(_trackNavigator, "_trackNavigator");
function _setWebVitalAttributes(span) {
  if (_lcpEntry) {
    if (_lcpEntry.element) {
      span.setAttribute("lcp.element", htmlTreeAsString(_lcpEntry.element));
    }
    if (_lcpEntry.id) {
      span.setAttribute("lcp.id", _lcpEntry.id);
    }
    if (_lcpEntry.url) {
      span.setAttribute("lcp.url", _lcpEntry.url.trim().slice(0, 200));
    }
    if (_lcpEntry.loadTime != null) {
      span.setAttribute("lcp.loadTime", _lcpEntry.loadTime);
    }
    if (_lcpEntry.renderTime != null) {
      span.setAttribute("lcp.renderTime", _lcpEntry.renderTime);
    }
    span.setAttribute("lcp.size", _lcpEntry.size);
  }
  if (_clsEntry && _clsEntry.sources) {
    _clsEntry.sources.forEach(
      (source, index2) => span.setAttribute(`cls.source.${index2 + 1}`, htmlTreeAsString(source.node))
    );
  }
}
__name(_setWebVitalAttributes, "_setWebVitalAttributes");
function setResourceEntrySizeData(attributes, entry, key, dataKey) {
  const entryVal = entry[key];
  if (entryVal != null && entryVal < MAX_INT_AS_BYTES) {
    attributes[dataKey] = entryVal;
  }
}
__name(setResourceEntrySizeData, "setResourceEntrySizeData");
function _addTtfbRequestTimeToMeasurements(_measurements2) {
  const navEntry = getNavigationEntry(false);
  if (!navEntry) {
    return;
  }
  const { responseStart, requestStart } = navEntry;
  if (requestStart <= responseStart) {
    _measurements2["ttfb.requestTime"] = {
      value: responseStart - requestStart,
      unit: "millisecond"
    };
  }
}
__name(_addTtfbRequestTimeToMeasurements, "_addTtfbRequestTimeToMeasurements");
const DEBOUNCE_DURATION = 1e3;
let debounceTimerID;
let lastCapturedEventType;
let lastCapturedEventTargetId;
function addClickKeypressInstrumentationHandler(handler14) {
  const type = "dom";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentDOM);
}
__name(addClickKeypressInstrumentationHandler, "addClickKeypressInstrumentationHandler");
function instrumentDOM() {
  if (!WINDOW$4.document) {
    return;
  }
  const triggerDOMHandler = triggerHandlers$1.bind(null, "dom");
  const globalDOMEventHandler = makeDOMEventHandler(triggerDOMHandler, true);
  WINDOW$4.document.addEventListener("click", globalDOMEventHandler, false);
  WINDOW$4.document.addEventListener("keypress", globalDOMEventHandler, false);
  ["EventTarget", "Node"].forEach((target2) => {
    const globalObject = WINDOW$4;
    const targetObj = globalObject[target2];
    const proto = targetObj && targetObj.prototype;
    if (!proto || !proto.hasOwnProperty || !proto.hasOwnProperty("addEventListener")) {
      return;
    }
    fill(proto, "addEventListener", function(originalAddEventListener) {
      return function(type, listener, options5) {
        if (type === "click" || type == "keypress") {
          try {
            const handlers2 = this.__sentry_instrumentation_handlers__ = this.__sentry_instrumentation_handlers__ || {};
            const handlerForType = handlers2[type] = handlers2[type] || { refCount: 0 };
            if (!handlerForType.handler) {
              const handler14 = makeDOMEventHandler(triggerDOMHandler);
              handlerForType.handler = handler14;
              originalAddEventListener.call(this, type, handler14, options5);
            }
            handlerForType.refCount++;
          } catch (e2) {
          }
        }
        return originalAddEventListener.call(this, type, listener, options5);
      };
    });
    fill(
      proto,
      "removeEventListener",
      function(originalRemoveEventListener) {
        return function(type, listener, options5) {
          if (type === "click" || type == "keypress") {
            try {
              const handlers2 = this.__sentry_instrumentation_handlers__ || {};
              const handlerForType = handlers2[type];
              if (handlerForType) {
                handlerForType.refCount--;
                if (handlerForType.refCount <= 0) {
                  originalRemoveEventListener.call(this, type, handlerForType.handler, options5);
                  handlerForType.handler = void 0;
                  delete handlers2[type];
                }
                if (Object.keys(handlers2).length === 0) {
                  delete this.__sentry_instrumentation_handlers__;
                }
              }
            } catch (e2) {
            }
          }
          return originalRemoveEventListener.call(this, type, listener, options5);
        };
      }
    );
  });
}
__name(instrumentDOM, "instrumentDOM");
function isSimilarToLastCapturedEvent(event) {
  if (event.type !== lastCapturedEventType) {
    return false;
  }
  try {
    if (!event.target || event.target._sentryId !== lastCapturedEventTargetId) {
      return false;
    }
  } catch (e2) {
  }
  return true;
}
__name(isSimilarToLastCapturedEvent, "isSimilarToLastCapturedEvent");
function shouldSkipDOMEvent(eventType, target2) {
  if (eventType !== "keypress") {
    return false;
  }
  if (!target2 || !target2.tagName) {
    return true;
  }
  if (target2.tagName === "INPUT" || target2.tagName === "TEXTAREA" || target2.isContentEditable) {
    return false;
  }
  return true;
}
__name(shouldSkipDOMEvent, "shouldSkipDOMEvent");
function makeDOMEventHandler(handler14, globalListener = false) {
  return (event) => {
    if (!event || event["_sentryCaptured"]) {
      return;
    }
    const target2 = getEventTarget$1(event);
    if (shouldSkipDOMEvent(event.type, target2)) {
      return;
    }
    addNonEnumerableProperty(event, "_sentryCaptured", true);
    if (target2 && !target2._sentryId) {
      addNonEnumerableProperty(target2, "_sentryId", uuid4());
    }
    const name2 = event.type === "keypress" ? "input" : event.type;
    if (!isSimilarToLastCapturedEvent(event)) {
      const handlerData = { event, name: name2, global: globalListener };
      handler14(handlerData);
      lastCapturedEventType = event.type;
      lastCapturedEventTargetId = target2 ? target2._sentryId : void 0;
    }
    clearTimeout(debounceTimerID);
    debounceTimerID = WINDOW$4.setTimeout(() => {
      lastCapturedEventTargetId = void 0;
      lastCapturedEventType = void 0;
    }, DEBOUNCE_DURATION);
  };
}
__name(makeDOMEventHandler, "makeDOMEventHandler");
function getEventTarget$1(event) {
  try {
    return event.target;
  } catch (e2) {
    return null;
  }
}
__name(getEventTarget$1, "getEventTarget$1");
let lastHref;
function addHistoryInstrumentationHandler(handler14) {
  const type = "history";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentHistory);
}
__name(addHistoryInstrumentationHandler, "addHistoryInstrumentationHandler");
function instrumentHistory() {
  if (!supportsHistory()) {
    return;
  }
  const oldOnPopState = WINDOW$4.onpopstate;
  WINDOW$4.onpopstate = function(...args) {
    const to = WINDOW$4.location.href;
    const from2 = lastHref;
    lastHref = to;
    const handlerData = { from: from2, to };
    triggerHandlers$1("history", handlerData);
    if (oldOnPopState) {
      try {
        return oldOnPopState.apply(this, args);
      } catch (_oO) {
      }
    }
  };
  function historyReplacementFunction(originalHistoryFunction) {
    return function(...args) {
      const url = args.length > 2 ? args[2] : void 0;
      if (url) {
        const from2 = lastHref;
        const to = String(url);
        lastHref = to;
        const handlerData = { from: from2, to };
        triggerHandlers$1("history", handlerData);
      }
      return originalHistoryFunction.apply(this, args);
    };
  }
  __name(historyReplacementFunction, "historyReplacementFunction");
  fill(WINDOW$4.history, "pushState", historyReplacementFunction);
  fill(WINDOW$4.history, "replaceState", historyReplacementFunction);
}
__name(instrumentHistory, "instrumentHistory");
const cachedImplementations$3 = {};
function getNativeImplementation(name2) {
  const cached = cachedImplementations$3[name2];
  if (cached) {
    return cached;
  }
  let impl = WINDOW$4[name2];
  if (isNativeFunction(impl)) {
    return cachedImplementations$3[name2] = impl.bind(WINDOW$4);
  }
  const document2 = WINDOW$4.document;
  if (document2 && typeof document2.createElement === "function") {
    try {
      const sandbox = document2.createElement("iframe");
      sandbox.hidden = true;
      document2.head.appendChild(sandbox);
      const contentWindow = sandbox.contentWindow;
      if (contentWindow && contentWindow[name2]) {
        impl = contentWindow[name2];
      }
      document2.head.removeChild(sandbox);
    } catch (e2) {
      DEBUG_BUILD$3 && logger$2.warn(`Could not create sandbox iframe for ${name2} check, bailing to window.${name2}: `, e2);
    }
  }
  if (!impl) {
    return impl;
  }
  return cachedImplementations$3[name2] = impl.bind(WINDOW$4);
}
__name(getNativeImplementation, "getNativeImplementation");
function clearCachedImplementation(name2) {
  cachedImplementations$3[name2] = void 0;
}
__name(clearCachedImplementation, "clearCachedImplementation");
function fetch$1(...rest) {
  return getNativeImplementation("fetch")(...rest);
}
__name(fetch$1, "fetch$1");
function setTimeout$3(...rest) {
  return getNativeImplementation("setTimeout")(...rest);
}
__name(setTimeout$3, "setTimeout$3");
const SENTRY_XHR_DATA_KEY = "__sentry_xhr_v3__";
function addXhrInstrumentationHandler(handler14) {
  const type = "xhr";
  addHandler$1(type, handler14);
  maybeInstrument(type, instrumentXHR);
}
__name(addXhrInstrumentationHandler, "addXhrInstrumentationHandler");
function instrumentXHR() {
  if (!WINDOW$4.XMLHttpRequest) {
    return;
  }
  const xhrproto = XMLHttpRequest.prototype;
  xhrproto.open = new Proxy(xhrproto.open, {
    apply(originalOpen, xhrOpenThisArg, xhrOpenArgArray) {
      const virtualError = new Error();
      const startTimestamp = timestampInSeconds() * 1e3;
      const method = isString$a(xhrOpenArgArray[0]) ? xhrOpenArgArray[0].toUpperCase() : void 0;
      const url = parseUrl(xhrOpenArgArray[1]);
      if (!method || !url) {
        return originalOpen.apply(xhrOpenThisArg, xhrOpenArgArray);
      }
      xhrOpenThisArg[SENTRY_XHR_DATA_KEY] = {
        method,
        url,
        request_headers: {}
      };
      if (method === "POST" && url.match(/sentry_key/)) {
        xhrOpenThisArg.__sentry_own_request__ = true;
      }
      const onreadystatechangeHandler = /* @__PURE__ */ __name(() => {
        const xhrInfo = xhrOpenThisArg[SENTRY_XHR_DATA_KEY];
        if (!xhrInfo) {
          return;
        }
        if (xhrOpenThisArg.readyState === 4) {
          try {
            xhrInfo.status_code = xhrOpenThisArg.status;
          } catch (e2) {
          }
          const handlerData = {
            endTimestamp: timestampInSeconds() * 1e3,
            startTimestamp,
            xhr: xhrOpenThisArg,
            virtualError
          };
          triggerHandlers$1("xhr", handlerData);
        }
      }, "onreadystatechangeHandler");
      if ("onreadystatechange" in xhrOpenThisArg && typeof xhrOpenThisArg.onreadystatechange === "function") {
        xhrOpenThisArg.onreadystatechange = new Proxy(xhrOpenThisArg.onreadystatechange, {
          apply(originalOnreadystatechange, onreadystatechangeThisArg, onreadystatechangeArgArray) {
            onreadystatechangeHandler();
            return originalOnreadystatechange.apply(onreadystatechangeThisArg, onreadystatechangeArgArray);
          }
        });
      } else {
        xhrOpenThisArg.addEventListener("readystatechange", onreadystatechangeHandler);
      }
      xhrOpenThisArg.setRequestHeader = new Proxy(xhrOpenThisArg.setRequestHeader, {
        apply(originalSetRequestHeader, setRequestHeaderThisArg, setRequestHeaderArgArray) {
          const [header3, value3] = setRequestHeaderArgArray;
          const xhrInfo = setRequestHeaderThisArg[SENTRY_XHR_DATA_KEY];
          if (xhrInfo && isString$a(header3) && isString$a(value3)) {
            xhrInfo.request_headers[header3.toLowerCase()] = value3;
          }
          return originalSetRequestHeader.apply(setRequestHeaderThisArg, setRequestHeaderArgArray);
        }
      });
      return originalOpen.apply(xhrOpenThisArg, xhrOpenArgArray);
    }
  });
  xhrproto.send = new Proxy(xhrproto.send, {
    apply(originalSend, sendThisArg, sendArgArray) {
      const sentryXhrData = sendThisArg[SENTRY_XHR_DATA_KEY];
      if (!sentryXhrData) {
        return originalSend.apply(sendThisArg, sendArgArray);
      }
      if (sendArgArray[0] !== void 0) {
        sentryXhrData.body = sendArgArray[0];
      }
      const handlerData = {
        startTimestamp: timestampInSeconds() * 1e3,
        xhr: sendThisArg
      };
      triggerHandlers$1("xhr", handlerData);
      return originalSend.apply(sendThisArg, sendArgArray);
    }
  });
}
__name(instrumentXHR, "instrumentXHR");
function parseUrl(url) {
  if (isString$a(url)) {
    return url;
  }
  try {
    return url.toString();
  } catch (e2) {
  }
  return void 0;
}
__name(parseUrl, "parseUrl");
const LAST_INTERACTIONS = [];
const INTERACTIONS_SPAN_MAP = /* @__PURE__ */ new Map();
function startTrackingINP() {
  const performance2 = getBrowserPerformanceAPI();
  if (performance2 && browserPerformanceTimeOrigin) {
    const inpCallback = _trackINP();
    return () => {
      inpCallback();
    };
  }
  return () => void 0;
}
__name(startTrackingINP, "startTrackingINP");
const INP_ENTRY_MAP = {
  click: "click",
  pointerdown: "click",
  pointerup: "click",
  mousedown: "click",
  mouseup: "click",
  touchstart: "click",
  touchend: "click",
  mouseover: "hover",
  mouseout: "hover",
  mouseenter: "hover",
  mouseleave: "hover",
  pointerover: "hover",
  pointerout: "hover",
  pointerenter: "hover",
  pointerleave: "hover",
  dragstart: "drag",
  dragend: "drag",
  drag: "drag",
  dragenter: "drag",
  dragleave: "drag",
  dragover: "drag",
  drop: "drag",
  keydown: "press",
  keyup: "press",
  keypress: "press",
  input: "press"
};
function _trackINP() {
  return addInpInstrumentationHandler(({ metric }) => {
    if (metric.value == void 0) {
      return;
    }
    const entry = metric.entries.find((entry2) => entry2.duration === metric.value && INP_ENTRY_MAP[entry2.name]);
    if (!entry) {
      return;
    }
    const { interactionId } = entry;
    const interactionType = INP_ENTRY_MAP[entry.name];
    const startTime = msToSec(browserPerformanceTimeOrigin + entry.startTime);
    const duration = msToSec(metric.value);
    const activeSpan = getActiveSpan();
    const rootSpan = activeSpan ? getRootSpan(activeSpan) : void 0;
    const cachedSpan = interactionId != null ? INTERACTIONS_SPAN_MAP.get(interactionId) : void 0;
    const spanToUse = cachedSpan || rootSpan;
    const routeName = spanToUse ? spanToJSON(spanToUse).description : getCurrentScope$1().getScopeData().transactionName;
    const name2 = htmlTreeAsString(entry.target);
    const attributes = dropUndefinedKeys({
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.http.browser.inp",
      [SEMANTIC_ATTRIBUTE_SENTRY_OP]: `ui.interaction.${interactionType}`,
      [SEMANTIC_ATTRIBUTE_EXCLUSIVE_TIME]: entry.duration
    });
    const span = startStandaloneWebVitalSpan({
      name: name2,
      transaction: routeName,
      attributes,
      startTime
    });
    if (span) {
      span.addEvent("inp", {
        [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_UNIT]: "millisecond",
        [SEMANTIC_ATTRIBUTE_SENTRY_MEASUREMENT_VALUE]: metric.value
      });
      span.end(startTime + duration);
    }
  });
}
__name(_trackINP, "_trackINP");
function registerInpInteractionListener(_latestRoute) {
  const handleEntries = /* @__PURE__ */ __name(({ entries }) => {
    const activeSpan = getActiveSpan();
    const activeRootSpan = activeSpan && getRootSpan(activeSpan);
    entries.forEach((entry) => {
      if (!isPerformanceEventTiming(entry) || !activeRootSpan) {
        return;
      }
      const interactionId = entry.interactionId;
      if (interactionId == null) {
        return;
      }
      if (INTERACTIONS_SPAN_MAP.has(interactionId)) {
        return;
      }
      if (LAST_INTERACTIONS.length > 10) {
        const last = LAST_INTERACTIONS.shift();
        INTERACTIONS_SPAN_MAP.delete(last);
      }
      LAST_INTERACTIONS.push(interactionId);
      INTERACTIONS_SPAN_MAP.set(interactionId, activeRootSpan);
    });
  }, "handleEntries");
  addPerformanceInstrumentationHandler("event", handleEntries);
  addPerformanceInstrumentationHandler("first-input", handleEntries);
}
__name(registerInpInteractionListener, "registerInpInteractionListener");
function makeFetchTransport(options5, nativeFetch = getNativeImplementation("fetch")) {
  let pendingBodySize = 0;
  let pendingCount = 0;
  function makeRequest(request) {
    const requestSize = request.body.length;
    pendingBodySize += requestSize;
    pendingCount++;
    const requestOptions = {
      body: request.body,
      method: "POST",
      referrerPolicy: "origin",
      headers: options5.headers,
      // Outgoing requests are usually cancelled when navigating to a different page, causing a "TypeError: Failed to
      // fetch" error and sending a "network_error" client-outcome - in Chrome, the request status shows "(cancelled)".
      // The `keepalive` flag keeps outgoing requests alive, even when switching pages. We want this since we're
      // frequently sending events right before the user is switching pages (eg. when finishing navigation transactions).
      // Gotchas:
      // - `keepalive` isn't supported by Firefox
      // - As per spec (https://fetch.spec.whatwg.org/#http-network-or-cache-fetch):
      //   If the sum of contentLength and inflightKeepaliveBytes is greater than 64 kibibytes, then return a network error.
      //   We will therefore only activate the flag when we're below that limit.
      // There is also a limit of requests that can be open at the same time, so we also limit this to 15
      // See https://github.com/getsentry/sentry-javascript/pull/7553 for details
      keepalive: pendingBodySize <= 6e4 && pendingCount < 15,
      ...options5.fetchOptions
    };
    if (!nativeFetch) {
      clearCachedImplementation("fetch");
      return rejectedSyncPromise("No fetch implementation available");
    }
    try {
      return nativeFetch(options5.url, requestOptions).then((response) => {
        pendingBodySize -= requestSize;
        pendingCount--;
        return {
          statusCode: response.status,
          headers: {
            "x-sentry-rate-limits": response.headers.get("X-Sentry-Rate-Limits"),
            "retry-after": response.headers.get("Retry-After")
          }
        };
      });
    } catch (e2) {
      clearCachedImplementation("fetch");
      pendingBodySize -= requestSize;
      pendingCount--;
      return rejectedSyncPromise(e2);
    }
  }
  __name(makeRequest, "makeRequest");
  return createTransport(options5, makeRequest);
}
__name(makeFetchTransport, "makeFetchTransport");
const OPERA10_PRIORITY = 10;
const OPERA11_PRIORITY = 20;
const CHROME_PRIORITY = 30;
const WINJS_PRIORITY = 40;
const GECKO_PRIORITY = 50;
function createFrame(filename, func, lineno, colno) {
  const frame = {
    filename,
    function: func === "<anonymous>" ? UNKNOWN_FUNCTION : func,
    in_app: true
    // All browser frames are considered in_app
  };
  if (lineno !== void 0) {
    frame.lineno = lineno;
  }
  if (colno !== void 0) {
    frame.colno = colno;
  }
  return frame;
}
__name(createFrame, "createFrame");
const chromeRegexNoFnName = /^\s*at (\S+?)(?::(\d+))(?::(\d+))\s*$/i;
const chromeRegex = /^\s*at (?:(.+?\)(?: \[.+\])?|.*?) ?\((?:address at )?)?(?:async )?((?:<anonymous>|[-a-z]+:|.*bundle|\/)?.*?)(?::(\d+))?(?::(\d+))?\)?\s*$/i;
const chromeEvalRegex = /\((\S*)(?::(\d+))(?::(\d+))\)/;
const chromeStackParserFn = /* @__PURE__ */ __name((line) => {
  const noFnParts = chromeRegexNoFnName.exec(line);
  if (noFnParts) {
    const [, filename, line2, col] = noFnParts;
    return createFrame(filename, UNKNOWN_FUNCTION, +line2, +col);
  }
  const parts2 = chromeRegex.exec(line);
  if (parts2) {
    const isEval = parts2[2] && parts2[2].indexOf("eval") === 0;
    if (isEval) {
      const subMatch = chromeEvalRegex.exec(parts2[2]);
      if (subMatch) {
        parts2[2] = subMatch[1];
        parts2[3] = subMatch[2];
        parts2[4] = subMatch[3];
      }
    }
    const [func, filename] = extractSafariExtensionDetails(parts2[1] || UNKNOWN_FUNCTION, parts2[2]);
    return createFrame(filename, func, parts2[3] ? +parts2[3] : void 0, parts2[4] ? +parts2[4] : void 0);
  }
  return;
}, "chromeStackParserFn");
const chromeStackLineParser = [CHROME_PRIORITY, chromeStackParserFn];
const geckoREgex = /^\s*(.*?)(?:\((.*?)\))?(?:^|@)?((?:[-a-z]+)?:\/.*?|\[native code\]|[^@]*(?:bundle|\d+\.js)|\/[\w\-. /=]+)(?::(\d+))?(?::(\d+))?\s*$/i;
const geckoEvalRegex = /(\S+) line (\d+)(?: > eval line \d+)* > eval/i;
const gecko$1 = /* @__PURE__ */ __name((line) => {
  const parts2 = geckoREgex.exec(line);
  if (parts2) {
    const isEval = parts2[3] && parts2[3].indexOf(" > eval") > -1;
    if (isEval) {
      const subMatch = geckoEvalRegex.exec(parts2[3]);
      if (subMatch) {
        parts2[1] = parts2[1] || "eval";
        parts2[3] = subMatch[1];
        parts2[4] = subMatch[2];
        parts2[5] = "";
      }
    }
    let filename = parts2[3];
    let func = parts2[1] || UNKNOWN_FUNCTION;
    [func, filename] = extractSafariExtensionDetails(func, filename);
    return createFrame(filename, func, parts2[4] ? +parts2[4] : void 0, parts2[5] ? +parts2[5] : void 0);
  }
  return;
}, "gecko$1");
const geckoStackLineParser = [GECKO_PRIORITY, gecko$1];
const winjsRegex = /^\s*at (?:((?:\[object object\])?.+) )?\(?((?:[-a-z]+):.*?):(\d+)(?::(\d+))?\)?\s*$/i;
const winjs = /* @__PURE__ */ __name((line) => {
  const parts2 = winjsRegex.exec(line);
  return parts2 ? createFrame(parts2[2], parts2[1] || UNKNOWN_FUNCTION, +parts2[3], parts2[4] ? +parts2[4] : void 0) : void 0;
}, "winjs");
const winjsStackLineParser = [WINJS_PRIORITY, winjs];
const opera10Regex = / line (\d+).*script (?:in )?(\S+)(?:: in function (\S+))?$/i;
const opera10 = /* @__PURE__ */ __name((line) => {
  const parts2 = opera10Regex.exec(line);
  return parts2 ? createFrame(parts2[2], parts2[3] || UNKNOWN_FUNCTION, +parts2[1]) : void 0;
}, "opera10");
const opera10StackLineParser = [OPERA10_PRIORITY, opera10];
const opera11Regex = / line (\d+), column (\d+)\s*(?:in (?:<anonymous function: ([^>]+)>|([^)]+))\(.*\))? in (.*):\s*$/i;
const opera11 = /* @__PURE__ */ __name((line) => {
  const parts2 = opera11Regex.exec(line);
  return parts2 ? createFrame(parts2[5], parts2[3] || parts2[4] || UNKNOWN_FUNCTION, +parts2[1], +parts2[2]) : void 0;
}, "opera11");
const opera11StackLineParser = [OPERA11_PRIORITY, opera11];
const defaultStackLineParsers = [chromeStackLineParser, geckoStackLineParser];
const defaultStackParser = createStackParser(...defaultStackLineParsers);
const extractSafariExtensionDetails = /* @__PURE__ */ __name((func, filename) => {
  const isSafariExtension = func.indexOf("safari-extension") !== -1;
  const isSafariWebExtension = func.indexOf("safari-web-extension") !== -1;
  return isSafariExtension || isSafariWebExtension ? [
    func.indexOf("@") !== -1 ? func.split("@")[0] : UNKNOWN_FUNCTION,
    isSafariExtension ? `safari-extension:${filename}` : `safari-web-extension:${filename}`
  ] : [func, filename];
}, "extractSafariExtensionDetails");
const MAX_ALLOWED_STRING_LENGTH = 1024;
const INTEGRATION_NAME$a = "Breadcrumbs";
const _breadcrumbsIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    console: true,
    dom: true,
    fetch: true,
    history: true,
    sentry: true,
    xhr: true,
    ...options5
  };
  return {
    name: INTEGRATION_NAME$a,
    setup(client) {
      if (_options.console) {
        addConsoleInstrumentationHandler(_getConsoleBreadcrumbHandler(client));
      }
      if (_options.dom) {
        addClickKeypressInstrumentationHandler(_getDomBreadcrumbHandler(client, _options.dom));
      }
      if (_options.xhr) {
        addXhrInstrumentationHandler(_getXhrBreadcrumbHandler(client));
      }
      if (_options.fetch) {
        addFetchInstrumentationHandler(_getFetchBreadcrumbHandler(client));
      }
      if (_options.history) {
        addHistoryInstrumentationHandler(_getHistoryBreadcrumbHandler(client));
      }
      if (_options.sentry) {
        client.on("beforeSendEvent", _getSentryBreadcrumbHandler(client));
      }
    }
  };
}, "_breadcrumbsIntegration");
const breadcrumbsIntegration = defineIntegration(_breadcrumbsIntegration);
function _getSentryBreadcrumbHandler(client) {
  return /* @__PURE__ */ __name(function addSentryBreadcrumb(event) {
    if (getClient() !== client) {
      return;
    }
    addBreadcrumb(
      {
        category: `sentry.${event.type === "transaction" ? "transaction" : "event"}`,
        event_id: event.event_id,
        level: event.level,
        message: getEventDescription(event)
      },
      {
        event
      }
    );
  }, "addSentryBreadcrumb");
}
__name(_getSentryBreadcrumbHandler, "_getSentryBreadcrumbHandler");
function _getDomBreadcrumbHandler(client, dom) {
  return /* @__PURE__ */ __name(function _innerDomBreadcrumb(handlerData) {
    if (getClient() !== client) {
      return;
    }
    let target2;
    let componentName;
    let keyAttrs = typeof dom === "object" ? dom.serializeAttribute : void 0;
    let maxStringLength = typeof dom === "object" && typeof dom.maxStringLength === "number" ? dom.maxStringLength : void 0;
    if (maxStringLength && maxStringLength > MAX_ALLOWED_STRING_LENGTH) {
      DEBUG_BUILD$4 && logger$2.warn(
        `\`dom.maxStringLength\` cannot exceed ${MAX_ALLOWED_STRING_LENGTH}, but a value of ${maxStringLength} was configured. Sentry will use ${MAX_ALLOWED_STRING_LENGTH} instead.`
      );
      maxStringLength = MAX_ALLOWED_STRING_LENGTH;
    }
    if (typeof keyAttrs === "string") {
      keyAttrs = [keyAttrs];
    }
    try {
      const event = handlerData.event;
      const element = _isEvent(event) ? event.target : event;
      target2 = htmlTreeAsString(element, { keyAttrs, maxStringLength });
      componentName = getComponentName$1(element);
    } catch (e2) {
      target2 = "<unknown>";
    }
    if (target2.length === 0) {
      return;
    }
    const breadcrumb = {
      category: `ui.${handlerData.name}`,
      message: target2
    };
    if (componentName) {
      breadcrumb.data = { "ui.component_name": componentName };
    }
    addBreadcrumb(breadcrumb, {
      event: handlerData.event,
      name: handlerData.name,
      global: handlerData.global
    });
  }, "_innerDomBreadcrumb");
}
__name(_getDomBreadcrumbHandler, "_getDomBreadcrumbHandler");
function _getConsoleBreadcrumbHandler(client) {
  return /* @__PURE__ */ __name(function _consoleBreadcrumb(handlerData) {
    if (getClient() !== client) {
      return;
    }
    const breadcrumb = {
      category: "console",
      data: {
        arguments: handlerData.args,
        logger: "console"
      },
      level: severityLevelFromString(handlerData.level),
      message: safeJoin(handlerData.args, " ")
    };
    if (handlerData.level === "assert") {
      if (handlerData.args[0] === false) {
        breadcrumb.message = `Assertion failed: ${safeJoin(handlerData.args.slice(1), " ") || "console.assert"}`;
        breadcrumb.data.arguments = handlerData.args.slice(1);
      } else {
        return;
      }
    }
    addBreadcrumb(breadcrumb, {
      input: handlerData.args,
      level: handlerData.level
    });
  }, "_consoleBreadcrumb");
}
__name(_getConsoleBreadcrumbHandler, "_getConsoleBreadcrumbHandler");
function _getXhrBreadcrumbHandler(client) {
  return /* @__PURE__ */ __name(function _xhrBreadcrumb(handlerData) {
    if (getClient() !== client) {
      return;
    }
    const { startTimestamp, endTimestamp } = handlerData;
    const sentryXhrData = handlerData.xhr[SENTRY_XHR_DATA_KEY];
    if (!startTimestamp || !endTimestamp || !sentryXhrData) {
      return;
    }
    const { method, url, status_code, body } = sentryXhrData;
    const data30 = {
      method,
      url,
      status_code
    };
    const hint = {
      xhr: handlerData.xhr,
      input: body,
      startTimestamp,
      endTimestamp
    };
    const level = getBreadcrumbLogLevelFromHttpStatusCode(status_code);
    addBreadcrumb(
      {
        category: "xhr",
        data: data30,
        type: "http",
        level
      },
      hint
    );
  }, "_xhrBreadcrumb");
}
__name(_getXhrBreadcrumbHandler, "_getXhrBreadcrumbHandler");
function _getFetchBreadcrumbHandler(client) {
  return /* @__PURE__ */ __name(function _fetchBreadcrumb(handlerData) {
    if (getClient() !== client) {
      return;
    }
    const { startTimestamp, endTimestamp } = handlerData;
    if (!endTimestamp) {
      return;
    }
    if (handlerData.fetchData.url.match(/sentry_key/) && handlerData.fetchData.method === "POST") {
      return;
    }
    if (handlerData.error) {
      const data30 = handlerData.fetchData;
      const hint = {
        data: handlerData.error,
        input: handlerData.args,
        startTimestamp,
        endTimestamp
      };
      addBreadcrumb(
        {
          category: "fetch",
          data: data30,
          level: "error",
          type: "http"
        },
        hint
      );
    } else {
      const response = handlerData.response;
      const data30 = {
        ...handlerData.fetchData,
        status_code: response && response.status
      };
      const hint = {
        input: handlerData.args,
        response,
        startTimestamp,
        endTimestamp
      };
      const level = getBreadcrumbLogLevelFromHttpStatusCode(data30.status_code);
      addBreadcrumb(
        {
          category: "fetch",
          data: data30,
          type: "http",
          level
        },
        hint
      );
    }
  }, "_fetchBreadcrumb");
}
__name(_getFetchBreadcrumbHandler, "_getFetchBreadcrumbHandler");
function _getHistoryBreadcrumbHandler(client) {
  return /* @__PURE__ */ __name(function _historyBreadcrumb(handlerData) {
    if (getClient() !== client) {
      return;
    }
    let from2 = handlerData.from;
    let to = handlerData.to;
    const parsedLoc = parseUrl$1(WINDOW$5.location.href);
    let parsedFrom = from2 ? parseUrl$1(from2) : void 0;
    const parsedTo = parseUrl$1(to);
    if (!parsedFrom || !parsedFrom.path) {
      parsedFrom = parsedLoc;
    }
    if (parsedLoc.protocol === parsedTo.protocol && parsedLoc.host === parsedTo.host) {
      to = parsedTo.relative;
    }
    if (parsedLoc.protocol === parsedFrom.protocol && parsedLoc.host === parsedFrom.host) {
      from2 = parsedFrom.relative;
    }
    addBreadcrumb({
      category: "navigation",
      data: {
        from: from2,
        to
      }
    });
  }, "_historyBreadcrumb");
}
__name(_getHistoryBreadcrumbHandler, "_getHistoryBreadcrumbHandler");
function _isEvent(event) {
  return !!event && !!event.target;
}
__name(_isEvent, "_isEvent");
const DEFAULT_EVENT_TARGET = [
  "EventTarget",
  "Window",
  "Node",
  "ApplicationCache",
  "AudioTrackList",
  "BroadcastChannel",
  "ChannelMergerNode",
  "CryptoOperation",
  "EventSource",
  "FileReader",
  "HTMLUnknownElement",
  "IDBDatabase",
  "IDBRequest",
  "IDBTransaction",
  "KeyOperation",
  "MediaController",
  "MessagePort",
  "ModalWindow",
  "Notification",
  "SVGElementInstance",
  "Screen",
  "SharedWorker",
  "TextTrack",
  "TextTrackCue",
  "TextTrackList",
  "WebSocket",
  "WebSocketWorker",
  "Worker",
  "XMLHttpRequest",
  "XMLHttpRequestEventTarget",
  "XMLHttpRequestUpload"
];
const INTEGRATION_NAME$9 = "BrowserApiErrors";
const _browserApiErrorsIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    XMLHttpRequest: true,
    eventTarget: true,
    requestAnimationFrame: true,
    setInterval: true,
    setTimeout: true,
    ...options5
  };
  return {
    name: INTEGRATION_NAME$9,
    // TODO: This currently only works for the first client this is setup
    // We may want to adjust this to check for client etc.
    setupOnce() {
      if (_options.setTimeout) {
        fill(WINDOW$5, "setTimeout", _wrapTimeFunction);
      }
      if (_options.setInterval) {
        fill(WINDOW$5, "setInterval", _wrapTimeFunction);
      }
      if (_options.requestAnimationFrame) {
        fill(WINDOW$5, "requestAnimationFrame", _wrapRAF);
      }
      if (_options.XMLHttpRequest && "XMLHttpRequest" in WINDOW$5) {
        fill(XMLHttpRequest.prototype, "send", _wrapXHR$1);
      }
      const eventTargetOption = _options.eventTarget;
      if (eventTargetOption) {
        const eventTarget = Array.isArray(eventTargetOption) ? eventTargetOption : DEFAULT_EVENT_TARGET;
        eventTarget.forEach(_wrapEventTarget);
      }
    }
  };
}, "_browserApiErrorsIntegration");
const browserApiErrorsIntegration = defineIntegration(_browserApiErrorsIntegration);
function _wrapTimeFunction(original) {
  return function(...args) {
    const originalCallback = args[0];
    args[0] = wrap$1(originalCallback, {
      mechanism: {
        data: { function: getFunctionName(original) },
        handled: false,
        type: "instrument"
      }
    });
    return original.apply(this, args);
  };
}
__name(_wrapTimeFunction, "_wrapTimeFunction");
function _wrapRAF(original) {
  return function(callback) {
    return original.apply(this, [
      wrap$1(callback, {
        mechanism: {
          data: {
            function: "requestAnimationFrame",
            handler: getFunctionName(original)
          },
          handled: false,
          type: "instrument"
        }
      })
    ]);
  };
}
__name(_wrapRAF, "_wrapRAF");
function _wrapXHR$1(originalSend) {
  return function(...args) {
    const xhr = this;
    const xmlHttpRequestProps = ["onload", "onerror", "onprogress", "onreadystatechange"];
    xmlHttpRequestProps.forEach((prop2) => {
      if (prop2 in xhr && typeof xhr[prop2] === "function") {
        fill(xhr, prop2, function(original) {
          const wrapOptions = {
            mechanism: {
              data: {
                function: prop2,
                handler: getFunctionName(original)
              },
              handled: false,
              type: "instrument"
            }
          };
          const originalFunction = getOriginalFunction(original);
          if (originalFunction) {
            wrapOptions.mechanism.data.handler = getFunctionName(originalFunction);
          }
          return wrap$1(original, wrapOptions);
        });
      }
    });
    return originalSend.apply(this, args);
  };
}
__name(_wrapXHR$1, "_wrapXHR$1");
function _wrapEventTarget(target2) {
  const globalObject = WINDOW$5;
  const targetObj = globalObject[target2];
  const proto = targetObj && targetObj.prototype;
  if (!proto || !proto.hasOwnProperty || !proto.hasOwnProperty("addEventListener")) {
    return;
  }
  fill(proto, "addEventListener", function(original) {
    return function(eventName, fn, options5) {
      try {
        if (isEventListenerObject(fn)) {
          fn.handleEvent = wrap$1(fn.handleEvent, {
            mechanism: {
              data: {
                function: "handleEvent",
                handler: getFunctionName(fn),
                target: target2
              },
              handled: false,
              type: "instrument"
            }
          });
        }
      } catch (e2) {
      }
      return original.apply(this, [
        eventName,
        wrap$1(fn, {
          mechanism: {
            data: {
              function: "addEventListener",
              handler: getFunctionName(fn),
              target: target2
            },
            handled: false,
            type: "instrument"
          }
        }),
        options5
      ]);
    };
  });
  fill(proto, "removeEventListener", function(originalRemoveEventListener) {
    return function(eventName, fn, options5) {
      try {
        const originalEventHandler = fn.__sentry_wrapped__;
        if (originalEventHandler) {
          originalRemoveEventListener.call(this, eventName, originalEventHandler, options5);
        }
      } catch (e2) {
      }
      return originalRemoveEventListener.call(this, eventName, fn, options5);
    };
  });
}
__name(_wrapEventTarget, "_wrapEventTarget");
function isEventListenerObject(obj) {
  return typeof obj.handleEvent === "function";
}
__name(isEventListenerObject, "isEventListenerObject");
const browserSessionIntegration = defineIntegration(() => {
  return {
    name: "BrowserSession",
    setupOnce() {
      if (typeof WINDOW$5.document === "undefined") {
        DEBUG_BUILD$4 && logger$2.warn("Using the `browserSessionIntegration` in non-browser environments is not supported.");
        return;
      }
      startSession({ ignoreDuration: true });
      captureSession();
      addHistoryInstrumentationHandler(({ from: from2, to }) => {
        if (from2 !== void 0 && from2 !== to) {
          startSession({ ignoreDuration: true });
          captureSession();
        }
      });
    }
  };
});
const INTEGRATION_NAME$8 = "GlobalHandlers";
const _globalHandlersIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    onerror: true,
    onunhandledrejection: true,
    ...options5
  };
  return {
    name: INTEGRATION_NAME$8,
    setupOnce() {
      Error.stackTraceLimit = 50;
    },
    setup(client) {
      if (_options.onerror) {
        _installGlobalOnErrorHandler(client);
        globalHandlerLog("onerror");
      }
      if (_options.onunhandledrejection) {
        _installGlobalOnUnhandledRejectionHandler(client);
        globalHandlerLog("onunhandledrejection");
      }
    }
  };
}, "_globalHandlersIntegration");
const globalHandlersIntegration = defineIntegration(_globalHandlersIntegration);
function _installGlobalOnErrorHandler(client) {
  addGlobalErrorInstrumentationHandler((data30) => {
    const { stackParser, attachStacktrace } = getOptions();
    if (getClient() !== client || shouldIgnoreOnError()) {
      return;
    }
    const { msg, url, line, column, error: error2 } = data30;
    const event = _enhanceEventWithInitialFrame(
      eventFromUnknownInput(stackParser, error2 || msg, void 0, attachStacktrace, false),
      url,
      line,
      column
    );
    event.level = "error";
    captureEvent(event, {
      originalException: error2,
      mechanism: {
        handled: false,
        type: "onerror"
      }
    });
  });
}
__name(_installGlobalOnErrorHandler, "_installGlobalOnErrorHandler");
function _installGlobalOnUnhandledRejectionHandler(client) {
  addGlobalUnhandledRejectionInstrumentationHandler((e2) => {
    const { stackParser, attachStacktrace } = getOptions();
    if (getClient() !== client || shouldIgnoreOnError()) {
      return;
    }
    const error2 = _getUnhandledRejectionError(e2);
    const event = isPrimitive(error2) ? _eventFromRejectionWithPrimitive(error2) : eventFromUnknownInput(stackParser, error2, void 0, attachStacktrace, true);
    event.level = "error";
    captureEvent(event, {
      originalException: error2,
      mechanism: {
        handled: false,
        type: "onunhandledrejection"
      }
    });
  });
}
__name(_installGlobalOnUnhandledRejectionHandler, "_installGlobalOnUnhandledRejectionHandler");
function _getUnhandledRejectionError(error2) {
  if (isPrimitive(error2)) {
    return error2;
  }
  try {
    if ("reason" in error2) {
      return error2.reason;
    }
    if ("detail" in error2 && "reason" in error2.detail) {
      return error2.detail.reason;
    }
  } catch (e2) {
  }
  return error2;
}
__name(_getUnhandledRejectionError, "_getUnhandledRejectionError");
function _eventFromRejectionWithPrimitive(reason) {
  return {
    exception: {
      values: [
        {
          type: "UnhandledRejection",
          // String() is needed because the Primitive type includes symbols (which can't be automatically stringified)
          value: `Non-Error promise rejection captured with value: ${String(reason)}`
        }
      ]
    }
  };
}
__name(_eventFromRejectionWithPrimitive, "_eventFromRejectionWithPrimitive");
function _enhanceEventWithInitialFrame(event, url, line, column) {
  const e2 = event.exception = event.exception || {};
  const ev = e2.values = e2.values || [];
  const ev0 = ev[0] = ev[0] || {};
  const ev0s = ev0.stacktrace = ev0.stacktrace || {};
  const ev0sf = ev0s.frames = ev0s.frames || [];
  const colno = column;
  const lineno = line;
  const filename = isString$a(url) && url.length > 0 ? url : getLocationHref();
  if (ev0sf.length === 0) {
    ev0sf.push({
      colno,
      filename,
      function: UNKNOWN_FUNCTION,
      in_app: true,
      lineno
    });
  }
  return event;
}
__name(_enhanceEventWithInitialFrame, "_enhanceEventWithInitialFrame");
function globalHandlerLog(type) {
  DEBUG_BUILD$4 && logger$2.log(`Global Handler attached: ${type}`);
}
__name(globalHandlerLog, "globalHandlerLog");
function getOptions() {
  const client = getClient();
  const options5 = client && client.getOptions() || {
    stackParser: /* @__PURE__ */ __name(() => [], "stackParser"),
    attachStacktrace: false
  };
  return options5;
}
__name(getOptions, "getOptions");
const httpContextIntegration = defineIntegration(() => {
  return {
    name: "HttpContext",
    preprocessEvent(event) {
      if (!WINDOW$5.navigator && !WINDOW$5.location && !WINDOW$5.document) {
        return;
      }
      const url = event.request && event.request.url || WINDOW$5.location && WINDOW$5.location.href;
      const { referrer } = WINDOW$5.document || {};
      const { userAgent } = WINDOW$5.navigator || {};
      const headers = {
        ...event.request && event.request.headers,
        ...referrer && { Referer: referrer },
        ...userAgent && { "User-Agent": userAgent }
      };
      const request = { ...event.request, ...url && { url }, headers };
      event.request = request;
    }
  };
});
const DEFAULT_KEY = "cause";
const DEFAULT_LIMIT = 5;
const INTEGRATION_NAME$7 = "LinkedErrors";
const _linkedErrorsIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const limit = options5.limit || DEFAULT_LIMIT;
  const key = options5.key || DEFAULT_KEY;
  return {
    name: INTEGRATION_NAME$7,
    preprocessEvent(event, hint, client) {
      const options6 = client.getOptions();
      applyAggregateErrorsToEvent(
        // This differs from the LinkedErrors integration in core by using a different exceptionFromError function
        exceptionFromError,
        options6.stackParser,
        options6.maxValueLength,
        key,
        limit,
        event,
        hint
      );
    }
  };
}, "_linkedErrorsIntegration");
const linkedErrorsIntegration = defineIntegration(_linkedErrorsIntegration);
function getDefaultIntegrations(options5) {
  const integrations = [
    inboundFiltersIntegration(),
    functionToStringIntegration(),
    browserApiErrorsIntegration(),
    breadcrumbsIntegration(),
    globalHandlersIntegration(),
    linkedErrorsIntegration(),
    dedupeIntegration(),
    httpContextIntegration()
  ];
  if (options5.autoSessionTracking !== false) {
    integrations.push(browserSessionIntegration());
  }
  return integrations;
}
__name(getDefaultIntegrations, "getDefaultIntegrations");
function applyDefaultOptions(optionsArg = {}) {
  const defaultOptions2 = {
    defaultIntegrations: getDefaultIntegrations(optionsArg),
    release: typeof __SENTRY_RELEASE__ === "string" ? __SENTRY_RELEASE__ : WINDOW$5.SENTRY_RELEASE && WINDOW$5.SENTRY_RELEASE.id ? WINDOW$5.SENTRY_RELEASE.id : void 0,
    autoSessionTracking: true,
    sendClientReports: true
  };
  if (optionsArg.defaultIntegrations == null) {
    delete optionsArg.defaultIntegrations;
  }
  return { ...defaultOptions2, ...optionsArg };
}
__name(applyDefaultOptions, "applyDefaultOptions");
function shouldShowBrowserExtensionError() {
  const windowWithMaybeExtension = typeof WINDOW$5.window !== "undefined" && WINDOW$5;
  if (!windowWithMaybeExtension) {
    return false;
  }
  const extensionKey = windowWithMaybeExtension.chrome ? "chrome" : "browser";
  const extensionObject = windowWithMaybeExtension[extensionKey];
  const runtimeId = extensionObject && extensionObject.runtime && extensionObject.runtime.id;
  const href = WINDOW$5.location && WINDOW$5.location.href || "";
  const extensionProtocols = ["chrome-extension:", "moz-extension:", "ms-browser-extension:", "safari-web-extension:"];
  const isDedicatedExtensionPage = !!runtimeId && WINDOW$5 === WINDOW$5.top && extensionProtocols.some((protocol) => href.startsWith(`${protocol}//`));
  const isNWjs = typeof windowWithMaybeExtension.nw !== "undefined";
  return !!runtimeId && !isDedicatedExtensionPage && !isNWjs;
}
__name(shouldShowBrowserExtensionError, "shouldShowBrowserExtensionError");
function init$4(browserOptions = {}) {
  const options5 = applyDefaultOptions(browserOptions);
  if (!options5.skipBrowserExtensionCheck && shouldShowBrowserExtensionError()) {
    consoleSandbox(() => {
      console.error(
        "[Sentry] You cannot run Sentry this way in a browser extension, check: https://docs.sentry.io/platforms/javascript/best-practices/browser-extensions/"
      );
    });
    return;
  }
  if (DEBUG_BUILD$4) {
    if (!supportsFetch()) {
      logger$2.warn(
        "No Fetch API detected. The Sentry SDK requires a Fetch API compatible environment to send events. Please add a Fetch API polyfill."
      );
    }
  }
  const clientOptions = {
    ...options5,
    stackParser: stackParserFromStackParserOptions(options5.stackParser || defaultStackParser),
    integrations: getIntegrationsToSetup(options5),
    transport: options5.transport || makeFetchTransport
  };
  return initAndBind(BrowserClient, clientOptions);
}
__name(init$4, "init$4");
function showReportDialog(options5 = {}) {
  if (!WINDOW$5.document) {
    DEBUG_BUILD$4 && logger$2.error("Global document not defined in showReportDialog call");
    return;
  }
  const scope = getCurrentScope$1();
  const client = scope.getClient();
  const dsn = client && client.getDsn();
  if (!dsn) {
    DEBUG_BUILD$4 && logger$2.error("DSN not configured for showReportDialog call");
    return;
  }
  if (scope) {
    options5.user = {
      ...scope.getUser(),
      ...options5.user
    };
  }
  if (!options5.eventId) {
    const eventId = lastEventId();
    if (eventId) {
      options5.eventId = eventId;
    }
  }
  const script2 = WINDOW$5.document.createElement("script");
  script2.async = true;
  script2.crossOrigin = "anonymous";
  script2.src = getReportDialogEndpoint(dsn, options5);
  if (options5.onLoad) {
    script2.onload = options5.onLoad;
  }
  const { onClose } = options5;
  if (onClose) {
    const reportDialogClosedMessageHandler = /* @__PURE__ */ __name((event) => {
      if (event.data === "__sentry_reportdialog_closed__") {
        try {
          onClose();
        } finally {
          WINDOW$5.removeEventListener("message", reportDialogClosedMessageHandler);
        }
      }
    }, "reportDialogClosedMessageHandler");
    WINDOW$5.addEventListener("message", reportDialogClosedMessageHandler);
  }
  const injectionPoint = WINDOW$5.document.head || WINDOW$5.document.body;
  if (injectionPoint) {
    injectionPoint.appendChild(script2);
  } else {
    DEBUG_BUILD$4 && logger$2.error("Not injecting report dialog. No injection point found in HTML");
  }
}
__name(showReportDialog, "showReportDialog");
function forceLoad() {
}
__name(forceLoad, "forceLoad");
function onLoad(callback) {
  callback();
}
__name(onLoad, "onLoad");
function captureUserFeedback(feedback) {
  const client = getClient();
  if (client) {
    client.captureUserFeedback(feedback);
  }
}
__name(captureUserFeedback, "captureUserFeedback");
const LazyLoadableIntegrations = {
  replayIntegration: "replay",
  replayCanvasIntegration: "replay-canvas",
  feedbackIntegration: "feedback",
  feedbackModalIntegration: "feedback-modal",
  feedbackScreenshotIntegration: "feedback-screenshot",
  captureConsoleIntegration: "captureconsole",
  contextLinesIntegration: "contextlines",
  linkedErrorsIntegration: "linkederrors",
  debugIntegration: "debug",
  dedupeIntegration: "dedupe",
  extraErrorDataIntegration: "extraerrordata",
  httpClientIntegration: "httpclient",
  reportingObserverIntegration: "reportingobserver",
  rewriteFramesIntegration: "rewriteframes",
  sessionTimingIntegration: "sessiontiming",
  browserProfilingIntegration: "browserprofiling",
  moduleMetadataIntegration: "modulemetadata"
};
const WindowWithMaybeIntegration = WINDOW$5;
async function lazyLoadIntegration(name2, scriptNonce) {
  const bundle = LazyLoadableIntegrations[name2];
  const sentryOnWindow = WindowWithMaybeIntegration.Sentry = WindowWithMaybeIntegration.Sentry || {};
  if (!bundle) {
    throw new Error(`Cannot lazy load integration: ${name2}`);
  }
  const existing = sentryOnWindow[name2];
  if (typeof existing === "function" && !("_isShim" in existing)) {
    return existing;
  }
  const url = getScriptURL(bundle);
  const script2 = WINDOW$5.document.createElement("script");
  script2.src = url;
  script2.crossOrigin = "anonymous";
  script2.referrerPolicy = "origin";
  if (scriptNonce) {
    script2.setAttribute("nonce", scriptNonce);
  }
  const waitForLoad = new Promise((resolve2, reject3) => {
    script2.addEventListener("load", () => resolve2());
    script2.addEventListener("error", reject3);
  });
  const currentScript = WINDOW$5.document.currentScript;
  const parent = WINDOW$5.document.body || WINDOW$5.document.head || currentScript && currentScript.parentElement;
  if (parent) {
    parent.appendChild(script2);
  } else {
    throw new Error(`Could not find parent element to insert lazy-loaded ${name2} script`);
  }
  try {
    await waitForLoad;
  } catch (e2) {
    throw new Error(`Error when loading integration: ${name2}`);
  }
  const integrationFn = sentryOnWindow[name2];
  if (typeof integrationFn !== "function") {
    throw new Error(`Could not load integration: ${name2}`);
  }
  return integrationFn;
}
__name(lazyLoadIntegration, "lazyLoadIntegration");
function getScriptURL(bundle) {
  const client = getClient();
  const options5 = client && client.getOptions();
  const baseURL = options5 && options5.cdnBaseUrl || "https://browser.sentry-cdn.com";
  return new URL(`/${SDK_VERSION}/${bundle}.min.js`, baseURL).toString();
}
__name(getScriptURL, "getScriptURL");
const WINDOW$3 = GLOBAL_OBJ;
const INTEGRATION_NAME$6 = "ReportingObserver";
const SETUP_CLIENTS = /* @__PURE__ */ new WeakMap();
const _reportingObserverIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const types = options5.types || ["crash", "deprecation", "intervention"];
  function handler14(reports) {
    if (!SETUP_CLIENTS.has(getClient())) {
      return;
    }
    for (const report of reports) {
      withScope((scope) => {
        scope.setExtra("url", report.url);
        const label8 = `ReportingObserver [${report.type}]`;
        let details = "No details available";
        if (report.body) {
          const plainBody = {};
          for (const prop2 in report.body) {
            plainBody[prop2] = report.body[prop2];
          }
          scope.setExtra("body", plainBody);
          if (report.type === "crash") {
            const body = report.body;
            details = [body.crashId || "", body.reason || ""].join(" ").trim() || details;
          } else {
            const body = report.body;
            details = body.message || details;
          }
        }
        captureMessage(`${label8}: ${details}`);
      });
    }
  }
  __name(handler14, "handler");
  return {
    name: INTEGRATION_NAME$6,
    setupOnce() {
      if (!supportsReportingObserver()) {
        return;
      }
      const observer = new WINDOW$3.ReportingObserver(
        handler14,
        {
          buffered: true,
          types
        }
      );
      observer.observe();
    },
    setup(client) {
      SETUP_CLIENTS.set(client, true);
    }
  };
}, "_reportingObserverIntegration");
const reportingObserverIntegration = defineIntegration(_reportingObserverIntegration);
const INTEGRATION_NAME$5 = "HttpClient";
const _httpClientIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const _options = {
    failedRequestStatusCodes: [[500, 599]],
    failedRequestTargets: [/.*/],
    ...options5
  };
  return {
    name: INTEGRATION_NAME$5,
    setup(client) {
      _wrapFetch(client, _options);
      _wrapXHR(client, _options);
    }
  };
}, "_httpClientIntegration");
const httpClientIntegration = defineIntegration(_httpClientIntegration);
function _fetchResponseHandler(options5, requestInfo, response, requestInit, error2) {
  if (_shouldCaptureResponse(options5, response.status, response.url)) {
    const request = _getRequest(requestInfo, requestInit);
    let requestHeaders, responseHeaders, requestCookies, responseCookies;
    if (_shouldSendDefaultPii()) {
      [requestHeaders, requestCookies] = _parseCookieHeaders("Cookie", request);
      [responseHeaders, responseCookies] = _parseCookieHeaders("Set-Cookie", response);
    }
    const event = _createEvent({
      url: request.url,
      method: request.method,
      status: response.status,
      requestHeaders,
      responseHeaders,
      requestCookies,
      responseCookies,
      error: error2
    });
    captureEvent(event);
  }
}
__name(_fetchResponseHandler, "_fetchResponseHandler");
function _parseCookieHeaders(cookieHeader, obj) {
  const headers = _extractFetchHeaders(obj.headers);
  let cookies2;
  try {
    const cookieString = headers[cookieHeader] || headers[cookieHeader.toLowerCase()] || void 0;
    if (cookieString) {
      cookies2 = _parseCookieString(cookieString);
    }
  } catch (e2) {
  }
  return [headers, cookies2];
}
__name(_parseCookieHeaders, "_parseCookieHeaders");
function _xhrResponseHandler(options5, xhr, method, headers, error2) {
  if (_shouldCaptureResponse(options5, xhr.status, xhr.responseURL)) {
    let requestHeaders, responseCookies, responseHeaders;
    if (_shouldSendDefaultPii()) {
      try {
        const cookieString = xhr.getResponseHeader("Set-Cookie") || xhr.getResponseHeader("set-cookie") || void 0;
        if (cookieString) {
          responseCookies = _parseCookieString(cookieString);
        }
      } catch (e3) {
      }
      try {
        responseHeaders = _getXHRResponseHeaders(xhr);
      } catch (e4) {
      }
      requestHeaders = headers;
    }
    const event = _createEvent({
      url: xhr.responseURL,
      method,
      status: xhr.status,
      requestHeaders,
      // Can't access request cookies from XHR
      responseHeaders,
      responseCookies,
      error: error2
    });
    captureEvent(event);
  }
}
__name(_xhrResponseHandler, "_xhrResponseHandler");
function _getResponseSizeFromHeaders(headers) {
  if (headers) {
    const contentLength = headers["Content-Length"] || headers["content-length"];
    if (contentLength) {
      return parseInt(contentLength, 10);
    }
  }
  return void 0;
}
__name(_getResponseSizeFromHeaders, "_getResponseSizeFromHeaders");
function _parseCookieString(cookieString) {
  return cookieString.split("; ").reduce((acc, cookie) => {
    const [key, value3] = cookie.split("=");
    if (key && value3) {
      acc[key] = value3;
    }
    return acc;
  }, {});
}
__name(_parseCookieString, "_parseCookieString");
function _extractFetchHeaders(headers) {
  const result = {};
  headers.forEach((value3, key) => {
    result[key] = value3;
  });
  return result;
}
__name(_extractFetchHeaders, "_extractFetchHeaders");
function _getXHRResponseHeaders(xhr) {
  const headers = xhr.getAllResponseHeaders();
  if (!headers) {
    return {};
  }
  return headers.split("\r\n").reduce((acc, line) => {
    const [key, value3] = line.split(": ");
    if (key && value3) {
      acc[key] = value3;
    }
    return acc;
  }, {});
}
__name(_getXHRResponseHeaders, "_getXHRResponseHeaders");
function _isInGivenRequestTargets(failedRequestTargets, target2) {
  return failedRequestTargets.some((givenRequestTarget) => {
    if (typeof givenRequestTarget === "string") {
      return target2.includes(givenRequestTarget);
    }
    return givenRequestTarget.test(target2);
  });
}
__name(_isInGivenRequestTargets, "_isInGivenRequestTargets");
function _isInGivenStatusRanges(failedRequestStatusCodes, status) {
  return failedRequestStatusCodes.some((range2) => {
    if (typeof range2 === "number") {
      return range2 === status;
    }
    return status >= range2[0] && status <= range2[1];
  });
}
__name(_isInGivenStatusRanges, "_isInGivenStatusRanges");
function _wrapFetch(client, options5) {
  if (!supportsNativeFetch()) {
    return;
  }
  addFetchInstrumentationHandler((handlerData) => {
    if (getClient() !== client) {
      return;
    }
    const { response, args, error: error2, virtualError } = handlerData;
    const [requestInfo, requestInit] = args;
    if (!response) {
      return;
    }
    _fetchResponseHandler(options5, requestInfo, response, requestInit, error2 || virtualError);
  }, false);
}
__name(_wrapFetch, "_wrapFetch");
function _wrapXHR(client, options5) {
  if (!("XMLHttpRequest" in GLOBAL_OBJ)) {
    return;
  }
  addXhrInstrumentationHandler((handlerData) => {
    if (getClient() !== client) {
      return;
    }
    const { error: error2, virtualError } = handlerData;
    const xhr = handlerData.xhr;
    const sentryXhrData = xhr[SENTRY_XHR_DATA_KEY];
    if (!sentryXhrData) {
      return;
    }
    const { method, request_headers: headers } = sentryXhrData;
    try {
      _xhrResponseHandler(options5, xhr, method, headers, error2 || virtualError);
    } catch (e2) {
      DEBUG_BUILD$4 && logger$2.warn("Error while extracting response event form XHR response", e2);
    }
  });
}
__name(_wrapXHR, "_wrapXHR");
function _shouldCaptureResponse(options5, status, url) {
  return _isInGivenStatusRanges(options5.failedRequestStatusCodes, status) && _isInGivenRequestTargets(options5.failedRequestTargets, url) && !isSentryRequestUrl(url, getClient());
}
__name(_shouldCaptureResponse, "_shouldCaptureResponse");
function _createEvent(data30) {
  const client = getClient();
  const virtualStackTrace = client && data30.error && data30.error instanceof Error ? data30.error.stack : void 0;
  const stack2 = virtualStackTrace && client ? client.getOptions().stackParser(virtualStackTrace, 0, 1) : void 0;
  const message3 = `HTTP Client Error with status code: ${data30.status}`;
  const event = {
    message: message3,
    exception: {
      values: [
        {
          type: "Error",
          value: message3,
          stacktrace: stack2 ? { frames: stack2 } : void 0
        }
      ]
    },
    request: {
      url: data30.url,
      method: data30.method,
      headers: data30.requestHeaders,
      cookies: data30.requestCookies
    },
    contexts: {
      response: {
        status_code: data30.status,
        headers: data30.responseHeaders,
        cookies: data30.responseCookies,
        body_size: _getResponseSizeFromHeaders(data30.responseHeaders)
      }
    }
  };
  addExceptionMechanism(event, {
    type: "http.client",
    handled: false
  });
  return event;
}
__name(_createEvent, "_createEvent");
function _getRequest(requestInfo, requestInit) {
  if (!requestInit && requestInfo instanceof Request) {
    return requestInfo;
  }
  if (requestInfo instanceof Request && requestInfo.bodyUsed) {
    return requestInfo;
  }
  return new Request(requestInfo, requestInit);
}
__name(_getRequest, "_getRequest");
function _shouldSendDefaultPii() {
  const client = getClient();
  return client ? Boolean(client.getOptions().sendDefaultPii) : false;
}
__name(_shouldSendDefaultPii, "_shouldSendDefaultPii");
const WINDOW$2 = GLOBAL_OBJ;
const DEFAULT_LINES_OF_CONTEXT = 7;
const INTEGRATION_NAME$4 = "ContextLines";
const _contextLinesIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const contextLines = options5.frameContextLines != null ? options5.frameContextLines : DEFAULT_LINES_OF_CONTEXT;
  return {
    name: INTEGRATION_NAME$4,
    processEvent(event) {
      return addSourceContext(event, contextLines);
    }
  };
}, "_contextLinesIntegration");
const contextLinesIntegration = defineIntegration(_contextLinesIntegration);
function addSourceContext(event, contextLines) {
  const doc2 = WINDOW$2.document;
  const htmlFilename = WINDOW$2.location && stripUrlQueryAndFragment(WINDOW$2.location.href);
  if (!doc2 || !htmlFilename) {
    return event;
  }
  const exceptions = event.exception && event.exception.values;
  if (!exceptions || !exceptions.length) {
    return event;
  }
  const html = doc2.documentElement.innerHTML;
  if (!html) {
    return event;
  }
  const htmlLines = ["<!DOCTYPE html>", "<html>", ...html.split("\n"), "</html>"];
  exceptions.forEach((exception) => {
    const stacktrace = exception.stacktrace;
    if (stacktrace && stacktrace.frames) {
      stacktrace.frames = stacktrace.frames.map(
        (frame) => applySourceContextToFrame(frame, htmlLines, htmlFilename, contextLines)
      );
    }
  });
  return event;
}
__name(addSourceContext, "addSourceContext");
function applySourceContextToFrame(frame, htmlLines, htmlFilename, linesOfContext) {
  if (frame.filename !== htmlFilename || !frame.lineno || !htmlLines.length) {
    return frame;
  }
  addContextToFrame(htmlLines, frame, linesOfContext);
  return frame;
}
__name(applySourceContextToFrame, "applySourceContextToFrame");
const WINDOW$1 = GLOBAL_OBJ;
const REPLAY_SESSION_KEY = "sentryReplaySession";
const REPLAY_EVENT_NAME = "replay_event";
const UNABLE_TO_SEND_REPLAY = "Unable to send Replay";
const SESSION_IDLE_PAUSE_DURATION = 3e5;
const SESSION_IDLE_EXPIRE_DURATION = 9e5;
const DEFAULT_FLUSH_MIN_DELAY = 5e3;
const DEFAULT_FLUSH_MAX_DELAY = 5500;
const BUFFER_CHECKOUT_TIME = 6e4;
const RETRY_BASE_INTERVAL = 5e3;
const RETRY_MAX_COUNT = 3;
const NETWORK_BODY_MAX_SIZE = 15e4;
const CONSOLE_ARG_MAX_SIZE = 5e3;
const SLOW_CLICK_THRESHOLD = 3e3;
const SLOW_CLICK_SCROLL_TIMEOUT = 300;
const REPLAY_MAX_EVENT_BUFFER_SIZE = 2e7;
const MIN_REPLAY_DURATION = 4999;
const MIN_REPLAY_DURATION_LIMIT = 15e3;
const MAX_REPLAY_DURATION = 36e5;
function _nullishCoalesce$1(lhs, rhsFn) {
  if (lhs != null) {
    return lhs;
  } else {
    return rhsFn();
  }
}
__name(_nullishCoalesce$1, "_nullishCoalesce$1");
function _optionalChain$5(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return void 0;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain$5, "_optionalChain$5");
var NodeType$3;
(function(NodeType3) {
  NodeType3[NodeType3["Document"] = 0] = "Document";
  NodeType3[NodeType3["DocumentType"] = 1] = "DocumentType";
  NodeType3[NodeType3["Element"] = 2] = "Element";
  NodeType3[NodeType3["Text"] = 3] = "Text";
  NodeType3[NodeType3["CDATA"] = 4] = "CDATA";
  NodeType3[NodeType3["Comment"] = 5] = "Comment";
})(NodeType$3 || (NodeType$3 = {}));
function isElement$1$1(n2) {
  return n2.nodeType === n2.ELEMENT_NODE;
}
__name(isElement$1$1, "isElement$1$1");
function isShadowRoot(n2) {
  const host = _optionalChain$5([n2, "optionalAccess", (_2) => _2.host]);
  return Boolean(_optionalChain$5([host, "optionalAccess", (_2) => _2.shadowRoot]) === n2);
}
__name(isShadowRoot, "isShadowRoot");
function isNativeShadowDom(shadowRoot) {
  return Object.prototype.toString.call(shadowRoot) === "[object ShadowRoot]";
}
__name(isNativeShadowDom, "isNativeShadowDom");
function fixBrowserCompatibilityIssuesInCSS(cssText) {
  if (cssText.includes(" background-clip: text;") && !cssText.includes(" -webkit-background-clip: text;")) {
    cssText = cssText.replace(/\sbackground-clip:\s*text;/g, " -webkit-background-clip: text; background-clip: text;");
  }
  return cssText;
}
__name(fixBrowserCompatibilityIssuesInCSS, "fixBrowserCompatibilityIssuesInCSS");
function escapeImportStatement(rule) {
  const { cssText } = rule;
  if (cssText.split('"').length < 3)
    return cssText;
  const statement = ["@import", `url(${JSON.stringify(rule.href)})`];
  if (rule.layerName === "") {
    statement.push(`layer`);
  } else if (rule.layerName) {
    statement.push(`layer(${rule.layerName})`);
  }
  if (rule.supportsText) {
    statement.push(`supports(${rule.supportsText})`);
  }
  if (rule.media.length) {
    statement.push(rule.media.mediaText);
  }
  return statement.join(" ") + ";";
}
__name(escapeImportStatement, "escapeImportStatement");
function stringifyStylesheet(s2) {
  try {
    const rules = s2.rules || s2.cssRules;
    return rules ? fixBrowserCompatibilityIssuesInCSS(Array.from(rules, stringifyRule).join("")) : null;
  } catch (error2) {
    return null;
  }
}
__name(stringifyStylesheet, "stringifyStylesheet");
function fixAllCssProperty(rule) {
  let styles = "";
  for (let i2 = 0; i2 < rule.style.length; i2++) {
    const styleDeclaration = rule.style;
    const attribute2 = styleDeclaration[i2];
    const isImportant = styleDeclaration.getPropertyPriority(attribute2);
    styles += `${attribute2}:${styleDeclaration.getPropertyValue(attribute2)}${isImportant ? ` !important` : ""};`;
  }
  return `${rule.selectorText} { ${styles} }`;
}
__name(fixAllCssProperty, "fixAllCssProperty");
function stringifyRule(rule) {
  let importStringified;
  if (isCSSImportRule(rule)) {
    try {
      importStringified = stringifyStylesheet(rule.styleSheet) || escapeImportStatement(rule);
    } catch (error2) {
    }
  } else if (isCSSStyleRule(rule)) {
    let cssText = rule.cssText;
    const needsSafariColonFix = rule.selectorText.includes(":");
    const needsAllFix = typeof rule.style["all"] === "string" && rule.style["all"];
    if (needsAllFix) {
      cssText = fixAllCssProperty(rule);
    }
    if (needsSafariColonFix) {
      cssText = fixSafariColons(cssText);
    }
    if (needsSafariColonFix || needsAllFix) {
      return cssText;
    }
  }
  return importStringified || rule.cssText;
}
__name(stringifyRule, "stringifyRule");
function fixSafariColons(cssStringified) {
  const regex2 = /(\[(?:[\w-]+)[^\\])(:(?:[\w-]+)\])/gm;
  return cssStringified.replace(regex2, "$1\\$2");
}
__name(fixSafariColons, "fixSafariColons");
function isCSSImportRule(rule) {
  return "styleSheet" in rule;
}
__name(isCSSImportRule, "isCSSImportRule");
function isCSSStyleRule(rule) {
  return "selectorText" in rule;
}
__name(isCSSStyleRule, "isCSSStyleRule");
class Mirror {
  static {
    __name(this, "Mirror");
  }
  constructor() {
    this.idNodeMap = /* @__PURE__ */ new Map();
    this.nodeMetaMap = /* @__PURE__ */ new WeakMap();
  }
  getId(n2) {
    if (!n2)
      return -1;
    const id4 = _optionalChain$5([this, "access", (_3) => _3.getMeta, "call", (_4) => _4(n2), "optionalAccess", (_5) => _5.id]);
    return _nullishCoalesce$1(id4, () => -1);
  }
  getNode(id4) {
    return this.idNodeMap.get(id4) || null;
  }
  getIds() {
    return Array.from(this.idNodeMap.keys());
  }
  getMeta(n2) {
    return this.nodeMetaMap.get(n2) || null;
  }
  removeNodeFromMap(n2) {
    const id4 = this.getId(n2);
    this.idNodeMap.delete(id4);
    if (n2.childNodes) {
      n2.childNodes.forEach((childNode) => this.removeNodeFromMap(childNode));
    }
  }
  has(id4) {
    return this.idNodeMap.has(id4);
  }
  hasNode(node3) {
    return this.nodeMetaMap.has(node3);
  }
  add(n2, meta) {
    const id4 = meta.id;
    this.idNodeMap.set(id4, n2);
    this.nodeMetaMap.set(n2, meta);
  }
  replace(id4, n2) {
    const oldNode = this.getNode(id4);
    if (oldNode) {
      const meta = this.nodeMetaMap.get(oldNode);
      if (meta)
        this.nodeMetaMap.set(n2, meta);
    }
    this.idNodeMap.set(id4, n2);
  }
  reset() {
    this.idNodeMap = /* @__PURE__ */ new Map();
    this.nodeMetaMap = /* @__PURE__ */ new WeakMap();
  }
}
function createMirror() {
  return new Mirror();
}
__name(createMirror, "createMirror");
function shouldMaskInput({ maskInputOptions, tagName, type }) {
  if (tagName === "OPTION") {
    tagName = "SELECT";
  }
  return Boolean(maskInputOptions[tagName.toLowerCase()] || type && maskInputOptions[type] || type === "password" || tagName === "INPUT" && !type && maskInputOptions["text"]);
}
__name(shouldMaskInput, "shouldMaskInput");
function maskInputValue({ isMasked: isMasked2, element, value: value3, maskInputFn }) {
  let text2 = value3 || "";
  if (!isMasked2) {
    return text2;
  }
  if (maskInputFn) {
    text2 = maskInputFn(text2, element);
  }
  return "*".repeat(text2.length);
}
__name(maskInputValue, "maskInputValue");
function toLowerCase(str) {
  return str.toLowerCase();
}
__name(toLowerCase, "toLowerCase");
function toUpperCase(str) {
  return str.toUpperCase();
}
__name(toUpperCase, "toUpperCase");
const ORIGINAL_ATTRIBUTE_NAME = "__rrweb_original__";
function is2DCanvasBlank(canvas2) {
  const ctx = canvas2.getContext("2d");
  if (!ctx)
    return true;
  const chunkSize = 50;
  for (let x2 = 0; x2 < canvas2.width; x2 += chunkSize) {
    for (let y2 = 0; y2 < canvas2.height; y2 += chunkSize) {
      const getImageData = ctx.getImageData;
      const originalGetImageData = ORIGINAL_ATTRIBUTE_NAME in getImageData ? getImageData[ORIGINAL_ATTRIBUTE_NAME] : getImageData;
      const pixelBuffer = new Uint32Array(originalGetImageData.call(ctx, x2, y2, Math.min(chunkSize, canvas2.width - x2), Math.min(chunkSize, canvas2.height - y2)).data.buffer);
      if (pixelBuffer.some((pixel) => pixel !== 0))
        return false;
    }
  }
  return true;
}
__name(is2DCanvasBlank, "is2DCanvasBlank");
function getInputType(element) {
  const type = element.type;
  return element.hasAttribute("data-rr-is-password") ? "password" : type ? toLowerCase(type) : null;
}
__name(getInputType, "getInputType");
function getInputValue(el, tagName, type) {
  if (tagName === "INPUT" && (type === "radio" || type === "checkbox")) {
    return el.getAttribute("value") || "";
  }
  return el.value;
}
__name(getInputValue, "getInputValue");
function extractFileExtension(path, baseURL) {
  let url;
  try {
    url = new URL(path, _nullishCoalesce$1(baseURL, () => window.location.href));
  } catch (err) {
    return null;
  }
  const regex2 = /\.([0-9a-z]+)(?:$)/i;
  const match2 = url.pathname.match(regex2);
  return _nullishCoalesce$1(_optionalChain$5([match2, "optionalAccess", (_6) => _6[1]]), () => null);
}
__name(extractFileExtension, "extractFileExtension");
const cachedImplementations$1 = {};
function getImplementation$1(name2) {
  const cached = cachedImplementations$1[name2];
  if (cached) {
    return cached;
  }
  const document2 = window.document;
  let impl = window[name2];
  if (document2 && typeof document2.createElement === "function") {
    try {
      const sandbox = document2.createElement("iframe");
      sandbox.hidden = true;
      document2.head.appendChild(sandbox);
      const contentWindow = sandbox.contentWindow;
      if (contentWindow && contentWindow[name2]) {
        impl = contentWindow[name2];
      }
      document2.head.removeChild(sandbox);
    } catch (e2) {
    }
  }
  return cachedImplementations$1[name2] = impl.bind(window);
}
__name(getImplementation$1, "getImplementation$1");
function setTimeout$2(...rest) {
  return getImplementation$1("setTimeout")(...rest);
}
__name(setTimeout$2, "setTimeout$2");
function clearTimeout$2(...rest) {
  return getImplementation$1("clearTimeout")(...rest);
}
__name(clearTimeout$2, "clearTimeout$2");
function getIframeContentDocument(iframe) {
  try {
    return iframe.contentDocument;
  } catch (e2) {
  }
}
__name(getIframeContentDocument, "getIframeContentDocument");
let _id$3 = 1;
const tagNameRegex = new RegExp("[^a-z0-9-_:]");
const IGNORED_NODE = -2;
function genId() {
  return _id$3++;
}
__name(genId, "genId");
function getValidTagName(element) {
  if (element instanceof HTMLFormElement) {
    return "form";
  }
  const processedTagName = toLowerCase(element.tagName);
  if (tagNameRegex.test(processedTagName)) {
    return "div";
  }
  return processedTagName;
}
__name(getValidTagName, "getValidTagName");
function extractOrigin(url) {
  let origin2 = "";
  if (url.indexOf("//") > -1) {
    origin2 = url.split("/").slice(0, 3).join("/");
  } else {
    origin2 = url.split("/")[0];
  }
  origin2 = origin2.split("?")[0];
  return origin2;
}
__name(extractOrigin, "extractOrigin");
let canvasService;
let canvasCtx;
const URL_IN_CSS_REF = /url\((?:(')([^']*)'|(")(.*?)"|([^)]*))\)/gm;
const URL_PROTOCOL_MATCH = /^(?:[a-z+]+:)?\/\//i;
const URL_WWW_MATCH = /^www\..*/i;
const DATA_URI = /^(data:)([^,]*),(.*)/i;
function absoluteToStylesheet(cssText, href) {
  return (cssText || "").replace(URL_IN_CSS_REF, (origin2, quote1, path1, quote2, path2, path3) => {
    const filePath = path1 || path2 || path3;
    const maybeQuote = quote1 || quote2 || "";
    if (!filePath) {
      return origin2;
    }
    if (URL_PROTOCOL_MATCH.test(filePath) || URL_WWW_MATCH.test(filePath)) {
      return `url(${maybeQuote}${filePath}${maybeQuote})`;
    }
    if (DATA_URI.test(filePath)) {
      return `url(${maybeQuote}${filePath}${maybeQuote})`;
    }
    if (filePath[0] === "/") {
      return `url(${maybeQuote}${extractOrigin(href) + filePath}${maybeQuote})`;
    }
    const stack2 = href.split("/");
    const parts2 = filePath.split("/");
    stack2.pop();
    for (const part of parts2) {
      if (part === ".") {
        continue;
      } else if (part === "..") {
        stack2.pop();
      } else {
        stack2.push(part);
      }
    }
    return `url(${maybeQuote}${stack2.join("/")}${maybeQuote})`;
  });
}
__name(absoluteToStylesheet, "absoluteToStylesheet");
const SRCSET_NOT_SPACES = /^[^ \t\n\r\u000c]+/;
const SRCSET_COMMAS_OR_SPACES = /^[, \t\n\r\u000c]+/;
function getAbsoluteSrcsetString(doc2, attributeValue) {
  if (attributeValue.trim() === "") {
    return attributeValue;
  }
  let pos = 0;
  function collectCharacters(regEx) {
    let chars2;
    const match2 = regEx.exec(attributeValue.substring(pos));
    if (match2) {
      chars2 = match2[0];
      pos += chars2.length;
      return chars2;
    }
    return "";
  }
  __name(collectCharacters, "collectCharacters");
  const output = [];
  while (true) {
    collectCharacters(SRCSET_COMMAS_OR_SPACES);
    if (pos >= attributeValue.length) {
      break;
    }
    let url = collectCharacters(SRCSET_NOT_SPACES);
    if (url.slice(-1) === ",") {
      url = absoluteToDoc(doc2, url.substring(0, url.length - 1));
      output.push(url);
    } else {
      let descriptorsStr = "";
      url = absoluteToDoc(doc2, url);
      let inParens = false;
      while (true) {
        const c2 = attributeValue.charAt(pos);
        if (c2 === "") {
          output.push((url + descriptorsStr).trim());
          break;
        } else if (!inParens) {
          if (c2 === ",") {
            pos += 1;
            output.push((url + descriptorsStr).trim());
            break;
          } else if (c2 === "(") {
            inParens = true;
          }
        } else {
          if (c2 === ")") {
            inParens = false;
          }
        }
        descriptorsStr += c2;
        pos += 1;
      }
    }
  }
  return output.join(", ");
}
__name(getAbsoluteSrcsetString, "getAbsoluteSrcsetString");
const cachedDocument = /* @__PURE__ */ new WeakMap();
function absoluteToDoc(doc2, attributeValue) {
  if (!attributeValue || attributeValue.trim() === "") {
    return attributeValue;
  }
  return getHref(doc2, attributeValue);
}
__name(absoluteToDoc, "absoluteToDoc");
function isSVGElement(el) {
  return Boolean(el.tagName === "svg" || el.ownerSVGElement);
}
__name(isSVGElement, "isSVGElement");
function getHref(doc2, customHref) {
  let a2 = cachedDocument.get(doc2);
  if (!a2) {
    a2 = doc2.createElement("a");
    cachedDocument.set(doc2, a2);
  }
  if (!customHref) {
    customHref = "";
  } else if (customHref.startsWith("blob:") || customHref.startsWith("data:")) {
    return customHref;
  }
  a2.setAttribute("href", customHref);
  return a2.href;
}
__name(getHref, "getHref");
function transformAttribute(doc2, tagName, name2, value3, element, maskAttributeFn) {
  if (!value3) {
    return value3;
  }
  if (name2 === "src" || name2 === "href" && !(tagName === "use" && value3[0] === "#")) {
    return absoluteToDoc(doc2, value3);
  } else if (name2 === "xlink:href" && value3[0] !== "#") {
    return absoluteToDoc(doc2, value3);
  } else if (name2 === "background" && (tagName === "table" || tagName === "td" || tagName === "th")) {
    return absoluteToDoc(doc2, value3);
  } else if (name2 === "srcset") {
    return getAbsoluteSrcsetString(doc2, value3);
  } else if (name2 === "style") {
    return absoluteToStylesheet(value3, getHref(doc2));
  } else if (tagName === "object" && name2 === "data") {
    return absoluteToDoc(doc2, value3);
  }
  if (typeof maskAttributeFn === "function") {
    return maskAttributeFn(name2, value3, element);
  }
  return value3;
}
__name(transformAttribute, "transformAttribute");
function ignoreAttribute(tagName, name2, _value) {
  return (tagName === "video" || tagName === "audio") && name2 === "autoplay";
}
__name(ignoreAttribute, "ignoreAttribute");
function _isBlockedElement(element, blockClass, blockSelector, unblockSelector) {
  try {
    if (unblockSelector && element.matches(unblockSelector)) {
      return false;
    }
    if (typeof blockClass === "string") {
      if (element.classList.contains(blockClass)) {
        return true;
      }
    } else {
      for (let eIndex = element.classList.length; eIndex--; ) {
        const className = element.classList[eIndex];
        if (blockClass.test(className)) {
          return true;
        }
      }
    }
    if (blockSelector) {
      return element.matches(blockSelector);
    }
  } catch (e2) {
  }
  return false;
}
__name(_isBlockedElement, "_isBlockedElement");
function elementClassMatchesRegex$1(el, regex2) {
  for (let eIndex = el.classList.length; eIndex--; ) {
    const className = el.classList[eIndex];
    if (regex2.test(className)) {
      return true;
    }
  }
  return false;
}
__name(elementClassMatchesRegex$1, "elementClassMatchesRegex$1");
function distanceToMatch$1(node3, matchPredicate, limit = Infinity, distance2 = 0) {
  if (!node3)
    return -1;
  if (node3.nodeType !== node3.ELEMENT_NODE)
    return -1;
  if (distance2 > limit)
    return -1;
  if (matchPredicate(node3))
    return distance2;
  return distanceToMatch$1(node3.parentNode, matchPredicate, limit, distance2 + 1);
}
__name(distanceToMatch$1, "distanceToMatch$1");
function createMatchPredicate$1(className, selector) {
  return (node3) => {
    const el = node3;
    if (el === null)
      return false;
    try {
      if (className) {
        if (typeof className === "string") {
          if (el.matches(`.${className}`))
            return true;
        } else if (elementClassMatchesRegex$1(el, className)) {
          return true;
        }
      }
      if (selector && el.matches(selector))
        return true;
      return false;
    } catch (e2) {
      return false;
    }
  };
}
__name(createMatchPredicate$1, "createMatchPredicate$1");
function needMaskingText(node3, maskTextClass, maskTextSelector, unmaskTextClass, unmaskTextSelector, maskAllText) {
  try {
    const el = node3.nodeType === node3.ELEMENT_NODE ? node3 : node3.parentElement;
    if (el === null)
      return false;
    if (el.tagName === "INPUT") {
      const autocomplete = el.getAttribute("autocomplete");
      const disallowedAutocompleteValues = [
        "current-password",
        "new-password",
        "cc-number",
        "cc-exp",
        "cc-exp-month",
        "cc-exp-year",
        "cc-csc"
      ];
      if (disallowedAutocompleteValues.includes(autocomplete)) {
        return true;
      }
    }
    let maskDistance = -1;
    let unmaskDistance = -1;
    if (maskAllText) {
      unmaskDistance = distanceToMatch$1(el, createMatchPredicate$1(unmaskTextClass, unmaskTextSelector));
      if (unmaskDistance < 0) {
        return true;
      }
      maskDistance = distanceToMatch$1(el, createMatchPredicate$1(maskTextClass, maskTextSelector), unmaskDistance >= 0 ? unmaskDistance : Infinity);
    } else {
      maskDistance = distanceToMatch$1(el, createMatchPredicate$1(maskTextClass, maskTextSelector));
      if (maskDistance < 0) {
        return false;
      }
      unmaskDistance = distanceToMatch$1(el, createMatchPredicate$1(unmaskTextClass, unmaskTextSelector), maskDistance >= 0 ? maskDistance : Infinity);
    }
    return maskDistance >= 0 ? unmaskDistance >= 0 ? maskDistance <= unmaskDistance : true : unmaskDistance >= 0 ? false : !!maskAllText;
  } catch (e2) {
  }
  return !!maskAllText;
}
__name(needMaskingText, "needMaskingText");
function onceIframeLoaded(iframeEl, listener, iframeLoadTimeout) {
  const win = iframeEl.contentWindow;
  if (!win) {
    return;
  }
  let fired = false;
  let readyState;
  try {
    readyState = win.document.readyState;
  } catch (error2) {
    return;
  }
  if (readyState !== "complete") {
    const timer = setTimeout$2(() => {
      if (!fired) {
        listener();
        fired = true;
      }
    }, iframeLoadTimeout);
    iframeEl.addEventListener("load", () => {
      clearTimeout$2(timer);
      fired = true;
      listener();
    });
    return;
  }
  const blankUrl = "about:blank";
  if (win.location.href !== blankUrl || iframeEl.src === blankUrl || iframeEl.src === "") {
    setTimeout$2(listener, 0);
    return iframeEl.addEventListener("load", listener);
  }
  iframeEl.addEventListener("load", listener);
}
__name(onceIframeLoaded, "onceIframeLoaded");
function onceStylesheetLoaded(link2, listener, styleSheetLoadTimeout) {
  let fired = false;
  let styleSheetLoaded;
  try {
    styleSheetLoaded = link2.sheet;
  } catch (error2) {
    return;
  }
  if (styleSheetLoaded)
    return;
  const timer = setTimeout$2(() => {
    if (!fired) {
      listener();
      fired = true;
    }
  }, styleSheetLoadTimeout);
  link2.addEventListener("load", () => {
    clearTimeout$2(timer);
    fired = true;
    listener();
  });
}
__name(onceStylesheetLoaded, "onceStylesheetLoaded");
function serializeNode(n2, options5) {
  const { doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, maskAllText, maskAttributeFn, maskTextClass, unmaskTextClass, maskTextSelector, unmaskTextSelector, inlineStylesheet, maskInputOptions = {}, maskTextFn, maskInputFn, dataURLOptions = {}, inlineImages, recordCanvas, keepIframeSrcFn, newlyAddedElement = false } = options5;
  const rootId = getRootId(doc2, mirror2);
  switch (n2.nodeType) {
    case n2.DOCUMENT_NODE:
      if (n2.compatMode !== "CSS1Compat") {
        return {
          type: NodeType$3.Document,
          childNodes: [],
          compatMode: n2.compatMode
        };
      } else {
        return {
          type: NodeType$3.Document,
          childNodes: []
        };
      }
    case n2.DOCUMENT_TYPE_NODE:
      return {
        type: NodeType$3.DocumentType,
        name: n2.name,
        publicId: n2.publicId,
        systemId: n2.systemId,
        rootId
      };
    case n2.ELEMENT_NODE:
      return serializeElementNode(n2, {
        doc: doc2,
        blockClass,
        blockSelector,
        unblockSelector,
        inlineStylesheet,
        maskAttributeFn,
        maskInputOptions,
        maskInputFn,
        dataURLOptions,
        inlineImages,
        recordCanvas,
        keepIframeSrcFn,
        newlyAddedElement,
        rootId,
        maskAllText,
        maskTextClass,
        unmaskTextClass,
        maskTextSelector,
        unmaskTextSelector
      });
    case n2.TEXT_NODE:
      return serializeTextNode(n2, {
        doc: doc2,
        maskAllText,
        maskTextClass,
        unmaskTextClass,
        maskTextSelector,
        unmaskTextSelector,
        maskTextFn,
        maskInputOptions,
        maskInputFn,
        rootId
      });
    case n2.CDATA_SECTION_NODE:
      return {
        type: NodeType$3.CDATA,
        textContent: "",
        rootId
      };
    case n2.COMMENT_NODE:
      return {
        type: NodeType$3.Comment,
        textContent: n2.textContent || "",
        rootId
      };
    default:
      return false;
  }
}
__name(serializeNode, "serializeNode");
function getRootId(doc2, mirror2) {
  if (!mirror2.hasNode(doc2))
    return void 0;
  const docId = mirror2.getId(doc2);
  return docId === 1 ? void 0 : docId;
}
__name(getRootId, "getRootId");
function serializeTextNode(n2, options5) {
  const { maskAllText, maskTextClass, unmaskTextClass, maskTextSelector, unmaskTextSelector, maskTextFn, maskInputOptions, maskInputFn, rootId } = options5;
  const parentTagName = n2.parentNode && n2.parentNode.tagName;
  let textContent = n2.textContent;
  const isStyle = parentTagName === "STYLE" ? true : void 0;
  const isScript = parentTagName === "SCRIPT" ? true : void 0;
  const isTextarea = parentTagName === "TEXTAREA" ? true : void 0;
  if (isStyle && textContent) {
    try {
      if (n2.nextSibling || n2.previousSibling) {
      } else if (_optionalChain$5([n2, "access", (_7) => _7.parentNode, "access", (_8) => _8.sheet, "optionalAccess", (_9) => _9.cssRules])) {
        textContent = stringifyStylesheet(n2.parentNode.sheet);
      }
    } catch (err) {
      console.warn(`Cannot get CSS styles from text's parentNode. Error: ${err}`, n2);
    }
    textContent = absoluteToStylesheet(textContent, getHref(options5.doc));
  }
  if (isScript) {
    textContent = "SCRIPT_PLACEHOLDER";
  }
  const forceMask = needMaskingText(n2, maskTextClass, maskTextSelector, unmaskTextClass, unmaskTextSelector, maskAllText);
  if (!isStyle && !isScript && !isTextarea && textContent && forceMask) {
    textContent = maskTextFn ? maskTextFn(textContent, n2.parentElement) : textContent.replace(/[\S]/g, "*");
  }
  if (isTextarea && textContent && (maskInputOptions.textarea || forceMask)) {
    textContent = maskInputFn ? maskInputFn(textContent, n2.parentNode) : textContent.replace(/[\S]/g, "*");
  }
  if (parentTagName === "OPTION" && textContent) {
    const isInputMasked = shouldMaskInput({
      type: null,
      tagName: parentTagName,
      maskInputOptions
    });
    textContent = maskInputValue({
      isMasked: needMaskingText(n2, maskTextClass, maskTextSelector, unmaskTextClass, unmaskTextSelector, isInputMasked),
      element: n2,
      value: textContent,
      maskInputFn
    });
  }
  return {
    type: NodeType$3.Text,
    textContent: textContent || "",
    isStyle,
    rootId
  };
}
__name(serializeTextNode, "serializeTextNode");
function serializeElementNode(n2, options5) {
  const { doc: doc2, blockClass, blockSelector, unblockSelector, inlineStylesheet, maskInputOptions = {}, maskAttributeFn, maskInputFn, dataURLOptions = {}, inlineImages, recordCanvas, keepIframeSrcFn, newlyAddedElement = false, rootId, maskAllText, maskTextClass, unmaskTextClass, maskTextSelector, unmaskTextSelector } = options5;
  const needBlock = _isBlockedElement(n2, blockClass, blockSelector, unblockSelector);
  const tagName = getValidTagName(n2);
  let attributes = {};
  const len = n2.attributes.length;
  for (let i2 = 0; i2 < len; i2++) {
    const attr = n2.attributes[i2];
    if (attr.name && !ignoreAttribute(tagName, attr.name, attr.value)) {
      attributes[attr.name] = transformAttribute(doc2, tagName, toLowerCase(attr.name), attr.value, n2, maskAttributeFn);
    }
  }
  if (tagName === "link" && inlineStylesheet) {
    const stylesheet = Array.from(doc2.styleSheets).find((s2) => {
      return s2.href === n2.href;
    });
    let cssText = null;
    if (stylesheet) {
      cssText = stringifyStylesheet(stylesheet);
    }
    if (cssText) {
      attributes.rel = null;
      attributes.href = null;
      attributes.crossorigin = null;
      attributes._cssText = absoluteToStylesheet(cssText, stylesheet.href);
    }
  }
  if (tagName === "style" && n2.sheet && !(n2.innerText || n2.textContent || "").trim().length) {
    const cssText = stringifyStylesheet(n2.sheet);
    if (cssText) {
      attributes._cssText = absoluteToStylesheet(cssText, getHref(doc2));
    }
  }
  if (tagName === "input" || tagName === "textarea" || tagName === "select" || tagName === "option") {
    const el = n2;
    const type = getInputType(el);
    const value3 = getInputValue(el, toUpperCase(tagName), type);
    const checked4 = el.checked;
    if (type !== "submit" && type !== "button" && value3) {
      const forceMask = needMaskingText(el, maskTextClass, maskTextSelector, unmaskTextClass, unmaskTextSelector, shouldMaskInput({
        type,
        tagName: toUpperCase(tagName),
        maskInputOptions
      }));
      attributes.value = maskInputValue({
        isMasked: forceMask,
        element: el,
        value: value3,
        maskInputFn
      });
    }
    if (checked4) {
      attributes.checked = checked4;
    }
  }
  if (tagName === "option") {
    if (n2.selected && !maskInputOptions["select"]) {
      attributes.selected = true;
    } else {
      delete attributes.selected;
    }
  }
  if (tagName === "canvas" && recordCanvas) {
    if (n2.__context === "2d") {
      if (!is2DCanvasBlank(n2)) {
        attributes.rr_dataURL = n2.toDataURL(dataURLOptions.type, dataURLOptions.quality);
      }
    } else if (!("__context" in n2)) {
      const canvasDataURL = n2.toDataURL(dataURLOptions.type, dataURLOptions.quality);
      const blankCanvas = doc2.createElement("canvas");
      blankCanvas.width = n2.width;
      blankCanvas.height = n2.height;
      const blankCanvasDataURL = blankCanvas.toDataURL(dataURLOptions.type, dataURLOptions.quality);
      if (canvasDataURL !== blankCanvasDataURL) {
        attributes.rr_dataURL = canvasDataURL;
      }
    }
  }
  if (tagName === "img" && inlineImages) {
    if (!canvasService) {
      canvasService = doc2.createElement("canvas");
      canvasCtx = canvasService.getContext("2d");
    }
    const image2 = n2;
    const imageSrc = image2.currentSrc || image2.getAttribute("src") || "<unknown-src>";
    const priorCrossOrigin = image2.crossOrigin;
    const recordInlineImage = /* @__PURE__ */ __name(() => {
      image2.removeEventListener("load", recordInlineImage);
      try {
        canvasService.width = image2.naturalWidth;
        canvasService.height = image2.naturalHeight;
        canvasCtx.drawImage(image2, 0, 0);
        attributes.rr_dataURL = canvasService.toDataURL(dataURLOptions.type, dataURLOptions.quality);
      } catch (err) {
        if (image2.crossOrigin !== "anonymous") {
          image2.crossOrigin = "anonymous";
          if (image2.complete && image2.naturalWidth !== 0)
            recordInlineImage();
          else
            image2.addEventListener("load", recordInlineImage);
          return;
        } else {
          console.warn(`Cannot inline img src=${imageSrc}! Error: ${err}`);
        }
      }
      if (image2.crossOrigin === "anonymous") {
        priorCrossOrigin ? attributes.crossOrigin = priorCrossOrigin : image2.removeAttribute("crossorigin");
      }
    }, "recordInlineImage");
    if (image2.complete && image2.naturalWidth !== 0)
      recordInlineImage();
    else
      image2.addEventListener("load", recordInlineImage);
  }
  if (tagName === "audio" || tagName === "video") {
    attributes.rr_mediaState = n2.paused ? "paused" : "played";
    attributes.rr_mediaCurrentTime = n2.currentTime;
  }
  if (!newlyAddedElement) {
    if (n2.scrollLeft) {
      attributes.rr_scrollLeft = n2.scrollLeft;
    }
    if (n2.scrollTop) {
      attributes.rr_scrollTop = n2.scrollTop;
    }
  }
  if (needBlock) {
    const { width: width2, height } = n2.getBoundingClientRect();
    attributes = {
      class: attributes.class,
      rr_width: `${width2}px`,
      rr_height: `${height}px`
    };
  }
  if (tagName === "iframe" && !keepIframeSrcFn(attributes.src)) {
    if (!needBlock && !getIframeContentDocument(n2)) {
      attributes.rr_src = attributes.src;
    }
    delete attributes.src;
  }
  let isCustomElement;
  try {
    if (customElements.get(tagName))
      isCustomElement = true;
  } catch (e2) {
  }
  return {
    type: NodeType$3.Element,
    tagName,
    attributes,
    childNodes: [],
    isSVG: isSVGElement(n2) || void 0,
    needBlock,
    rootId,
    isCustom: isCustomElement
  };
}
__name(serializeElementNode, "serializeElementNode");
function lowerIfExists(maybeAttr) {
  if (maybeAttr === void 0 || maybeAttr === null) {
    return "";
  } else {
    return maybeAttr.toLowerCase();
  }
}
__name(lowerIfExists, "lowerIfExists");
function slimDOMExcluded(sn, slimDOMOptions) {
  if (slimDOMOptions.comment && sn.type === NodeType$3.Comment) {
    return true;
  } else if (sn.type === NodeType$3.Element) {
    if (slimDOMOptions.script && (sn.tagName === "script" || sn.tagName === "link" && (sn.attributes.rel === "preload" || sn.attributes.rel === "modulepreload") || sn.tagName === "link" && sn.attributes.rel === "prefetch" && typeof sn.attributes.href === "string" && extractFileExtension(sn.attributes.href) === "js")) {
      return true;
    } else if (slimDOMOptions.headFavicon && (sn.tagName === "link" && sn.attributes.rel === "shortcut icon" || sn.tagName === "meta" && (lowerIfExists(sn.attributes.name).match(/^msapplication-tile(image|color)$/) || lowerIfExists(sn.attributes.name) === "application-name" || lowerIfExists(sn.attributes.rel) === "icon" || lowerIfExists(sn.attributes.rel) === "apple-touch-icon" || lowerIfExists(sn.attributes.rel) === "shortcut icon"))) {
      return true;
    } else if (sn.tagName === "meta") {
      if (slimDOMOptions.headMetaDescKeywords && lowerIfExists(sn.attributes.name).match(/^description|keywords$/)) {
        return true;
      } else if (slimDOMOptions.headMetaSocial && (lowerIfExists(sn.attributes.property).match(/^(og|twitter|fb):/) || lowerIfExists(sn.attributes.name).match(/^(og|twitter):/) || lowerIfExists(sn.attributes.name) === "pinterest")) {
        return true;
      } else if (slimDOMOptions.headMetaRobots && (lowerIfExists(sn.attributes.name) === "robots" || lowerIfExists(sn.attributes.name) === "googlebot" || lowerIfExists(sn.attributes.name) === "bingbot")) {
        return true;
      } else if (slimDOMOptions.headMetaHttpEquiv && sn.attributes["http-equiv"] !== void 0) {
        return true;
      } else if (slimDOMOptions.headMetaAuthorship && (lowerIfExists(sn.attributes.name) === "author" || lowerIfExists(sn.attributes.name) === "generator" || lowerIfExists(sn.attributes.name) === "framework" || lowerIfExists(sn.attributes.name) === "publisher" || lowerIfExists(sn.attributes.name) === "progid" || lowerIfExists(sn.attributes.property).match(/^article:/) || lowerIfExists(sn.attributes.property).match(/^product:/))) {
        return true;
      } else if (slimDOMOptions.headMetaVerification && (lowerIfExists(sn.attributes.name) === "google-site-verification" || lowerIfExists(sn.attributes.name) === "yandex-verification" || lowerIfExists(sn.attributes.name) === "csrf-token" || lowerIfExists(sn.attributes.name) === "p:domain_verify" || lowerIfExists(sn.attributes.name) === "verify-v1" || lowerIfExists(sn.attributes.name) === "verification" || lowerIfExists(sn.attributes.name) === "shopify-checkout-api-token")) {
        return true;
      }
    }
  }
  return false;
}
__name(slimDOMExcluded, "slimDOMExcluded");
function serializeNodeWithId(n2, options5) {
  const { doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, maskAllText, maskTextClass, unmaskTextClass, maskTextSelector, unmaskTextSelector, skipChild = false, inlineStylesheet = true, maskInputOptions = {}, maskAttributeFn, maskTextFn, maskInputFn, slimDOMOptions, dataURLOptions = {}, inlineImages = false, recordCanvas = false, onSerialize, onIframeLoad, iframeLoadTimeout = 5e3, onStylesheetLoad, stylesheetLoadTimeout = 5e3, keepIframeSrcFn = /* @__PURE__ */ __name(() => false, "keepIframeSrcFn"), newlyAddedElement = false } = options5;
  let { preserveWhiteSpace = true } = options5;
  const _serializedNode = serializeNode(n2, {
    doc: doc2,
    mirror: mirror2,
    blockClass,
    blockSelector,
    maskAllText,
    unblockSelector,
    maskTextClass,
    unmaskTextClass,
    maskTextSelector,
    unmaskTextSelector,
    inlineStylesheet,
    maskInputOptions,
    maskAttributeFn,
    maskTextFn,
    maskInputFn,
    dataURLOptions,
    inlineImages,
    recordCanvas,
    keepIframeSrcFn,
    newlyAddedElement
  });
  if (!_serializedNode) {
    console.warn(n2, "not serialized");
    return null;
  }
  let id4;
  if (mirror2.hasNode(n2)) {
    id4 = mirror2.getId(n2);
  } else if (slimDOMExcluded(_serializedNode, slimDOMOptions) || !preserveWhiteSpace && _serializedNode.type === NodeType$3.Text && !_serializedNode.isStyle && !_serializedNode.textContent.replace(/^\s+|\s+$/gm, "").length) {
    id4 = IGNORED_NODE;
  } else {
    id4 = genId();
  }
  const serializedNode = Object.assign(_serializedNode, { id: id4 });
  mirror2.add(n2, serializedNode);
  if (id4 === IGNORED_NODE) {
    return null;
  }
  if (onSerialize) {
    onSerialize(n2);
  }
  let recordChild = !skipChild;
  if (serializedNode.type === NodeType$3.Element) {
    recordChild = recordChild && !serializedNode.needBlock;
    delete serializedNode.needBlock;
    const shadowRoot = n2.shadowRoot;
    if (shadowRoot && isNativeShadowDom(shadowRoot))
      serializedNode.isShadowHost = true;
  }
  if ((serializedNode.type === NodeType$3.Document || serializedNode.type === NodeType$3.Element) && recordChild) {
    if (slimDOMOptions.headWhitespace && serializedNode.type === NodeType$3.Element && serializedNode.tagName === "head") {
      preserveWhiteSpace = false;
    }
    const bypassOptions = {
      doc: doc2,
      mirror: mirror2,
      blockClass,
      blockSelector,
      maskAllText,
      unblockSelector,
      maskTextClass,
      unmaskTextClass,
      maskTextSelector,
      unmaskTextSelector,
      skipChild,
      inlineStylesheet,
      maskInputOptions,
      maskAttributeFn,
      maskTextFn,
      maskInputFn,
      slimDOMOptions,
      dataURLOptions,
      inlineImages,
      recordCanvas,
      preserveWhiteSpace,
      onSerialize,
      onIframeLoad,
      iframeLoadTimeout,
      onStylesheetLoad,
      stylesheetLoadTimeout,
      keepIframeSrcFn
    };
    for (const childN of Array.from(n2.childNodes)) {
      const serializedChildNode = serializeNodeWithId(childN, bypassOptions);
      if (serializedChildNode) {
        serializedNode.childNodes.push(serializedChildNode);
      }
    }
    if (isElement$1$1(n2) && n2.shadowRoot) {
      for (const childN of Array.from(n2.shadowRoot.childNodes)) {
        const serializedChildNode = serializeNodeWithId(childN, bypassOptions);
        if (serializedChildNode) {
          isNativeShadowDom(n2.shadowRoot) && (serializedChildNode.isShadow = true);
          serializedNode.childNodes.push(serializedChildNode);
        }
      }
    }
  }
  if (n2.parentNode && isShadowRoot(n2.parentNode) && isNativeShadowDom(n2.parentNode)) {
    serializedNode.isShadow = true;
  }
  if (serializedNode.type === NodeType$3.Element && serializedNode.tagName === "iframe") {
    onceIframeLoaded(n2, () => {
      const iframeDoc = getIframeContentDocument(n2);
      if (iframeDoc && onIframeLoad) {
        const serializedIframeNode = serializeNodeWithId(iframeDoc, {
          doc: iframeDoc,
          mirror: mirror2,
          blockClass,
          blockSelector,
          unblockSelector,
          maskAllText,
          maskTextClass,
          unmaskTextClass,
          maskTextSelector,
          unmaskTextSelector,
          skipChild: false,
          inlineStylesheet,
          maskInputOptions,
          maskAttributeFn,
          maskTextFn,
          maskInputFn,
          slimDOMOptions,
          dataURLOptions,
          inlineImages,
          recordCanvas,
          preserveWhiteSpace,
          onSerialize,
          onIframeLoad,
          iframeLoadTimeout,
          onStylesheetLoad,
          stylesheetLoadTimeout,
          keepIframeSrcFn
        });
        if (serializedIframeNode) {
          onIframeLoad(n2, serializedIframeNode);
        }
      }
    }, iframeLoadTimeout);
  }
  if (serializedNode.type === NodeType$3.Element && serializedNode.tagName === "link" && typeof serializedNode.attributes.rel === "string" && (serializedNode.attributes.rel === "stylesheet" || serializedNode.attributes.rel === "preload" && typeof serializedNode.attributes.href === "string" && extractFileExtension(serializedNode.attributes.href) === "css")) {
    onceStylesheetLoaded(n2, () => {
      if (onStylesheetLoad) {
        const serializedLinkNode = serializeNodeWithId(n2, {
          doc: doc2,
          mirror: mirror2,
          blockClass,
          blockSelector,
          unblockSelector,
          maskAllText,
          maskTextClass,
          unmaskTextClass,
          maskTextSelector,
          unmaskTextSelector,
          skipChild: false,
          inlineStylesheet,
          maskInputOptions,
          maskAttributeFn,
          maskTextFn,
          maskInputFn,
          slimDOMOptions,
          dataURLOptions,
          inlineImages,
          recordCanvas,
          preserveWhiteSpace,
          onSerialize,
          onIframeLoad,
          iframeLoadTimeout,
          onStylesheetLoad,
          stylesheetLoadTimeout,
          keepIframeSrcFn
        });
        if (serializedLinkNode) {
          onStylesheetLoad(n2, serializedLinkNode);
        }
      }
    }, stylesheetLoadTimeout);
  }
  return serializedNode;
}
__name(serializeNodeWithId, "serializeNodeWithId");
function snapshot(n2, options5) {
  const { mirror: mirror2 = new Mirror(), blockClass = "rr-block", blockSelector = null, unblockSelector = null, maskAllText = false, maskTextClass = "rr-mask", unmaskTextClass = null, maskTextSelector = null, unmaskTextSelector = null, inlineStylesheet = true, inlineImages = false, recordCanvas = false, maskAllInputs = false, maskAttributeFn, maskTextFn, maskInputFn, slimDOM = false, dataURLOptions, preserveWhiteSpace, onSerialize, onIframeLoad, iframeLoadTimeout, onStylesheetLoad, stylesheetLoadTimeout, keepIframeSrcFn = /* @__PURE__ */ __name(() => false, "keepIframeSrcFn") } = options5 || {};
  const maskInputOptions = maskAllInputs === true ? {
    color: true,
    date: true,
    "datetime-local": true,
    email: true,
    month: true,
    number: true,
    range: true,
    search: true,
    tel: true,
    text: true,
    time: true,
    url: true,
    week: true,
    textarea: true,
    select: true
  } : maskAllInputs === false ? {} : maskAllInputs;
  const slimDOMOptions = slimDOM === true || slimDOM === "all" ? {
    script: true,
    comment: true,
    headFavicon: true,
    headWhitespace: true,
    headMetaDescKeywords: slimDOM === "all",
    headMetaSocial: true,
    headMetaRobots: true,
    headMetaHttpEquiv: true,
    headMetaAuthorship: true,
    headMetaVerification: true
  } : slimDOM === false ? {} : slimDOM;
  return serializeNodeWithId(n2, {
    doc: n2,
    mirror: mirror2,
    blockClass,
    blockSelector,
    unblockSelector,
    maskAllText,
    maskTextClass,
    unmaskTextClass,
    maskTextSelector,
    unmaskTextSelector,
    skipChild: false,
    inlineStylesheet,
    maskInputOptions,
    maskAttributeFn,
    maskTextFn,
    maskInputFn,
    slimDOMOptions,
    dataURLOptions,
    inlineImages,
    recordCanvas,
    preserveWhiteSpace,
    onSerialize,
    onIframeLoad,
    iframeLoadTimeout,
    onStylesheetLoad,
    stylesheetLoadTimeout,
    keepIframeSrcFn,
    newlyAddedElement: false
  });
}
__name(snapshot, "snapshot");
function _optionalChain$4(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return void 0;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain$4, "_optionalChain$4");
function on(type, fn, target2 = document) {
  const options5 = { capture: true, passive: true };
  target2.addEventListener(type, fn, options5);
  return () => target2.removeEventListener(type, fn, options5);
}
__name(on, "on");
const DEPARTED_MIRROR_ACCESS_WARNING$1 = "Please stop import mirror directly. Instead of that,\r\nnow you can use replayer.getMirror() to access the mirror instance of a replayer,\r\nor you can use record.mirror to access the mirror instance during recording.";
let _mirror$1 = {
  map: {},
  getId() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
    return -1;
  },
  getNode() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
    return null;
  },
  removeNodeFromMap() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
  },
  has() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
    return false;
  },
  reset() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
  }
};
if (typeof window !== "undefined" && window.Proxy && window.Reflect) {
  _mirror$1 = new Proxy(_mirror$1, {
    get(target2, prop2, receiver) {
      if (prop2 === "map") {
        console.error(DEPARTED_MIRROR_ACCESS_WARNING$1);
      }
      return Reflect.get(target2, prop2, receiver);
    }
  });
}
function throttle$1(func, wait, options5 = {}) {
  let timeout = null;
  let previous = 0;
  return function(...args) {
    const now2 = Date.now();
    if (!previous && options5.leading === false) {
      previous = now2;
    }
    const remaining = wait - (now2 - previous);
    const context = this;
    if (remaining <= 0 || remaining > wait) {
      if (timeout) {
        clearTimeout$1(timeout);
        timeout = null;
      }
      previous = now2;
      func.apply(context, args);
    } else if (!timeout && options5.trailing !== false) {
      timeout = setTimeout$1$1(() => {
        previous = options5.leading === false ? 0 : Date.now();
        timeout = null;
        func.apply(context, args);
      }, remaining);
    }
  };
}
__name(throttle$1, "throttle$1");
function hookSetter$1(target2, key, d2, isRevoked, win = window) {
  const original = win.Object.getOwnPropertyDescriptor(target2, key);
  win.Object.defineProperty(target2, key, isRevoked ? d2 : {
    set(value3) {
      setTimeout$1$1(() => {
        d2.set.call(this, value3);
      }, 0);
      if (original && original.set) {
        original.set.call(this, value3);
      }
    }
  });
  return () => hookSetter$1(target2, key, original || {}, true);
}
__name(hookSetter$1, "hookSetter$1");
function patch$2(source, name2, replacement) {
  try {
    if (!(name2 in source)) {
      return () => {
      };
    }
    const original = source[name2];
    const wrapped = replacement(original);
    if (typeof wrapped === "function") {
      wrapped.prototype = wrapped.prototype || {};
      Object.defineProperties(wrapped, {
        __rrweb_original__: {
          enumerable: false,
          value: original
        }
      });
    }
    source[name2] = wrapped;
    return () => {
      source[name2] = original;
    };
  } catch (e2) {
    return () => {
    };
  }
}
__name(patch$2, "patch$2");
let nowTimestamp = Date.now;
if (!/[1-9][0-9]{12}/.test(Date.now().toString())) {
  nowTimestamp = /* @__PURE__ */ __name(() => (/* @__PURE__ */ new Date()).getTime(), "nowTimestamp");
}
function getWindowScroll(win) {
  const doc2 = win.document;
  return {
    left: doc2.scrollingElement ? doc2.scrollingElement.scrollLeft : win.pageXOffset !== void 0 ? win.pageXOffset : _optionalChain$4([doc2, "optionalAccess", (_2) => _2.documentElement, "access", (_2) => _2.scrollLeft]) || _optionalChain$4([doc2, "optionalAccess", (_3) => _3.body, "optionalAccess", (_4) => _4.parentElement, "optionalAccess", (_5) => _5.scrollLeft]) || _optionalChain$4([doc2, "optionalAccess", (_6) => _6.body, "optionalAccess", (_7) => _7.scrollLeft]) || 0,
    top: doc2.scrollingElement ? doc2.scrollingElement.scrollTop : win.pageYOffset !== void 0 ? win.pageYOffset : _optionalChain$4([doc2, "optionalAccess", (_8) => _8.documentElement, "access", (_9) => _9.scrollTop]) || _optionalChain$4([doc2, "optionalAccess", (_10) => _10.body, "optionalAccess", (_11) => _11.parentElement, "optionalAccess", (_12) => _12.scrollTop]) || _optionalChain$4([doc2, "optionalAccess", (_13) => _13.body, "optionalAccess", (_14) => _14.scrollTop]) || 0
  };
}
__name(getWindowScroll, "getWindowScroll");
function getWindowHeight() {
  return window.innerHeight || document.documentElement && document.documentElement.clientHeight || document.body && document.body.clientHeight;
}
__name(getWindowHeight, "getWindowHeight");
function getWindowWidth() {
  return window.innerWidth || document.documentElement && document.documentElement.clientWidth || document.body && document.body.clientWidth;
}
__name(getWindowWidth, "getWindowWidth");
function closestElementOfNode$1(node3) {
  if (!node3) {
    return null;
  }
  const el = node3.nodeType === node3.ELEMENT_NODE ? node3 : node3.parentElement;
  return el;
}
__name(closestElementOfNode$1, "closestElementOfNode$1");
function isBlocked$1(node3, blockClass, blockSelector, unblockSelector, checkAncestors) {
  if (!node3) {
    return false;
  }
  const el = closestElementOfNode$1(node3);
  if (!el) {
    return false;
  }
  const blockedPredicate = createMatchPredicate$1(blockClass, blockSelector);
  if (!checkAncestors) {
    const isUnblocked = unblockSelector && el.matches(unblockSelector);
    return blockedPredicate(el) && !isUnblocked;
  }
  const blockDistance = distanceToMatch$1(el, blockedPredicate);
  let unblockDistance = -1;
  if (blockDistance < 0) {
    return false;
  }
  if (unblockSelector) {
    unblockDistance = distanceToMatch$1(el, createMatchPredicate$1(null, unblockSelector));
  }
  if (blockDistance > -1 && unblockDistance < 0) {
    return true;
  }
  return blockDistance < unblockDistance;
}
__name(isBlocked$1, "isBlocked$1");
function isSerialized(n2, mirror2) {
  return mirror2.getId(n2) !== -1;
}
__name(isSerialized, "isSerialized");
function isIgnored(n2, mirror2) {
  return mirror2.getId(n2) === IGNORED_NODE;
}
__name(isIgnored, "isIgnored");
function isAncestorRemoved(target2, mirror2) {
  if (isShadowRoot(target2)) {
    return false;
  }
  const id4 = mirror2.getId(target2);
  if (!mirror2.has(id4)) {
    return true;
  }
  if (target2.parentNode && target2.parentNode.nodeType === target2.DOCUMENT_NODE) {
    return false;
  }
  if (!target2.parentNode) {
    return true;
  }
  return isAncestorRemoved(target2.parentNode, mirror2);
}
__name(isAncestorRemoved, "isAncestorRemoved");
function legacy_isTouchEvent(event) {
  return Boolean(event.changedTouches);
}
__name(legacy_isTouchEvent, "legacy_isTouchEvent");
function polyfill(win = window) {
  if ("NodeList" in win && !win.NodeList.prototype.forEach) {
    win.NodeList.prototype.forEach = Array.prototype.forEach;
  }
  if ("DOMTokenList" in win && !win.DOMTokenList.prototype.forEach) {
    win.DOMTokenList.prototype.forEach = Array.prototype.forEach;
  }
  if (!Node.prototype.contains) {
    Node.prototype.contains = (...args) => {
      let node3 = args[0];
      if (!(0 in args)) {
        throw new TypeError("1 argument is required");
      }
      do {
        if (this === node3) {
          return true;
        }
      } while (node3 = node3 && node3.parentNode);
      return false;
    };
  }
}
__name(polyfill, "polyfill");
function isSerializedIframe(n2, mirror2) {
  return Boolean(n2.nodeName === "IFRAME" && mirror2.getMeta(n2));
}
__name(isSerializedIframe, "isSerializedIframe");
function isSerializedStylesheet(n2, mirror2) {
  return Boolean(n2.nodeName === "LINK" && n2.nodeType === n2.ELEMENT_NODE && n2.getAttribute && n2.getAttribute("rel") === "stylesheet" && mirror2.getMeta(n2));
}
__name(isSerializedStylesheet, "isSerializedStylesheet");
function hasShadowRoot(n2) {
  return Boolean(_optionalChain$4([n2, "optionalAccess", (_18) => _18.shadowRoot]));
}
__name(hasShadowRoot, "hasShadowRoot");
class StyleSheetMirror {
  static {
    __name(this, "StyleSheetMirror");
  }
  constructor() {
    this.id = 1;
    this.styleIDMap = /* @__PURE__ */ new WeakMap();
    this.idStyleMap = /* @__PURE__ */ new Map();
  }
  getId(stylesheet) {
    return _nullishCoalesce(this.styleIDMap.get(stylesheet), () => -1);
  }
  has(stylesheet) {
    return this.styleIDMap.has(stylesheet);
  }
  add(stylesheet, id4) {
    if (this.has(stylesheet))
      return this.getId(stylesheet);
    let newId;
    if (id4 === void 0) {
      newId = this.id++;
    } else
      newId = id4;
    this.styleIDMap.set(stylesheet, newId);
    this.idStyleMap.set(newId, stylesheet);
    return newId;
  }
  getStyle(id4) {
    return this.idStyleMap.get(id4) || null;
  }
  reset() {
    this.styleIDMap = /* @__PURE__ */ new WeakMap();
    this.idStyleMap = /* @__PURE__ */ new Map();
    this.id = 1;
  }
  generateId() {
    return this.id++;
  }
}
function getShadowHost(n2) {
  let shadowHost = null;
  if (_optionalChain$4([n2, "access", (_19) => _19.getRootNode, "optionalCall", (_20) => _20(), "optionalAccess", (_21) => _21.nodeType]) === Node.DOCUMENT_FRAGMENT_NODE && n2.getRootNode().host)
    shadowHost = n2.getRootNode().host;
  return shadowHost;
}
__name(getShadowHost, "getShadowHost");
function getRootShadowHost(n2) {
  let rootShadowHost = n2;
  let shadowHost;
  while (shadowHost = getShadowHost(rootShadowHost))
    rootShadowHost = shadowHost;
  return rootShadowHost;
}
__name(getRootShadowHost, "getRootShadowHost");
function shadowHostInDom(n2) {
  const doc2 = n2.ownerDocument;
  if (!doc2)
    return false;
  const shadowHost = getRootShadowHost(n2);
  return doc2.contains(shadowHost);
}
__name(shadowHostInDom, "shadowHostInDom");
function inDom(n2) {
  const doc2 = n2.ownerDocument;
  if (!doc2)
    return false;
  return doc2.contains(n2) || shadowHostInDom(n2);
}
__name(inDom, "inDom");
const cachedImplementations$2 = {};
function getImplementation$2(name2) {
  const cached = cachedImplementations$2[name2];
  if (cached) {
    return cached;
  }
  const document2 = window.document;
  let impl = window[name2];
  if (document2 && typeof document2.createElement === "function") {
    try {
      const sandbox = document2.createElement("iframe");
      sandbox.hidden = true;
      document2.head.appendChild(sandbox);
      const contentWindow = sandbox.contentWindow;
      if (contentWindow && contentWindow[name2]) {
        impl = contentWindow[name2];
      }
      document2.head.removeChild(sandbox);
    } catch (e2) {
    }
  }
  return cachedImplementations$2[name2] = impl.bind(window);
}
__name(getImplementation$2, "getImplementation$2");
function onRequestAnimationFrame$1(...rest) {
  return getImplementation$2("requestAnimationFrame")(...rest);
}
__name(onRequestAnimationFrame$1, "onRequestAnimationFrame$1");
function setTimeout$1$1(...rest) {
  return getImplementation$2("setTimeout")(...rest);
}
__name(setTimeout$1$1, "setTimeout$1$1");
function clearTimeout$1(...rest) {
  return getImplementation$2("clearTimeout")(...rest);
}
__name(clearTimeout$1, "clearTimeout$1");
var EventType = /* @__PURE__ */ ((EventType2) => {
  EventType2[EventType2["DomContentLoaded"] = 0] = "DomContentLoaded";
  EventType2[EventType2["Load"] = 1] = "Load";
  EventType2[EventType2["FullSnapshot"] = 2] = "FullSnapshot";
  EventType2[EventType2["IncrementalSnapshot"] = 3] = "IncrementalSnapshot";
  EventType2[EventType2["Meta"] = 4] = "Meta";
  EventType2[EventType2["Custom"] = 5] = "Custom";
  EventType2[EventType2["Plugin"] = 6] = "Plugin";
  return EventType2;
})(EventType || {});
var IncrementalSource = /* @__PURE__ */ ((IncrementalSource2) => {
  IncrementalSource2[IncrementalSource2["Mutation"] = 0] = "Mutation";
  IncrementalSource2[IncrementalSource2["MouseMove"] = 1] = "MouseMove";
  IncrementalSource2[IncrementalSource2["MouseInteraction"] = 2] = "MouseInteraction";
  IncrementalSource2[IncrementalSource2["Scroll"] = 3] = "Scroll";
  IncrementalSource2[IncrementalSource2["ViewportResize"] = 4] = "ViewportResize";
  IncrementalSource2[IncrementalSource2["Input"] = 5] = "Input";
  IncrementalSource2[IncrementalSource2["TouchMove"] = 6] = "TouchMove";
  IncrementalSource2[IncrementalSource2["MediaInteraction"] = 7] = "MediaInteraction";
  IncrementalSource2[IncrementalSource2["StyleSheetRule"] = 8] = "StyleSheetRule";
  IncrementalSource2[IncrementalSource2["CanvasMutation"] = 9] = "CanvasMutation";
  IncrementalSource2[IncrementalSource2["Font"] = 10] = "Font";
  IncrementalSource2[IncrementalSource2["Log"] = 11] = "Log";
  IncrementalSource2[IncrementalSource2["Drag"] = 12] = "Drag";
  IncrementalSource2[IncrementalSource2["StyleDeclaration"] = 13] = "StyleDeclaration";
  IncrementalSource2[IncrementalSource2["Selection"] = 14] = "Selection";
  IncrementalSource2[IncrementalSource2["AdoptedStyleSheet"] = 15] = "AdoptedStyleSheet";
  IncrementalSource2[IncrementalSource2["CustomElement"] = 16] = "CustomElement";
  return IncrementalSource2;
})(IncrementalSource || {});
var MouseInteractions = /* @__PURE__ */ ((MouseInteractions2) => {
  MouseInteractions2[MouseInteractions2["MouseUp"] = 0] = "MouseUp";
  MouseInteractions2[MouseInteractions2["MouseDown"] = 1] = "MouseDown";
  MouseInteractions2[MouseInteractions2["Click"] = 2] = "Click";
  MouseInteractions2[MouseInteractions2["ContextMenu"] = 3] = "ContextMenu";
  MouseInteractions2[MouseInteractions2["DblClick"] = 4] = "DblClick";
  MouseInteractions2[MouseInteractions2["Focus"] = 5] = "Focus";
  MouseInteractions2[MouseInteractions2["Blur"] = 6] = "Blur";
  MouseInteractions2[MouseInteractions2["TouchStart"] = 7] = "TouchStart";
  MouseInteractions2[MouseInteractions2["TouchMove_Departed"] = 8] = "TouchMove_Departed";
  MouseInteractions2[MouseInteractions2["TouchEnd"] = 9] = "TouchEnd";
  MouseInteractions2[MouseInteractions2["TouchCancel"] = 10] = "TouchCancel";
  return MouseInteractions2;
})(MouseInteractions || {});
var PointerTypes = /* @__PURE__ */ ((PointerTypes2) => {
  PointerTypes2[PointerTypes2["Mouse"] = 0] = "Mouse";
  PointerTypes2[PointerTypes2["Pen"] = 1] = "Pen";
  PointerTypes2[PointerTypes2["Touch"] = 2] = "Touch";
  return PointerTypes2;
})(PointerTypes || {});
var NodeType$1$1;
(function(NodeType3) {
  NodeType3[NodeType3["Document"] = 0] = "Document";
  NodeType3[NodeType3["DocumentType"] = 1] = "DocumentType";
  NodeType3[NodeType3["Element"] = 2] = "Element";
  NodeType3[NodeType3["Text"] = 3] = "Text";
  NodeType3[NodeType3["CDATA"] = 4] = "CDATA";
  NodeType3[NodeType3["Comment"] = 5] = "Comment";
})(NodeType$1$1 || (NodeType$1$1 = {}));
var NodeType$2$1;
(function(NodeType3) {
  NodeType3[NodeType3["PLACEHOLDER"] = 0] = "PLACEHOLDER";
  NodeType3[NodeType3["ELEMENT_NODE"] = 1] = "ELEMENT_NODE";
  NodeType3[NodeType3["ATTRIBUTE_NODE"] = 2] = "ATTRIBUTE_NODE";
  NodeType3[NodeType3["TEXT_NODE"] = 3] = "TEXT_NODE";
  NodeType3[NodeType3["CDATA_SECTION_NODE"] = 4] = "CDATA_SECTION_NODE";
  NodeType3[NodeType3["ENTITY_REFERENCE_NODE"] = 5] = "ENTITY_REFERENCE_NODE";
  NodeType3[NodeType3["ENTITY_NODE"] = 6] = "ENTITY_NODE";
  NodeType3[NodeType3["PROCESSING_INSTRUCTION_NODE"] = 7] = "PROCESSING_INSTRUCTION_NODE";
  NodeType3[NodeType3["COMMENT_NODE"] = 8] = "COMMENT_NODE";
  NodeType3[NodeType3["DOCUMENT_NODE"] = 9] = "DOCUMENT_NODE";
  NodeType3[NodeType3["DOCUMENT_TYPE_NODE"] = 10] = "DOCUMENT_TYPE_NODE";
  NodeType3[NodeType3["DOCUMENT_FRAGMENT_NODE"] = 11] = "DOCUMENT_FRAGMENT_NODE";
})(NodeType$2$1 || (NodeType$2$1 = {}));
function getIFrameContentDocument(iframe) {
  try {
    return iframe.contentDocument;
  } catch (e2) {
  }
}
__name(getIFrameContentDocument, "getIFrameContentDocument");
function getIFrameContentWindow(iframe) {
  try {
    return iframe.contentWindow;
  } catch (e2) {
  }
}
__name(getIFrameContentWindow, "getIFrameContentWindow");
function _optionalChain$3(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return void 0;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain$3, "_optionalChain$3");
function isNodeInLinkedList(n2) {
  return "__ln" in n2;
}
__name(isNodeInLinkedList, "isNodeInLinkedList");
class DoubleLinkedList {
  static {
    __name(this, "DoubleLinkedList");
  }
  constructor() {
    this.length = 0;
    this.head = null;
    this.tail = null;
  }
  get(position3) {
    if (position3 >= this.length) {
      throw new Error("Position outside of list range");
    }
    let current = this.head;
    for (let index2 = 0; index2 < position3; index2++) {
      current = _optionalChain$3([current, "optionalAccess", (_2) => _2.next]) || null;
    }
    return current;
  }
  addNode(n2) {
    const node3 = {
      value: n2,
      previous: null,
      next: null
    };
    n2.__ln = node3;
    if (n2.previousSibling && isNodeInLinkedList(n2.previousSibling)) {
      const current = n2.previousSibling.__ln.next;
      node3.next = current;
      node3.previous = n2.previousSibling.__ln;
      n2.previousSibling.__ln.next = node3;
      if (current) {
        current.previous = node3;
      }
    } else if (n2.nextSibling && isNodeInLinkedList(n2.nextSibling) && n2.nextSibling.__ln.previous) {
      const current = n2.nextSibling.__ln.previous;
      node3.previous = current;
      node3.next = n2.nextSibling.__ln;
      n2.nextSibling.__ln.previous = node3;
      if (current) {
        current.next = node3;
      }
    } else {
      if (this.head) {
        this.head.previous = node3;
      }
      node3.next = this.head;
      this.head = node3;
    }
    if (node3.next === null) {
      this.tail = node3;
    }
    this.length++;
  }
  removeNode(n2) {
    const current = n2.__ln;
    if (!this.head) {
      return;
    }
    if (!current.previous) {
      this.head = current.next;
      if (this.head) {
        this.head.previous = null;
      } else {
        this.tail = null;
      }
    } else {
      current.previous.next = current.next;
      if (current.next) {
        current.next.previous = current.previous;
      } else {
        this.tail = current.previous;
      }
    }
    if (n2.__ln) {
      delete n2.__ln;
    }
    this.length--;
  }
}
const moveKey = /* @__PURE__ */ __name((id4, parentId) => `${id4}@${parentId}`, "moveKey");
class MutationBuffer {
  static {
    __name(this, "MutationBuffer");
  }
  constructor() {
    this.frozen = false;
    this.locked = false;
    this.texts = [];
    this.attributes = [];
    this.attributeMap = /* @__PURE__ */ new WeakMap();
    this.removes = [];
    this.mapRemoves = [];
    this.movedMap = {};
    this.addedSet = /* @__PURE__ */ new Set();
    this.movedSet = /* @__PURE__ */ new Set();
    this.droppedSet = /* @__PURE__ */ new Set();
    this.processMutations = (mutations) => {
      mutations.forEach(this.processMutation);
      this.emit();
    };
    this.emit = () => {
      if (this.frozen || this.locked) {
        return;
      }
      const adds = [];
      const addedIds = /* @__PURE__ */ new Set();
      const addList = new DoubleLinkedList();
      const getNextId = /* @__PURE__ */ __name((n2) => {
        let ns = n2;
        let nextId = IGNORED_NODE;
        while (nextId === IGNORED_NODE) {
          ns = ns && ns.nextSibling;
          nextId = ns && this.mirror.getId(ns);
        }
        return nextId;
      }, "getNextId");
      const pushAdd = /* @__PURE__ */ __name((n2) => {
        if (!n2.parentNode || !inDom(n2)) {
          return;
        }
        const parentId = isShadowRoot(n2.parentNode) ? this.mirror.getId(getShadowHost(n2)) : this.mirror.getId(n2.parentNode);
        const nextId = getNextId(n2);
        if (parentId === -1 || nextId === -1) {
          return addList.addNode(n2);
        }
        const sn = serializeNodeWithId(n2, {
          doc: this.doc,
          mirror: this.mirror,
          blockClass: this.blockClass,
          blockSelector: this.blockSelector,
          maskAllText: this.maskAllText,
          unblockSelector: this.unblockSelector,
          maskTextClass: this.maskTextClass,
          unmaskTextClass: this.unmaskTextClass,
          maskTextSelector: this.maskTextSelector,
          unmaskTextSelector: this.unmaskTextSelector,
          skipChild: true,
          newlyAddedElement: true,
          inlineStylesheet: this.inlineStylesheet,
          maskInputOptions: this.maskInputOptions,
          maskAttributeFn: this.maskAttributeFn,
          maskTextFn: this.maskTextFn,
          maskInputFn: this.maskInputFn,
          slimDOMOptions: this.slimDOMOptions,
          dataURLOptions: this.dataURLOptions,
          recordCanvas: this.recordCanvas,
          inlineImages: this.inlineImages,
          onSerialize: /* @__PURE__ */ __name((currentN) => {
            if (isSerializedIframe(currentN, this.mirror) && !isBlocked$1(currentN, this.blockClass, this.blockSelector, this.unblockSelector, false)) {
              this.iframeManager.addIframe(currentN);
            }
            if (isSerializedStylesheet(currentN, this.mirror)) {
              this.stylesheetManager.trackLinkElement(currentN);
            }
            if (hasShadowRoot(n2)) {
              this.shadowDomManager.addShadowRoot(n2.shadowRoot, this.doc);
            }
          }, "onSerialize"),
          onIframeLoad: /* @__PURE__ */ __name((iframe, childSn) => {
            if (isBlocked$1(iframe, this.blockClass, this.blockSelector, this.unblockSelector, false)) {
              return;
            }
            this.iframeManager.attachIframe(iframe, childSn);
            if (iframe.contentWindow) {
              this.canvasManager.addWindow(iframe.contentWindow);
            }
            this.shadowDomManager.observeAttachShadow(iframe);
          }, "onIframeLoad"),
          onStylesheetLoad: /* @__PURE__ */ __name((link2, childSn) => {
            this.stylesheetManager.attachLinkElement(link2, childSn);
          }, "onStylesheetLoad")
        });
        if (sn) {
          adds.push({
            parentId,
            nextId,
            node: sn
          });
          addedIds.add(sn.id);
        }
      }, "pushAdd");
      while (this.mapRemoves.length) {
        this.mirror.removeNodeFromMap(this.mapRemoves.shift());
      }
      for (const n2 of this.movedSet) {
        if (isParentRemoved(this.removes, n2, this.mirror) && !this.movedSet.has(n2.parentNode)) {
          continue;
        }
        pushAdd(n2);
      }
      for (const n2 of this.addedSet) {
        if (!isAncestorInSet(this.droppedSet, n2) && !isParentRemoved(this.removes, n2, this.mirror)) {
          pushAdd(n2);
        } else if (isAncestorInSet(this.movedSet, n2)) {
          pushAdd(n2);
        } else {
          this.droppedSet.add(n2);
        }
      }
      let candidate = null;
      while (addList.length) {
        let node3 = null;
        if (candidate) {
          const parentId = this.mirror.getId(candidate.value.parentNode);
          const nextId = getNextId(candidate.value);
          if (parentId !== -1 && nextId !== -1) {
            node3 = candidate;
          }
        }
        if (!node3) {
          let tailNode = addList.tail;
          while (tailNode) {
            const _node = tailNode;
            tailNode = tailNode.previous;
            if (_node) {
              const parentId = this.mirror.getId(_node.value.parentNode);
              const nextId = getNextId(_node.value);
              if (nextId === -1)
                continue;
              else if (parentId !== -1) {
                node3 = _node;
                break;
              } else {
                const unhandledNode = _node.value;
                if (unhandledNode.parentNode && unhandledNode.parentNode.nodeType === Node.DOCUMENT_FRAGMENT_NODE) {
                  const shadowHost = unhandledNode.parentNode.host;
                  const parentId2 = this.mirror.getId(shadowHost);
                  if (parentId2 !== -1) {
                    node3 = _node;
                    break;
                  }
                }
              }
            }
          }
        }
        if (!node3) {
          while (addList.head) {
            addList.removeNode(addList.head.value);
          }
          break;
        }
        candidate = node3.previous;
        addList.removeNode(node3.value);
        pushAdd(node3.value);
      }
      const payload = {
        texts: this.texts.map((text2) => ({
          id: this.mirror.getId(text2.node),
          value: text2.value
        })).filter((text2) => !addedIds.has(text2.id)).filter((text2) => this.mirror.has(text2.id)),
        attributes: this.attributes.map((attribute2) => {
          const { attributes } = attribute2;
          if (typeof attributes.style === "string") {
            const diffAsStr = JSON.stringify(attribute2.styleDiff);
            const unchangedAsStr = JSON.stringify(attribute2._unchangedStyles);
            if (diffAsStr.length < attributes.style.length) {
              if ((diffAsStr + unchangedAsStr).split("var(").length === attributes.style.split("var(").length) {
                attributes.style = attribute2.styleDiff;
              }
            }
          }
          return {
            id: this.mirror.getId(attribute2.node),
            attributes
          };
        }).filter((attribute2) => !addedIds.has(attribute2.id)).filter((attribute2) => this.mirror.has(attribute2.id)),
        removes: this.removes,
        adds
      };
      if (!payload.texts.length && !payload.attributes.length && !payload.removes.length && !payload.adds.length) {
        return;
      }
      this.texts = [];
      this.attributes = [];
      this.attributeMap = /* @__PURE__ */ new WeakMap();
      this.removes = [];
      this.addedSet = /* @__PURE__ */ new Set();
      this.movedSet = /* @__PURE__ */ new Set();
      this.droppedSet = /* @__PURE__ */ new Set();
      this.movedMap = {};
      this.mutationCb(payload);
    };
    this.processMutation = (m2) => {
      if (isIgnored(m2.target, this.mirror)) {
        return;
      }
      switch (m2.type) {
        case "characterData": {
          const value3 = m2.target.textContent;
          if (!isBlocked$1(m2.target, this.blockClass, this.blockSelector, this.unblockSelector, false) && value3 !== m2.oldValue) {
            this.texts.push({
              value: needMaskingText(m2.target, this.maskTextClass, this.maskTextSelector, this.unmaskTextClass, this.unmaskTextSelector, this.maskAllText) && value3 ? this.maskTextFn ? this.maskTextFn(value3, closestElementOfNode$1(m2.target)) : value3.replace(/[\S]/g, "*") : value3,
              node: m2.target
            });
          }
          break;
        }
        case "attributes": {
          const target2 = m2.target;
          let attributeName = m2.attributeName;
          let value3 = m2.target.getAttribute(attributeName);
          if (attributeName === "value") {
            const type = getInputType(target2);
            const tagName = target2.tagName;
            value3 = getInputValue(target2, tagName, type);
            const isInputMasked = shouldMaskInput({
              maskInputOptions: this.maskInputOptions,
              tagName,
              type
            });
            const forceMask = needMaskingText(m2.target, this.maskTextClass, this.maskTextSelector, this.unmaskTextClass, this.unmaskTextSelector, isInputMasked);
            value3 = maskInputValue({
              isMasked: forceMask,
              element: target2,
              value: value3,
              maskInputFn: this.maskInputFn
            });
          }
          if (isBlocked$1(m2.target, this.blockClass, this.blockSelector, this.unblockSelector, false) || value3 === m2.oldValue) {
            return;
          }
          let item3 = this.attributeMap.get(m2.target);
          if (target2.tagName === "IFRAME" && attributeName === "src" && !this.keepIframeSrcFn(value3)) {
            const iframeDoc = getIFrameContentDocument(target2);
            if (!iframeDoc) {
              attributeName = "rr_src";
            } else {
              return;
            }
          }
          if (!item3) {
            item3 = {
              node: m2.target,
              attributes: {},
              styleDiff: {},
              _unchangedStyles: {}
            };
            this.attributes.push(item3);
            this.attributeMap.set(m2.target, item3);
          }
          if (attributeName === "type" && target2.tagName === "INPUT" && (m2.oldValue || "").toLowerCase() === "password") {
            target2.setAttribute("data-rr-is-password", "true");
          }
          if (!ignoreAttribute(target2.tagName, attributeName)) {
            item3.attributes[attributeName] = transformAttribute(this.doc, toLowerCase(target2.tagName), toLowerCase(attributeName), value3, target2, this.maskAttributeFn);
            if (attributeName === "style") {
              if (!this.unattachedDoc) {
                try {
                  this.unattachedDoc = document.implementation.createHTMLDocument();
                } catch (e2) {
                  this.unattachedDoc = this.doc;
                }
              }
              const old = this.unattachedDoc.createElement("span");
              if (m2.oldValue) {
                old.setAttribute("style", m2.oldValue);
              }
              for (const pname of Array.from(target2.style)) {
                const newValue2 = target2.style.getPropertyValue(pname);
                const newPriority = target2.style.getPropertyPriority(pname);
                if (newValue2 !== old.style.getPropertyValue(pname) || newPriority !== old.style.getPropertyPriority(pname)) {
                  if (newPriority === "") {
                    item3.styleDiff[pname] = newValue2;
                  } else {
                    item3.styleDiff[pname] = [newValue2, newPriority];
                  }
                } else {
                  item3._unchangedStyles[pname] = [newValue2, newPriority];
                }
              }
              for (const pname of Array.from(old.style)) {
                if (target2.style.getPropertyValue(pname) === "") {
                  item3.styleDiff[pname] = false;
                }
              }
            }
          }
          break;
        }
        case "childList": {
          if (isBlocked$1(m2.target, this.blockClass, this.blockSelector, this.unblockSelector, true)) {
            return;
          }
          m2.addedNodes.forEach((n2) => this.genAdds(n2, m2.target));
          m2.removedNodes.forEach((n2) => {
            const nodeId = this.mirror.getId(n2);
            const parentId = isShadowRoot(m2.target) ? this.mirror.getId(m2.target.host) : this.mirror.getId(m2.target);
            if (isBlocked$1(m2.target, this.blockClass, this.blockSelector, this.unblockSelector, false) || isIgnored(n2, this.mirror) || !isSerialized(n2, this.mirror)) {
              return;
            }
            if (this.addedSet.has(n2)) {
              deepDelete(this.addedSet, n2);
              this.droppedSet.add(n2);
            } else if (this.addedSet.has(m2.target) && nodeId === -1) ;
            else if (isAncestorRemoved(m2.target, this.mirror)) ;
            else if (this.movedSet.has(n2) && this.movedMap[moveKey(nodeId, parentId)]) {
              deepDelete(this.movedSet, n2);
            } else {
              this.removes.push({
                parentId,
                id: nodeId,
                isShadow: isShadowRoot(m2.target) && isNativeShadowDom(m2.target) ? true : void 0
              });
            }
            this.mapRemoves.push(n2);
          });
          break;
        }
      }
    };
    this.genAdds = (n2, target2) => {
      if (this.processedNodeManager.inOtherBuffer(n2, this))
        return;
      if (this.addedSet.has(n2) || this.movedSet.has(n2))
        return;
      if (this.mirror.hasNode(n2)) {
        if (isIgnored(n2, this.mirror)) {
          return;
        }
        this.movedSet.add(n2);
        let targetId = null;
        if (target2 && this.mirror.hasNode(target2)) {
          targetId = this.mirror.getId(target2);
        }
        if (targetId && targetId !== -1) {
          this.movedMap[moveKey(this.mirror.getId(n2), targetId)] = true;
        }
      } else {
        this.addedSet.add(n2);
        this.droppedSet.delete(n2);
      }
      if (!isBlocked$1(n2, this.blockClass, this.blockSelector, this.unblockSelector, false)) {
        n2.childNodes.forEach((childN) => this.genAdds(childN));
        if (hasShadowRoot(n2)) {
          n2.shadowRoot.childNodes.forEach((childN) => {
            this.processedNodeManager.add(childN, this);
            this.genAdds(childN, n2);
          });
        }
      }
    };
  }
  init(options5) {
    [
      "mutationCb",
      "blockClass",
      "blockSelector",
      "unblockSelector",
      "maskAllText",
      "maskTextClass",
      "unmaskTextClass",
      "maskTextSelector",
      "unmaskTextSelector",
      "inlineStylesheet",
      "maskInputOptions",
      "maskAttributeFn",
      "maskTextFn",
      "maskInputFn",
      "keepIframeSrcFn",
      "recordCanvas",
      "inlineImages",
      "slimDOMOptions",
      "dataURLOptions",
      "doc",
      "mirror",
      "iframeManager",
      "stylesheetManager",
      "shadowDomManager",
      "canvasManager",
      "processedNodeManager"
    ].forEach((key) => {
      this[key] = options5[key];
    });
  }
  freeze() {
    this.frozen = true;
    this.canvasManager.freeze();
  }
  unfreeze() {
    this.frozen = false;
    this.canvasManager.unfreeze();
    this.emit();
  }
  isFrozen() {
    return this.frozen;
  }
  lock() {
    this.locked = true;
    this.canvasManager.lock();
  }
  unlock() {
    this.locked = false;
    this.canvasManager.unlock();
    this.emit();
  }
  reset() {
    this.shadowDomManager.reset();
    this.canvasManager.reset();
  }
}
function deepDelete(addsSet, n2) {
  addsSet.delete(n2);
  n2.childNodes.forEach((childN) => deepDelete(addsSet, childN));
}
__name(deepDelete, "deepDelete");
function isParentRemoved(removes, n2, mirror2) {
  if (removes.length === 0)
    return false;
  return _isParentRemoved(removes, n2, mirror2);
}
__name(isParentRemoved, "isParentRemoved");
function _isParentRemoved(removes, n2, mirror2) {
  let node3 = n2.parentNode;
  while (node3) {
    const parentId = mirror2.getId(node3);
    if (removes.some((r2) => r2.id === parentId)) {
      return true;
    }
    node3 = node3.parentNode;
  }
  return false;
}
__name(_isParentRemoved, "_isParentRemoved");
function isAncestorInSet(set3, n2) {
  if (set3.size === 0)
    return false;
  return _isAncestorInSet(set3, n2);
}
__name(isAncestorInSet, "isAncestorInSet");
function _isAncestorInSet(set3, n2) {
  const { parentNode: parentNode2 } = n2;
  if (!parentNode2) {
    return false;
  }
  if (set3.has(parentNode2)) {
    return true;
  }
  return _isAncestorInSet(set3, parentNode2);
}
__name(_isAncestorInSet, "_isAncestorInSet");
let errorHandler$1;
function registerErrorHandler$1(handler14) {
  errorHandler$1 = handler14;
}
__name(registerErrorHandler$1, "registerErrorHandler$1");
function unregisterErrorHandler() {
  errorHandler$1 = void 0;
}
__name(unregisterErrorHandler, "unregisterErrorHandler");
const callbackWrapper$1 = /* @__PURE__ */ __name((cb) => {
  if (!errorHandler$1) {
    return cb;
  }
  const rrwebWrapped = /* @__PURE__ */ __name((...rest) => {
    try {
      return cb(...rest);
    } catch (error2) {
      if (errorHandler$1 && errorHandler$1(error2) === true) {
        return () => {
        };
      }
      throw error2;
    }
  }, "rrwebWrapped");
  return rrwebWrapped;
}, "callbackWrapper$1");
function _optionalChain$2(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return void 0;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain$2, "_optionalChain$2");
const mutationBuffers = [];
function getEventTarget(event) {
  try {
    if ("composedPath" in event) {
      const path = event.composedPath();
      if (path.length) {
        return path[0];
      }
    } else if ("path" in event && event.path.length) {
      return event.path[0];
    }
  } catch (e2) {
  }
  return event && event.target;
}
__name(getEventTarget, "getEventTarget");
function initMutationObserver(options5, rootEl) {
  const mutationBuffer = new MutationBuffer();
  mutationBuffers.push(mutationBuffer);
  mutationBuffer.init(options5);
  let mutationObserverCtor = window.MutationObserver || window.__rrMutationObserver;
  const angularZoneSymbol = _optionalChain$2([window, "optionalAccess", (_2) => _2.Zone, "optionalAccess", (_2) => _2.__symbol__, "optionalCall", (_3) => _3("MutationObserver")]);
  if (angularZoneSymbol && window[angularZoneSymbol]) {
    mutationObserverCtor = window[angularZoneSymbol];
  }
  const observer = new mutationObserverCtor(callbackWrapper$1((mutations) => {
    if (options5.onMutation && options5.onMutation(mutations) === false) {
      return;
    }
    mutationBuffer.processMutations.bind(mutationBuffer)(mutations);
  }));
  observer.observe(rootEl, {
    attributes: true,
    attributeOldValue: true,
    characterData: true,
    characterDataOldValue: true,
    childList: true,
    subtree: true
  });
  return observer;
}
__name(initMutationObserver, "initMutationObserver");
function initMoveObserver({ mousemoveCb, sampling, doc: doc2, mirror: mirror2 }) {
  if (sampling.mousemove === false) {
    return () => {
    };
  }
  const threshold = typeof sampling.mousemove === "number" ? sampling.mousemove : 50;
  const callbackThreshold = typeof sampling.mousemoveCallback === "number" ? sampling.mousemoveCallback : 500;
  let positions = [];
  let timeBaseline;
  const wrappedCb = throttle$1(callbackWrapper$1((source) => {
    const totalOffset = Date.now() - timeBaseline;
    mousemoveCb(positions.map((p2) => {
      p2.timeOffset -= totalOffset;
      return p2;
    }), source);
    positions = [];
    timeBaseline = null;
  }), callbackThreshold);
  const updatePosition = callbackWrapper$1(throttle$1(callbackWrapper$1((evt) => {
    const target2 = getEventTarget(evt);
    const { clientX, clientY } = legacy_isTouchEvent(evt) ? evt.changedTouches[0] : evt;
    if (!timeBaseline) {
      timeBaseline = nowTimestamp();
    }
    positions.push({
      x: clientX,
      y: clientY,
      id: mirror2.getId(target2),
      timeOffset: nowTimestamp() - timeBaseline
    });
    wrappedCb(typeof DragEvent !== "undefined" && evt instanceof DragEvent ? IncrementalSource.Drag : evt instanceof MouseEvent ? IncrementalSource.MouseMove : IncrementalSource.TouchMove);
  }), threshold, {
    trailing: false
  }));
  const handlers2 = [
    on("mousemove", updatePosition, doc2),
    on("touchmove", updatePosition, doc2),
    on("drag", updatePosition, doc2)
  ];
  return callbackWrapper$1(() => {
    handlers2.forEach((h2) => h2());
  });
}
__name(initMoveObserver, "initMoveObserver");
function initMouseInteractionObserver({ mouseInteractionCb, doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, sampling }) {
  if (sampling.mouseInteraction === false) {
    return () => {
    };
  }
  const disableMap = sampling.mouseInteraction === true || sampling.mouseInteraction === void 0 ? {} : sampling.mouseInteraction;
  const handlers2 = [];
  let currentPointerType = null;
  const getHandler = /* @__PURE__ */ __name((eventKey) => {
    return (event) => {
      const target2 = getEventTarget(event);
      if (isBlocked$1(target2, blockClass, blockSelector, unblockSelector, true)) {
        return;
      }
      let pointerType = null;
      let thisEventKey = eventKey;
      if ("pointerType" in event) {
        switch (event.pointerType) {
          case "mouse":
            pointerType = PointerTypes.Mouse;
            break;
          case "touch":
            pointerType = PointerTypes.Touch;
            break;
          case "pen":
            pointerType = PointerTypes.Pen;
            break;
        }
        if (pointerType === PointerTypes.Touch) {
          if (MouseInteractions[eventKey] === MouseInteractions.MouseDown) {
            thisEventKey = "TouchStart";
          } else if (MouseInteractions[eventKey] === MouseInteractions.MouseUp) {
            thisEventKey = "TouchEnd";
          }
        } else if (pointerType === PointerTypes.Pen) ;
      } else if (legacy_isTouchEvent(event)) {
        pointerType = PointerTypes.Touch;
      }
      if (pointerType !== null) {
        currentPointerType = pointerType;
        if (thisEventKey.startsWith("Touch") && pointerType === PointerTypes.Touch || thisEventKey.startsWith("Mouse") && pointerType === PointerTypes.Mouse) {
          pointerType = null;
        }
      } else if (MouseInteractions[eventKey] === MouseInteractions.Click) {
        pointerType = currentPointerType;
        currentPointerType = null;
      }
      const e2 = legacy_isTouchEvent(event) ? event.changedTouches[0] : event;
      if (!e2) {
        return;
      }
      const id4 = mirror2.getId(target2);
      const { clientX, clientY } = e2;
      callbackWrapper$1(mouseInteractionCb)({
        type: MouseInteractions[thisEventKey],
        id: id4,
        x: clientX,
        y: clientY,
        ...pointerType !== null && { pointerType }
      });
    };
  }, "getHandler");
  Object.keys(MouseInteractions).filter((key) => Number.isNaN(Number(key)) && !key.endsWith("_Departed") && disableMap[key] !== false).forEach((eventKey) => {
    let eventName = toLowerCase(eventKey);
    const handler14 = getHandler(eventKey);
    if (window.PointerEvent) {
      switch (MouseInteractions[eventKey]) {
        case MouseInteractions.MouseDown:
        case MouseInteractions.MouseUp:
          eventName = eventName.replace("mouse", "pointer");
          break;
        case MouseInteractions.TouchStart:
        case MouseInteractions.TouchEnd:
          return;
      }
    }
    handlers2.push(on(eventName, handler14, doc2));
  });
  return callbackWrapper$1(() => {
    handlers2.forEach((h2) => h2());
  });
}
__name(initMouseInteractionObserver, "initMouseInteractionObserver");
function initScrollObserver({ scrollCb, doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, sampling }) {
  const updatePosition = callbackWrapper$1(throttle$1(callbackWrapper$1((evt) => {
    const target2 = getEventTarget(evt);
    if (!target2 || isBlocked$1(target2, blockClass, blockSelector, unblockSelector, true)) {
      return;
    }
    const id4 = mirror2.getId(target2);
    if (target2 === doc2 && doc2.defaultView) {
      const scrollLeftTop = getWindowScroll(doc2.defaultView);
      scrollCb({
        id: id4,
        x: scrollLeftTop.left,
        y: scrollLeftTop.top
      });
    } else {
      scrollCb({
        id: id4,
        x: target2.scrollLeft,
        y: target2.scrollTop
      });
    }
  }), sampling.scroll || 100));
  return on("scroll", updatePosition, doc2);
}
__name(initScrollObserver, "initScrollObserver");
function initViewportResizeObserver({ viewportResizeCb }, { win }) {
  let lastH = -1;
  let lastW = -1;
  const updateDimension = callbackWrapper$1(throttle$1(callbackWrapper$1(() => {
    const height = getWindowHeight();
    const width2 = getWindowWidth();
    if (lastH !== height || lastW !== width2) {
      viewportResizeCb({
        width: Number(width2),
        height: Number(height)
      });
      lastH = height;
      lastW = width2;
    }
  }), 200));
  return on("resize", updateDimension, win);
}
__name(initViewportResizeObserver, "initViewportResizeObserver");
const INPUT_TAGS = ["INPUT", "TEXTAREA", "SELECT"];
const lastInputValueMap = /* @__PURE__ */ new WeakMap();
function initInputObserver({ inputCb, doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, ignoreClass, ignoreSelector, maskInputOptions, maskInputFn, sampling, userTriggeredOnInput, maskTextClass, unmaskTextClass, maskTextSelector, unmaskTextSelector }) {
  function eventHandler(event) {
    let target2 = getEventTarget(event);
    const userTriggered = event.isTrusted;
    const tagName = target2 && toUpperCase(target2.tagName);
    if (tagName === "OPTION")
      target2 = target2.parentElement;
    if (!target2 || !tagName || INPUT_TAGS.indexOf(tagName) < 0 || isBlocked$1(target2, blockClass, blockSelector, unblockSelector, true)) {
      return;
    }
    const el = target2;
    if (el.classList.contains(ignoreClass) || ignoreSelector && el.matches(ignoreSelector)) {
      return;
    }
    const type = getInputType(target2);
    let text2 = getInputValue(el, tagName, type);
    let isChecked2 = false;
    const isInputMasked = shouldMaskInput({
      maskInputOptions,
      tagName,
      type
    });
    const forceMask = needMaskingText(target2, maskTextClass, maskTextSelector, unmaskTextClass, unmaskTextSelector, isInputMasked);
    if (type === "radio" || type === "checkbox") {
      isChecked2 = target2.checked;
    }
    text2 = maskInputValue({
      isMasked: forceMask,
      element: target2,
      value: text2,
      maskInputFn
    });
    cbWithDedup(target2, userTriggeredOnInput ? { text: text2, isChecked: isChecked2, userTriggered } : { text: text2, isChecked: isChecked2 });
    const name2 = target2.name;
    if (type === "radio" && name2 && isChecked2) {
      doc2.querySelectorAll(`input[type="radio"][name="${name2}"]`).forEach((el2) => {
        if (el2 !== target2) {
          const text3 = maskInputValue({
            isMasked: forceMask,
            element: el2,
            value: getInputValue(el2, tagName, type),
            maskInputFn
          });
          cbWithDedup(el2, userTriggeredOnInput ? { text: text3, isChecked: !isChecked2, userTriggered: false } : { text: text3, isChecked: !isChecked2 });
        }
      });
    }
  }
  __name(eventHandler, "eventHandler");
  function cbWithDedup(target2, v2) {
    const lastInputValue = lastInputValueMap.get(target2);
    if (!lastInputValue || lastInputValue.text !== v2.text || lastInputValue.isChecked !== v2.isChecked) {
      lastInputValueMap.set(target2, v2);
      const id4 = mirror2.getId(target2);
      callbackWrapper$1(inputCb)({
        ...v2,
        id: id4
      });
    }
  }
  __name(cbWithDedup, "cbWithDedup");
  const events2 = sampling.input === "last" ? ["change"] : ["input", "change"];
  const handlers2 = events2.map((eventName) => on(eventName, callbackWrapper$1(eventHandler), doc2));
  const currentWindow = doc2.defaultView;
  if (!currentWindow) {
    return () => {
      handlers2.forEach((h2) => h2());
    };
  }
  const propertyDescriptor = currentWindow.Object.getOwnPropertyDescriptor(currentWindow.HTMLInputElement.prototype, "value");
  const hookProperties = [
    [currentWindow.HTMLInputElement.prototype, "value"],
    [currentWindow.HTMLInputElement.prototype, "checked"],
    [currentWindow.HTMLSelectElement.prototype, "value"],
    [currentWindow.HTMLTextAreaElement.prototype, "value"],
    [currentWindow.HTMLSelectElement.prototype, "selectedIndex"],
    [currentWindow.HTMLOptionElement.prototype, "selected"]
  ];
  if (propertyDescriptor && propertyDescriptor.set) {
    handlers2.push(...hookProperties.map((p2) => hookSetter$1(p2[0], p2[1], {
      set() {
        callbackWrapper$1(eventHandler)({
          target: this,
          isTrusted: false
        });
      }
    }, false, currentWindow)));
  }
  return callbackWrapper$1(() => {
    handlers2.forEach((h2) => h2());
  });
}
__name(initInputObserver, "initInputObserver");
function getNestedCSSRulePositions(rule) {
  const positions = [];
  function recurse(childRule, pos) {
    if (hasNestedCSSRule("CSSGroupingRule") && childRule.parentRule instanceof CSSGroupingRule || hasNestedCSSRule("CSSMediaRule") && childRule.parentRule instanceof CSSMediaRule || hasNestedCSSRule("CSSSupportsRule") && childRule.parentRule instanceof CSSSupportsRule || hasNestedCSSRule("CSSConditionRule") && childRule.parentRule instanceof CSSConditionRule) {
      const rules = Array.from(childRule.parentRule.cssRules);
      const index2 = rules.indexOf(childRule);
      pos.unshift(index2);
    } else if (childRule.parentStyleSheet) {
      const rules = Array.from(childRule.parentStyleSheet.cssRules);
      const index2 = rules.indexOf(childRule);
      pos.unshift(index2);
    }
    return pos;
  }
  __name(recurse, "recurse");
  return recurse(rule, positions);
}
__name(getNestedCSSRulePositions, "getNestedCSSRulePositions");
function getIdAndStyleId(sheet, mirror2, styleMirror) {
  let id4, styleId;
  if (!sheet)
    return {};
  if (sheet.ownerNode)
    id4 = mirror2.getId(sheet.ownerNode);
  else
    styleId = styleMirror.getId(sheet);
  return {
    styleId,
    id: id4
  };
}
__name(getIdAndStyleId, "getIdAndStyleId");
function initStyleSheetObserver({ styleSheetRuleCb, mirror: mirror2, stylesheetManager }, { win }) {
  if (!win.CSSStyleSheet || !win.CSSStyleSheet.prototype) {
    return () => {
    };
  }
  const insertRule = win.CSSStyleSheet.prototype.insertRule;
  win.CSSStyleSheet.prototype.insertRule = new Proxy(insertRule, {
    apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
      const [rule, index2] = argumentsList;
      const { id: id4, styleId } = getIdAndStyleId(thisArg, mirror2, stylesheetManager.styleMirror);
      if (id4 && id4 !== -1 || styleId && styleId !== -1) {
        styleSheetRuleCb({
          id: id4,
          styleId,
          adds: [{ rule, index: index2 }]
        });
      }
      return target2.apply(thisArg, argumentsList);
    })
  });
  const deleteRule = win.CSSStyleSheet.prototype.deleteRule;
  win.CSSStyleSheet.prototype.deleteRule = new Proxy(deleteRule, {
    apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
      const [index2] = argumentsList;
      const { id: id4, styleId } = getIdAndStyleId(thisArg, mirror2, stylesheetManager.styleMirror);
      if (id4 && id4 !== -1 || styleId && styleId !== -1) {
        styleSheetRuleCb({
          id: id4,
          styleId,
          removes: [{ index: index2 }]
        });
      }
      return target2.apply(thisArg, argumentsList);
    })
  });
  let replace2;
  if (win.CSSStyleSheet.prototype.replace) {
    replace2 = win.CSSStyleSheet.prototype.replace;
    win.CSSStyleSheet.prototype.replace = new Proxy(replace2, {
      apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
        const [text2] = argumentsList;
        const { id: id4, styleId } = getIdAndStyleId(thisArg, mirror2, stylesheetManager.styleMirror);
        if (id4 && id4 !== -1 || styleId && styleId !== -1) {
          styleSheetRuleCb({
            id: id4,
            styleId,
            replace: text2
          });
        }
        return target2.apply(thisArg, argumentsList);
      })
    });
  }
  let replaceSync;
  if (win.CSSStyleSheet.prototype.replaceSync) {
    replaceSync = win.CSSStyleSheet.prototype.replaceSync;
    win.CSSStyleSheet.prototype.replaceSync = new Proxy(replaceSync, {
      apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
        const [text2] = argumentsList;
        const { id: id4, styleId } = getIdAndStyleId(thisArg, mirror2, stylesheetManager.styleMirror);
        if (id4 && id4 !== -1 || styleId && styleId !== -1) {
          styleSheetRuleCb({
            id: id4,
            styleId,
            replaceSync: text2
          });
        }
        return target2.apply(thisArg, argumentsList);
      })
    });
  }
  const supportedNestedCSSRuleTypes = {};
  if (canMonkeyPatchNestedCSSRule("CSSGroupingRule")) {
    supportedNestedCSSRuleTypes.CSSGroupingRule = win.CSSGroupingRule;
  } else {
    if (canMonkeyPatchNestedCSSRule("CSSMediaRule")) {
      supportedNestedCSSRuleTypes.CSSMediaRule = win.CSSMediaRule;
    }
    if (canMonkeyPatchNestedCSSRule("CSSConditionRule")) {
      supportedNestedCSSRuleTypes.CSSConditionRule = win.CSSConditionRule;
    }
    if (canMonkeyPatchNestedCSSRule("CSSSupportsRule")) {
      supportedNestedCSSRuleTypes.CSSSupportsRule = win.CSSSupportsRule;
    }
  }
  const unmodifiedFunctions = {};
  Object.entries(supportedNestedCSSRuleTypes).forEach(([typeKey, type]) => {
    unmodifiedFunctions[typeKey] = {
      insertRule: type.prototype.insertRule,
      deleteRule: type.prototype.deleteRule
    };
    type.prototype.insertRule = new Proxy(unmodifiedFunctions[typeKey].insertRule, {
      apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
        const [rule, index2] = argumentsList;
        const { id: id4, styleId } = getIdAndStyleId(thisArg.parentStyleSheet, mirror2, stylesheetManager.styleMirror);
        if (id4 && id4 !== -1 || styleId && styleId !== -1) {
          styleSheetRuleCb({
            id: id4,
            styleId,
            adds: [
              {
                rule,
                index: [
                  ...getNestedCSSRulePositions(thisArg),
                  index2 || 0
                ]
              }
            ]
          });
        }
        return target2.apply(thisArg, argumentsList);
      })
    });
    type.prototype.deleteRule = new Proxy(unmodifiedFunctions[typeKey].deleteRule, {
      apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
        const [index2] = argumentsList;
        const { id: id4, styleId } = getIdAndStyleId(thisArg.parentStyleSheet, mirror2, stylesheetManager.styleMirror);
        if (id4 && id4 !== -1 || styleId && styleId !== -1) {
          styleSheetRuleCb({
            id: id4,
            styleId,
            removes: [
              { index: [...getNestedCSSRulePositions(thisArg), index2] }
            ]
          });
        }
        return target2.apply(thisArg, argumentsList);
      })
    });
  });
  return callbackWrapper$1(() => {
    win.CSSStyleSheet.prototype.insertRule = insertRule;
    win.CSSStyleSheet.prototype.deleteRule = deleteRule;
    replace2 && (win.CSSStyleSheet.prototype.replace = replace2);
    replaceSync && (win.CSSStyleSheet.prototype.replaceSync = replaceSync);
    Object.entries(supportedNestedCSSRuleTypes).forEach(([typeKey, type]) => {
      type.prototype.insertRule = unmodifiedFunctions[typeKey].insertRule;
      type.prototype.deleteRule = unmodifiedFunctions[typeKey].deleteRule;
    });
  });
}
__name(initStyleSheetObserver, "initStyleSheetObserver");
function initAdoptedStyleSheetObserver({ mirror: mirror2, stylesheetManager }, host) {
  let hostId = null;
  if (host.nodeName === "#document")
    hostId = mirror2.getId(host);
  else
    hostId = mirror2.getId(host.host);
  const patchTarget = host.nodeName === "#document" ? _optionalChain$2([host, "access", (_4) => _4.defaultView, "optionalAccess", (_5) => _5.Document]) : _optionalChain$2([host, "access", (_6) => _6.ownerDocument, "optionalAccess", (_7) => _7.defaultView, "optionalAccess", (_8) => _8.ShadowRoot]);
  const originalPropertyDescriptor = _optionalChain$2([patchTarget, "optionalAccess", (_9) => _9.prototype]) ? Object.getOwnPropertyDescriptor(_optionalChain$2([patchTarget, "optionalAccess", (_10) => _10.prototype]), "adoptedStyleSheets") : void 0;
  if (hostId === null || hostId === -1 || !patchTarget || !originalPropertyDescriptor)
    return () => {
    };
  Object.defineProperty(host, "adoptedStyleSheets", {
    configurable: originalPropertyDescriptor.configurable,
    enumerable: originalPropertyDescriptor.enumerable,
    get() {
      return _optionalChain$2([originalPropertyDescriptor, "access", (_11) => _11.get, "optionalAccess", (_12) => _12.call, "call", (_13) => _13(this)]);
    },
    set(sheets) {
      const result = _optionalChain$2([originalPropertyDescriptor, "access", (_14) => _14.set, "optionalAccess", (_15) => _15.call, "call", (_16) => _16(this, sheets)]);
      if (hostId !== null && hostId !== -1) {
        try {
          stylesheetManager.adoptStyleSheets(sheets, hostId);
        } catch (e2) {
        }
      }
      return result;
    }
  });
  return callbackWrapper$1(() => {
    Object.defineProperty(host, "adoptedStyleSheets", {
      configurable: originalPropertyDescriptor.configurable,
      enumerable: originalPropertyDescriptor.enumerable,
      get: originalPropertyDescriptor.get,
      set: originalPropertyDescriptor.set
    });
  });
}
__name(initAdoptedStyleSheetObserver, "initAdoptedStyleSheetObserver");
function initStyleDeclarationObserver({ styleDeclarationCb, mirror: mirror2, ignoreCSSAttributes, stylesheetManager }, { win }) {
  const setProperty2 = win.CSSStyleDeclaration.prototype.setProperty;
  win.CSSStyleDeclaration.prototype.setProperty = new Proxy(setProperty2, {
    apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
      const [property, value3, priority] = argumentsList;
      if (ignoreCSSAttributes.has(property)) {
        return setProperty2.apply(thisArg, [property, value3, priority]);
      }
      const { id: id4, styleId } = getIdAndStyleId(_optionalChain$2([thisArg, "access", (_17) => _17.parentRule, "optionalAccess", (_18) => _18.parentStyleSheet]), mirror2, stylesheetManager.styleMirror);
      if (id4 && id4 !== -1 || styleId && styleId !== -1) {
        styleDeclarationCb({
          id: id4,
          styleId,
          set: {
            property,
            value: value3,
            priority
          },
          index: getNestedCSSRulePositions(thisArg.parentRule)
        });
      }
      return target2.apply(thisArg, argumentsList);
    })
  });
  const removeProperty = win.CSSStyleDeclaration.prototype.removeProperty;
  win.CSSStyleDeclaration.prototype.removeProperty = new Proxy(removeProperty, {
    apply: callbackWrapper$1((target2, thisArg, argumentsList) => {
      const [property] = argumentsList;
      if (ignoreCSSAttributes.has(property)) {
        return removeProperty.apply(thisArg, [property]);
      }
      const { id: id4, styleId } = getIdAndStyleId(_optionalChain$2([thisArg, "access", (_19) => _19.parentRule, "optionalAccess", (_20) => _20.parentStyleSheet]), mirror2, stylesheetManager.styleMirror);
      if (id4 && id4 !== -1 || styleId && styleId !== -1) {
        styleDeclarationCb({
          id: id4,
          styleId,
          remove: {
            property
          },
          index: getNestedCSSRulePositions(thisArg.parentRule)
        });
      }
      return target2.apply(thisArg, argumentsList);
    })
  });
  return callbackWrapper$1(() => {
    win.CSSStyleDeclaration.prototype.setProperty = setProperty2;
    win.CSSStyleDeclaration.prototype.removeProperty = removeProperty;
  });
}
__name(initStyleDeclarationObserver, "initStyleDeclarationObserver");
function initMediaInteractionObserver({ mediaInteractionCb, blockClass, blockSelector, unblockSelector, mirror: mirror2, sampling, doc: doc2 }) {
  const handler14 = callbackWrapper$1((type) => throttle$1(callbackWrapper$1((event) => {
    const target2 = getEventTarget(event);
    if (!target2 || isBlocked$1(target2, blockClass, blockSelector, unblockSelector, true)) {
      return;
    }
    const { currentTime, volume, muted, playbackRate } = target2;
    mediaInteractionCb({
      type,
      id: mirror2.getId(target2),
      currentTime,
      volume,
      muted,
      playbackRate
    });
  }), sampling.media || 500));
  const handlers2 = [
    on("play", handler14(0), doc2),
    on("pause", handler14(1), doc2),
    on("seeked", handler14(2), doc2),
    on("volumechange", handler14(3), doc2),
    on("ratechange", handler14(4), doc2)
  ];
  return callbackWrapper$1(() => {
    handlers2.forEach((h2) => h2());
  });
}
__name(initMediaInteractionObserver, "initMediaInteractionObserver");
function initFontObserver({ fontCb, doc: doc2 }) {
  const win = doc2.defaultView;
  if (!win) {
    return () => {
    };
  }
  const handlers2 = [];
  const fontMap = /* @__PURE__ */ new WeakMap();
  const originalFontFace = win.FontFace;
  win.FontFace = /* @__PURE__ */ __name(function FontFace(family, source, descriptors2) {
    const fontFace = new originalFontFace(family, source, descriptors2);
    fontMap.set(fontFace, {
      family,
      buffer: typeof source !== "string",
      descriptors: descriptors2,
      fontSource: typeof source === "string" ? source : JSON.stringify(Array.from(new Uint8Array(source)))
    });
    return fontFace;
  }, "FontFace");
  const restoreHandler = patch$2(doc2.fonts, "add", function(original) {
    return function(fontFace) {
      setTimeout$1$1(callbackWrapper$1(() => {
        const p2 = fontMap.get(fontFace);
        if (p2) {
          fontCb(p2);
          fontMap.delete(fontFace);
        }
      }), 0);
      return original.apply(this, [fontFace]);
    };
  });
  handlers2.push(() => {
    win.FontFace = originalFontFace;
  });
  handlers2.push(restoreHandler);
  return callbackWrapper$1(() => {
    handlers2.forEach((h2) => h2());
  });
}
__name(initFontObserver, "initFontObserver");
function initSelectionObserver(param) {
  const { doc: doc2, mirror: mirror2, blockClass, blockSelector, unblockSelector, selectionCb } = param;
  let collapsed2 = true;
  const updateSelection2 = callbackWrapper$1(() => {
    const selection = doc2.getSelection();
    if (!selection || collapsed2 && _optionalChain$2([selection, "optionalAccess", (_21) => _21.isCollapsed]))
      return;
    collapsed2 = selection.isCollapsed || false;
    const ranges = [];
    const count = selection.rangeCount || 0;
    for (let i2 = 0; i2 < count; i2++) {
      const range2 = selection.getRangeAt(i2);
      const { startContainer, startOffset, endContainer, endOffset } = range2;
      const blocked2 = isBlocked$1(startContainer, blockClass, blockSelector, unblockSelector, true) || isBlocked$1(endContainer, blockClass, blockSelector, unblockSelector, true);
      if (blocked2)
        continue;
      ranges.push({
        start: mirror2.getId(startContainer),
        startOffset,
        end: mirror2.getId(endContainer),
        endOffset
      });
    }
    selectionCb({ ranges });
  });
  updateSelection2();
  return on("selectionchange", updateSelection2);
}
__name(initSelectionObserver, "initSelectionObserver");
function initCustomElementObserver({ doc: doc2, customElementCb }) {
  const win = doc2.defaultView;
  if (!win || !win.customElements)
    return () => {
    };
  const restoreHandler = patch$2(win.customElements, "define", function(original) {
    return function(name2, constructor, options5) {
      try {
        customElementCb({
          define: {
            name: name2
          }
        });
      } catch (e2) {
      }
      return original.apply(this, [name2, constructor, options5]);
    };
  });
  return restoreHandler;
}
__name(initCustomElementObserver, "initCustomElementObserver");
function initObservers(o2, _hooks = {}) {
  const currentWindow = o2.doc.defaultView;
  if (!currentWindow) {
    return () => {
    };
  }
  let mutationObserver;
  if (o2.recordDOM) {
    mutationObserver = initMutationObserver(o2, o2.doc);
  }
  const mousemoveHandler = initMoveObserver(o2);
  const mouseInteractionHandler = initMouseInteractionObserver(o2);
  const scrollHandler = initScrollObserver(o2);
  const viewportResizeHandler = initViewportResizeObserver(o2, {
    win: currentWindow
  });
  const inputHandler = initInputObserver(o2);
  const mediaInteractionHandler = initMediaInteractionObserver(o2);
  let styleSheetObserver = /* @__PURE__ */ __name(() => {
  }, "styleSheetObserver");
  let adoptedStyleSheetObserver = /* @__PURE__ */ __name(() => {
  }, "adoptedStyleSheetObserver");
  let styleDeclarationObserver = /* @__PURE__ */ __name(() => {
  }, "styleDeclarationObserver");
  let fontObserver = /* @__PURE__ */ __name(() => {
  }, "fontObserver");
  if (o2.recordDOM) {
    styleSheetObserver = initStyleSheetObserver(o2, { win: currentWindow });
    adoptedStyleSheetObserver = initAdoptedStyleSheetObserver(o2, o2.doc);
    styleDeclarationObserver = initStyleDeclarationObserver(o2, {
      win: currentWindow
    });
    if (o2.collectFonts) {
      fontObserver = initFontObserver(o2);
    }
  }
  const selectionObserver = initSelectionObserver(o2);
  const customElementObserver = initCustomElementObserver(o2);
  const pluginHandlers = [];
  for (const plugin of o2.plugins) {
    pluginHandlers.push(plugin.observer(plugin.callback, currentWindow, plugin.options));
  }
  return callbackWrapper$1(() => {
    mutationBuffers.forEach((b2) => b2.reset());
    _optionalChain$2([mutationObserver, "optionalAccess", (_22) => _22.disconnect, "call", (_23) => _23()]);
    mousemoveHandler();
    mouseInteractionHandler();
    scrollHandler();
    viewportResizeHandler();
    inputHandler();
    mediaInteractionHandler();
    styleSheetObserver();
    adoptedStyleSheetObserver();
    styleDeclarationObserver();
    fontObserver();
    selectionObserver();
    customElementObserver();
    pluginHandlers.forEach((h2) => h2());
  });
}
__name(initObservers, "initObservers");
function hasNestedCSSRule(prop2) {
  return typeof window[prop2] !== "undefined";
}
__name(hasNestedCSSRule, "hasNestedCSSRule");
function canMonkeyPatchNestedCSSRule(prop2) {
  return Boolean(typeof window[prop2] !== "undefined" && window[prop2].prototype && "insertRule" in window[prop2].prototype && "deleteRule" in window[prop2].prototype);
}
__name(canMonkeyPatchNestedCSSRule, "canMonkeyPatchNestedCSSRule");
class CrossOriginIframeMirror {
  static {
    __name(this, "CrossOriginIframeMirror");
  }
  constructor(generateIdFn) {
    this.generateIdFn = generateIdFn;
    this.iframeIdToRemoteIdMap = /* @__PURE__ */ new WeakMap();
    this.iframeRemoteIdToIdMap = /* @__PURE__ */ new WeakMap();
  }
  getId(iframe, remoteId, idToRemoteMap, remoteToIdMap) {
    const idToRemoteIdMap = idToRemoteMap || this.getIdToRemoteIdMap(iframe);
    const remoteIdToIdMap = remoteToIdMap || this.getRemoteIdToIdMap(iframe);
    let id4 = idToRemoteIdMap.get(remoteId);
    if (!id4) {
      id4 = this.generateIdFn();
      idToRemoteIdMap.set(remoteId, id4);
      remoteIdToIdMap.set(id4, remoteId);
    }
    return id4;
  }
  getIds(iframe, remoteId) {
    const idToRemoteIdMap = this.getIdToRemoteIdMap(iframe);
    const remoteIdToIdMap = this.getRemoteIdToIdMap(iframe);
    return remoteId.map((id4) => this.getId(iframe, id4, idToRemoteIdMap, remoteIdToIdMap));
  }
  getRemoteId(iframe, id4, map3) {
    const remoteIdToIdMap = map3 || this.getRemoteIdToIdMap(iframe);
    if (typeof id4 !== "number")
      return id4;
    const remoteId = remoteIdToIdMap.get(id4);
    if (!remoteId)
      return -1;
    return remoteId;
  }
  getRemoteIds(iframe, ids) {
    const remoteIdToIdMap = this.getRemoteIdToIdMap(iframe);
    return ids.map((id4) => this.getRemoteId(iframe, id4, remoteIdToIdMap));
  }
  reset(iframe) {
    if (!iframe) {
      this.iframeIdToRemoteIdMap = /* @__PURE__ */ new WeakMap();
      this.iframeRemoteIdToIdMap = /* @__PURE__ */ new WeakMap();
      return;
    }
    this.iframeIdToRemoteIdMap.delete(iframe);
    this.iframeRemoteIdToIdMap.delete(iframe);
  }
  getIdToRemoteIdMap(iframe) {
    let idToRemoteIdMap = this.iframeIdToRemoteIdMap.get(iframe);
    if (!idToRemoteIdMap) {
      idToRemoteIdMap = /* @__PURE__ */ new Map();
      this.iframeIdToRemoteIdMap.set(iframe, idToRemoteIdMap);
    }
    return idToRemoteIdMap;
  }
  getRemoteIdToIdMap(iframe) {
    let remoteIdToIdMap = this.iframeRemoteIdToIdMap.get(iframe);
    if (!remoteIdToIdMap) {
      remoteIdToIdMap = /* @__PURE__ */ new Map();
      this.iframeRemoteIdToIdMap.set(iframe, remoteIdToIdMap);
    }
    return remoteIdToIdMap;
  }
}
function _optionalChain$1(ops) {
  let lastAccessLHS = void 0;
  let value3 = ops[0];
  let i2 = 1;
  while (i2 < ops.length) {
    const op = ops[i2];
    const fn = ops[i2 + 1];
    i2 += 2;
    if ((op === "optionalAccess" || op === "optionalCall") && value3 == null) {
      return void 0;
    }
    if (op === "access" || op === "optionalAccess") {
      lastAccessLHS = value3;
      value3 = fn(value3);
    } else if (op === "call" || op === "optionalCall") {
      value3 = fn((...args) => value3.call(lastAccessLHS, ...args));
      lastAccessLHS = void 0;
    }
  }
  return value3;
}
__name(_optionalChain$1, "_optionalChain$1");
class IframeManagerNoop {
  static {
    __name(this, "IframeManagerNoop");
  }
  constructor() {
    this.crossOriginIframeMirror = new CrossOriginIframeMirror(genId);
    this.crossOriginIframeRootIdMap = /* @__PURE__ */ new WeakMap();
  }
  addIframe() {
  }
  addLoadListener() {
  }
  attachIframe() {
  }
}
class IframeManager {
  static {
    __name(this, "IframeManager");
  }
  constructor(options5) {
    this.iframes = /* @__PURE__ */ new WeakMap();
    this.crossOriginIframeMap = /* @__PURE__ */ new WeakMap();
    this.crossOriginIframeMirror = new CrossOriginIframeMirror(genId);
    this.crossOriginIframeRootIdMap = /* @__PURE__ */ new WeakMap();
    this.mutationCb = options5.mutationCb;
    this.wrappedEmit = options5.wrappedEmit;
    this.stylesheetManager = options5.stylesheetManager;
    this.recordCrossOriginIframes = options5.recordCrossOriginIframes;
    this.crossOriginIframeStyleMirror = new CrossOriginIframeMirror(this.stylesheetManager.styleMirror.generateId.bind(this.stylesheetManager.styleMirror));
    this.mirror = options5.mirror;
    if (this.recordCrossOriginIframes) {
      window.addEventListener("message", this.handleMessage.bind(this));
    }
  }
  addIframe(iframeEl) {
    this.iframes.set(iframeEl, true);
    if (iframeEl.contentWindow)
      this.crossOriginIframeMap.set(iframeEl.contentWindow, iframeEl);
  }
  addLoadListener(cb) {
    this.loadListener = cb;
  }
  attachIframe(iframeEl, childSn) {
    this.mutationCb({
      adds: [
        {
          parentId: this.mirror.getId(iframeEl),
          nextId: null,
          node: childSn
        }
      ],
      removes: [],
      texts: [],
      attributes: [],
      isAttachIframe: true
    });
    _optionalChain$1([this, "access", (_2) => _2.loadListener, "optionalCall", (_2) => _2(iframeEl)]);
    const iframeDoc = getIFrameContentDocument(iframeEl);
    if (iframeDoc && iframeDoc.adoptedStyleSheets && iframeDoc.adoptedStyleSheets.length > 0)
      this.stylesheetManager.adoptStyleSheets(iframeDoc.adoptedStyleSheets, this.mirror.getId(iframeDoc));
  }
  handleMessage(message3) {
    const crossOriginMessageEvent = message3;
    if (crossOriginMessageEvent.data.type !== "rrweb" || crossOriginMessageEvent.origin !== crossOriginMessageEvent.data.origin)
      return;
    const iframeSourceWindow = message3.source;
    if (!iframeSourceWindow)
      return;
    const iframeEl = this.crossOriginIframeMap.get(message3.source);
    if (!iframeEl)
      return;
    const transformedEvent = this.transformCrossOriginEvent(iframeEl, crossOriginMessageEvent.data.event);
    if (transformedEvent)
      this.wrappedEmit(transformedEvent, crossOriginMessageEvent.data.isCheckout);
  }
  transformCrossOriginEvent(iframeEl, e2) {
    switch (e2.type) {
      case EventType.FullSnapshot: {
        this.crossOriginIframeMirror.reset(iframeEl);
        this.crossOriginIframeStyleMirror.reset(iframeEl);
        this.replaceIdOnNode(e2.data.node, iframeEl);
        const rootId = e2.data.node.id;
        this.crossOriginIframeRootIdMap.set(iframeEl, rootId);
        this.patchRootIdOnNode(e2.data.node, rootId);
        return {
          timestamp: e2.timestamp,
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.Mutation,
            adds: [
              {
                parentId: this.mirror.getId(iframeEl),
                nextId: null,
                node: e2.data.node
              }
            ],
            removes: [],
            texts: [],
            attributes: [],
            isAttachIframe: true
          }
        };
      }
      case EventType.Meta:
      case EventType.Load:
      case EventType.DomContentLoaded: {
        return false;
      }
      case EventType.Plugin: {
        return e2;
      }
      case EventType.Custom: {
        this.replaceIds(e2.data.payload, iframeEl, ["id", "parentId", "previousId", "nextId"]);
        return e2;
      }
      case EventType.IncrementalSnapshot: {
        switch (e2.data.source) {
          case IncrementalSource.Mutation: {
            e2.data.adds.forEach((n2) => {
              this.replaceIds(n2, iframeEl, [
                "parentId",
                "nextId",
                "previousId"
              ]);
              this.replaceIdOnNode(n2.node, iframeEl);
              const rootId = this.crossOriginIframeRootIdMap.get(iframeEl);
              rootId && this.patchRootIdOnNode(n2.node, rootId);
            });
            e2.data.removes.forEach((n2) => {
              this.replaceIds(n2, iframeEl, ["parentId", "id"]);
            });
            e2.data.attributes.forEach((n2) => {
              this.replaceIds(n2, iframeEl, ["id"]);
            });
            e2.data.texts.forEach((n2) => {
              this.replaceIds(n2, iframeEl, ["id"]);
            });
            return e2;
          }
          case IncrementalSource.Drag:
          case IncrementalSource.TouchMove:
          case IncrementalSource.MouseMove: {
            e2.data.positions.forEach((p2) => {
              this.replaceIds(p2, iframeEl, ["id"]);
            });
            return e2;
          }
          case IncrementalSource.ViewportResize: {
            return false;
          }
          case IncrementalSource.MediaInteraction:
          case IncrementalSource.MouseInteraction:
          case IncrementalSource.Scroll:
          case IncrementalSource.CanvasMutation:
          case IncrementalSource.Input: {
            this.replaceIds(e2.data, iframeEl, ["id"]);
            return e2;
          }
          case IncrementalSource.StyleSheetRule:
          case IncrementalSource.StyleDeclaration: {
            this.replaceIds(e2.data, iframeEl, ["id"]);
            this.replaceStyleIds(e2.data, iframeEl, ["styleId"]);
            return e2;
          }
          case IncrementalSource.Font: {
            return e2;
          }
          case IncrementalSource.Selection: {
            e2.data.ranges.forEach((range2) => {
              this.replaceIds(range2, iframeEl, ["start", "end"]);
            });
            return e2;
          }
          case IncrementalSource.AdoptedStyleSheet: {
            this.replaceIds(e2.data, iframeEl, ["id"]);
            this.replaceStyleIds(e2.data, iframeEl, ["styleIds"]);
            _optionalChain$1([e2, "access", (_3) => _3.data, "access", (_4) => _4.styles, "optionalAccess", (_5) => _5.forEach, "call", (_6) => _6((style2) => {
              this.replaceStyleIds(style2, iframeEl, ["styleId"]);
            })]);
            return e2;
          }
        }
      }
    }
    return false;
  }
  replace(iframeMirror, obj, iframeEl, keys2) {
    for (const key of keys2) {
      if (!Array.isArray(obj[key]) && typeof obj[key] !== "number")
        continue;
      if (Array.isArray(obj[key])) {
        obj[key] = iframeMirror.getIds(iframeEl, obj[key]);
      } else {
        obj[key] = iframeMirror.getId(iframeEl, obj[key]);
      }
    }
    return obj;
  }
  replaceIds(obj, iframeEl, keys2) {
    return this.replace(this.crossOriginIframeMirror, obj, iframeEl, keys2);
  }
  replaceStyleIds(obj, iframeEl, keys2) {
    return this.replace(this.crossOriginIframeStyleMirror, obj, iframeEl, keys2);
  }
  replaceIdOnNode(node3, iframeEl) {
    this.replaceIds(node3, iframeEl, ["id", "rootId"]);
    if ("childNodes" in node3) {
      node3.childNodes.forEach((child) => {
        this.replaceIdOnNode(child, iframeEl);
      });
    }
  }
  patchRootIdOnNode(node3, rootId) {
    if (node3.type !== NodeType$3.Document && !node3.rootId)
      node3.rootId = rootId;
    if ("childNodes" in node3) {
      node3.childNodes.forEach((child) => {
        this.patchRootIdOnNode(child, rootId);
      });
    }
  }
}
class ShadowDomManagerNoop {
  static {
    __name(this, "ShadowDomManagerNoop");
  }
  init() {
  }
  addShadowRoot() {
  }
  observeAttachShadow() {
  }
  reset() {
  }
}
class ShadowDomManager {
  static {
    __name(this, "ShadowDomManager");
  }
  constructor(options5) {
    this.shadowDoms = /* @__PURE__ */ new WeakSet();
    this.restoreHandlers = [];
    this.mutationCb = options5.mutationCb;
    this.scrollCb = options5.scrollCb;
    this.bypassOptions = options5.bypassOptions;
    this.mirror = options5.mirror;
    this.init();
  }
  init() {
    this.reset();
    this.patchAttachShadow(Element, document);
  }
  addShadowRoot(shadowRoot, doc2) {
    if (!isNativeShadowDom(shadowRoot))
      return;
    if (this.shadowDoms.has(shadowRoot))
      return;
    this.shadowDoms.add(shadowRoot);
    this.bypassOptions.canvasManager.addShadowRoot(shadowRoot);
    const observer = initMutationObserver({
      ...this.bypassOptions,
      doc: doc2,
      mutationCb: this.mutationCb,
      mirror: this.mirror,
      shadowDomManager: this
    }, shadowRoot);
    this.restoreHandlers.push(() => observer.disconnect());
    this.restoreHandlers.push(initScrollObserver({
      ...this.bypassOptions,
      scrollCb: this.scrollCb,
      doc: shadowRoot,
      mirror: this.mirror
    }));
    setTimeout$1$1(() => {
      if (shadowRoot.adoptedStyleSheets && shadowRoot.adoptedStyleSheets.length > 0)
        this.bypassOptions.stylesheetManager.adoptStyleSheets(shadowRoot.adoptedStyleSheets, this.mirror.getId(shadowRoot.host));
      this.restoreHandlers.push(initAdoptedStyleSheetObserver({
        mirror: this.mirror,
        stylesheetManager: this.bypassOptions.stylesheetManager
      }, shadowRoot));
    }, 0);
  }
  observeAttachShadow(iframeElement) {
    const iframeDoc = getIFrameContentDocument(iframeElement);
    const iframeWindow = getIFrameContentWindow(iframeElement);
    if (!iframeDoc || !iframeWindow)
      return;
    this.patchAttachShadow(iframeWindow.Element, iframeDoc);
  }
  patchAttachShadow(element, doc2) {
    const manager2 = this;
    this.restoreHandlers.push(patch$2(element.prototype, "attachShadow", function(original) {
      return function(option5) {
        const shadowRoot = original.call(this, option5);
        if (this.shadowRoot && inDom(this))
          manager2.addShadowRoot(this.shadowRoot, doc2);
        return shadowRoot;
      };
    }));
  }
  reset() {
    this.restoreHandlers.forEach((handler14) => {
      try {
        handler14();
      } catch (e2) {
      }
    });
    this.restoreHandlers = [];
    this.shadowDoms = /* @__PURE__ */ new WeakSet();
    this.bypassOptions.canvasManager.resetShadowRoots();
  }
}
class CanvasManagerNoop {
  static {
    __name(this, "CanvasManagerNoop");
  }
  reset() {
  }
  freeze() {
  }
  unfreeze() {
  }
  lock() {
  }
  unlock() {
  }
  snapshot() {
  }
  addWindow() {
  }
  addShadowRoot() {
  }
  resetShadowRoots() {
  }
}
class StylesheetManager {
  static {
    __name(this, "StylesheetManager");
  }
  constructor(options5) {
    this.trackedLinkElements = /* @__PURE__ */ new WeakSet();
    this.styleMirror = new StyleSheetMirror();
    this.mutationCb = options5.mutationCb;
    this.adoptedStyleSheetCb = options5.adoptedStyleSheetCb;
  }
  attachLinkElement(linkEl, childSn) {
    if ("_cssText" in childSn.attributes)
      this.mutationCb({
        adds: [],
        removes: [],
        texts: [],
        attributes: [
          {
            id: childSn.id,
            attributes: childSn.attributes
          }
        ]
      });
    this.trackLinkElement(linkEl);
  }
  trackLinkElement(linkEl) {
    if (this.trackedLinkElements.has(linkEl))
      return;
    this.trackedLinkElements.add(linkEl);
    this.trackStylesheetInLinkElement(linkEl);
  }
  adoptStyleSheets(sheets, hostId) {
    if (sheets.length === 0)
      return;
    const adoptedStyleSheetData = {
      id: hostId,
      styleIds: []
    };
    const styles = [];
    for (const sheet of sheets) {
      let styleId;
      if (!this.styleMirror.has(sheet)) {
        styleId = this.styleMirror.add(sheet);
        styles.push({
          styleId,
          rules: Array.from(sheet.rules || CSSRule, (r2, index2) => ({
            rule: stringifyRule(r2),
            index: index2
          }))
        });
      } else
        styleId = this.styleMirror.getId(sheet);
      adoptedStyleSheetData.styleIds.push(styleId);
    }
    if (styles.length > 0)
      adoptedStyleSheetData.styles = styles;
    this.adoptedStyleSheetCb(adoptedStyleSheetData);
  }
  reset() {
    this.styleMirror.reset();
    this.trackedLinkElements = /* @__PURE__ */ new WeakSet();
  }
  trackStylesheetInLinkElement(linkEl) {
  }
}
class ProcessedNodeManager {
  static {
    __name(this, "ProcessedNodeManager");
  }
  constructor() {
    this.nodeMap = /* @__PURE__ */ new WeakMap();
    this.active = false;
  }
  inOtherBuffer(node3, thisBuffer) {
    const buffers = this.nodeMap.get(node3);
    return buffers && Array.from(buffers).some((buffer2) => buffer2 !== thisBuffer);
  }
  add(node3, buffer2) {
    if (!this.active) {
      this.active = true;
      onRequestAnimationFrame$1(() => {
        this.nodeMap = /* @__PURE__ */ new WeakMap();
        this.active = false;
      });
    }
    this.nodeMap.set(node3, (this.nodeMap.get(node3) || /* @__PURE__ */ new Set()).add(buffer2));
  }
  destroy() {
  }
}
let wrappedEmit;
let _takeFullSnapshot;
try {
  if (Array.from([1], (x2) => x2 * 2)[0] !== 2) {
    const cleanFrame = document.createElement("iframe");
    document.body.appendChild(cleanFrame);
    Array.from = _optionalChain([cleanFrame, "access", (_2) => _2.contentWindow, "optionalAccess", (_2) => _2.Array, "access", (_3) => _3.from]) || Array.from;
    document.body.removeChild(cleanFrame);
  }
} catch (err) {
  console.debug("Unable to override Array.from", err);
}
const mirror = createMirror();
function record(options5 = {}) {
  const { emit: emit2, checkoutEveryNms, checkoutEveryNth, blockClass = "rr-block", blockSelector = null, unblockSelector = null, ignoreClass = "rr-ignore", ignoreSelector = null, maskAllText = false, maskTextClass = "rr-mask", unmaskTextClass = null, maskTextSelector = null, unmaskTextSelector = null, inlineStylesheet = true, maskAllInputs, maskInputOptions: _maskInputOptions, slimDOMOptions: _slimDOMOptions, maskAttributeFn, maskInputFn, maskTextFn, maxCanvasSize = null, packFn, sampling = {}, dataURLOptions = {}, mousemoveWait, recordDOM = true, recordCanvas = false, recordCrossOriginIframes = false, recordAfter = options5.recordAfter === "DOMContentLoaded" ? options5.recordAfter : "load", userTriggeredOnInput = false, collectFonts = false, inlineImages = false, plugins, keepIframeSrcFn = /* @__PURE__ */ __name(() => false, "keepIframeSrcFn"), ignoreCSSAttributes = /* @__PURE__ */ new Set([]), errorHandler: errorHandler2, onMutation, getCanvasManager } = options5;
  registerErrorHandler$1(errorHandler2);
  const inEmittingFrame = recordCrossOriginIframes ? window.parent === window : true;
  let passEmitsToParent = false;
  if (!inEmittingFrame) {
    try {
      if (window.parent.document) {
        passEmitsToParent = false;
      }
    } catch (e2) {
      passEmitsToParent = true;
    }
  }
  if (inEmittingFrame && !emit2) {
    throw new Error("emit function is required");
  }
  if (!inEmittingFrame && !passEmitsToParent) {
    return () => {
    };
  }
  if (mousemoveWait !== void 0 && sampling.mousemove === void 0) {
    sampling.mousemove = mousemoveWait;
  }
  mirror.reset();
  const maskInputOptions = maskAllInputs === true ? {
    color: true,
    date: true,
    "datetime-local": true,
    email: true,
    month: true,
    number: true,
    range: true,
    search: true,
    tel: true,
    text: true,
    time: true,
    url: true,
    week: true,
    textarea: true,
    select: true,
    radio: true,
    checkbox: true
  } : _maskInputOptions !== void 0 ? _maskInputOptions : {};
  const slimDOMOptions = _slimDOMOptions === true || _slimDOMOptions === "all" ? {
    script: true,
    comment: true,
    headFavicon: true,
    headWhitespace: true,
    headMetaSocial: true,
    headMetaRobots: true,
    headMetaHttpEquiv: true,
    headMetaVerification: true,
    headMetaAuthorship: _slimDOMOptions === "all",
    headMetaDescKeywords: _slimDOMOptions === "all"
  } : _slimDOMOptions ? _slimDOMOptions : {};
  polyfill();
  let lastFullSnapshotEvent;
  let incrementalSnapshotCount = 0;
  const eventProcessor = /* @__PURE__ */ __name((e2) => {
    for (const plugin of plugins || []) {
      if (plugin.eventProcessor) {
        e2 = plugin.eventProcessor(e2);
      }
    }
    if (packFn && !passEmitsToParent) {
      e2 = packFn(e2);
    }
    return e2;
  }, "eventProcessor");
  wrappedEmit = /* @__PURE__ */ __name((r2, isCheckout) => {
    const e2 = r2;
    e2.timestamp = nowTimestamp();
    if (_optionalChain([mutationBuffers, "access", (_4) => _4[0], "optionalAccess", (_5) => _5.isFrozen, "call", (_6) => _6()]) && e2.type !== EventType.FullSnapshot && !(e2.type === EventType.IncrementalSnapshot && e2.data.source === IncrementalSource.Mutation)) {
      mutationBuffers.forEach((buf) => buf.unfreeze());
    }
    if (inEmittingFrame) {
      _optionalChain([emit2, "optionalCall", (_7) => _7(eventProcessor(e2), isCheckout)]);
    } else if (passEmitsToParent) {
      const message3 = {
        type: "rrweb",
        event: eventProcessor(e2),
        origin: window.location.origin,
        isCheckout
      };
      window.parent.postMessage(message3, "*");
    }
    if (e2.type === EventType.FullSnapshot) {
      lastFullSnapshotEvent = e2;
      incrementalSnapshotCount = 0;
    } else if (e2.type === EventType.IncrementalSnapshot) {
      if (e2.data.source === IncrementalSource.Mutation && e2.data.isAttachIframe) {
        return;
      }
      incrementalSnapshotCount++;
      const exceedCount = checkoutEveryNth && incrementalSnapshotCount >= checkoutEveryNth;
      const exceedTime = checkoutEveryNms && lastFullSnapshotEvent && e2.timestamp - lastFullSnapshotEvent.timestamp > checkoutEveryNms;
      if (exceedCount || exceedTime) {
        takeFullSnapshot2(true);
      }
    }
  }, "wrappedEmit");
  const wrappedMutationEmit = /* @__PURE__ */ __name((m2) => {
    wrappedEmit({
      type: EventType.IncrementalSnapshot,
      data: {
        source: IncrementalSource.Mutation,
        ...m2
      }
    });
  }, "wrappedMutationEmit");
  const wrappedScrollEmit = /* @__PURE__ */ __name((p2) => wrappedEmit({
    type: EventType.IncrementalSnapshot,
    data: {
      source: IncrementalSource.Scroll,
      ...p2
    }
  }), "wrappedScrollEmit");
  const wrappedCanvasMutationEmit = /* @__PURE__ */ __name((p2) => wrappedEmit({
    type: EventType.IncrementalSnapshot,
    data: {
      source: IncrementalSource.CanvasMutation,
      ...p2
    }
  }), "wrappedCanvasMutationEmit");
  const wrappedAdoptedStyleSheetEmit = /* @__PURE__ */ __name((a2) => wrappedEmit({
    type: EventType.IncrementalSnapshot,
    data: {
      source: IncrementalSource.AdoptedStyleSheet,
      ...a2
    }
  }), "wrappedAdoptedStyleSheetEmit");
  const stylesheetManager = new StylesheetManager({
    mutationCb: wrappedMutationEmit,
    adoptedStyleSheetCb: wrappedAdoptedStyleSheetEmit
  });
  const iframeManager = typeof __RRWEB_EXCLUDE_IFRAME__ === "boolean" && __RRWEB_EXCLUDE_IFRAME__ ? new IframeManagerNoop() : new IframeManager({
    mirror,
    mutationCb: wrappedMutationEmit,
    stylesheetManager,
    recordCrossOriginIframes,
    wrappedEmit
  });
  for (const plugin of plugins || []) {
    if (plugin.getMirror)
      plugin.getMirror({
        nodeMirror: mirror,
        crossOriginIframeMirror: iframeManager.crossOriginIframeMirror,
        crossOriginIframeStyleMirror: iframeManager.crossOriginIframeStyleMirror
      });
  }
  const processedNodeManager = new ProcessedNodeManager();
  const canvasManager = _getCanvasManager(getCanvasManager, {
    mirror,
    win: window,
    mutationCb: /* @__PURE__ */ __name((p2) => wrappedEmit({
      type: EventType.IncrementalSnapshot,
      data: {
        source: IncrementalSource.CanvasMutation,
        ...p2
      }
    }), "mutationCb"),
    recordCanvas,
    blockClass,
    blockSelector,
    unblockSelector,
    maxCanvasSize,
    sampling: sampling["canvas"],
    dataURLOptions,
    errorHandler: errorHandler2
  });
  const shadowDomManager = typeof __RRWEB_EXCLUDE_SHADOW_DOM__ === "boolean" && __RRWEB_EXCLUDE_SHADOW_DOM__ ? new ShadowDomManagerNoop() : new ShadowDomManager({
    mutationCb: wrappedMutationEmit,
    scrollCb: wrappedScrollEmit,
    bypassOptions: {
      onMutation,
      blockClass,
      blockSelector,
      unblockSelector,
      maskAllText,
      maskTextClass,
      unmaskTextClass,
      maskTextSelector,
      unmaskTextSelector,
      inlineStylesheet,
      maskInputOptions,
      dataURLOptions,
      maskAttributeFn,
      maskTextFn,
      maskInputFn,
      recordCanvas,
      inlineImages,
      sampling,
      slimDOMOptions,
      iframeManager,
      stylesheetManager,
      canvasManager,
      keepIframeSrcFn,
      processedNodeManager
    },
    mirror
  });
  const takeFullSnapshot2 = /* @__PURE__ */ __name((isCheckout = false) => {
    if (!recordDOM) {
      return;
    }
    wrappedEmit({
      type: EventType.Meta,
      data: {
        href: window.location.href,
        width: getWindowWidth(),
        height: getWindowHeight()
      }
    }, isCheckout);
    stylesheetManager.reset();
    shadowDomManager.init();
    mutationBuffers.forEach((buf) => buf.lock());
    const node3 = snapshot(document, {
      mirror,
      blockClass,
      blockSelector,
      unblockSelector,
      maskAllText,
      maskTextClass,
      unmaskTextClass,
      maskTextSelector,
      unmaskTextSelector,
      inlineStylesheet,
      maskAllInputs: maskInputOptions,
      maskAttributeFn,
      maskInputFn,
      maskTextFn,
      slimDOM: slimDOMOptions,
      dataURLOptions,
      recordCanvas,
      inlineImages,
      onSerialize: /* @__PURE__ */ __name((n2) => {
        if (isSerializedIframe(n2, mirror)) {
          iframeManager.addIframe(n2);
        }
        if (isSerializedStylesheet(n2, mirror)) {
          stylesheetManager.trackLinkElement(n2);
        }
        if (hasShadowRoot(n2)) {
          shadowDomManager.addShadowRoot(n2.shadowRoot, document);
        }
      }, "onSerialize"),
      onIframeLoad: /* @__PURE__ */ __name((iframe, childSn) => {
        iframeManager.attachIframe(iframe, childSn);
        if (iframe.contentWindow) {
          canvasManager.addWindow(iframe.contentWindow);
        }
        shadowDomManager.observeAttachShadow(iframe);
      }, "onIframeLoad"),
      onStylesheetLoad: /* @__PURE__ */ __name((linkEl, childSn) => {
        stylesheetManager.attachLinkElement(linkEl, childSn);
      }, "onStylesheetLoad"),
      keepIframeSrcFn
    });
    if (!node3) {
      return console.warn("Failed to snapshot the document");
    }
    wrappedEmit({
      type: EventType.FullSnapshot,
      data: {
        node: node3,
        initialOffset: getWindowScroll(window)
      }
    });
    mutationBuffers.forEach((buf) => buf.unlock());
    if (document.adoptedStyleSheets && document.adoptedStyleSheets.length > 0)
      stylesheetManager.adoptStyleSheets(document.adoptedStyleSheets, mirror.getId(document));
  }, "takeFullSnapshot");
  _takeFullSnapshot = takeFullSnapshot2;
  try {
    const handlers2 = [];
    const observe2 = /* @__PURE__ */ __name((doc2) => {
      return callbackWrapper$1(initObservers)({
        onMutation,
        mutationCb: wrappedMutationEmit,
        mousemoveCb: /* @__PURE__ */ __name((positions, source) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source,
            positions
          }
        }), "mousemoveCb"),
        mouseInteractionCb: /* @__PURE__ */ __name((d2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.MouseInteraction,
            ...d2
          }
        }), "mouseInteractionCb"),
        scrollCb: wrappedScrollEmit,
        viewportResizeCb: /* @__PURE__ */ __name((d2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.ViewportResize,
            ...d2
          }
        }), "viewportResizeCb"),
        inputCb: /* @__PURE__ */ __name((v2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.Input,
            ...v2
          }
        }), "inputCb"),
        mediaInteractionCb: /* @__PURE__ */ __name((p2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.MediaInteraction,
            ...p2
          }
        }), "mediaInteractionCb"),
        styleSheetRuleCb: /* @__PURE__ */ __name((r2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.StyleSheetRule,
            ...r2
          }
        }), "styleSheetRuleCb"),
        styleDeclarationCb: /* @__PURE__ */ __name((r2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.StyleDeclaration,
            ...r2
          }
        }), "styleDeclarationCb"),
        canvasMutationCb: wrappedCanvasMutationEmit,
        fontCb: /* @__PURE__ */ __name((p2) => wrappedEmit({
          type: EventType.IncrementalSnapshot,
          data: {
            source: IncrementalSource.Font,
            ...p2
          }
        }), "fontCb"),
        selectionCb: /* @__PURE__ */ __name((p2) => {
          wrappedEmit({
            type: EventType.IncrementalSnapshot,
            data: {
              source: IncrementalSource.Selection,
              ...p2
            }
          });
        }, "selectionCb"),
        customElementCb: /* @__PURE__ */ __name((c2) => {
          wrappedEmit({
            type: EventType.IncrementalSnapshot,
            data: {
              source: IncrementalSource.CustomElement,
              ...c2
            }
          });
        }, "customElementCb"),
        blockClass,
        ignoreClass,
        ignoreSelector,
        maskAllText,
        maskTextClass,
        unmaskTextClass,
        maskTextSelector,
        unmaskTextSelector,
        maskInputOptions,
        inlineStylesheet,
        sampling,
        recordDOM,
        recordCanvas,
        inlineImages,
        userTriggeredOnInput,
        collectFonts,
        doc: doc2,
        maskAttributeFn,
        maskInputFn,
        maskTextFn,
        keepIframeSrcFn,
        blockSelector,
        unblockSelector,
        slimDOMOptions,
        dataURLOptions,
        mirror,
        iframeManager,
        stylesheetManager,
        shadowDomManager,
        processedNodeManager,
        canvasManager,
        ignoreCSSAttributes,
        plugins: _optionalChain([
          plugins,
          "optionalAccess",
          (_8) => _8.filter,
          "call",
          (_9) => _9((p2) => p2.observer),
          "optionalAccess",
          (_10) => _10.map,
          "call",
          (_11) => _11((p2) => ({
            observer: p2.observer,
            options: p2.options,
            callback: /* @__PURE__ */ __name((payload) => wrappedEmit({
              type: EventType.Plugin,
              data: {
                plugin: p2.name,
                payload
              }
            }), "callback")
          }))
        ]) || []
      }, {});
    }, "observe");
    iframeManager.addLoadListener((iframeEl) => {
      try {
        handlers2.push(observe2(iframeEl.contentDocument));
      } catch (error2) {
        console.warn(error2);
      }
    });
    const init3 = /* @__PURE__ */ __name(() => {
      takeFullSnapshot2();
      handlers2.push(observe2(document));
    }, "init");
    if (document.readyState === "interactive" || document.readyState === "complete") {
      init3();
    } else {
      handlers2.push(on("DOMContentLoaded", () => {
        wrappedEmit({
          type: EventType.DomContentLoaded,
          data: {}
        });
        if (recordAfter === "DOMContentLoaded")
          init3();
      }));
      handlers2.push(on("load", () => {
        wrappedEmit({
          type: EventType.Load,
          data: {}
        });
        if (recordAfter === "load")
          init3();
      }, window));
    }
    return () => {
      handlers2.forEach((h2) => h2());
      processedNodeManager.destroy();
      _takeFullSnapshot = void 0;
      unregisterErrorHandler();
    };
  } catch (error2) {
    console.warn(error2);
  }
}
__name(record, "record");
function takeFullSnapshot(isCheckout) {
  if (!_takeFullSnapshot) {
    throw new Error("please take full snapshot after start recording");
  }
  _takeFullSnapshot(isCheckout);
}
__name(takeFullSnapshot, "takeFullSnapshot");
record.mirror = mirror;
record.takeFullSnapshot = takeFullSnapshot;
function _getCanvasManager(getCanvasManagerFn, options5) {
  try {
    return getCanvasManagerFn ? getCanvasManagerFn(options5) : new CanvasManagerNoop();
  } catch (e2) {
    console.warn("Unable to initialize CanvasManager");
    return new CanvasManagerNoop();
  }
}
__name(_getCanvasManager, "_getCanvasManager");
const ReplayEventTypeIncrementalSnapshot = 3;
const ReplayEventTypeCustom = 5;
function timestampToMs(timestamp2) {
  const isMs = timestamp2 > 9999999999;
  return isMs ? timestamp2 : timestamp2 * 1e3;
}
__name(timestampToMs, "timestampToMs");
function timestampToS(timestamp2) {
  const isMs = timestamp2 > 9999999999;
  return isMs ? timestamp2 / 1e3 : timestamp2;
}
__name(timestampToS, "timestampToS");
function addBreadcrumbEvent(replay, breadcrumb) {
  if (breadcrumb.category === "sentry.transaction") {
    return;
  }
  if (["ui.click", "ui.input"].includes(breadcrumb.category)) {
    replay.triggerUserActivity();
  } else {
    replay.checkAndHandleExpiredSession();
  }
  replay.addUpdate(() => {
    replay.throttledAddEvent({
      type: EventType.Custom,
      // TODO: We were converting from ms to seconds for breadcrumbs, spans,
      // but maybe we should just keep them as milliseconds
      timestamp: (breadcrumb.timestamp || 0) * 1e3,
      data: {
        tag: "breadcrumb",
        // normalize to max. 10 depth and 1_000 properties per object
        payload: normalize$2(breadcrumb, 10, 1e3)
      }
    });
    return breadcrumb.category === "console";
  });
}
__name(addBreadcrumbEvent, "addBreadcrumbEvent");
const INTERACTIVE_SELECTOR = "button,a";
function getClosestInteractive(element) {
  const closestInteractive = element.closest(INTERACTIVE_SELECTOR);
  return closestInteractive || element;
}
__name(getClosestInteractive, "getClosestInteractive");
function getClickTargetNode(event) {
  const target2 = getTargetNode(event);
  if (!target2 || !(target2 instanceof Element)) {
    return target2;
  }
  return getClosestInteractive(target2);
}
__name(getClickTargetNode, "getClickTargetNode");
function getTargetNode(event) {
  if (isEventWithTarget(event)) {
    return event.target;
  }
  return event;
}
__name(getTargetNode, "getTargetNode");
function isEventWithTarget(event) {
  return typeof event === "object" && !!event && "target" in event;
}
__name(isEventWithTarget, "isEventWithTarget");
let handlers$2;
function onWindowOpen(cb) {
  if (!handlers$2) {
    handlers$2 = [];
    monkeyPatchWindowOpen();
  }
  handlers$2.push(cb);
  return () => {
    const pos = handlers$2 ? handlers$2.indexOf(cb) : -1;
    if (pos > -1) {
      handlers$2.splice(pos, 1);
    }
  };
}
__name(onWindowOpen, "onWindowOpen");
function monkeyPatchWindowOpen() {
  fill(WINDOW$1, "open", function(originalWindowOpen) {
    return function(...args) {
      if (handlers$2) {
        try {
          handlers$2.forEach((handler14) => handler14());
        } catch (e2) {
        }
      }
      return originalWindowOpen.apply(WINDOW$1, args);
    };
  });
}
__name(monkeyPatchWindowOpen, "monkeyPatchWindowOpen");
const IncrementalMutationSources = /* @__PURE__ */ new Set([
  IncrementalSource.Mutation,
  IncrementalSource.StyleSheetRule,
  IncrementalSource.StyleDeclaration,
  IncrementalSource.AdoptedStyleSheet,
  IncrementalSource.CanvasMutation,
  IncrementalSource.Selection,
  IncrementalSource.MediaInteraction
]);
function handleClick$1(clickDetector, clickBreadcrumb, node3) {
  clickDetector.handleClick(clickBreadcrumb, node3);
}
__name(handleClick$1, "handleClick$1");
class ClickDetector {
  static {
    __name(this, "ClickDetector");
  }
  // protected for testing
  constructor(replay, slowClickConfig, _addBreadcrumbEvent = addBreadcrumbEvent) {
    this._lastMutation = 0;
    this._lastScroll = 0;
    this._clicks = [];
    this._timeout = slowClickConfig.timeout / 1e3;
    this._threshold = slowClickConfig.threshold / 1e3;
    this._scrollTimeout = slowClickConfig.scrollTimeout / 1e3;
    this._replay = replay;
    this._ignoreSelector = slowClickConfig.ignoreSelector;
    this._addBreadcrumbEvent = _addBreadcrumbEvent;
  }
  /** Register click detection handlers on mutation or scroll. */
  addListeners() {
    const cleanupWindowOpen = onWindowOpen(() => {
      this._lastMutation = nowInSeconds();
    });
    this._teardown = () => {
      cleanupWindowOpen();
      this._clicks = [];
      this._lastMutation = 0;
      this._lastScroll = 0;
    };
  }
  /** Clean up listeners. */
  removeListeners() {
    if (this._teardown) {
      this._teardown();
    }
    if (this._checkClickTimeout) {
      clearTimeout(this._checkClickTimeout);
    }
  }
  /** @inheritDoc */
  handleClick(breadcrumb, node3) {
    if (ignoreElement(node3, this._ignoreSelector) || !isClickBreadcrumb(breadcrumb)) {
      return;
    }
    const newClick = {
      timestamp: timestampToS(breadcrumb.timestamp),
      clickBreadcrumb: breadcrumb,
      // Set this to 0 so we know it originates from the click breadcrumb
      clickCount: 0,
      node: node3
    };
    if (this._clicks.some((click2) => click2.node === newClick.node && Math.abs(click2.timestamp - newClick.timestamp) < 1)) {
      return;
    }
    this._clicks.push(newClick);
    if (this._clicks.length === 1) {
      this._scheduleCheckClicks();
    }
  }
  /** @inheritDoc */
  registerMutation(timestamp2 = Date.now()) {
    this._lastMutation = timestampToS(timestamp2);
  }
  /** @inheritDoc */
  registerScroll(timestamp2 = Date.now()) {
    this._lastScroll = timestampToS(timestamp2);
  }
  /** @inheritDoc */
  registerClick(element) {
    const node3 = getClosestInteractive(element);
    this._handleMultiClick(node3);
  }
  /** Count multiple clicks on elements. */
  _handleMultiClick(node3) {
    this._getClicks(node3).forEach((click2) => {
      click2.clickCount++;
    });
  }
  /** Get all pending clicks for a given node. */
  _getClicks(node3) {
    return this._clicks.filter((click2) => click2.node === node3);
  }
  /** Check the clicks that happened. */
  _checkClicks() {
    const timedOutClicks = [];
    const now2 = nowInSeconds();
    this._clicks.forEach((click2) => {
      if (!click2.mutationAfter && this._lastMutation) {
        click2.mutationAfter = click2.timestamp <= this._lastMutation ? this._lastMutation - click2.timestamp : void 0;
      }
      if (!click2.scrollAfter && this._lastScroll) {
        click2.scrollAfter = click2.timestamp <= this._lastScroll ? this._lastScroll - click2.timestamp : void 0;
      }
      if (click2.timestamp + this._timeout <= now2) {
        timedOutClicks.push(click2);
      }
    });
    for (const click2 of timedOutClicks) {
      const pos = this._clicks.indexOf(click2);
      if (pos > -1) {
        this._generateBreadcrumbs(click2);
        this._clicks.splice(pos, 1);
      }
    }
    if (this._clicks.length) {
      this._scheduleCheckClicks();
    }
  }
  /** Generate matching breadcrumb(s) for the click. */
  _generateBreadcrumbs(click2) {
    const replay = this._replay;
    const hadScroll = click2.scrollAfter && click2.scrollAfter <= this._scrollTimeout;
    const hadMutation = click2.mutationAfter && click2.mutationAfter <= this._threshold;
    const isSlowClick = !hadScroll && !hadMutation;
    const { clickCount, clickBreadcrumb } = click2;
    if (isSlowClick) {
      const timeAfterClickMs = Math.min(click2.mutationAfter || this._timeout, this._timeout) * 1e3;
      const endReason = timeAfterClickMs < this._timeout * 1e3 ? "mutation" : "timeout";
      const breadcrumb = {
        type: "default",
        message: clickBreadcrumb.message,
        timestamp: clickBreadcrumb.timestamp,
        category: "ui.slowClickDetected",
        data: {
          ...clickBreadcrumb.data,
          url: WINDOW$1.location.href,
          route: replay.getCurrentRoute(),
          timeAfterClickMs,
          endReason,
          // If clickCount === 0, it means multiClick was not correctly captured here
          // - we still want to send 1 in this case
          clickCount: clickCount || 1
        }
      };
      this._addBreadcrumbEvent(replay, breadcrumb);
      return;
    }
    if (clickCount > 1) {
      const breadcrumb = {
        type: "default",
        message: clickBreadcrumb.message,
        timestamp: clickBreadcrumb.timestamp,
        category: "ui.multiClick",
        data: {
          ...clickBreadcrumb.data,
          url: WINDOW$1.location.href,
          route: replay.getCurrentRoute(),
          clickCount,
          metric: true
        }
      };
      this._addBreadcrumbEvent(replay, breadcrumb);
    }
  }
  /** Schedule to check current clicks. */
  _scheduleCheckClicks() {
    if (this._checkClickTimeout) {
      clearTimeout(this._checkClickTimeout);
    }
    this._checkClickTimeout = setTimeout$3(() => this._checkClicks(), 1e3);
  }
}
const SLOW_CLICK_TAGS = ["A", "BUTTON", "INPUT"];
function ignoreElement(node3, ignoreSelector) {
  if (!SLOW_CLICK_TAGS.includes(node3.tagName)) {
    return true;
  }
  if (node3.tagName === "INPUT" && !["submit", "button"].includes(node3.getAttribute("type") || "")) {
    return true;
  }
  if (node3.tagName === "A" && (node3.hasAttribute("download") || node3.hasAttribute("target") && node3.getAttribute("target") !== "_self")) {
    return true;
  }
  if (ignoreSelector && node3.matches(ignoreSelector)) {
    return true;
  }
  return false;
}
__name(ignoreElement, "ignoreElement");
function isClickBreadcrumb(breadcrumb) {
  return !!(breadcrumb.data && typeof breadcrumb.data.nodeId === "number" && breadcrumb.timestamp);
}
__name(isClickBreadcrumb, "isClickBreadcrumb");
function nowInSeconds() {
  return Date.now() / 1e3;
}
__name(nowInSeconds, "nowInSeconds");
function updateClickDetectorForRecordingEvent(clickDetector, event) {
  try {
    if (!isIncrementalEvent(event)) {
      return;
    }
    const { source } = event.data;
    if (IncrementalMutationSources.has(source)) {
      clickDetector.registerMutation(event.timestamp);
    }
    if (source === IncrementalSource.Scroll) {
      clickDetector.registerScroll(event.timestamp);
    }
    if (isIncrementalMouseInteraction(event)) {
      const { type, id: id4 } = event.data;
      const node3 = record.mirror.getNode(id4);
      if (node3 instanceof HTMLElement && type === MouseInteractions.Click) {
        clickDetector.registerClick(node3);
      }
    }
  } catch (e2) {
  }
}
__name(updateClickDetectorForRecordingEvent, "updateClickDetectorForRecordingEvent");
function isIncrementalEvent(event) {
  return event.type === ReplayEventTypeIncrementalSnapshot;
}
__name(isIncrementalEvent, "isIncrementalEvent");
function isIncrementalMouseInteraction(event) {
  return event.data.source === IncrementalSource.MouseInteraction;
}
__name(isIncrementalMouseInteraction, "isIncrementalMouseInteraction");
function createBreadcrumb(breadcrumb) {
  return {
    timestamp: Date.now() / 1e3,
    type: "default",
    ...breadcrumb
  };
}
__name(createBreadcrumb, "createBreadcrumb");
var NodeType$4;
(function(NodeType3) {
  NodeType3[NodeType3["Document"] = 0] = "Document";
  NodeType3[NodeType3["DocumentType"] = 1] = "DocumentType";
  NodeType3[NodeType3["Element"] = 2] = "Element";
  NodeType3[NodeType3["Text"] = 3] = "Text";
  NodeType3[NodeType3["CDATA"] = 4] = "CDATA";
  NodeType3[NodeType3["Comment"] = 5] = "Comment";
})(NodeType$4 || (NodeType$4 = {}));
const ATTRIBUTES_TO_RECORD = /* @__PURE__ */ new Set([
  "id",
  "class",
  "aria-label",
  "role",
  "name",
  "alt",
  "title",
  "data-test-id",
  "data-testid",
  "disabled",
  "aria-disabled",
  "data-sentry-component"
]);
function getAttributesToRecord(attributes) {
  const obj = {};
  if (!attributes["data-sentry-component"] && attributes["data-sentry-element"]) {
    attributes["data-sentry-component"] = attributes["data-sentry-element"];
  }
  for (const key in attributes) {
    if (ATTRIBUTES_TO_RECORD.has(key)) {
      let normalizedKey = key;
      if (key === "data-testid" || key === "data-test-id") {
        normalizedKey = "testId";
      }
      obj[normalizedKey] = attributes[key];
    }
  }
  return obj;
}
__name(getAttributesToRecord, "getAttributesToRecord");
const handleDomListener = /* @__PURE__ */ __name((replay) => {
  return (handlerData) => {
    if (!replay.isEnabled()) {
      return;
    }
    const result = handleDom(handlerData);
    if (!result) {
      return;
    }
    const isClick = handlerData.name === "click";
    const event = isClick ? handlerData.event : void 0;
    if (isClick && replay.clickDetector && event && event.target && !event.altKey && !event.metaKey && !event.ctrlKey && !event.shiftKey) {
      handleClick$1(
        replay.clickDetector,
        result,
        getClickTargetNode(handlerData.event)
      );
    }
    addBreadcrumbEvent(replay, result);
  };
}, "handleDomListener");
function getBaseDomBreadcrumb(target2, message3) {
  const nodeId = record.mirror.getId(target2);
  const node3 = nodeId && record.mirror.getNode(nodeId);
  const meta = node3 && record.mirror.getMeta(node3);
  const element = meta && isElement$2(meta) ? meta : null;
  return {
    message: message3,
    data: element ? {
      nodeId,
      node: {
        id: nodeId,
        tagName: element.tagName,
        textContent: Array.from(element.childNodes).map((node4) => node4.type === NodeType$4.Text && node4.textContent).filter(Boolean).map((text2) => text2.trim()).join(""),
        attributes: getAttributesToRecord(element.attributes)
      }
    } : {}
  };
}
__name(getBaseDomBreadcrumb, "getBaseDomBreadcrumb");
function handleDom(handlerData) {
  const { target: target2, message: message3 } = getDomTarget(handlerData);
  return createBreadcrumb({
    category: `ui.${handlerData.name}`,
    ...getBaseDomBreadcrumb(target2, message3)
  });
}
__name(handleDom, "handleDom");
function getDomTarget(handlerData) {
  const isClick = handlerData.name === "click";
  let message3;
  let target2 = null;
  try {
    target2 = isClick ? getClickTargetNode(handlerData.event) : getTargetNode(handlerData.event);
    message3 = htmlTreeAsString(target2, { maxStringLength: 200 }) || "<unknown>";
  } catch (e2) {
    message3 = "<unknown>";
  }
  return { target: target2, message: message3 };
}
__name(getDomTarget, "getDomTarget");
function isElement$2(node3) {
  return node3.type === NodeType$4.Element;
}
__name(isElement$2, "isElement$2");
function handleKeyboardEvent(replay, event) {
  if (!replay.isEnabled()) {
    return;
  }
  replay.updateUserActivity();
  const breadcrumb = getKeyboardBreadcrumb(event);
  if (!breadcrumb) {
    return;
  }
  addBreadcrumbEvent(replay, breadcrumb);
}
__name(handleKeyboardEvent, "handleKeyboardEvent");
function getKeyboardBreadcrumb(event) {
  const { metaKey, shiftKey, ctrlKey, altKey, key, target: target2 } = event;
  if (!target2 || isInputElement(target2) || !key) {
    return null;
  }
  const hasModifierKey = metaKey || ctrlKey || altKey;
  const isCharacterKey = key.length === 1;
  if (!hasModifierKey && isCharacterKey) {
    return null;
  }
  const message3 = htmlTreeAsString(target2, { maxStringLength: 200 }) || "<unknown>";
  const baseBreadcrumb = getBaseDomBreadcrumb(target2, message3);
  return createBreadcrumb({
    category: "ui.keyDown",
    message: message3,
    data: {
      ...baseBreadcrumb.data,
      metaKey,
      shiftKey,
      ctrlKey,
      altKey,
      key
    }
  });
}
__name(getKeyboardBreadcrumb, "getKeyboardBreadcrumb");
function isInputElement(target2) {
  return target2.tagName === "INPUT" || target2.tagName === "TEXTAREA" || target2.isContentEditable;
}
__name(isInputElement, "isInputElement");
const ENTRY_TYPES = {
  // @ts-expect-error TODO: entry type does not fit the create* functions entry type
  resource: createResourceEntry,
  paint: createPaintEntry,
  // @ts-expect-error TODO: entry type does not fit the create* functions entry type
  navigation: createNavigationEntry
};
function webVitalHandler(getter, replay) {
  return ({ metric }) => void replay.replayPerformanceEntries.push(getter(metric));
}
__name(webVitalHandler, "webVitalHandler");
function createPerformanceEntries(entries) {
  return entries.map(createPerformanceEntry).filter(Boolean);
}
__name(createPerformanceEntries, "createPerformanceEntries");
function createPerformanceEntry(entry) {
  const entryType = ENTRY_TYPES[entry.entryType];
  if (!entryType) {
    return null;
  }
  return entryType(entry);
}
__name(createPerformanceEntry, "createPerformanceEntry");
function getAbsoluteTime$1(time) {
  return ((browserPerformanceTimeOrigin || WINDOW$1.performance.timeOrigin) + time) / 1e3;
}
__name(getAbsoluteTime$1, "getAbsoluteTime$1");
function createPaintEntry(entry) {
  const { duration, entryType, name: name2, startTime } = entry;
  const start2 = getAbsoluteTime$1(startTime);
  return {
    type: entryType,
    name: name2,
    start: start2,
    end: start2 + duration,
    data: void 0
  };
}
__name(createPaintEntry, "createPaintEntry");
function createNavigationEntry(entry) {
  const {
    entryType,
    name: name2,
    decodedBodySize,
    duration,
    domComplete,
    encodedBodySize,
    domContentLoadedEventStart,
    domContentLoadedEventEnd,
    domInteractive,
    loadEventStart,
    loadEventEnd,
    redirectCount,
    startTime,
    transferSize,
    type
  } = entry;
  if (duration === 0) {
    return null;
  }
  return {
    type: `${entryType}.${type}`,
    start: getAbsoluteTime$1(startTime),
    end: getAbsoluteTime$1(domComplete),
    name: name2,
    data: {
      size: transferSize,
      decodedBodySize,
      encodedBodySize,
      duration,
      domInteractive,
      domContentLoadedEventStart,
      domContentLoadedEventEnd,
      loadEventStart,
      loadEventEnd,
      domComplete,
      redirectCount
    }
  };
}
__name(createNavigationEntry, "createNavigationEntry");
function createResourceEntry(entry) {
  const {
    entryType,
    initiatorType,
    name: name2,
    responseEnd,
    startTime,
    decodedBodySize,
    encodedBodySize,
    responseStatus,
    transferSize
  } = entry;
  if (["fetch", "xmlhttprequest"].includes(initiatorType)) {
    return null;
  }
  return {
    type: `${entryType}.${initiatorType}`,
    start: getAbsoluteTime$1(startTime),
    end: getAbsoluteTime$1(responseEnd),
    name: name2,
    data: {
      size: transferSize,
      statusCode: responseStatus,
      decodedBodySize,
      encodedBodySize
    }
  };
}
__name(createResourceEntry, "createResourceEntry");
function getLargestContentfulPaint(metric) {
  const lastEntry = metric.entries[metric.entries.length - 1];
  const node3 = lastEntry && lastEntry.element ? [lastEntry.element] : void 0;
  return getWebVital(metric, "largest-contentful-paint", node3);
}
__name(getLargestContentfulPaint, "getLargestContentfulPaint");
function isLayoutShift(entry) {
  return entry.sources !== void 0;
}
__name(isLayoutShift, "isLayoutShift");
function getCumulativeLayoutShift(metric) {
  const layoutShifts = [];
  const nodes = [];
  for (const entry of metric.entries) {
    if (isLayoutShift(entry)) {
      const nodeIds = [];
      for (const source of entry.sources) {
        if (source.node) {
          nodes.push(source.node);
          const nodeId = record.mirror.getId(source.node);
          if (nodeId) {
            nodeIds.push(nodeId);
          }
        }
      }
      layoutShifts.push({ value: entry.value, nodeIds: nodeIds.length ? nodeIds : void 0 });
    }
  }
  return getWebVital(metric, "cumulative-layout-shift", nodes, layoutShifts);
}
__name(getCumulativeLayoutShift, "getCumulativeLayoutShift");
function getFirstInputDelay(metric) {
  const lastEntry = metric.entries[metric.entries.length - 1];
  const node3 = lastEntry && lastEntry.target ? [lastEntry.target] : void 0;
  return getWebVital(metric, "first-input-delay", node3);
}
__name(getFirstInputDelay, "getFirstInputDelay");
function getInteractionToNextPaint(metric) {
  const lastEntry = metric.entries[metric.entries.length - 1];
  const node3 = lastEntry && lastEntry.target ? [lastEntry.target] : void 0;
  return getWebVital(metric, "interaction-to-next-paint", node3);
}
__name(getInteractionToNextPaint, "getInteractionToNextPaint");
function getWebVital(metric, name2, nodes, attributions) {
  const value3 = metric.value;
  const rating = metric.rating;
  const end = getAbsoluteTime$1(value3);
  return {
    type: "web-vital",
    name: name2,
    start: end,
    end,
    data: {
      value: value3,
      size: value3,
      rating,
      nodeIds: nodes ? nodes.map((node3) => record.mirror.getId(node3)) : void 0,
      attributions
    }
  };
}
__name(getWebVital, "getWebVital");
function setupPerformanceObserver(replay) {
  function addPerformanceEntry(entry) {
    if (!replay.performanceEntries.includes(entry)) {
      replay.performanceEntries.push(entry);
    }
  }
  __name(addPerformanceEntry, "addPerformanceEntry");
  function onEntries({ entries }) {
    entries.forEach(addPerformanceEntry);
  }
  __name(onEntries, "onEntries");
  const clearCallbacks = [];
  ["navigation", "paint", "resource"].forEach((type) => {
    clearCallbacks.push(addPerformanceInstrumentationHandler(type, onEntries));
  });
  clearCallbacks.push(
    addLcpInstrumentationHandler(webVitalHandler(getLargestContentfulPaint, replay)),
    addClsInstrumentationHandler(webVitalHandler(getCumulativeLayoutShift, replay)),
    addFidInstrumentationHandler(webVitalHandler(getFirstInputDelay, replay)),
    addInpInstrumentationHandler(webVitalHandler(getInteractionToNextPaint, replay))
  );
  return () => {
    clearCallbacks.forEach((clearCallback) => clearCallback());
  };
}
__name(setupPerformanceObserver, "setupPerformanceObserver");
const DEBUG_BUILD$2 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
const r$3 = `var t=Uint8Array,n=Uint16Array,r=Int32Array,e=new t([0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0,0,0,0]),i=new t([0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13,0,0]),a=new t([16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15]),s=function(t,e){for(var i=new n(31),a=0;a<31;++a)i[a]=e+=1<<t[a-1];var s=new r(i[30]);for(a=1;a<30;++a)for(var o=i[a];o<i[a+1];++o)s[o]=o-i[a]<<5|a;return{b:i,r:s}},o=s(e,2),f=o.b,h=o.r;f[28]=258,h[258]=28;for(var l=s(i,0).r,u=new n(32768),c=0;c<32768;++c){var v=(43690&c)>>1|(21845&c)<<1;v=(61680&(v=(52428&v)>>2|(13107&v)<<2))>>4|(3855&v)<<4,u[c]=((65280&v)>>8|(255&v)<<8)>>1}var d=function(t,r,e){for(var i=t.length,a=0,s=new n(r);a<i;++a)t[a]&&++s[t[a]-1];var o,f=new n(r);for(a=1;a<r;++a)f[a]=f[a-1]+s[a-1]<<1;if(e){o=new n(1<<r);var h=15-r;for(a=0;a<i;++a)if(t[a])for(var l=a<<4|t[a],c=r-t[a],v=f[t[a]-1]++<<c,d=v|(1<<c)-1;v<=d;++v)o[u[v]>>h]=l}else for(o=new n(i),a=0;a<i;++a)t[a]&&(o[a]=u[f[t[a]-1]++]>>15-t[a]);return o},g=new t(288);for(c=0;c<144;++c)g[c]=8;for(c=144;c<256;++c)g[c]=9;for(c=256;c<280;++c)g[c]=7;for(c=280;c<288;++c)g[c]=8;var w=new t(32);for(c=0;c<32;++c)w[c]=5;var p=d(g,9,0),y=d(w,5,0),m=function(t){return(t+7)/8|0},b=function(n,r,e){return(null==e||e>n.length)&&(e=n.length),new t(n.subarray(r,e))},M=["unexpected EOF","invalid block type","invalid length/literal","invalid distance","stream finished","no stream handler",,"no callback","invalid UTF-8 data","extra field too long","date not in range 1980-2099","filename too long","stream finishing","invalid zip data"],E=function(t,n,r){var e=new Error(n||M[t]);if(e.code=t,Error.captureStackTrace&&Error.captureStackTrace(e,E),!r)throw e;return e},z=function(t,n,r){r<<=7&n;var e=n/8|0;t[e]|=r,t[e+1]|=r>>8},_=function(t,n,r){r<<=7&n;var e=n/8|0;t[e]|=r,t[e+1]|=r>>8,t[e+2]|=r>>16},x=function(r,e){for(var i=[],a=0;a<r.length;++a)r[a]&&i.push({s:a,f:r[a]});var s=i.length,o=i.slice();if(!s)return{t:F,l:0};if(1==s){var f=new t(i[0].s+1);return f[i[0].s]=1,{t:f,l:1}}i.sort((function(t,n){return t.f-n.f})),i.push({s:-1,f:25001});var h=i[0],l=i[1],u=0,c=1,v=2;for(i[0]={s:-1,f:h.f+l.f,l:h,r:l};c!=s-1;)h=i[i[u].f<i[v].f?u++:v++],l=i[u!=c&&i[u].f<i[v].f?u++:v++],i[c++]={s:-1,f:h.f+l.f,l:h,r:l};var d=o[0].s;for(a=1;a<s;++a)o[a].s>d&&(d=o[a].s);var g=new n(d+1),w=A(i[c-1],g,0);if(w>e){a=0;var p=0,y=w-e,m=1<<y;for(o.sort((function(t,n){return g[n.s]-g[t.s]||t.f-n.f}));a<s;++a){var b=o[a].s;if(!(g[b]>e))break;p+=m-(1<<w-g[b]),g[b]=e}for(p>>=y;p>0;){var M=o[a].s;g[M]<e?p-=1<<e-g[M]++-1:++a}for(;a>=0&&p;--a){var E=o[a].s;g[E]==e&&(--g[E],++p)}w=e}return{t:new t(g),l:w}},A=function(t,n,r){return-1==t.s?Math.max(A(t.l,n,r+1),A(t.r,n,r+1)):n[t.s]=r},D=function(t){for(var r=t.length;r&&!t[--r];);for(var e=new n(++r),i=0,a=t[0],s=1,o=function(t){e[i++]=t},f=1;f<=r;++f)if(t[f]==a&&f!=r)++s;else{if(!a&&s>2){for(;s>138;s-=138)o(32754);s>2&&(o(s>10?s-11<<5|28690:s-3<<5|12305),s=0)}else if(s>3){for(o(a),--s;s>6;s-=6)o(8304);s>2&&(o(s-3<<5|8208),s=0)}for(;s--;)o(a);s=1,a=t[f]}return{c:e.subarray(0,i),n:r}},T=function(t,n){for(var r=0,e=0;e<n.length;++e)r+=t[e]*n[e];return r},k=function(t,n,r){var e=r.length,i=m(n+2);t[i]=255&e,t[i+1]=e>>8,t[i+2]=255^t[i],t[i+3]=255^t[i+1];for(var a=0;a<e;++a)t[i+a+4]=r[a];return 8*(i+4+e)},U=function(t,r,s,o,f,h,l,u,c,v,m){z(r,m++,s),++f[256];for(var b=x(f,15),M=b.t,E=b.l,A=x(h,15),U=A.t,C=A.l,F=D(M),I=F.c,S=F.n,L=D(U),O=L.c,j=L.n,q=new n(19),B=0;B<I.length;++B)++q[31&I[B]];for(B=0;B<O.length;++B)++q[31&O[B]];for(var G=x(q,7),H=G.t,J=G.l,K=19;K>4&&!H[a[K-1]];--K);var N,P,Q,R,V=v+5<<3,W=T(f,g)+T(h,w)+l,X=T(f,M)+T(h,U)+l+14+3*K+T(q,H)+2*q[16]+3*q[17]+7*q[18];if(c>=0&&V<=W&&V<=X)return k(r,m,t.subarray(c,c+v));if(z(r,m,1+(X<W)),m+=2,X<W){N=d(M,E,0),P=M,Q=d(U,C,0),R=U;var Y=d(H,J,0);z(r,m,S-257),z(r,m+5,j-1),z(r,m+10,K-4),m+=14;for(B=0;B<K;++B)z(r,m+3*B,H[a[B]]);m+=3*K;for(var Z=[I,O],$=0;$<2;++$){var tt=Z[$];for(B=0;B<tt.length;++B){var nt=31&tt[B];z(r,m,Y[nt]),m+=H[nt],nt>15&&(z(r,m,tt[B]>>5&127),m+=tt[B]>>12)}}}else N=p,P=g,Q=y,R=w;for(B=0;B<u;++B){var rt=o[B];if(rt>255){_(r,m,N[(nt=rt>>18&31)+257]),m+=P[nt+257],nt>7&&(z(r,m,rt>>23&31),m+=e[nt]);var et=31&rt;_(r,m,Q[et]),m+=R[et],et>3&&(_(r,m,rt>>5&8191),m+=i[et])}else _(r,m,N[rt]),m+=P[rt]}return _(r,m,N[256]),m+P[256]},C=new r([65540,131080,131088,131104,262176,1048704,1048832,2114560,2117632]),F=new t(0),I=function(){for(var t=new Int32Array(256),n=0;n<256;++n){for(var r=n,e=9;--e;)r=(1&r&&-306674912)^r>>>1;t[n]=r}return t}(),S=function(){var t=-1;return{p:function(n){for(var r=t,e=0;e<n.length;++e)r=I[255&r^n[e]]^r>>>8;t=r},d:function(){return~t}}},L=function(){var t=1,n=0;return{p:function(r){for(var e=t,i=n,a=0|r.length,s=0;s!=a;){for(var o=Math.min(s+2655,a);s<o;++s)i+=e+=r[s];e=(65535&e)+15*(e>>16),i=(65535&i)+15*(i>>16)}t=e,n=i},d:function(){return(255&(t%=65521))<<24|(65280&t)<<8|(255&(n%=65521))<<8|n>>8}}},O=function(a,s,o,f,u){if(!u&&(u={l:1},s.dictionary)){var c=s.dictionary.subarray(-32768),v=new t(c.length+a.length);v.set(c),v.set(a,c.length),a=v,u.w=c.length}return function(a,s,o,f,u,c){var v=c.z||a.length,d=new t(f+v+5*(1+Math.ceil(v/7e3))+u),g=d.subarray(f,d.length-u),w=c.l,p=7&(c.r||0);if(s){p&&(g[0]=c.r>>3);for(var y=C[s-1],M=y>>13,E=8191&y,z=(1<<o)-1,_=c.p||new n(32768),x=c.h||new n(z+1),A=Math.ceil(o/3),D=2*A,T=function(t){return(a[t]^a[t+1]<<A^a[t+2]<<D)&z},F=new r(25e3),I=new n(288),S=new n(32),L=0,O=0,j=c.i||0,q=0,B=c.w||0,G=0;j+2<v;++j){var H=T(j),J=32767&j,K=x[H];if(_[J]=K,x[H]=J,B<=j){var N=v-j;if((L>7e3||q>24576)&&(N>423||!w)){p=U(a,g,0,F,I,S,O,q,G,j-G,p),q=L=O=0,G=j;for(var P=0;P<286;++P)I[P]=0;for(P=0;P<30;++P)S[P]=0}var Q=2,R=0,V=E,W=J-K&32767;if(N>2&&H==T(j-W))for(var X=Math.min(M,N)-1,Y=Math.min(32767,j),Z=Math.min(258,N);W<=Y&&--V&&J!=K;){if(a[j+Q]==a[j+Q-W]){for(var $=0;$<Z&&a[j+$]==a[j+$-W];++$);if($>Q){if(Q=$,R=W,$>X)break;var tt=Math.min(W,$-2),nt=0;for(P=0;P<tt;++P){var rt=j-W+P&32767,et=rt-_[rt]&32767;et>nt&&(nt=et,K=rt)}}}W+=(J=K)-(K=_[J])&32767}if(R){F[q++]=268435456|h[Q]<<18|l[R];var it=31&h[Q],at=31&l[R];O+=e[it]+i[at],++I[257+it],++S[at],B=j+Q,++L}else F[q++]=a[j],++I[a[j]]}}for(j=Math.max(j,B);j<v;++j)F[q++]=a[j],++I[a[j]];p=U(a,g,w,F,I,S,O,q,G,j-G,p),w||(c.r=7&p|g[p/8|0]<<3,p-=7,c.h=x,c.p=_,c.i=j,c.w=B)}else{for(j=c.w||0;j<v+w;j+=65535){var st=j+65535;st>=v&&(g[p/8|0]=w,st=v),p=k(g,p+1,a.subarray(j,st))}c.i=v}return b(d,0,f+m(p)+u)}(a,null==s.level?6:s.level,null==s.mem?Math.ceil(1.5*Math.max(8,Math.min(13,Math.log(a.length)))):12+s.mem,o,f,u)},j=function(t,n,r){for(;r;++n)t[n]=r,r>>>=8},q=function(t,n){var r=n.filename;if(t[0]=31,t[1]=139,t[2]=8,t[8]=n.level<2?4:9==n.level?2:0,t[9]=3,0!=n.mtime&&j(t,4,Math.floor(new Date(n.mtime||Date.now())/1e3)),r){t[3]=8;for(var e=0;e<=r.length;++e)t[e+10]=r.charCodeAt(e)}},B=function(t){return 10+(t.filename?t.filename.length+1:0)},G=function(){function n(n,r){if("function"==typeof n&&(r=n,n={}),this.ondata=r,this.o=n||{},this.s={l:0,i:32768,w:32768,z:32768},this.b=new t(98304),this.o.dictionary){var e=this.o.dictionary.subarray(-32768);this.b.set(e,32768-e.length),this.s.i=32768-e.length}}return n.prototype.p=function(t,n){this.ondata(O(t,this.o,0,0,this.s),n)},n.prototype.push=function(n,r){this.ondata||E(5),this.s.l&&E(4);var e=n.length+this.s.z;if(e>this.b.length){if(e>2*this.b.length-32768){var i=new t(-32768&e);i.set(this.b.subarray(0,this.s.z)),this.b=i}var a=this.b.length-this.s.z;a&&(this.b.set(n.subarray(0,a),this.s.z),this.s.z=this.b.length,this.p(this.b,!1)),this.b.set(this.b.subarray(-32768)),this.b.set(n.subarray(a),32768),this.s.z=n.length-a+32768,this.s.i=32766,this.s.w=32768}else this.b.set(n,this.s.z),this.s.z+=n.length;this.s.l=1&r,(this.s.z>this.s.w+8191||r)&&(this.p(this.b,r||!1),this.s.w=this.s.i,this.s.i-=2)},n}();var H=function(){function t(t,n){this.c=L(),this.v=1,G.call(this,t,n)}return t.prototype.push=function(t,n){this.c.p(t),G.prototype.push.call(this,t,n)},t.prototype.p=function(t,n){var r=O(t,this.o,this.v&&(this.o.dictionary?6:2),n&&4,this.s);this.v&&(function(t,n){var r=n.level,e=0==r?0:r<6?1:9==r?3:2;if(t[0]=120,t[1]=e<<6|(n.dictionary&&32),t[1]|=31-(t[0]<<8|t[1])%31,n.dictionary){var i=L();i.p(n.dictionary),j(t,2,i.d())}}(r,this.o),this.v=0),n&&j(r,r.length-4,this.c.d()),this.ondata(r,n)},t}(),J="undefined"!=typeof TextEncoder&&new TextEncoder,K="undefined"!=typeof TextDecoder&&new TextDecoder;try{K.decode(F,{stream:!0})}catch(t){}var N=function(){function t(t){this.ondata=t}return t.prototype.push=function(t,n){this.ondata||E(5),this.d&&E(4),this.ondata(P(t),this.d=n||!1)},t}();function P(n,r){if(J)return J.encode(n);for(var e=n.length,i=new t(n.length+(n.length>>1)),a=0,s=function(t){i[a++]=t},o=0;o<e;++o){if(a+5>i.length){var f=new t(a+8+(e-o<<1));f.set(i),i=f}var h=n.charCodeAt(o);h<128||r?s(h):h<2048?(s(192|h>>6),s(128|63&h)):h>55295&&h<57344?(s(240|(h=65536+(1047552&h)|1023&n.charCodeAt(++o))>>18),s(128|h>>12&63),s(128|h>>6&63),s(128|63&h)):(s(224|h>>12),s(128|h>>6&63),s(128|63&h))}return b(i,0,a)}function Q(t){return function(t,n){n||(n={});var r=S(),e=t.length;r.p(t);var i=O(t,n,B(n),8),a=i.length;return q(i,n),j(i,a-8,r.d()),j(i,a-4,e),i}(P(t))}const R=new class{constructor(){this._init()}clear(){this._init()}addEvent(t){if(!t)throw new Error("Adding invalid event");const n=this._hasEvents?",":"";this.stream.push(n+t),this._hasEvents=!0}finish(){this.stream.push("]",!0);const t=function(t){let n=0;for(const r of t)n+=r.length;const r=new Uint8Array(n);for(let n=0,e=0,i=t.length;n<i;n++){const i=t[n];r.set(i,e),e+=i.length}return r}(this._deflatedData);return this._init(),t}_init(){this._hasEvents=!1,this._deflatedData=[],this.deflate=new H,this.deflate.ondata=(t,n)=>{this._deflatedData.push(t)},this.stream=new N(((t,n)=>{this.deflate.push(t,n)})),this.stream.push("[")}},V={clear:()=>{R.clear()},addEvent:t=>R.addEvent(t),finish:()=>R.finish(),compress:t=>Q(t)};addEventListener("message",(function(t){const n=t.data.method,r=t.data.id,e=t.data.arg;if(n in V&&"function"==typeof V[n])try{const t=V[n](e);postMessage({id:r,method:n,success:!0,response:t})}catch(t){postMessage({id:r,method:n,success:!1,response:t.message}),console.error(t)}})),postMessage({id:void 0,method:"init",success:!0,response:void 0});`;
function e$1() {
  const e2 = new Blob([r$3]);
  return URL.createObjectURL(e2);
}
__name(e$1, "e$1");
const CONSOLE_LEVELS = ["info", "warn", "error", "log"];
const PREFIX$1 = "[Replay] ";
function _addBreadcrumb(message3, level = "info") {
  addBreadcrumb(
    {
      category: "console",
      data: {
        logger: "replay"
      },
      level,
      message: `${PREFIX$1}${message3}`
    },
    { level }
  );
}
__name(_addBreadcrumb, "_addBreadcrumb");
function makeReplayLogger() {
  let _capture = false;
  let _trace = false;
  const _logger = {
    exception: /* @__PURE__ */ __name(() => void 0, "exception"),
    infoTick: /* @__PURE__ */ __name(() => void 0, "infoTick"),
    setConfig: /* @__PURE__ */ __name((opts) => {
      _capture = opts.captureExceptions;
      _trace = opts.traceInternals;
    }, "setConfig")
  };
  if (DEBUG_BUILD$2) {
    CONSOLE_LEVELS.forEach((name2) => {
      _logger[name2] = (...args) => {
        logger$2[name2](PREFIX$1, ...args);
        if (_trace) {
          _addBreadcrumb(args.join(""), severityLevelFromString(name2));
        }
      };
    });
    _logger.exception = (error2, ...message3) => {
      if (message3.length && _logger.error) {
        _logger.error(...message3);
      }
      logger$2.error(PREFIX$1, error2);
      if (_capture) {
        captureException(error2);
      } else if (_trace) {
        _addBreadcrumb(error2, "error");
      }
    };
    _logger.infoTick = (...args) => {
      logger$2.info(PREFIX$1, ...args);
      if (_trace) {
        setTimeout(() => _addBreadcrumb(args[0]), 0);
      }
    };
  } else {
    CONSOLE_LEVELS.forEach((name2) => {
      _logger[name2] = () => void 0;
    });
  }
  return _logger;
}
__name(makeReplayLogger, "makeReplayLogger");
const logger$1 = makeReplayLogger();
class EventBufferSizeExceededError extends Error {
  static {
    __name(this, "EventBufferSizeExceededError");
  }
  constructor() {
    super(`Event buffer exceeded maximum size of ${REPLAY_MAX_EVENT_BUFFER_SIZE}.`);
  }
}
class EventBufferArray {
  static {
    __name(this, "EventBufferArray");
  }
  /** All the events that are buffered to be sent. */
  /** @inheritdoc */
  /** @inheritdoc */
  constructor() {
    this.events = [];
    this._totalSize = 0;
    this.hasCheckout = false;
    this.waitForCheckout = false;
  }
  /** @inheritdoc */
  get hasEvents() {
    return this.events.length > 0;
  }
  /** @inheritdoc */
  get type() {
    return "sync";
  }
  /** @inheritdoc */
  destroy() {
    this.events = [];
  }
  /** @inheritdoc */
  async addEvent(event) {
    const eventSize = JSON.stringify(event).length;
    this._totalSize += eventSize;
    if (this._totalSize > REPLAY_MAX_EVENT_BUFFER_SIZE) {
      throw new EventBufferSizeExceededError();
    }
    this.events.push(event);
  }
  /** @inheritdoc */
  finish() {
    return new Promise((resolve2) => {
      const eventsRet = this.events;
      this.clear();
      resolve2(JSON.stringify(eventsRet));
    });
  }
  /** @inheritdoc */
  clear() {
    this.events = [];
    this._totalSize = 0;
    this.hasCheckout = false;
  }
  /** @inheritdoc */
  getEarliestTimestamp() {
    const timestamp2 = this.events.map((event) => event.timestamp).sort()[0];
    if (!timestamp2) {
      return null;
    }
    return timestampToMs(timestamp2);
  }
}
class WorkerHandler {
  static {
    __name(this, "WorkerHandler");
  }
  constructor(worker) {
    this._worker = worker;
    this._id = 0;
  }
  /**
   * Ensure the worker is ready (or not).
   * This will either resolve when the worker is ready, or reject if an error occurred.
   */
  ensureReady() {
    if (this._ensureReadyPromise) {
      return this._ensureReadyPromise;
    }
    this._ensureReadyPromise = new Promise((resolve2, reject3) => {
      this._worker.addEventListener(
        "message",
        ({ data: data30 }) => {
          if (data30.success) {
            resolve2();
          } else {
            reject3();
          }
        },
        { once: true }
      );
      this._worker.addEventListener(
        "error",
        (error2) => {
          reject3(error2);
        },
        { once: true }
      );
    });
    return this._ensureReadyPromise;
  }
  /**
   * Destroy the worker.
   */
  destroy() {
    DEBUG_BUILD$2 && logger$1.info("Destroying compression worker");
    this._worker.terminate();
  }
  /**
   * Post message to worker and wait for response before resolving promise.
   */
  postMessage(method, arg) {
    const id4 = this._getAndIncrementId();
    return new Promise((resolve2, reject3) => {
      const listener = /* @__PURE__ */ __name(({ data: data30 }) => {
        const response = data30;
        if (response.method !== method) {
          return;
        }
        if (response.id !== id4) {
          return;
        }
        this._worker.removeEventListener("message", listener);
        if (!response.success) {
          DEBUG_BUILD$2 && logger$1.error("Error in compression worker: ", response.response);
          reject3(new Error("Error in compression worker"));
          return;
        }
        resolve2(response.response);
      }, "listener");
      this._worker.addEventListener("message", listener);
      this._worker.postMessage({ id: id4, method, arg });
    });
  }
  /** Get the current ID and increment it for the next call. */
  _getAndIncrementId() {
    return this._id++;
  }
}
class EventBufferCompressionWorker {
  static {
    __name(this, "EventBufferCompressionWorker");
  }
  /** @inheritdoc */
  /** @inheritdoc */
  constructor(worker) {
    this._worker = new WorkerHandler(worker);
    this._earliestTimestamp = null;
    this._totalSize = 0;
    this.hasCheckout = false;
    this.waitForCheckout = false;
  }
  /** @inheritdoc */
  get hasEvents() {
    return !!this._earliestTimestamp;
  }
  /** @inheritdoc */
  get type() {
    return "worker";
  }
  /**
   * Ensure the worker is ready (or not).
   * This will either resolve when the worker is ready, or reject if an error occurred.
   */
  ensureReady() {
    return this._worker.ensureReady();
  }
  /**
   * Destroy the event buffer.
   */
  destroy() {
    this._worker.destroy();
  }
  /**
   * Add an event to the event buffer.
   *
   * Returns true if event was successfully received and processed by worker.
   */
  addEvent(event) {
    const timestamp2 = timestampToMs(event.timestamp);
    if (!this._earliestTimestamp || timestamp2 < this._earliestTimestamp) {
      this._earliestTimestamp = timestamp2;
    }
    const data30 = JSON.stringify(event);
    this._totalSize += data30.length;
    if (this._totalSize > REPLAY_MAX_EVENT_BUFFER_SIZE) {
      return Promise.reject(new EventBufferSizeExceededError());
    }
    return this._sendEventToWorker(data30);
  }
  /**
   * Finish the event buffer and return the compressed data.
   */
  finish() {
    return this._finishRequest();
  }
  /** @inheritdoc */
  clear() {
    this._earliestTimestamp = null;
    this._totalSize = 0;
    this.hasCheckout = false;
    this._worker.postMessage("clear").then(null, (e2) => {
      DEBUG_BUILD$2 && logger$1.exception(e2, 'Sending "clear" message to worker failed', e2);
    });
  }
  /** @inheritdoc */
  getEarliestTimestamp() {
    return this._earliestTimestamp;
  }
  /**
   * Send the event to the worker.
   */
  _sendEventToWorker(data30) {
    return this._worker.postMessage("addEvent", data30);
  }
  /**
   * Finish the request and return the compressed data from the worker.
   */
  async _finishRequest() {
    const response = await this._worker.postMessage("finish");
    this._earliestTimestamp = null;
    this._totalSize = 0;
    return response;
  }
}
class EventBufferProxy {
  static {
    __name(this, "EventBufferProxy");
  }
  constructor(worker) {
    this._fallback = new EventBufferArray();
    this._compression = new EventBufferCompressionWorker(worker);
    this._used = this._fallback;
    this._ensureWorkerIsLoadedPromise = this._ensureWorkerIsLoaded();
  }
  /** @inheritdoc */
  get waitForCheckout() {
    return this._used.waitForCheckout;
  }
  /** @inheritdoc */
  get type() {
    return this._used.type;
  }
  /** @inheritDoc */
  get hasEvents() {
    return this._used.hasEvents;
  }
  /** @inheritdoc */
  get hasCheckout() {
    return this._used.hasCheckout;
  }
  /** @inheritdoc */
  set hasCheckout(value3) {
    this._used.hasCheckout = value3;
  }
  /** @inheritdoc */
  // eslint-disable-next-line @typescript-eslint/adjacent-overload-signatures
  set waitForCheckout(value3) {
    this._used.waitForCheckout = value3;
  }
  /** @inheritDoc */
  destroy() {
    this._fallback.destroy();
    this._compression.destroy();
  }
  /** @inheritdoc */
  clear() {
    return this._used.clear();
  }
  /** @inheritdoc */
  getEarliestTimestamp() {
    return this._used.getEarliestTimestamp();
  }
  /**
   * Add an event to the event buffer.
   *
   * Returns true if event was successfully added.
   */
  addEvent(event) {
    return this._used.addEvent(event);
  }
  /** @inheritDoc */
  async finish() {
    await this.ensureWorkerIsLoaded();
    return this._used.finish();
  }
  /** Ensure the worker has loaded. */
  ensureWorkerIsLoaded() {
    return this._ensureWorkerIsLoadedPromise;
  }
  /** Actually check if the worker has been loaded. */
  async _ensureWorkerIsLoaded() {
    try {
      await this._compression.ensureReady();
    } catch (error2) {
      DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to load the compression worker, falling back to simple buffer");
      return;
    }
    await this._switchToCompressionWorker();
  }
  /** Switch the used buffer to the compression worker. */
  async _switchToCompressionWorker() {
    const { events: events2, hasCheckout, waitForCheckout } = this._fallback;
    const addEventPromises = [];
    for (const event of events2) {
      addEventPromises.push(this._compression.addEvent(event));
    }
    this._compression.hasCheckout = hasCheckout;
    this._compression.waitForCheckout = waitForCheckout;
    this._used = this._compression;
    try {
      await Promise.all(addEventPromises);
      this._fallback.clear();
    } catch (error2) {
      DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to add events when switching buffers.");
    }
  }
}
function createEventBuffer({
  useCompression,
  workerUrl: customWorkerUrl
}) {
  if (useCompression && // eslint-disable-next-line no-restricted-globals
  window.Worker) {
    const worker = _loadWorker(customWorkerUrl);
    if (worker) {
      return worker;
    }
  }
  DEBUG_BUILD$2 && logger$1.info("Using simple buffer");
  return new EventBufferArray();
}
__name(createEventBuffer, "createEventBuffer");
function _loadWorker(customWorkerUrl) {
  try {
    const workerUrl = customWorkerUrl || _getWorkerUrl();
    if (!workerUrl) {
      return;
    }
    DEBUG_BUILD$2 && logger$1.info(`Using compression worker${customWorkerUrl ? ` from ${customWorkerUrl}` : ""}`);
    const worker = new Worker(workerUrl);
    return new EventBufferProxy(worker);
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to create compression worker");
  }
}
__name(_loadWorker, "_loadWorker");
function _getWorkerUrl() {
  if (typeof __SENTRY_EXCLUDE_REPLAY_WORKER__ === "undefined" || !__SENTRY_EXCLUDE_REPLAY_WORKER__) {
    return e$1();
  }
  return "";
}
__name(_getWorkerUrl, "_getWorkerUrl");
function hasSessionStorage() {
  try {
    return "sessionStorage" in WINDOW$1 && !!WINDOW$1.sessionStorage;
  } catch (e2) {
    return false;
  }
}
__name(hasSessionStorage, "hasSessionStorage");
function clearSession(replay) {
  deleteSession();
  replay.session = void 0;
}
__name(clearSession, "clearSession");
function deleteSession() {
  if (!hasSessionStorage()) {
    return;
  }
  try {
    WINDOW$1.sessionStorage.removeItem(REPLAY_SESSION_KEY);
  } catch (e2) {
  }
}
__name(deleteSession, "deleteSession");
function isSampled(sampleRate) {
  if (sampleRate === void 0) {
    return false;
  }
  return Math.random() < sampleRate;
}
__name(isSampled, "isSampled");
function makeSession(session) {
  const now2 = Date.now();
  const id4 = session.id || uuid4();
  const started = session.started || now2;
  const lastActivity = session.lastActivity || now2;
  const segmentId = session.segmentId || 0;
  const sampled = session.sampled;
  const previousSessionId = session.previousSessionId;
  return {
    id: id4,
    started,
    lastActivity,
    segmentId,
    sampled,
    previousSessionId
  };
}
__name(makeSession, "makeSession");
function saveSession(session) {
  if (!hasSessionStorage()) {
    return;
  }
  try {
    WINDOW$1.sessionStorage.setItem(REPLAY_SESSION_KEY, JSON.stringify(session));
  } catch (e2) {
  }
}
__name(saveSession, "saveSession");
function getSessionSampleType(sessionSampleRate, allowBuffering) {
  return isSampled(sessionSampleRate) ? "session" : allowBuffering ? "buffer" : false;
}
__name(getSessionSampleType, "getSessionSampleType");
function createSession({ sessionSampleRate, allowBuffering, stickySession = false }, { previousSessionId } = {}) {
  const sampled = getSessionSampleType(sessionSampleRate, allowBuffering);
  const session = makeSession({
    sampled,
    previousSessionId
  });
  if (stickySession) {
    saveSession(session);
  }
  return session;
}
__name(createSession, "createSession");
function fetchSession() {
  if (!hasSessionStorage()) {
    return null;
  }
  try {
    const sessionStringFromStorage = WINDOW$1.sessionStorage.getItem(REPLAY_SESSION_KEY);
    if (!sessionStringFromStorage) {
      return null;
    }
    const sessionObj = JSON.parse(sessionStringFromStorage);
    DEBUG_BUILD$2 && logger$1.infoTick("Loading existing session");
    return makeSession(sessionObj);
  } catch (e2) {
    return null;
  }
}
__name(fetchSession, "fetchSession");
function isExpired(initialTime, expiry, targetTime = +/* @__PURE__ */ new Date()) {
  if (initialTime === null || expiry === void 0 || expiry < 0) {
    return true;
  }
  if (expiry === 0) {
    return false;
  }
  return initialTime + expiry <= targetTime;
}
__name(isExpired, "isExpired");
function isSessionExpired(session, {
  maxReplayDuration,
  sessionIdleExpire,
  targetTime = Date.now()
}) {
  return (
    // First, check that maximum session length has not been exceeded
    isExpired(session.started, maxReplayDuration, targetTime) || // check that the idle timeout has not been exceeded (i.e. user has
    // performed an action within the last `sessionIdleExpire` ms)
    isExpired(session.lastActivity, sessionIdleExpire, targetTime)
  );
}
__name(isSessionExpired, "isSessionExpired");
function shouldRefreshSession(session, { sessionIdleExpire, maxReplayDuration }) {
  if (!isSessionExpired(session, { sessionIdleExpire, maxReplayDuration })) {
    return false;
  }
  if (session.sampled === "buffer" && session.segmentId === 0) {
    return false;
  }
  return true;
}
__name(shouldRefreshSession, "shouldRefreshSession");
function loadOrCreateSession({
  sessionIdleExpire,
  maxReplayDuration,
  previousSessionId
}, sessionOptions) {
  const existingSession = sessionOptions.stickySession && fetchSession();
  if (!existingSession) {
    DEBUG_BUILD$2 && logger$1.infoTick("Creating new session");
    return createSession(sessionOptions, { previousSessionId });
  }
  if (!shouldRefreshSession(existingSession, { sessionIdleExpire, maxReplayDuration })) {
    return existingSession;
  }
  DEBUG_BUILD$2 && logger$1.infoTick("Session in sessionStorage is expired, creating new one...");
  return createSession(sessionOptions, { previousSessionId: existingSession.id });
}
__name(loadOrCreateSession, "loadOrCreateSession");
function isCustomEvent(event) {
  return event.type === EventType.Custom;
}
__name(isCustomEvent, "isCustomEvent");
function addEventSync(replay, event, isCheckout) {
  if (!shouldAddEvent(replay, event)) {
    return false;
  }
  _addEvent(replay, event, isCheckout);
  return true;
}
__name(addEventSync, "addEventSync");
function addEvent(replay, event, isCheckout) {
  if (!shouldAddEvent(replay, event)) {
    return Promise.resolve(null);
  }
  return _addEvent(replay, event, isCheckout);
}
__name(addEvent, "addEvent");
async function _addEvent(replay, event, isCheckout) {
  const { eventBuffer } = replay;
  if (!eventBuffer || eventBuffer.waitForCheckout && !isCheckout) {
    return null;
  }
  const isBufferMode = replay.recordingMode === "buffer";
  try {
    if (isCheckout && isBufferMode) {
      eventBuffer.clear();
    }
    if (isCheckout) {
      eventBuffer.hasCheckout = true;
      eventBuffer.waitForCheckout = false;
    }
    const replayOptions = replay.getOptions();
    const eventAfterPossibleCallback = maybeApplyCallback(event, replayOptions.beforeAddRecordingEvent);
    if (!eventAfterPossibleCallback) {
      return;
    }
    return await eventBuffer.addEvent(eventAfterPossibleCallback);
  } catch (error2) {
    const isExceeded = error2 && error2 instanceof EventBufferSizeExceededError;
    const reason = isExceeded ? "addEventSizeExceeded" : "addEvent";
    if (isExceeded && isBufferMode) {
      eventBuffer.clear();
      eventBuffer.waitForCheckout = true;
      return null;
    }
    replay.handleException(error2);
    await replay.stop({ reason });
    const client = getClient();
    if (client) {
      client.recordDroppedEvent("internal_sdk_error", "replay");
    }
  }
}
__name(_addEvent, "_addEvent");
function shouldAddEvent(replay, event) {
  if (!replay.eventBuffer || replay.isPaused() || !replay.isEnabled()) {
    return false;
  }
  const timestampInMs = timestampToMs(event.timestamp);
  if (timestampInMs + replay.timeouts.sessionIdlePause < Date.now()) {
    return false;
  }
  if (timestampInMs > replay.getContext().initialTimestamp + replay.getOptions().maxReplayDuration) {
    DEBUG_BUILD$2 && logger$1.infoTick(`Skipping event with timestamp ${timestampInMs} because it is after maxReplayDuration`);
    return false;
  }
  return true;
}
__name(shouldAddEvent, "shouldAddEvent");
function maybeApplyCallback(event, callback) {
  try {
    if (typeof callback === "function" && isCustomEvent(event)) {
      return callback(event);
    }
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "An error occurred in the `beforeAddRecordingEvent` callback, skipping the event...");
    return null;
  }
  return event;
}
__name(maybeApplyCallback, "maybeApplyCallback");
function isErrorEvent(event) {
  return !event.type;
}
__name(isErrorEvent, "isErrorEvent");
function isTransactionEvent(event) {
  return event.type === "transaction";
}
__name(isTransactionEvent, "isTransactionEvent");
function isReplayEvent(event) {
  return event.type === "replay_event";
}
__name(isReplayEvent, "isReplayEvent");
function isFeedbackEvent(event) {
  return event.type === "feedback";
}
__name(isFeedbackEvent, "isFeedbackEvent");
function handleAfterSendEvent(replay) {
  return (event, sendResponse) => {
    if (!replay.isEnabled() || !isErrorEvent(event) && !isTransactionEvent(event)) {
      return;
    }
    const statusCode = sendResponse && sendResponse.statusCode;
    if (!statusCode || statusCode < 200 || statusCode >= 300) {
      return;
    }
    if (isTransactionEvent(event)) {
      handleTransactionEvent(replay, event);
      return;
    }
    handleErrorEvent(replay, event);
  };
}
__name(handleAfterSendEvent, "handleAfterSendEvent");
function handleTransactionEvent(replay, event) {
  const replayContext = replay.getContext();
  if (event.contexts && event.contexts.trace && event.contexts.trace.trace_id && replayContext.traceIds.size < 100) {
    replayContext.traceIds.add(event.contexts.trace.trace_id);
  }
}
__name(handleTransactionEvent, "handleTransactionEvent");
function handleErrorEvent(replay, event) {
  const replayContext = replay.getContext();
  if (event.event_id && replayContext.errorIds.size < 100) {
    replayContext.errorIds.add(event.event_id);
  }
  if (replay.recordingMode !== "buffer" || !event.tags || !event.tags.replayId) {
    return;
  }
  const { beforeErrorSampling } = replay.getOptions();
  if (typeof beforeErrorSampling === "function" && !beforeErrorSampling(event)) {
    return;
  }
  setTimeout$3(async () => {
    try {
      await replay.sendBufferedReplayOrFlush();
    } catch (err) {
      replay.handleException(err);
    }
  });
}
__name(handleErrorEvent, "handleErrorEvent");
function handleBeforeSendEvent(replay) {
  return (event) => {
    if (!replay.isEnabled() || !isErrorEvent(event)) {
      return;
    }
    handleHydrationError(replay, event);
  };
}
__name(handleBeforeSendEvent, "handleBeforeSendEvent");
function handleHydrationError(replay, event) {
  const exceptionValue = event.exception && event.exception.values && event.exception.values[0] && event.exception.values[0].value;
  if (typeof exceptionValue !== "string") {
    return;
  }
  if (
    // Only matches errors in production builds of react-dom
    // Example https://reactjs.org/docs/error-decoder.html?invariant=423
    // With newer React versions, the messages changed to a different website https://react.dev/errors/418
    exceptionValue.match(
      /(reactjs\.org\/docs\/error-decoder\.html\?invariant=|react\.dev\/errors\/)(418|419|422|423|425)/
    ) || // Development builds of react-dom
    // Error 1: Hydration failed because the initial UI does not match what was rendered on the server.
    // Error 2: Text content does not match server-rendered HTML. Warning: Text content did not match.
    exceptionValue.match(/(does not match server-rendered HTML|Hydration failed because)/i)
  ) {
    const breadcrumb = createBreadcrumb({
      category: "replay.hydrate-error",
      data: {
        url: getLocationHref()
      }
    });
    addBreadcrumbEvent(replay, breadcrumb);
  }
}
__name(handleHydrationError, "handleHydrationError");
function handleBreadcrumbs(replay) {
  const client = getClient();
  if (!client) {
    return;
  }
  client.on("beforeAddBreadcrumb", (breadcrumb) => beforeAddBreadcrumb(replay, breadcrumb));
}
__name(handleBreadcrumbs, "handleBreadcrumbs");
function beforeAddBreadcrumb(replay, breadcrumb) {
  if (!replay.isEnabled() || !isBreadcrumbWithCategory(breadcrumb)) {
    return;
  }
  const result = normalizeBreadcrumb(breadcrumb);
  if (result) {
    addBreadcrumbEvent(replay, result);
  }
}
__name(beforeAddBreadcrumb, "beforeAddBreadcrumb");
function normalizeBreadcrumb(breadcrumb) {
  if (!isBreadcrumbWithCategory(breadcrumb) || [
    // fetch & xhr are handled separately,in handleNetworkBreadcrumbs
    "fetch",
    "xhr",
    // These two are breadcrumbs for emitted sentry events, we don't care about them
    "sentry.event",
    "sentry.transaction"
  ].includes(breadcrumb.category) || // We capture UI breadcrumbs separately
  breadcrumb.category.startsWith("ui.")) {
    return null;
  }
  if (breadcrumb.category === "console") {
    return normalizeConsoleBreadcrumb(breadcrumb);
  }
  return createBreadcrumb(breadcrumb);
}
__name(normalizeBreadcrumb, "normalizeBreadcrumb");
function normalizeConsoleBreadcrumb(breadcrumb) {
  const args = breadcrumb.data && breadcrumb.data.arguments;
  if (!Array.isArray(args) || args.length === 0) {
    return createBreadcrumb(breadcrumb);
  }
  let isTruncated = false;
  const normalizedArgs = args.map((arg) => {
    if (!arg) {
      return arg;
    }
    if (typeof arg === "string") {
      if (arg.length > CONSOLE_ARG_MAX_SIZE) {
        isTruncated = true;
        return `${arg.slice(0, CONSOLE_ARG_MAX_SIZE)}…`;
      }
      return arg;
    }
    if (typeof arg === "object") {
      try {
        const normalizedArg = normalize$2(arg, 7);
        const stringified = JSON.stringify(normalizedArg);
        if (stringified.length > CONSOLE_ARG_MAX_SIZE) {
          isTruncated = true;
          return `${JSON.stringify(normalizedArg, null, 2).slice(0, CONSOLE_ARG_MAX_SIZE)}…`;
        }
        return normalizedArg;
      } catch (e2) {
      }
    }
    return arg;
  });
  return createBreadcrumb({
    ...breadcrumb,
    data: {
      ...breadcrumb.data,
      arguments: normalizedArgs,
      ...isTruncated ? { _meta: { warnings: ["CONSOLE_ARG_TRUNCATED"] } } : {}
    }
  });
}
__name(normalizeConsoleBreadcrumb, "normalizeConsoleBreadcrumb");
function isBreadcrumbWithCategory(breadcrumb) {
  return !!breadcrumb.category;
}
__name(isBreadcrumbWithCategory, "isBreadcrumbWithCategory");
function isRrwebError(event, hint) {
  if (event.type || !event.exception || !event.exception.values || !event.exception.values.length) {
    return false;
  }
  if (hint.originalException && hint.originalException.__rrweb__) {
    return true;
  }
  return false;
}
__name(isRrwebError, "isRrwebError");
function resetReplayIdOnDynamicSamplingContext() {
  const dsc = getCurrentScope$1().getPropagationContext().dsc;
  if (dsc) {
    delete dsc.replay_id;
  }
  const activeSpan = getActiveSpan();
  if (activeSpan) {
    const dsc2 = getDynamicSamplingContextFromSpan(activeSpan);
    delete dsc2.replay_id;
  }
}
__name(resetReplayIdOnDynamicSamplingContext, "resetReplayIdOnDynamicSamplingContext");
function addFeedbackBreadcrumb(replay, event) {
  replay.triggerUserActivity();
  replay.addUpdate(() => {
    if (!event.timestamp) {
      return true;
    }
    replay.throttledAddEvent({
      type: EventType.Custom,
      timestamp: event.timestamp * 1e3,
      data: {
        tag: "breadcrumb",
        payload: {
          timestamp: event.timestamp,
          type: "default",
          category: "sentry.feedback",
          data: {
            feedbackId: event.event_id
          }
        }
      }
    });
    return false;
  });
}
__name(addFeedbackBreadcrumb, "addFeedbackBreadcrumb");
function shouldSampleForBufferEvent(replay, event) {
  if (replay.recordingMode !== "buffer") {
    return false;
  }
  if (event.message === UNABLE_TO_SEND_REPLAY) {
    return false;
  }
  if (!event.exception || event.type) {
    return false;
  }
  return isSampled(replay.getOptions().errorSampleRate);
}
__name(shouldSampleForBufferEvent, "shouldSampleForBufferEvent");
function handleGlobalEventListener(replay) {
  return Object.assign(
    (event, hint) => {
      if (!replay.isEnabled() || replay.isPaused()) {
        return event;
      }
      if (isReplayEvent(event)) {
        delete event.breadcrumbs;
        return event;
      }
      if (!isErrorEvent(event) && !isTransactionEvent(event) && !isFeedbackEvent(event)) {
        return event;
      }
      const isSessionActive = replay.checkAndHandleExpiredSession();
      if (!isSessionActive) {
        resetReplayIdOnDynamicSamplingContext();
        return event;
      }
      if (isFeedbackEvent(event)) {
        replay.flush();
        event.contexts.feedback.replay_id = replay.getSessionId();
        addFeedbackBreadcrumb(replay, event);
        return event;
      }
      if (isRrwebError(event, hint) && !replay.getOptions()._experiments.captureExceptions) {
        DEBUG_BUILD$2 && logger$1.log("Ignoring error from rrweb internals", event);
        return null;
      }
      const isErrorEventSampled = shouldSampleForBufferEvent(replay, event);
      const shouldTagReplayId = isErrorEventSampled || replay.recordingMode === "session";
      if (shouldTagReplayId) {
        event.tags = { ...event.tags, replayId: replay.getSessionId() };
      }
      return event;
    },
    { id: "Replay" }
  );
}
__name(handleGlobalEventListener, "handleGlobalEventListener");
function createPerformanceSpans(replay, entries) {
  return entries.map(({ type, start: start2, end, name: name2, data: data30 }) => {
    const response = replay.throttledAddEvent({
      type: EventType.Custom,
      timestamp: start2,
      data: {
        tag: "performanceSpan",
        payload: {
          op: type,
          description: name2,
          startTimestamp: start2,
          endTimestamp: end,
          data: data30
        }
      }
    });
    return typeof response === "string" ? Promise.resolve(null) : response;
  });
}
__name(createPerformanceSpans, "createPerformanceSpans");
function handleHistory(handlerData) {
  const { from: from2, to } = handlerData;
  const now2 = Date.now() / 1e3;
  return {
    type: "navigation.push",
    start: now2,
    end: now2,
    name: to,
    data: {
      previous: from2
    }
  };
}
__name(handleHistory, "handleHistory");
function handleHistorySpanListener(replay) {
  return (handlerData) => {
    if (!replay.isEnabled()) {
      return;
    }
    const result = handleHistory(handlerData);
    if (result === null) {
      return;
    }
    replay.getContext().urls.push(result.name);
    replay.triggerUserActivity();
    replay.addUpdate(() => {
      createPerformanceSpans(replay, [result]);
      return false;
    });
  };
}
__name(handleHistorySpanListener, "handleHistorySpanListener");
function shouldFilterRequest(replay, url) {
  if (DEBUG_BUILD$2 && replay.getOptions()._experiments.traceInternals) {
    return false;
  }
  return isSentryRequestUrl(url, getClient());
}
__name(shouldFilterRequest, "shouldFilterRequest");
function addNetworkBreadcrumb(replay, result) {
  if (!replay.isEnabled()) {
    return;
  }
  if (result === null) {
    return;
  }
  if (shouldFilterRequest(replay, result.name)) {
    return;
  }
  replay.addUpdate(() => {
    createPerformanceSpans(replay, [result]);
    return true;
  });
}
__name(addNetworkBreadcrumb, "addNetworkBreadcrumb");
function getBodySize(body) {
  if (!body) {
    return void 0;
  }
  const textEncoder = new TextEncoder();
  try {
    if (typeof body === "string") {
      return textEncoder.encode(body).length;
    }
    if (body instanceof URLSearchParams) {
      return textEncoder.encode(body.toString()).length;
    }
    if (body instanceof FormData) {
      const formDataStr = _serializeFormData(body);
      return textEncoder.encode(formDataStr).length;
    }
    if (body instanceof Blob) {
      return body.size;
    }
    if (body instanceof ArrayBuffer) {
      return body.byteLength;
    }
  } catch (e2) {
  }
  return void 0;
}
__name(getBodySize, "getBodySize");
function parseContentLengthHeader(header3) {
  if (!header3) {
    return void 0;
  }
  const size = parseInt(header3, 10);
  return isNaN(size) ? void 0 : size;
}
__name(parseContentLengthHeader, "parseContentLengthHeader");
function getBodyString(body) {
  try {
    if (typeof body === "string") {
      return [body];
    }
    if (body instanceof URLSearchParams) {
      return [body.toString()];
    }
    if (body instanceof FormData) {
      return [_serializeFormData(body)];
    }
    if (!body) {
      return [void 0];
    }
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to serialize body", body);
    return [void 0, "BODY_PARSE_ERROR"];
  }
  DEBUG_BUILD$2 && logger$1.info("Skipping network body because of body type", body);
  return [void 0, "UNPARSEABLE_BODY_TYPE"];
}
__name(getBodyString, "getBodyString");
function mergeWarning(info, warning) {
  if (!info) {
    return {
      headers: {},
      size: void 0,
      _meta: {
        warnings: [warning]
      }
    };
  }
  const newMeta = { ...info._meta };
  const existingWarnings = newMeta.warnings || [];
  newMeta.warnings = [...existingWarnings, warning];
  info._meta = newMeta;
  return info;
}
__name(mergeWarning, "mergeWarning");
function makeNetworkReplayBreadcrumb(type, data30) {
  if (!data30) {
    return null;
  }
  const { startTimestamp, endTimestamp, url, method, statusCode, request, response } = data30;
  const result = {
    type,
    start: startTimestamp / 1e3,
    end: endTimestamp / 1e3,
    name: url,
    data: dropUndefinedKeys({
      method,
      statusCode,
      request,
      response
    })
  };
  return result;
}
__name(makeNetworkReplayBreadcrumb, "makeNetworkReplayBreadcrumb");
function buildSkippedNetworkRequestOrResponse(bodySize) {
  return {
    headers: {},
    size: bodySize,
    _meta: {
      warnings: ["URL_SKIPPED"]
    }
  };
}
__name(buildSkippedNetworkRequestOrResponse, "buildSkippedNetworkRequestOrResponse");
function buildNetworkRequestOrResponse(headers, bodySize, body) {
  if (!bodySize && Object.keys(headers).length === 0) {
    return void 0;
  }
  if (!bodySize) {
    return {
      headers
    };
  }
  if (!body) {
    return {
      headers,
      size: bodySize
    };
  }
  const info = {
    headers,
    size: bodySize
  };
  const { body: normalizedBody, warnings } = normalizeNetworkBody(body);
  info.body = normalizedBody;
  if (warnings && warnings.length > 0) {
    info._meta = {
      warnings
    };
  }
  return info;
}
__name(buildNetworkRequestOrResponse, "buildNetworkRequestOrResponse");
function getAllowedHeaders(headers, allowedHeaders) {
  return Object.entries(headers).reduce((filteredHeaders, [key, value3]) => {
    const normalizedKey = key.toLowerCase();
    if (allowedHeaders.includes(normalizedKey) && headers[key]) {
      filteredHeaders[normalizedKey] = value3;
    }
    return filteredHeaders;
  }, {});
}
__name(getAllowedHeaders, "getAllowedHeaders");
function _serializeFormData(formData) {
  return new URLSearchParams(formData).toString();
}
__name(_serializeFormData, "_serializeFormData");
function normalizeNetworkBody(body) {
  if (!body || typeof body !== "string") {
    return {
      body
    };
  }
  const exceedsSizeLimit = body.length > NETWORK_BODY_MAX_SIZE;
  const isProbablyJson = _strIsProbablyJson(body);
  if (exceedsSizeLimit) {
    const truncatedBody = body.slice(0, NETWORK_BODY_MAX_SIZE);
    if (isProbablyJson) {
      return {
        body: truncatedBody,
        warnings: ["MAYBE_JSON_TRUNCATED"]
      };
    }
    return {
      body: `${truncatedBody}…`,
      warnings: ["TEXT_TRUNCATED"]
    };
  }
  if (isProbablyJson) {
    try {
      const jsonBody = JSON.parse(body);
      return {
        body: jsonBody
      };
    } catch (e2) {
    }
  }
  return {
    body
  };
}
__name(normalizeNetworkBody, "normalizeNetworkBody");
function _strIsProbablyJson(str) {
  const first2 = str[0];
  const last = str[str.length - 1];
  return first2 === "[" && last === "]" || first2 === "{" && last === "}";
}
__name(_strIsProbablyJson, "_strIsProbablyJson");
function urlMatches(url, urls) {
  const fullUrl = getFullUrl(url);
  return stringMatchesSomePattern(fullUrl, urls);
}
__name(urlMatches, "urlMatches");
function getFullUrl(url, baseURI = WINDOW$1.document.baseURI) {
  if (url.startsWith("http://") || url.startsWith("https://") || url.startsWith(WINDOW$1.location.origin)) {
    return url;
  }
  const fixedUrl = new URL(url, baseURI);
  if (fixedUrl.origin !== new URL(baseURI).origin) {
    return url;
  }
  const fullUrl = fixedUrl.href;
  if (!url.endsWith("/") && fullUrl.endsWith("/")) {
    return fullUrl.slice(0, -1);
  }
  return fullUrl;
}
__name(getFullUrl, "getFullUrl");
async function captureFetchBreadcrumbToReplay(breadcrumb, hint, options5) {
  try {
    const data30 = await _prepareFetchData(breadcrumb, hint, options5);
    const result = makeNetworkReplayBreadcrumb("resource.fetch", data30);
    addNetworkBreadcrumb(options5.replay, result);
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to capture fetch breadcrumb");
  }
}
__name(captureFetchBreadcrumbToReplay, "captureFetchBreadcrumbToReplay");
function enrichFetchBreadcrumb(breadcrumb, hint) {
  const { input, response } = hint;
  const body = input ? _getFetchRequestArgBody(input) : void 0;
  const reqSize = getBodySize(body);
  const resSize = response ? parseContentLengthHeader(response.headers.get("content-length")) : void 0;
  if (reqSize !== void 0) {
    breadcrumb.data.request_body_size = reqSize;
  }
  if (resSize !== void 0) {
    breadcrumb.data.response_body_size = resSize;
  }
}
__name(enrichFetchBreadcrumb, "enrichFetchBreadcrumb");
async function _prepareFetchData(breadcrumb, hint, options5) {
  const now2 = Date.now();
  const { startTimestamp = now2, endTimestamp = now2 } = hint;
  const {
    url,
    method,
    status_code: statusCode = 0,
    request_body_size: requestBodySize,
    response_body_size: responseBodySize
  } = breadcrumb.data;
  const captureDetails = urlMatches(url, options5.networkDetailAllowUrls) && !urlMatches(url, options5.networkDetailDenyUrls);
  const request = captureDetails ? _getRequestInfo(options5, hint.input, requestBodySize) : buildSkippedNetworkRequestOrResponse(requestBodySize);
  const response = await _getResponseInfo(captureDetails, options5, hint.response, responseBodySize);
  return {
    startTimestamp,
    endTimestamp,
    url,
    method,
    statusCode,
    request,
    response
  };
}
__name(_prepareFetchData, "_prepareFetchData");
function _getRequestInfo({ networkCaptureBodies, networkRequestHeaders }, input, requestBodySize) {
  const headers = input ? getRequestHeaders(input, networkRequestHeaders) : {};
  if (!networkCaptureBodies) {
    return buildNetworkRequestOrResponse(headers, requestBodySize, void 0);
  }
  const requestBody = _getFetchRequestArgBody(input);
  const [bodyStr, warning] = getBodyString(requestBody);
  const data30 = buildNetworkRequestOrResponse(headers, requestBodySize, bodyStr);
  if (warning) {
    return mergeWarning(data30, warning);
  }
  return data30;
}
__name(_getRequestInfo, "_getRequestInfo");
async function _getResponseInfo(captureDetails, {
  networkCaptureBodies,
  networkResponseHeaders
}, response, responseBodySize) {
  if (!captureDetails && responseBodySize !== void 0) {
    return buildSkippedNetworkRequestOrResponse(responseBodySize);
  }
  const headers = response ? getAllHeaders(response.headers, networkResponseHeaders) : {};
  if (!response || !networkCaptureBodies && responseBodySize !== void 0) {
    return buildNetworkRequestOrResponse(headers, responseBodySize, void 0);
  }
  const [bodyText, warning] = await _parseFetchResponseBody(response);
  const result = getResponseData(bodyText, {
    networkCaptureBodies,
    responseBodySize,
    captureDetails,
    headers
  });
  if (warning) {
    return mergeWarning(result, warning);
  }
  return result;
}
__name(_getResponseInfo, "_getResponseInfo");
function getResponseData(bodyText, {
  networkCaptureBodies,
  responseBodySize,
  captureDetails,
  headers
}) {
  try {
    const size = bodyText && bodyText.length && responseBodySize === void 0 ? getBodySize(bodyText) : responseBodySize;
    if (!captureDetails) {
      return buildSkippedNetworkRequestOrResponse(size);
    }
    if (networkCaptureBodies) {
      return buildNetworkRequestOrResponse(headers, size, bodyText);
    }
    return buildNetworkRequestOrResponse(headers, size, void 0);
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to serialize response body");
    return buildNetworkRequestOrResponse(headers, responseBodySize, void 0);
  }
}
__name(getResponseData, "getResponseData");
async function _parseFetchResponseBody(response) {
  const res = _tryCloneResponse(response);
  if (!res) {
    return [void 0, "BODY_PARSE_ERROR"];
  }
  try {
    const text2 = await _tryGetResponseText(res);
    return [text2];
  } catch (error2) {
    if (error2 instanceof Error && error2.message.indexOf("Timeout") > -1) {
      DEBUG_BUILD$2 && logger$1.warn("Parsing text body from response timed out");
      return [void 0, "BODY_PARSE_TIMEOUT"];
    }
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to get text body from response");
    return [void 0, "BODY_PARSE_ERROR"];
  }
}
__name(_parseFetchResponseBody, "_parseFetchResponseBody");
function _getFetchRequestArgBody(fetchArgs = []) {
  if (fetchArgs.length !== 2 || typeof fetchArgs[1] !== "object") {
    return void 0;
  }
  return fetchArgs[1].body;
}
__name(_getFetchRequestArgBody, "_getFetchRequestArgBody");
function getAllHeaders(headers, allowedHeaders) {
  const allHeaders = {};
  allowedHeaders.forEach((header3) => {
    if (headers.get(header3)) {
      allHeaders[header3] = headers.get(header3);
    }
  });
  return allHeaders;
}
__name(getAllHeaders, "getAllHeaders");
function getRequestHeaders(fetchArgs, allowedHeaders) {
  if (fetchArgs.length === 1 && typeof fetchArgs[0] !== "string") {
    return getHeadersFromOptions(fetchArgs[0], allowedHeaders);
  }
  if (fetchArgs.length === 2) {
    return getHeadersFromOptions(fetchArgs[1], allowedHeaders);
  }
  return {};
}
__name(getRequestHeaders, "getRequestHeaders");
function getHeadersFromOptions(input, allowedHeaders) {
  if (!input) {
    return {};
  }
  const headers = input.headers;
  if (!headers) {
    return {};
  }
  if (headers instanceof Headers) {
    return getAllHeaders(headers, allowedHeaders);
  }
  if (Array.isArray(headers)) {
    return {};
  }
  return getAllowedHeaders(headers, allowedHeaders);
}
__name(getHeadersFromOptions, "getHeadersFromOptions");
function _tryCloneResponse(response) {
  try {
    return response.clone();
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to clone response body");
  }
}
__name(_tryCloneResponse, "_tryCloneResponse");
function _tryGetResponseText(response) {
  return new Promise((resolve2, reject3) => {
    const timeout = setTimeout$3(() => reject3(new Error("Timeout while trying to read response body")), 500);
    _getResponseText(response).then(
      (txt) => resolve2(txt),
      (reason) => reject3(reason)
    ).finally(() => clearTimeout(timeout));
  });
}
__name(_tryGetResponseText, "_tryGetResponseText");
async function _getResponseText(response) {
  return await response.text();
}
__name(_getResponseText, "_getResponseText");
async function captureXhrBreadcrumbToReplay(breadcrumb, hint, options5) {
  try {
    const data30 = _prepareXhrData(breadcrumb, hint, options5);
    const result = makeNetworkReplayBreadcrumb("resource.xhr", data30);
    addNetworkBreadcrumb(options5.replay, result);
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to capture xhr breadcrumb");
  }
}
__name(captureXhrBreadcrumbToReplay, "captureXhrBreadcrumbToReplay");
function enrichXhrBreadcrumb(breadcrumb, hint) {
  const { xhr, input } = hint;
  if (!xhr) {
    return;
  }
  const reqSize = getBodySize(input);
  const resSize = xhr.getResponseHeader("content-length") ? parseContentLengthHeader(xhr.getResponseHeader("content-length")) : _getBodySize(xhr.response, xhr.responseType);
  if (reqSize !== void 0) {
    breadcrumb.data.request_body_size = reqSize;
  }
  if (resSize !== void 0) {
    breadcrumb.data.response_body_size = resSize;
  }
}
__name(enrichXhrBreadcrumb, "enrichXhrBreadcrumb");
function _prepareXhrData(breadcrumb, hint, options5) {
  const now2 = Date.now();
  const { startTimestamp = now2, endTimestamp = now2, input, xhr } = hint;
  const {
    url,
    method,
    status_code: statusCode = 0,
    request_body_size: requestBodySize,
    response_body_size: responseBodySize
  } = breadcrumb.data;
  if (!url) {
    return null;
  }
  if (!xhr || !urlMatches(url, options5.networkDetailAllowUrls) || urlMatches(url, options5.networkDetailDenyUrls)) {
    const request2 = buildSkippedNetworkRequestOrResponse(requestBodySize);
    const response2 = buildSkippedNetworkRequestOrResponse(responseBodySize);
    return {
      startTimestamp,
      endTimestamp,
      url,
      method,
      statusCode,
      request: request2,
      response: response2
    };
  }
  const xhrInfo = xhr[SENTRY_XHR_DATA_KEY];
  const networkRequestHeaders = xhrInfo ? getAllowedHeaders(xhrInfo.request_headers, options5.networkRequestHeaders) : {};
  const networkResponseHeaders = getAllowedHeaders(getResponseHeaders(xhr), options5.networkResponseHeaders);
  const [requestBody, requestWarning] = options5.networkCaptureBodies ? getBodyString(input) : [void 0];
  const [responseBody, responseWarning] = options5.networkCaptureBodies ? _getXhrResponseBody(xhr) : [void 0];
  const request = buildNetworkRequestOrResponse(networkRequestHeaders, requestBodySize, requestBody);
  const response = buildNetworkRequestOrResponse(networkResponseHeaders, responseBodySize, responseBody);
  return {
    startTimestamp,
    endTimestamp,
    url,
    method,
    statusCode,
    request: requestWarning ? mergeWarning(request, requestWarning) : request,
    response: responseWarning ? mergeWarning(response, responseWarning) : response
  };
}
__name(_prepareXhrData, "_prepareXhrData");
function getResponseHeaders(xhr) {
  const headers = xhr.getAllResponseHeaders();
  if (!headers) {
    return {};
  }
  return headers.split("\r\n").reduce((acc, line) => {
    const [key, value3] = line.split(": ");
    if (value3) {
      acc[key.toLowerCase()] = value3;
    }
    return acc;
  }, {});
}
__name(getResponseHeaders, "getResponseHeaders");
function _getXhrResponseBody(xhr) {
  const errors2 = [];
  try {
    return [xhr.responseText];
  } catch (e2) {
    errors2.push(e2);
  }
  try {
    return _parseXhrResponse(xhr.response, xhr.responseType);
  } catch (e2) {
    errors2.push(e2);
  }
  DEBUG_BUILD$2 && logger$1.warn("Failed to get xhr response body", ...errors2);
  return [void 0];
}
__name(_getXhrResponseBody, "_getXhrResponseBody");
function _parseXhrResponse(body, responseType) {
  try {
    if (typeof body === "string") {
      return [body];
    }
    if (body instanceof Document) {
      return [body.body.outerHTML];
    }
    if (responseType === "json" && body && typeof body === "object") {
      return [JSON.stringify(body)];
    }
    if (!body) {
      return [void 0];
    }
  } catch (error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2, "Failed to serialize body", body);
    return [void 0, "BODY_PARSE_ERROR"];
  }
  DEBUG_BUILD$2 && logger$1.info("Skipping network body because of body type", body);
  return [void 0, "UNPARSEABLE_BODY_TYPE"];
}
__name(_parseXhrResponse, "_parseXhrResponse");
function _getBodySize(body, responseType) {
  try {
    const bodyStr = responseType === "json" && body && typeof body === "object" ? JSON.stringify(body) : body;
    return getBodySize(bodyStr);
  } catch (e2) {
    return void 0;
  }
}
__name(_getBodySize, "_getBodySize");
function handleNetworkBreadcrumbs(replay) {
  const client = getClient();
  try {
    const {
      networkDetailAllowUrls,
      networkDetailDenyUrls,
      networkCaptureBodies,
      networkRequestHeaders,
      networkResponseHeaders
    } = replay.getOptions();
    const options5 = {
      replay,
      networkDetailAllowUrls,
      networkDetailDenyUrls,
      networkCaptureBodies,
      networkRequestHeaders,
      networkResponseHeaders
    };
    if (client) {
      client.on("beforeAddBreadcrumb", (breadcrumb, hint) => beforeAddNetworkBreadcrumb(options5, breadcrumb, hint));
    }
  } catch (e2) {
  }
}
__name(handleNetworkBreadcrumbs, "handleNetworkBreadcrumbs");
function beforeAddNetworkBreadcrumb(options5, breadcrumb, hint) {
  if (!breadcrumb.data) {
    return;
  }
  try {
    if (_isXhrBreadcrumb(breadcrumb) && _isXhrHint(hint)) {
      enrichXhrBreadcrumb(breadcrumb, hint);
      captureXhrBreadcrumbToReplay(breadcrumb, hint, options5);
    }
    if (_isFetchBreadcrumb(breadcrumb) && _isFetchHint(hint)) {
      enrichFetchBreadcrumb(breadcrumb, hint);
      captureFetchBreadcrumbToReplay(breadcrumb, hint, options5);
    }
  } catch (e2) {
    DEBUG_BUILD$2 && logger$1.exception(e2, "Error when enriching network breadcrumb");
  }
}
__name(beforeAddNetworkBreadcrumb, "beforeAddNetworkBreadcrumb");
function _isXhrBreadcrumb(breadcrumb) {
  return breadcrumb.category === "xhr";
}
__name(_isXhrBreadcrumb, "_isXhrBreadcrumb");
function _isFetchBreadcrumb(breadcrumb) {
  return breadcrumb.category === "fetch";
}
__name(_isFetchBreadcrumb, "_isFetchBreadcrumb");
function _isXhrHint(hint) {
  return hint && hint.xhr;
}
__name(_isXhrHint, "_isXhrHint");
function _isFetchHint(hint) {
  return hint && hint.response;
}
__name(_isFetchHint, "_isFetchHint");
function addGlobalListeners(replay) {
  const client = getClient();
  addClickKeypressInstrumentationHandler(handleDomListener(replay));
  addHistoryInstrumentationHandler(handleHistorySpanListener(replay));
  handleBreadcrumbs(replay);
  handleNetworkBreadcrumbs(replay);
  const eventProcessor = handleGlobalEventListener(replay);
  addEventProcessor(eventProcessor);
  if (client) {
    client.on("beforeSendEvent", handleBeforeSendEvent(replay));
    client.on("afterSendEvent", handleAfterSendEvent(replay));
    client.on("createDsc", (dsc) => {
      const replayId = replay.getSessionId();
      if (replayId && replay.isEnabled() && replay.recordingMode === "session") {
        const isSessionActive = replay.checkAndHandleExpiredSession();
        if (isSessionActive) {
          dsc.replay_id = replayId;
        }
      }
    });
    client.on("spanStart", (span) => {
      replay.lastActiveSpan = span;
    });
    client.on("spanEnd", (span) => {
      replay.lastActiveSpan = span;
    });
    client.on("beforeSendFeedback", (feedbackEvent, options5) => {
      const replayId = replay.getSessionId();
      if (options5 && options5.includeReplay && replay.isEnabled() && replayId) {
        if (feedbackEvent.contexts && feedbackEvent.contexts.feedback) {
          feedbackEvent.contexts.feedback.replay_id = replayId;
        }
      }
    });
  }
}
__name(addGlobalListeners, "addGlobalListeners");
async function addMemoryEntry(replay) {
  try {
    return Promise.all(
      createPerformanceSpans(replay, [
        // @ts-expect-error memory doesn't exist on type Performance as the API is non-standard (we check that it exists above)
        createMemoryEntry(WINDOW$1.performance.memory)
      ])
    );
  } catch (error2) {
    return [];
  }
}
__name(addMemoryEntry, "addMemoryEntry");
function createMemoryEntry(memoryEntry) {
  const { jsHeapSizeLimit, totalJSHeapSize, usedJSHeapSize } = memoryEntry;
  const time = Date.now() / 1e3;
  return {
    type: "memory",
    name: "memory",
    start: time,
    end: time,
    data: {
      memory: {
        jsHeapSizeLimit,
        totalJSHeapSize,
        usedJSHeapSize
      }
    }
  };
}
__name(createMemoryEntry, "createMemoryEntry");
function debounce(func, wait, options5) {
  let callbackReturnValue;
  let timerId;
  let maxTimerId;
  const maxWait = options5 && options5.maxWait ? Math.max(options5.maxWait, wait) : 0;
  function invokeFunc() {
    cancelTimers();
    callbackReturnValue = func();
    return callbackReturnValue;
  }
  __name(invokeFunc, "invokeFunc");
  function cancelTimers() {
    timerId !== void 0 && clearTimeout(timerId);
    maxTimerId !== void 0 && clearTimeout(maxTimerId);
    timerId = maxTimerId = void 0;
  }
  __name(cancelTimers, "cancelTimers");
  function flush2() {
    if (timerId !== void 0 || maxTimerId !== void 0) {
      return invokeFunc();
    }
    return callbackReturnValue;
  }
  __name(flush2, "flush");
  function debounced() {
    if (timerId) {
      clearTimeout(timerId);
    }
    timerId = setTimeout$3(invokeFunc, wait);
    if (maxWait && maxTimerId === void 0) {
      maxTimerId = setTimeout$3(invokeFunc, maxWait);
    }
    return callbackReturnValue;
  }
  __name(debounced, "debounced");
  debounced.cancel = cancelTimers;
  debounced.flush = flush2;
  return debounced;
}
__name(debounce, "debounce");
function getHandleRecordingEmit(replay) {
  let hadFirstEvent = false;
  return (event, _isCheckout) => {
    if (!replay.checkAndHandleExpiredSession()) {
      DEBUG_BUILD$2 && logger$1.warn("Received replay event after session expired.");
      return;
    }
    const isCheckout = _isCheckout || !hadFirstEvent;
    hadFirstEvent = true;
    if (replay.clickDetector) {
      updateClickDetectorForRecordingEvent(replay.clickDetector, event);
    }
    replay.addUpdate(() => {
      if (replay.recordingMode === "buffer" && isCheckout) {
        replay.setInitialState();
      }
      if (!addEventSync(replay, event, isCheckout)) {
        return true;
      }
      if (!isCheckout) {
        return false;
      }
      const session = replay.session;
      addSettingsEvent(replay, isCheckout);
      if (replay.recordingMode === "buffer" && session && replay.eventBuffer) {
        const earliestEvent = replay.eventBuffer.getEarliestTimestamp();
        if (earliestEvent) {
          DEBUG_BUILD$2 && logger$1.info(`Updating session start time to earliest event in buffer to ${new Date(earliestEvent)}`);
          session.started = earliestEvent;
          if (replay.getOptions().stickySession) {
            saveSession(session);
          }
        }
      }
      if (session && session.previousSessionId) {
        return true;
      }
      if (replay.recordingMode === "session") {
        void replay.flush();
      }
      return true;
    });
  };
}
__name(getHandleRecordingEmit, "getHandleRecordingEmit");
function createOptionsEvent(replay) {
  const options5 = replay.getOptions();
  return {
    type: EventType.Custom,
    timestamp: Date.now(),
    data: {
      tag: "options",
      payload: {
        shouldRecordCanvas: replay.isRecordingCanvas(),
        sessionSampleRate: options5.sessionSampleRate,
        errorSampleRate: options5.errorSampleRate,
        useCompressionOption: options5.useCompression,
        blockAllMedia: options5.blockAllMedia,
        maskAllText: options5.maskAllText,
        maskAllInputs: options5.maskAllInputs,
        useCompression: replay.eventBuffer ? replay.eventBuffer.type === "worker" : false,
        networkDetailHasUrls: options5.networkDetailAllowUrls.length > 0,
        networkCaptureBodies: options5.networkCaptureBodies,
        networkRequestHasHeaders: options5.networkRequestHeaders.length > 0,
        networkResponseHasHeaders: options5.networkResponseHeaders.length > 0
      }
    }
  };
}
__name(createOptionsEvent, "createOptionsEvent");
function addSettingsEvent(replay, isCheckout) {
  if (!isCheckout || !replay.session || replay.session.segmentId !== 0) {
    return;
  }
  addEventSync(replay, createOptionsEvent(replay), false);
}
__name(addSettingsEvent, "addSettingsEvent");
function createReplayEnvelope(replayEvent, recordingData, dsn, tunnel) {
  return createEnvelope(
    createEventEnvelopeHeaders(replayEvent, getSdkMetadataForEnvelopeHeader(replayEvent), tunnel, dsn),
    [
      [{ type: "replay_event" }, replayEvent],
      [
        {
          type: "replay_recording",
          // If string then we need to encode to UTF8, otherwise will have
          // wrong size. TextEncoder has similar browser support to
          // MutationObserver, although it does not accept IE11.
          length: typeof recordingData === "string" ? new TextEncoder().encode(recordingData).length : recordingData.length
        },
        recordingData
      ]
    ]
  );
}
__name(createReplayEnvelope, "createReplayEnvelope");
function prepareRecordingData({
  recordingData,
  headers
}) {
  let payloadWithSequence;
  const replayHeaders = `${JSON.stringify(headers)}
`;
  if (typeof recordingData === "string") {
    payloadWithSequence = `${replayHeaders}${recordingData}`;
  } else {
    const enc = new TextEncoder();
    const sequence = enc.encode(replayHeaders);
    payloadWithSequence = new Uint8Array(sequence.length + recordingData.length);
    payloadWithSequence.set(sequence);
    payloadWithSequence.set(recordingData, sequence.length);
  }
  return payloadWithSequence;
}
__name(prepareRecordingData, "prepareRecordingData");
async function prepareReplayEvent({
  client,
  scope,
  replayId: event_id,
  event
}) {
  const integrations = typeof client._integrations === "object" && client._integrations !== null && !Array.isArray(client._integrations) ? Object.keys(client._integrations) : void 0;
  const eventHint = { event_id, integrations };
  client.emit("preprocessEvent", event, eventHint);
  const preparedEvent = await prepareEvent(
    client.getOptions(),
    event,
    eventHint,
    scope,
    client,
    getIsolationScope()
  );
  if (!preparedEvent) {
    return null;
  }
  preparedEvent.platform = preparedEvent.platform || "javascript";
  const metadata = client.getSdkMetadata();
  const { name: name2, version: version2 } = metadata && metadata.sdk || {};
  preparedEvent.sdk = {
    ...preparedEvent.sdk,
    name: name2 || "sentry.javascript.unknown",
    version: version2 || "0.0.0"
  };
  return preparedEvent;
}
__name(prepareReplayEvent, "prepareReplayEvent");
async function sendReplayRequest({
  recordingData,
  replayId,
  segmentId: segment_id,
  eventContext,
  timestamp: timestamp2,
  session
}) {
  const preparedRecordingData = prepareRecordingData({
    recordingData,
    headers: {
      segment_id
    }
  });
  const { urls, errorIds, traceIds, initialTimestamp } = eventContext;
  const client = getClient();
  const scope = getCurrentScope$1();
  const transport = client && client.getTransport();
  const dsn = client && client.getDsn();
  if (!client || !transport || !dsn || !session.sampled) {
    return resolvedSyncPromise({});
  }
  const baseEvent = {
    type: REPLAY_EVENT_NAME,
    replay_start_timestamp: initialTimestamp / 1e3,
    timestamp: timestamp2 / 1e3,
    error_ids: errorIds,
    trace_ids: traceIds,
    urls,
    replay_id: replayId,
    segment_id,
    replay_type: session.sampled
  };
  const replayEvent = await prepareReplayEvent({ scope, client, replayId, event: baseEvent });
  if (!replayEvent) {
    client.recordDroppedEvent("event_processor", "replay", baseEvent);
    DEBUG_BUILD$2 && logger$1.info("An event processor returned `null`, will not send event.");
    return resolvedSyncPromise({});
  }
  delete replayEvent.sdkProcessingMetadata;
  const envelope = createReplayEnvelope(replayEvent, preparedRecordingData, dsn, client.getOptions().tunnel);
  let response;
  try {
    response = await transport.send(envelope);
  } catch (err) {
    const error2 = new Error(UNABLE_TO_SEND_REPLAY);
    try {
      error2.cause = err;
    } catch (e2) {
    }
    throw error2;
  }
  if (typeof response.statusCode === "number" && (response.statusCode < 200 || response.statusCode >= 300)) {
    throw new TransportStatusCodeError(response.statusCode);
  }
  const rateLimits = updateRateLimits({}, response);
  if (isRateLimited(rateLimits, "replay")) {
    throw new RateLimitError(rateLimits);
  }
  return response;
}
__name(sendReplayRequest, "sendReplayRequest");
class TransportStatusCodeError extends Error {
  static {
    __name(this, "TransportStatusCodeError");
  }
  constructor(statusCode) {
    super(`Transport returned status code ${statusCode}`);
  }
}
class RateLimitError extends Error {
  static {
    __name(this, "RateLimitError");
  }
  constructor(rateLimits) {
    super("Rate limit hit");
    this.rateLimits = rateLimits;
  }
}
async function sendReplay(replayData, retryConfig = {
  count: 0,
  interval: RETRY_BASE_INTERVAL
}) {
  const { recordingData, onError } = replayData;
  if (!recordingData.length) {
    return;
  }
  try {
    await sendReplayRequest(replayData);
    return true;
  } catch (err) {
    if (err instanceof TransportStatusCodeError || err instanceof RateLimitError) {
      throw err;
    }
    setContext("Replays", {
      _retryCount: retryConfig.count
    });
    if (onError) {
      onError(err);
    }
    if (retryConfig.count >= RETRY_MAX_COUNT) {
      const error2 = new Error(`${UNABLE_TO_SEND_REPLAY} - max retries exceeded`);
      try {
        error2.cause = err;
      } catch (e2) {
      }
      throw error2;
    }
    retryConfig.interval *= ++retryConfig.count;
    return new Promise((resolve2, reject3) => {
      setTimeout$3(async () => {
        try {
          await sendReplay(replayData, retryConfig);
          resolve2(true);
        } catch (err2) {
          reject3(err2);
        }
      }, retryConfig.interval);
    });
  }
}
__name(sendReplay, "sendReplay");
const THROTTLED = "__THROTTLED";
const SKIPPED = "__SKIPPED";
function throttle$2(fn, maxCount, durationSeconds) {
  const counter = /* @__PURE__ */ new Map();
  const _cleanup = /* @__PURE__ */ __name((now2) => {
    const threshold = now2 - durationSeconds;
    counter.forEach((_value, key) => {
      if (key < threshold) {
        counter.delete(key);
      }
    });
  }, "_cleanup");
  const _getTotalCount = /* @__PURE__ */ __name(() => {
    return [...counter.values()].reduce((a2, b2) => a2 + b2, 0);
  }, "_getTotalCount");
  let isThrottled = false;
  return (...rest) => {
    const now2 = Math.floor(Date.now() / 1e3);
    _cleanup(now2);
    if (_getTotalCount() >= maxCount) {
      const wasThrottled = isThrottled;
      isThrottled = true;
      return wasThrottled ? SKIPPED : THROTTLED;
    }
    isThrottled = false;
    const count = counter.get(now2) || 0;
    counter.set(now2, count + 1);
    return fn(...rest);
  };
}
__name(throttle$2, "throttle$2");
class ReplayContainer {
  static {
    __name(this, "ReplayContainer");
  }
  /**
   * Recording can happen in one of two modes:
   *   - session: Record the whole session, sending it continuously
   *   - buffer: Always keep the last 60s of recording, requires:
   *     - having replaysOnErrorSampleRate > 0 to capture replay when an error occurs
   *     - or calling `flush()` to send the replay
   */
  /**
   * The current or last active span.
   * This is only available when performance is enabled.
   */
  /**
   * These are here so we can overwrite them in tests etc.
   * @hidden
   */
  /** The replay has to be manually started, because no sample rate (neither session or error) was provided. */
  /**
   * Options to pass to `rrweb.record()`
   */
  /**
   * Timestamp of the last user activity. This lives across sessions.
   */
  /**
   * Is the integration currently active?
   */
  /**
   * Paused is a state where:
   * - DOM Recording is not listening at all
   * - Nothing will be added to event buffer (e.g. core SDK events)
   */
  /**
   * Have we attached listeners to the core SDK?
   * Note we have to track this as there is no way to remove instrumentation handlers.
   */
  /**
   * Function to stop recording
   */
  /**
   * Internal use for canvas recording options
   */
  constructor({
    options: options5,
    recordingOptions
  }) {
    ReplayContainer.prototype.__init.call(this);
    ReplayContainer.prototype.__init2.call(this);
    ReplayContainer.prototype.__init3.call(this);
    ReplayContainer.prototype.__init4.call(this);
    ReplayContainer.prototype.__init5.call(this);
    ReplayContainer.prototype.__init6.call(this);
    this.eventBuffer = null;
    this.performanceEntries = [];
    this.replayPerformanceEntries = [];
    this.recordingMode = "session";
    this.timeouts = {
      sessionIdlePause: SESSION_IDLE_PAUSE_DURATION,
      sessionIdleExpire: SESSION_IDLE_EXPIRE_DURATION
    };
    this._lastActivity = Date.now();
    this._isEnabled = false;
    this._isPaused = false;
    this._requiresManualStart = false;
    this._hasInitializedCoreListeners = false;
    this._context = {
      errorIds: /* @__PURE__ */ new Set(),
      traceIds: /* @__PURE__ */ new Set(),
      urls: [],
      initialTimestamp: Date.now(),
      initialUrl: ""
    };
    this._recordingOptions = recordingOptions;
    this._options = options5;
    this._debouncedFlush = debounce(() => this._flush(), this._options.flushMinDelay, {
      maxWait: this._options.flushMaxDelay
    });
    this._throttledAddEvent = throttle$2(
      (event, isCheckout) => addEvent(this, event, isCheckout),
      // Max 300 events...
      300,
      // ... per 5s
      5
    );
    const { slowClickTimeout, slowClickIgnoreSelectors } = this.getOptions();
    const slowClickConfig = slowClickTimeout ? {
      threshold: Math.min(SLOW_CLICK_THRESHOLD, slowClickTimeout),
      timeout: slowClickTimeout,
      scrollTimeout: SLOW_CLICK_SCROLL_TIMEOUT,
      ignoreSelector: slowClickIgnoreSelectors ? slowClickIgnoreSelectors.join(",") : ""
    } : void 0;
    if (slowClickConfig) {
      this.clickDetector = new ClickDetector(this, slowClickConfig);
    }
    if (DEBUG_BUILD$2) {
      const experiments = options5._experiments;
      logger$1.setConfig({
        captureExceptions: !!experiments.captureExceptions,
        traceInternals: !!experiments.traceInternals
      });
    }
  }
  /** Get the event context. */
  getContext() {
    return this._context;
  }
  /** If recording is currently enabled. */
  isEnabled() {
    return this._isEnabled;
  }
  /** If recording is currently paused. */
  isPaused() {
    return this._isPaused;
  }
  /**
   * Determine if canvas recording is enabled
   */
  isRecordingCanvas() {
    return Boolean(this._canvas);
  }
  /** Get the replay integration options. */
  getOptions() {
    return this._options;
  }
  /** A wrapper to conditionally capture exceptions. */
  handleException(error2) {
    DEBUG_BUILD$2 && logger$1.exception(error2);
    if (this._options.onError) {
      this._options.onError(error2);
    }
  }
  /**
   * Initializes the plugin based on sampling configuration. Should not be
   * called outside of constructor.
   */
  initializeSampling(previousSessionId) {
    const { errorSampleRate, sessionSampleRate } = this._options;
    const requiresManualStart = errorSampleRate <= 0 && sessionSampleRate <= 0;
    this._requiresManualStart = requiresManualStart;
    if (requiresManualStart) {
      return;
    }
    this._initializeSessionForSampling(previousSessionId);
    if (!this.session) {
      DEBUG_BUILD$2 && logger$1.exception(new Error("Unable to initialize and create session"));
      return;
    }
    if (this.session.sampled === false) {
      return;
    }
    this.recordingMode = this.session.sampled === "buffer" && this.session.segmentId === 0 ? "buffer" : "session";
    DEBUG_BUILD$2 && logger$1.infoTick(`Starting replay in ${this.recordingMode} mode`);
    this._initializeRecording();
  }
  /**
   * Start a replay regardless of sampling rate. Calling this will always
   * create a new session. Will log a message if replay is already in progress.
   *
   * Creates or loads a session, attaches listeners to varying events (DOM,
   * _performanceObserver, Recording, Sentry SDK, etc)
   */
  start() {
    if (this._isEnabled && this.recordingMode === "session") {
      DEBUG_BUILD$2 && logger$1.info("Recording is already in progress");
      return;
    }
    if (this._isEnabled && this.recordingMode === "buffer") {
      DEBUG_BUILD$2 && logger$1.info("Buffering is in progress, call `flush()` to save the replay");
      return;
    }
    DEBUG_BUILD$2 && logger$1.infoTick("Starting replay in session mode");
    this._updateUserActivity();
    const session = loadOrCreateSession(
      {
        maxReplayDuration: this._options.maxReplayDuration,
        sessionIdleExpire: this.timeouts.sessionIdleExpire
      },
      {
        stickySession: this._options.stickySession,
        // This is intentional: create a new session-based replay when calling `start()`
        sessionSampleRate: 1,
        allowBuffering: false
      }
    );
    this.session = session;
    this._initializeRecording();
  }
  /**
   * Start replay buffering. Buffers until `flush()` is called or, if
   * `replaysOnErrorSampleRate` > 0, an error occurs.
   */
  startBuffering() {
    if (this._isEnabled) {
      DEBUG_BUILD$2 && logger$1.info("Buffering is in progress, call `flush()` to save the replay");
      return;
    }
    DEBUG_BUILD$2 && logger$1.infoTick("Starting replay in buffer mode");
    const session = loadOrCreateSession(
      {
        sessionIdleExpire: this.timeouts.sessionIdleExpire,
        maxReplayDuration: this._options.maxReplayDuration
      },
      {
        stickySession: this._options.stickySession,
        sessionSampleRate: 0,
        allowBuffering: true
      }
    );
    this.session = session;
    this.recordingMode = "buffer";
    this._initializeRecording();
  }
  /**
   * Start recording.
   *
   * Note that this will cause a new DOM checkout
   */
  startRecording() {
    try {
      const canvasOptions = this._canvas;
      this._stopRecording = record({
        ...this._recordingOptions,
        // When running in error sampling mode, we need to overwrite `checkoutEveryNms`
        // Without this, it would record forever, until an error happens, which we don't want
        // instead, we'll always keep the last 60 seconds of replay before an error happened
        ...this.recordingMode === "buffer" ? { checkoutEveryNms: BUFFER_CHECKOUT_TIME } : (
          // Otherwise, use experimental option w/ min checkout time of 6 minutes
          // This is to improve playback seeking as there could potentially be
          // less mutations to process in the worse cases.
          //
          // checkout by "N" events is probably ideal, but means we have less
          // control about the number of checkouts we make (which generally
          // increases replay size)
          this._options._experiments.continuousCheckout && {
            // Minimum checkout time is 6 minutes
            checkoutEveryNms: Math.max(36e4, this._options._experiments.continuousCheckout)
          }
        ),
        emit: getHandleRecordingEmit(this),
        onMutation: this._onMutationHandler,
        ...canvasOptions ? {
          recordCanvas: canvasOptions.recordCanvas,
          getCanvasManager: canvasOptions.getCanvasManager,
          sampling: canvasOptions.sampling,
          dataURLOptions: canvasOptions.dataURLOptions
        } : {}
      });
    } catch (err) {
      this.handleException(err);
    }
  }
  /**
   * Stops the recording, if it was running.
   *
   * Returns true if it was previously stopped, or is now stopped,
   * otherwise false.
   */
  stopRecording() {
    try {
      if (this._stopRecording) {
        this._stopRecording();
        this._stopRecording = void 0;
      }
      return true;
    } catch (err) {
      this.handleException(err);
      return false;
    }
  }
  /**
   * Currently, this needs to be manually called (e.g. for tests). Sentry SDK
   * does not support a teardown
   */
  async stop({ forceFlush = false, reason } = {}) {
    if (!this._isEnabled) {
      return;
    }
    this._isEnabled = false;
    try {
      DEBUG_BUILD$2 && logger$1.info(`Stopping Replay${reason ? ` triggered by ${reason}` : ""}`);
      resetReplayIdOnDynamicSamplingContext();
      this._removeListeners();
      this.stopRecording();
      this._debouncedFlush.cancel();
      if (forceFlush) {
        await this._flush({ force: true });
      }
      this.eventBuffer && this.eventBuffer.destroy();
      this.eventBuffer = null;
      clearSession(this);
    } catch (err) {
      this.handleException(err);
    }
  }
  /**
   * Pause some replay functionality. See comments for `_isPaused`.
   * This differs from stop as this only stops DOM recording, it is
   * not as thorough of a shutdown as `stop()`.
   */
  pause() {
    if (this._isPaused) {
      return;
    }
    this._isPaused = true;
    this.stopRecording();
    DEBUG_BUILD$2 && logger$1.info("Pausing replay");
  }
  /**
   * Resumes recording, see notes for `pause().
   *
   * Note that calling `startRecording()` here will cause a
   * new DOM checkout.`
   */
  resume() {
    if (!this._isPaused || !this._checkSession()) {
      return;
    }
    this._isPaused = false;
    this.startRecording();
    DEBUG_BUILD$2 && logger$1.info("Resuming replay");
  }
  /**
   * If not in "session" recording mode, flush event buffer which will create a new replay.
   * Unless `continueRecording` is false, the replay will continue to record and
   * behave as a "session"-based replay.
   *
   * Otherwise, queue up a flush.
   */
  async sendBufferedReplayOrFlush({ continueRecording = true } = {}) {
    if (this.recordingMode === "session") {
      return this.flushImmediate();
    }
    const activityTime = Date.now();
    DEBUG_BUILD$2 && logger$1.info("Converting buffer to session");
    await this.flushImmediate();
    const hasStoppedRecording = this.stopRecording();
    if (!continueRecording || !hasStoppedRecording) {
      return;
    }
    if (this.recordingMode === "session") {
      return;
    }
    this.recordingMode = "session";
    if (this.session) {
      this._updateUserActivity(activityTime);
      this._updateSessionActivity(activityTime);
      this._maybeSaveSession();
    }
    this.startRecording();
  }
  /**
   * We want to batch uploads of replay events. Save events only if
   * `<flushMinDelay>` milliseconds have elapsed since the last event
   * *OR* if `<flushMaxDelay>` milliseconds have elapsed.
   *
   * Accepts a callback to perform side-effects and returns true to stop batch
   * processing and hand back control to caller.
   */
  addUpdate(cb) {
    const cbResult = cb();
    if (this.recordingMode === "buffer") {
      return;
    }
    if (cbResult === true) {
      return;
    }
    this._debouncedFlush();
  }
  /**
   * Updates the user activity timestamp and resumes recording. This should be
   * called in an event handler for a user action that we consider as the user
   * being "active" (e.g. a mouse click).
   */
  triggerUserActivity() {
    this._updateUserActivity();
    if (!this._stopRecording) {
      if (!this._checkSession()) {
        return;
      }
      this.resume();
      return;
    }
    this.checkAndHandleExpiredSession();
    this._updateSessionActivity();
  }
  /**
   * Updates the user activity timestamp *without* resuming
   * recording. Some user events (e.g. keydown) can be create
   * low-value replays that only contain the keypress as a
   * breadcrumb. Instead this would require other events to
   * create a new replay after a session has expired.
   */
  updateUserActivity() {
    this._updateUserActivity();
    this._updateSessionActivity();
  }
  /**
   * Only flush if `this.recordingMode === 'session'`
   */
  conditionalFlush() {
    if (this.recordingMode === "buffer") {
      return Promise.resolve();
    }
    return this.flushImmediate();
  }
  /**
   * Flush using debounce flush
   */
  flush() {
    return this._debouncedFlush();
  }
  /**
   * Always flush via `_debouncedFlush` so that we do not have flushes triggered
   * from calling both `flush` and `_debouncedFlush`. Otherwise, there could be
   * cases of multiple flushes happening closely together.
   */
  flushImmediate() {
    this._debouncedFlush();
    return this._debouncedFlush.flush();
  }
  /**
   * Cancels queued up flushes.
   */
  cancelFlush() {
    this._debouncedFlush.cancel();
  }
  /** Get the current session (=replay) ID */
  getSessionId() {
    return this.session && this.session.id;
  }
  /**
   * Checks if recording should be stopped due to user inactivity. Otherwise
   * check if session is expired and create a new session if so. Triggers a new
   * full snapshot on new session.
   *
   * Returns true if session is not expired, false otherwise.
   * @hidden
   */
  checkAndHandleExpiredSession() {
    if (this._lastActivity && isExpired(this._lastActivity, this.timeouts.sessionIdlePause) && this.session && this.session.sampled === "session") {
      this.pause();
      return;
    }
    if (!this._checkSession()) {
      return false;
    }
    return true;
  }
  /**
   * Capture some initial state that can change throughout the lifespan of the
   * replay. This is required because otherwise they would be captured at the
   * first flush.
   */
  setInitialState() {
    const urlPath = `${WINDOW$1.location.pathname}${WINDOW$1.location.hash}${WINDOW$1.location.search}`;
    const url = `${WINDOW$1.location.origin}${urlPath}`;
    this.performanceEntries = [];
    this.replayPerformanceEntries = [];
    this._clearContext();
    this._context.initialUrl = url;
    this._context.initialTimestamp = Date.now();
    this._context.urls.push(url);
  }
  /**
   * Add a breadcrumb event, that may be throttled.
   * If it was throttled, we add a custom breadcrumb to indicate that.
   */
  throttledAddEvent(event, isCheckout) {
    const res = this._throttledAddEvent(event, isCheckout);
    if (res === THROTTLED) {
      const breadcrumb = createBreadcrumb({
        category: "replay.throttled"
      });
      this.addUpdate(() => {
        return !addEventSync(this, {
          type: ReplayEventTypeCustom,
          timestamp: breadcrumb.timestamp || 0,
          data: {
            tag: "breadcrumb",
            payload: breadcrumb,
            metric: true
          }
        });
      });
    }
    return res;
  }
  /**
   * This will get the parametrized route name of the current page.
   * This is only available if performance is enabled, and if an instrumented router is used.
   */
  getCurrentRoute() {
    const lastActiveSpan = this.lastActiveSpan || getActiveSpan();
    const lastRootSpan = lastActiveSpan && getRootSpan(lastActiveSpan);
    const attributes = lastRootSpan && spanToJSON(lastRootSpan).data || {};
    const source = attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE];
    if (!lastRootSpan || !source || !["route", "custom"].includes(source)) {
      return void 0;
    }
    return spanToJSON(lastRootSpan).description;
  }
  /**
   * Initialize and start all listeners to varying events (DOM,
   * Performance Observer, Recording, Sentry SDK, etc)
   */
  _initializeRecording() {
    this.setInitialState();
    this._updateSessionActivity();
    this.eventBuffer = createEventBuffer({
      useCompression: this._options.useCompression,
      workerUrl: this._options.workerUrl
    });
    this._removeListeners();
    this._addListeners();
    this._isEnabled = true;
    this._isPaused = false;
    this.startRecording();
  }
  /**
   * Loads (or refreshes) the current session.
   */
  _initializeSessionForSampling(previousSessionId) {
    const allowBuffering = this._options.errorSampleRate > 0;
    const session = loadOrCreateSession(
      {
        sessionIdleExpire: this.timeouts.sessionIdleExpire,
        maxReplayDuration: this._options.maxReplayDuration,
        previousSessionId
      },
      {
        stickySession: this._options.stickySession,
        sessionSampleRate: this._options.sessionSampleRate,
        allowBuffering
      }
    );
    this.session = session;
  }
  /**
   * Checks and potentially refreshes the current session.
   * Returns false if session is not recorded.
   */
  _checkSession() {
    if (!this.session) {
      return false;
    }
    const currentSession = this.session;
    if (shouldRefreshSession(currentSession, {
      sessionIdleExpire: this.timeouts.sessionIdleExpire,
      maxReplayDuration: this._options.maxReplayDuration
    })) {
      this._refreshSession(currentSession);
      return false;
    }
    return true;
  }
  /**
   * Refresh a session with a new one.
   * This stops the current session (without forcing a flush, as that would never work since we are expired),
   * and then does a new sampling based on the refreshed session.
   */
  async _refreshSession(session) {
    if (!this._isEnabled) {
      return;
    }
    await this.stop({ reason: "refresh session" });
    this.initializeSampling(session.id);
  }
  /**
   * Adds listeners to record events for the replay
   */
  _addListeners() {
    try {
      WINDOW$1.document.addEventListener("visibilitychange", this._handleVisibilityChange);
      WINDOW$1.addEventListener("blur", this._handleWindowBlur);
      WINDOW$1.addEventListener("focus", this._handleWindowFocus);
      WINDOW$1.addEventListener("keydown", this._handleKeyboardEvent);
      if (this.clickDetector) {
        this.clickDetector.addListeners();
      }
      if (!this._hasInitializedCoreListeners) {
        addGlobalListeners(this);
        this._hasInitializedCoreListeners = true;
      }
    } catch (err) {
      this.handleException(err);
    }
    this._performanceCleanupCallback = setupPerformanceObserver(this);
  }
  /**
   * Cleans up listeners that were created in `_addListeners`
   */
  _removeListeners() {
    try {
      WINDOW$1.document.removeEventListener("visibilitychange", this._handleVisibilityChange);
      WINDOW$1.removeEventListener("blur", this._handleWindowBlur);
      WINDOW$1.removeEventListener("focus", this._handleWindowFocus);
      WINDOW$1.removeEventListener("keydown", this._handleKeyboardEvent);
      if (this.clickDetector) {
        this.clickDetector.removeListeners();
      }
      if (this._performanceCleanupCallback) {
        this._performanceCleanupCallback();
      }
    } catch (err) {
      this.handleException(err);
    }
  }
  /**
   * Handle when visibility of the page content changes. Opening a new tab will
   * cause the state to change to hidden because of content of current page will
   * be hidden. Likewise, moving a different window to cover the contents of the
   * page will also trigger a change to a hidden state.
   */
  __init() {
    this._handleVisibilityChange = () => {
      if (WINDOW$1.document.visibilityState === "visible") {
        this._doChangeToForegroundTasks();
      } else {
        this._doChangeToBackgroundTasks();
      }
    };
  }
  /**
   * Handle when page is blurred
   */
  __init2() {
    this._handleWindowBlur = () => {
      const breadcrumb = createBreadcrumb({
        category: "ui.blur"
      });
      this._doChangeToBackgroundTasks(breadcrumb);
    };
  }
  /**
   * Handle when page is focused
   */
  __init3() {
    this._handleWindowFocus = () => {
      const breadcrumb = createBreadcrumb({
        category: "ui.focus"
      });
      this._doChangeToForegroundTasks(breadcrumb);
    };
  }
  /** Ensure page remains active when a key is pressed. */
  __init4() {
    this._handleKeyboardEvent = (event) => {
      handleKeyboardEvent(this, event);
    };
  }
  /**
   * Tasks to run when we consider a page to be hidden (via blurring and/or visibility)
   */
  _doChangeToBackgroundTasks(breadcrumb) {
    if (!this.session) {
      return;
    }
    const expired = isSessionExpired(this.session, {
      maxReplayDuration: this._options.maxReplayDuration,
      sessionIdleExpire: this.timeouts.sessionIdleExpire
    });
    if (expired) {
      return;
    }
    if (breadcrumb) {
      this._createCustomBreadcrumb(breadcrumb);
    }
    void this.conditionalFlush();
  }
  /**
   * Tasks to run when we consider a page to be visible (via focus and/or visibility)
   */
  _doChangeToForegroundTasks(breadcrumb) {
    if (!this.session) {
      return;
    }
    const isSessionActive = this.checkAndHandleExpiredSession();
    if (!isSessionActive) {
      DEBUG_BUILD$2 && logger$1.info("Document has become active, but session has expired");
      return;
    }
    if (breadcrumb) {
      this._createCustomBreadcrumb(breadcrumb);
    }
  }
  /**
   * Update user activity (across session lifespans)
   */
  _updateUserActivity(_lastActivity = Date.now()) {
    this._lastActivity = _lastActivity;
  }
  /**
   * Updates the session's last activity timestamp
   */
  _updateSessionActivity(_lastActivity = Date.now()) {
    if (this.session) {
      this.session.lastActivity = _lastActivity;
      this._maybeSaveSession();
    }
  }
  /**
   * Helper to create (and buffer) a replay breadcrumb from a core SDK breadcrumb
   */
  _createCustomBreadcrumb(breadcrumb) {
    this.addUpdate(() => {
      this.throttledAddEvent({
        type: EventType.Custom,
        timestamp: breadcrumb.timestamp || 0,
        data: {
          tag: "breadcrumb",
          payload: breadcrumb
        }
      });
    });
  }
  /**
   * Observed performance events are added to `this.performanceEntries`. These
   * are included in the replay event before it is finished and sent to Sentry.
   */
  _addPerformanceEntries() {
    let performanceEntries = createPerformanceEntries(this.performanceEntries).concat(this.replayPerformanceEntries);
    this.performanceEntries = [];
    this.replayPerformanceEntries = [];
    if (this._requiresManualStart) {
      const initialTimestampInSeconds = this._context.initialTimestamp / 1e3;
      performanceEntries = performanceEntries.filter((entry) => entry.start >= initialTimestampInSeconds);
    }
    return Promise.all(createPerformanceSpans(this, performanceEntries));
  }
  /**
   * Clear _context
   */
  _clearContext() {
    this._context.errorIds.clear();
    this._context.traceIds.clear();
    this._context.urls = [];
  }
  /** Update the initial timestamp based on the buffer content. */
  _updateInitialTimestampFromEventBuffer() {
    const { session, eventBuffer } = this;
    if (!session || !eventBuffer || this._requiresManualStart) {
      return;
    }
    if (session.segmentId) {
      return;
    }
    const earliestEvent = eventBuffer.getEarliestTimestamp();
    if (earliestEvent && earliestEvent < this._context.initialTimestamp) {
      this._context.initialTimestamp = earliestEvent;
    }
  }
  /**
   * Return and clear _context
   */
  _popEventContext() {
    const _context = {
      initialTimestamp: this._context.initialTimestamp,
      initialUrl: this._context.initialUrl,
      errorIds: Array.from(this._context.errorIds),
      traceIds: Array.from(this._context.traceIds),
      urls: this._context.urls
    };
    this._clearContext();
    return _context;
  }
  /**
   * Flushes replay event buffer to Sentry.
   *
   * Performance events are only added right before flushing - this is
   * due to the buffered performance observer events.
   *
   * Should never be called directly, only by `flush`
   */
  async _runFlush() {
    const replayId = this.getSessionId();
    if (!this.session || !this.eventBuffer || !replayId) {
      DEBUG_BUILD$2 && logger$1.error("No session or eventBuffer found to flush.");
      return;
    }
    await this._addPerformanceEntries();
    if (!this.eventBuffer || !this.eventBuffer.hasEvents) {
      return;
    }
    await addMemoryEntry(this);
    if (!this.eventBuffer) {
      return;
    }
    if (replayId !== this.getSessionId()) {
      return;
    }
    try {
      this._updateInitialTimestampFromEventBuffer();
      const timestamp2 = Date.now();
      if (timestamp2 - this._context.initialTimestamp > this._options.maxReplayDuration + 3e4) {
        throw new Error("Session is too long, not sending replay");
      }
      const eventContext = this._popEventContext();
      const segmentId = this.session.segmentId++;
      this._maybeSaveSession();
      const recordingData = await this.eventBuffer.finish();
      await sendReplay({
        replayId,
        recordingData,
        segmentId,
        eventContext,
        session: this.session,
        timestamp: timestamp2,
        onError: /* @__PURE__ */ __name((err) => this.handleException(err), "onError")
      });
    } catch (err) {
      this.handleException(err);
      this.stop({ reason: "sendReplay" });
      const client = getClient();
      if (client) {
        const dropReason = err instanceof RateLimitError ? "ratelimit_backoff" : "send_error";
        client.recordDroppedEvent(dropReason, "replay");
      }
    }
  }
  /**
   * Flush recording data to Sentry. Creates a lock so that only a single flush
   * can be active at a time. Do not call this directly.
   */
  __init5() {
    this._flush = async ({
      force = false
    } = {}) => {
      if (!this._isEnabled && !force) {
        return;
      }
      if (!this.checkAndHandleExpiredSession()) {
        DEBUG_BUILD$2 && logger$1.error("Attempting to finish replay event after session expired.");
        return;
      }
      if (!this.session) {
        return;
      }
      const start2 = this.session.started;
      const now2 = Date.now();
      const duration = now2 - start2;
      this._debouncedFlush.cancel();
      const tooShort = duration < this._options.minReplayDuration;
      const tooLong = duration > this._options.maxReplayDuration + 5e3;
      if (tooShort || tooLong) {
        DEBUG_BUILD$2 && logger$1.info(
          `Session duration (${Math.floor(duration / 1e3)}s) is too ${tooShort ? "short" : "long"}, not sending replay.`
        );
        if (tooShort) {
          this._debouncedFlush();
        }
        return;
      }
      const eventBuffer = this.eventBuffer;
      if (eventBuffer && this.session.segmentId === 0 && !eventBuffer.hasCheckout) {
        DEBUG_BUILD$2 && logger$1.info("Flushing initial segment without checkout.");
      }
      const _flushInProgress = !!this._flushLock;
      if (!this._flushLock) {
        this._flushLock = this._runFlush();
      }
      try {
        await this._flushLock;
      } catch (err) {
        this.handleException(err);
      } finally {
        this._flushLock = void 0;
        if (_flushInProgress) {
          this._debouncedFlush();
        }
      }
    };
  }
  /** Save the session, if it is sticky */
  _maybeSaveSession() {
    if (this.session && this._options.stickySession) {
      saveSession(this.session);
    }
  }
  /** Handler for rrweb.record.onMutation */
  __init6() {
    this._onMutationHandler = (mutations) => {
      const count = mutations.length;
      const mutationLimit = this._options.mutationLimit;
      const mutationBreadcrumbLimit = this._options.mutationBreadcrumbLimit;
      const overMutationLimit = mutationLimit && count > mutationLimit;
      if (count > mutationBreadcrumbLimit || overMutationLimit) {
        const breadcrumb = createBreadcrumb({
          category: "replay.mutations",
          data: {
            count,
            limit: overMutationLimit
          }
        });
        this._createCustomBreadcrumb(breadcrumb);
      }
      if (overMutationLimit) {
        this.stop({ reason: "mutationLimit", forceFlush: this.recordingMode === "session" });
        return false;
      }
      return true;
    };
  }
}
function getOption(selectors, defaultSelectors) {
  return [
    ...selectors,
    // sentry defaults
    ...defaultSelectors
  ].join(",");
}
__name(getOption, "getOption");
function getPrivacyOptions({ mask: mask3, unmask, block: block3, unblock: unblock2, ignore }) {
  const defaultBlockedElements = ["base", "iframe[srcdoc]:not([src])"];
  const maskSelector = getOption(mask3, [".sentry-mask", "[data-sentry-mask]"]);
  const unmaskSelector = getOption(unmask, []);
  const options5 = {
    // We are making the decision to make text and input selectors the same
    maskTextSelector: maskSelector,
    unmaskTextSelector: unmaskSelector,
    blockSelector: getOption(block3, [".sentry-block", "[data-sentry-block]", ...defaultBlockedElements]),
    unblockSelector: getOption(unblock2, []),
    ignoreSelector: getOption(ignore, [".sentry-ignore", "[data-sentry-ignore]", 'input[type="file"]'])
  };
  return options5;
}
__name(getPrivacyOptions, "getPrivacyOptions");
function maskAttribute({
  el,
  key,
  maskAttributes,
  maskAllText,
  privacyOptions,
  value: value3
}) {
  if (!maskAllText) {
    return value3;
  }
  if (privacyOptions.unmaskTextSelector && el.matches(privacyOptions.unmaskTextSelector)) {
    return value3;
  }
  if (maskAttributes.includes(key) || // Need to mask `value` attribute for `<input>` if it's a button-like
  // type
  key === "value" && el.tagName === "INPUT" && ["submit", "button"].includes(el.getAttribute("type") || "")) {
    return value3.replace(/[\S]/g, "*");
  }
  return value3;
}
__name(maskAttribute, "maskAttribute");
const MEDIA_SELECTORS = 'img,image,svg,video,object,picture,embed,map,audio,link[rel="icon"],link[rel="apple-touch-icon"]';
const DEFAULT_NETWORK_HEADERS = ["content-length", "content-type", "accept"];
let _initialized = false;
const replayIntegration = /* @__PURE__ */ __name((options5) => {
  return new Replay(options5);
}, "replayIntegration");
class Replay {
  static {
    __name(this, "Replay");
  }
  /**
   * @inheritDoc
   */
  static __initStatic() {
    this.id = "Replay";
  }
  /**
   * @inheritDoc
   */
  /**
   * Options to pass to `rrweb.record()`
   */
  /**
   * Initial options passed to the replay integration, merged with default values.
   * Note: `sessionSampleRate` and `errorSampleRate` are not required here, as they
   * can only be finally set when setupOnce() is called.
   *
   * @private
   */
  constructor({
    flushMinDelay = DEFAULT_FLUSH_MIN_DELAY,
    flushMaxDelay = DEFAULT_FLUSH_MAX_DELAY,
    minReplayDuration = MIN_REPLAY_DURATION,
    maxReplayDuration = MAX_REPLAY_DURATION,
    stickySession = true,
    useCompression = true,
    workerUrl,
    _experiments = {},
    maskAllText = true,
    maskAllInputs = true,
    blockAllMedia = true,
    mutationBreadcrumbLimit = 750,
    mutationLimit = 1e4,
    slowClickTimeout = 7e3,
    slowClickIgnoreSelectors = [],
    networkDetailAllowUrls = [],
    networkDetailDenyUrls = [],
    networkCaptureBodies = true,
    networkRequestHeaders = [],
    networkResponseHeaders = [],
    mask: mask3 = [],
    maskAttributes = ["title", "placeholder"],
    unmask = [],
    block: block3 = [],
    unblock: unblock2 = [],
    ignore = [],
    maskFn,
    beforeAddRecordingEvent,
    beforeErrorSampling,
    onError
  } = {}) {
    this.name = Replay.id;
    const privacyOptions = getPrivacyOptions({
      mask: mask3,
      unmask,
      block: block3,
      unblock: unblock2,
      ignore
    });
    this._recordingOptions = {
      maskAllInputs,
      maskAllText,
      maskInputOptions: { password: true },
      maskTextFn: maskFn,
      maskInputFn: maskFn,
      maskAttributeFn: /* @__PURE__ */ __name((key, value3, el) => maskAttribute({
        maskAttributes,
        maskAllText,
        privacyOptions,
        key,
        value: value3,
        el
      }), "maskAttributeFn"),
      ...privacyOptions,
      // Our defaults
      slimDOMOptions: "all",
      inlineStylesheet: true,
      // Disable inline images as it will increase segment/replay size
      inlineImages: false,
      // collect fonts, but be aware that `sentry.io` needs to be an allowed
      // origin for playback
      collectFonts: true,
      errorHandler: /* @__PURE__ */ __name((err) => {
        try {
          err.__rrweb__ = true;
        } catch (error2) {
        }
      }, "errorHandler")
    };
    this._initialOptions = {
      flushMinDelay,
      flushMaxDelay,
      minReplayDuration: Math.min(minReplayDuration, MIN_REPLAY_DURATION_LIMIT),
      maxReplayDuration: Math.min(maxReplayDuration, MAX_REPLAY_DURATION),
      stickySession,
      useCompression,
      workerUrl,
      blockAllMedia,
      maskAllInputs,
      maskAllText,
      mutationBreadcrumbLimit,
      mutationLimit,
      slowClickTimeout,
      slowClickIgnoreSelectors,
      networkDetailAllowUrls,
      networkDetailDenyUrls,
      networkCaptureBodies,
      networkRequestHeaders: _getMergedNetworkHeaders(networkRequestHeaders),
      networkResponseHeaders: _getMergedNetworkHeaders(networkResponseHeaders),
      beforeAddRecordingEvent,
      beforeErrorSampling,
      onError,
      _experiments
    };
    if (this._initialOptions.blockAllMedia) {
      this._recordingOptions.blockSelector = !this._recordingOptions.blockSelector ? MEDIA_SELECTORS : `${this._recordingOptions.blockSelector},${MEDIA_SELECTORS}`;
    }
    if (this._isInitialized && isBrowser$1()) {
      throw new Error("Multiple Sentry Session Replay instances are not supported");
    }
    this._isInitialized = true;
  }
  /** If replay has already been initialized */
  get _isInitialized() {
    return _initialized;
  }
  /** Update _isInitialized */
  set _isInitialized(value3) {
    _initialized = value3;
  }
  /**
   * Setup and initialize replay container
   */
  afterAllSetup(client) {
    if (!isBrowser$1() || this._replay) {
      return;
    }
    this._setup(client);
    this._initialize(client);
  }
  /**
   * Start a replay regardless of sampling rate. Calling this will always
   * create a new session. Will log a message if replay is already in progress.
   *
   * Creates or loads a session, attaches listeners to varying events (DOM,
   * PerformanceObserver, Recording, Sentry SDK, etc)
   */
  start() {
    if (!this._replay) {
      return;
    }
    this._replay.start();
  }
  /**
   * Start replay buffering. Buffers until `flush()` is called or, if
   * `replaysOnErrorSampleRate` > 0, until an error occurs.
   */
  startBuffering() {
    if (!this._replay) {
      return;
    }
    this._replay.startBuffering();
  }
  /**
   * Currently, this needs to be manually called (e.g. for tests). Sentry SDK
   * does not support a teardown
   */
  stop() {
    if (!this._replay) {
      return Promise.resolve();
    }
    return this._replay.stop({ forceFlush: this._replay.recordingMode === "session" });
  }
  /**
   * If not in "session" recording mode, flush event buffer which will create a new replay.
   * If replay is not enabled, a new session replay is started.
   * Unless `continueRecording` is false, the replay will continue to record and
   * behave as a "session"-based replay.
   *
   * Otherwise, queue up a flush.
   */
  flush(options5) {
    if (!this._replay) {
      return Promise.resolve();
    }
    if (!this._replay.isEnabled()) {
      this._replay.start();
      return Promise.resolve();
    }
    return this._replay.sendBufferedReplayOrFlush(options5);
  }
  /**
   * Get the current session ID.
   */
  getReplayId() {
    if (!this._replay || !this._replay.isEnabled()) {
      return;
    }
    return this._replay.getSessionId();
  }
  /**
   * Get the current recording mode. This can be either `session` or `buffer`.
   *
   * `session`: Recording the whole session, sending it continuously
   * `buffer`: Always keeping the last 60s of recording, requires:
   *   - having replaysOnErrorSampleRate > 0 to capture replay when an error occurs
   *   - or calling `flush()` to send the replay
   */
  getRecordingMode() {
    if (!this._replay || !this._replay.isEnabled()) {
      return;
    }
    return this._replay.recordingMode;
  }
  /**
   * Initializes replay.
   */
  _initialize(client) {
    if (!this._replay) {
      return;
    }
    this._maybeLoadFromReplayCanvasIntegration(client);
    this._replay.initializeSampling();
  }
  /** Setup the integration. */
  _setup(client) {
    const finalOptions = loadReplayOptionsFromClient(this._initialOptions, client);
    this._replay = new ReplayContainer({
      options: finalOptions,
      recordingOptions: this._recordingOptions
    });
  }
  /** Get canvas options from ReplayCanvas integration, if it is also added. */
  _maybeLoadFromReplayCanvasIntegration(client) {
    try {
      const canvasIntegration = client.getIntegrationByName("ReplayCanvas");
      if (!canvasIntegration) {
        return;
      }
      this._replay["_canvas"] = canvasIntegration.getOptions();
    } catch (e2) {
    }
  }
}
Replay.__initStatic();
function loadReplayOptionsFromClient(initialOptions, client) {
  const opt = client.getOptions();
  const finalOptions = {
    sessionSampleRate: 0,
    errorSampleRate: 0,
    ...dropUndefinedKeys(initialOptions)
  };
  const replaysSessionSampleRate = parseSampleRate(opt.replaysSessionSampleRate);
  const replaysOnErrorSampleRate = parseSampleRate(opt.replaysOnErrorSampleRate);
  if (replaysSessionSampleRate == null && replaysOnErrorSampleRate == null) {
    consoleSandbox(() => {
      console.warn(
        "Replay is disabled because neither `replaysSessionSampleRate` nor `replaysOnErrorSampleRate` are set."
      );
    });
  }
  if (replaysSessionSampleRate != null) {
    finalOptions.sessionSampleRate = replaysSessionSampleRate;
  }
  if (replaysOnErrorSampleRate != null) {
    finalOptions.errorSampleRate = replaysOnErrorSampleRate;
  }
  return finalOptions;
}
__name(loadReplayOptionsFromClient, "loadReplayOptionsFromClient");
function _getMergedNetworkHeaders(headers) {
  return [...DEFAULT_NETWORK_HEADERS, ...headers.map((header3) => header3.toLowerCase())];
}
__name(_getMergedNetworkHeaders, "_getMergedNetworkHeaders");
function getReplay() {
  const client = getClient();
  return client && client.getIntegrationByName("Replay");
}
__name(getReplay, "getReplay");
var NodeType$2;
(function(NodeType3) {
  NodeType3[NodeType3["Document"] = 0] = "Document";
  NodeType3[NodeType3["DocumentType"] = 1] = "DocumentType";
  NodeType3[NodeType3["Element"] = 2] = "Element";
  NodeType3[NodeType3["Text"] = 3] = "Text";
  NodeType3[NodeType3["CDATA"] = 4] = "CDATA";
  NodeType3[NodeType3["Comment"] = 5] = "Comment";
})(NodeType$2 || (NodeType$2 = {}));
function elementClassMatchesRegex(el, regex2) {
  for (let eIndex = el.classList.length; eIndex--; ) {
    const className = el.classList[eIndex];
    if (regex2.test(className)) {
      return true;
    }
  }
  return false;
}
__name(elementClassMatchesRegex, "elementClassMatchesRegex");
function distanceToMatch(node3, matchPredicate, limit = Infinity, distance2 = 0) {
  if (!node3)
    return -1;
  if (node3.nodeType !== node3.ELEMENT_NODE)
    return -1;
  if (distance2 > limit)
    return -1;
  if (matchPredicate(node3))
    return distance2;
  return distanceToMatch(node3.parentNode, matchPredicate, limit, distance2 + 1);
}
__name(distanceToMatch, "distanceToMatch");
function createMatchPredicate(className, selector) {
  return (node3) => {
    const el = node3;
    if (el === null)
      return false;
    try {
      if (className) {
        if (typeof className === "string") {
          if (el.matches(`.${className}`))
            return true;
        } else if (elementClassMatchesRegex(el, className)) {
          return true;
        }
      }
      if (selector && el.matches(selector))
        return true;
      return false;
    } catch (e2) {
      return false;
    }
  };
}
__name(createMatchPredicate, "createMatchPredicate");
const DEPARTED_MIRROR_ACCESS_WARNING = "Please stop import mirror directly. Instead of that,\r\nnow you can use replayer.getMirror() to access the mirror instance of a replayer,\r\nor you can use record.mirror to access the mirror instance during recording.";
let _mirror = {
  map: {},
  getId() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING);
    return -1;
  },
  getNode() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING);
    return null;
  },
  removeNodeFromMap() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING);
  },
  has() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING);
    return false;
  },
  reset() {
    console.error(DEPARTED_MIRROR_ACCESS_WARNING);
  }
};
if (typeof window !== "undefined" && window.Proxy && window.Reflect) {
  _mirror = new Proxy(_mirror, {
    get(target2, prop2, receiver) {
      if (prop2 === "map") {
        console.error(DEPARTED_MIRROR_ACCESS_WARNING);
      }
      return Reflect.get(target2, prop2, receiver);
    }
  });
}
function hookSetter(target2, key, d2, isRevoked, win = window) {
  const original = win.Object.getOwnPropertyDescriptor(target2, key);
  win.Object.defineProperty(target2, key, isRevoked ? d2 : {
    set(value3) {
      setTimeout$1(() => {
        d2.set.call(this, value3);
      }, 0);
      if (original && original.set) {
        original.set.call(this, value3);
      }
    }
  });
  return () => hookSetter(target2, key, original || {}, true);
}
__name(hookSetter, "hookSetter");
function patch$1(source, name2, replacement) {
  try {
    if (!(name2 in source)) {
      return () => {
      };
    }
    const original = source[name2];
    const wrapped = replacement(original);
    if (typeof wrapped === "function") {
      wrapped.prototype = wrapped.prototype || {};
      Object.defineProperties(wrapped, {
        __rrweb_original__: {
          enumerable: false,
          value: original
        }
      });
    }
    source[name2] = wrapped;
    return () => {
      source[name2] = original;
    };
  } catch (e2) {
    return () => {
    };
  }
}
__name(patch$1, "patch$1");
if (!/[1-9][0-9]{12}/.test(Date.now().toString())) ;
function closestElementOfNode(node3) {
  if (!node3) {
    return null;
  }
  const el = node3.nodeType === node3.ELEMENT_NODE ? node3 : node3.parentElement;
  return el;
}
__name(closestElementOfNode, "closestElementOfNode");
function isBlocked(node3, blockClass, blockSelector, unblockSelector, checkAncestors) {
  if (!node3) {
    return false;
  }
  const el = closestElementOfNode(node3);
  if (!el) {
    return false;
  }
  const blockedPredicate = createMatchPredicate(blockClass, blockSelector);
  const blockDistance = distanceToMatch(el, blockedPredicate);
  let unblockDistance = -1;
  if (blockDistance < 0) {
    return false;
  }
  if (unblockSelector) {
    unblockDistance = distanceToMatch(el, createMatchPredicate(null, unblockSelector));
  }
  if (blockDistance > -1 && unblockDistance < 0) {
    return true;
  }
  return blockDistance < unblockDistance;
}
__name(isBlocked, "isBlocked");
const cachedImplementations = {};
function getImplementation(name2) {
  const cached = cachedImplementations[name2];
  if (cached) {
    return cached;
  }
  const document2 = window.document;
  let impl = window[name2];
  if (document2 && typeof document2.createElement === "function") {
    try {
      const sandbox = document2.createElement("iframe");
      sandbox.hidden = true;
      document2.head.appendChild(sandbox);
      const contentWindow = sandbox.contentWindow;
      if (contentWindow && contentWindow[name2]) {
        impl = contentWindow[name2];
      }
      document2.head.removeChild(sandbox);
    } catch (e2) {
    }
  }
  return cachedImplementations[name2] = impl.bind(window);
}
__name(getImplementation, "getImplementation");
function onRequestAnimationFrame(...rest) {
  return getImplementation("requestAnimationFrame")(...rest);
}
__name(onRequestAnimationFrame, "onRequestAnimationFrame");
function setTimeout$1(...rest) {
  return getImplementation("setTimeout")(...rest);
}
__name(setTimeout$1, "setTimeout$1");
var CanvasContext = /* @__PURE__ */ ((CanvasContext2) => {
  CanvasContext2[CanvasContext2["2D"] = 0] = "2D";
  CanvasContext2[CanvasContext2["WebGL"] = 1] = "WebGL";
  CanvasContext2[CanvasContext2["WebGL2"] = 2] = "WebGL2";
  return CanvasContext2;
})(CanvasContext || {});
let errorHandler;
function registerErrorHandler(handler14) {
  errorHandler = handler14;
}
__name(registerErrorHandler, "registerErrorHandler");
const callbackWrapper = /* @__PURE__ */ __name((cb) => {
  if (!errorHandler) {
    return cb;
  }
  const rrwebWrapped = /* @__PURE__ */ __name((...rest) => {
    try {
      return cb(...rest);
    } catch (error2) {
      if (errorHandler && errorHandler(error2) === true) {
        return () => {
        };
      }
      throw error2;
    }
  }, "rrwebWrapped");
  return rrwebWrapped;
}, "callbackWrapper");
var chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
var lookup = typeof Uint8Array === "undefined" ? [] : new Uint8Array(256);
for (var i$3 = 0; i$3 < chars.length; i$3++) {
  lookup[chars.charCodeAt(i$3)] = i$3;
}
var encode$5 = /* @__PURE__ */ __name(function(arraybuffer) {
  var bytes = new Uint8Array(arraybuffer), i2, len = bytes.length, base64 = "";
  for (i2 = 0; i2 < len; i2 += 3) {
    base64 += chars[bytes[i2] >> 2];
    base64 += chars[(bytes[i2] & 3) << 4 | bytes[i2 + 1] >> 4];
    base64 += chars[(bytes[i2 + 1] & 15) << 2 | bytes[i2 + 2] >> 6];
    base64 += chars[bytes[i2 + 2] & 63];
  }
  if (len % 3 === 2) {
    base64 = base64.substring(0, base64.length - 1) + "=";
  } else if (len % 3 === 1) {
    base64 = base64.substring(0, base64.length - 2) + "==";
  }
  return base64;
}, "encode$5");
const canvasVarMap = /* @__PURE__ */ new Map();
function variableListFor(ctx, ctor) {
  let contextMap = canvasVarMap.get(ctx);
  if (!contextMap) {
    contextMap = /* @__PURE__ */ new Map();
    canvasVarMap.set(ctx, contextMap);
  }
  if (!contextMap.has(ctor)) {
    contextMap.set(ctor, []);
  }
  return contextMap.get(ctor);
}
__name(variableListFor, "variableListFor");
const saveWebGLVar = /* @__PURE__ */ __name((value3, win, ctx) => {
  if (!value3 || !(isInstanceOfWebGLObject(value3, win) || typeof value3 === "object"))
    return;
  const name2 = value3.constructor.name;
  const list2 = variableListFor(ctx, name2);
  let index2 = list2.indexOf(value3);
  if (index2 === -1) {
    index2 = list2.length;
    list2.push(value3);
  }
  return index2;
}, "saveWebGLVar");
function serializeArg(value3, win, ctx) {
  if (value3 instanceof Array) {
    return value3.map((arg) => serializeArg(arg, win, ctx));
  } else if (value3 === null) {
    return value3;
  } else if (value3 instanceof Float32Array || value3 instanceof Float64Array || value3 instanceof Int32Array || value3 instanceof Uint32Array || value3 instanceof Uint8Array || value3 instanceof Uint16Array || value3 instanceof Int16Array || value3 instanceof Int8Array || value3 instanceof Uint8ClampedArray) {
    const name2 = value3.constructor.name;
    return {
      rr_type: name2,
      args: [Object.values(value3)]
    };
  } else if (value3 instanceof ArrayBuffer) {
    const name2 = value3.constructor.name;
    const base64 = encode$5(value3);
    return {
      rr_type: name2,
      base64
    };
  } else if (value3 instanceof DataView) {
    const name2 = value3.constructor.name;
    return {
      rr_type: name2,
      args: [
        serializeArg(value3.buffer, win, ctx),
        value3.byteOffset,
        value3.byteLength
      ]
    };
  } else if (value3 instanceof HTMLImageElement) {
    const name2 = value3.constructor.name;
    const { src } = value3;
    return {
      rr_type: name2,
      src
    };
  } else if (value3 instanceof HTMLCanvasElement) {
    const name2 = "HTMLImageElement";
    const src = value3.toDataURL();
    return {
      rr_type: name2,
      src
    };
  } else if (value3 instanceof ImageData) {
    const name2 = value3.constructor.name;
    return {
      rr_type: name2,
      args: [serializeArg(value3.data, win, ctx), value3.width, value3.height]
    };
  } else if (isInstanceOfWebGLObject(value3, win) || typeof value3 === "object") {
    const name2 = value3.constructor.name;
    const index2 = saveWebGLVar(value3, win, ctx);
    return {
      rr_type: name2,
      index: index2
    };
  }
  return value3;
}
__name(serializeArg, "serializeArg");
const serializeArgs = /* @__PURE__ */ __name((args, win, ctx) => {
  return args.map((arg) => serializeArg(arg, win, ctx));
}, "serializeArgs");
const isInstanceOfWebGLObject = /* @__PURE__ */ __name((value3, win) => {
  const webGLConstructorNames = [
    "WebGLActiveInfo",
    "WebGLBuffer",
    "WebGLFramebuffer",
    "WebGLProgram",
    "WebGLRenderbuffer",
    "WebGLShader",
    "WebGLShaderPrecisionFormat",
    "WebGLTexture",
    "WebGLUniformLocation",
    "WebGLVertexArrayObject",
    "WebGLVertexArrayObjectOES"
  ];
  const supportedWebGLConstructorNames = webGLConstructorNames.filter((name2) => typeof win[name2] === "function");
  return Boolean(supportedWebGLConstructorNames.find((name2) => value3 instanceof win[name2]));
}, "isInstanceOfWebGLObject");
function initCanvas2DMutationObserver(cb, win, blockClass, blockSelector, unblockSelector) {
  const handlers2 = [];
  const props2D = Object.getOwnPropertyNames(win.CanvasRenderingContext2D.prototype);
  for (const prop2 of props2D) {
    try {
      if (typeof win.CanvasRenderingContext2D.prototype[prop2] !== "function") {
        continue;
      }
      const restoreHandler = patch$1(win.CanvasRenderingContext2D.prototype, prop2, function(original) {
        return function(...args) {
          if (!isBlocked(this.canvas, blockClass, blockSelector, unblockSelector, true)) {
            setTimeout$1(() => {
              const recordArgs = serializeArgs(args, win, this);
              cb(this.canvas, {
                type: CanvasContext["2D"],
                property: prop2,
                args: recordArgs
              });
            }, 0);
          }
          return original.apply(this, args);
        };
      });
      handlers2.push(restoreHandler);
    } catch (e2) {
      const hookHandler = hookSetter(win.CanvasRenderingContext2D.prototype, prop2, {
        set(v2) {
          cb(this.canvas, {
            type: CanvasContext["2D"],
            property: prop2,
            args: [v2],
            setter: true
          });
        }
      });
      handlers2.push(hookHandler);
    }
  }
  return () => {
    handlers2.forEach((h2) => h2());
  };
}
__name(initCanvas2DMutationObserver, "initCanvas2DMutationObserver");
function getNormalizedContextName(contextType) {
  return contextType === "experimental-webgl" ? "webgl" : contextType;
}
__name(getNormalizedContextName, "getNormalizedContextName");
function initCanvasContextObserver(win, blockClass, blockSelector, unblockSelector, setPreserveDrawingBufferToTrue) {
  const handlers2 = [];
  try {
    const restoreHandler = patch$1(win.HTMLCanvasElement.prototype, "getContext", function(original) {
      return function(contextType, ...args) {
        if (!isBlocked(this, blockClass, blockSelector, unblockSelector, true)) {
          const ctxName = getNormalizedContextName(contextType);
          if (!("__context" in this))
            this.__context = ctxName;
          if (setPreserveDrawingBufferToTrue && ["webgl", "webgl2"].includes(ctxName)) {
            if (args[0] && typeof args[0] === "object") {
              const contextAttributes = args[0];
              if (!contextAttributes.preserveDrawingBuffer) {
                contextAttributes.preserveDrawingBuffer = true;
              }
            } else {
              args.splice(0, 1, {
                preserveDrawingBuffer: true
              });
            }
          }
        }
        return original.apply(this, [contextType, ...args]);
      };
    });
    handlers2.push(restoreHandler);
  } catch (e2) {
    console.error("failed to patch HTMLCanvasElement.prototype.getContext");
  }
  return () => {
    handlers2.forEach((h2) => h2());
  };
}
__name(initCanvasContextObserver, "initCanvasContextObserver");
function patchGLPrototype(prototype2, type, cb, blockClass, blockSelector, unblockSelector, mirror2, win) {
  const handlers2 = [];
  const props = Object.getOwnPropertyNames(prototype2);
  for (const prop2 of props) {
    if ([
      "isContextLost",
      "canvas",
      "drawingBufferWidth",
      "drawingBufferHeight"
    ].includes(prop2)) {
      continue;
    }
    try {
      if (typeof prototype2[prop2] !== "function") {
        continue;
      }
      const restoreHandler = patch$1(prototype2, prop2, function(original) {
        return function(...args) {
          const result = original.apply(this, args);
          saveWebGLVar(result, win, this);
          if ("tagName" in this.canvas && !isBlocked(this.canvas, blockClass, blockSelector, unblockSelector, true)) {
            const recordArgs = serializeArgs(args, win, this);
            const mutation = {
              type,
              property: prop2,
              args: recordArgs
            };
            cb(this.canvas, mutation);
          }
          return result;
        };
      });
      handlers2.push(restoreHandler);
    } catch (e2) {
      const hookHandler = hookSetter(prototype2, prop2, {
        set(v2) {
          cb(this.canvas, {
            type,
            property: prop2,
            args: [v2],
            setter: true
          });
        }
      });
      handlers2.push(hookHandler);
    }
  }
  return handlers2;
}
__name(patchGLPrototype, "patchGLPrototype");
function initCanvasWebGLMutationObserver(cb, win, blockClass, blockSelector, unblockSelector, mirror2) {
  const handlers2 = [];
  handlers2.push(...patchGLPrototype(win.WebGLRenderingContext.prototype, CanvasContext.WebGL, cb, blockClass, blockSelector, unblockSelector, mirror2, win));
  if (typeof win.WebGL2RenderingContext !== "undefined") {
    handlers2.push(...patchGLPrototype(win.WebGL2RenderingContext.prototype, CanvasContext.WebGL2, cb, blockClass, blockSelector, unblockSelector, mirror2, win));
  }
  return () => {
    handlers2.forEach((h2) => h2());
  };
}
__name(initCanvasWebGLMutationObserver, "initCanvasWebGLMutationObserver");
var r$2 = `for(var e="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t="undefined"==typeof Uint8Array?[]:new Uint8Array(256),a=0;a<64;a++)t[e.charCodeAt(a)]=a;var n=function(t){var a,n=new Uint8Array(t),r=n.length,s="";for(a=0;a<r;a+=3)s+=e[n[a]>>2],s+=e[(3&n[a])<<4|n[a+1]>>4],s+=e[(15&n[a+1])<<2|n[a+2]>>6],s+=e[63&n[a+2]];return r%3==2?s=s.substring(0,s.length-1)+"=":r%3==1&&(s=s.substring(0,s.length-2)+"=="),s};const r=new Map,s=new Map;const i=self;i.onmessage=async function(e){if(!("OffscreenCanvas"in globalThis))return i.postMessage({id:e.data.id});{const{id:t,bitmap:a,width:o,height:f,maxCanvasSize:c,dataURLOptions:g}=e.data,u=async function(e,t,a){const r=e+"-"+t;if("OffscreenCanvas"in globalThis){if(s.has(r))return s.get(r);const i=new OffscreenCanvas(e,t);i.getContext("2d");const o=await i.convertToBlob(a),f=await o.arrayBuffer(),c=n(f);return s.set(r,c),c}return""}(o,f,g),[h,d]=function(e,t,a){if(!a)return[e,t];const[n,r]=a;if(e<=n&&t<=r)return[e,t];let s=e,i=t;return s>n&&(i=Math.floor(n*t/e),s=n),i>r&&(s=Math.floor(r*e/t),i=r),[s,i]}(o,f,c),l=new OffscreenCanvas(h,d),w=l.getContext("bitmaprenderer"),p=h===o&&d===f?a:await createImageBitmap(a,{resizeWidth:h,resizeHeight:d,resizeQuality:"low"});w.transferFromImageBitmap(p),a.close();const y=await l.convertToBlob(g),v=y.type,b=await y.arrayBuffer(),m=n(b);if(p.close(),!r.has(t)&&await u===m)return r.set(t,m),i.postMessage({id:t});if(r.get(t)===m)return i.postMessage({id:t});i.postMessage({id:t,type:v,base64:m,width:o,height:f}),r.set(t,m)}};`;
function t$2() {
  const t2 = new Blob([r$2]);
  return URL.createObjectURL(t2);
}
__name(t$2, "t$2");
class CanvasManager {
  static {
    __name(this, "CanvasManager");
  }
  reset() {
    this.pendingCanvasMutations.clear();
    this.restoreHandlers.forEach((handler14) => {
      try {
        handler14();
      } catch (e2) {
      }
    });
    this.restoreHandlers = [];
    this.windowsSet = /* @__PURE__ */ new WeakSet();
    this.windows = [];
    this.shadowDoms = /* @__PURE__ */ new Set();
    _optionalChain([this, "access", (_2) => _2.worker, "optionalAccess", (_2) => _2.terminate, "call", (_3) => _3()]);
    this.worker = null;
    this.snapshotInProgressMap = /* @__PURE__ */ new Map();
  }
  freeze() {
    this.frozen = true;
  }
  unfreeze() {
    this.frozen = false;
  }
  lock() {
    this.locked = true;
  }
  unlock() {
    this.locked = false;
  }
  constructor(options5) {
    this.pendingCanvasMutations = /* @__PURE__ */ new Map();
    this.rafStamps = { latestId: 0, invokeId: null };
    this.shadowDoms = /* @__PURE__ */ new Set();
    this.windowsSet = /* @__PURE__ */ new WeakSet();
    this.windows = [];
    this.restoreHandlers = [];
    this.frozen = false;
    this.locked = false;
    this.snapshotInProgressMap = /* @__PURE__ */ new Map();
    this.worker = null;
    this.processMutation = (target2, mutation) => {
      const newFrame = this.rafStamps.invokeId && this.rafStamps.latestId !== this.rafStamps.invokeId;
      if (newFrame || !this.rafStamps.invokeId)
        this.rafStamps.invokeId = this.rafStamps.latestId;
      if (!this.pendingCanvasMutations.has(target2)) {
        this.pendingCanvasMutations.set(target2, []);
      }
      this.pendingCanvasMutations.get(target2).push(mutation);
    };
    const { sampling = "all", win, blockClass, blockSelector, unblockSelector, maxCanvasSize, recordCanvas, dataURLOptions, errorHandler: errorHandler2 } = options5;
    this.mutationCb = options5.mutationCb;
    this.mirror = options5.mirror;
    this.options = options5;
    if (errorHandler2) {
      registerErrorHandler(errorHandler2);
    }
    if (recordCanvas && typeof sampling === "number" || options5.enableManualSnapshot) {
      this.worker = this.initFPSWorker();
    }
    this.addWindow(win);
    if (options5.enableManualSnapshot) {
      return;
    }
    callbackWrapper(() => {
      if (recordCanvas && sampling === "all") {
        this.startRAFTimestamping();
        this.startPendingCanvasMutationFlusher();
      }
      if (recordCanvas && typeof sampling === "number") {
        this.initCanvasFPSObserver(sampling, blockClass, blockSelector, unblockSelector, maxCanvasSize, {
          dataURLOptions
        });
      }
    })();
  }
  addWindow(win) {
    const { sampling = "all", blockClass, blockSelector, unblockSelector, recordCanvas, enableManualSnapshot } = this.options;
    if (this.windowsSet.has(win))
      return;
    if (enableManualSnapshot) {
      this.windowsSet.add(win);
      this.windows.push(new WeakRef(win));
      return;
    }
    callbackWrapper(() => {
      if (recordCanvas && sampling === "all") {
        this.initCanvasMutationObserver(win, blockClass, blockSelector, unblockSelector);
      }
      if (recordCanvas && typeof sampling === "number") {
        const canvasContextReset = initCanvasContextObserver(win, blockClass, blockSelector, unblockSelector, true);
        this.restoreHandlers.push(() => {
          canvasContextReset();
        });
      }
    })();
    this.windowsSet.add(win);
    this.windows.push(new WeakRef(win));
  }
  addShadowRoot(shadowRoot) {
    this.shadowDoms.add(new WeakRef(shadowRoot));
  }
  resetShadowRoots() {
    this.shadowDoms = /* @__PURE__ */ new Set();
  }
  initFPSWorker() {
    const worker = new Worker(t$2());
    worker.onmessage = (e2) => {
      const data30 = e2.data;
      const { id: id4 } = data30;
      this.snapshotInProgressMap.set(id4, false);
      if (!("base64" in data30))
        return;
      const { base64, type, width: width2, height } = data30;
      this.mutationCb({
        id: id4,
        type: CanvasContext["2D"],
        commands: [
          {
            property: "clearRect",
            args: [0, 0, width2, height]
          },
          {
            property: "drawImage",
            args: [
              {
                rr_type: "ImageBitmap",
                args: [
                  {
                    rr_type: "Blob",
                    data: [{ rr_type: "ArrayBuffer", base64 }],
                    type
                  }
                ]
              },
              0,
              0,
              width2,
              height
            ]
          }
        ]
      });
    };
    return worker;
  }
  initCanvasFPSObserver(fps, blockClass, blockSelector, unblockSelector, maxCanvasSize, options5) {
    const rafId = this.takeSnapshot(false, fps, blockClass, blockSelector, unblockSelector, maxCanvasSize, options5.dataURLOptions);
    this.restoreHandlers.push(() => {
      cancelAnimationFrame(rafId);
    });
  }
  initCanvasMutationObserver(win, blockClass, blockSelector, unblockSelector) {
    const canvasContextReset = initCanvasContextObserver(win, blockClass, blockSelector, unblockSelector, false);
    const canvas2DReset = initCanvas2DMutationObserver(this.processMutation.bind(this), win, blockClass, blockSelector, unblockSelector);
    const canvasWebGL1and2Reset = initCanvasWebGLMutationObserver(this.processMutation.bind(this), win, blockClass, blockSelector, unblockSelector, this.mirror);
    this.restoreHandlers.push(() => {
      canvasContextReset();
      canvas2DReset();
      canvasWebGL1and2Reset();
    });
  }
  snapshot(canvasElement) {
    const { options: options5 } = this;
    const rafId = this.takeSnapshot(true, options5.sampling === "all" ? 2 : options5.sampling || 2, options5.blockClass, options5.blockSelector, options5.unblockSelector, options5.maxCanvasSize, options5.dataURLOptions, canvasElement);
    this.restoreHandlers.push(() => {
      cancelAnimationFrame(rafId);
    });
  }
  takeSnapshot(isManualSnapshot, fps, blockClass, blockSelector, unblockSelector, maxCanvasSize, dataURLOptions, canvasElement) {
    const timeBetweenSnapshots = 1e3 / fps;
    let lastSnapshotTime = 0;
    let rafId;
    const getCanvas = /* @__PURE__ */ __name((canvasElement2) => {
      if (canvasElement2) {
        return [canvasElement2];
      }
      const matchedCanvas = [];
      const searchCanvas = /* @__PURE__ */ __name((root34) => {
        root34.querySelectorAll("canvas").forEach((canvas2) => {
          if (!isBlocked(canvas2, blockClass, blockSelector, unblockSelector)) {
            matchedCanvas.push(canvas2);
          }
        });
      }, "searchCanvas");
      for (const item3 of this.windows) {
        const window2 = item3.deref();
        if (window2) {
          searchCanvas(window2.document);
        }
      }
      for (const item3 of this.shadowDoms) {
        const shadowRoot = item3.deref();
        if (shadowRoot) {
          searchCanvas(shadowRoot);
        }
      }
      return matchedCanvas;
    }, "getCanvas");
    const takeCanvasSnapshots = /* @__PURE__ */ __name((timestamp2) => {
      if (!this.windows.length) {
        return;
      }
      if (lastSnapshotTime && timestamp2 - lastSnapshotTime < timeBetweenSnapshots) {
        rafId = onRequestAnimationFrame(takeCanvasSnapshots);
        return;
      }
      lastSnapshotTime = timestamp2;
      getCanvas(canvasElement).forEach((canvas2) => {
        if (!this.mirror.hasNode(canvas2)) {
          return;
        }
        const id4 = this.mirror.getId(canvas2);
        if (this.snapshotInProgressMap.get(id4))
          return;
        if (!canvas2.width || !canvas2.height)
          return;
        this.snapshotInProgressMap.set(id4, true);
        if (!isManualSnapshot && ["webgl", "webgl2"].includes(canvas2.__context)) {
          const context = canvas2.getContext(canvas2.__context);
          if (_optionalChain([context, "optionalAccess", (_4) => _4.getContextAttributes, "call", (_5) => _5(), "optionalAccess", (_6) => _6.preserveDrawingBuffer]) === false) {
            context.clear(context.COLOR_BUFFER_BIT);
          }
        }
        createImageBitmap(canvas2).then((bitmap) => {
          _optionalChain([this, "access", (_7) => _7.worker, "optionalAccess", (_8) => _8.postMessage, "call", (_9) => _9({
            id: id4,
            bitmap,
            width: canvas2.width,
            height: canvas2.height,
            dataURLOptions,
            maxCanvasSize
          }, [bitmap])]);
        }).catch((error2) => {
          callbackWrapper(() => {
            throw error2;
          })();
        });
      });
      if (!isManualSnapshot) {
        rafId = onRequestAnimationFrame(takeCanvasSnapshots);
      }
    }, "takeCanvasSnapshots");
    rafId = onRequestAnimationFrame(takeCanvasSnapshots);
    return rafId;
  }
  startPendingCanvasMutationFlusher() {
    onRequestAnimationFrame(() => this.flushPendingCanvasMutations());
  }
  startRAFTimestamping() {
    const setLatestRAFTimestamp = /* @__PURE__ */ __name((timestamp2) => {
      this.rafStamps.latestId = timestamp2;
      onRequestAnimationFrame(setLatestRAFTimestamp);
    }, "setLatestRAFTimestamp");
    onRequestAnimationFrame(setLatestRAFTimestamp);
  }
  flushPendingCanvasMutations() {
    this.pendingCanvasMutations.forEach((values, canvas2) => {
      const id4 = this.mirror.getId(canvas2);
      this.flushPendingCanvasMutationFor(canvas2, id4);
    });
    onRequestAnimationFrame(() => this.flushPendingCanvasMutations());
  }
  flushPendingCanvasMutationFor(canvas2, id4) {
    if (this.frozen || this.locked) {
      return;
    }
    const valuesWithType = this.pendingCanvasMutations.get(canvas2);
    if (!valuesWithType || id4 === -1)
      return;
    const values = valuesWithType.map((value3) => {
      const { type: type2, ...rest } = value3;
      return rest;
    });
    const { type } = valuesWithType[0];
    this.mutationCb({ id: id4, type, commands: values });
    this.pendingCanvasMutations.delete(canvas2);
  }
}
const CANVAS_QUALITY = {
  low: {
    sampling: {
      canvas: 1
    },
    dataURLOptions: {
      type: "image/webp",
      quality: 0.25
    }
  },
  medium: {
    sampling: {
      canvas: 2
    },
    dataURLOptions: {
      type: "image/webp",
      quality: 0.4
    }
  },
  high: {
    sampling: {
      canvas: 4
    },
    dataURLOptions: {
      type: "image/webp",
      quality: 0.5
    }
  }
};
const INTEGRATION_NAME$3 = "ReplayCanvas";
const DEFAULT_MAX_CANVAS_SIZE = 1280;
const _replayCanvasIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const [maxCanvasWidth, maxCanvasHeight] = options5.maxCanvasSize || [];
  const _canvasOptions = {
    quality: options5.quality || "medium",
    enableManualSnapshot: options5.enableManualSnapshot,
    maxCanvasSize: [
      maxCanvasWidth ? Math.min(maxCanvasWidth, DEFAULT_MAX_CANVAS_SIZE) : DEFAULT_MAX_CANVAS_SIZE,
      maxCanvasHeight ? Math.min(maxCanvasHeight, DEFAULT_MAX_CANVAS_SIZE) : DEFAULT_MAX_CANVAS_SIZE
    ]
  };
  let canvasManagerResolve;
  const _canvasManager = new Promise((resolve2) => canvasManagerResolve = resolve2);
  return {
    name: INTEGRATION_NAME$3,
    getOptions() {
      const { quality, enableManualSnapshot, maxCanvasSize } = _canvasOptions;
      return {
        enableManualSnapshot,
        recordCanvas: true,
        getCanvasManager: /* @__PURE__ */ __name((getCanvasManagerOptions) => {
          const manager2 = new CanvasManager({
            ...getCanvasManagerOptions,
            enableManualSnapshot,
            maxCanvasSize,
            errorHandler: /* @__PURE__ */ __name((err) => {
              try {
                if (typeof err === "object") {
                  err.__rrweb__ = true;
                }
              } catch (error2) {
              }
            }, "errorHandler")
          });
          canvasManagerResolve(manager2);
          return manager2;
        }, "getCanvasManager"),
        ...CANVAS_QUALITY[quality || "medium"] || CANVAS_QUALITY.medium
      };
    },
    async snapshot(canvasElement) {
      const canvasManager = await _canvasManager;
      canvasManager.snapshot(canvasElement);
    }
  };
}, "_replayCanvasIntegration");
const replayCanvasIntegration = defineIntegration(
  _replayCanvasIntegration
);
const WINDOW = GLOBAL_OBJ;
const DOCUMENT = WINDOW.document;
const NAVIGATOR = WINDOW.navigator;
const TRIGGER_LABEL = "Report a Bug";
const CANCEL_BUTTON_LABEL = "Cancel";
const SUBMIT_BUTTON_LABEL = "Send Bug Report";
const CONFIRM_BUTTON_LABEL = "Confirm";
const FORM_TITLE = "Report a Bug";
const EMAIL_PLACEHOLDER = "your.email@example.org";
const EMAIL_LABEL = "Email";
const MESSAGE_PLACEHOLDER = "What's the bug? What did you expect?";
const MESSAGE_LABEL = "Description";
const NAME_PLACEHOLDER = "Your Name";
const NAME_LABEL = "Name";
const SUCCESS_MESSAGE_TEXT = "Thank you for your report!";
const IS_REQUIRED_LABEL = "(required)";
const ADD_SCREENSHOT_LABEL = "Add a screenshot";
const REMOVE_SCREENSHOT_LABEL = "Remove screenshot";
const FEEDBACK_WIDGET_SOURCE = "widget";
const FEEDBACK_API_SOURCE = "api";
const SUCCESS_MESSAGE_TIMEOUT = 5e3;
const sendFeedback = /* @__PURE__ */ __name((params, hint = { includeReplay: true }) => {
  if (!params.message) {
    throw new Error("Unable to submit feedback with empty message");
  }
  const client = getClient();
  if (!client) {
    throw new Error("No client setup, cannot send feedback.");
  }
  if (params.tags && Object.keys(params.tags).length) {
    getCurrentScope$1().setTags(params.tags);
  }
  const eventId = captureFeedback(
    {
      source: FEEDBACK_API_SOURCE,
      url: getLocationHref(),
      ...params
    },
    hint
  );
  return new Promise((resolve2, reject3) => {
    const timeout = setTimeout(() => reject3("Unable to determine if Feedback was correctly sent."), 5e3);
    const cleanup = client.on("afterSendEvent", (event, response) => {
      if (event.event_id !== eventId) {
        return;
      }
      clearTimeout(timeout);
      cleanup();
      if (response && typeof response.statusCode === "number" && response.statusCode >= 200 && response.statusCode < 300) {
        return resolve2(eventId);
      }
      if (response && typeof response.statusCode === "number" && response.statusCode === 0) {
        return reject3(
          "Unable to send Feedback. This is because of network issues, or because you are using an ad-blocker."
        );
      }
      if (response && typeof response.statusCode === "number" && response.statusCode === 403) {
        return reject3(
          "Unable to send Feedback. This could be because this domain is not in your list of allowed domains."
        );
      }
      return reject3(
        "Unable to send Feedback. This could be because of network issues, or because you are using an ad-blocker"
      );
    });
  });
}, "sendFeedback");
const DEBUG_BUILD$1 = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
function isScreenshotSupported() {
  if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(NAVIGATOR.userAgent)) {
    return false;
  }
  if (/Macintosh/i.test(NAVIGATOR.userAgent) && NAVIGATOR.maxTouchPoints && NAVIGATOR.maxTouchPoints > 1) {
    return false;
  }
  if (!isSecureContext) {
    return false;
  }
  return true;
}
__name(isScreenshotSupported, "isScreenshotSupported");
function mergeOptions$2(defaultOptions2, optionOverrides) {
  return {
    ...defaultOptions2,
    ...optionOverrides,
    tags: {
      ...defaultOptions2.tags,
      ...optionOverrides.tags
    },
    onFormOpen: /* @__PURE__ */ __name(() => {
      optionOverrides.onFormOpen && optionOverrides.onFormOpen();
      defaultOptions2.onFormOpen && defaultOptions2.onFormOpen();
    }, "onFormOpen"),
    onFormClose: /* @__PURE__ */ __name(() => {
      optionOverrides.onFormClose && optionOverrides.onFormClose();
      defaultOptions2.onFormClose && defaultOptions2.onFormClose();
    }, "onFormClose"),
    onSubmitSuccess: /* @__PURE__ */ __name((data30) => {
      optionOverrides.onSubmitSuccess && optionOverrides.onSubmitSuccess(data30);
      defaultOptions2.onSubmitSuccess && defaultOptions2.onSubmitSuccess(data30);
    }, "onSubmitSuccess"),
    onSubmitError: /* @__PURE__ */ __name((error2) => {
      optionOverrides.onSubmitError && optionOverrides.onSubmitError(error2);
      defaultOptions2.onSubmitError && defaultOptions2.onSubmitError(error2);
    }, "onSubmitError"),
    onFormSubmitted: /* @__PURE__ */ __name(() => {
      optionOverrides.onFormSubmitted && optionOverrides.onFormSubmitted();
      defaultOptions2.onFormSubmitted && defaultOptions2.onFormSubmitted();
    }, "onFormSubmitted"),
    themeDark: {
      ...defaultOptions2.themeDark,
      ...optionOverrides.themeDark
    },
    themeLight: {
      ...defaultOptions2.themeLight,
      ...optionOverrides.themeLight
    }
  };
}
__name(mergeOptions$2, "mergeOptions$2");
function createActorStyles(styleNonce) {
  const style2 = DOCUMENT.createElement("style");
  style2.textContent = `
.widget__actor {
  position: fixed;
  z-index: var(--z-index);
  margin: var(--page-margin);
  inset: var(--actor-inset);

  display: flex;
  align-items: center;
  gap: 8px;
  padding: 16px;

  font-family: inherit;
  font-size: var(--font-size);
  font-weight: 600;
  line-height: 1.14em;
  text-decoration: none;

  background: var(--actor-background, var(--background));
  border-radius: var(--actor-border-radius, 1.7em/50%);
  border: var(--actor-border, var(--border));
  box-shadow: var(--actor-box-shadow, var(--box-shadow));
  color: var(--actor-color, var(--foreground));
  fill: var(--actor-color, var(--foreground));
  cursor: pointer;
  opacity: 1;
  transition: transform 0.2s ease-in-out;
  transform: translate(0, 0) scale(1);
}
.widget__actor[aria-hidden="true"] {
  opacity: 0;
  pointer-events: none;
  visibility: hidden;
  transform: translate(0, 16px) scale(0.98);
}

.widget__actor:hover {
  background: var(--actor-hover-background, var(--background));
  filter: var(--interactive-filter);
}

.widget__actor svg {
  width: 1.14em;
  height: 1.14em;
}

@media (max-width: 600px) {
  .widget__actor span {
    display: none;
  }
}
`;
  if (styleNonce) {
    style2.setAttribute("nonce", styleNonce);
  }
  return style2;
}
__name(createActorStyles, "createActorStyles");
function setAttributesNS(el, attributes) {
  Object.entries(attributes).forEach(([key, val]) => {
    el.setAttributeNS(null, key, val);
  });
  return el;
}
__name(setAttributesNS, "setAttributesNS");
const SIZE = 20;
const XMLNS$2 = "http://www.w3.org/2000/svg";
function FeedbackIcon() {
  const createElementNS = /* @__PURE__ */ __name((tagName) => WINDOW.document.createElementNS(XMLNS$2, tagName), "createElementNS");
  const svg = setAttributesNS(createElementNS("svg"), {
    width: `${SIZE}`,
    height: `${SIZE}`,
    viewBox: `0 0 ${SIZE} ${SIZE}`,
    fill: "var(--actor-color, var(--foreground))"
  });
  const g2 = setAttributesNS(createElementNS("g"), {
    clipPath: "url(#clip0_57_80)"
  });
  const path = setAttributesNS(createElementNS("path"), {
    ["fill-rule"]: "evenodd",
    ["clip-rule"]: "evenodd",
    d: "M15.6622 15H12.3997C12.2129 14.9959 12.031 14.9396 11.8747 14.8375L8.04965 12.2H7.49956V19.1C7.4875 19.3348 7.3888 19.5568 7.22256 19.723C7.05632 19.8892 6.83435 19.9879 6.59956 20H2.04956C1.80193 19.9968 1.56535 19.8969 1.39023 19.7218C1.21511 19.5467 1.1153 19.3101 1.11206 19.0625V12.2H0.949652C0.824431 12.2017 0.700142 12.1783 0.584123 12.1311C0.468104 12.084 0.362708 12.014 0.274155 11.9255C0.185602 11.8369 0.115689 11.7315 0.0685419 11.6155C0.0213952 11.4995 -0.00202913 11.3752 -0.00034808 11.25V3.75C-0.00900498 3.62067 0.0092504 3.49095 0.0532651 3.36904C0.0972798 3.24712 0.166097 3.13566 0.255372 3.04168C0.344646 2.94771 0.452437 2.87327 0.571937 2.82307C0.691437 2.77286 0.82005 2.74798 0.949652 2.75H8.04965L11.8747 0.1625C12.031 0.0603649 12.2129 0.00407221 12.3997 0H15.6622C15.9098 0.00323746 16.1464 0.103049 16.3215 0.278167C16.4966 0.453286 16.5964 0.689866 16.5997 0.9375V3.25269C17.3969 3.42959 18.1345 3.83026 18.7211 4.41679C19.5322 5.22788 19.9878 6.32796 19.9878 7.47502C19.9878 8.62209 19.5322 9.72217 18.7211 10.5333C18.1345 11.1198 17.3969 11.5205 16.5997 11.6974V14.0125C16.6047 14.1393 16.5842 14.2659 16.5395 14.3847C16.4948 14.5035 16.4268 14.6121 16.3394 14.7042C16.252 14.7962 16.147 14.8698 16.0307 14.9206C15.9144 14.9714 15.7891 14.9984 15.6622 15ZM1.89695 10.325H1.88715V4.625H8.33715C8.52423 4.62301 8.70666 4.56654 8.86215 4.4625L12.6872 1.875H14.7247V13.125H12.6872L8.86215 10.4875C8.70666 10.3835 8.52423 10.327 8.33715 10.325H2.20217C2.15205 10.3167 2.10102 10.3125 2.04956 10.3125C1.9981 10.3125 1.94708 10.3167 1.89695 10.325ZM2.98706 12.2V18.1625H5.66206V12.2H2.98706ZM16.5997 9.93612V5.01393C16.6536 5.02355 16.7072 5.03495 16.7605 5.04814C17.1202 5.13709 17.4556 5.30487 17.7425 5.53934C18.0293 5.77381 18.2605 6.06912 18.4192 6.40389C18.578 6.73866 18.6603 7.10452 18.6603 7.47502C18.6603 7.84552 18.578 8.21139 18.4192 8.54616C18.2605 8.88093 18.0293 9.17624 17.7425 9.41071C17.4556 9.64518 17.1202 9.81296 16.7605 9.90191C16.7072 9.91509 16.6536 9.9265 16.5997 9.93612Z"
  });
  svg.appendChild(g2).appendChild(path);
  const speakerDefs = createElementNS("defs");
  const speakerClipPathDef = setAttributesNS(createElementNS("clipPath"), {
    id: "clip0_57_80"
  });
  const speakerRect = setAttributesNS(createElementNS("rect"), {
    width: `${SIZE}`,
    height: `${SIZE}`,
    fill: "white"
  });
  speakerClipPathDef.appendChild(speakerRect);
  speakerDefs.appendChild(speakerClipPathDef);
  svg.appendChild(speakerDefs).appendChild(speakerClipPathDef).appendChild(speakerRect);
  return svg;
}
__name(FeedbackIcon, "FeedbackIcon");
function Actor({ triggerLabel, triggerAriaLabel, shadow, styleNonce }) {
  const el = DOCUMENT.createElement("button");
  el.type = "button";
  el.className = "widget__actor";
  el.ariaHidden = "false";
  el.ariaLabel = triggerAriaLabel || triggerLabel || TRIGGER_LABEL;
  el.appendChild(FeedbackIcon());
  if (triggerLabel) {
    const label8 = DOCUMENT.createElement("span");
    label8.appendChild(DOCUMENT.createTextNode(triggerLabel));
    el.appendChild(label8);
  }
  const style2 = createActorStyles(styleNonce);
  return {
    el,
    appendToDom() {
      shadow.appendChild(style2);
      shadow.appendChild(el);
    },
    removeFromDom() {
      shadow.removeChild(el);
      shadow.removeChild(style2);
    },
    show() {
      el.ariaHidden = "false";
    },
    hide() {
      el.ariaHidden = "true";
    }
  };
}
__name(Actor, "Actor");
const PURPLE = "rgba(88, 74, 192, 1)";
const DEFAULT_LIGHT = {
  foreground: "#2b2233",
  background: "#ffffff",
  accentForeground: "white",
  accentBackground: PURPLE,
  successColor: "#268d75",
  errorColor: "#df3338",
  border: "1.5px solid rgba(41, 35, 47, 0.13)",
  boxShadow: "0px 4px 24px 0px rgba(43, 34, 51, 0.12)",
  outline: "1px auto var(--accent-background)",
  interactiveFilter: "brightness(95%)"
};
const DEFAULT_DARK = {
  foreground: "#ebe6ef",
  background: "#29232f",
  accentForeground: "white",
  accentBackground: PURPLE,
  successColor: "#2da98c",
  errorColor: "#f55459",
  border: "1.5px solid rgba(235, 230, 239, 0.15)",
  boxShadow: "0px 4px 24px 0px rgba(43, 34, 51, 0.12)",
  outline: "1px auto var(--accent-background)",
  interactiveFilter: "brightness(150%)"
};
function getThemedCssVariables(theme47) {
  return `
  --foreground: ${theme47.foreground};
  --background: ${theme47.background};
  --accent-foreground: ${theme47.accentForeground};
  --accent-background: ${theme47.accentBackground};
  --success-color: ${theme47.successColor};
  --error-color: ${theme47.errorColor};
  --border: ${theme47.border};
  --box-shadow: ${theme47.boxShadow};
  --outline: ${theme47.outline};
  --interactive-filter: ${theme47.interactiveFilter};
  `;
}
__name(getThemedCssVariables, "getThemedCssVariables");
function createMainStyles({
  colorScheme,
  themeDark,
  themeLight,
  styleNonce
}) {
  const style2 = DOCUMENT.createElement("style");
  style2.textContent = `
:host {
  --font-family: system-ui, 'Helvetica Neue', Arial, sans-serif;
  --font-size: 14px;
  --z-index: 100000;

  --page-margin: 16px;
  --inset: auto 0 0 auto;
  --actor-inset: var(--inset);

  font-family: var(--font-family);
  font-size: var(--font-size);

  ${colorScheme !== "system" ? "color-scheme: only light;" : ""}

  ${getThemedCssVariables(
    colorScheme === "dark" ? { ...DEFAULT_DARK, ...themeDark } : { ...DEFAULT_LIGHT, ...themeLight }
  )}
}

${colorScheme === "system" ? `
@media (prefers-color-scheme: dark) {
  :host {
    ${getThemedCssVariables({ ...DEFAULT_DARK, ...themeDark })}
  }
}` : ""}
}
`;
  if (styleNonce) {
    style2.setAttribute("nonce", styleNonce);
  }
  return style2;
}
__name(createMainStyles, "createMainStyles");
const buildFeedbackIntegration = /* @__PURE__ */ __name(({
  lazyLoadIntegration: lazyLoadIntegration2,
  getModalIntegration,
  getScreenshotIntegration
}) => {
  const feedbackIntegration = /* @__PURE__ */ __name(({
    // FeedbackGeneralConfiguration
    id: id4 = "sentry-feedback",
    autoInject = true,
    showBranding = true,
    isEmailRequired = false,
    isNameRequired = false,
    showEmail = true,
    showName = true,
    enableScreenshot = true,
    useSentryUser = {
      email: "email",
      name: "username"
    },
    tags,
    styleNonce,
    scriptNonce,
    // FeedbackThemeConfiguration
    colorScheme = "system",
    themeLight = {},
    themeDark = {},
    // FeedbackTextConfiguration
    addScreenshotButtonLabel = ADD_SCREENSHOT_LABEL,
    cancelButtonLabel = CANCEL_BUTTON_LABEL,
    confirmButtonLabel = CONFIRM_BUTTON_LABEL,
    emailLabel = EMAIL_LABEL,
    emailPlaceholder = EMAIL_PLACEHOLDER,
    formTitle = FORM_TITLE,
    isRequiredLabel = IS_REQUIRED_LABEL,
    messageLabel = MESSAGE_LABEL,
    messagePlaceholder = MESSAGE_PLACEHOLDER,
    nameLabel = NAME_LABEL,
    namePlaceholder = NAME_PLACEHOLDER,
    removeScreenshotButtonLabel = REMOVE_SCREENSHOT_LABEL,
    submitButtonLabel = SUBMIT_BUTTON_LABEL,
    successMessageText = SUCCESS_MESSAGE_TEXT,
    triggerLabel = TRIGGER_LABEL,
    triggerAriaLabel = "",
    // FeedbackCallbacks
    onFormOpen,
    onFormClose,
    onSubmitSuccess,
    onSubmitError,
    onFormSubmitted
  } = {}) => {
    const _options = {
      id: id4,
      autoInject,
      showBranding,
      isEmailRequired,
      isNameRequired,
      showEmail,
      showName,
      enableScreenshot,
      useSentryUser,
      tags,
      styleNonce,
      scriptNonce,
      colorScheme,
      themeDark,
      themeLight,
      triggerLabel,
      triggerAriaLabel,
      cancelButtonLabel,
      submitButtonLabel,
      confirmButtonLabel,
      formTitle,
      emailLabel,
      emailPlaceholder,
      messageLabel,
      messagePlaceholder,
      nameLabel,
      namePlaceholder,
      successMessageText,
      isRequiredLabel,
      addScreenshotButtonLabel,
      removeScreenshotButtonLabel,
      onFormClose,
      onFormOpen,
      onSubmitError,
      onSubmitSuccess,
      onFormSubmitted
    };
    let _shadow = null;
    let _subscriptions = [];
    const _createShadow = /* @__PURE__ */ __name((options5) => {
      if (!_shadow) {
        const host = DOCUMENT.createElement("div");
        host.id = String(options5.id);
        DOCUMENT.body.appendChild(host);
        _shadow = host.attachShadow({ mode: "open" });
        _shadow.appendChild(createMainStyles(options5));
      }
      return _shadow;
    }, "_createShadow");
    const _loadAndRenderDialog = /* @__PURE__ */ __name(async (options5) => {
      const screenshotRequired = options5.enableScreenshot && isScreenshotSupported();
      let modalIntegration;
      let screenshotIntegration;
      try {
        const modalIntegrationFn = getModalIntegration ? getModalIntegration() : await lazyLoadIntegration2("feedbackModalIntegration", scriptNonce);
        modalIntegration = modalIntegrationFn();
        addIntegration(modalIntegration);
      } catch (e2) {
        DEBUG_BUILD$1 && logger$2.error(
          "[Feedback] Error when trying to load feedback integrations. Try using `feedbackSyncIntegration` in your `Sentry.init`."
        );
        throw new Error("[Feedback] Missing feedback modal integration!");
      }
      try {
        const screenshotIntegrationFn = screenshotRequired ? getScreenshotIntegration ? getScreenshotIntegration() : await lazyLoadIntegration2("feedbackScreenshotIntegration", scriptNonce) : void 0;
        if (screenshotIntegrationFn) {
          screenshotIntegration = screenshotIntegrationFn();
          addIntegration(screenshotIntegration);
        }
      } catch (e2) {
        DEBUG_BUILD$1 && logger$2.error("[Feedback] Missing feedback screenshot integration. Proceeding without screenshots.");
      }
      const dialog = modalIntegration.createDialog({
        options: {
          ...options5,
          onFormClose: /* @__PURE__ */ __name(() => {
            dialog && dialog.close();
            options5.onFormClose && options5.onFormClose();
          }, "onFormClose"),
          onFormSubmitted: /* @__PURE__ */ __name(() => {
            dialog && dialog.close();
            options5.onFormSubmitted && options5.onFormSubmitted();
          }, "onFormSubmitted")
        },
        screenshotIntegration,
        sendFeedback,
        shadow: _createShadow(options5)
      });
      return dialog;
    }, "_loadAndRenderDialog");
    const _attachTo = /* @__PURE__ */ __name((el, optionOverrides = {}) => {
      const mergedOptions = mergeOptions$2(_options, optionOverrides);
      const targetEl = typeof el === "string" ? DOCUMENT.querySelector(el) : typeof el.addEventListener === "function" ? el : null;
      if (!targetEl) {
        DEBUG_BUILD$1 && logger$2.error("[Feedback] Unable to attach to target element");
        throw new Error("Unable to attach to target element");
      }
      let dialog = null;
      const handleClick2 = /* @__PURE__ */ __name(async () => {
        if (!dialog) {
          dialog = await _loadAndRenderDialog({
            ...mergedOptions,
            onFormSubmitted: /* @__PURE__ */ __name(() => {
              dialog && dialog.removeFromDom();
              mergedOptions.onFormSubmitted && mergedOptions.onFormSubmitted();
            }, "onFormSubmitted")
          });
        }
        dialog.appendToDom();
        dialog.open();
      }, "handleClick");
      targetEl.addEventListener("click", handleClick2);
      const unsubscribe = /* @__PURE__ */ __name(() => {
        _subscriptions = _subscriptions.filter((sub) => sub !== unsubscribe);
        dialog && dialog.removeFromDom();
        dialog = null;
        targetEl.removeEventListener("click", handleClick2);
      }, "unsubscribe");
      _subscriptions.push(unsubscribe);
      return unsubscribe;
    }, "_attachTo");
    const _createActor = /* @__PURE__ */ __name((optionOverrides = {}) => {
      const mergedOptions = mergeOptions$2(_options, optionOverrides);
      const shadow = _createShadow(mergedOptions);
      const actor = Actor({
        triggerLabel: mergedOptions.triggerLabel,
        triggerAriaLabel: mergedOptions.triggerAriaLabel,
        shadow,
        styleNonce
      });
      _attachTo(actor.el, {
        ...mergedOptions,
        onFormOpen() {
          actor.hide();
        },
        onFormClose() {
          actor.show();
        },
        onFormSubmitted() {
          actor.show();
        }
      });
      return actor;
    }, "_createActor");
    return {
      name: "Feedback",
      setupOnce() {
        if (!isBrowser$1() || !_options.autoInject) {
          return;
        }
        if (DOCUMENT.readyState === "loading") {
          DOCUMENT.addEventListener("DOMContentLoaded", () => _createActor().appendToDom());
        } else {
          _createActor().appendToDom();
        }
      },
      /**
       * Adds click listener to the element to open a feedback dialog
       *
       * The returned function can be used to remove the click listener
       */
      attachTo: _attachTo,
      /**
       * Creates a new widget which is composed of a Button which triggers a Dialog.
       * Accepts partial options to override any options passed to constructor.
       */
      createWidget(optionOverrides = {}) {
        const actor = _createActor(mergeOptions$2(_options, optionOverrides));
        actor.appendToDom();
        return actor;
      },
      /**
       * Creates a new Form which you can
       * Accepts partial options to override any options passed to constructor.
       */
      async createForm(optionOverrides = {}) {
        return _loadAndRenderDialog(mergeOptions$2(_options, optionOverrides));
      },
      /**
       * Removes the Feedback integration (including host, shadow DOM, and all widgets)
       */
      remove() {
        if (_shadow) {
          _shadow.parentElement && _shadow.parentElement.remove();
          _shadow = null;
        }
        _subscriptions.forEach((sub) => sub());
        _subscriptions = [];
      }
    };
  }, "feedbackIntegration");
  return feedbackIntegration;
}, "buildFeedbackIntegration");
function getFeedback() {
  const client = getClient();
  return client && client.getIntegrationByName("Feedback");
}
__name(getFeedback, "getFeedback");
var n, l$1, u$1, i$1, o$1, r$1, f$1, c$1 = {}, s$1 = [], a$1 = /acit|ex(?:s|g|n|p|$)|rph|grid|ows|mnc|ntw|ine[ch]|zoo|^ord|itera/i, h$1 = Array.isArray;
function v$1(n2, l2) {
  for (var u2 in l2) n2[u2] = l2[u2];
  return n2;
}
__name(v$1, "v$1");
function p$1(n2) {
  var l2 = n2.parentNode;
  l2 && l2.removeChild(n2);
}
__name(p$1, "p$1");
function y$1(l2, u2, t2) {
  var i2, o2, r2, f2 = {};
  for (r2 in u2) "key" == r2 ? i2 = u2[r2] : "ref" == r2 ? o2 = u2[r2] : f2[r2] = u2[r2];
  if (arguments.length > 2 && (f2.children = arguments.length > 3 ? n.call(arguments, 2) : t2), "function" == typeof l2 && null != l2.defaultProps) for (r2 in l2.defaultProps) void 0 === f2[r2] && (f2[r2] = l2.defaultProps[r2]);
  return d$1(l2, f2, i2, o2, null);
}
__name(y$1, "y$1");
function d$1(n2, t2, i2, o2, r2) {
  var f2 = { type: n2, props: t2, key: i2, ref: o2, __k: null, __: null, __b: 0, __e: null, __d: void 0, __c: null, constructor: void 0, __v: null == r2 ? ++u$1 : r2, __i: -1, __u: 0 };
  return null == r2 && null != l$1.vnode && l$1.vnode(f2), f2;
}
__name(d$1, "d$1");
function g$1$1(n2) {
  return n2.children;
}
__name(g$1$1, "g$1$1");
function b$1(n2, l2) {
  this.props = n2, this.context = l2;
}
__name(b$1, "b$1");
function m$1(n2, l2) {
  if (null == l2) return n2.__ ? m$1(n2.__, n2.__i + 1) : null;
  for (var u2; l2 < n2.__k.length; l2++) if (null != (u2 = n2.__k[l2]) && null != u2.__e) return u2.__e;
  return "function" == typeof n2.type ? m$1(n2) : null;
}
__name(m$1, "m$1");
function w$1(n2, u2, t2) {
  var i2, o2 = n2.__v, r2 = o2.__e, f2 = n2.__P;
  if (f2) return (i2 = v$1({}, o2)).__v = o2.__v + 1, l$1.vnode && l$1.vnode(i2), M(f2, i2, o2, n2.__n, void 0 !== f2.ownerSVGElement, 32 & o2.__u ? [r2] : null, u2, null == r2 ? m$1(o2) : r2, !!(32 & o2.__u), t2), i2.__.__k[i2.__i] = i2, i2.__d = void 0, i2.__e != r2 && k$1(i2), i2;
}
__name(w$1, "w$1");
function k$1(n2) {
  var l2, u2;
  if (null != (n2 = n2.__) && null != n2.__c) {
    for (n2.__e = n2.__c.base = null, l2 = 0; l2 < n2.__k.length; l2++) if (null != (u2 = n2.__k[l2]) && null != u2.__e) {
      n2.__e = n2.__c.base = u2.__e;
      break;
    }
    return k$1(n2);
  }
}
__name(k$1, "k$1");
function x$1(n2) {
  (!n2.__d && (n2.__d = true) && i$1.push(n2) && !C$1.__r++ || o$1 !== l$1.debounceRendering) && ((o$1 = l$1.debounceRendering) || r$1)(C$1);
}
__name(x$1, "x$1");
function C$1() {
  var n2, u2, t2, o2 = [], r2 = [];
  for (i$1.sort(f$1); n2 = i$1.shift(); ) n2.__d && (t2 = i$1.length, u2 = w$1(n2, o2, r2) || u2, 0 === t2 || i$1.length > t2 ? (j$1(o2, u2, r2), r2.length = o2.length = 0, u2 = void 0, i$1.sort(f$1)) : u2 && l$1.__c && l$1.__c(u2, s$1));
  u2 && j$1(o2, u2, r2), C$1.__r = 0;
}
__name(C$1, "C$1");
function P$1(n2, l2, u2, t2, i2, o2, r2, f2, e2, a2, h2) {
  var v2, p2, y2, d2, _2, g2 = t2 && t2.__k || s$1, b2 = l2.length;
  for (u2.__d = e2, S(u2, l2, g2), e2 = u2.__d, v2 = 0; v2 < b2; v2++) null != (y2 = u2.__k[v2]) && "boolean" != typeof y2 && "function" != typeof y2 && (p2 = -1 === y2.__i ? c$1 : g2[y2.__i] || c$1, y2.__i = v2, M(n2, y2, p2, i2, o2, r2, f2, e2, a2, h2), d2 = y2.__e, y2.ref && p2.ref != y2.ref && (p2.ref && N(p2.ref, null, y2), h2.push(y2.ref, y2.__c || d2, y2)), null == _2 && null != d2 && (_2 = d2), 65536 & y2.__u || p2.__k === y2.__k ? e2 = $(y2, e2, n2) : "function" == typeof y2.type && void 0 !== y2.__d ? e2 = y2.__d : d2 && (e2 = d2.nextSibling), y2.__d = void 0, y2.__u &= -196609);
  u2.__d = e2, u2.__e = _2;
}
__name(P$1, "P$1");
function S(n2, l2, u2) {
  var t2, i2, o2, r2, f2, e2 = l2.length, c2 = u2.length, s2 = c2, a2 = 0;
  for (n2.__k = [], t2 = 0; t2 < e2; t2++) null != (i2 = n2.__k[t2] = null == (i2 = l2[t2]) || "boolean" == typeof i2 || "function" == typeof i2 ? null : "string" == typeof i2 || "number" == typeof i2 || "bigint" == typeof i2 || i2.constructor == String ? d$1(null, i2, null, null, i2) : h$1(i2) ? d$1(g$1$1, { children: i2 }, null, null, null) : void 0 === i2.constructor && i2.__b > 0 ? d$1(i2.type, i2.props, i2.key, i2.ref ? i2.ref : null, i2.__v) : i2) ? (i2.__ = n2, i2.__b = n2.__b + 1, f2 = I(i2, u2, r2 = t2 + a2, s2), i2.__i = f2, o2 = null, -1 !== f2 && (s2--, (o2 = u2[f2]) && (o2.__u |= 131072)), null == o2 || null === o2.__v ? (-1 == f2 && a2--, "function" != typeof i2.type && (i2.__u |= 65536)) : f2 !== r2 && (f2 === r2 + 1 ? a2++ : f2 > r2 ? s2 > e2 - r2 ? a2 += f2 - r2 : a2-- : a2 = f2 < r2 && f2 == r2 - 1 ? f2 - r2 : 0, f2 !== t2 + a2 && (i2.__u |= 65536))) : (o2 = u2[t2]) && null == o2.key && o2.__e && (o2.__e == n2.__d && (n2.__d = m$1(o2)), O(o2, o2, false), u2[t2] = null, s2--);
  if (s2) for (t2 = 0; t2 < c2; t2++) null != (o2 = u2[t2]) && 0 == (131072 & o2.__u) && (o2.__e == n2.__d && (n2.__d = m$1(o2)), O(o2, o2));
}
__name(S, "S");
function $(n2, l2, u2) {
  var t2, i2;
  if ("function" == typeof n2.type) {
    for (t2 = n2.__k, i2 = 0; t2 && i2 < t2.length; i2++) t2[i2] && (t2[i2].__ = n2, l2 = $(t2[i2], l2, u2));
    return l2;
  }
  n2.__e != l2 && (u2.insertBefore(n2.__e, l2 || null), l2 = n2.__e);
  do {
    l2 = l2 && l2.nextSibling;
  } while (null != l2 && 8 === l2.nodeType);
  return l2;
}
__name($, "$");
function I(n2, l2, u2, t2) {
  var i2 = n2.key, o2 = n2.type, r2 = u2 - 1, f2 = u2 + 1, e2 = l2[u2];
  if (null === e2 || e2 && i2 == e2.key && o2 === e2.type) return u2;
  if (t2 > (null != e2 && 0 == (131072 & e2.__u) ? 1 : 0)) for (; r2 >= 0 || f2 < l2.length; ) {
    if (r2 >= 0) {
      if ((e2 = l2[r2]) && 0 == (131072 & e2.__u) && i2 == e2.key && o2 === e2.type) return r2;
      r2--;
    }
    if (f2 < l2.length) {
      if ((e2 = l2[f2]) && 0 == (131072 & e2.__u) && i2 == e2.key && o2 === e2.type) return f2;
      f2++;
    }
  }
  return -1;
}
__name(I, "I");
function T$1(n2, l2, u2) {
  "-" === l2[0] ? n2.setProperty(l2, null == u2 ? "" : u2) : n2[l2] = null == u2 ? "" : "number" != typeof u2 || a$1.test(l2) ? u2 : u2 + "px";
}
__name(T$1, "T$1");
function A$1(n2, l2, u2, t2, i2) {
  var o2;
  n: if ("style" === l2) if ("string" == typeof u2) n2.style.cssText = u2;
  else {
    if ("string" == typeof t2 && (n2.style.cssText = t2 = ""), t2) for (l2 in t2) u2 && l2 in u2 || T$1(n2.style, l2, "");
    if (u2) for (l2 in u2) t2 && u2[l2] === t2[l2] || T$1(n2.style, l2, u2[l2]);
  }
  else if ("o" === l2[0] && "n" === l2[1]) o2 = l2 !== (l2 = l2.replace(/(PointerCapture)$|Capture$/i, "$1")), l2 = l2.toLowerCase() in n2 ? l2.toLowerCase().slice(2) : l2.slice(2), n2.l || (n2.l = {}), n2.l[l2 + o2] = u2, u2 ? t2 ? u2.u = t2.u : (u2.u = Date.now(), n2.addEventListener(l2, o2 ? L : D$1, o2)) : n2.removeEventListener(l2, o2 ? L : D$1, o2);
  else {
    if (i2) l2 = l2.replace(/xlink(H|:h)/, "h").replace(/sName$/, "s");
    else if ("width" !== l2 && "height" !== l2 && "href" !== l2 && "list" !== l2 && "form" !== l2 && "tabIndex" !== l2 && "download" !== l2 && "rowSpan" !== l2 && "colSpan" !== l2 && "role" !== l2 && l2 in n2) try {
      n2[l2] = null == u2 ? "" : u2;
      break n;
    } catch (n3) {
    }
    "function" == typeof u2 || (null == u2 || false === u2 && "-" !== l2[4] ? n2.removeAttribute(l2) : n2.setAttribute(l2, u2));
  }
}
__name(A$1, "A$1");
function D$1(n2) {
  if (this.l) {
    var u2 = this.l[n2.type + false];
    if (n2.t) {
      if (n2.t <= u2.u) return;
    } else n2.t = Date.now();
    return u2(l$1.event ? l$1.event(n2) : n2);
  }
}
__name(D$1, "D$1");
function L(n2) {
  if (this.l) return this.l[n2.type + true](l$1.event ? l$1.event(n2) : n2);
}
__name(L, "L");
function M(n2, u2, t2, i2, o2, r2, f2, e2, c2, s2) {
  var a2, p2, y2, d2, _2, m2, w2, k2, x2, C2, S2, $2, H, I2, T2, A2 = u2.type;
  if (void 0 !== u2.constructor) return null;
  128 & t2.__u && (c2 = !!(32 & t2.__u), r2 = [e2 = u2.__e = t2.__e]), (a2 = l$1.__b) && a2(u2);
  n: if ("function" == typeof A2) try {
    if (k2 = u2.props, x2 = (a2 = A2.contextType) && i2[a2.__c], C2 = a2 ? x2 ? x2.props.value : a2.__ : i2, t2.__c ? w2 = (p2 = u2.__c = t2.__c).__ = p2.__E : ("prototype" in A2 && A2.prototype.render ? u2.__c = p2 = new A2(k2, C2) : (u2.__c = p2 = new b$1(k2, C2), p2.constructor = A2, p2.render = q$1), x2 && x2.sub(p2), p2.props = k2, p2.state || (p2.state = {}), p2.context = C2, p2.__n = i2, y2 = p2.__d = true, p2.__h = [], p2._sb = []), null == p2.__s && (p2.__s = p2.state), null != A2.getDerivedStateFromProps && (p2.__s == p2.state && (p2.__s = v$1({}, p2.__s)), v$1(p2.__s, A2.getDerivedStateFromProps(k2, p2.__s))), d2 = p2.props, _2 = p2.state, p2.__v = u2, y2) null == A2.getDerivedStateFromProps && null != p2.componentWillMount && p2.componentWillMount(), null != p2.componentDidMount && p2.__h.push(p2.componentDidMount);
    else {
      if (null == A2.getDerivedStateFromProps && k2 !== d2 && null != p2.componentWillReceiveProps && p2.componentWillReceiveProps(k2, C2), !p2.__e && (null != p2.shouldComponentUpdate && false === p2.shouldComponentUpdate(k2, p2.__s, C2) || u2.__v === t2.__v)) {
        for (u2.__v !== t2.__v && (p2.props = k2, p2.state = p2.__s, p2.__d = false), u2.__e = t2.__e, u2.__k = t2.__k, u2.__k.forEach(function(n3) {
          n3 && (n3.__ = u2);
        }), S2 = 0; S2 < p2._sb.length; S2++) p2.__h.push(p2._sb[S2]);
        p2._sb = [], p2.__h.length && f2.push(p2);
        break n;
      }
      null != p2.componentWillUpdate && p2.componentWillUpdate(k2, p2.__s, C2), null != p2.componentDidUpdate && p2.__h.push(function() {
        p2.componentDidUpdate(d2, _2, m2);
      });
    }
    if (p2.context = C2, p2.props = k2, p2.__P = n2, p2.__e = false, $2 = l$1.__r, H = 0, "prototype" in A2 && A2.prototype.render) {
      for (p2.state = p2.__s, p2.__d = false, $2 && $2(u2), a2 = p2.render(p2.props, p2.state, p2.context), I2 = 0; I2 < p2._sb.length; I2++) p2.__h.push(p2._sb[I2]);
      p2._sb = [];
    } else do {
      p2.__d = false, $2 && $2(u2), a2 = p2.render(p2.props, p2.state, p2.context), p2.state = p2.__s;
    } while (p2.__d && ++H < 25);
    p2.state = p2.__s, null != p2.getChildContext && (i2 = v$1(v$1({}, i2), p2.getChildContext())), y2 || null == p2.getSnapshotBeforeUpdate || (m2 = p2.getSnapshotBeforeUpdate(d2, _2)), P$1(n2, h$1(T2 = null != a2 && a2.type === g$1$1 && null == a2.key ? a2.props.children : a2) ? T2 : [T2], u2, t2, i2, o2, r2, f2, e2, c2, s2), p2.base = u2.__e, u2.__u &= -161, p2.__h.length && f2.push(p2), w2 && (p2.__E = p2.__ = null);
  } catch (n3) {
    u2.__v = null, c2 || null != r2 ? (u2.__e = e2, u2.__u |= c2 ? 160 : 32, r2[r2.indexOf(e2)] = null) : (u2.__e = t2.__e, u2.__k = t2.__k), l$1.__e(n3, u2, t2);
  }
  else null == r2 && u2.__v === t2.__v ? (u2.__k = t2.__k, u2.__e = t2.__e) : u2.__e = z$1(t2.__e, u2, t2, i2, o2, r2, f2, c2, s2);
  (a2 = l$1.diffed) && a2(u2);
}
__name(M, "M");
function j$1(n2, u2, t2) {
  for (var i2 = 0; i2 < t2.length; i2++) N(t2[i2], t2[++i2], t2[++i2]);
  l$1.__c && l$1.__c(u2, n2), n2.some(function(u3) {
    try {
      n2 = u3.__h, u3.__h = [], n2.some(function(n3) {
        n3.call(u3);
      });
    } catch (n3) {
      l$1.__e(n3, u3.__v);
    }
  });
}
__name(j$1, "j$1");
function z$1(l2, u2, t2, i2, o2, r2, f2, e2, s2) {
  var a2, v2, y2, d2, _2, g2, b2, w2 = t2.props, k2 = u2.props, x2 = u2.type;
  if ("svg" === x2 && (o2 = true), null != r2) {
    for (a2 = 0; a2 < r2.length; a2++) if ((_2 = r2[a2]) && "setAttribute" in _2 == !!x2 && (x2 ? _2.localName === x2 : 3 === _2.nodeType)) {
      l2 = _2, r2[a2] = null;
      break;
    }
  }
  if (null == l2) {
    if (null === x2) return document.createTextNode(k2);
    l2 = o2 ? document.createElementNS("http://www.w3.org/2000/svg", x2) : document.createElement(x2, k2.is && k2), r2 = null, e2 = false;
  }
  if (null === x2) w2 === k2 || e2 && l2.data === k2 || (l2.data = k2);
  else {
    if (r2 = r2 && n.call(l2.childNodes), w2 = t2.props || c$1, !e2 && null != r2) for (w2 = {}, a2 = 0; a2 < l2.attributes.length; a2++) w2[(_2 = l2.attributes[a2]).name] = _2.value;
    for (a2 in w2) _2 = w2[a2], "children" == a2 || ("dangerouslySetInnerHTML" == a2 ? y2 = _2 : "key" === a2 || a2 in k2 || A$1(l2, a2, null, _2, o2));
    for (a2 in k2) _2 = k2[a2], "children" == a2 ? d2 = _2 : "dangerouslySetInnerHTML" == a2 ? v2 = _2 : "value" == a2 ? g2 = _2 : "checked" == a2 ? b2 = _2 : "key" === a2 || e2 && "function" != typeof _2 || w2[a2] === _2 || A$1(l2, a2, _2, w2[a2], o2);
    if (v2) e2 || y2 && (v2.__html === y2.__html || v2.__html === l2.innerHTML) || (l2.innerHTML = v2.__html), u2.__k = [];
    else if (y2 && (l2.innerHTML = ""), P$1(l2, h$1(d2) ? d2 : [d2], u2, t2, i2, o2 && "foreignObject" !== x2, r2, f2, r2 ? r2[0] : t2.__k && m$1(t2, 0), e2, s2), null != r2) for (a2 = r2.length; a2--; ) null != r2[a2] && p$1(r2[a2]);
    e2 || (a2 = "value", void 0 !== g2 && (g2 !== l2[a2] || "progress" === x2 && !g2 || "option" === x2 && g2 !== w2[a2]) && A$1(l2, a2, g2, w2[a2], false), a2 = "checked", void 0 !== b2 && b2 !== l2[a2] && A$1(l2, a2, b2, w2[a2], false));
  }
  return l2;
}
__name(z$1, "z$1");
function N(n2, u2, t2) {
  try {
    "function" == typeof n2 ? n2(u2) : n2.current = u2;
  } catch (n3) {
    l$1.__e(n3, t2);
  }
}
__name(N, "N");
function O(n2, u2, t2) {
  var i2, o2;
  if (l$1.unmount && l$1.unmount(n2), (i2 = n2.ref) && (i2.current && i2.current !== n2.__e || N(i2, null, u2)), null != (i2 = n2.__c)) {
    if (i2.componentWillUnmount) try {
      i2.componentWillUnmount();
    } catch (n3) {
      l$1.__e(n3, u2);
    }
    i2.base = i2.__P = null, n2.__c = void 0;
  }
  if (i2 = n2.__k) for (o2 = 0; o2 < i2.length; o2++) i2[o2] && O(i2[o2], u2, t2 || "function" != typeof n2.type);
  t2 || null == n2.__e || p$1(n2.__e), n2.__ = n2.__e = n2.__d = void 0;
}
__name(O, "O");
function q$1(n2, l2, u2) {
  return this.constructor(n2, u2);
}
__name(q$1, "q$1");
function B$1(u2, t2, i2) {
  var o2, r2, f2, e2;
  l$1.__ && l$1.__(u2, t2), r2 = (o2 = "function" == typeof i2) ? null : t2.__k, f2 = [], e2 = [], M(t2, u2 = (!o2 && i2 || t2).__k = y$1(g$1$1, null, [u2]), r2 || c$1, c$1, void 0 !== t2.ownerSVGElement, !o2 && i2 ? [i2] : r2 ? null : t2.firstChild ? n.call(t2.childNodes) : null, f2, !o2 && i2 ? i2 : r2 ? r2.__e : t2.firstChild, o2, e2), u2.__d = void 0, j$1(f2, u2, e2);
}
__name(B$1, "B$1");
n = s$1.slice, l$1 = { __e: /* @__PURE__ */ __name(function(n2, l2, u2, t2) {
  for (var i2, o2, r2; l2 = l2.__; ) if ((i2 = l2.__c) && !i2.__) try {
    if ((o2 = i2.constructor) && null != o2.getDerivedStateFromError && (i2.setState(o2.getDerivedStateFromError(n2)), r2 = i2.__d), null != i2.componentDidCatch && (i2.componentDidCatch(n2, t2 || {}), r2 = i2.__d), r2) return i2.__E = i2;
  } catch (l3) {
    n2 = l3;
  }
  throw n2;
}, "__e") }, u$1 = 0, b$1.prototype.setState = function(n2, l2) {
  var u2;
  u2 = null != this.__s && this.__s !== this.state ? this.__s : this.__s = v$1({}, this.state), "function" == typeof n2 && (n2 = n2(v$1({}, u2), this.props)), n2 && v$1(u2, n2), null != n2 && this.__v && (l2 && this._sb.push(l2), x$1(this));
}, b$1.prototype.forceUpdate = function(n2) {
  this.__v && (this.__e = true, n2 && this.__h.push(n2), x$1(this));
}, b$1.prototype.render = g$1$1, i$1 = [], r$1 = "function" == typeof Promise ? Promise.prototype.then.bind(Promise.resolve()) : setTimeout, f$1 = /* @__PURE__ */ __name(function(n2, l2) {
  return n2.__v.__b - l2.__v.__b;
}, "f$1"), C$1.__r = 0;
var t$1, r, u, i$2, o = 0, f = [], c = [], e = l$1, a = e.__b, v = e.__r, l = e.diffed, m$2 = e.__c, s = e.unmount, d = e.__;
function h$2(n2, t2) {
  e.__h && e.__h(r, n2, o || t2), o = 0;
  var u2 = r.__H || (r.__H = { __: [], __h: [] });
  return n2 >= u2.__.length && u2.__.push({ __V: c }), u2.__[n2];
}
__name(h$2, "h$2");
function p$2(n2) {
  return o = 1, y(D, n2);
}
__name(p$2, "p$2");
function y(n2, u2, i2) {
  var o2 = h$2(t$1++, 2);
  if (o2.t = n2, !o2.__c && (o2.__ = [i2 ? i2(u2) : D(void 0, u2), function(n3) {
    var t2 = o2.__N ? o2.__N[0] : o2.__[0], r2 = o2.t(t2, n3);
    t2 !== r2 && (o2.__N = [r2, o2.__[1]], o2.__c.setState({}));
  }], o2.__c = r, !r.u)) {
    var f2 = /* @__PURE__ */ __name(function(n3, t2, r2) {
      if (!o2.__c.__H) return true;
      var u3 = o2.__c.__H.__.filter(function(n4) {
        return !!n4.__c;
      });
      if (u3.every(function(n4) {
        return !n4.__N;
      })) return !c2 || c2.call(this, n3, t2, r2);
      var i3 = false;
      return u3.forEach(function(n4) {
        if (n4.__N) {
          var t3 = n4.__[0];
          n4.__ = n4.__N, n4.__N = void 0, t3 !== n4.__[0] && (i3 = true);
        }
      }), !(!i3 && o2.__c.props === n3) && (!c2 || c2.call(this, n3, t2, r2));
    }, "f");
    r.u = true;
    var c2 = r.shouldComponentUpdate, e2 = r.componentWillUpdate;
    r.componentWillUpdate = function(n3, t2, r2) {
      if (this.__e) {
        var u3 = c2;
        c2 = void 0, f2(n3, t2, r2), c2 = u3;
      }
      e2 && e2.call(this, n3, t2, r2);
    }, r.shouldComponentUpdate = f2;
  }
  return o2.__N || o2.__;
}
__name(y, "y");
function _$1(n2, u2) {
  var i2 = h$2(t$1++, 3);
  !e.__s && C(i2.__H, u2) && (i2.__ = n2, i2.i = u2, r.__H.__h.push(i2));
}
__name(_$1, "_$1");
function A(n2, u2) {
  var i2 = h$2(t$1++, 4);
  !e.__s && C(i2.__H, u2) && (i2.__ = n2, i2.i = u2, r.__h.push(i2));
}
__name(A, "A");
function F(n2) {
  return o = 5, q(function() {
    return { current: n2 };
  }, []);
}
__name(F, "F");
function T(n2, t2, r2) {
  o = 6, A(function() {
    return "function" == typeof n2 ? (n2(t2()), function() {
      return n2(null);
    }) : n2 ? (n2.current = t2(), function() {
      return n2.current = null;
    }) : void 0;
  }, null == r2 ? r2 : r2.concat(n2));
}
__name(T, "T");
function q(n2, r2) {
  var u2 = h$2(t$1++, 7);
  return C(u2.__H, r2) ? (u2.__V = n2(), u2.i = r2, u2.__h = n2, u2.__V) : u2.__;
}
__name(q, "q");
function x(n2, t2) {
  return o = 8, q(function() {
    return n2;
  }, t2);
}
__name(x, "x");
function P$2(n2) {
  var u2 = r.context[n2.__c], i2 = h$2(t$1++, 9);
  return i2.c = n2, u2 ? (null == i2.__ && (i2.__ = true, u2.sub(r)), u2.props.value) : n2.__;
}
__name(P$2, "P$2");
function V(n2, t2) {
  e.useDebugValue && e.useDebugValue(t2 ? t2(n2) : n2);
}
__name(V, "V");
function b(n2) {
  var u2 = h$2(t$1++, 10), i2 = p$2();
  return u2.__ = n2, r.componentDidCatch || (r.componentDidCatch = function(n3, t2) {
    u2.__ && u2.__(n3, t2), i2[1](n3);
  }), [i2[0], function() {
    i2[1](void 0);
  }];
}
__name(b, "b");
function g$6() {
  var n2 = h$2(t$1++, 11);
  if (!n2.__) {
    for (var u2 = r.__v; null !== u2 && !u2.__m && null !== u2.__; ) u2 = u2.__;
    var i2 = u2.__m || (u2.__m = [0, 0]);
    n2.__ = "P" + i2[0] + "-" + i2[1]++;
  }
  return n2.__;
}
__name(g$6, "g$6");
function j() {
  for (var n2; n2 = f.shift(); ) if (n2.__P && n2.__H) try {
    n2.__H.__h.forEach(z$2), n2.__H.__h.forEach(B), n2.__H.__h = [];
  } catch (t2) {
    n2.__H.__h = [], e.__e(t2, n2.__v);
  }
}
__name(j, "j");
e.__b = function(n2) {
  r = null, a && a(n2);
}, e.__ = function(n2, t2) {
  t2.__k && t2.__k.__m && (n2.__m = t2.__k.__m), d && d(n2, t2);
}, e.__r = function(n2) {
  v && v(n2), t$1 = 0;
  var i2 = (r = n2.__c).__H;
  i2 && (u === r ? (i2.__h = [], r.__h = [], i2.__.forEach(function(n3) {
    n3.__N && (n3.__ = n3.__N), n3.__V = c, n3.__N = n3.i = void 0;
  })) : (i2.__h.forEach(z$2), i2.__h.forEach(B), i2.__h = [], t$1 = 0)), u = r;
}, e.diffed = function(n2) {
  l && l(n2);
  var t2 = n2.__c;
  t2 && t2.__H && (t2.__H.__h.length && (1 !== f.push(t2) && i$2 === e.requestAnimationFrame || ((i$2 = e.requestAnimationFrame) || w)(j)), t2.__H.__.forEach(function(n3) {
    n3.i && (n3.__H = n3.i), n3.__V !== c && (n3.__ = n3.__V), n3.i = void 0, n3.__V = c;
  })), u = r = null;
}, e.__c = function(n2, t2) {
  t2.some(function(n3) {
    try {
      n3.__h.forEach(z$2), n3.__h = n3.__h.filter(function(n4) {
        return !n4.__ || B(n4);
      });
    } catch (r2) {
      t2.some(function(n4) {
        n4.__h && (n4.__h = []);
      }), t2 = [], e.__e(r2, n3.__v);
    }
  }), m$2 && m$2(n2, t2);
}, e.unmount = function(n2) {
  s && s(n2);
  var t2, r2 = n2.__c;
  r2 && r2.__H && (r2.__H.__.forEach(function(n3) {
    try {
      z$2(n3);
    } catch (n4) {
      t2 = n4;
    }
  }), r2.__H = void 0, t2 && e.__e(t2, r2.__v));
};
var k = "function" == typeof requestAnimationFrame;
function w(n2) {
  var t2, r2 = /* @__PURE__ */ __name(function() {
    clearTimeout(u2), k && cancelAnimationFrame(t2), setTimeout(n2);
  }, "r"), u2 = setTimeout(r2, 100);
  k && (t2 = requestAnimationFrame(r2));
}
__name(w, "w");
function z$2(n2) {
  var t2 = r, u2 = n2.__c;
  "function" == typeof u2 && (n2.__c = void 0, u2()), r = t2;
}
__name(z$2, "z$2");
function B(n2) {
  var t2 = r;
  n2.__c = n2.__(), r = t2;
}
__name(B, "B");
function C(n2, t2) {
  return !n2 || n2.length !== t2.length || t2.some(function(t3, r2) {
    return t3 !== n2[r2];
  });
}
__name(C, "C");
function D(n2, t2) {
  return "function" == typeof t2 ? t2(n2) : t2;
}
__name(D, "D");
const hooks = {
  __proto__: null,
  useCallback: x,
  useContext: P$2,
  useDebugValue: V,
  useEffect: _$1,
  useErrorBoundary: b,
  useId: g$6,
  useImperativeHandle: T,
  useLayoutEffect: A,
  useMemo: q,
  useReducer: y,
  useRef: F,
  useState: p$2
};
const XMLNS$1 = "http://www.w3.org/2000/svg";
function SentryLogo() {
  const createElementNS = /* @__PURE__ */ __name((tagName) => DOCUMENT.createElementNS(XMLNS$1, tagName), "createElementNS");
  const svg = setAttributesNS(createElementNS("svg"), {
    width: "32",
    height: "30",
    viewBox: "0 0 72 66",
    fill: "inherit"
  });
  const path = setAttributesNS(createElementNS("path"), {
    transform: "translate(11, 11)",
    d: "M29,2.26a4.67,4.67,0,0,0-8,0L14.42,13.53A32.21,32.21,0,0,1,32.17,40.19H27.55A27.68,27.68,0,0,0,12.09,17.47L6,28a15.92,15.92,0,0,1,9.23,12.17H4.62A.76.76,0,0,1,4,39.06l2.94-5a10.74,10.74,0,0,0-3.36-1.9l-2.91,5a4.54,4.54,0,0,0,1.69,6.24A4.66,4.66,0,0,0,4.62,44H19.15a19.4,19.4,0,0,0-8-17.31l2.31-4A23.87,23.87,0,0,1,23.76,44H36.07a35.88,35.88,0,0,0-16.41-31.8l4.67-8a.77.77,0,0,1,1.05-.27c.53.29,20.29,34.77,20.66,35.17a.76.76,0,0,1-.68,1.13H40.6q.09,1.91,0,3.81h4.78A4.59,4.59,0,0,0,50,39.43a4.49,4.49,0,0,0-.62-2.28Z"
  });
  svg.appendChild(path);
  return svg;
}
__name(SentryLogo, "SentryLogo");
function DialogHeader({ options: options5 }) {
  const logoHtml = q(() => ({ __html: SentryLogo().outerHTML }), []);
  return y$1(
    "h2",
    { class: "dialog__header" },
    y$1("span", { class: "dialog__title" }, options5.formTitle),
    options5.showBranding ? y$1(
      "a",
      {
        class: "brand-link",
        target: "_blank",
        href: "https://sentry.io/welcome/",
        title: "Powered by Sentry",
        rel: "noopener noreferrer",
        dangerouslySetInnerHTML: logoHtml
      }
    ) : null
  );
}
__name(DialogHeader, "DialogHeader");
function getMissingFields(feedback, props) {
  const emptyFields = [];
  if (props.isNameRequired && !feedback.name) {
    emptyFields.push(props.nameLabel);
  }
  if (props.isEmailRequired && !feedback.email) {
    emptyFields.push(props.emailLabel);
  }
  if (!feedback.message) {
    emptyFields.push(props.messageLabel);
  }
  return emptyFields;
}
__name(getMissingFields, "getMissingFields");
function retrieveStringValue(formData, key) {
  const value3 = formData.get(key);
  if (typeof value3 === "string") {
    return value3.trim();
  }
  return "";
}
__name(retrieveStringValue, "retrieveStringValue");
function Form({
  options: options5,
  defaultEmail,
  defaultName,
  onFormClose,
  onSubmit,
  onSubmitSuccess,
  onSubmitError,
  showEmail,
  showName,
  screenshotInput
}) {
  const {
    tags,
    addScreenshotButtonLabel,
    removeScreenshotButtonLabel,
    cancelButtonLabel,
    emailLabel,
    emailPlaceholder,
    isEmailRequired,
    isNameRequired,
    messageLabel,
    messagePlaceholder,
    nameLabel,
    namePlaceholder,
    submitButtonLabel,
    isRequiredLabel
  } = options5;
  const [error2, setError] = p$2(null);
  const [showScreenshotInput, setShowScreenshotInput] = p$2(false);
  const ScreenshotInputComponent = screenshotInput && screenshotInput.input;
  const [screenshotError, setScreenshotError] = p$2(null);
  const onScreenshotError = x((error3) => {
    setScreenshotError(error3);
    setShowScreenshotInput(false);
  }, []);
  const hasAllRequiredFields = x(
    (data30) => {
      const missingFields = getMissingFields(data30, {
        emailLabel,
        isEmailRequired,
        isNameRequired,
        messageLabel,
        nameLabel
      });
      if (missingFields.length > 0) {
        setError(`Please enter in the following required fields: ${missingFields.join(", ")}`);
      } else {
        setError(null);
      }
      return missingFields.length === 0;
    },
    [emailLabel, isEmailRequired, isNameRequired, messageLabel, nameLabel]
  );
  const handleSubmit = x(
    async (e2) => {
      try {
        e2.preventDefault();
        if (!(e2.target instanceof HTMLFormElement)) {
          return;
        }
        const formData = new FormData(e2.target);
        const attachment = await (screenshotInput && showScreenshotInput ? screenshotInput.value() : void 0);
        const data30 = {
          name: retrieveStringValue(formData, "name"),
          email: retrieveStringValue(formData, "email"),
          message: retrieveStringValue(formData, "message"),
          attachments: attachment ? [attachment] : void 0
        };
        if (!hasAllRequiredFields(data30)) {
          return;
        }
        try {
          await onSubmit(
            {
              name: data30.name,
              email: data30.email,
              message: data30.message,
              source: FEEDBACK_WIDGET_SOURCE,
              tags
            },
            { attachments: data30.attachments }
          );
          onSubmitSuccess(data30);
        } catch (error3) {
          DEBUG_BUILD$1 && logger$2.error(error3);
          setError(error3);
          onSubmitError(error3);
        }
      } catch (e22) {
      }
    },
    [screenshotInput && showScreenshotInput, onSubmitSuccess, onSubmitError]
  );
  return y$1(
    "form",
    { class: "form", onSubmit: handleSubmit },
    ScreenshotInputComponent && showScreenshotInput ? y$1(ScreenshotInputComponent, { onError: onScreenshotError }) : null,
    y$1(
      "div",
      { class: "form__right", "data-sentry-feedback": true },
      y$1(
        "div",
        { class: "form__top" },
        error2 ? y$1("div", { class: "form__error-container" }, error2) : null,
        showName ? y$1(
          "label",
          { for: "name", class: "form__label" },
          y$1(LabelText, { label: nameLabel, isRequiredLabel, isRequired: isNameRequired }),
          y$1(
            "input",
            {
              class: "form__input",
              defaultValue: defaultName,
              id: "name",
              name: "name",
              placeholder: namePlaceholder,
              required: isNameRequired,
              type: "text"
            }
          )
        ) : y$1("input", { "aria-hidden": true, value: defaultName, name: "name", type: "hidden" }),
        showEmail ? y$1(
          "label",
          { for: "email", class: "form__label" },
          y$1(LabelText, { label: emailLabel, isRequiredLabel, isRequired: isEmailRequired }),
          y$1(
            "input",
            {
              class: "form__input",
              defaultValue: defaultEmail,
              id: "email",
              name: "email",
              placeholder: emailPlaceholder,
              required: isEmailRequired,
              type: "email"
            }
          )
        ) : y$1("input", { "aria-hidden": true, value: defaultEmail, name: "email", type: "hidden" }),
        y$1(
          "label",
          { for: "message", class: "form__label" },
          y$1(LabelText, { label: messageLabel, isRequiredLabel, isRequired: true }),
          y$1(
            "textarea",
            {
              autoFocus: true,
              class: "form__input form__input--textarea",
              id: "message",
              name: "message",
              placeholder: messagePlaceholder,
              required: true,
              rows: 5
            }
          )
        ),
        ScreenshotInputComponent ? y$1(
          "label",
          { for: "screenshot", class: "form__label" },
          y$1(
            "button",
            {
              class: "btn btn--default",
              type: "button",
              onClick: /* @__PURE__ */ __name(() => {
                setScreenshotError(null);
                setShowScreenshotInput((prev2) => !prev2);
              }, "onClick")
            },
            showScreenshotInput ? removeScreenshotButtonLabel : addScreenshotButtonLabel
          ),
          screenshotError ? y$1("div", { class: "form__error-container" }, screenshotError.message) : null
        ) : null
      ),
      y$1(
        "div",
        { class: "btn-group" },
        y$1(
          "button",
          { class: "btn btn--primary", type: "submit" },
          submitButtonLabel
        ),
        y$1(
          "button",
          { class: "btn btn--default", type: "button", onClick: onFormClose },
          cancelButtonLabel
        )
      )
    )
  );
}
__name(Form, "Form");
function LabelText({
  label: label8,
  isRequired,
  isRequiredLabel
}) {
  return y$1(
    "span",
    { class: "form__label__text" },
    label8,
    isRequired && y$1("span", { class: "form__label__text--required" }, isRequiredLabel)
  );
}
__name(LabelText, "LabelText");
const WIDTH = 16;
const HEIGHT = 17;
const XMLNS = "http://www.w3.org/2000/svg";
function SuccessIcon() {
  const createElementNS = /* @__PURE__ */ __name((tagName) => WINDOW.document.createElementNS(XMLNS, tagName), "createElementNS");
  const svg = setAttributesNS(createElementNS("svg"), {
    width: `${WIDTH}`,
    height: `${HEIGHT}`,
    viewBox: `0 0 ${WIDTH} ${HEIGHT}`,
    fill: "inherit"
  });
  const g2 = setAttributesNS(createElementNS("g"), {
    clipPath: "url(#clip0_57_156)"
  });
  const path2 = setAttributesNS(createElementNS("path"), {
    ["fill-rule"]: "evenodd",
    ["clip-rule"]: "evenodd",
    d: "M3.55544 15.1518C4.87103 16.0308 6.41775 16.5 8 16.5C10.1217 16.5 12.1566 15.6571 13.6569 14.1569C15.1571 12.6566 16 10.6217 16 8.5C16 6.91775 15.5308 5.37103 14.6518 4.05544C13.7727 2.73985 12.5233 1.71447 11.0615 1.10897C9.59966 0.503466 7.99113 0.34504 6.43928 0.653721C4.88743 0.962403 3.46197 1.72433 2.34315 2.84315C1.22433 3.96197 0.462403 5.38743 0.153721 6.93928C-0.15496 8.49113 0.00346625 10.0997 0.608967 11.5615C1.21447 13.0233 2.23985 14.2727 3.55544 15.1518ZM4.40546 3.1204C5.46945 2.40946 6.72036 2.03 8 2.03C9.71595 2.03 11.3616 2.71166 12.575 3.92502C13.7883 5.13838 14.47 6.78405 14.47 8.5C14.47 9.77965 14.0905 11.0306 13.3796 12.0945C12.6687 13.1585 11.6582 13.9878 10.476 14.4775C9.29373 14.9672 7.99283 15.0953 6.73777 14.8457C5.48271 14.596 4.32987 13.9798 3.42502 13.075C2.52018 12.1701 1.90397 11.0173 1.65432 9.76224C1.40468 8.50718 1.5328 7.20628 2.0225 6.02404C2.5122 4.8418 3.34148 3.83133 4.40546 3.1204Z"
  });
  const path = setAttributesNS(createElementNS("path"), {
    d: "M6.68775 12.4297C6.78586 12.4745 6.89218 12.4984 7 12.5C7.11275 12.4955 7.22315 12.4664 7.32337 12.4145C7.4236 12.3627 7.51121 12.2894 7.58 12.2L12 5.63999C12.0848 5.47724 12.1071 5.28902 12.0625 5.11098C12.0178 4.93294 11.9095 4.77744 11.7579 4.67392C11.6064 4.57041 11.4221 4.52608 11.24 4.54931C11.0579 4.57254 10.8907 4.66173 10.77 4.79999L6.88 10.57L5.13 8.56999C5.06508 8.49566 4.98613 8.43488 4.89768 8.39111C4.80922 8.34735 4.713 8.32148 4.61453 8.31498C4.51605 8.30847 4.41727 8.32147 4.32382 8.35322C4.23038 8.38497 4.14413 8.43484 4.07 8.49999C3.92511 8.63217 3.83692 8.81523 3.82387 9.01092C3.81083 9.2066 3.87393 9.39976 4 9.54999L6.43 12.24C6.50187 12.3204 6.58964 12.385 6.68775 12.4297Z"
  });
  svg.appendChild(g2).append(path, path2);
  const speakerDefs = createElementNS("defs");
  const speakerClipPathDef = setAttributesNS(createElementNS("clipPath"), {
    id: "clip0_57_156"
  });
  const speakerRect = setAttributesNS(createElementNS("rect"), {
    width: `${WIDTH}`,
    height: `${WIDTH}`,
    fill: "white",
    transform: "translate(0 0.5)"
  });
  speakerClipPathDef.appendChild(speakerRect);
  speakerDefs.appendChild(speakerClipPathDef);
  svg.appendChild(speakerDefs).appendChild(speakerClipPathDef).appendChild(speakerRect);
  return svg;
}
__name(SuccessIcon, "SuccessIcon");
function Dialog({ open: open2, onFormSubmitted, ...props }) {
  const options5 = props.options;
  const successIconHtml = q(() => ({ __html: SuccessIcon().outerHTML }), []);
  const [timeoutId, setTimeoutId] = p$2(null);
  const handleOnSuccessClick = x(() => {
    if (timeoutId) {
      clearTimeout(timeoutId);
      setTimeoutId(null);
    }
    onFormSubmitted();
  }, [timeoutId]);
  const onSubmitSuccess = x(
    (data30) => {
      props.onSubmitSuccess(data30);
      setTimeoutId(
        setTimeout(() => {
          onFormSubmitted();
          setTimeoutId(null);
        }, SUCCESS_MESSAGE_TIMEOUT)
      );
    },
    [onFormSubmitted]
  );
  return y$1(
    g$1$1,
    null,
    timeoutId ? y$1(
      "div",
      { class: "success__position", onClick: handleOnSuccessClick },
      y$1(
        "div",
        { class: "success__content" },
        options5.successMessageText,
        y$1("span", { class: "success__icon", dangerouslySetInnerHTML: successIconHtml })
      )
    ) : y$1(
      "dialog",
      { class: "dialog", onClick: options5.onFormClose, open: open2 },
      y$1(
        "div",
        { class: "dialog__position" },
        y$1(
          "div",
          {
            class: "dialog__content",
            onClick: /* @__PURE__ */ __name((e2) => {
              e2.stopPropagation();
            }, "onClick")
          },
          y$1(DialogHeader, { options: options5 }),
          y$1(Form, { ...props, onSubmitSuccess })
        )
      )
    )
  );
}
__name(Dialog, "Dialog");
const DIALOG = `
.dialog {
  position: fixed;
  z-index: var(--z-index);
  margin: 0;
  inset: 0;

  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  height: 100vh;
  width: 100vw;

  color: var(--dialog-color, var(--foreground));
  fill: var(--dialog-color, var(--foreground));
  line-height: 1.75em;

  background-color: rgba(0, 0, 0, 0.05);
  border: none;
  inset: 0;
  opacity: 1;
  transition: opacity 0.2s ease-in-out;
}

.dialog__position {
  position: fixed;
  z-index: var(--z-index);
  inset: var(--dialog-inset);
  padding: var(--page-margin);
  display: flex;
  max-height: calc(100vh - (2 * var(--page-margin)));
}
@media (max-width: 600px) {
  .dialog__position {
    inset: var(--page-margin);
    padding: 0;
  }
}

.dialog__position:has(.editor) {
  inset: var(--page-margin);
  padding: 0;
}

.dialog:not([open]) {
  opacity: 0;
  pointer-events: none;
  visibility: hidden;
}
.dialog:not([open]) .dialog__content {
  transform: translate(0, -16px) scale(0.98);
}

.dialog__content {
  display: flex;
  flex-direction: column;
  gap: 16px;
  padding: var(--dialog-padding, 24px);
  max-width: 100%;
  width: 100%;
  max-height: 100%;
  overflow: auto;

  background: var(--dialog-background, var(--background));
  border-radius: var(--dialog-border-radius, 20px);
  border: var(--dialog-border, var(--border));
  box-shadow: var(--dialog-box-shadow, var(--box-shadow));
  transform: translate(0, 0) scale(1);
  transition: transform 0.2s ease-in-out;
}

`;
const DIALOG_HEADER = `
.dialog__header {
  display: flex;
  gap: 4px;
  justify-content: space-between;
  font-weight: var(--dialog-header-weight, 600);
  margin: 0;
}
.dialog__title {
  align-self: center;
  width: var(--form-width, 272px);
}

@media (max-width: 600px) {
  .dialog__title {
    width: auto;
  }
}

.dialog__position:has(.editor) .dialog__title {
  width: auto;
}


.brand-link {
  display: inline-flex;
}
.brand-link:focus-visible {
  outline: var(--outline);
}
`;
const FORM = `
.form {
  display: flex;
  overflow: auto;
  flex-direction: row;
  gap: 16px;
  flex: 1 0;
}

.form__right {
  flex: 0 0 auto;
  display: flex;
  overflow: auto;
  flex-direction: column;
  justify-content: space-between;
  gap: 20px;
  width: var(--form-width, 100%);
}

.dialog__position:has(.editor) .form__right {
  width: var(--form-width, 272px);
}

.form__top {
  display: flex;
  flex-direction: column;
  gap: 8px;
}

.form__error-container {
  color: var(--error-color);
  fill: var(--error-color);
}

.form__label {
  display: flex;
  flex-direction: column;
  gap: 4px;
  margin: 0px;
}

.form__label__text {
  display: flex;
  gap: 4px;
  align-items: center;
}

.form__label__text--required {
  font-size: 0.85em;
}

.form__input {
  font-family: inherit;
  line-height: inherit;
  background: transparent;
  box-sizing: border-box;
  border: var(--input-border, var(--border));
  border-radius: var(--input-border-radius, 6px);
  color: var(--input-color, inherit);
  fill: var(--input-color, inherit);
  font-size: var(--input-font-size, inherit);
  font-weight: var(--input-font-weight, 500);
  padding: 6px 12px;
}

.form__input::placeholder {
  opacity: 0.65;
  color: var(--input-placeholder-color, inherit);
  filter: var(--interactive-filter);
}

.form__input:focus-visible {
  outline: var(--input-focus-outline, var(--outline));
}

.form__input--textarea {
  font-family: inherit;
  resize: vertical;
}

.error {
  color: var(--error-color);
  fill: var(--error-color);
}
`;
const BUTTON = `
.btn-group {
  display: grid;
  gap: 8px;
}

.btn {
  line-height: inherit;
  border: var(--button-border, var(--border));
  border-radius: var(--button-border-radius, 6px);
  cursor: pointer;
  font-family: inherit;
  font-size: var(--button-font-size, inherit);
  font-weight: var(--button-font-weight, 600);
  padding: var(--button-padding, 6px 16px);
}
.btn[disabled] {
  opacity: 0.6;
  pointer-events: none;
}

.btn--primary {
  color: var(--button-primary-color, var(--accent-foreground));
  fill: var(--button-primary-color, var(--accent-foreground));
  background: var(--button-primary-background, var(--accent-background));
  border: var(--button-primary-border, var(--border));
  border-radius: var(--button-primary-border-radius, 6px);
  font-weight: var(--button-primary-font-weight, 500);
}
.btn--primary:hover {
  color: var(--button-primary-hover-color, var(--accent-foreground));
  fill: var(--button-primary-hover-color, var(--accent-foreground));
  background: var(--button-primary-hover-background, var(--accent-background));
  filter: var(--interactive-filter);
}
.btn--primary:focus-visible {
  background: var(--button-primary-hover-background, var(--accent-background));
  filter: var(--interactive-filter);
  outline: var(--button-primary-focus-outline, var(--outline));
}

.btn--default {
  color: var(--button-color, var(--foreground));
  fill: var(--button-color, var(--foreground));
  background: var(--button-background, var(--background));
  border: var(--button-border, var(--border));
  border-radius: var(--button-border-radius, 6px);
  font-weight: var(--button-font-weight, 500);
}
.btn--default:hover {
  color: var(--button-color, var(--foreground));
  fill: var(--button-color, var(--foreground));
  background: var(--button-hover-background, var(--background));
  filter: var(--interactive-filter);
}
.btn--default:focus-visible {
  background: var(--button-hover-background, var(--background));
  filter: var(--interactive-filter);
  outline: var(--button-focus-outline, var(--outline));
}
`;
const SUCCESS = `
.success__position {
  position: fixed;
  inset: var(--dialog-inset);
  padding: var(--page-margin);
  z-index: var(--z-index);
}
.success__content {
  background: var(--success-background, var(--background));
  border: var(--success-border, var(--border));
  border-radius: var(--success-border-radius, 1.7em/50%);
  box-shadow: var(--success-box-shadow, var(--box-shadow));
  font-weight: var(--success-font-weight, 600);
  color: var(--success-color);
  fill: var(--success-color);
  padding: 12px 24px;
  line-height: 1.75em;

  display: grid;
  align-items: center;
  grid-auto-flow: column;
  gap: 6px;
  cursor: default;
}

.success__icon {
  display: flex;
}
`;
function createDialogStyles(styleNonce) {
  const style2 = DOCUMENT.createElement("style");
  style2.textContent = `
:host {
  --dialog-inset: var(--inset);
}

${DIALOG}
${DIALOG_HEADER}
${FORM}
${BUTTON}
${SUCCESS}
`;
  if (styleNonce) {
    style2.setAttribute("nonce", styleNonce);
  }
  return style2;
}
__name(createDialogStyles, "createDialogStyles");
function getUser() {
  const currentUser = getCurrentScope$1().getUser();
  const isolationUser = getIsolationScope().getUser();
  const globalUser = getGlobalScope().getUser();
  if (currentUser && Object.keys(currentUser).length) {
    return currentUser;
  }
  if (isolationUser && Object.keys(isolationUser).length) {
    return isolationUser;
  }
  return globalUser;
}
__name(getUser, "getUser");
const feedbackModalIntegration = /* @__PURE__ */ __name(() => {
  return {
    name: "FeedbackModal",
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    setupOnce() {
    },
    createDialog: /* @__PURE__ */ __name(({ options: options5, screenshotIntegration, sendFeedback: sendFeedback2, shadow }) => {
      const shadowRoot = shadow;
      const userKey = options5.useSentryUser;
      const user = getUser();
      const el = DOCUMENT.createElement("div");
      const style2 = createDialogStyles(options5.styleNonce);
      let originalOverflow = "";
      const dialog = {
        get el() {
          return el;
        },
        appendToDom() {
          if (!shadowRoot.contains(style2) && !shadowRoot.contains(el)) {
            shadowRoot.appendChild(style2);
            shadowRoot.appendChild(el);
          }
        },
        removeFromDom() {
          shadowRoot.removeChild(el);
          shadowRoot.removeChild(style2);
          DOCUMENT.body.style.overflow = originalOverflow;
        },
        open() {
          renderContent(true);
          options5.onFormOpen && options5.onFormOpen();
          originalOverflow = DOCUMENT.body.style.overflow;
          DOCUMENT.body.style.overflow = "hidden";
        },
        close() {
          renderContent(false);
          DOCUMENT.body.style.overflow = originalOverflow;
        }
      };
      const screenshotInput = screenshotIntegration && screenshotIntegration.createInput({ h: y$1, hooks, dialog, options: options5 });
      const renderContent = /* @__PURE__ */ __name((open2) => {
        B$1(
          y$1(
            Dialog,
            {
              options: options5,
              screenshotInput,
              showName: options5.showName || options5.isNameRequired,
              showEmail: options5.showEmail || options5.isEmailRequired,
              defaultName: userKey && user && user[userKey.name] || "",
              defaultEmail: userKey && user && user[userKey.email] || "",
              onFormClose: /* @__PURE__ */ __name(() => {
                renderContent(false);
                options5.onFormClose && options5.onFormClose();
              }, "onFormClose"),
              onSubmit: sendFeedback2,
              onSubmitSuccess: /* @__PURE__ */ __name((data30) => {
                renderContent(false);
                options5.onSubmitSuccess && options5.onSubmitSuccess(data30);
              }, "onSubmitSuccess"),
              onSubmitError: /* @__PURE__ */ __name((error2) => {
                options5.onSubmitError && options5.onSubmitError(error2);
              }, "onSubmitError"),
              onFormSubmitted: /* @__PURE__ */ __name(() => {
                options5.onFormSubmitted && options5.onFormSubmitted();
              }, "onFormSubmitted"),
              open: open2
            }
          ),
          el
        );
      }, "renderContent");
      return dialog;
    }, "createDialog")
  };
}, "feedbackModalIntegration");
function CropCornerFactory({
  h: h2
  // eslint-disable-line @typescript-eslint/no-unused-vars
}) {
  return /* @__PURE__ */ __name(function CropCorner({
    top,
    left,
    corner,
    onGrabButton
  }) {
    return h2(
      "button",
      {
        class: `editor__crop-corner editor__crop-corner--${corner} `,
        style: {
          top,
          left
        },
        onMouseDown: /* @__PURE__ */ __name((e2) => {
          e2.preventDefault();
          onGrabButton(e2, corner);
        }, "onMouseDown"),
        onClick: /* @__PURE__ */ __name((e2) => {
          e2.preventDefault();
        }, "onClick")
      }
    );
  }, "CropCorner");
}
__name(CropCornerFactory, "CropCornerFactory");
function createScreenshotInputStyles(styleNonce) {
  const style2 = DOCUMENT.createElement("style");
  const surface200 = "#1A141F";
  const gray100 = "#302735";
  style2.textContent = `
.editor {
  padding: 10px;
  padding-top: 65px;
  padding-bottom: 65px;
  flex-grow: 1;

  background-color: ${surface200};
  background-image: repeating-linear-gradient(
      -145deg,
      transparent,
      transparent 8px,
      ${surface200} 8px,
      ${surface200} 11px
    ),
    repeating-linear-gradient(
      -45deg,
      transparent,
      transparent 15px,
      ${gray100} 15px,
      ${gray100} 16px
    );
}

.editor__canvas-container {
  width: 100%;
  height: 100%;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
}

.editor__canvas-container canvas {
  object-fit: contain;
  position: relative;
}

.editor__crop-btn-group {
  padding: 8px;
  gap: 8px;
  border-radius: var(--menu-border-radius, 6px);
  background: var(--button-primary-background, var(--background));
  width: 175px;
  position: absolute;
}

.editor__crop-corner {
  width: 30px;
  height: 30px;
  position: absolute;
  background: none;
  border: 3px solid #ffffff;
}

.editor__crop-corner--top-left {
  cursor: nwse-resize;
  border-right: none;
  border-bottom: none;
}
.editor__crop-corner--top-right {
  cursor: nesw-resize;
  border-left: none;
  border-bottom: none;
}
.editor__crop-corner--bottom-left {
  cursor: nesw-resize;
  border-right: none;
  border-top: none;
}
.editor__crop-corner--bottom-right {
  cursor: nwse-resize;
  border-left: none;
  border-top: none;
}
`;
  if (styleNonce) {
    style2.setAttribute("nonce", styleNonce);
  }
  return style2;
}
__name(createScreenshotInputStyles, "createScreenshotInputStyles");
function useTakeScreenshotFactory({ hooks: hooks2 }) {
  return /* @__PURE__ */ __name(function useTakeScreenshot({ onBeforeScreenshot, onScreenshot, onAfterScreenshot, onError }) {
    hooks2.useEffect(() => {
      const takeScreenshot = /* @__PURE__ */ __name(async () => {
        onBeforeScreenshot();
        const stream = await NAVIGATOR.mediaDevices.getDisplayMedia({
          video: {
            width: WINDOW.innerWidth * WINDOW.devicePixelRatio,
            height: WINDOW.innerHeight * WINDOW.devicePixelRatio
          },
          audio: false,
          // @ts-expect-error experimental flags: https://developer.mozilla.org/en-US/docs/Web/API/MediaDevices/getDisplayMedia#prefercurrenttab
          monitorTypeSurfaces: "exclude",
          preferCurrentTab: true,
          selfBrowserSurface: "include",
          surfaceSwitching: "exclude"
        });
        const video = DOCUMENT.createElement("video");
        await new Promise((resolve2, reject3) => {
          video.srcObject = stream;
          video.onloadedmetadata = () => {
            onScreenshot(video);
            stream.getTracks().forEach((track2) => track2.stop());
            resolve2();
          };
          video.play().catch(reject3);
        });
        onAfterScreenshot();
      }, "takeScreenshot");
      takeScreenshot().catch(onError);
    }, []);
  }, "useTakeScreenshot");
}
__name(useTakeScreenshotFactory, "useTakeScreenshotFactory");
const CROP_BUTTON_SIZE = 30;
const CROP_BUTTON_BORDER = 3;
const CROP_BUTTON_OFFSET = CROP_BUTTON_SIZE + CROP_BUTTON_BORDER;
const DPI = WINDOW.devicePixelRatio;
const constructRect = /* @__PURE__ */ __name((box) => {
  return {
    x: Math.min(box.startX, box.endX),
    y: Math.min(box.startY, box.endY),
    width: Math.abs(box.startX - box.endX),
    height: Math.abs(box.startY - box.endY)
  };
}, "constructRect");
const getContainedSize = /* @__PURE__ */ __name((img) => {
  const imgClientHeight = img.clientHeight;
  const imgClientWidth = img.clientWidth;
  const ratio = img.width / img.height;
  let width2 = imgClientHeight * ratio;
  let height = imgClientHeight;
  if (width2 > imgClientWidth) {
    width2 = imgClientWidth;
    height = imgClientWidth / ratio;
  }
  const x2 = (imgClientWidth - width2) / 2;
  const y2 = (imgClientHeight - height) / 2;
  return { startX: x2, startY: y2, endX: width2 + x2, endY: height + y2 };
}, "getContainedSize");
function ScreenshotEditorFactory({
  h: h2,
  hooks: hooks2,
  imageBuffer,
  dialog,
  options: options5
}) {
  const useTakeScreenshot = useTakeScreenshotFactory({ hooks: hooks2 });
  return /* @__PURE__ */ __name(function ScreenshotEditor({ onError }) {
    const styles = hooks2.useMemo(() => ({ __html: createScreenshotInputStyles(options5.styleNonce).innerText }), []);
    const CropCorner = CropCornerFactory({ h: h2 });
    const canvasContainerRef = hooks2.useRef(null);
    const cropContainerRef = hooks2.useRef(null);
    const croppingRef = hooks2.useRef(null);
    const [croppingRect, setCroppingRect] = hooks2.useState({ startX: 0, startY: 0, endX: 0, endY: 0 });
    const [confirmCrop, setConfirmCrop] = hooks2.useState(false);
    const [isResizing, setIsResizing] = hooks2.useState(false);
    hooks2.useEffect(() => {
      WINDOW.addEventListener("resize", resizeCropper, false);
    }, []);
    function resizeCropper() {
      const cropper = croppingRef.current;
      const imageDimensions = constructRect(getContainedSize(imageBuffer));
      if (cropper) {
        cropper.width = imageDimensions.width * DPI;
        cropper.height = imageDimensions.height * DPI;
        cropper.style.width = `${imageDimensions.width}px`;
        cropper.style.height = `${imageDimensions.height}px`;
        const ctx = cropper.getContext("2d");
        if (ctx) {
          ctx.scale(DPI, DPI);
        }
      }
      const cropButton = cropContainerRef.current;
      if (cropButton) {
        cropButton.style.width = `${imageDimensions.width}px`;
        cropButton.style.height = `${imageDimensions.height}px`;
      }
      setCroppingRect({ startX: 0, startY: 0, endX: imageDimensions.width, endY: imageDimensions.height });
    }
    __name(resizeCropper, "resizeCropper");
    hooks2.useEffect(() => {
      const cropper = croppingRef.current;
      if (!cropper) {
        return;
      }
      const ctx = cropper.getContext("2d");
      if (!ctx) {
        return;
      }
      const imageDimensions = constructRect(getContainedSize(imageBuffer));
      const croppingBox = constructRect(croppingRect);
      ctx.clearRect(0, 0, imageDimensions.width, imageDimensions.height);
      ctx.fillStyle = "rgba(0, 0, 0, 0.5)";
      ctx.fillRect(0, 0, imageDimensions.width, imageDimensions.height);
      ctx.clearRect(croppingBox.x, croppingBox.y, croppingBox.width, croppingBox.height);
      ctx.strokeStyle = "#ffffff";
      ctx.lineWidth = 3;
      ctx.strokeRect(croppingBox.x + 1, croppingBox.y + 1, croppingBox.width - 2, croppingBox.height - 2);
      ctx.strokeStyle = "#000000";
      ctx.lineWidth = 1;
      ctx.strokeRect(croppingBox.x + 3, croppingBox.y + 3, croppingBox.width - 6, croppingBox.height - 6);
    }, [croppingRect]);
    function onGrabButton(e2, corner) {
      setConfirmCrop(false);
      setIsResizing(true);
      const handleMouseMove2 = makeHandleMouseMove(corner);
      const handleMouseUp = /* @__PURE__ */ __name(() => {
        DOCUMENT.removeEventListener("mousemove", handleMouseMove2);
        DOCUMENT.removeEventListener("mouseup", handleMouseUp);
        setConfirmCrop(true);
        setIsResizing(false);
      }, "handleMouseUp");
      DOCUMENT.addEventListener("mouseup", handleMouseUp);
      DOCUMENT.addEventListener("mousemove", handleMouseMove2);
    }
    __name(onGrabButton, "onGrabButton");
    const makeHandleMouseMove = hooks2.useCallback((corner) => {
      return function(e2) {
        if (!croppingRef.current) {
          return;
        }
        const cropCanvas = croppingRef.current;
        const cropBoundingRect = cropCanvas.getBoundingClientRect();
        const mouseX = e2.clientX - cropBoundingRect.x;
        const mouseY = e2.clientY - cropBoundingRect.y;
        switch (corner) {
          case "top-left":
            setCroppingRect((prev2) => ({
              ...prev2,
              startX: Math.min(Math.max(0, mouseX), prev2.endX - CROP_BUTTON_OFFSET),
              startY: Math.min(Math.max(0, mouseY), prev2.endY - CROP_BUTTON_OFFSET)
            }));
            break;
          case "top-right":
            setCroppingRect((prev2) => ({
              ...prev2,
              endX: Math.max(Math.min(mouseX, cropCanvas.width / DPI), prev2.startX + CROP_BUTTON_OFFSET),
              startY: Math.min(Math.max(0, mouseY), prev2.endY - CROP_BUTTON_OFFSET)
            }));
            break;
          case "bottom-left":
            setCroppingRect((prev2) => ({
              ...prev2,
              startX: Math.min(Math.max(0, mouseX), prev2.endX - CROP_BUTTON_OFFSET),
              endY: Math.max(Math.min(mouseY, cropCanvas.height / DPI), prev2.startY + CROP_BUTTON_OFFSET)
            }));
            break;
          case "bottom-right":
            setCroppingRect((prev2) => ({
              ...prev2,
              endX: Math.max(Math.min(mouseX, cropCanvas.width / DPI), prev2.startX + CROP_BUTTON_OFFSET),
              endY: Math.max(Math.min(mouseY, cropCanvas.height / DPI), prev2.startY + CROP_BUTTON_OFFSET)
            }));
            break;
        }
      };
    }, []);
    const initialPositionRef = hooks2.useRef({ initialX: 0, initialY: 0 });
    function onDragStart2(e2) {
      if (isResizing) return;
      initialPositionRef.current = { initialX: e2.clientX, initialY: e2.clientY };
      const handleMouseMove2 = /* @__PURE__ */ __name((moveEvent) => {
        const cropCanvas = croppingRef.current;
        if (!cropCanvas) return;
        const deltaX = moveEvent.clientX - initialPositionRef.current.initialX;
        const deltaY = moveEvent.clientY - initialPositionRef.current.initialY;
        setCroppingRect((prev2) => {
          const newStartX = Math.max(
            0,
            Math.min(prev2.startX + deltaX, cropCanvas.width / DPI - (prev2.endX - prev2.startX))
          );
          const newStartY = Math.max(
            0,
            Math.min(prev2.startY + deltaY, cropCanvas.height / DPI - (prev2.endY - prev2.startY))
          );
          const newEndX = newStartX + (prev2.endX - prev2.startX);
          const newEndY = newStartY + (prev2.endY - prev2.startY);
          initialPositionRef.current.initialX = moveEvent.clientX;
          initialPositionRef.current.initialY = moveEvent.clientY;
          return {
            startX: newStartX,
            startY: newStartY,
            endX: newEndX,
            endY: newEndY
          };
        });
      }, "handleMouseMove");
      const handleMouseUp = /* @__PURE__ */ __name(() => {
        DOCUMENT.removeEventListener("mousemove", handleMouseMove2);
        DOCUMENT.removeEventListener("mouseup", handleMouseUp);
      }, "handleMouseUp");
      DOCUMENT.addEventListener("mousemove", handleMouseMove2);
      DOCUMENT.addEventListener("mouseup", handleMouseUp);
    }
    __name(onDragStart2, "onDragStart");
    function submit() {
      const cutoutCanvas = DOCUMENT.createElement("canvas");
      const imageBox = constructRect(getContainedSize(imageBuffer));
      const croppingBox = constructRect(croppingRect);
      cutoutCanvas.width = croppingBox.width * DPI;
      cutoutCanvas.height = croppingBox.height * DPI;
      const cutoutCtx = cutoutCanvas.getContext("2d");
      if (cutoutCtx && imageBuffer) {
        cutoutCtx.drawImage(
          imageBuffer,
          croppingBox.x / imageBox.width * imageBuffer.width,
          croppingBox.y / imageBox.height * imageBuffer.height,
          croppingBox.width / imageBox.width * imageBuffer.width,
          croppingBox.height / imageBox.height * imageBuffer.height,
          0,
          0,
          cutoutCanvas.width,
          cutoutCanvas.height
        );
      }
      const ctx = imageBuffer.getContext("2d");
      if (ctx) {
        ctx.clearRect(0, 0, imageBuffer.width, imageBuffer.height);
        imageBuffer.width = cutoutCanvas.width;
        imageBuffer.height = cutoutCanvas.height;
        imageBuffer.style.width = `${croppingBox.width}px`;
        imageBuffer.style.height = `${croppingBox.height}px`;
        ctx.drawImage(cutoutCanvas, 0, 0);
        resizeCropper();
      }
    }
    __name(submit, "submit");
    useTakeScreenshot({
      onBeforeScreenshot: hooks2.useCallback(() => {
        dialog.el.style.display = "none";
      }, []),
      onScreenshot: hooks2.useCallback(
        (imageSource) => {
          const context = imageBuffer.getContext("2d");
          if (!context) {
            throw new Error("Could not get canvas context");
          }
          imageBuffer.width = imageSource.videoWidth;
          imageBuffer.height = imageSource.videoHeight;
          imageBuffer.style.width = "100%";
          imageBuffer.style.height = "100%";
          context.drawImage(imageSource, 0, 0);
        },
        [imageBuffer]
      ),
      onAfterScreenshot: hooks2.useCallback(() => {
        dialog.el.style.display = "block";
        const container = canvasContainerRef.current;
        container && container.appendChild(imageBuffer);
        resizeCropper();
      }, []),
      onError: hooks2.useCallback((error2) => {
        dialog.el.style.display = "block";
        onError(error2);
      }, [])
    });
    return h2(
      "div",
      { class: "editor" },
      h2("style", { nonce: options5.styleNonce, dangerouslySetInnerHTML: styles }),
      h2(
        "div",
        { class: "editor__canvas-container", ref: canvasContainerRef },
        h2(
          "div",
          { class: "editor__crop-container", style: { position: "absolute", zIndex: 1 }, ref: cropContainerRef },
          h2(
            "canvas",
            {
              onMouseDown: onDragStart2,
              style: { position: "absolute", cursor: confirmCrop ? "move" : "auto" },
              ref: croppingRef
            }
          ),
          h2(
            CropCorner,
            {
              left: croppingRect.startX - CROP_BUTTON_BORDER,
              top: croppingRect.startY - CROP_BUTTON_BORDER,
              onGrabButton,
              corner: "top-left"
            }
          ),
          h2(
            CropCorner,
            {
              left: croppingRect.endX - CROP_BUTTON_SIZE + CROP_BUTTON_BORDER,
              top: croppingRect.startY - CROP_BUTTON_BORDER,
              onGrabButton,
              corner: "top-right"
            }
          ),
          h2(
            CropCorner,
            {
              left: croppingRect.startX - CROP_BUTTON_BORDER,
              top: croppingRect.endY - CROP_BUTTON_SIZE + CROP_BUTTON_BORDER,
              onGrabButton,
              corner: "bottom-left"
            }
          ),
          h2(
            CropCorner,
            {
              left: croppingRect.endX - CROP_BUTTON_SIZE + CROP_BUTTON_BORDER,
              top: croppingRect.endY - CROP_BUTTON_SIZE + CROP_BUTTON_BORDER,
              onGrabButton,
              corner: "bottom-right"
            }
          ),
          h2(
            "div",
            {
              style: {
                left: Math.max(0, croppingRect.endX - 191),
                top: Math.max(0, croppingRect.endY + 8),
                display: confirmCrop ? "flex" : "none"
              },
              class: "editor__crop-btn-group"
            },
            h2(
              "button",
              {
                onClick: /* @__PURE__ */ __name((e2) => {
                  e2.preventDefault();
                  if (croppingRef.current) {
                    setCroppingRect({
                      startX: 0,
                      startY: 0,
                      endX: croppingRef.current.width / DPI,
                      endY: croppingRef.current.height / DPI
                    });
                  }
                  setConfirmCrop(false);
                }, "onClick"),
                class: "btn btn--default"
              },
              options5.cancelButtonLabel
            ),
            h2(
              "button",
              {
                onClick: /* @__PURE__ */ __name((e2) => {
                  e2.preventDefault();
                  submit();
                  setConfirmCrop(false);
                }, "onClick"),
                class: "btn btn--primary"
              },
              options5.confirmButtonLabel
            )
          )
        )
      )
    );
  }, "ScreenshotEditor");
}
__name(ScreenshotEditorFactory, "ScreenshotEditorFactory");
const feedbackScreenshotIntegration = /* @__PURE__ */ __name(() => {
  return {
    name: "FeedbackScreenshot",
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    setupOnce() {
    },
    createInput: /* @__PURE__ */ __name(({ h: h2, hooks: hooks2, dialog, options: options5 }) => {
      const imageBuffer = DOCUMENT.createElement("canvas");
      return {
        input: ScreenshotEditorFactory({
          h: h2,
          hooks: hooks2,
          imageBuffer,
          dialog,
          options: options5
        }),
        // eslint-disable-line @typescript-eslint/no-explicit-any
        value: /* @__PURE__ */ __name(async () => {
          const blob = await new Promise((resolve2) => {
            imageBuffer.toBlob(resolve2, "image/png");
          });
          if (blob) {
            const data30 = new Uint8Array(await blob.arrayBuffer());
            const attachment = {
              data: data30,
              filename: "screenshot.png",
              contentType: "application/png"
              // attachmentType?: string;
            };
            return attachment;
          }
          return void 0;
        }, "value")
      };
    }, "createInput")
  };
}, "feedbackScreenshotIntegration");
const feedbackAsyncIntegration = buildFeedbackIntegration({
  lazyLoadIntegration
});
const feedbackSyncIntegration = buildFeedbackIntegration({
  getModalIntegration: /* @__PURE__ */ __name(() => feedbackModalIntegration, "getModalIntegration"),
  getScreenshotIntegration: /* @__PURE__ */ __name(() => feedbackScreenshotIntegration, "getScreenshotIntegration")
});
function increment(name2, value3 = 1, data30) {
  metrics$1.increment(BrowserMetricsAggregator, name2, value3, data30);
}
__name(increment, "increment");
function distribution(name2, value3, data30) {
  metrics$1.distribution(BrowserMetricsAggregator, name2, value3, data30);
}
__name(distribution, "distribution");
function set$4(name2, value3, data30) {
  metrics$1.set(BrowserMetricsAggregator, name2, value3, data30);
}
__name(set$4, "set$4");
function gauge(name2, value3, data30) {
  metrics$1.gauge(BrowserMetricsAggregator, name2, value3, data30);
}
__name(gauge, "gauge");
function timing(name2, value3, unit = "second", data30) {
  return metrics$1.timing(BrowserMetricsAggregator, name2, value3, unit, data30);
}
__name(timing, "timing");
const metrics = {
  increment,
  distribution,
  set: set$4,
  gauge,
  timing
};
const responseToSpanId = /* @__PURE__ */ new WeakMap();
const spanIdToEndTimestamp = /* @__PURE__ */ new Map();
const defaultRequestInstrumentationOptions = {
  traceFetch: true,
  traceXHR: true,
  enableHTTPTimings: true,
  trackFetchStreamPerformance: false
};
function instrumentOutgoingRequests(client, _options) {
  const {
    traceFetch,
    traceXHR,
    trackFetchStreamPerformance,
    shouldCreateSpanForRequest,
    enableHTTPTimings,
    tracePropagationTargets
  } = {
    traceFetch: defaultRequestInstrumentationOptions.traceFetch,
    traceXHR: defaultRequestInstrumentationOptions.traceXHR,
    trackFetchStreamPerformance: defaultRequestInstrumentationOptions.trackFetchStreamPerformance,
    ..._options
  };
  const shouldCreateSpan = typeof shouldCreateSpanForRequest === "function" ? shouldCreateSpanForRequest : (_2) => true;
  const shouldAttachHeadersWithTargets = /* @__PURE__ */ __name((url) => shouldAttachHeaders(url, tracePropagationTargets), "shouldAttachHeadersWithTargets");
  const spans = {};
  if (traceFetch) {
    client.addEventProcessor((event) => {
      if (event.type === "transaction" && event.spans) {
        event.spans.forEach((span) => {
          if (span.op === "http.client") {
            const updatedTimestamp = spanIdToEndTimestamp.get(span.span_id);
            if (updatedTimestamp) {
              span.timestamp = updatedTimestamp / 1e3;
              spanIdToEndTimestamp.delete(span.span_id);
            }
          }
        });
      }
      return event;
    });
    if (trackFetchStreamPerformance) {
      addFetchEndInstrumentationHandler((handlerData) => {
        if (handlerData.response) {
          const span = responseToSpanId.get(handlerData.response);
          if (span && handlerData.endTimestamp) {
            spanIdToEndTimestamp.set(span, handlerData.endTimestamp);
          }
        }
      });
    }
    addFetchInstrumentationHandler((handlerData) => {
      const createdSpan = instrumentFetchRequest(handlerData, shouldCreateSpan, shouldAttachHeadersWithTargets, spans);
      if (handlerData.response && handlerData.fetchData.__span) {
        responseToSpanId.set(handlerData.response, handlerData.fetchData.__span);
      }
      if (createdSpan) {
        const fullUrl = getFullURL(handlerData.fetchData.url);
        const host = fullUrl ? parseUrl$1(fullUrl).host : void 0;
        createdSpan.setAttributes({
          "http.url": fullUrl,
          "server.address": host
        });
      }
      if (enableHTTPTimings && createdSpan) {
        addHTTPTimings(createdSpan);
      }
    });
  }
  if (traceXHR) {
    addXhrInstrumentationHandler((handlerData) => {
      const createdSpan = xhrCallback(handlerData, shouldCreateSpan, shouldAttachHeadersWithTargets, spans);
      if (enableHTTPTimings && createdSpan) {
        addHTTPTimings(createdSpan);
      }
    });
  }
}
__name(instrumentOutgoingRequests, "instrumentOutgoingRequests");
function isPerformanceResourceTiming(entry) {
  return entry.entryType === "resource" && "initiatorType" in entry && typeof entry.nextHopProtocol === "string" && (entry.initiatorType === "fetch" || entry.initiatorType === "xmlhttprequest");
}
__name(isPerformanceResourceTiming, "isPerformanceResourceTiming");
function addHTTPTimings(span) {
  const { url } = spanToJSON(span).data || {};
  if (!url || typeof url !== "string") {
    return;
  }
  const cleanup = addPerformanceInstrumentationHandler("resource", ({ entries }) => {
    entries.forEach((entry) => {
      if (isPerformanceResourceTiming(entry) && entry.name.endsWith(url)) {
        const spanData = resourceTimingEntryToSpanData(entry);
        spanData.forEach((data30) => span.setAttribute(...data30));
        setTimeout(cleanup);
      }
    });
  });
}
__name(addHTTPTimings, "addHTTPTimings");
function extractNetworkProtocol(nextHopProtocol) {
  let name2 = "unknown";
  let version2 = "unknown";
  let _name = "";
  for (const char of nextHopProtocol) {
    if (char === "/") {
      [name2, version2] = nextHopProtocol.split("/");
      break;
    }
    if (!isNaN(Number(char))) {
      name2 = _name === "h" ? "http" : _name;
      version2 = nextHopProtocol.split(_name)[1];
      break;
    }
    _name += char;
  }
  if (_name === nextHopProtocol) {
    name2 = _name;
  }
  return { name: name2, version: version2 };
}
__name(extractNetworkProtocol, "extractNetworkProtocol");
function getAbsoluteTime(time = 0) {
  return ((browserPerformanceTimeOrigin || performance.timeOrigin) + time) / 1e3;
}
__name(getAbsoluteTime, "getAbsoluteTime");
function resourceTimingEntryToSpanData(resourceTiming) {
  const { name: name2, version: version2 } = extractNetworkProtocol(resourceTiming.nextHopProtocol);
  const timingSpanData = [];
  timingSpanData.push(["network.protocol.version", version2], ["network.protocol.name", name2]);
  if (!browserPerformanceTimeOrigin) {
    return timingSpanData;
  }
  return [
    ...timingSpanData,
    ["http.request.redirect_start", getAbsoluteTime(resourceTiming.redirectStart)],
    ["http.request.fetch_start", getAbsoluteTime(resourceTiming.fetchStart)],
    ["http.request.domain_lookup_start", getAbsoluteTime(resourceTiming.domainLookupStart)],
    ["http.request.domain_lookup_end", getAbsoluteTime(resourceTiming.domainLookupEnd)],
    ["http.request.connect_start", getAbsoluteTime(resourceTiming.connectStart)],
    ["http.request.secure_connection_start", getAbsoluteTime(resourceTiming.secureConnectionStart)],
    ["http.request.connection_end", getAbsoluteTime(resourceTiming.connectEnd)],
    ["http.request.request_start", getAbsoluteTime(resourceTiming.requestStart)],
    ["http.request.response_start", getAbsoluteTime(resourceTiming.responseStart)],
    ["http.request.response_end", getAbsoluteTime(resourceTiming.responseEnd)]
  ];
}
__name(resourceTimingEntryToSpanData, "resourceTimingEntryToSpanData");
function shouldAttachHeaders(targetUrl, tracePropagationTargets) {
  const href = WINDOW$5.location && WINDOW$5.location.href;
  if (!href) {
    const isRelativeSameOriginRequest = !!targetUrl.match(/^\/(?!\/)/);
    if (!tracePropagationTargets) {
      return isRelativeSameOriginRequest;
    } else {
      return stringMatchesSomePattern(targetUrl, tracePropagationTargets);
    }
  } else {
    let resolvedUrl;
    let currentOrigin;
    try {
      resolvedUrl = new URL(targetUrl, href);
      currentOrigin = new URL(href).origin;
    } catch (e2) {
      return false;
    }
    const isSameOriginRequest = resolvedUrl.origin === currentOrigin;
    if (!tracePropagationTargets) {
      return isSameOriginRequest;
    } else {
      return stringMatchesSomePattern(resolvedUrl.toString(), tracePropagationTargets) || isSameOriginRequest && stringMatchesSomePattern(resolvedUrl.pathname, tracePropagationTargets);
    }
  }
}
__name(shouldAttachHeaders, "shouldAttachHeaders");
function xhrCallback(handlerData, shouldCreateSpan, shouldAttachHeaders2, spans) {
  const xhr = handlerData.xhr;
  const sentryXhrData = xhr && xhr[SENTRY_XHR_DATA_KEY];
  if (!xhr || xhr.__sentry_own_request__ || !sentryXhrData) {
    return void 0;
  }
  const shouldCreateSpanResult = hasTracingEnabled() && shouldCreateSpan(sentryXhrData.url);
  if (handlerData.endTimestamp && shouldCreateSpanResult) {
    const spanId = xhr.__sentry_xhr_span_id__;
    if (!spanId) return;
    const span2 = spans[spanId];
    if (span2 && sentryXhrData.status_code !== void 0) {
      setHttpStatus(span2, sentryXhrData.status_code);
      span2.end();
      delete spans[spanId];
    }
    return void 0;
  }
  const fullUrl = getFullURL(sentryXhrData.url);
  const host = fullUrl ? parseUrl$1(fullUrl).host : void 0;
  const hasParent = !!getActiveSpan();
  const span = shouldCreateSpanResult && hasParent ? startInactiveSpan({
    name: `${sentryXhrData.method} ${sentryXhrData.url}`,
    attributes: {
      type: "xhr",
      "http.method": sentryXhrData.method,
      "http.url": fullUrl,
      url: sentryXhrData.url,
      "server.address": host,
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.http.browser",
      [SEMANTIC_ATTRIBUTE_SENTRY_OP]: "http.client"
    }
  }) : new SentryNonRecordingSpan();
  xhr.__sentry_xhr_span_id__ = span.spanContext().spanId;
  spans[xhr.__sentry_xhr_span_id__] = span;
  if (shouldAttachHeaders2(sentryXhrData.url)) {
    addTracingHeadersToXhrRequest(
      xhr,
      // If performance is disabled (TWP) or there's no active root span (pageload/navigation/interaction),
      // we do not want to use the span as base for the trace headers,
      // which means that the headers will be generated from the scope and the sampling decision is deferred
      hasTracingEnabled() && hasParent ? span : void 0
    );
  }
  return span;
}
__name(xhrCallback, "xhrCallback");
function addTracingHeadersToXhrRequest(xhr, span) {
  const { "sentry-trace": sentryTrace, baggage } = getTraceData({ span });
  if (sentryTrace) {
    setHeaderOnXhr(xhr, sentryTrace, baggage);
  }
}
__name(addTracingHeadersToXhrRequest, "addTracingHeadersToXhrRequest");
function setHeaderOnXhr(xhr, sentryTraceHeader, sentryBaggageHeader) {
  try {
    xhr.setRequestHeader("sentry-trace", sentryTraceHeader);
    if (sentryBaggageHeader) {
      xhr.setRequestHeader("baggage", sentryBaggageHeader);
    }
  } catch (_2) {
  }
}
__name(setHeaderOnXhr, "setHeaderOnXhr");
function getFullURL(url) {
  try {
    const parsed = new URL(url, WINDOW$5.location.origin);
    return parsed.href;
  } catch (e2) {
    return void 0;
  }
}
__name(getFullURL, "getFullURL");
function registerBackgroundTabDetection() {
  if (WINDOW$5 && WINDOW$5.document) {
    WINDOW$5.document.addEventListener("visibilitychange", () => {
      const activeSpan = getActiveSpan();
      if (!activeSpan) {
        return;
      }
      const rootSpan = getRootSpan(activeSpan);
      if (WINDOW$5.document.hidden && rootSpan) {
        const cancelledStatus = "cancelled";
        const { op, status } = spanToJSON(rootSpan);
        if (DEBUG_BUILD$4) {
          logger$2.log(`[Tracing] Transaction: ${cancelledStatus} -> since tab moved to the background, op: ${op}`);
        }
        if (!status) {
          rootSpan.setStatus({ code: SPAN_STATUS_ERROR, message: cancelledStatus });
        }
        rootSpan.setAttribute("sentry.cancellation_reason", "document.hidden");
        rootSpan.end();
      }
    });
  } else {
    DEBUG_BUILD$4 && logger$2.warn("[Tracing] Could not set up background tab detection due to lack of global document");
  }
}
__name(registerBackgroundTabDetection, "registerBackgroundTabDetection");
const BROWSER_TRACING_INTEGRATION_ID = "BrowserTracing";
const DEFAULT_BROWSER_TRACING_OPTIONS = {
  ...TRACING_DEFAULTS,
  instrumentNavigation: true,
  instrumentPageLoad: true,
  markBackgroundSpan: true,
  enableLongTask: true,
  enableLongAnimationFrame: true,
  enableInp: true,
  _experiments: {},
  ...defaultRequestInstrumentationOptions
};
const browserTracingIntegration$1 = /* @__PURE__ */ __name((_options = {}) => {
  registerSpanErrorInstrumentation();
  const {
    enableInp,
    enableLongTask,
    enableLongAnimationFrame,
    _experiments: { enableInteractions, enableStandaloneClsSpans },
    beforeStartSpan,
    idleTimeout,
    finalTimeout,
    childSpanTimeout,
    markBackgroundSpan,
    traceFetch,
    traceXHR,
    trackFetchStreamPerformance,
    shouldCreateSpanForRequest,
    enableHTTPTimings,
    instrumentPageLoad,
    instrumentNavigation
  } = {
    ...DEFAULT_BROWSER_TRACING_OPTIONS,
    ..._options
  };
  const _collectWebVitals = startTrackingWebVitals({ recordClsStandaloneSpans: enableStandaloneClsSpans || false });
  if (enableInp) {
    startTrackingINP();
  }
  if (enableLongAnimationFrame && GLOBAL_OBJ.PerformanceObserver && PerformanceObserver.supportedEntryTypes && PerformanceObserver.supportedEntryTypes.includes("long-animation-frame")) {
    startTrackingLongAnimationFrames();
  } else if (enableLongTask) {
    startTrackingLongTasks();
  }
  if (enableInteractions) {
    startTrackingInteractions();
  }
  const latestRoute = {
    name: void 0,
    source: void 0
  };
  function _createRouteSpan(client, startSpanOptions) {
    const isPageloadTransaction = startSpanOptions.op === "pageload";
    const finalStartSpanOptions = beforeStartSpan ? beforeStartSpan(startSpanOptions) : startSpanOptions;
    const attributes = finalStartSpanOptions.attributes || {};
    if (startSpanOptions.name !== finalStartSpanOptions.name) {
      attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE] = "custom";
      finalStartSpanOptions.attributes = attributes;
    }
    latestRoute.name = finalStartSpanOptions.name;
    latestRoute.source = attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE];
    const idleSpan = startIdleSpan(finalStartSpanOptions, {
      idleTimeout,
      finalTimeout,
      childSpanTimeout,
      // should wait for finish signal if it's a pageload transaction
      disableAutoFinish: isPageloadTransaction,
      beforeSpanEnd: /* @__PURE__ */ __name((span) => {
        _collectWebVitals();
        addPerformanceEntries(span, { recordClsOnPageloadSpan: !enableStandaloneClsSpans });
      }, "beforeSpanEnd")
    });
    function emitFinish() {
      if (["interactive", "complete"].includes(WINDOW$5.document.readyState)) {
        client.emit("idleSpanEnableAutoFinish", idleSpan);
      }
    }
    __name(emitFinish, "emitFinish");
    if (isPageloadTransaction && WINDOW$5.document) {
      WINDOW$5.document.addEventListener("readystatechange", () => {
        emitFinish();
      });
      emitFinish();
    }
    return idleSpan;
  }
  __name(_createRouteSpan, "_createRouteSpan");
  return {
    name: BROWSER_TRACING_INTEGRATION_ID,
    afterAllSetup(client) {
      let activeSpan;
      let startingUrl = WINDOW$5.location && WINDOW$5.location.href;
      function maybeEndActiveSpan() {
        if (activeSpan && !spanToJSON(activeSpan).timestamp) {
          DEBUG_BUILD$4 && logger$2.log(`[Tracing] Finishing current active span with op: ${spanToJSON(activeSpan).op}`);
          activeSpan.end();
        }
      }
      __name(maybeEndActiveSpan, "maybeEndActiveSpan");
      client.on("startNavigationSpan", (startSpanOptions) => {
        if (getClient() !== client) {
          return;
        }
        maybeEndActiveSpan();
        activeSpan = _createRouteSpan(client, {
          op: "navigation",
          ...startSpanOptions
        });
      });
      client.on("startPageLoadSpan", (startSpanOptions, traceOptions = {}) => {
        if (getClient() !== client) {
          return;
        }
        maybeEndActiveSpan();
        const sentryTrace = traceOptions.sentryTrace || getMetaContent("sentry-trace");
        const baggage = traceOptions.baggage || getMetaContent("baggage");
        const propagationContext = propagationContextFromHeaders(sentryTrace, baggage);
        getCurrentScope$1().setPropagationContext(propagationContext);
        activeSpan = _createRouteSpan(client, {
          op: "pageload",
          ...startSpanOptions
        });
      });
      client.on("spanEnd", (span) => {
        const op = spanToJSON(span).op;
        if (span !== getRootSpan(span) || op !== "navigation" && op !== "pageload") {
          return;
        }
        const scope = getCurrentScope$1();
        const oldPropagationContext = scope.getPropagationContext();
        scope.setPropagationContext({
          ...oldPropagationContext,
          sampled: oldPropagationContext.sampled !== void 0 ? oldPropagationContext.sampled : spanIsSampled(span),
          dsc: oldPropagationContext.dsc || getDynamicSamplingContextFromSpan(span)
        });
      });
      if (WINDOW$5.location) {
        if (instrumentPageLoad) {
          startBrowserTracingPageLoadSpan(client, {
            name: WINDOW$5.location.pathname,
            // pageload should always start at timeOrigin (and needs to be in s, not ms)
            startTime: browserPerformanceTimeOrigin ? browserPerformanceTimeOrigin / 1e3 : void 0,
            attributes: {
              [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "url",
              [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.pageload.browser"
            }
          });
        }
        if (instrumentNavigation) {
          addHistoryInstrumentationHandler(({ to, from: from2 }) => {
            if (from2 === void 0 && startingUrl && startingUrl.indexOf(to) !== -1) {
              startingUrl = void 0;
              return;
            }
            if (from2 !== to) {
              startingUrl = void 0;
              startBrowserTracingNavigationSpan(client, {
                name: WINDOW$5.location.pathname,
                attributes: {
                  [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: "url",
                  [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.navigation.browser"
                }
              });
            }
          });
        }
      }
      if (markBackgroundSpan) {
        registerBackgroundTabDetection();
      }
      if (enableInteractions) {
        registerInteractionListener(idleTimeout, finalTimeout, childSpanTimeout, latestRoute);
      }
      if (enableInp) {
        registerInpInteractionListener();
      }
      instrumentOutgoingRequests(client, {
        traceFetch,
        traceXHR,
        trackFetchStreamPerformance,
        tracePropagationTargets: client.getOptions().tracePropagationTargets,
        shouldCreateSpanForRequest,
        enableHTTPTimings
      });
    }
  };
}, "browserTracingIntegration$1");
function startBrowserTracingPageLoadSpan(client, spanOptions, traceOptions) {
  client.emit("startPageLoadSpan", spanOptions, traceOptions);
  getCurrentScope$1().setTransactionName(spanOptions.name);
  const span = getActiveSpan();
  const op = span && spanToJSON(span).op;
  return op === "pageload" ? span : void 0;
}
__name(startBrowserTracingPageLoadSpan, "startBrowserTracingPageLoadSpan");
function startBrowserTracingNavigationSpan(client, spanOptions) {
  getIsolationScope().setPropagationContext({ traceId: generateTraceId() });
  getCurrentScope$1().setPropagationContext({ traceId: generateTraceId() });
  client.emit("startNavigationSpan", spanOptions);
  getCurrentScope$1().setTransactionName(spanOptions.name);
  const span = getActiveSpan();
  const op = span && spanToJSON(span).op;
  return op === "navigation" ? span : void 0;
}
__name(startBrowserTracingNavigationSpan, "startBrowserTracingNavigationSpan");
function getMetaContent(metaName) {
  const metaTag = getDomElement(`meta[name=${metaName}]`);
  return metaTag ? metaTag.getAttribute("content") : void 0;
}
__name(getMetaContent, "getMetaContent");
function registerInteractionListener(idleTimeout, finalTimeout, childSpanTimeout, latestRoute) {
  let inflightInteractionSpan;
  const registerInteractionTransaction = /* @__PURE__ */ __name(() => {
    const op = "ui.action.click";
    const activeSpan = getActiveSpan();
    const rootSpan = activeSpan && getRootSpan(activeSpan);
    if (rootSpan) {
      const currentRootSpanOp = spanToJSON(rootSpan).op;
      if (["navigation", "pageload"].includes(currentRootSpanOp)) {
        DEBUG_BUILD$4 && logger$2.warn(`[Tracing] Did not create ${op} span because a pageload or navigation span is in progress.`);
        return void 0;
      }
    }
    if (inflightInteractionSpan) {
      inflightInteractionSpan.setAttribute(SEMANTIC_ATTRIBUTE_SENTRY_IDLE_SPAN_FINISH_REASON, "interactionInterrupted");
      inflightInteractionSpan.end();
      inflightInteractionSpan = void 0;
    }
    if (!latestRoute.name) {
      DEBUG_BUILD$4 && logger$2.warn(`[Tracing] Did not create ${op} transaction because _latestRouteName is missing.`);
      return void 0;
    }
    inflightInteractionSpan = startIdleSpan(
      {
        name: latestRoute.name,
        op,
        attributes: {
          [SEMANTIC_ATTRIBUTE_SENTRY_SOURCE]: latestRoute.source || "url"
        }
      },
      {
        idleTimeout,
        finalTimeout,
        childSpanTimeout
      }
    );
  }, "registerInteractionTransaction");
  if (WINDOW$5.document) {
    addEventListener("click", registerInteractionTransaction, { once: false, capture: true });
  }
}
__name(registerInteractionListener, "registerInteractionListener");
function promisifyRequest(request) {
  return new Promise((resolve2, reject3) => {
    request.oncomplete = request.onsuccess = () => resolve2(request.result);
    request.onabort = request.onerror = () => reject3(request.error);
  });
}
__name(promisifyRequest, "promisifyRequest");
function createStore(dbName, storeName) {
  const request = indexedDB.open(dbName);
  request.onupgradeneeded = () => request.result.createObjectStore(storeName);
  const dbp = promisifyRequest(request);
  return (callback) => dbp.then((db) => callback(db.transaction(storeName, "readwrite").objectStore(storeName)));
}
__name(createStore, "createStore");
function keys$7(store) {
  return promisifyRequest(store.getAllKeys());
}
__name(keys$7, "keys$7");
function push(store, value3, maxQueueSize) {
  return store((store2) => {
    return keys$7(store2).then((keys2) => {
      if (keys2.length >= maxQueueSize) {
        return;
      }
      store2.put(value3, Math.max(...keys2, 0) + 1);
      return promisifyRequest(store2.transaction);
    });
  });
}
__name(push, "push");
function unshift(store, value3, maxQueueSize) {
  return store((store2) => {
    return keys$7(store2).then((keys2) => {
      if (keys2.length >= maxQueueSize) {
        return;
      }
      store2.put(value3, Math.min(...keys2, 0) - 1);
      return promisifyRequest(store2.transaction);
    });
  });
}
__name(unshift, "unshift");
function shift$1(store) {
  return store((store2) => {
    return keys$7(store2).then((keys2) => {
      const firstKey = keys2[0];
      if (firstKey == null) {
        return void 0;
      }
      return promisifyRequest(store2.get(firstKey)).then((value3) => {
        store2.delete(firstKey);
        return promisifyRequest(store2.transaction).then(() => value3);
      });
    });
  });
}
__name(shift$1, "shift$1");
function createIndexedDbStore(options5) {
  let store;
  function getStore() {
    if (store == void 0) {
      store = createStore(options5.dbName || "sentry-offline", options5.storeName || "queue");
    }
    return store;
  }
  __name(getStore, "getStore");
  return {
    push: /* @__PURE__ */ __name(async (env) => {
      try {
        const serialized = await serializeEnvelope(env);
        await push(getStore(), serialized, options5.maxQueueSize || 30);
      } catch (_2) {
      }
    }, "push"),
    unshift: /* @__PURE__ */ __name(async (env) => {
      try {
        const serialized = await serializeEnvelope(env);
        await unshift(getStore(), serialized, options5.maxQueueSize || 30);
      } catch (_2) {
      }
    }, "unshift"),
    shift: /* @__PURE__ */ __name(async () => {
      try {
        const deserialized = await shift$1(getStore());
        if (deserialized) {
          return parseEnvelope(deserialized);
        }
      } catch (_2) {
      }
      return void 0;
    }, "shift")
  };
}
__name(createIndexedDbStore, "createIndexedDbStore");
function makeIndexedDbOfflineTransport(createTransport2) {
  return (options5) => createTransport2({ ...options5, createStore: createIndexedDbStore });
}
__name(makeIndexedDbOfflineTransport, "makeIndexedDbOfflineTransport");
function makeBrowserOfflineTransport(createTransport2 = makeFetchTransport) {
  return makeIndexedDbOfflineTransport(makeOfflineTransport(createTransport2));
}
__name(makeBrowserOfflineTransport, "makeBrowserOfflineTransport");
const MS_TO_NS = 1e6;
const THREAD_ID_STRING = String(0);
const THREAD_NAME = "main";
let OS_PLATFORM = "";
let OS_PLATFORM_VERSION = "";
let OS_ARCH = "";
let OS_BROWSER = WINDOW$5.navigator && WINDOW$5.navigator.userAgent || "";
let OS_MODEL = "";
const OS_LOCALE = WINDOW$5.navigator && WINDOW$5.navigator.language || WINDOW$5.navigator && WINDOW$5.navigator.languages && WINDOW$5.navigator.languages[0] || "";
function isUserAgentData(data30) {
  return typeof data30 === "object" && data30 !== null && "getHighEntropyValues" in data30;
}
__name(isUserAgentData, "isUserAgentData");
const userAgentData = WINDOW$5.navigator && WINDOW$5.navigator.userAgentData;
if (isUserAgentData(userAgentData)) {
  userAgentData.getHighEntropyValues(["architecture", "model", "platform", "platformVersion", "fullVersionList"]).then((ua) => {
    OS_PLATFORM = ua.platform || "";
    OS_ARCH = ua.architecture || "";
    OS_MODEL = ua.model || "";
    OS_PLATFORM_VERSION = ua.platformVersion || "";
    if (ua.fullVersionList && ua.fullVersionList.length > 0) {
      const firstUa = ua.fullVersionList[ua.fullVersionList.length - 1];
      OS_BROWSER = `${firstUa.brand} ${firstUa.version}`;
    }
  }).catch((e2) => void 0);
}
function isProcessedJSSelfProfile(profile) {
  return !("thread_metadata" in profile);
}
__name(isProcessedJSSelfProfile, "isProcessedJSSelfProfile");
function enrichWithThreadInformation(profile) {
  if (!isProcessedJSSelfProfile(profile)) {
    return profile;
  }
  return convertJSSelfProfileToSampledFormat(profile);
}
__name(enrichWithThreadInformation, "enrichWithThreadInformation");
function getTraceId(event) {
  const traceId = event && event.contexts && event.contexts["trace"] && event.contexts["trace"]["trace_id"];
  if (typeof traceId === "string" && traceId.length !== 32) {
    if (DEBUG_BUILD$4) {
      logger$2.log(`[Profiling] Invalid traceId: ${traceId} on profiled event`);
    }
  }
  if (typeof traceId !== "string") {
    return "";
  }
  return traceId;
}
__name(getTraceId, "getTraceId");
function createProfilePayload(profile_id, start_timestamp, processed_profile, event) {
  if (event.type !== "transaction") {
    throw new TypeError("Profiling events may only be attached to transactions, this should never occur.");
  }
  if (processed_profile === void 0 || processed_profile === null) {
    throw new TypeError(
      `Cannot construct profiling event envelope without a valid profile. Got ${processed_profile} instead.`
    );
  }
  const traceId = getTraceId(event);
  const enrichedThreadProfile = enrichWithThreadInformation(processed_profile);
  const transactionStartMs = start_timestamp ? start_timestamp : typeof event.start_timestamp === "number" ? event.start_timestamp * 1e3 : timestampInSeconds() * 1e3;
  const transactionEndMs = typeof event.timestamp === "number" ? event.timestamp * 1e3 : timestampInSeconds() * 1e3;
  const profile = {
    event_id: profile_id,
    timestamp: new Date(transactionStartMs).toISOString(),
    platform: "javascript",
    version: "1",
    release: event.release || "",
    environment: event.environment || DEFAULT_ENVIRONMENT,
    runtime: {
      name: "javascript",
      version: WINDOW$5.navigator.userAgent
    },
    os: {
      name: OS_PLATFORM,
      version: OS_PLATFORM_VERSION,
      build_number: OS_BROWSER
    },
    device: {
      locale: OS_LOCALE,
      model: OS_MODEL,
      manufacturer: OS_BROWSER,
      architecture: OS_ARCH,
      is_emulator: false
    },
    debug_meta: {
      images: applyDebugMetadata(processed_profile.resources)
    },
    profile: enrichedThreadProfile,
    transactions: [
      {
        name: event.transaction || "",
        id: event.event_id || uuid4(),
        trace_id: traceId,
        active_thread_id: THREAD_ID_STRING,
        relative_start_ns: "0",
        relative_end_ns: ((transactionEndMs - transactionStartMs) * 1e6).toFixed(0)
      }
    ]
  };
  return profile;
}
__name(createProfilePayload, "createProfilePayload");
function isAutomatedPageLoadSpan(span) {
  return spanToJSON(span).op === "pageload";
}
__name(isAutomatedPageLoadSpan, "isAutomatedPageLoadSpan");
function convertJSSelfProfileToSampledFormat(input) {
  let EMPTY_STACK_ID = void 0;
  let STACK_ID = 0;
  const profile = {
    samples: [],
    stacks: [],
    frames: [],
    thread_metadata: {
      [THREAD_ID_STRING]: { name: THREAD_NAME }
    }
  };
  const firstSample = input.samples[0];
  if (!firstSample) {
    return profile;
  }
  const start2 = firstSample.timestamp;
  const origin2 = typeof performance.timeOrigin === "number" ? performance.timeOrigin : browserPerformanceTimeOrigin || 0;
  const adjustForOriginChange = origin2 - (browserPerformanceTimeOrigin || origin2);
  input.samples.forEach((jsSample, i2) => {
    if (jsSample.stackId === void 0) {
      if (EMPTY_STACK_ID === void 0) {
        EMPTY_STACK_ID = STACK_ID;
        profile.stacks[EMPTY_STACK_ID] = [];
        STACK_ID++;
      }
      profile["samples"][i2] = {
        // convert ms timestamp to ns
        elapsed_since_start_ns: ((jsSample.timestamp + adjustForOriginChange - start2) * MS_TO_NS).toFixed(0),
        stack_id: EMPTY_STACK_ID,
        thread_id: THREAD_ID_STRING
      };
      return;
    }
    let stackTop = input.stacks[jsSample.stackId];
    const stack2 = [];
    while (stackTop) {
      stack2.push(stackTop.frameId);
      const frame = input.frames[stackTop.frameId];
      if (frame && profile.frames[stackTop.frameId] === void 0) {
        profile.frames[stackTop.frameId] = {
          function: frame.name,
          abs_path: typeof frame.resourceId === "number" ? input.resources[frame.resourceId] : void 0,
          lineno: frame.line,
          colno: frame.column
        };
      }
      stackTop = stackTop.parentId === void 0 ? void 0 : input.stacks[stackTop.parentId];
    }
    const sample = {
      // convert ms timestamp to ns
      elapsed_since_start_ns: ((jsSample.timestamp + adjustForOriginChange - start2) * MS_TO_NS).toFixed(0),
      stack_id: STACK_ID,
      thread_id: THREAD_ID_STRING
    };
    profile["stacks"][STACK_ID] = stack2;
    profile["samples"][i2] = sample;
    STACK_ID++;
  });
  return profile;
}
__name(convertJSSelfProfileToSampledFormat, "convertJSSelfProfileToSampledFormat");
function addProfilesToEnvelope(envelope, profiles) {
  if (!profiles.length) {
    return envelope;
  }
  for (const profile of profiles) {
    envelope[1].push([{ type: "profile" }, profile]);
  }
  return envelope;
}
__name(addProfilesToEnvelope, "addProfilesToEnvelope");
function findProfiledTransactionsFromEnvelope(envelope) {
  const events2 = [];
  forEachEnvelopeItem(envelope, (item3, type) => {
    if (type !== "transaction") {
      return;
    }
    for (let j2 = 1; j2 < item3.length; j2++) {
      const event = item3[j2];
      if (event && event.contexts && event.contexts["profile"] && event.contexts["profile"]["profile_id"]) {
        events2.push(item3[j2]);
      }
    }
  });
  return events2;
}
__name(findProfiledTransactionsFromEnvelope, "findProfiledTransactionsFromEnvelope");
function applyDebugMetadata(resource_paths) {
  const client = getClient();
  const options5 = client && client.getOptions();
  const stackParser = options5 && options5.stackParser;
  if (!stackParser) {
    return [];
  }
  return getDebugImagesForResources(stackParser, resource_paths);
}
__name(applyDebugMetadata, "applyDebugMetadata");
function isValidSampleRate(rate) {
  if (typeof rate !== "number" && typeof rate !== "boolean" || typeof rate === "number" && isNaN(rate)) {
    DEBUG_BUILD$4 && logger$2.warn(
      `[Profiling] Invalid sample rate. Sample rate must be a boolean or a number between 0 and 1. Got ${JSON.stringify(
        rate
      )} of type ${JSON.stringify(typeof rate)}.`
    );
    return false;
  }
  if (rate === true || rate === false) {
    return true;
  }
  if (rate < 0 || rate > 1) {
    DEBUG_BUILD$4 && logger$2.warn(`[Profiling] Invalid sample rate. Sample rate must be between 0 and 1. Got ${rate}.`);
    return false;
  }
  return true;
}
__name(isValidSampleRate, "isValidSampleRate");
function isValidProfile(profile) {
  if (profile.samples.length < 2) {
    if (DEBUG_BUILD$4) {
      logger$2.log("[Profiling] Discarding profile because it contains less than 2 samples");
    }
    return false;
  }
  if (!profile.frames.length) {
    if (DEBUG_BUILD$4) {
      logger$2.log("[Profiling] Discarding profile because it contains no frames");
    }
    return false;
  }
  return true;
}
__name(isValidProfile, "isValidProfile");
let PROFILING_CONSTRUCTOR_FAILED = false;
const MAX_PROFILE_DURATION_MS = 3e4;
function isJSProfilerSupported(maybeProfiler) {
  return typeof maybeProfiler === "function";
}
__name(isJSProfilerSupported, "isJSProfilerSupported");
function startJSSelfProfile() {
  const JSProfilerConstructor = WINDOW$5.Profiler;
  if (!isJSProfilerSupported(JSProfilerConstructor)) {
    if (DEBUG_BUILD$4) {
      logger$2.log(
        "[Profiling] Profiling is not supported by this browser, Profiler interface missing on window object."
      );
    }
    return;
  }
  const samplingIntervalMS = 10;
  const maxSamples = Math.floor(MAX_PROFILE_DURATION_MS / samplingIntervalMS);
  try {
    return new JSProfilerConstructor({ sampleInterval: samplingIntervalMS, maxBufferSize: maxSamples });
  } catch (e2) {
    if (DEBUG_BUILD$4) {
      logger$2.log(
        "[Profiling] Failed to initialize the Profiling constructor, this is likely due to a missing 'Document-Policy': 'js-profiling' header."
      );
      logger$2.log("[Profiling] Disabling profiling for current user session.");
    }
    PROFILING_CONSTRUCTOR_FAILED = true;
  }
  return;
}
__name(startJSSelfProfile, "startJSSelfProfile");
function shouldProfileSpan(span) {
  if (PROFILING_CONSTRUCTOR_FAILED) {
    if (DEBUG_BUILD$4) {
      logger$2.log("[Profiling] Profiling has been disabled for the duration of the current user session.");
    }
    return false;
  }
  if (!span.isRecording()) {
    if (DEBUG_BUILD$4) {
      logger$2.log("[Profiling] Discarding profile because transaction was not sampled.");
    }
    return false;
  }
  const client = getClient();
  const options5 = client && client.getOptions();
  if (!options5) {
    DEBUG_BUILD$4 && logger$2.log("[Profiling] Profiling disabled, no options found.");
    return false;
  }
  const profilesSampleRate = options5.profilesSampleRate;
  if (!isValidSampleRate(profilesSampleRate)) {
    DEBUG_BUILD$4 && logger$2.warn("[Profiling] Discarding profile because of invalid sample rate.");
    return false;
  }
  if (!profilesSampleRate) {
    DEBUG_BUILD$4 && logger$2.log(
      "[Profiling] Discarding profile because a negative sampling decision was inherited or profileSampleRate is set to 0"
    );
    return false;
  }
  const sampled = profilesSampleRate === true ? true : Math.random() < profilesSampleRate;
  if (!sampled) {
    DEBUG_BUILD$4 && logger$2.log(
      `[Profiling] Discarding profile because it's not included in the random sample (sampling rate = ${Number(
        profilesSampleRate
      )})`
    );
    return false;
  }
  return true;
}
__name(shouldProfileSpan, "shouldProfileSpan");
function createProfilingEvent(profile_id, start_timestamp, profile, event) {
  if (!isValidProfile(profile)) {
    return null;
  }
  return createProfilePayload(profile_id, start_timestamp, profile, event);
}
__name(createProfilingEvent, "createProfilingEvent");
const PROFILE_MAP = /* @__PURE__ */ new Map();
function getActiveProfilesCount() {
  return PROFILE_MAP.size;
}
__name(getActiveProfilesCount, "getActiveProfilesCount");
function takeProfileFromGlobalCache(profile_id) {
  const profile = PROFILE_MAP.get(profile_id);
  if (profile) {
    PROFILE_MAP.delete(profile_id);
  }
  return profile;
}
__name(takeProfileFromGlobalCache, "takeProfileFromGlobalCache");
function addProfileToGlobalCache(profile_id, profile) {
  PROFILE_MAP.set(profile_id, profile);
  if (PROFILE_MAP.size > 30) {
    const last = PROFILE_MAP.keys().next().value;
    PROFILE_MAP.delete(last);
  }
}
__name(addProfileToGlobalCache, "addProfileToGlobalCache");
function startProfileForSpan(span) {
  let startTimestamp;
  if (isAutomatedPageLoadSpan(span)) {
    startTimestamp = timestampInSeconds() * 1e3;
  }
  const profiler2 = startJSSelfProfile();
  if (!profiler2) {
    return;
  }
  if (DEBUG_BUILD$4) {
    logger$2.log(`[Profiling] started profiling span: ${spanToJSON(span).description}`);
  }
  const profileId = uuid4();
  getCurrentScope$1().setContext("profile", {
    profile_id: profileId,
    start_timestamp: startTimestamp
  });
  async function onProfileHandler() {
    if (!span) {
      return;
    }
    if (!profiler2) {
      return;
    }
    return profiler2.stop().then((profile) => {
      if (maxDurationTimeoutID) {
        WINDOW$5.clearTimeout(maxDurationTimeoutID);
        maxDurationTimeoutID = void 0;
      }
      if (DEBUG_BUILD$4) {
        logger$2.log(`[Profiling] stopped profiling of span: ${spanToJSON(span).description}`);
      }
      if (!profile) {
        if (DEBUG_BUILD$4) {
          logger$2.log(
            `[Profiling] profiler returned null profile for: ${spanToJSON(span).description}`,
            "this may indicate an overlapping span or a call to stopProfiling with a profile title that was never started"
          );
        }
        return;
      }
      addProfileToGlobalCache(profileId, profile);
    }).catch((error2) => {
      if (DEBUG_BUILD$4) {
        logger$2.log("[Profiling] error while stopping profiler:", error2);
      }
    });
  }
  __name(onProfileHandler, "onProfileHandler");
  let maxDurationTimeoutID = WINDOW$5.setTimeout(() => {
    if (DEBUG_BUILD$4) {
      logger$2.log("[Profiling] max profile duration elapsed, stopping profiling for:", spanToJSON(span).description);
    }
    onProfileHandler();
  }, MAX_PROFILE_DURATION_MS);
  const originalEnd = span.end.bind(span);
  function profilingWrappedSpanEnd() {
    if (!span) {
      return originalEnd();
    }
    void onProfileHandler().then(
      () => {
        originalEnd();
      },
      () => {
        originalEnd();
      }
    );
    return span;
  }
  __name(profilingWrappedSpanEnd, "profilingWrappedSpanEnd");
  span.end = profilingWrappedSpanEnd;
}
__name(startProfileForSpan, "startProfileForSpan");
const INTEGRATION_NAME$2 = "BrowserProfiling";
const _browserProfilingIntegration = /* @__PURE__ */ __name(() => {
  return {
    name: INTEGRATION_NAME$2,
    setup(client) {
      const activeSpan = getActiveSpan();
      const rootSpan = activeSpan && getRootSpan(activeSpan);
      if (rootSpan && isAutomatedPageLoadSpan(rootSpan)) {
        if (shouldProfileSpan(rootSpan)) {
          startProfileForSpan(rootSpan);
        }
      }
      client.on("spanStart", (span) => {
        if (span === getRootSpan(span) && shouldProfileSpan(span)) {
          startProfileForSpan(span);
        }
      });
      client.on("beforeEnvelope", (envelope) => {
        if (!getActiveProfilesCount()) {
          return;
        }
        const profiledTransactionEvents = findProfiledTransactionsFromEnvelope(envelope);
        if (!profiledTransactionEvents.length) {
          return;
        }
        const profilesToAddToEnvelope = [];
        for (const profiledTransaction of profiledTransactionEvents) {
          const context = profiledTransaction && profiledTransaction.contexts;
          const profile_id = context && context["profile"] && context["profile"]["profile_id"];
          const start_timestamp = context && context["profile"] && context["profile"]["start_timestamp"];
          if (typeof profile_id !== "string") {
            DEBUG_BUILD$4 && logger$2.log("[Profiling] cannot find profile for a span without a profile context");
            continue;
          }
          if (!profile_id) {
            DEBUG_BUILD$4 && logger$2.log("[Profiling] cannot find profile for a span without a profile context");
            continue;
          }
          if (context && context["profile"]) {
            delete context.profile;
          }
          const profile = takeProfileFromGlobalCache(profile_id);
          if (!profile) {
            DEBUG_BUILD$4 && logger$2.log(`[Profiling] Could not retrieve profile for span: ${profile_id}`);
            continue;
          }
          const profileEvent = createProfilingEvent(
            profile_id,
            start_timestamp,
            profile,
            profiledTransaction
          );
          if (profileEvent) {
            profilesToAddToEnvelope.push(profileEvent);
          }
        }
        addProfilesToEnvelope(envelope, profilesToAddToEnvelope);
      });
    }
  };
}, "_browserProfilingIntegration");
const browserProfilingIntegration = defineIntegration(_browserProfilingIntegration);
const INTEGRATION_NAME$1 = "SpotlightBrowser";
const _spotlightIntegration = /* @__PURE__ */ __name((options5 = {}) => {
  const sidecarUrl = options5.sidecarUrl || "http://localhost:8969/stream";
  return {
    name: INTEGRATION_NAME$1,
    setup: /* @__PURE__ */ __name(() => {
      DEBUG_BUILD$4 && logger$2.log("Using Sidecar URL", sidecarUrl);
    }, "setup"),
    // We don't want to send interaction transactions/root spans created from
    // clicks within Spotlight to Sentry. Neither do we want them to be sent to
    // spotlight.
    processEvent: /* @__PURE__ */ __name((event) => isSpotlightInteraction(event) ? null : event, "processEvent"),
    afterAllSetup: /* @__PURE__ */ __name((client) => {
      setupSidecarForwarding(client, sidecarUrl);
    }, "afterAllSetup")
  };
}, "_spotlightIntegration");
function setupSidecarForwarding(client, sidecarUrl) {
  const makeFetch = getNativeImplementation("fetch");
  let failCount = 0;
  client.on("beforeEnvelope", (envelope) => {
    if (failCount > 3) {
      logger$2.warn("[Spotlight] Disabled Sentry -> Spotlight integration due to too many failed requests:", failCount);
      return;
    }
    makeFetch(sidecarUrl, {
      method: "POST",
      body: serializeEnvelope(envelope),
      headers: {
        "Content-Type": "application/x-sentry-envelope"
      },
      mode: "cors"
    }).then(
      (res) => {
        if (res.status >= 200 && res.status < 400) {
          failCount = 0;
        }
      },
      (err) => {
        failCount++;
        logger$2.error(
          "Sentry SDK can't connect to Sidecar is it running? See: https://spotlightjs.com/sidecar/npx/",
          err
        );
      }
    );
  });
}
__name(setupSidecarForwarding, "setupSidecarForwarding");
const spotlightBrowserIntegration = defineIntegration(_spotlightIntegration);
function isSpotlightInteraction(event) {
  return Boolean(
    event.type === "transaction" && event.spans && event.contexts && event.contexts.trace && event.contexts.trace.op === "ui.action.click" && event.spans.some(({ description }) => description && description.includes("#sentry-spotlight"))
  );
}
__name(isSpotlightInteraction, "isSpotlightInteraction");
const FLAG_BUFFER_SIZE = 100;
function copyFlagsFromScopeToEvent(event) {
  const scope = getCurrentScope$1();
  const flagContext = scope.getScopeData().contexts.flags;
  const flagBuffer = flagContext ? flagContext.values : [];
  if (!flagBuffer.length) {
    return event;
  }
  if (event.contexts === void 0) {
    event.contexts = {};
  }
  event.contexts.flags = { values: [...flagBuffer] };
  return event;
}
__name(copyFlagsFromScopeToEvent, "copyFlagsFromScopeToEvent");
function insertFlagToScope(name2, value3, maxSize = FLAG_BUFFER_SIZE) {
  const scopeContexts = getCurrentScope$1().getScopeData().contexts;
  if (!scopeContexts.flags) {
    scopeContexts.flags = { values: [] };
  }
  const flags = scopeContexts.flags.values;
  insertToFlagBuffer(flags, name2, value3, maxSize);
}
__name(insertFlagToScope, "insertFlagToScope");
function insertToFlagBuffer(flags, name2, value3, maxSize) {
  if (typeof value3 !== "boolean") {
    return;
  }
  if (flags.length > maxSize) {
    DEBUG_BUILD$4 && logger$2.error(`[Feature Flags] insertToFlagBuffer called on a buffer larger than maxSize=${maxSize}`);
    return;
  }
  const index2 = flags.findIndex((f2) => f2.flag === name2);
  if (index2 !== -1) {
    flags.splice(index2, 1);
  }
  if (flags.length === maxSize) {
    flags.shift();
  }
  flags.push({
    flag: name2,
    result: value3
  });
}
__name(insertToFlagBuffer, "insertToFlagBuffer");
const featureFlagsIntegration = defineIntegration(() => {
  return {
    name: "FeatureFlags",
    processEvent(event, _hint, _client) {
      return copyFlagsFromScopeToEvent(event);
    },
    addFeatureFlag(name2, value3) {
      insertFlagToScope(name2, value3);
    }
  };
});
const launchDarklyIntegration = defineIntegration(() => {
  return {
    name: "LaunchDarkly",
    processEvent(event, _hint, _client) {
      return copyFlagsFromScopeToEvent(event);
    }
  };
});
function buildLaunchDarklyFlagUsedHandler() {
  return {
    name: "sentry-flag-auditor",
    type: "flag-used",
    synchronous: true,
    /**
     * Handle a flag evaluation by storing its name and value on the current scope.
     */
    method: /* @__PURE__ */ __name((flagKey, flagDetail, _context) => {
      insertFlagToScope(flagKey, flagDetail.value);
    }, "method")
  };
}
__name(buildLaunchDarklyFlagUsedHandler, "buildLaunchDarklyFlagUsedHandler");
const openFeatureIntegration = defineIntegration(() => {
  return {
    name: "OpenFeature",
    processEvent(event, _hint, _client) {
      return copyFlagsFromScopeToEvent(event);
    }
  };
});
class OpenFeatureIntegrationHook {
  static {
    __name(this, "OpenFeatureIntegrationHook");
  }
  /**
   * Successful evaluation result.
   */
  after(_hookContext, evaluationDetails) {
    insertFlagToScope(evaluationDetails.flagKey, evaluationDetails.value);
  }
  /**
   * On error evaluation result.
   */
  error(hookContext, _error, _hookHints) {
    insertFlagToScope(hookContext.flagKey, hookContext.defaultValue);
  }
}
const DEFAULT_HOOKS = ["activate", "mount", "update"];
const DEBUG_BUILD = typeof __SENTRY_DEBUG__ === "undefined" || __SENTRY_DEBUG__;
const classifyRE$1 = /(?:^|[-_])(\w)/g;
const classify$1 = /* @__PURE__ */ __name((str) => str.replace(classifyRE$1, (c2) => c2.toUpperCase()).replace(/[-_]/g, ""), "classify$1");
const ROOT_COMPONENT_NAME = "<Root>";
const ANONYMOUS_COMPONENT_NAME = "<Anonymous>";
const repeat = /* @__PURE__ */ __name((str, n2) => {
  return str.repeat(n2);
}, "repeat");
const formatComponentName$1 = /* @__PURE__ */ __name((vm, includeFile) => {
  if (!vm) {
    return ANONYMOUS_COMPONENT_NAME;
  }
  if (vm.$root === vm) {
    return ROOT_COMPONENT_NAME;
  }
  if (!vm.$options) {
    return ANONYMOUS_COMPONENT_NAME;
  }
  const options5 = vm.$options;
  let name2 = options5.name || options5._componentTag || options5.__name;
  const file = options5.__file;
  if (!name2 && file) {
    const match2 = file.match(/([^/\\]+)\.vue$/);
    if (match2) {
      name2 = match2[1];
    }
  }
  return (name2 ? `<${classify$1(name2)}>` : ANONYMOUS_COMPONENT_NAME) + (file && includeFile !== false ? ` at ${file}` : "");
}, "formatComponentName$1");
const generateComponentTrace = /* @__PURE__ */ __name((vm) => {
  if (vm && (vm._isVue || vm.__isVue) && vm.$parent) {
    const tree = [];
    let currentRecursiveSequence = 0;
    while (vm) {
      if (tree.length > 0) {
        const last = tree[tree.length - 1];
        if (last.constructor === vm.constructor) {
          currentRecursiveSequence++;
          vm = vm.$parent;
          continue;
        } else if (currentRecursiveSequence > 0) {
          tree[tree.length - 1] = [last, currentRecursiveSequence];
          currentRecursiveSequence = 0;
        }
      }
      tree.push(vm);
      vm = vm.$parent;
    }
    const formattedTree = tree.map(
      (vm2, i2) => `${(i2 === 0 ? "---> " : repeat(" ", 5 + i2 * 2)) + (Array.isArray(vm2) ? `${formatComponentName$1(vm2[0])}... (${vm2[1]} recursive calls)` : formatComponentName$1(vm2))}`
    ).join("\n");
    return `

found in

${formattedTree}`;
  }
  return `

(found in ${formatComponentName$1(vm)})`;
}, "generateComponentTrace");
const attachErrorHandler = /* @__PURE__ */ __name((app2, options5) => {
  const { errorHandler: originalErrorHandler, warnHandler, silent } = app2.config;
  app2.config.errorHandler = (error2, vm, lifecycleHook) => {
    const componentName = formatComponentName$1(vm, false);
    const trace = vm ? generateComponentTrace(vm) : "";
    const metadata = {
      componentName,
      lifecycleHook,
      trace
    };
    if (options5.attachProps && vm) {
      if (vm.$options && vm.$options.propsData) {
        metadata.propsData = vm.$options.propsData;
      } else if (vm.$props) {
        metadata.propsData = vm.$props;
      }
    }
    setTimeout(() => {
      captureException(error2, {
        captureContext: { contexts: { vue: metadata } },
        mechanism: { handled: false }
      });
    });
    if (typeof originalErrorHandler === "function" && app2.config.errorHandler) {
      originalErrorHandler.call(app2, error2, vm, lifecycleHook);
    }
    if (options5.logErrors) {
      const hasConsole = typeof console !== "undefined";
      const message3 = `Error in ${lifecycleHook}: "${error2 && error2.toString()}"`;
      if (warnHandler) {
        warnHandler.call(null, message3, vm, trace);
      } else if (hasConsole && !silent) {
        consoleSandbox(() => {
          console.error(`[Vue warn]: ${message3}${trace}`);
        });
      }
    }
  };
}, "attachErrorHandler");
const VUE_OP = "ui.vue";
const HOOKS = {
  activate: ["activated", "deactivated"],
  create: ["beforeCreate", "created"],
  // Vue 3
  unmount: ["beforeUnmount", "unmounted"],
  // Vue 2
  destroy: ["beforeDestroy", "destroyed"],
  mount: ["beforeMount", "mounted"],
  update: ["beforeUpdate", "updated"]
};
function finishRootSpan(vm, timestamp2, timeout) {
  if (vm.$_sentryRootSpanTimer) {
    clearTimeout(vm.$_sentryRootSpanTimer);
  }
  vm.$_sentryRootSpanTimer = setTimeout(() => {
    if (vm.$root && vm.$root.$_sentryRootSpan) {
      vm.$root.$_sentryRootSpan.end(timestamp2);
      vm.$root.$_sentryRootSpan = void 0;
    }
  }, timeout);
}
__name(finishRootSpan, "finishRootSpan");
function findTrackComponent(trackComponents, formattedName) {
  function extractComponentName(name2) {
    return name2.replace(/^<([^\s]*)>(?: at [^\s]*)?$/, "$1");
  }
  __name(extractComponentName, "extractComponentName");
  const isMatched = trackComponents.some((compo) => {
    return extractComponentName(formattedName) === extractComponentName(compo);
  });
  return isMatched;
}
__name(findTrackComponent, "findTrackComponent");
const createTracingMixins = /* @__PURE__ */ __name((options5) => {
  const hooks2 = (options5.hooks || []).concat(DEFAULT_HOOKS).filter((value3, index2, self2) => self2.indexOf(value3) === index2);
  const mixins = {};
  for (const operation of hooks2) {
    const internalHooks = HOOKS[operation];
    if (!internalHooks) {
      DEBUG_BUILD && logger$2.warn(`Unknown hook: ${operation}`);
      continue;
    }
    for (const internalHook of internalHooks) {
      mixins[internalHook] = function() {
        const isRoot = this.$root === this;
        if (isRoot) {
          this.$_sentryRootSpan = this.$_sentryRootSpan || startInactiveSpan({
            name: "Application Render",
            op: `${VUE_OP}.render`,
            attributes: {
              [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.vue"
            },
            onlyIfParent: true
          });
        }
        const name2 = formatComponentName$1(this, false);
        const shouldTrack2 = Array.isArray(options5.trackComponents) ? findTrackComponent(options5.trackComponents, name2) : options5.trackComponents;
        if (!isRoot && !shouldTrack2) {
          return;
        }
        this.$_sentrySpans = this.$_sentrySpans || {};
        if (internalHook == internalHooks[0]) {
          const activeSpan = this.$root && this.$root.$_sentryRootSpan || getActiveSpan();
          if (activeSpan) {
            const oldSpan = this.$_sentrySpans[operation];
            if (oldSpan) {
              oldSpan.end();
            }
            this.$_sentrySpans[operation] = startInactiveSpan({
              name: `Vue ${name2}`,
              op: `${VUE_OP}.${operation}`,
              attributes: {
                [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.ui.vue"
              },
              // UI spans should only be created if there is an active root span (transaction)
              onlyIfParent: true
            });
          }
        } else {
          const span = this.$_sentrySpans[operation];
          if (!span) return;
          span.end();
          finishRootSpan(this, timestampInSeconds(), options5.timeout);
        }
      };
    }
  }
  return mixins;
}, "createTracingMixins");
const globalWithVue = GLOBAL_OBJ;
const DEFAULT_CONFIG = {
  Vue: globalWithVue.Vue,
  attachProps: true,
  logErrors: true,
  attachErrorHandler: true,
  hooks: DEFAULT_HOOKS,
  timeout: 2e3,
  trackComponents: false
};
const INTEGRATION_NAME = "Vue";
const vueIntegration = defineIntegration((integrationOptions = {}) => {
  return {
    name: INTEGRATION_NAME,
    setup(client) {
      const options5 = { ...DEFAULT_CONFIG, ...client.getOptions(), ...integrationOptions };
      if (!options5.Vue && !options5.app) {
        consoleSandbox(() => {
          console.warn(
            "[@sentry/vue]: Misconfigured SDK. Vue specific errors will not be captured. Update your `Sentry.init` call with an appropriate config option: `app` (Application Instance - Vue 3) or `Vue` (Vue Constructor - Vue 2)."
          );
        });
        return;
      }
      if (options5.app) {
        const apps = Array.isArray(options5.app) ? options5.app : [options5.app];
        apps.forEach((app2) => vueInit(app2, options5));
      } else if (options5.Vue) {
        vueInit(options5.Vue, options5);
      }
    }
  };
});
const vueInit = /* @__PURE__ */ __name((app2, options5) => {
  if (DEBUG_BUILD) {
    const appWithInstance = app2;
    const isMounted = appWithInstance._instance && appWithInstance._instance.isMounted;
    if (isMounted === true) {
      consoleSandbox(() => {
        console.warn(
          "[@sentry/vue]: Misconfigured SDK. Vue app is already mounted. Make sure to call `app.mount()` after `Sentry.init()`."
        );
      });
    }
  }
  if (options5.attachErrorHandler) {
    attachErrorHandler(app2, options5);
  }
  if (hasTracingEnabled(options5)) {
    app2.mixin(
      createTracingMixins({
        ...options5,
        // eslint-disable-next-line deprecation/deprecation
        ...options5.tracingOptions
      })
    );
  }
}, "vueInit");
function init$3(config2 = {}) {
  const options5 = {
    _metadata: {
      sdk: {
        name: "sentry.javascript.vue",
        packages: [
          {
            name: "npm:@sentry/vue",
            version: SDK_VERSION
          }
        ],
        version: SDK_VERSION
      }
    },
    defaultIntegrations: [...getDefaultIntegrations(config2), vueIntegration()],
    ...config2
  };
  return init$4(options5);
}
__name(init$3, "init$3");
function instrumentVueRouter(router2, options5, startNavigationSpanFn) {
  let isFirstPageLoad = true;
  router2.onError((error2) => captureException(error2, { mechanism: { handled: false } }));
  router2.beforeEach((to, from2, next2) => {
    const isPageLoadNavigation = from2.name == null && from2.matched.length === 0 || from2.name === void 0 && isFirstPageLoad;
    if (isFirstPageLoad) {
      isFirstPageLoad = false;
    }
    const attributes = {
      [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.navigation.vue"
    };
    for (const key of Object.keys(to.params)) {
      attributes[`params.${key}`] = to.params[key];
    }
    for (const key of Object.keys(to.query)) {
      const value3 = to.query[key];
      if (value3) {
        attributes[`query.${key}`] = value3;
      }
    }
    let spanName = to.path;
    let transactionSource = "url";
    if (to.name && options5.routeLabel !== "path") {
      spanName = to.name.toString();
      transactionSource = "custom";
    } else if (to.matched.length > 0) {
      const lastIndex = to.matched.length - 1;
      spanName = to.matched[lastIndex].path;
      transactionSource = "route";
    }
    getCurrentScope$1().setTransactionName(spanName);
    if (options5.instrumentPageLoad && isPageLoadNavigation) {
      const activeRootSpan = getActiveRootSpan();
      if (activeRootSpan) {
        const existingAttributes = spanToJSON(activeRootSpan).data || {};
        if (existingAttributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE] !== "custom") {
          activeRootSpan.updateName(spanName);
          activeRootSpan.setAttribute(SEMANTIC_ATTRIBUTE_SENTRY_SOURCE, transactionSource);
        }
        activeRootSpan.setAttributes({
          ...attributes,
          [SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN]: "auto.pageload.vue"
        });
      }
    }
    if (options5.instrumentNavigation && !isPageLoadNavigation) {
      attributes[SEMANTIC_ATTRIBUTE_SENTRY_SOURCE] = transactionSource;
      attributes[SEMANTIC_ATTRIBUTE_SENTRY_ORIGIN] = "auto.navigation.vue";
      startNavigationSpanFn({
        name: spanName,
        op: "navigation",
        attributes
      });
    }
    if (next2) {
      next2();
    }
  });
}
__name(instrumentVueRouter, "instrumentVueRouter");
function getActiveRootSpan() {
  const span = getActiveSpan();
  const rootSpan = span && getRootSpan(span);
  if (!rootSpan) {
    return void 0;
  }
  const op = spanToJSON(rootSpan).op;
  return op === "navigation" || op === "pageload" ? rootSpan : void 0;
}
__name(getActiveRootSpan, "getActiveRootSpan");
function browserTracingIntegration(options5 = {}) {
  if (!options5.router) {
    return browserTracingIntegration$1(options5);
  }
  const integration = browserTracingIntegration$1({
    ...options5,
    instrumentNavigation: false
  });
  const { router: router2, instrumentNavigation = true, instrumentPageLoad = true, routeLabel = "name" } = options5;
  return {
    ...integration,
    afterAllSetup(client) {
      integration.afterAllSetup(client);
      const startNavigationSpan = /* @__PURE__ */ __name((options6) => {
        startBrowserTracingNavigationSpan(client, options6);
      }, "startNavigationSpan");
      instrumentVueRouter(router2, { routeLabel, instrumentNavigation, instrumentPageLoad }, startNavigationSpan);
    }
  };
}
__name(browserTracingIntegration, "browserTracingIntegration");
const createSentryPiniaPlugin = /* @__PURE__ */ __name((options5 = {
  attachPiniaState: true,
  addBreadcrumbs: true,
  actionTransformer: /* @__PURE__ */ __name((action) => action, "actionTransformer"),
  stateTransformer: /* @__PURE__ */ __name((state) => state, "stateTransformer")
}) => {
  const plugin = /* @__PURE__ */ __name(({ store }) => {
    options5.attachPiniaState !== false && getGlobalScope().addEventProcessor((event, hint) => {
      try {
        const timestamp2 = (/* @__PURE__ */ new Date()).toTimeString().split(" ")[0];
        const filename = `pinia_state_${store.$id}_${timestamp2}.json`;
        hint.attachments = [
          ...hint.attachments || [],
          {
            filename,
            data: JSON.stringify(store.$state)
          }
        ];
      } catch (_2) {
      }
      return event;
    });
    store.$onAction((context) => {
      context.after(() => {
        const transformedActionName = options5.actionTransformer ? options5.actionTransformer(context.name) : context.name;
        if (typeof transformedActionName !== "undefined" && transformedActionName !== null && options5.addBreadcrumbs !== false) {
          addBreadcrumb({
            category: "action",
            message: transformedActionName,
            level: "info"
          });
        }
        const transformedState = options5.stateTransformer ? options5.stateTransformer(store.$state) : store.$state;
        const scope = getCurrentScope$1();
        const currentState = scope.getScopeData().contexts.state;
        if (typeof transformedState !== "undefined" && transformedState !== null) {
          const client = getClient();
          const options6 = client && client.getOptions();
          const normalizationDepth = options6 && options6.normalizeDepth || 3;
          const piniaStateContext = { type: "pinia", value: transformedState };
          const newState = {
            ...currentState || {},
            state: piniaStateContext
          };
          addNonEnumerableProperty(
            newState,
            "__sentry_override_normalization_depth__",
            3 + // 3 layers for `state.value.transformedState
            normalizationDepth
            // rest for the actual state
          );
          scope.setContext("state", newState);
        } else {
          scope.setContext("state", {
            ...currentState || {},
            state: { type: "pinia", value: "undefined" }
          });
        }
      });
    });
  }, "plugin");
  return plugin;
}, "createSentryPiniaPlugin");
/**
* @vue/shared v3.5.13
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/
/*! #__NO_SIDE_EFFECTS__ */
// @__NO_SIDE_EFFECTS__
function makeMap(str) {
  const map3 = /* @__PURE__ */ Object.create(null);
  for (const key of str.split(",")) map3[key] = 1;
  return (val) => val in map3;
}
__name(makeMap, "makeMap");
const EMPTY_OBJ = false ? Object.freeze({}) : {};
const EMPTY_ARR = false ? Object.freeze([]) : [];
const NOOP = /* @__PURE__ */ __name(() => {
}, "NOOP");
const NO = /* @__PURE__ */ __name(() => false, "NO");
const isOn = /* @__PURE__ */ __name((key) => key.charCodeAt(0) === 111 && key.charCodeAt(1) === 110 && // uppercase letter
(key.charCodeAt(2) > 122 || key.charCodeAt(2) < 97), "isOn");
const isModelListener = /* @__PURE__ */ __name((key) => key.startsWith("onUpdate:"), "isModelListener");
const extend$1 = Object.assign;
const remove$2 = /* @__PURE__ */ __name((arr, el) => {
  const i2 = arr.indexOf(el);
  if (i2 > -1) {
    arr.splice(i2, 1);
  }
}, "remove$2");
const hasOwnProperty$d = Object.prototype.hasOwnProperty;
const hasOwn$3 = /* @__PURE__ */ __name((val, key) => hasOwnProperty$d.call(val, key), "hasOwn$3");
const isArray$b = Array.isArray;
const isMap$3 = /* @__PURE__ */ __name((val) => toTypeString$1(val) === "[object Map]", "isMap$3");
const isSet$3 = /* @__PURE__ */ __name((val) => toTypeString$1(val) === "[object Set]", "isSet$3");
const isDate$4 = /* @__PURE__ */ __name((val) => toTypeString$1(val) === "[object Date]", "isDate$4");
const isRegExp$4 = /* @__PURE__ */ __name((val) => toTypeString$1(val) === "[object RegExp]", "isRegExp$4");
const isFunction$c = /* @__PURE__ */ __name((val) => typeof val === "function", "isFunction$c");
const isString$9 = /* @__PURE__ */ __name((val) => typeof val === "string", "isString$9");
const isSymbol$1 = /* @__PURE__ */ __name((val) => typeof val === "symbol", "isSymbol$1");
const isObject$f = /* @__PURE__ */ __name((val) => val !== null && typeof val === "object", "isObject$f");
const isPromise$1 = /* @__PURE__ */ __name((val) => {
  return (isObject$f(val) || isFunction$c(val)) && isFunction$c(val.then) && isFunction$c(val.catch);
}, "isPromise$1");
const objectToString$3 = Object.prototype.toString;
const toTypeString$1 = /* @__PURE__ */ __name((value3) => objectToString$3.call(value3), "toTypeString$1");
const toRawType = /* @__PURE__ */ __name((value3) => {
  return toTypeString$1(value3).slice(8, -1);
}, "toRawType");
const isPlainObject$4 = /* @__PURE__ */ __name((val) => toTypeString$1(val) === "[object Object]", "isPlainObject$4");
const isIntegerKey = /* @__PURE__ */ __name((key) => isString$9(key) && key !== "NaN" && key[0] !== "-" && "" + parseInt(key, 10) === key, "isIntegerKey");
const isReservedProp = /* @__PURE__ */ makeMap(
  // the leading comma is intentional so empty string "" is also included
  ",key,ref,ref_for,ref_key,onVnodeBeforeMount,onVnodeMounted,onVnodeBeforeUpdate,onVnodeUpdated,onVnodeBeforeUnmount,onVnodeUnmounted"
);
const isBuiltInDirective = /* @__PURE__ */ makeMap(
  "bind,cloak,else-if,else,for,html,if,model,on,once,pre,show,slot,text,memo"
);
const cacheStringFunction$1 = /* @__PURE__ */ __name((fn) => {
  const cache2 = /* @__PURE__ */ Object.create(null);
  return (str) => {
    const hit = cache2[str];
    return hit || (cache2[str] = fn(str));
  };
}, "cacheStringFunction$1");
const camelizeRE$1 = /-(\w)/g;
const camelize$1 = cacheStringFunction$1(
  (str) => {
    return str.replace(camelizeRE$1, (_2, c2) => c2 ? c2.toUpperCase() : "");
  }
);
const hyphenateRE$1 = /\B([A-Z])/g;
const hyphenate$1 = cacheStringFunction$1(
  (str) => str.replace(hyphenateRE$1, "-$1").toLowerCase()
);
const capitalize$1 = cacheStringFunction$1((str) => {
  return str.charAt(0).toUpperCase() + str.slice(1);
});
const toHandlerKey = cacheStringFunction$1(
  (str) => {
    const s2 = str ? `on${capitalize$1(str)}` : ``;
    return s2;
  }
);
const hasChanged = /* @__PURE__ */ __name((value3, oldValue) => !Object.is(value3, oldValue), "hasChanged");
const invokeArrayFns = /* @__PURE__ */ __name((fns, ...arg) => {
  for (let i2 = 0; i2 < fns.length; i2++) {
    fns[i2](...arg);
  }
}, "invokeArrayFns");
const def = /* @__PURE__ */ __name((obj, key, value3, writable = false) => {
  Object.defineProperty(obj, key, {
    configurable: true,
    enumerable: false,
    writable,
    value: value3
  });
}, "def");
const looseToNumber = /* @__PURE__ */ __name((val) => {
  const n2 = parseFloat(val);
  return isNaN(n2) ? val : n2;
}, "looseToNumber");
const toNumber = /* @__PURE__ */ __name((val) => {
  const n2 = isString$9(val) ? Number(val) : NaN;
  return isNaN(n2) ? val : n2;
}, "toNumber");
let _globalThis$1;
const getGlobalThis$1 = /* @__PURE__ */ __name(() => {
  return _globalThis$1 || (_globalThis$1 = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : {});
}, "getGlobalThis$1");
const identRE = /^[_$a-zA-Z\xA0-\uFFFF][_$a-zA-Z0-9\xA0-\uFFFF]*$/;
function genPropsAccessExp(name2) {
  return identRE.test(name2) ? `__props.${name2}` : `__props[${JSON.stringify(name2)}]`;
}
__name(genPropsAccessExp, "genPropsAccessExp");
function genCacheKey(source, options5) {
  return source + JSON.stringify(
    options5,
    (_2, val) => typeof val === "function" ? val.toString() : val
  );
}
__name(genCacheKey, "genCacheKey");
const PatchFlags = {
  "TEXT": 1,
  "1": "TEXT",
  "CLASS": 2,
  "2": "CLASS",
  "STYLE": 4,
  "4": "STYLE",
  "PROPS": 8,
  "8": "PROPS",
  "FULL_PROPS": 16,
  "16": "FULL_PROPS",
  "NEED_HYDRATION": 32,
  "32": "NEED_HYDRATION",
  "STABLE_FRAGMENT": 64,
  "64": "STABLE_FRAGMENT",
  "KEYED_FRAGMENT": 128,
  "128": "KEYED_FRAGMENT",
  "UNKEYED_FRAGMENT": 256,
  "256": "UNKEYED_FRAGMENT",
  "NEED_PATCH": 512,
  "512": "NEED_PATCH",
  "DYNAMIC_SLOTS": 1024,
  "1024": "DYNAMIC_SLOTS",
  "DEV_ROOT_FRAGMENT": 2048,
  "2048": "DEV_ROOT_FRAGMENT",
  "CACHED": -1,
  "-1": "CACHED",
  "BAIL": -2,
  "-2": "BAIL"
};
const PatchFlagNames = {
  [1]: `TEXT`,
  [2]: `CLASS`,
  [4]: `STYLE`,
  [8]: `PROPS`,
  [16]: `FULL_PROPS`,
  [32]: `NEED_HYDRATION`,
  [64]: `STABLE_FRAGMENT`,
  [128]: `KEYED_FRAGMENT`,
  [256]: `UNKEYED_FRAGMENT`,
  [512]: `NEED_PATCH`,
  [1024]: `DYNAMIC_SLOTS`,
  [2048]: `DEV_ROOT_FRAGMENT`,
  [-1]: `HOISTED`,
  [-2]: `BAIL`
};
const ShapeFlags = {
  "ELEMENT": 1,
  "1": "ELEMENT",
  "FUNCTIONAL_COMPONENT": 2,
  "2": "FUNCTIONAL_COMPONENT",
  "STATEFUL_COMPONENT": 4,
  "4": "STATEFUL_COMPONENT",
  "TEXT_CHILDREN": 8,
  "8": "TEXT_CHILDREN",
  "ARRAY_CHILDREN": 16,
  "16": "ARRAY_CHILDREN",
  "SLOTS_CHILDREN": 32,
  "32": "SLOTS_CHILDREN",
  "TELEPORT": 64,
  "64": "TELEPORT",
  "SUSPENSE": 128,
  "128": "SUSPENSE",
  "COMPONENT_SHOULD_KEEP_ALIVE": 256,
  "256": "COMPONENT_SHOULD_KEEP_ALIVE",
  "COMPONENT_KEPT_ALIVE": 512,
  "512": "COMPONENT_KEPT_ALIVE",
  "COMPONENT": 6,
  "6": "COMPONENT"
};
const SlotFlags = {
  "STABLE": 1,
  "1": "STABLE",
  "DYNAMIC": 2,
  "2": "DYNAMIC",
  "FORWARDED": 3,
  "3": "FORWARDED"
};
const slotFlagsText = {
  [1]: "STABLE",
  [2]: "DYNAMIC",
  [3]: "FORWARDED"
};
const GLOBALS_ALLOWED = "Infinity,undefined,NaN,isFinite,isNaN,parseFloat,parseInt,decodeURI,decodeURIComponent,encodeURI,encodeURIComponent,Math,Number,Date,Array,Object,Boolean,String,RegExp,Map,Set,JSON,Intl,BigInt,console,Error,Symbol";
const isGloballyAllowed = /* @__PURE__ */ makeMap(GLOBALS_ALLOWED);
const isGloballyWhitelisted = isGloballyAllowed;
const range = 2;
function generateCodeFrame$1(source, start2 = 0, end = source.length) {
  start2 = Math.max(0, Math.min(start2, source.length));
  end = Math.max(0, Math.min(end, source.length));
  if (start2 > end) return "";
  let lines = source.split(/(\r?\n)/);
  const newlineSequences = lines.filter((_2, idx) => idx % 2 === 1);
  lines = lines.filter((_2, idx) => idx % 2 === 0);
  let count = 0;
  const res = [];
  for (let i2 = 0; i2 < lines.length; i2++) {
    count += lines[i2].length + (newlineSequences[i2] && newlineSequences[i2].length || 0);
    if (count >= start2) {
      for (let j2 = i2 - range; j2 <= i2 + range || end > count; j2++) {
        if (j2 < 0 || j2 >= lines.length) continue;
        const line = j2 + 1;
        res.push(
          `${line}${" ".repeat(Math.max(3 - String(line).length, 0))}|  ${lines[j2]}`
        );
        const lineLength = lines[j2].length;
        const newLineSeqLength = newlineSequences[j2] && newlineSequences[j2].length || 0;
        if (j2 === i2) {
          const pad = start2 - (count - (lineLength + newLineSeqLength));
          const length = Math.max(
            1,
            end > count ? lineLength - pad : end - start2
          );
          res.push(`   |  ` + " ".repeat(pad) + "^".repeat(length));
        } else if (j2 > i2) {
          if (end > count) {
            const length = Math.max(Math.min(end - count, lineLength), 1);
            res.push(`   |  ` + "^".repeat(length));
          }
          count += lineLength + newLineSeqLength;
        }
      }
      break;
    }
  }
  return res.join("\n");
}
__name(generateCodeFrame$1, "generateCodeFrame$1");
function normalizeStyle(value3) {
  if (isArray$b(value3)) {
    const res = {};
    for (let i2 = 0; i2 < value3.length; i2++) {
      const item3 = value3[i2];
      const normalized = isString$9(item3) ? parseStringStyle(item3) : normalizeStyle(item3);
      if (normalized) {
        for (const key in normalized) {
          res[key] = normalized[key];
        }
      }
    }
    return res;
  } else if (isString$9(value3) || isObject$f(value3)) {
    return value3;
  }
}
__name(normalizeStyle, "normalizeStyle");
const listDelimiterRE = /;(?![^(]*\))/g;
const propertyDelimiterRE = /:([^]+)/;
const styleCommentRE = /\/\*[^]*?\*\//g;
function parseStringStyle(cssText) {
  const ret = {};
  cssText.replace(styleCommentRE, "").split(listDelimiterRE).forEach((item3) => {
    if (item3) {
      const tmp = item3.split(propertyDelimiterRE);
      tmp.length > 1 && (ret[tmp[0].trim()] = tmp[1].trim());
    }
  });
  return ret;
}
__name(parseStringStyle, "parseStringStyle");
function stringifyStyle(styles) {
  if (!styles) return "";
  if (isString$9(styles)) return styles;
  let ret = "";
  for (const key in styles) {
    const value3 = styles[key];
    if (isString$9(value3) || typeof value3 === "number") {
      const normalizedKey = key.startsWith(`--`) ? key : hyphenate$1(key);
      ret += `${normalizedKey}:${value3};`;
    }
  }
  return ret;
}
__name(stringifyStyle, "stringifyStyle");
function normalizeClass(value3) {
  let res = "";
  if (isString$9(value3)) {
    res = value3;
  } else if (isArray$b(value3)) {
    for (let i2 = 0; i2 < value3.length; i2++) {
      const normalized = normalizeClass(value3[i2]);
      if (normalized) {
        res += normalized + " ";
      }
    }
  } else if (isObject$f(value3)) {
    for (const name2 in value3) {
      if (value3[name2]) {
        res += name2 + " ";
      }
    }
  }
  return res.trim();
}
__name(normalizeClass, "normalizeClass");
function normalizeProps(props) {
  if (!props) return null;
  let { class: klass, style: style2 } = props;
  if (klass && !isString$9(klass)) {
    props.class = normalizeClass(klass);
  }
  if (style2) {
    props.style = normalizeStyle(style2);
  }
  return props;
}
__name(normalizeProps, "normalizeProps");
const HTML_TAGS = "html,body,base,head,link,meta,style,title,address,article,aside,footer,header,hgroup,h1,h2,h3,h4,h5,h6,nav,section,div,dd,dl,dt,figcaption,figure,picture,hr,img,li,main,ol,p,pre,ul,a,b,abbr,bdi,bdo,br,cite,code,data,dfn,em,i,kbd,mark,q,rp,rt,ruby,s,samp,small,span,strong,sub,sup,time,u,var,wbr,area,audio,map,track,video,embed,object,param,source,canvas,script,noscript,del,ins,caption,col,colgroup,table,thead,tbody,td,th,tr,button,datalist,fieldset,form,input,label,legend,meter,optgroup,option,output,progress,select,textarea,details,dialog,menu,summary,template,blockquote,iframe,tfoot";
const SVG_TAGS = "svg,animate,animateMotion,animateTransform,circle,clipPath,color-profile,defs,desc,discard,ellipse,feBlend,feColorMatrix,feComponentTransfer,feComposite,feConvolveMatrix,feDiffuseLighting,feDisplacementMap,feDistantLight,feDropShadow,feFlood,feFuncA,feFuncB,feFuncG,feFuncR,feGaussianBlur,feImage,feMerge,feMergeNode,feMorphology,feOffset,fePointLight,feSpecularLighting,feSpotLight,feTile,feTurbulence,filter,foreignObject,g,hatch,hatchpath,image,line,linearGradient,marker,mask,mesh,meshgradient,meshpatch,meshrow,metadata,mpath,path,pattern,polygon,polyline,radialGradient,rect,set,solidcolor,stop,switch,symbol,text,textPath,title,tspan,unknown,use,view";
const MATH_TAGS = "annotation,annotation-xml,maction,maligngroup,malignmark,math,menclose,merror,mfenced,mfrac,mfraction,mglyph,mi,mlabeledtr,mlongdiv,mmultiscripts,mn,mo,mover,mpadded,mphantom,mprescripts,mroot,mrow,ms,mscarries,mscarry,msgroup,msline,mspace,msqrt,msrow,mstack,mstyle,msub,msubsup,msup,mtable,mtd,mtext,mtr,munder,munderover,none,semantics";
const VOID_TAGS = "area,base,br,col,embed,hr,img,input,link,meta,param,source,track,wbr";
const isHTMLTag = /* @__PURE__ */ makeMap(HTML_TAGS);
const isSVGTag = /* @__PURE__ */ makeMap(SVG_TAGS);
const isMathMLTag = /* @__PURE__ */ makeMap(MATH_TAGS);
const isVoidTag = /* @__PURE__ */ makeMap(VOID_TAGS);
const specialBooleanAttrs = `itemscope,allowfullscreen,formnovalidate,ismap,nomodule,novalidate,readonly`;
const isSpecialBooleanAttr = /* @__PURE__ */ makeMap(specialBooleanAttrs);
const isBooleanAttr = /* @__PURE__ */ makeMap(
  specialBooleanAttrs + `,async,autofocus,autoplay,controls,default,defer,disabled,hidden,inert,loop,open,required,reversed,scoped,seamless,checked,muted,multiple,selected`
);
function includeBooleanAttr(value3) {
  return !!value3 || value3 === "";
}
__name(includeBooleanAttr, "includeBooleanAttr");
const unsafeAttrCharRE = /[>/="'\u0009\u000a\u000c\u0020]/;
const attrValidationCache = {};
function isSSRSafeAttrName(name2) {
  if (attrValidationCache.hasOwnProperty(name2)) {
    return attrValidationCache[name2];
  }
  const isUnsafe = unsafeAttrCharRE.test(name2);
  if (isUnsafe) {
    console.error(`unsafe attribute name: ${name2}`);
  }
  return attrValidationCache[name2] = !isUnsafe;
}
__name(isSSRSafeAttrName, "isSSRSafeAttrName");
const propsToAttrMap = {
  acceptCharset: "accept-charset",
  className: "class",
  htmlFor: "for",
  httpEquiv: "http-equiv"
};
const isKnownHtmlAttr = /* @__PURE__ */ makeMap(
  `accept,accept-charset,accesskey,action,align,allow,alt,async,autocapitalize,autocomplete,autofocus,autoplay,background,bgcolor,border,buffered,capture,challenge,charset,checked,cite,class,code,codebase,color,cols,colspan,content,contenteditable,contextmenu,controls,coords,crossorigin,csp,data,datetime,decoding,default,defer,dir,dirname,disabled,download,draggable,dropzone,enctype,enterkeyhint,for,form,formaction,formenctype,formmethod,formnovalidate,formtarget,headers,height,hidden,high,href,hreflang,http-equiv,icon,id,importance,inert,integrity,ismap,itemprop,keytype,kind,label,lang,language,loading,list,loop,low,manifest,max,maxlength,minlength,media,min,multiple,muted,name,novalidate,open,optimum,pattern,ping,placeholder,poster,preload,radiogroup,readonly,referrerpolicy,rel,required,reversed,rows,rowspan,sandbox,scope,scoped,selected,shape,size,sizes,slot,span,spellcheck,src,srcdoc,srclang,srcset,start,step,style,summary,tabindex,target,title,translate,type,usemap,value,width,wrap`
);
const isKnownSvgAttr = /* @__PURE__ */ makeMap(
  `xmlns,accent-height,accumulate,additive,alignment-baseline,alphabetic,amplitude,arabic-form,ascent,attributeName,attributeType,azimuth,baseFrequency,baseline-shift,baseProfile,bbox,begin,bias,by,calcMode,cap-height,class,clip,clipPathUnits,clip-path,clip-rule,color,color-interpolation,color-interpolation-filters,color-profile,color-rendering,contentScriptType,contentStyleType,crossorigin,cursor,cx,cy,d,decelerate,descent,diffuseConstant,direction,display,divisor,dominant-baseline,dur,dx,dy,edgeMode,elevation,enable-background,end,exponent,fill,fill-opacity,fill-rule,filter,filterRes,filterUnits,flood-color,flood-opacity,font-family,font-size,font-size-adjust,font-stretch,font-style,font-variant,font-weight,format,from,fr,fx,fy,g1,g2,glyph-name,glyph-orientation-horizontal,glyph-orientation-vertical,glyphRef,gradientTransform,gradientUnits,hanging,height,href,hreflang,horiz-adv-x,horiz-origin-x,id,ideographic,image-rendering,in,in2,intercept,k,k1,k2,k3,k4,kernelMatrix,kernelUnitLength,kerning,keyPoints,keySplines,keyTimes,lang,lengthAdjust,letter-spacing,lighting-color,limitingConeAngle,local,marker-end,marker-mid,marker-start,markerHeight,markerUnits,markerWidth,mask,maskContentUnits,maskUnits,mathematical,max,media,method,min,mode,name,numOctaves,offset,opacity,operator,order,orient,orientation,origin,overflow,overline-position,overline-thickness,panose-1,paint-order,path,pathLength,patternContentUnits,patternTransform,patternUnits,ping,pointer-events,points,pointsAtX,pointsAtY,pointsAtZ,preserveAlpha,preserveAspectRatio,primitiveUnits,r,radius,referrerPolicy,refX,refY,rel,rendering-intent,repeatCount,repeatDur,requiredExtensions,requiredFeatures,restart,result,rotate,rx,ry,scale,seed,shape-rendering,slope,spacing,specularConstant,specularExponent,speed,spreadMethod,startOffset,stdDeviation,stemh,stemv,stitchTiles,stop-color,stop-opacity,strikethrough-position,strikethrough-thickness,string,stroke,stroke-dasharray,stroke-dashoffset,stroke-linecap,stroke-linejoin,stroke-miterlimit,stroke-opacity,stroke-width,style,surfaceScale,systemLanguage,tabindex,tableValues,target,targetX,targetY,text-anchor,text-decoration,text-rendering,textLength,to,transform,transform-origin,type,u1,u2,underline-position,underline-thickness,unicode,unicode-bidi,unicode-range,units-per-em,v-alphabetic,v-hanging,v-ideographic,v-mathematical,values,vector-effect,version,vert-adv-y,vert-origin-x,vert-origin-y,viewBox,viewTarget,visibility,width,widths,word-spacing,writing-mode,x,x-height,x1,x2,xChannelSelector,xlink:actuate,xlink:arcrole,xlink:href,xlink:role,xlink:show,xlink:title,xlink:type,xmlns:xlink,xml:base,xml:lang,xml:space,y,y1,y2,yChannelSelector,z,zoomAndPan`
);
const isKnownMathMLAttr = /* @__PURE__ */ makeMap(
  `accent,accentunder,actiontype,align,alignmentscope,altimg,altimg-height,altimg-valign,altimg-width,alttext,bevelled,close,columnsalign,columnlines,columnspan,denomalign,depth,dir,display,displaystyle,encoding,equalcolumns,equalrows,fence,fontstyle,fontweight,form,frame,framespacing,groupalign,height,href,id,indentalign,indentalignfirst,indentalignlast,indentshift,indentshiftfirst,indentshiftlast,indextype,justify,largetop,largeop,lquote,lspace,mathbackground,mathcolor,mathsize,mathvariant,maxsize,minlabelspacing,mode,other,overflow,position,rowalign,rowlines,rowspan,rquote,rspace,scriptlevel,scriptminsize,scriptsizemultiplier,selection,separator,separators,shift,side,src,stackalign,stretchy,subscriptshift,superscriptshift,symmetric,voffset,width,widths,xlink:href,xlink:show,xlink:type,xmlns`
);
function isRenderableAttrValue(value3) {
  if (value3 == null) {
    return false;
  }
  const type = typeof value3;
  return type === "string" || type === "number" || type === "boolean";
}
__name(isRenderableAttrValue, "isRenderableAttrValue");
const escapeRE$2 = /["'&<>]/;
function escapeHtml$2(string) {
  const str = "" + string;
  const match2 = escapeRE$2.exec(str);
  if (!match2) {
    return str;
  }
  let html = "";
  let escaped;
  let index2;
  let lastIndex = 0;
  for (index2 = match2.index; index2 < str.length; index2++) {
    switch (str.charCodeAt(index2)) {
      case 34:
        escaped = "&quot;";
        break;
      case 38:
        escaped = "&amp;";
        break;
      case 39:
        escaped = "&#39;";
        break;
      case 60:
        escaped = "&lt;";
        break;
      case 62:
        escaped = "&gt;";
        break;
      default:
        continue;
    }
    if (lastIndex !== index2) {
      html += str.slice(lastIndex, index2);
    }
    lastIndex = index2 + 1;
    html += escaped;
  }
  return lastIndex !== index2 ? html + str.slice(lastIndex, index2) : html;
}
__name(escapeHtml$2, "escapeHtml$2");
const commentStripRE = /^-?>|<!--|-->|--!>|<!-$/g;
function escapeHtmlComment(src) {
  return src.replace(commentStripRE, "");
}
__name(escapeHtmlComment, "escapeHtmlComment");
const cssVarNameEscapeSymbolsRE = /[ !"#$%&'()*+,./:;<=>?@[\\\]^`{|}~]/g;
function getEscapedCssVarName(key, doubleEscape) {
  return key.replace(
    cssVarNameEscapeSymbolsRE,
    (s2) => doubleEscape ? s2 === '"' ? '\\\\\\"' : `\\\\${s2}` : `\\${s2}`
  );
}
__name(getEscapedCssVarName, "getEscapedCssVarName");
function looseCompareArrays(a2, b2) {
  if (a2.length !== b2.length) return false;
  let equal = true;
  for (let i2 = 0; equal && i2 < a2.length; i2++) {
    equal = looseEqual(a2[i2], b2[i2]);
  }
  return equal;
}
__name(looseCompareArrays, "looseCompareArrays");
function looseEqual(a2, b2) {
  if (a2 === b2) return true;
  let aValidType = isDate$4(a2);
  let bValidType = isDate$4(b2);
  if (aValidType || bValidType) {
    return aValidType && bValidType ? a2.getTime() === b2.getTime() : false;
  }
  aValidType = isSymbol$1(a2);
  bValidType = isSymbol$1(b2);
  if (aValidType || bValidType) {
    return a2 === b2;
  }
  aValidType = isArray$b(a2);
  bValidType = isArray$b(b2);
  if (aValidType || bValidType) {
    return aValidType && bValidType ? looseCompareArrays(a2, b2) : false;
  }
  aValidType = isObject$f(a2);
  bValidType = isObject$f(b2);
  if (aValidType || bValidType) {
    if (!aValidType || !bValidType) {
      return false;
    }
    const aKeysCount = Object.keys(a2).length;
    const bKeysCount = Object.keys(b2).length;
    if (aKeysCount !== bKeysCount) {
      return false;
    }
    for (const key in a2) {
      const aHasKey = a2.hasOwnProperty(key);
      const bHasKey = b2.hasOwnProperty(key);
      if (aHasKey && !bHasKey || !aHasKey && bHasKey || !looseEqual(a2[key], b2[key])) {
        return false;
      }
    }
  }
  return String(a2) === String(b2);
}
__name(looseEqual, "looseEqual");
function looseIndexOf(arr, val) {
  return arr.findIndex((item3) => looseEqual(item3, val));
}
__name(looseIndexOf, "looseIndexOf");
const isRef$1 = /* @__PURE__ */ __name((val) => {
  return !!(val && val["__v_isRef"] === true);
}, "isRef$1");
const toDisplayString$1 = /* @__PURE__ */ __name((val) => {
  return isString$9(val) ? val : val == null ? "" : isArray$b(val) || isObject$f(val) && (val.toString === objectToString$3 || !isFunction$c(val.toString)) ? isRef$1(val) ? toDisplayString$1(val.value) : JSON.stringify(val, replacer, 2) : String(val);
}, "toDisplayString$1");
const replacer = /* @__PURE__ */ __name((_key, val) => {
  if (isRef$1(val)) {
    return replacer(_key, val.value);
  } else if (isMap$3(val)) {
    return {
      [`Map(${val.size})`]: [...val.entries()].reduce(
        (entries, [key, val2], i2) => {
          entries[stringifySymbol(key, i2) + " =>"] = val2;
          return entries;
        },
        {}
      )
    };
  } else if (isSet$3(val)) {
    return {
      [`Set(${val.size})`]: [...val.values()].map((v2) => stringifySymbol(v2))
    };
  } else if (isSymbol$1(val)) {
    return stringifySymbol(val);
  } else if (isObject$f(val) && !isArray$b(val) && !isPlainObject$4(val)) {
    return String(val);
  }
  return val;
}, "replacer");
const stringifySymbol = /* @__PURE__ */ __name((v2, i2 = "") => {
  var _a2;
  return (
    // Symbol.description in es2019+ so we need to cast here to pass
    // the lib: es2016 check
    isSymbol$1(v2) ? `Symbol(${(_a2 = v2.description) != null ? _a2 : i2})` : v2
  );
}, "stringifySymbol");
/**
* @vue/reactivity v3.5.13
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/
function warn$4(msg, ...args) {
  console.warn(`[Vue warn] ${msg}`, ...args);
}
__name(warn$4, "warn$4");
let activeEffectScope;
class EffectScope {
  static {
    __name(this, "EffectScope");
  }
  constructor(detached = false) {
    this.detached = detached;
    this._active = true;
    this.effects = [];
    this.cleanups = [];
    this._isPaused = false;
    this.parent = activeEffectScope;
    if (!detached && activeEffectScope) {
      this.index = (activeEffectScope.scopes || (activeEffectScope.scopes = [])).push(
        this
      ) - 1;
    }
  }
  get active() {
    return this._active;
  }
  pause() {
    if (this._active) {
      this._isPaused = true;
      let i2, l2;
      if (this.scopes) {
        for (i2 = 0, l2 = this.scopes.length; i2 < l2; i2++) {
          this.scopes[i2].pause();
        }
      }
      for (i2 = 0, l2 = this.effects.length; i2 < l2; i2++) {
        this.effects[i2].pause();
      }
    }
  }
  /**
   * Resumes the effect scope, including all child scopes and effects.
   */
  resume() {
    if (this._active) {
      if (this._isPaused) {
        this._isPaused = false;
        let i2, l2;
        if (this.scopes) {
          for (i2 = 0, l2 = this.scopes.length; i2 < l2; i2++) {
            this.scopes[i2].resume();
          }
        }
        for (i2 = 0, l2 = this.effects.length; i2 < l2; i2++) {
          this.effects[i2].resume();
        }
      }
    }
  }
  run(fn) {
    if (this._active) {
      const currentEffectScope = activeEffectScope;
      try {
        activeEffectScope = this;
        return fn();
      } finally {
        activeEffectScope = currentEffectScope;
      }
    } else if (false) {
      warn$4(`cannot run an inactive effect scope.`);
    }
  }
  /**
   * This should only be called on non-detached scopes
   * @internal
   */
  on() {
    activeEffectScope = this;
  }
  /**
   * This should only be called on non-detached scopes
   * @internal
   */
  off() {
    activeEffectScope = this.parent;
  }
  stop(fromParent) {
    if (this._active) {
      this._active = false;
      let i2, l2;
      for (i2 = 0, l2 = this.effects.length; i2 < l2; i2++) {
        this.effects[i2].stop();
      }
      this.effects.length = 0;
      for (i2 = 0, l2 = this.cleanups.length; i2 < l2; i2++) {
        this.cleanups[i2]();
      }
      this.cleanups.length = 0;
      if (this.scopes) {
        for (i2 = 0, l2 = this.scopes.length; i2 < l2; i2++) {
          this.scopes[i2].stop(true);
        }
        this.scopes.length = 0;
      }
      if (!this.detached && this.parent && !fromParent) {
        const last = this.parent.scopes.pop();
        if (last && last !== this) {
          this.parent.scopes[this.index] = last;
          last.index = this.index;
        }
      }
      this.parent = void 0;
    }
  }
}
function effectScope(detached) {
  return new EffectScope(detached);
}
__name(effectScope, "effectScope");
function getCurrentScope() {
  return activeEffectScope;
}
__name(getCurrentScope, "getCurrentScope");
function onScopeDispose(fn, failSilently = false) {
  if (activeEffectScope) {
    activeEffectScope.cleanups.push(fn);
  } else if (false) {
    warn$4(
      `onScopeDispose() is called when there is no active effect scope to be associated with.`
    );
  }
}
__name(onScopeDispose, "onScopeDispose");
let activeSub;
const EffectFlags = {
  "ACTIVE": 1,
  "1": "ACTIVE",
  "RUNNING": 2,
  "2": "RUNNING",
  "TRACKING": 4,
  "4": "TRACKING",
  "NOTIFIED": 8,
  "8": "NOTIFIED",
  "DIRTY": 16,
  "16": "DIRTY",
  "ALLOW_RECURSE": 32,
  "32": "ALLOW_RECURSE",
  "PAUSED": 64,
  "64": "PAUSED"
};
const pausedQueueEffects = /* @__PURE__ */ new WeakSet();
class ReactiveEffect {
  static {
    __name(this, "ReactiveEffect");
  }
  constructor(fn) {
    this.fn = fn;
    this.deps = void 0;
    this.depsTail = void 0;
    this.flags = 1 | 4;
    this.next = void 0;
    this.cleanup = void 0;
    this.scheduler = void 0;
    if (activeEffectScope && activeEffectScope.active) {
      activeEffectScope.effects.push(this);
    }
  }
  pause() {
    this.flags |= 64;
  }
  resume() {
    if (this.flags & 64) {
      this.flags &= ~64;
      if (pausedQueueEffects.has(this)) {
        pausedQueueEffects.delete(this);
        this.trigger();
      }
    }
  }
  /**
   * @internal
   */
  notify() {
    if (this.flags & 2 && !(this.flags & 32)) {
      return;
    }
    if (!(this.flags & 8)) {
      batch(this);
    }
  }
  run() {
    if (!(this.flags & 1)) {
      return this.fn();
    }
    this.flags |= 2;
    cleanupEffect(this);
    prepareDeps(this);
    const prevEffect = activeSub;
    const prevShouldTrack = shouldTrack;
    activeSub = this;
    shouldTrack = true;
    try {
      return this.fn();
    } finally {
      if (false) {
        warn$4(
          "Active effect was not restored correctly - this is likely a Vue internal bug."
        );
      }
      cleanupDeps(this);
      activeSub = prevEffect;
      shouldTrack = prevShouldTrack;
      this.flags &= ~2;
    }
  }
  stop() {
    if (this.flags & 1) {
      for (let link2 = this.deps; link2; link2 = link2.nextDep) {
        removeSub(link2);
      }
      this.deps = this.depsTail = void 0;
      cleanupEffect(this);
      this.onStop && this.onStop();
      this.flags &= ~1;
    }
  }
  trigger() {
    if (this.flags & 64) {
      pausedQueueEffects.add(this);
    } else if (this.scheduler) {
      this.scheduler();
    } else {
      this.runIfDirty();
    }
  }
  /**
   * @internal
   */
  runIfDirty() {
    if (isDirty$1(this)) {
      this.run();
    }
  }
  get dirty() {
    return isDirty$1(this);
  }
}
let batchDepth = 0;
let batchedSub;
let batchedComputed;
function batch(sub, isComputed2 = false) {
  sub.flags |= 8;
  if (isComputed2) {
    sub.next = batchedComputed;
    batchedComputed = sub;
    return;
  }
  sub.next = batchedSub;
  batchedSub = sub;
}
__name(batch, "batch");
function startBatch() {
  batchDepth++;
}
__name(startBatch, "startBatch");
function endBatch() {
  if (--batchDepth > 0) {
    return;
  }
  if (batchedComputed) {
    let e2 = batchedComputed;
    batchedComputed = void 0;
    while (e2) {
      const next2 = e2.next;
      e2.next = void 0;
      e2.flags &= ~8;
      e2 = next2;
    }
  }
  let error2;
  while (batchedSub) {
    let e2 = batchedSub;
    batchedSub = void 0;
    while (e2) {
      const next2 = e2.next;
      e2.next = void 0;
      e2.flags &= ~8;
      if (e2.flags & 1) {
        try {
          ;
          e2.trigger();
        } catch (err) {
          if (!error2) error2 = err;
        }
      }
      e2 = next2;
    }
  }
  if (error2) throw error2;
}
__name(endBatch, "endBatch");
function prepareDeps(sub) {
  for (let link2 = sub.deps; link2; link2 = link2.nextDep) {
    link2.version = -1;
    link2.prevActiveLink = link2.dep.activeLink;
    link2.dep.activeLink = link2;
  }
}
__name(prepareDeps, "prepareDeps");
function cleanupDeps(sub) {
  let head;
  let tail = sub.depsTail;
  let link2 = tail;
  while (link2) {
    const prev2 = link2.prevDep;
    if (link2.version === -1) {
      if (link2 === tail) tail = prev2;
      removeSub(link2);
      removeDep(link2);
    } else {
      head = link2;
    }
    link2.dep.activeLink = link2.prevActiveLink;
    link2.prevActiveLink = void 0;
    link2 = prev2;
  }
  sub.deps = head;
  sub.depsTail = tail;
}
__name(cleanupDeps, "cleanupDeps");
function isDirty$1(sub) {
  for (let link2 = sub.deps; link2; link2 = link2.nextDep) {
    if (link2.dep.version !== link2.version || link2.dep.computed && (refreshComputed(link2.dep.computed) || link2.dep.version !== link2.version)) {
      return true;
    }
  }
  if (sub._dirty) {
    return true;
  }
  return false;
}
__name(isDirty$1, "isDirty$1");
function refreshComputed(computed2) {
  if (computed2.flags & 4 && !(computed2.flags & 16)) {
    return;
  }
  computed2.flags &= ~16;
  if (computed2.globalVersion === globalVersion) {
    return;
  }
  computed2.globalVersion = globalVersion;
  const dep = computed2.dep;
  computed2.flags |= 2;
  if (dep.version > 0 && !computed2.isSSR && computed2.deps && !isDirty$1(computed2)) {
    computed2.flags &= ~2;
    return;
  }
  const prevSub = activeSub;
  const prevShouldTrack = shouldTrack;
  activeSub = computed2;
  shouldTrack = true;
  try {
    prepareDeps(computed2);
    const value3 = computed2.fn(computed2._value);
    if (dep.version === 0 || hasChanged(value3, computed2._value)) {
      computed2._value = value3;
      dep.version++;
    }
  } catch (err) {
    dep.version++;
    throw err;
  } finally {
    activeSub = prevSub;
    shouldTrack = prevShouldTrack;
    cleanupDeps(computed2);
    computed2.flags &= ~2;
  }
}
__name(refreshComputed, "refreshComputed");
function removeSub(link2, soft = false) {
  const { dep, prevSub, nextSub } = link2;
  if (prevSub) {
    prevSub.nextSub = nextSub;
    link2.prevSub = void 0;
  }
  if (nextSub) {
    nextSub.prevSub = prevSub;
    link2.nextSub = void 0;
  }
  if (false) {
    dep.subsHead = nextSub;
  }
  if (dep.subs === link2) {
    dep.subs = prevSub;
    if (!prevSub && dep.computed) {
      dep.computed.flags &= ~4;
      for (let l2 = dep.computed.deps; l2; l2 = l2.nextDep) {
        removeSub(l2, true);
      }
    }
  }
  if (!soft && !--dep.sc && dep.map) {
    dep.map.delete(dep.key);
  }
}
__name(removeSub, "removeSub");
function removeDep(link2) {
  const { prevDep, nextDep } = link2;
  if (prevDep) {
    prevDep.nextDep = nextDep;
    link2.prevDep = void 0;
  }
  if (nextDep) {
    nextDep.prevDep = prevDep;
    link2.nextDep = void 0;
  }
}
__name(removeDep, "removeDep");
function effect(fn, options5) {
  if (fn.effect instanceof ReactiveEffect) {
    fn = fn.effect.fn;
  }
  const e2 = new ReactiveEffect(fn);
  if (options5) {
    extend$1(e2, options5);
  }
  try {
    e2.run();
  } catch (err) {
    e2.stop();
    throw err;
  }
  const runner = e2.run.bind(e2);
  runner.effect = e2;
  return runner;
}
__name(effect, "effect");
function stop(runner) {
  runner.effect.stop();
}
__name(stop, "stop");
let shouldTrack = true;
const trackStack = [];
function pauseTracking() {
  trackStack.push(shouldTrack);
  shouldTrack = false;
}
__name(pauseTracking, "pauseTracking");
function enableTracking() {
  trackStack.push(shouldTrack);
  shouldTrack = true;
}
__name(enableTracking, "enableTracking");
function resetTracking() {
  const last = trackStack.pop();
  shouldTrack = last === void 0 ? true : last;
}
__name(resetTracking, "resetTracking");
function onEffectCleanup(fn, failSilently = false) {
  if (activeSub instanceof ReactiveEffect) {
    activeSub.cleanup = fn;
  } else if (false) {
    warn$4(
      `onEffectCleanup() was called when there was no active effect to associate with.`
    );
  }
}
__name(onEffectCleanup, "onEffectCleanup");
function cleanupEffect(e2) {
  const { cleanup } = e2;
  e2.cleanup = void 0;
  if (cleanup) {
    const prevSub = activeSub;
    activeSub = void 0;
    try {
      cleanup();
    } finally {
      activeSub = prevSub;
    }
  }
}
__name(cleanupEffect, "cleanupEffect");
let globalVersion = 0;
let Link$3 = class Link2 {
  static {
    __name(this, "Link");
  }
  constructor(sub, dep) {
    this.sub = sub;
    this.dep = dep;
    this.version = dep.version;
    this.nextDep = this.prevDep = this.nextSub = this.prevSub = this.prevActiveLink = void 0;
  }
};
class Dep {
  static {
    __name(this, "Dep");
  }
  constructor(computed2) {
    this.computed = computed2;
    this.version = 0;
    this.activeLink = void 0;
    this.subs = void 0;
    this.map = void 0;
    this.key = void 0;
    this.sc = 0;
    if (false) {
      this.subsHead = void 0;
    }
  }
  track(debugInfo) {
    if (!activeSub || !shouldTrack || activeSub === this.computed) {
      return;
    }
    let link2 = this.activeLink;
    if (link2 === void 0 || link2.sub !== activeSub) {
      link2 = this.activeLink = new Link$3(activeSub, this);
      if (!activeSub.deps) {
        activeSub.deps = activeSub.depsTail = link2;
      } else {
        link2.prevDep = activeSub.depsTail;
        activeSub.depsTail.nextDep = link2;
        activeSub.depsTail = link2;
      }
      addSub(link2);
    } else if (link2.version === -1) {
      link2.version = this.version;
      if (link2.nextDep) {
        const next2 = link2.nextDep;
        next2.prevDep = link2.prevDep;
        if (link2.prevDep) {
          link2.prevDep.nextDep = next2;
        }
        link2.prevDep = activeSub.depsTail;
        link2.nextDep = void 0;
        activeSub.depsTail.nextDep = link2;
        activeSub.depsTail = link2;
        if (activeSub.deps === link2) {
          activeSub.deps = next2;
        }
      }
    }
    if (false) {
      activeSub.onTrack(
        extend$1(
          {
            effect: activeSub
          },
          debugInfo
        )
      );
    }
    return link2;
  }
  trigger(debugInfo) {
    this.version++;
    globalVersion++;
    this.notify(debugInfo);
  }
  notify(debugInfo) {
    startBatch();
    try {
      if (false) {
        for (let head = this.subsHead; head; head = head.nextSub) {
          if (head.sub.onTrigger && !(head.sub.flags & 8)) {
            head.sub.onTrigger(
              extend$1(
                {
                  effect: head.sub
                },
                debugInfo
              )
            );
          }
        }
      }
      for (let link2 = this.subs; link2; link2 = link2.prevSub) {
        if (link2.sub.notify()) {
          ;
          link2.sub.dep.notify();
        }
      }
    } finally {
      endBatch();
    }
  }
}
function addSub(link2) {
  link2.dep.sc++;
  if (link2.sub.flags & 4) {
    const computed2 = link2.dep.computed;
    if (computed2 && !link2.dep.subs) {
      computed2.flags |= 4 | 16;
      for (let l2 = computed2.deps; l2; l2 = l2.nextDep) {
        addSub(l2);
      }
    }
    const currentTail = link2.dep.subs;
    if (currentTail !== link2) {
      link2.prevSub = currentTail;
      if (currentTail) currentTail.nextSub = link2;
    }
    if (false) {
      link2.dep.subsHead = link2;
    }
    link2.dep.subs = link2;
  }
}
__name(addSub, "addSub");
const targetMap = /* @__PURE__ */ new WeakMap();
const ITERATE_KEY = Symbol(
  false ? "Object iterate" : ""
);
const MAP_KEY_ITERATE_KEY = Symbol(
  false ? "Map keys iterate" : ""
);
const ARRAY_ITERATE_KEY = Symbol(
  false ? "Array iterate" : ""
);
function track(target2, type, key) {
  if (shouldTrack && activeSub) {
    let depsMap = targetMap.get(target2);
    if (!depsMap) {
      targetMap.set(target2, depsMap = /* @__PURE__ */ new Map());
    }
    let dep = depsMap.get(key);
    if (!dep) {
      depsMap.set(key, dep = new Dep());
      dep.map = depsMap;
      dep.key = key;
    }
    if (false) {
      dep.track({
        target: target2,
        type,
        key
      });
    } else {
      dep.track();
    }
  }
}
__name(track, "track");
function trigger(target2, type, key, newValue2, oldValue, oldTarget) {
  const depsMap = targetMap.get(target2);
  if (!depsMap) {
    globalVersion++;
    return;
  }
  const run2 = /* @__PURE__ */ __name((dep) => {
    if (dep) {
      if (false) {
        dep.trigger({
          target: target2,
          type,
          key,
          newValue: newValue2,
          oldValue,
          oldTarget
        });
      } else {
        dep.trigger();
      }
    }
  }, "run");
  startBatch();
  if (type === "clear") {
    depsMap.forEach(run2);
  } else {
    const targetIsArray = isArray$b(target2);
    const isArrayIndex = targetIsArray && isIntegerKey(key);
    if (targetIsArray && key === "length") {
      const newLength = Number(newValue2);
      depsMap.forEach((dep, key2) => {
        if (key2 === "length" || key2 === ARRAY_ITERATE_KEY || !isSymbol$1(key2) && key2 >= newLength) {
          run2(dep);
        }
      });
    } else {
      if (key !== void 0 || depsMap.has(void 0)) {
        run2(depsMap.get(key));
      }
      if (isArrayIndex) {
        run2(depsMap.get(ARRAY_ITERATE_KEY));
      }
      switch (type) {
        case "add":
          if (!targetIsArray) {
            run2(depsMap.get(ITERATE_KEY));
            if (isMap$3(target2)) {
              run2(depsMap.get(MAP_KEY_ITERATE_KEY));
            }
          } else if (isArrayIndex) {
            run2(depsMap.get("length"));
          }
          break;
        case "delete":
          if (!targetIsArray) {
            run2(depsMap.get(ITERATE_KEY));
            if (isMap$3(target2)) {
              run2(depsMap.get(MAP_KEY_ITERATE_KEY));
            }
          }
          break;
        case "set":
          if (isMap$3(target2)) {
            run2(depsMap.get(ITERATE_KEY));
          }
          break;
      }
    }
  }
  endBatch();
}
__name(trigger, "trigger");
function getDepFromReactive(object, key) {
  const depMap = targetMap.get(object);
  return depMap && depMap.get(key);
}
__name(getDepFromReactive, "getDepFromReactive");
function reactiveReadArray(array) {
  const raw = toRaw(array);
  if (raw === array) return raw;
  track(raw, "iterate", ARRAY_ITERATE_KEY);
  return isShallow(array) ? raw : raw.map(toReactive$1);
}
__name(reactiveReadArray, "reactiveReadArray");
function shallowReadArray(arr) {
  track(arr = toRaw(arr), "iterate", ARRAY_ITERATE_KEY);
  return arr;
}
__name(shallowReadArray, "shallowReadArray");
const arrayInstrumentations = {
  __proto__: null,
  [Symbol.iterator]() {
    return iterator(this, Symbol.iterator, toReactive$1);
  },
  concat(...args) {
    return reactiveReadArray(this).concat(
      ...args.map((x2) => isArray$b(x2) ? reactiveReadArray(x2) : x2)
    );
  },
  entries() {
    return iterator(this, "entries", (value3) => {
      value3[1] = toReactive$1(value3[1]);
      return value3;
    });
  },
  every(fn, thisArg) {
    return apply$2(this, "every", fn, thisArg, void 0, arguments);
  },
  filter(fn, thisArg) {
    return apply$2(this, "filter", fn, thisArg, (v2) => v2.map(toReactive$1), arguments);
  },
  find(fn, thisArg) {
    return apply$2(this, "find", fn, thisArg, toReactive$1, arguments);
  },
  findIndex(fn, thisArg) {
    return apply$2(this, "findIndex", fn, thisArg, void 0, arguments);
  },
  findLast(fn, thisArg) {
    return apply$2(this, "findLast", fn, thisArg, toReactive$1, arguments);
  },
  findLastIndex(fn, thisArg) {
    return apply$2(this, "findLastIndex", fn, thisArg, void 0, arguments);
  },
  // flat, flatMap could benefit from ARRAY_ITERATE but are not straight-forward to implement
  forEach(fn, thisArg) {
    return apply$2(this, "forEach", fn, thisArg, void 0, arguments);
  },
  includes(...args) {
    return searchProxy(this, "includes", args);
  },
  indexOf(...args) {
    return searchProxy(this, "indexOf", args);
  },
  join(separator) {
    return reactiveReadArray(this).join(separator);
  },
  // keys() iterator only reads `length`, no optimisation required
  lastIndexOf(...args) {
    return searchProxy(this, "lastIndexOf", args);
  },
  map(fn, thisArg) {
    return apply$2(this, "map", fn, thisArg, void 0, arguments);
  },
  pop() {
    return noTracking(this, "pop");
  },
  push(...args) {
    return noTracking(this, "push", args);
  },
  reduce(fn, ...args) {
    return reduce(this, "reduce", fn, args);
  },
  reduceRight(fn, ...args) {
    return reduce(this, "reduceRight", fn, args);
  },
  shift() {
    return noTracking(this, "shift");
  },
  // slice could use ARRAY_ITERATE but also seems to beg for range tracking
  some(fn, thisArg) {
    return apply$2(this, "some", fn, thisArg, void 0, arguments);
  },
  splice(...args) {
    return noTracking(this, "splice", args);
  },
  toReversed() {
    return reactiveReadArray(this).toReversed();
  },
  toSorted(comparer) {
    return reactiveReadArray(this).toSorted(comparer);
  },
  toSpliced(...args) {
    return reactiveReadArray(this).toSpliced(...args);
  },
  unshift(...args) {
    return noTracking(this, "unshift", args);
  },
  values() {
    return iterator(this, "values", toReactive$1);
  }
};
function iterator(self2, method, wrapValue) {
  const arr = shallowReadArray(self2);
  const iter = arr[method]();
  if (arr !== self2 && !isShallow(self2)) {
    iter._next = iter.next;
    iter.next = () => {
      const result = iter._next();
      if (result.value) {
        result.value = wrapValue(result.value);
      }
      return result;
    };
  }
  return iter;
}
__name(iterator, "iterator");
const arrayProto$1 = Array.prototype;
function apply$2(self2, method, fn, thisArg, wrappedRetFn, args) {
  const arr = shallowReadArray(self2);
  const needsWrap = arr !== self2 && !isShallow(self2);
  const methodFn = arr[method];
  if (methodFn !== arrayProto$1[method]) {
    const result2 = methodFn.apply(self2, args);
    return needsWrap ? toReactive$1(result2) : result2;
  }
  let wrappedFn = fn;
  if (arr !== self2) {
    if (needsWrap) {
      wrappedFn = /* @__PURE__ */ __name(function(item3, index2) {
        return fn.call(this, toReactive$1(item3), index2, self2);
      }, "wrappedFn");
    } else if (fn.length > 2) {
      wrappedFn = /* @__PURE__ */ __name(function(item3, index2) {
        return fn.call(this, item3, index2, self2);
      }, "wrappedFn");
    }
  }
  const result = methodFn.call(arr, wrappedFn, thisArg);
  return needsWrap && wrappedRetFn ? wrappedRetFn(result) : result;
}
__name(apply$2, "apply$2");
function reduce(self2, method, fn, args) {
  const arr = shallowReadArray(self2);
  let wrappedFn = fn;
  if (arr !== self2) {
    if (!isShallow(self2)) {
      wrappedFn = /* @__PURE__ */ __name(function(acc, item3, index2) {
        return fn.call(this, acc, toReactive$1(item3), index2, self2);
      }, "wrappedFn");
    } else if (fn.length > 3) {
      wrappedFn = /* @__PURE__ */ __name(function(acc, item3, index2) {
        return fn.call(this, acc, item3, index2, self2);
      }, "wrappedFn");
    }
  }
  return arr[method](wrappedFn, ...args);
}
__name(reduce, "reduce");
function searchProxy(self2, method, args) {
  const arr = toRaw(self2);
  track(arr, "iterate", ARRAY_ITERATE_KEY);
  const res = arr[method](...args);
  if ((res === -1 || res === false) && isProxy(args[0])) {
    args[0] = toRaw(args[0]);
    return arr[method](...args);
  }
  return res;
}
__name(searchProxy, "searchProxy");
function noTracking(self2, method, args = []) {
  pauseTracking();
  startBatch();
  const res = toRaw(self2)[method].apply(self2, args);
  endBatch();
  resetTracking();
  return res;
}
__name(noTracking, "noTracking");
const isNonTrackableKeys = /* @__PURE__ */ makeMap(`__proto__,__v_isRef,__isVue`);
const builtInSymbols = new Set(
  /* @__PURE__ */ Object.getOwnPropertyNames(Symbol).filter((key) => key !== "arguments" && key !== "caller").map((key) => Symbol[key]).filter(isSymbol$1)
);
function hasOwnProperty$c(key) {
  if (!isSymbol$1(key)) key = String(key);
  const obj = toRaw(this);
  track(obj, "has", key);
  return obj.hasOwnProperty(key);
}
__name(hasOwnProperty$c, "hasOwnProperty$c");
class BaseReactiveHandler {
  static {
    __name(this, "BaseReactiveHandler");
  }
  constructor(_isReadonly = false, _isShallow = false) {
    this._isReadonly = _isReadonly;
    this._isShallow = _isShallow;
  }
  get(target2, key, receiver) {
    if (key === "__v_skip") return target2["__v_skip"];
    const isReadonly2 = this._isReadonly, isShallow2 = this._isShallow;
    if (key === "__v_isReactive") {
      return !isReadonly2;
    } else if (key === "__v_isReadonly") {
      return isReadonly2;
    } else if (key === "__v_isShallow") {
      return isShallow2;
    } else if (key === "__v_raw") {
      if (receiver === (isReadonly2 ? isShallow2 ? shallowReadonlyMap : readonlyMap : isShallow2 ? shallowReactiveMap : reactiveMap).get(target2) || // receiver is not the reactive proxy, but has the same prototype
      // this means the receiver is a user proxy of the reactive proxy
      Object.getPrototypeOf(target2) === Object.getPrototypeOf(receiver)) {
        return target2;
      }
      return;
    }
    const targetIsArray = isArray$b(target2);
    if (!isReadonly2) {
      let fn;
      if (targetIsArray && (fn = arrayInstrumentations[key])) {
        return fn;
      }
      if (key === "hasOwnProperty") {
        return hasOwnProperty$c;
      }
    }
    const res = Reflect.get(
      target2,
      key,
      // if this is a proxy wrapping a ref, return methods using the raw ref
      // as receiver so that we don't have to call `toRaw` on the ref in all
      // its class methods
      isRef(target2) ? target2 : receiver
    );
    if (isSymbol$1(key) ? builtInSymbols.has(key) : isNonTrackableKeys(key)) {
      return res;
    }
    if (!isReadonly2) {
      track(target2, "get", key);
    }
    if (isShallow2) {
      return res;
    }
    if (isRef(res)) {
      return targetIsArray && isIntegerKey(key) ? res : res.value;
    }
    if (isObject$f(res)) {
      return isReadonly2 ? readonly(res) : reactive(res);
    }
    return res;
  }
}
class MutableReactiveHandler extends BaseReactiveHandler {
  static {
    __name(this, "MutableReactiveHandler");
  }
  constructor(isShallow2 = false) {
    super(false, isShallow2);
  }
  set(target2, key, value3, receiver) {
    let oldValue = target2[key];
    if (!this._isShallow) {
      const isOldValueReadonly = isReadonly(oldValue);
      if (!isShallow(value3) && !isReadonly(value3)) {
        oldValue = toRaw(oldValue);
        value3 = toRaw(value3);
      }
      if (!isArray$b(target2) && isRef(oldValue) && !isRef(value3)) {
        if (isOldValueReadonly) {
          return false;
        } else {
          oldValue.value = value3;
          return true;
        }
      }
    }
    const hadKey = isArray$b(target2) && isIntegerKey(key) ? Number(key) < target2.length : hasOwn$3(target2, key);
    const result = Reflect.set(
      target2,
      key,
      value3,
      isRef(target2) ? target2 : receiver
    );
    if (target2 === toRaw(receiver)) {
      if (!hadKey) {
        trigger(target2, "add", key, value3);
      } else if (hasChanged(value3, oldValue)) {
        trigger(target2, "set", key, value3, oldValue);
      }
    }
    return result;
  }
  deleteProperty(target2, key) {
    const hadKey = hasOwn$3(target2, key);
    const oldValue = target2[key];
    const result = Reflect.deleteProperty(target2, key);
    if (result && hadKey) {
      trigger(target2, "delete", key, void 0, oldValue);
    }
    return result;
  }
  has(target2, key) {
    const result = Reflect.has(target2, key);
    if (!isSymbol$1(key) || !builtInSymbols.has(key)) {
      track(target2, "has", key);
    }
    return result;
  }
  ownKeys(target2) {
    track(
      target2,
      "iterate",
      isArray$b(target2) ? "length" : ITERATE_KEY
    );
    return Reflect.ownKeys(target2);
  }
}
class ReadonlyReactiveHandler extends BaseReactiveHandler {
  static {
    __name(this, "ReadonlyReactiveHandler");
  }
  constructor(isShallow2 = false) {
    super(true, isShallow2);
  }
  set(target2, key) {
    if (false) {
      warn$4(
        `Set operation on key "${String(key)}" failed: target is readonly.`,
        target2
      );
    }
    return true;
  }
  deleteProperty(target2, key) {
    if (false) {
      warn$4(
        `Delete operation on key "${String(key)}" failed: target is readonly.`,
        target2
      );
    }
    return true;
  }
}
const mutableHandlers = /* @__PURE__ */ new MutableReactiveHandler();
const readonlyHandlers = /* @__PURE__ */ new ReadonlyReactiveHandler();
const shallowReactiveHandlers = /* @__PURE__ */ new MutableReactiveHandler(true);
const shallowReadonlyHandlers = /* @__PURE__ */ new ReadonlyReactiveHandler(true);
const toShallow = /* @__PURE__ */ __name((value3) => value3, "toShallow");
const getProto = /* @__PURE__ */ __name((v2) => Reflect.getPrototypeOf(v2), "getProto");
function createIterableMethod(method, isReadonly2, isShallow2) {
  return function(...args) {
    const target2 = this["__v_raw"];
    const rawTarget = toRaw(target2);
    const targetIsMap = isMap$3(rawTarget);
    const isPair = method === "entries" || method === Symbol.iterator && targetIsMap;
    const isKeyOnly = method === "keys" && targetIsMap;
    const innerIterator = target2[method](...args);
    const wrap2 = isShallow2 ? toShallow : isReadonly2 ? toReadonly : toReactive$1;
    !isReadonly2 && track(
      rawTarget,
      "iterate",
      isKeyOnly ? MAP_KEY_ITERATE_KEY : ITERATE_KEY
    );
    return {
      // iterator protocol
      next() {
        const { value: value3, done } = innerIterator.next();
        return done ? { value: value3, done } : {
          value: isPair ? [wrap2(value3[0]), wrap2(value3[1])] : wrap2(value3),
          done
        };
      },
      // iterable protocol
      [Symbol.iterator]() {
        return this;
      }
    };
  };
}
__name(createIterableMethod, "createIterableMethod");
function createReadonlyMethod(type) {
  return function(...args) {
    if (false) {
      const key = args[0] ? `on key "${args[0]}" ` : ``;
      warn$4(
        `${capitalize$1(type)} operation ${key}failed: target is readonly.`,
        toRaw(this)
      );
    }
    return type === "delete" ? false : type === "clear" ? void 0 : this;
  };
}
__name(createReadonlyMethod, "createReadonlyMethod");
function createInstrumentations(readonly2, shallow) {
  const instrumentations = {
    get(key) {
      const target2 = this["__v_raw"];
      const rawTarget = toRaw(target2);
      const rawKey = toRaw(key);
      if (!readonly2) {
        if (hasChanged(key, rawKey)) {
          track(rawTarget, "get", key);
        }
        track(rawTarget, "get", rawKey);
      }
      const { has: has2 } = getProto(rawTarget);
      const wrap2 = shallow ? toShallow : readonly2 ? toReadonly : toReactive$1;
      if (has2.call(rawTarget, key)) {
        return wrap2(target2.get(key));
      } else if (has2.call(rawTarget, rawKey)) {
        return wrap2(target2.get(rawKey));
      } else if (target2 !== rawTarget) {
        target2.get(key);
      }
    },
    get size() {
      const target2 = this["__v_raw"];
      !readonly2 && track(toRaw(target2), "iterate", ITERATE_KEY);
      return Reflect.get(target2, "size", target2);
    },
    has(key) {
      const target2 = this["__v_raw"];
      const rawTarget = toRaw(target2);
      const rawKey = toRaw(key);
      if (!readonly2) {
        if (hasChanged(key, rawKey)) {
          track(rawTarget, "has", key);
        }
        track(rawTarget, "has", rawKey);
      }
      return key === rawKey ? target2.has(key) : target2.has(key) || target2.has(rawKey);
    },
    forEach(callback, thisArg) {
      const observed = this;
      const target2 = observed["__v_raw"];
      const rawTarget = toRaw(target2);
      const wrap2 = shallow ? toShallow : readonly2 ? toReadonly : toReactive$1;
      !readonly2 && track(rawTarget, "iterate", ITERATE_KEY);
      return target2.forEach((value3, key) => {
        return callback.call(thisArg, wrap2(value3), wrap2(key), observed);
      });
    }
  };
  extend$1(
    instrumentations,
    readonly2 ? {
      add: createReadonlyMethod("add"),
      set: createReadonlyMethod("set"),
      delete: createReadonlyMethod("delete"),
      clear: createReadonlyMethod("clear")
    } : {
      add(value3) {
        if (!shallow && !isShallow(value3) && !isReadonly(value3)) {
          value3 = toRaw(value3);
        }
        const target2 = toRaw(this);
        const proto = getProto(target2);
        const hadKey = proto.has.call(target2, value3);
        if (!hadKey) {
          target2.add(value3);
          trigger(target2, "add", value3, value3);
        }
        return this;
      },
      set(key, value3) {
        if (!shallow && !isShallow(value3) && !isReadonly(value3)) {
          value3 = toRaw(value3);
        }
        const target2 = toRaw(this);
        const { has: has2, get: get3 } = getProto(target2);
        let hadKey = has2.call(target2, key);
        if (!hadKey) {
          key = toRaw(key);
          hadKey = has2.call(target2, key);
        } else if (false) {
          checkIdentityKeys(target2, has2, key);
        }
        const oldValue = get3.call(target2, key);
        target2.set(key, value3);
        if (!hadKey) {
          trigger(target2, "add", key, value3);
        } else if (hasChanged(value3, oldValue)) {
          trigger(target2, "set", key, value3, oldValue);
        }
        return this;
      },
      delete(key) {
        const target2 = toRaw(this);
        const { has: has2, get: get3 } = getProto(target2);
        let hadKey = has2.call(target2, key);
        if (!hadKey) {
          key = toRaw(key);
          hadKey = has2.call(target2, key);
        } else if (false) {
          checkIdentityKeys(target2, has2, key);
        }
        const oldValue = get3 ? get3.call(target2, key) : void 0;
        const result = target2.delete(key);
        if (hadKey) {
          trigger(target2, "delete", key, void 0, oldValue);
        }
        return result;
      },
      clear() {
        const target2 = toRaw(this);
        const hadItems = target2.size !== 0;
        const oldTarget = false ? isMap$3(target2) ? new Map(target2) : new Set(target2) : void 0;
        const result = target2.clear();
        if (hadItems) {
          trigger(
            target2,
            "clear",
            void 0,
            void 0,
            oldTarget
          );
        }
        return result;
      }
    }
  );
  const iteratorMethods = [
    "keys",
    "values",
    "entries",
    Symbol.iterator
  ];
  iteratorMethods.forEach((method) => {
    instrumentations[method] = createIterableMethod(method, readonly2, shallow);
  });
  return instrumentations;
}
__name(createInstrumentations, "createInstrumentations");
function createInstrumentationGetter(isReadonly2, shallow) {
  const instrumentations = createInstrumentations(isReadonly2, shallow);
  return (target2, key, receiver) => {
    if (key === "__v_isReactive") {
      return !isReadonly2;
    } else if (key === "__v_isReadonly") {
      return isReadonly2;
    } else if (key === "__v_raw") {
      return target2;
    }
    return Reflect.get(
      hasOwn$3(instrumentations, key) && key in target2 ? instrumentations : target2,
      key,
      receiver
    );
  };
}
__name(createInstrumentationGetter, "createInstrumentationGetter");
const mutableCollectionHandlers = {
  get: /* @__PURE__ */ createInstrumentationGetter(false, false)
};
const shallowCollectionHandlers = {
  get: /* @__PURE__ */ createInstrumentationGetter(false, true)
};
const readonlyCollectionHandlers = {
  get: /* @__PURE__ */ createInstrumentationGetter(true, false)
};
const shallowReadonlyCollectionHandlers = {
  get: /* @__PURE__ */ createInstrumentationGetter(true, true)
};
function checkIdentityKeys(target2, has2, key) {
  const rawKey = toRaw(key);
  if (rawKey !== key && has2.call(target2, rawKey)) {
    const type = toRawType(target2);
    warn$4(
      `Reactive ${type} contains both the raw and reactive versions of the same object${type === `Map` ? ` as keys` : ``}, which can lead to inconsistencies. Avoid differentiating between the raw and reactive versions of an object and only use the reactive version if possible.`
    );
  }
}
__name(checkIdentityKeys, "checkIdentityKeys");
const reactiveMap = /* @__PURE__ */ new WeakMap();
const shallowReactiveMap = /* @__PURE__ */ new WeakMap();
const readonlyMap = /* @__PURE__ */ new WeakMap();
const shallowReadonlyMap = /* @__PURE__ */ new WeakMap();
function targetTypeMap(rawType) {
  switch (rawType) {
    case "Object":
    case "Array":
      return 1;
    case "Map":
    case "Set":
    case "WeakMap":
    case "WeakSet":
      return 2;
    default:
      return 0;
  }
}
__name(targetTypeMap, "targetTypeMap");
function getTargetType(value3) {
  return value3["__v_skip"] || !Object.isExtensible(value3) ? 0 : targetTypeMap(toRawType(value3));
}
__name(getTargetType, "getTargetType");
function reactive(target2) {
  if (isReadonly(target2)) {
    return target2;
  }
  return createReactiveObject(
    target2,
    false,
    mutableHandlers,
    mutableCollectionHandlers,
    reactiveMap
  );
}
__name(reactive, "reactive");
function shallowReactive(target2) {
  return createReactiveObject(
    target2,
    false,
    shallowReactiveHandlers,
    shallowCollectionHandlers,
    shallowReactiveMap
  );
}
__name(shallowReactive, "shallowReactive");
function readonly(target2) {
  return createReactiveObject(
    target2,
    true,
    readonlyHandlers,
    readonlyCollectionHandlers,
    readonlyMap
  );
}
__name(readonly, "readonly");
function shallowReadonly(target2) {
  return createReactiveObject(
    target2,
    true,
    shallowReadonlyHandlers,
    shallowReadonlyCollectionHandlers,
    shallowReadonlyMap
  );
}
__name(shallowReadonly, "shallowReadonly");
function createReactiveObject(target2, isReadonly2, baseHandlers, collectionHandlers, proxyMap) {
  if (!isObject$f(target2)) {
    if (false) {
      warn$4(
        `value cannot be made ${isReadonly2 ? "readonly" : "reactive"}: ${String(
          target2
        )}`
      );
    }
    return target2;
  }
  if (target2["__v_raw"] && !(isReadonly2 && target2["__v_isReactive"])) {
    return target2;
  }
  const existingProxy = proxyMap.get(target2);
  if (existingProxy) {
    return existingProxy;
  }
  const targetType = getTargetType(target2);
  if (targetType === 0) {
    return target2;
  }
  const proxy = new Proxy(
    target2,
    targetType === 2 ? collectionHandlers : baseHandlers
  );
  proxyMap.set(target2, proxy);
  return proxy;
}
__name(createReactiveObject, "createReactiveObject");
function isReactive(value3) {
  if (isReadonly(value3)) {
    return isReactive(value3["__v_raw"]);
  }
  return !!(value3 && value3["__v_isReactive"]);
}
__name(isReactive, "isReactive");
function isReadonly(value3) {
  return !!(value3 && value3["__v_isReadonly"]);
}
__name(isReadonly, "isReadonly");
function isShallow(value3) {
  return !!(value3 && value3["__v_isShallow"]);
}
__name(isShallow, "isShallow");
function isProxy(value3) {
  return value3 ? !!value3["__v_raw"] : false;
}
__name(isProxy, "isProxy");
function toRaw(observed) {
  const raw = observed && observed["__v_raw"];
  return raw ? toRaw(raw) : observed;
}
__name(toRaw, "toRaw");
function markRaw(value3) {
  if (!hasOwn$3(value3, "__v_skip") && Object.isExtensible(value3)) {
    def(value3, "__v_skip", true);
  }
  return value3;
}
__name(markRaw, "markRaw");
const toReactive$1 = /* @__PURE__ */ __name((value3) => isObject$f(value3) ? reactive(value3) : value3, "toReactive$1");
const toReadonly = /* @__PURE__ */ __name((value3) => isObject$f(value3) ? readonly(value3) : value3, "toReadonly");
function isRef(r2) {
  return r2 ? r2["__v_isRef"] === true : false;
}
__name(isRef, "isRef");
function ref(value3) {
  return createRef(value3, false);
}
__name(ref, "ref");
function shallowRef(value3) {
  return createRef(value3, true);
}
__name(shallowRef, "shallowRef");
function createRef(rawValue, shallow) {
  if (isRef(rawValue)) {
    return rawValue;
  }
  return new RefImpl(rawValue, shallow);
}
__name(createRef, "createRef");
class RefImpl {
  static {
    __name(this, "RefImpl");
  }
  constructor(value3, isShallow2) {
    this.dep = new Dep();
    this["__v_isRef"] = true;
    this["__v_isShallow"] = false;
    this._rawValue = isShallow2 ? value3 : toRaw(value3);
    this._value = isShallow2 ? value3 : toReactive$1(value3);
    this["__v_isShallow"] = isShallow2;
  }
  get value() {
    if (false) {
      this.dep.track({
        target: this,
        type: "get",
        key: "value"
      });
    } else {
      this.dep.track();
    }
    return this._value;
  }
  set value(newValue2) {
    const oldValue = this._rawValue;
    const useDirectValue = this["__v_isShallow"] || isShallow(newValue2) || isReadonly(newValue2);
    newValue2 = useDirectValue ? newValue2 : toRaw(newValue2);
    if (hasChanged(newValue2, oldValue)) {
      this._rawValue = newValue2;
      this._value = useDirectValue ? newValue2 : toReactive$1(newValue2);
      if (false) {
        this.dep.trigger({
          target: this,
          type: "set",
          key: "value",
          newValue: newValue2,
          oldValue
        });
      } else {
        this.dep.trigger();
      }
    }
  }
}
function triggerRef(ref2) {
  if (ref2.dep) {
    if (false) {
      ref2.dep.trigger({
        target: ref2,
        type: "set",
        key: "value",
        newValue: ref2._value
      });
    } else {
      ref2.dep.trigger();
    }
  }
}
__name(triggerRef, "triggerRef");
function unref(ref2) {
  return isRef(ref2) ? ref2.value : ref2;
}
__name(unref, "unref");
function toValue$4(source) {
  return isFunction$c(source) ? source() : unref(source);
}
__name(toValue$4, "toValue$4");
const shallowUnwrapHandlers = {
  get: /* @__PURE__ */ __name((target2, key, receiver) => key === "__v_raw" ? target2 : unref(Reflect.get(target2, key, receiver)), "get"),
  set: /* @__PURE__ */ __name((target2, key, value3, receiver) => {
    const oldValue = target2[key];
    if (isRef(oldValue) && !isRef(value3)) {
      oldValue.value = value3;
      return true;
    } else {
      return Reflect.set(target2, key, value3, receiver);
    }
  }, "set")
};
function proxyRefs(objectWithRefs) {
  return isReactive(objectWithRefs) ? objectWithRefs : new Proxy(objectWithRefs, shallowUnwrapHandlers);
}
__name(proxyRefs, "proxyRefs");
class CustomRefImpl {
  static {
    __name(this, "CustomRefImpl");
  }
  constructor(factory) {
    this["__v_isRef"] = true;
    this._value = void 0;
    const dep = this.dep = new Dep();
    const { get: get3, set: set3 } = factory(dep.track.bind(dep), dep.trigger.bind(dep));
    this._get = get3;
    this._set = set3;
  }
  get value() {
    return this._value = this._get();
  }
  set value(newVal) {
    this._set(newVal);
  }
}
function customRef(factory) {
  return new CustomRefImpl(factory);
}
__name(customRef, "customRef");
function toRefs$1(object) {
  if (false) {
    warn$4(`toRefs() expects a reactive object but received a plain one.`);
  }
  const ret = isArray$b(object) ? new Array(object.length) : {};
  for (const key in object) {
    ret[key] = propertyToRef(object, key);
  }
  return ret;
}
__name(toRefs$1, "toRefs$1");
class ObjectRefImpl {
  static {
    __name(this, "ObjectRefImpl");
  }
  constructor(_object, _key, _defaultValue) {
    this._object = _object;
    this._key = _key;
    this._defaultValue = _defaultValue;
    this["__v_isRef"] = true;
    this._value = void 0;
  }
  get value() {
    const val = this._object[this._key];
    return this._value = val === void 0 ? this._defaultValue : val;
  }
  set value(newVal) {
    this._object[this._key] = newVal;
  }
  get dep() {
    return getDepFromReactive(toRaw(this._object), this._key);
  }
}
class GetterRefImpl {
  static {
    __name(this, "GetterRefImpl");
  }
  constructor(_getter) {
    this._getter = _getter;
    this["__v_isRef"] = true;
    this["__v_isReadonly"] = true;
    this._value = void 0;
  }
  get value() {
    return this._value = this._getter();
  }
}
function toRef$1(source, key, defaultValue2) {
  if (isRef(source)) {
    return source;
  } else if (isFunction$c(source)) {
    return new GetterRefImpl(source);
  } else if (isObject$f(source) && arguments.length > 1) {
    return propertyToRef(source, key, defaultValue2);
  } else {
    return ref(source);
  }
}
__name(toRef$1, "toRef$1");
function propertyToRef(source, key, defaultValue2) {
  const val = source[key];
  return isRef(val) ? val : new ObjectRefImpl(source, key, defaultValue2);
}
__name(propertyToRef, "propertyToRef");
class ComputedRefImpl {
  static {
    __name(this, "ComputedRefImpl");
  }
  constructor(fn, setter, isSSR) {
    this.fn = fn;
    this.setter = setter;
    this._value = void 0;
    this.dep = new Dep(this);
    this.__v_isRef = true;
    this.deps = void 0;
    this.depsTail = void 0;
    this.flags = 16;
    this.globalVersion = globalVersion - 1;
    this.next = void 0;
    this.effect = this;
    this["__v_isReadonly"] = !setter;
    this.isSSR = isSSR;
  }
  /**
   * @internal
   */
  notify() {
    this.flags |= 16;
    if (!(this.flags & 8) && // avoid infinite self recursion
    activeSub !== this) {
      batch(this, true);
      return true;
    } else if (false) ;
  }
  get value() {
    const link2 = false ? this.dep.track({
      target: this,
      type: "get",
      key: "value"
    }) : this.dep.track();
    refreshComputed(this);
    if (link2) {
      link2.version = this.dep.version;
    }
    return this._value;
  }
  set value(newValue2) {
    if (this.setter) {
      this.setter(newValue2);
    } else if (false) {
      warn$4("Write operation failed: computed value is readonly");
    }
  }
}
function computed$1(getterOrOptions, debugOptions, isSSR = false) {
  let getter;
  let setter;
  if (isFunction$c(getterOrOptions)) {
    getter = getterOrOptions;
  } else {
    getter = getterOrOptions.get;
    setter = getterOrOptions.set;
  }
  const cRef = new ComputedRefImpl(getter, setter, isSSR);
  if (false) {
    cRef.onTrack = debugOptions.onTrack;
    cRef.onTrigger = debugOptions.onTrigger;
  }
  return cRef;
}
__name(computed$1, "computed$1");
const TrackOpTypes = {
  "GET": "get",
  "HAS": "has",
  "ITERATE": "iterate"
};
const TriggerOpTypes = {
  "SET": "set",
  "ADD": "add",
  "DELETE": "delete",
  "CLEAR": "clear"
};
const ReactiveFlags = {
  "SKIP": "__v_skip",
  "IS_REACTIVE": "__v_isReactive",
  "IS_READONLY": "__v_isReadonly",
  "IS_SHALLOW": "__v_isShallow",
  "RAW": "__v_raw",
  "IS_REF": "__v_isRef"
};
const WatchErrorCodes = {
  "WATCH_GETTER": 2,
  "2": "WATCH_GETTER",
  "WATCH_CALLBACK": 3,
  "3": "WATCH_CALLBACK",
  "WATCH_CLEANUP": 4,
  "4": "WATCH_CLEANUP"
};
const INITIAL_WATCHER_VALUE = {};
const cleanupMap = /* @__PURE__ */ new WeakMap();
let activeWatcher = void 0;
function getCurrentWatcher() {
  return activeWatcher;
}
__name(getCurrentWatcher, "getCurrentWatcher");
function onWatcherCleanup(cleanupFn, failSilently = false, owner = activeWatcher) {
  if (owner) {
    let cleanups = cleanupMap.get(owner);
    if (!cleanups) cleanupMap.set(owner, cleanups = []);
    cleanups.push(cleanupFn);
  } else if (false) {
    warn$4(
      `onWatcherCleanup() was called when there was no active watcher to associate with.`
    );
  }
}
__name(onWatcherCleanup, "onWatcherCleanup");
function watch$1(source, cb, options5 = EMPTY_OBJ) {
  const { immediate, deep, once: once2, scheduler, augmentJob, call } = options5;
  const warnInvalidSource = /* @__PURE__ */ __name((s2) => {
    (options5.onWarn || warn$4)(
      `Invalid watch source: `,
      s2,
      `A watch source can only be a getter/effect function, a ref, a reactive object, or an array of these types.`
    );
  }, "warnInvalidSource");
  const reactiveGetter = /* @__PURE__ */ __name((source2) => {
    if (deep) return source2;
    if (isShallow(source2) || deep === false || deep === 0)
      return traverse(source2, 1);
    return traverse(source2);
  }, "reactiveGetter");
  let effect2;
  let getter;
  let cleanup;
  let boundCleanup;
  let forceTrigger = false;
  let isMultiSource = false;
  if (isRef(source)) {
    getter = /* @__PURE__ */ __name(() => source.value, "getter");
    forceTrigger = isShallow(source);
  } else if (isReactive(source)) {
    getter = /* @__PURE__ */ __name(() => reactiveGetter(source), "getter");
    forceTrigger = true;
  } else if (isArray$b(source)) {
    isMultiSource = true;
    forceTrigger = source.some((s2) => isReactive(s2) || isShallow(s2));
    getter = /* @__PURE__ */ __name(() => source.map((s2) => {
      if (isRef(s2)) {
        return s2.value;
      } else if (isReactive(s2)) {
        return reactiveGetter(s2);
      } else if (isFunction$c(s2)) {
        return call ? call(s2, 2) : s2();
      } else {
      }
    }), "getter");
  } else if (isFunction$c(source)) {
    if (cb) {
      getter = call ? () => call(source, 2) : source;
    } else {
      getter = /* @__PURE__ */ __name(() => {
        if (cleanup) {
          pauseTracking();
          try {
            cleanup();
          } finally {
            resetTracking();
          }
        }
        const currentEffect = activeWatcher;
        activeWatcher = effect2;
        try {
          return call ? call(source, 3, [boundCleanup]) : source(boundCleanup);
        } finally {
          activeWatcher = currentEffect;
        }
      }, "getter");
    }
  } else {
    getter = NOOP;
  }
  if (cb && deep) {
    const baseGetter = getter;
    const depth = deep === true ? Infinity : deep;
    getter = /* @__PURE__ */ __name(() => traverse(baseGetter(), depth), "getter");
  }
  const scope = getCurrentScope();
  const watchHandle = /* @__PURE__ */ __name(() => {
    effect2.stop();
    if (scope && scope.active) {
      remove$2(scope.effects, effect2);
    }
  }, "watchHandle");
  if (once2 && cb) {
    const _cb = cb;
    cb = /* @__PURE__ */ __name((...args) => {
      _cb(...args);
      watchHandle();
    }, "cb");
  }
  let oldValue = isMultiSource ? new Array(source.length).fill(INITIAL_WATCHER_VALUE) : INITIAL_WATCHER_VALUE;
  const job = /* @__PURE__ */ __name((immediateFirstRun) => {
    if (!(effect2.flags & 1) || !effect2.dirty && !immediateFirstRun) {
      return;
    }
    if (cb) {
      const newValue2 = effect2.run();
      if (deep || forceTrigger || (isMultiSource ? newValue2.some((v2, i2) => hasChanged(v2, oldValue[i2])) : hasChanged(newValue2, oldValue))) {
        if (cleanup) {
          cleanup();
        }
        const currentWatcher = activeWatcher;
        activeWatcher = effect2;
        try {
          const args = [
            newValue2,
            // pass undefined as the old value when it's changed for the first time
            oldValue === INITIAL_WATCHER_VALUE ? void 0 : isMultiSource && oldValue[0] === INITIAL_WATCHER_VALUE ? [] : oldValue,
            boundCleanup
          ];
          call ? call(cb, 3, args) : (
            // @ts-expect-error
            cb(...args)
          );
          oldValue = newValue2;
        } finally {
          activeWatcher = currentWatcher;
        }
      }
    } else {
      effect2.run();
    }
  }, "job");
  if (augmentJob) {
    augmentJob(job);
  }
  effect2 = new ReactiveEffect(getter);
  effect2.scheduler = scheduler ? () => scheduler(job, false) : job;
  boundCleanup = /* @__PURE__ */ __name((fn) => onWatcherCleanup(fn, false, effect2), "boundCleanup");
  cleanup = effect2.onStop = () => {
    const cleanups = cleanupMap.get(effect2);
    if (cleanups) {
      if (call) {
        call(cleanups, 4);
      } else {
        for (const cleanup2 of cleanups) cleanup2();
      }
      cleanupMap.delete(effect2);
    }
  };
  if (false) {
    effect2.onTrack = options5.onTrack;
    effect2.onTrigger = options5.onTrigger;
  }
  if (cb) {
    if (immediate) {
      job(true);
    } else {
      oldValue = effect2.run();
    }
  } else if (scheduler) {
    scheduler(job.bind(null, true), true);
  } else {
    effect2.run();
  }
  watchHandle.pause = effect2.pause.bind(effect2);
  watchHandle.resume = effect2.resume.bind(effect2);
  watchHandle.stop = watchHandle;
  return watchHandle;
}
__name(watch$1, "watch$1");
function traverse(value3, depth = Infinity, seen2) {
  if (depth <= 0 || !isObject$f(value3) || value3["__v_skip"]) {
    return value3;
  }
  seen2 = seen2 || /* @__PURE__ */ new Set();
  if (seen2.has(value3)) {
    return value3;
  }
  seen2.add(value3);
  depth--;
  if (isRef(value3)) {
    traverse(value3.value, depth, seen2);
  } else if (isArray$b(value3)) {
    for (let i2 = 0; i2 < value3.length; i2++) {
      traverse(value3[i2], depth, seen2);
    }
  } else if (isSet$3(value3) || isMap$3(value3)) {
    value3.forEach((v2) => {
      traverse(v2, depth, seen2);
    });
  } else if (isPlainObject$4(value3)) {
    for (const key in value3) {
      traverse(value3[key], depth, seen2);
    }
    for (const key of Object.getOwnPropertySymbols(value3)) {
      if (Object.prototype.propertyIsEnumerable.call(value3, key)) {
        traverse(value3[key], depth, seen2);
      }
    }
  }
  return value3;
}
__name(traverse, "traverse");
/**
* @vue/runtime-core v3.5.13
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/
const stack = [];
function pushWarningContext(vnode) {
  stack.push(vnode);
}
__name(pushWarningContext, "pushWarningContext");
function popWarningContext() {
  stack.pop();
}
__name(popWarningContext, "popWarningContext");
let isWarning = false;
function warn$1$1(msg, ...args) {
  if (isWarning) return;
  isWarning = true;
  pauseTracking();
  const instance = stack.length ? stack[stack.length - 1].component : null;
  const appWarnHandler = instance && instance.appContext.config.warnHandler;
  const trace = getComponentTrace();
  if (appWarnHandler) {
    callWithErrorHandling(
      appWarnHandler,
      instance,
      11,
      [
        // eslint-disable-next-line no-restricted-syntax
        msg + args.map((a2) => {
          var _a2, _b;
          return (_b = (_a2 = a2.toString) == null ? void 0 : _a2.call(a2)) != null ? _b : JSON.stringify(a2);
        }).join(""),
        instance && instance.proxy,
        trace.map(
          ({ vnode }) => `at <${formatComponentName(instance, vnode.type)}>`
        ).join("\n"),
        trace
      ]
    );
  } else {
    const warnArgs = [`[Vue warn]: ${msg}`, ...args];
    if (trace.length && // avoid spamming console during tests
    true) {
      warnArgs.push(`
`, ...formatTrace(trace));
    }
    console.warn(...warnArgs);
  }
  resetTracking();
  isWarning = false;
}
__name(warn$1$1, "warn$1$1");
function getComponentTrace() {
  let currentVNode = stack[stack.length - 1];
  if (!currentVNode) {
    return [];
  }
  const normalizedStack = [];
  while (currentVNode) {
    const last = normalizedStack[0];
    if (last && last.vnode === currentVNode) {
      last.recurseCount++;
    } else {
      normalizedStack.push({
        vnode: currentVNode,
        recurseCount: 0
      });
    }
    const parentInstance = currentVNode.component && currentVNode.component.parent;
    currentVNode = parentInstance && parentInstance.vnode;
  }
  return normalizedStack;
}
__name(getComponentTrace, "getComponentTrace");
function formatTrace(trace) {
  const logs = [];
  trace.forEach((entry, i2) => {
    logs.push(...i2 === 0 ? [] : [`
`], ...formatTraceEntry(entry));
  });
  return logs;
}
__name(formatTrace, "formatTrace");
function formatTraceEntry({ vnode, recurseCount }) {
  const postfix = recurseCount > 0 ? `... (${recurseCount} recursive calls)` : ``;
  const isRoot = vnode.component ? vnode.component.parent == null : false;
  const open2 = ` at <${formatComponentName(
    vnode.component,
    vnode.type,
    isRoot
  )}`;
  const close5 = `>` + postfix;
  return vnode.props ? [open2, ...formatProps(vnode.props), close5] : [open2 + close5];
}
__name(formatTraceEntry, "formatTraceEntry");
function formatProps(props) {
  const res = [];
  const keys2 = Object.keys(props);
  keys2.slice(0, 3).forEach((key) => {
    res.push(...formatProp(key, props[key]));
  });
  if (keys2.length > 3) {
    res.push(` ...`);
  }
  return res;
}
__name(formatProps, "formatProps");
function formatProp(key, value3, raw) {
  if (isString$9(value3)) {
    value3 = JSON.stringify(value3);
    return raw ? value3 : [`${key}=${value3}`];
  } else if (typeof value3 === "number" || typeof value3 === "boolean" || value3 == null) {
    return raw ? value3 : [`${key}=${value3}`];
  } else if (isRef(value3)) {
    value3 = formatProp(key, toRaw(value3.value), true);
    return raw ? value3 : [`${key}=Ref<`, value3, `>`];
  } else if (isFunction$c(value3)) {
    return [`${key}=fn${value3.name ? `<${value3.name}>` : ``}`];
  } else {
    value3 = toRaw(value3);
    return raw ? value3 : [`${key}=`, value3];
  }
}
__name(formatProp, "formatProp");
function assertNumber(val, type) {
  if (true) return;
  if (val === void 0) {
    return;
  } else if (typeof val !== "number") {
    warn$1$1(`${type} is not a valid number - got ${JSON.stringify(val)}.`);
  } else if (isNaN(val)) {
    warn$1$1(`${type} is NaN - the duration expression might be incorrect.`);
  }
}
__name(assertNumber, "assertNumber");
const ErrorCodes = {
  "SETUP_FUNCTION": 0,
  "0": "SETUP_FUNCTION",
  "RENDER_FUNCTION": 1,
  "1": "RENDER_FUNCTION",
  "NATIVE_EVENT_HANDLER": 5,
  "5": "NATIVE_EVENT_HANDLER",
  "COMPONENT_EVENT_HANDLER": 6,
  "6": "COMPONENT_EVENT_HANDLER",
  "VNODE_HOOK": 7,
  "7": "VNODE_HOOK",
  "DIRECTIVE_HOOK": 8,
  "8": "DIRECTIVE_HOOK",
  "TRANSITION_HOOK": 9,
  "9": "TRANSITION_HOOK",
  "APP_ERROR_HANDLER": 10,
  "10": "APP_ERROR_HANDLER",
  "APP_WARN_HANDLER": 11,
  "11": "APP_WARN_HANDLER",
  "FUNCTION_REF": 12,
  "12": "FUNCTION_REF",
  "ASYNC_COMPONENT_LOADER": 13,
  "13": "ASYNC_COMPONENT_LOADER",
  "SCHEDULER": 14,
  "14": "SCHEDULER",
  "COMPONENT_UPDATE": 15,
  "15": "COMPONENT_UPDATE",
  "APP_UNMOUNT_CLEANUP": 16,
  "16": "APP_UNMOUNT_CLEANUP"
};
const ErrorTypeStrings$1 = {
  ["sp"]: "serverPrefetch hook",
  ["bc"]: "beforeCreate hook",
  ["c"]: "created hook",
  ["bm"]: "beforeMount hook",
  ["m"]: "mounted hook",
  ["bu"]: "beforeUpdate hook",
  ["u"]: "updated",
  ["bum"]: "beforeUnmount hook",
  ["um"]: "unmounted hook",
  ["a"]: "activated hook",
  ["da"]: "deactivated hook",
  ["ec"]: "errorCaptured hook",
  ["rtc"]: "renderTracked hook",
  ["rtg"]: "renderTriggered hook",
  [0]: "setup function",
  [1]: "render function",
  [2]: "watcher getter",
  [3]: "watcher callback",
  [4]: "watcher cleanup function",
  [5]: "native event handler",
  [6]: "component event handler",
  [7]: "vnode hook",
  [8]: "directive hook",
  [9]: "transition hook",
  [10]: "app errorHandler",
  [11]: "app warnHandler",
  [12]: "ref function",
  [13]: "async component loader",
  [14]: "scheduler flush",
  [15]: "component update",
  [16]: "app unmount cleanup function"
};
function callWithErrorHandling(fn, instance, type, args) {
  try {
    return args ? fn(...args) : fn();
  } catch (err) {
    handleError(err, instance, type);
  }
}
__name(callWithErrorHandling, "callWithErrorHandling");
function callWithAsyncErrorHandling(fn, instance, type, args) {
  if (isFunction$c(fn)) {
    const res = callWithErrorHandling(fn, instance, type, args);
    if (res && isPromise$1(res)) {
      res.catch((err) => {
        handleError(err, instance, type);
      });
    }
    return res;
  }
  if (isArray$b(fn)) {
    const values = [];
    for (let i2 = 0; i2 < fn.length; i2++) {
      values.push(callWithAsyncErrorHandling(fn[i2], instance, type, args));
    }
    return values;
  } else if (false) {
    warn$1$1(
      `Invalid value type passed to callWithAsyncErrorHandling(): ${typeof fn}`
    );
  }
}
__name(callWithAsyncErrorHandling, "callWithAsyncErrorHandling");
function handleError(err, instance, type, throwInDev = true) {
  const contextVNode = instance ? instance.vnode : null;
  const { errorHandler: errorHandler2, throwUnhandledErrorInProduction } = instance && instance.appContext.config || EMPTY_OBJ;
  if (instance) {
    let cur = instance.parent;
    const exposedInstance = instance.proxy;
    const errorInfo = false ? ErrorTypeStrings$1[type] : `https://vuejs.org/error-reference/#runtime-${type}`;
    while (cur) {
      const errorCapturedHooks = cur.ec;
      if (errorCapturedHooks) {
        for (let i2 = 0; i2 < errorCapturedHooks.length; i2++) {
          if (errorCapturedHooks[i2](err, exposedInstance, errorInfo) === false) {
            return;
          }
        }
      }
      cur = cur.parent;
    }
    if (errorHandler2) {
      pauseTracking();
      callWithErrorHandling(errorHandler2, null, 10, [
        err,
        exposedInstance,
        errorInfo
      ]);
      resetTracking();
      return;
    }
  }
  logError(err, type, contextVNode, throwInDev, throwUnhandledErrorInProduction);
}
__name(handleError, "handleError");
function logError(err, type, contextVNode, throwInDev = true, throwInProd = false) {
  if (false) {
    const info = ErrorTypeStrings$1[type];
    if (contextVNode) {
      pushWarningContext(contextVNode);
    }
    warn$1$1(`Unhandled error${info ? ` during execution of ${info}` : ``}`);
    if (contextVNode) {
      popWarningContext();
    }
    if (throwInDev) {
      throw err;
    } else {
      console.error(err);
    }
  } else if (throwInProd) {
    throw err;
  } else {
    console.error(err);
  }
}
__name(logError, "logError");
const queue = [];
let flushIndex = -1;
const pendingPostFlushCbs = [];
let activePostFlushCbs = null;
let postFlushIndex = 0;
const resolvedPromise = /* @__PURE__ */ Promise.resolve();
let currentFlushPromise = null;
const RECURSION_LIMIT = 100;
function nextTick(fn) {
  const p2 = currentFlushPromise || resolvedPromise;
  return fn ? p2.then(this ? fn.bind(this) : fn) : p2;
}
__name(nextTick, "nextTick");
function findInsertionIndex$1(id4) {
  let start2 = flushIndex + 1;
  let end = queue.length;
  while (start2 < end) {
    const middle = start2 + end >>> 1;
    const middleJob = queue[middle];
    const middleJobId = getId(middleJob);
    if (middleJobId < id4 || middleJobId === id4 && middleJob.flags & 2) {
      start2 = middle + 1;
    } else {
      end = middle;
    }
  }
  return start2;
}
__name(findInsertionIndex$1, "findInsertionIndex$1");
function queueJob(job) {
  if (!(job.flags & 1)) {
    const jobId = getId(job);
    const lastJob = queue[queue.length - 1];
    if (!lastJob || // fast path when the job id is larger than the tail
    !(job.flags & 2) && jobId >= getId(lastJob)) {
      queue.push(job);
    } else {
      queue.splice(findInsertionIndex$1(jobId), 0, job);
    }
    job.flags |= 1;
    queueFlush();
  }
}
__name(queueJob, "queueJob");
function queueFlush() {
  if (!currentFlushPromise) {
    currentFlushPromise = resolvedPromise.then(flushJobs);
  }
}
__name(queueFlush, "queueFlush");
function queuePostFlushCb(cb) {
  if (!isArray$b(cb)) {
    if (activePostFlushCbs && cb.id === -1) {
      activePostFlushCbs.splice(postFlushIndex + 1, 0, cb);
    } else if (!(cb.flags & 1)) {
      pendingPostFlushCbs.push(cb);
      cb.flags |= 1;
    }
  } else {
    pendingPostFlushCbs.push(...cb);
  }
  queueFlush();
}
__name(queuePostFlushCb, "queuePostFlushCb");
function flushPreFlushCbs(instance, seen2, i2 = flushIndex + 1) {
  if (false) {
    seen2 = seen2 || /* @__PURE__ */ new Map();
  }
  for (; i2 < queue.length; i2++) {
    const cb = queue[i2];
    if (cb && cb.flags & 2) {
      if (instance && cb.id !== instance.uid) {
        continue;
      }
      if (false) {
        continue;
      }
      queue.splice(i2, 1);
      i2--;
      if (cb.flags & 4) {
        cb.flags &= ~1;
      }
      cb();
      if (!(cb.flags & 4)) {
        cb.flags &= ~1;
      }
    }
  }
}
__name(flushPreFlushCbs, "flushPreFlushCbs");
function flushPostFlushCbs(seen2) {
  if (pendingPostFlushCbs.length) {
    const deduped = [...new Set(pendingPostFlushCbs)].sort(
      (a2, b2) => getId(a2) - getId(b2)
    );
    pendingPostFlushCbs.length = 0;
    if (activePostFlushCbs) {
      activePostFlushCbs.push(...deduped);
      return;
    }
    activePostFlushCbs = deduped;
    if (false) {
      seen2 = seen2 || /* @__PURE__ */ new Map();
    }
    for (postFlushIndex = 0; postFlushIndex < activePostFlushCbs.length; postFlushIndex++) {
      const cb = activePostFlushCbs[postFlushIndex];
      if (false) {
        continue;
      }
      if (cb.flags & 4) {
        cb.flags &= ~1;
      }
      if (!(cb.flags & 8)) cb();
      cb.flags &= ~1;
    }
    activePostFlushCbs = null;
    postFlushIndex = 0;
  }
}
__name(flushPostFlushCbs, "flushPostFlushCbs");
const getId = /* @__PURE__ */ __name((job) => job.id == null ? job.flags & 2 ? -1 : Infinity : job.id, "getId");
function flushJobs(seen2) {
  if (false) {
    seen2 = seen2 || /* @__PURE__ */ new Map();
  }
  const check = false ? (job) => checkRecursiveUpdates(seen2, job) : NOOP;
  try {
    for (flushIndex = 0; flushIndex < queue.length; flushIndex++) {
      const job = queue[flushIndex];
      if (job && !(job.flags & 8)) {
        if (false) {
          continue;
        }
        if (job.flags & 4) {
          job.flags &= ~1;
        }
        callWithErrorHandling(
          job,
          job.i,
          job.i ? 15 : 14
        );
        if (!(job.flags & 4)) {
          job.flags &= ~1;
        }
      }
    }
  } finally {
    for (; flushIndex < queue.length; flushIndex++) {
      const job = queue[flushIndex];
      if (job) {
        job.flags &= ~1;
      }
    }
    flushIndex = -1;
    queue.length = 0;
    flushPostFlushCbs(seen2);
    currentFlushPromise = null;
    if (queue.length || pendingPostFlushCbs.length) {
      flushJobs(seen2);
    }
  }
}
__name(flushJobs, "flushJobs");
function checkRecursiveUpdates(seen2, fn) {
  const count = seen2.get(fn) || 0;
  if (count > RECURSION_LIMIT) {
    const instance = fn.i;
    const componentName = instance && getComponentName(instance.type);
    handleError(
      `Maximum recursive updates exceeded${componentName ? ` in component <${componentName}>` : ``}. This means you have a reactive effect that is mutating its own dependencies and thus recursively triggering itself. Possible sources include component template, render function, updated hook or watcher source function.`,
      null,
      10
    );
    return true;
  }
  seen2.set(fn, count + 1);
  return false;
}
__name(checkRecursiveUpdates, "checkRecursiveUpdates");
let isHmrUpdating = false;
const hmrDirtyComponents = /* @__PURE__ */ new Map();
if (false) {
  getGlobalThis$1().__VUE_HMR_RUNTIME__ = {
    createRecord: tryWrap(createRecord),
    rerender: tryWrap(rerender),
    reload: tryWrap(reload)
  };
}
const map$1 = /* @__PURE__ */ new Map();
function registerHMR(instance) {
  const id4 = instance.type.__hmrId;
  let record2 = map$1.get(id4);
  if (!record2) {
    createRecord(id4, instance.type);
    record2 = map$1.get(id4);
  }
  record2.instances.add(instance);
}
__name(registerHMR, "registerHMR");
function unregisterHMR(instance) {
  map$1.get(instance.type.__hmrId).instances.delete(instance);
}
__name(unregisterHMR, "unregisterHMR");
function createRecord(id4, initialDef) {
  if (map$1.has(id4)) {
    return false;
  }
  map$1.set(id4, {
    initialDef: normalizeClassComponent(initialDef),
    instances: /* @__PURE__ */ new Set()
  });
  return true;
}
__name(createRecord, "createRecord");
function normalizeClassComponent(component) {
  return isClassComponent(component) ? component.__vccOpts : component;
}
__name(normalizeClassComponent, "normalizeClassComponent");
function rerender(id4, newRender) {
  const record2 = map$1.get(id4);
  if (!record2) {
    return;
  }
  record2.initialDef.render = newRender;
  [...record2.instances].forEach((instance) => {
    if (newRender) {
      instance.render = newRender;
      normalizeClassComponent(instance.type).render = newRender;
    }
    instance.renderCache = [];
    isHmrUpdating = true;
    instance.update();
    isHmrUpdating = false;
  });
}
__name(rerender, "rerender");
function reload(id4, newComp) {
  const record2 = map$1.get(id4);
  if (!record2) return;
  newComp = normalizeClassComponent(newComp);
  updateComponentDef(record2.initialDef, newComp);
  const instances = [...record2.instances];
  for (let i2 = 0; i2 < instances.length; i2++) {
    const instance = instances[i2];
    const oldComp = normalizeClassComponent(instance.type);
    let dirtyInstances = hmrDirtyComponents.get(oldComp);
    if (!dirtyInstances) {
      if (oldComp !== record2.initialDef) {
        updateComponentDef(oldComp, newComp);
      }
      hmrDirtyComponents.set(oldComp, dirtyInstances = /* @__PURE__ */ new Set());
    }
    dirtyInstances.add(instance);
    instance.appContext.propsCache.delete(instance.type);
    instance.appContext.emitsCache.delete(instance.type);
    instance.appContext.optionsCache.delete(instance.type);
    if (instance.ceReload) {
      dirtyInstances.add(instance);
      instance.ceReload(newComp.styles);
      dirtyInstances.delete(instance);
    } else if (instance.parent) {
      queueJob(() => {
        isHmrUpdating = true;
        instance.parent.update();
        isHmrUpdating = false;
        dirtyInstances.delete(instance);
      });
    } else if (instance.appContext.reload) {
      instance.appContext.reload();
    } else if (typeof window !== "undefined") {
      window.location.reload();
    } else {
      console.warn(
        "[HMR] Root or manually mounted instance modified. Full reload required."
      );
    }
    if (instance.root.ce && instance !== instance.root) {
      instance.root.ce._removeChildStyle(oldComp);
    }
  }
  queuePostFlushCb(() => {
    hmrDirtyComponents.clear();
  });
}
__name(reload, "reload");
function updateComponentDef(oldComp, newComp) {
  extend$1(oldComp, newComp);
  for (const key in oldComp) {
    if (key !== "__file" && !(key in newComp)) {
      delete oldComp[key];
    }
  }
}
__name(updateComponentDef, "updateComponentDef");
function tryWrap(fn) {
  return (id4, arg) => {
    try {
      return fn(id4, arg);
    } catch (e2) {
      console.error(e2);
      console.warn(
        `[HMR] Something went wrong during Vue component hot-reload. Full reload required.`
      );
    }
  };
}
__name(tryWrap, "tryWrap");
let devtools$1;
let buffer = [];
let devtoolsNotInstalled = false;
function emit$1(event, ...args) {
  if (devtools$1) {
    devtools$1.emit(event, ...args);
  } else if (!devtoolsNotInstalled) {
    buffer.push({ event, args });
  }
}
__name(emit$1, "emit$1");
function setDevtoolsHook$1(hook, target2) {
  var _a2, _b;
  devtools$1 = hook;
  if (devtools$1) {
    devtools$1.enabled = true;
    buffer.forEach(({ event, args }) => devtools$1.emit(event, ...args));
    buffer = [];
  } else if (
    // handle late devtools injection - only do this if we are in an actual
    // browser environment to avoid the timer handle stalling test runner exit
    // (#4815)
    typeof window !== "undefined" && // some envs mock window but not fully
    window.HTMLElement && // also exclude jsdom
    // eslint-disable-next-line no-restricted-syntax
    !((_b = (_a2 = window.navigator) == null ? void 0 : _a2.userAgent) == null ? void 0 : _b.includes("jsdom"))
  ) {
    const replay = target2.__VUE_DEVTOOLS_HOOK_REPLAY__ = target2.__VUE_DEVTOOLS_HOOK_REPLAY__ || [];
    replay.push((newHook) => {
      setDevtoolsHook$1(newHook, target2);
    });
    setTimeout(() => {
      if (!devtools$1) {
        target2.__VUE_DEVTOOLS_HOOK_REPLAY__ = null;
        devtoolsNotInstalled = true;
        buffer = [];
      }
    }, 3e3);
  } else {
    devtoolsNotInstalled = true;
    buffer = [];
  }
}
__name(setDevtoolsHook$1, "setDevtoolsHook$1");
function devtoolsInitApp(app2, version2) {
  emit$1("app:init", app2, version2, {
    Fragment: Fragment$1,
    Text: Text$4,
    Comment,
    Static
  });
}
__name(devtoolsInitApp, "devtoolsInitApp");
function devtoolsUnmountApp(app2) {
  emit$1("app:unmount", app2);
}
__name(devtoolsUnmountApp, "devtoolsUnmountApp");
const devtoolsComponentAdded = /* @__PURE__ */ createDevtoolsComponentHook(
  "component:added"
  /* COMPONENT_ADDED */
);
const devtoolsComponentUpdated = /* @__PURE__ */ createDevtoolsComponentHook(
  "component:updated"
  /* COMPONENT_UPDATED */
);
const _devtoolsComponentRemoved = /* @__PURE__ */ createDevtoolsComponentHook(
  "component:removed"
  /* COMPONENT_REMOVED */
);
const devtoolsComponentRemoved = /* @__PURE__ */ __name((component) => {
  if (devtools$1 && typeof devtools$1.cleanupBuffer === "function" && // remove the component if it wasn't buffered
  !devtools$1.cleanupBuffer(component)) {
    _devtoolsComponentRemoved(component);
  }
}, "devtoolsComponentRemoved");
/*! #__NO_SIDE_EFFECTS__ */
// @__NO_SIDE_EFFECTS__
function createDevtoolsComponentHook(hook) {
  return (component) => {
    emit$1(
      hook,
      component.appContext.app,
      component.uid,
      component.parent ? component.parent.uid : void 0,
      component
    );
  };
}
__name(createDevtoolsComponentHook, "createDevtoolsComponentHook");
const devtoolsPerfStart = /* @__PURE__ */ createDevtoolsPerformanceHook(
  "perf:start"
  /* PERFORMANCE_START */
);
const devtoolsPerfEnd = /* @__PURE__ */ createDevtoolsPerformanceHook(
  "perf:end"
  /* PERFORMANCE_END */
);
function createDevtoolsPerformanceHook(hook) {
  return (component, type, time) => {
    emit$1(hook, component.appContext.app, component.uid, component, type, time);
  };
}
__name(createDevtoolsPerformanceHook, "createDevtoolsPerformanceHook");
function devtoolsComponentEmit(component, event, params) {
  emit$1(
    "component:emit",
    component.appContext.app,
    component,
    event,
    params
  );
}
__name(devtoolsComponentEmit, "devtoolsComponentEmit");
let currentRenderingInstance = null;
let currentScopeId = null;
function setCurrentRenderingInstance(instance) {
  const prev2 = currentRenderingInstance;
  currentRenderingInstance = instance;
  currentScopeId = instance && instance.type.__scopeId || null;
  return prev2;
}
__name(setCurrentRenderingInstance, "setCurrentRenderingInstance");
function pushScopeId(id4) {
  currentScopeId = id4;
}
__name(pushScopeId, "pushScopeId");
function popScopeId() {
  currentScopeId = null;
}
__name(popScopeId, "popScopeId");
const withScopeId = /* @__PURE__ */ __name((_id2) => withCtx, "withScopeId");
function withCtx(fn, ctx = currentRenderingInstance, isNonScopedSlot) {
  if (!ctx) return fn;
  if (fn._n) {
    return fn;
  }
  const renderFnWithContext = /* @__PURE__ */ __name((...args) => {
    if (renderFnWithContext._d) {
      setBlockTracking(-1);
    }
    const prevInstance = setCurrentRenderingInstance(ctx);
    let res;
    try {
      res = fn(...args);
    } finally {
      setCurrentRenderingInstance(prevInstance);
      if (renderFnWithContext._d) {
        setBlockTracking(1);
      }
    }
    if (false) {
      devtoolsComponentUpdated(ctx);
    }
    return res;
  }, "renderFnWithContext");
  renderFnWithContext._n = true;
  renderFnWithContext._c = true;
  renderFnWithContext._d = true;
  return renderFnWithContext;
}
__name(withCtx, "withCtx");
function validateDirectiveName(name2) {
  if (isBuiltInDirective(name2)) {
    warn$1$1("Do not use built-in directive ids as custom directive id: " + name2);
  }
}
__name(validateDirectiveName, "validateDirectiveName");
function withDirectives(vnode, directives) {
  if (currentRenderingInstance === null) {
    return vnode;
  }
  const instance = getComponentPublicInstance(currentRenderingInstance);
  const bindings = vnode.dirs || (vnode.dirs = []);
  for (let i2 = 0; i2 < directives.length; i2++) {
    let [dir, value3, arg, modifiers2 = EMPTY_OBJ] = directives[i2];
    if (dir) {
      if (isFunction$c(dir)) {
        dir = {
          mounted: dir,
          updated: dir
        };
      }
      if (dir.deep) {
        traverse(value3);
      }
      bindings.push({
        dir,
        instance,
        value: value3,
        oldValue: void 0,
        arg,
        modifiers: modifiers2
      });
    }
  }
  return vnode;
}
__name(withDirectives, "withDirectives");
function invokeDirectiveHook(vnode, prevVNode, instance, name2) {
  const bindings = vnode.dirs;
  const oldBindings = prevVNode && prevVNode.dirs;
  for (let i2 = 0; i2 < bindings.length; i2++) {
    const binding = bindings[i2];
    if (oldBindings) {
      binding.oldValue = oldBindings[i2].value;
    }
    let hook = binding.dir[name2];
    if (hook) {
      pauseTracking();
      callWithAsyncErrorHandling(hook, instance, 8, [
        vnode.el,
        binding,
        vnode,
        prevVNode
      ]);
      resetTracking();
    }
  }
}
__name(invokeDirectiveHook, "invokeDirectiveHook");
const TeleportEndKey = Symbol("_vte");
const isTeleport = /* @__PURE__ */ __name((type) => type.__isTeleport, "isTeleport");
const isTeleportDisabled = /* @__PURE__ */ __name((props) => props && (props.disabled || props.disabled === ""), "isTeleportDisabled");
const isTeleportDeferred = /* @__PURE__ */ __name((props) => props && (props.defer || props.defer === ""), "isTeleportDeferred");
const isTargetSVG = /* @__PURE__ */ __name((target2) => typeof SVGElement !== "undefined" && target2 instanceof SVGElement, "isTargetSVG");
const isTargetMathML = /* @__PURE__ */ __name((target2) => typeof MathMLElement === "function" && target2 instanceof MathMLElement, "isTargetMathML");
const resolveTarget = /* @__PURE__ */ __name((props, select) => {
  const targetSelector = props && props.to;
  if (isString$9(targetSelector)) {
    if (!select) {
      return null;
    } else {
      const target2 = select(targetSelector);
      if (false) {
        warn$1$1(
          `Failed to locate Teleport target with selector "${targetSelector}". Note the target element must exist before the component is mounted - i.e. the target cannot be rendered by the component itself, and ideally should be outside of the entire Vue component tree.`
        );
      }
      return target2;
    }
  } else {
    if (false) {
      warn$1$1(`Invalid Teleport target: ${targetSelector}`);
    }
    return targetSelector;
  }
}, "resolveTarget");
const TeleportImpl = {
  name: "Teleport",
  __isTeleport: true,
  process(n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized, internals) {
    const {
      mc: mountChildren,
      pc: patchChildren,
      pbc: patchBlockChildren,
      o: { insert: insert2, querySelector, createText, createComment }
    } = internals;
    const disabled3 = isTeleportDisabled(n2.props);
    let { shapeFlag, children, dynamicChildren } = n2;
    if (false) {
      optimized = false;
      dynamicChildren = null;
    }
    if (n1 == null) {
      const placeholder = n2.el = false ? createComment("teleport start") : createText("");
      const mainAnchor = n2.anchor = false ? createComment("teleport end") : createText("");
      insert2(placeholder, container, anchor);
      insert2(mainAnchor, container, anchor);
      const mount2 = /* @__PURE__ */ __name((container2, anchor2) => {
        if (shapeFlag & 16) {
          if (parentComponent && parentComponent.isCE) {
            parentComponent.ce._teleportTarget = container2;
          }
          mountChildren(
            children,
            container2,
            anchor2,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        }
      }, "mount");
      const mountToTarget = /* @__PURE__ */ __name(() => {
        const target2 = n2.target = resolveTarget(n2.props, querySelector);
        const targetAnchor = prepareAnchor(target2, n2, createText, insert2);
        if (target2) {
          if (namespace !== "svg" && isTargetSVG(target2)) {
            namespace = "svg";
          } else if (namespace !== "mathml" && isTargetMathML(target2)) {
            namespace = "mathml";
          }
          if (!disabled3) {
            mount2(target2, targetAnchor);
            updateCssVars(n2, false);
          }
        } else if (false) {
          warn$1$1(
            "Invalid Teleport target on mount:",
            target2,
            `(${typeof target2})`
          );
        }
      }, "mountToTarget");
      if (disabled3) {
        mount2(container, mainAnchor);
        updateCssVars(n2, true);
      }
      if (isTeleportDeferred(n2.props)) {
        queuePostRenderEffect(() => {
          mountToTarget();
          n2.el.__isMounted = true;
        }, parentSuspense);
      } else {
        mountToTarget();
      }
    } else {
      if (isTeleportDeferred(n2.props) && !n1.el.__isMounted) {
        queuePostRenderEffect(() => {
          TeleportImpl.process(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized,
            internals
          );
          delete n1.el.__isMounted;
        }, parentSuspense);
        return;
      }
      n2.el = n1.el;
      n2.targetStart = n1.targetStart;
      const mainAnchor = n2.anchor = n1.anchor;
      const target2 = n2.target = n1.target;
      const targetAnchor = n2.targetAnchor = n1.targetAnchor;
      const wasDisabled = isTeleportDisabled(n1.props);
      const currentContainer = wasDisabled ? container : target2;
      const currentAnchor = wasDisabled ? mainAnchor : targetAnchor;
      if (namespace === "svg" || isTargetSVG(target2)) {
        namespace = "svg";
      } else if (namespace === "mathml" || isTargetMathML(target2)) {
        namespace = "mathml";
      }
      if (dynamicChildren) {
        patchBlockChildren(
          n1.dynamicChildren,
          dynamicChildren,
          currentContainer,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds
        );
        traverseStaticChildren(n1, n2, true);
      } else if (!optimized) {
        patchChildren(
          n1,
          n2,
          currentContainer,
          currentAnchor,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          false
        );
      }
      if (disabled3) {
        if (!wasDisabled) {
          moveTeleport(
            n2,
            container,
            mainAnchor,
            internals,
            1
          );
        } else {
          if (n2.props && n1.props && n2.props.to !== n1.props.to) {
            n2.props.to = n1.props.to;
          }
        }
      } else {
        if ((n2.props && n2.props.to) !== (n1.props && n1.props.to)) {
          const nextTarget = n2.target = resolveTarget(
            n2.props,
            querySelector
          );
          if (nextTarget) {
            moveTeleport(
              n2,
              nextTarget,
              null,
              internals,
              0
            );
          } else if (false) {
            warn$1$1(
              "Invalid Teleport target on update:",
              target2,
              `(${typeof target2})`
            );
          }
        } else if (wasDisabled) {
          moveTeleport(
            n2,
            target2,
            targetAnchor,
            internals,
            1
          );
        }
      }
      updateCssVars(n2, disabled3);
    }
  },
  remove(vnode, parentComponent, parentSuspense, { um: unmount, o: { remove: hostRemove } }, doRemove) {
    const {
      shapeFlag,
      children,
      anchor,
      targetStart,
      targetAnchor,
      target: target2,
      props
    } = vnode;
    if (target2) {
      hostRemove(targetStart);
      hostRemove(targetAnchor);
    }
    doRemove && hostRemove(anchor);
    if (shapeFlag & 16) {
      const shouldRemove = doRemove || !isTeleportDisabled(props);
      for (let i2 = 0; i2 < children.length; i2++) {
        const child = children[i2];
        unmount(
          child,
          parentComponent,
          parentSuspense,
          shouldRemove,
          !!child.dynamicChildren
        );
      }
    }
  },
  move: moveTeleport,
  hydrate: hydrateTeleport
};
function moveTeleport(vnode, container, parentAnchor, { o: { insert: insert2 }, m: move }, moveType = 2) {
  if (moveType === 0) {
    insert2(vnode.targetAnchor, container, parentAnchor);
  }
  const { el, anchor, shapeFlag, children, props } = vnode;
  const isReorder = moveType === 2;
  if (isReorder) {
    insert2(el, container, parentAnchor);
  }
  if (!isReorder || isTeleportDisabled(props)) {
    if (shapeFlag & 16) {
      for (let i2 = 0; i2 < children.length; i2++) {
        move(
          children[i2],
          container,
          parentAnchor,
          2
        );
      }
    }
  }
  if (isReorder) {
    insert2(anchor, container, parentAnchor);
  }
}
__name(moveTeleport, "moveTeleport");
function hydrateTeleport(node3, vnode, parentComponent, parentSuspense, slotScopeIds, optimized, {
  o: { nextSibling, parentNode: parentNode2, querySelector, insert: insert2, createText }
}, hydrateChildren) {
  const target2 = vnode.target = resolveTarget(
    vnode.props,
    querySelector
  );
  if (target2) {
    const disabled3 = isTeleportDisabled(vnode.props);
    const targetNode = target2._lpa || target2.firstChild;
    if (vnode.shapeFlag & 16) {
      if (disabled3) {
        vnode.anchor = hydrateChildren(
          nextSibling(node3),
          vnode,
          parentNode2(node3),
          parentComponent,
          parentSuspense,
          slotScopeIds,
          optimized
        );
        vnode.targetStart = targetNode;
        vnode.targetAnchor = targetNode && nextSibling(targetNode);
      } else {
        vnode.anchor = nextSibling(node3);
        let targetAnchor = targetNode;
        while (targetAnchor) {
          if (targetAnchor && targetAnchor.nodeType === 8) {
            if (targetAnchor.data === "teleport start anchor") {
              vnode.targetStart = targetAnchor;
            } else if (targetAnchor.data === "teleport anchor") {
              vnode.targetAnchor = targetAnchor;
              target2._lpa = vnode.targetAnchor && nextSibling(vnode.targetAnchor);
              break;
            }
          }
          targetAnchor = nextSibling(targetAnchor);
        }
        if (!vnode.targetAnchor) {
          prepareAnchor(target2, vnode, createText, insert2);
        }
        hydrateChildren(
          targetNode && nextSibling(targetNode),
          vnode,
          target2,
          parentComponent,
          parentSuspense,
          slotScopeIds,
          optimized
        );
      }
    }
    updateCssVars(vnode, disabled3);
  }
  return vnode.anchor && nextSibling(vnode.anchor);
}
__name(hydrateTeleport, "hydrateTeleport");
const Teleport = TeleportImpl;
function updateCssVars(vnode, isDisabled) {
  const ctx = vnode.ctx;
  if (ctx && ctx.ut) {
    let node3, anchor;
    if (isDisabled) {
      node3 = vnode.el;
      anchor = vnode.anchor;
    } else {
      node3 = vnode.targetStart;
      anchor = vnode.targetAnchor;
    }
    while (node3 && node3 !== anchor) {
      if (node3.nodeType === 1) node3.setAttribute("data-v-owner", ctx.uid);
      node3 = node3.nextSibling;
    }
    ctx.ut();
  }
}
__name(updateCssVars, "updateCssVars");
function prepareAnchor(target2, vnode, createText, insert2) {
  const targetStart = vnode.targetStart = createText("");
  const targetAnchor = vnode.targetAnchor = createText("");
  targetStart[TeleportEndKey] = targetAnchor;
  if (target2) {
    insert2(targetStart, target2);
    insert2(targetAnchor, target2);
  }
  return targetAnchor;
}
__name(prepareAnchor, "prepareAnchor");
const leaveCbKey = Symbol("_leaveCb");
const enterCbKey$1 = Symbol("_enterCb");
function useTransitionState() {
  const state = {
    isMounted: false,
    isLeaving: false,
    isUnmounting: false,
    leavingVNodes: /* @__PURE__ */ new Map()
  };
  onMounted(() => {
    state.isMounted = true;
  });
  onBeforeUnmount(() => {
    state.isUnmounting = true;
  });
  return state;
}
__name(useTransitionState, "useTransitionState");
const TransitionHookValidator = [Function, Array];
const BaseTransitionPropsValidators = {
  mode: String,
  appear: Boolean,
  persisted: Boolean,
  // enter
  onBeforeEnter: TransitionHookValidator,
  onEnter: TransitionHookValidator,
  onAfterEnter: TransitionHookValidator,
  onEnterCancelled: TransitionHookValidator,
  // leave
  onBeforeLeave: TransitionHookValidator,
  onLeave: TransitionHookValidator,
  onAfterLeave: TransitionHookValidator,
  onLeaveCancelled: TransitionHookValidator,
  // appear
  onBeforeAppear: TransitionHookValidator,
  onAppear: TransitionHookValidator,
  onAfterAppear: TransitionHookValidator,
  onAppearCancelled: TransitionHookValidator
};
const recursiveGetSubtree = /* @__PURE__ */ __name((instance) => {
  const subTree = instance.subTree;
  return subTree.component ? recursiveGetSubtree(subTree.component) : subTree;
}, "recursiveGetSubtree");
const BaseTransitionImpl = {
  name: `BaseTransition`,
  props: BaseTransitionPropsValidators,
  setup(props, { slots }) {
    const instance = getCurrentInstance();
    const state = useTransitionState();
    return () => {
      const children = slots.default && getTransitionRawChildren(slots.default(), true);
      if (!children || !children.length) {
        return;
      }
      const child = findNonCommentChild(children);
      const rawProps = toRaw(props);
      const { mode: mode2 } = rawProps;
      if (false) {
        warn$1$1(`invalid <transition> mode: ${mode2}`);
      }
      if (state.isLeaving) {
        return emptyPlaceholder(child);
      }
      const innerChild = getInnerChild$1(child);
      if (!innerChild) {
        return emptyPlaceholder(child);
      }
      let enterHooks = resolveTransitionHooks(
        innerChild,
        rawProps,
        state,
        instance,
        // #11061, ensure enterHooks is fresh after clone
        (hooks2) => enterHooks = hooks2
      );
      if (innerChild.type !== Comment) {
        setTransitionHooks(innerChild, enterHooks);
      }
      let oldInnerChild = instance.subTree && getInnerChild$1(instance.subTree);
      if (oldInnerChild && oldInnerChild.type !== Comment && !isSameVNodeType(innerChild, oldInnerChild) && recursiveGetSubtree(instance).type !== Comment) {
        let leavingHooks = resolveTransitionHooks(
          oldInnerChild,
          rawProps,
          state,
          instance
        );
        setTransitionHooks(oldInnerChild, leavingHooks);
        if (mode2 === "out-in" && innerChild.type !== Comment) {
          state.isLeaving = true;
          leavingHooks.afterLeave = () => {
            state.isLeaving = false;
            if (!(instance.job.flags & 8)) {
              instance.update();
            }
            delete leavingHooks.afterLeave;
            oldInnerChild = void 0;
          };
          return emptyPlaceholder(child);
        } else if (mode2 === "in-out" && innerChild.type !== Comment) {
          leavingHooks.delayLeave = (el, earlyRemove, delayedLeave) => {
            const leavingVNodesCache = getLeavingNodesForType(
              state,
              oldInnerChild
            );
            leavingVNodesCache[String(oldInnerChild.key)] = oldInnerChild;
            el[leaveCbKey] = () => {
              earlyRemove();
              el[leaveCbKey] = void 0;
              delete enterHooks.delayedLeave;
              oldInnerChild = void 0;
            };
            enterHooks.delayedLeave = () => {
              delayedLeave();
              delete enterHooks.delayedLeave;
              oldInnerChild = void 0;
            };
          };
        } else {
          oldInnerChild = void 0;
        }
      } else if (oldInnerChild) {
        oldInnerChild = void 0;
      }
      return child;
    };
  }
};
function findNonCommentChild(children) {
  let child = children[0];
  if (children.length > 1) {
    let hasFound = false;
    for (const c2 of children) {
      if (c2.type !== Comment) {
        if (false) {
          warn$1$1(
            "<transition> can only be used on a single element or component. Use <transition-group> for lists."
          );
          break;
        }
        child = c2;
        hasFound = true;
        if (true) break;
      }
    }
  }
  return child;
}
__name(findNonCommentChild, "findNonCommentChild");
const BaseTransition = BaseTransitionImpl;
function getLeavingNodesForType(state, vnode) {
  const { leavingVNodes } = state;
  let leavingVNodesCache = leavingVNodes.get(vnode.type);
  if (!leavingVNodesCache) {
    leavingVNodesCache = /* @__PURE__ */ Object.create(null);
    leavingVNodes.set(vnode.type, leavingVNodesCache);
  }
  return leavingVNodesCache;
}
__name(getLeavingNodesForType, "getLeavingNodesForType");
function resolveTransitionHooks(vnode, props, state, instance, postClone) {
  const {
    appear,
    mode: mode2,
    persisted = false,
    onBeforeEnter: onBeforeEnter2,
    onEnter: onEnter7,
    onAfterEnter: onAfterEnter4,
    onEnterCancelled,
    onBeforeLeave: onBeforeLeave3,
    onLeave: onLeave5,
    onAfterLeave: onAfterLeave6,
    onLeaveCancelled,
    onBeforeAppear,
    onAppear,
    onAfterAppear,
    onAppearCancelled
  } = props;
  const key = String(vnode.key);
  const leavingVNodesCache = getLeavingNodesForType(state, vnode);
  const callHook2 = /* @__PURE__ */ __name((hook, args) => {
    hook && callWithAsyncErrorHandling(
      hook,
      instance,
      9,
      args
    );
  }, "callHook2");
  const callAsyncHook = /* @__PURE__ */ __name((hook, args) => {
    const done = args[1];
    callHook2(hook, args);
    if (isArray$b(hook)) {
      if (hook.every((hook2) => hook2.length <= 1)) done();
    } else if (hook.length <= 1) {
      done();
    }
  }, "callAsyncHook");
  const hooks2 = {
    mode: mode2,
    persisted,
    beforeEnter(el) {
      let hook = onBeforeEnter2;
      if (!state.isMounted) {
        if (appear) {
          hook = onBeforeAppear || onBeforeEnter2;
        } else {
          return;
        }
      }
      if (el[leaveCbKey]) {
        el[leaveCbKey](
          true
          /* cancelled */
        );
      }
      const leavingVNode = leavingVNodesCache[key];
      if (leavingVNode && isSameVNodeType(vnode, leavingVNode) && leavingVNode.el[leaveCbKey]) {
        leavingVNode.el[leaveCbKey]();
      }
      callHook2(hook, [el]);
    },
    enter(el) {
      let hook = onEnter7;
      let afterHook = onAfterEnter4;
      let cancelHook = onEnterCancelled;
      if (!state.isMounted) {
        if (appear) {
          hook = onAppear || onEnter7;
          afterHook = onAfterAppear || onAfterEnter4;
          cancelHook = onAppearCancelled || onEnterCancelled;
        } else {
          return;
        }
      }
      let called = false;
      const done = el[enterCbKey$1] = (cancelled) => {
        if (called) return;
        called = true;
        if (cancelled) {
          callHook2(cancelHook, [el]);
        } else {
          callHook2(afterHook, [el]);
        }
        if (hooks2.delayedLeave) {
          hooks2.delayedLeave();
        }
        el[enterCbKey$1] = void 0;
      };
      if (hook) {
        callAsyncHook(hook, [el, done]);
      } else {
        done();
      }
    },
    leave(el, remove22) {
      const key2 = String(vnode.key);
      if (el[enterCbKey$1]) {
        el[enterCbKey$1](
          true
          /* cancelled */
        );
      }
      if (state.isUnmounting) {
        return remove22();
      }
      callHook2(onBeforeLeave3, [el]);
      let called = false;
      const done = el[leaveCbKey] = (cancelled) => {
        if (called) return;
        called = true;
        remove22();
        if (cancelled) {
          callHook2(onLeaveCancelled, [el]);
        } else {
          callHook2(onAfterLeave6, [el]);
        }
        el[leaveCbKey] = void 0;
        if (leavingVNodesCache[key2] === vnode) {
          delete leavingVNodesCache[key2];
        }
      };
      leavingVNodesCache[key2] = vnode;
      if (onLeave5) {
        callAsyncHook(onLeave5, [el, done]);
      } else {
        done();
      }
    },
    clone(vnode2) {
      const hooks22 = resolveTransitionHooks(
        vnode2,
        props,
        state,
        instance,
        postClone
      );
      if (postClone) postClone(hooks22);
      return hooks22;
    }
  };
  return hooks2;
}
__name(resolveTransitionHooks, "resolveTransitionHooks");
function emptyPlaceholder(vnode) {
  if (isKeepAlive(vnode)) {
    vnode = cloneVNode(vnode);
    vnode.children = null;
    return vnode;
  }
}
__name(emptyPlaceholder, "emptyPlaceholder");
function getInnerChild$1(vnode) {
  if (!isKeepAlive(vnode)) {
    if (isTeleport(vnode.type) && vnode.children) {
      return findNonCommentChild(vnode.children);
    }
    return vnode;
  }
  if (false) {
    return vnode.component.subTree;
  }
  const { shapeFlag, children } = vnode;
  if (children) {
    if (shapeFlag & 16) {
      return children[0];
    }
    if (shapeFlag & 32 && isFunction$c(children.default)) {
      return children.default();
    }
  }
}
__name(getInnerChild$1, "getInnerChild$1");
function setTransitionHooks(vnode, hooks2) {
  if (vnode.shapeFlag & 6 && vnode.component) {
    vnode.transition = hooks2;
    setTransitionHooks(vnode.component.subTree, hooks2);
  } else if (vnode.shapeFlag & 128) {
    vnode.ssContent.transition = hooks2.clone(vnode.ssContent);
    vnode.ssFallback.transition = hooks2.clone(vnode.ssFallback);
  } else {
    vnode.transition = hooks2;
  }
}
__name(setTransitionHooks, "setTransitionHooks");
function getTransitionRawChildren(children, keepComment = false, parentKey) {
  let ret = [];
  let keyedFragmentCount = 0;
  for (let i2 = 0; i2 < children.length; i2++) {
    let child = children[i2];
    const key = parentKey == null ? child.key : String(parentKey) + String(child.key != null ? child.key : i2);
    if (child.type === Fragment$1) {
      if (child.patchFlag & 128) keyedFragmentCount++;
      ret = ret.concat(
        getTransitionRawChildren(child.children, keepComment, key)
      );
    } else if (keepComment || child.type !== Comment) {
      ret.push(key != null ? cloneVNode(child, { key }) : child);
    }
  }
  if (keyedFragmentCount > 1) {
    for (let i2 = 0; i2 < ret.length; i2++) {
      ret[i2].patchFlag = -2;
    }
  }
  return ret;
}
__name(getTransitionRawChildren, "getTransitionRawChildren");
/*! #__NO_SIDE_EFFECTS__ */
// @__NO_SIDE_EFFECTS__
function defineComponent(options5, extraOptions) {
  return isFunction$c(options5) ? (
    // #8236: extend call and options.name access are considered side-effects
    // by Rollup, so we have to wrap it in a pure-annotated IIFE.
    /* @__PURE__ */ (() => extend$1({ name: options5.name }, extraOptions, { setup: options5 }))()
  ) : options5;
}
__name(defineComponent, "defineComponent");
function useId() {
  const i2 = getCurrentInstance();
  if (i2) {
    return (i2.appContext.config.idPrefix || "v") + "-" + i2.ids[0] + i2.ids[1]++;
  } else if (false) {
    warn$1$1(
      `useId() is called when there is no active component instance to be associated with.`
    );
  }
  return "";
}
__name(useId, "useId");
function markAsyncBoundary(instance) {
  instance.ids = [instance.ids[0] + instance.ids[2]++ + "-", 0, 0];
}
__name(markAsyncBoundary, "markAsyncBoundary");
const knownTemplateRefs = /* @__PURE__ */ new WeakSet();
function useTemplateRef(key) {
  const i2 = getCurrentInstance();
  const r2 = shallowRef(null);
  if (i2) {
    const refs = i2.refs === EMPTY_OBJ ? i2.refs = {} : i2.refs;
    let desc;
    if (false) {
      warn$1$1(`useTemplateRef('${key}') already exists.`);
    } else {
      Object.defineProperty(refs, key, {
        enumerable: true,
        get: /* @__PURE__ */ __name(() => r2.value, "get"),
        set: /* @__PURE__ */ __name((val) => r2.value = val, "set")
      });
    }
  } else if (false) {
    warn$1$1(
      `useTemplateRef() is called when there is no active component instance to be associated with.`
    );
  }
  const ret = false ? readonly(r2) : r2;
  if (false) {
    knownTemplateRefs.add(ret);
  }
  return ret;
}
__name(useTemplateRef, "useTemplateRef");
function setRef(rawRef, oldRawRef, parentSuspense, vnode, isUnmount = false) {
  if (isArray$b(rawRef)) {
    rawRef.forEach(
      (r2, i2) => setRef(
        r2,
        oldRawRef && (isArray$b(oldRawRef) ? oldRawRef[i2] : oldRawRef),
        parentSuspense,
        vnode,
        isUnmount
      )
    );
    return;
  }
  if (isAsyncWrapper(vnode) && !isUnmount) {
    if (vnode.shapeFlag & 512 && vnode.type.__asyncResolved && vnode.component.subTree.component) {
      setRef(rawRef, oldRawRef, parentSuspense, vnode.component.subTree);
    }
    return;
  }
  const refValue = vnode.shapeFlag & 4 ? getComponentPublicInstance(vnode.component) : vnode.el;
  const value3 = isUnmount ? null : refValue;
  const { i: owner, r: ref3 } = rawRef;
  if (false) {
    warn$1$1(
      `Missing ref owner context. ref cannot be used on hoisted vnodes. A vnode with ref must be created inside the render function.`
    );
    return;
  }
  const oldRef = oldRawRef && oldRawRef.r;
  const refs = owner.refs === EMPTY_OBJ ? owner.refs = {} : owner.refs;
  const setupState = owner.setupState;
  const rawSetupState = toRaw(setupState);
  const canSetSetupRef = setupState === EMPTY_OBJ ? () => false : (key) => {
    if (false) {
      if (hasOwn$3(rawSetupState, key) && !isRef(rawSetupState[key])) {
        warn$1$1(
          `Template ref "${key}" used on a non-ref value. It will not work in the production build.`
        );
      }
      if (knownTemplateRefs.has(rawSetupState[key])) {
        return false;
      }
    }
    return hasOwn$3(rawSetupState, key);
  };
  if (oldRef != null && oldRef !== ref3) {
    if (isString$9(oldRef)) {
      refs[oldRef] = null;
      if (canSetSetupRef(oldRef)) {
        setupState[oldRef] = null;
      }
    } else if (isRef(oldRef)) {
      oldRef.value = null;
    }
  }
  if (isFunction$c(ref3)) {
    callWithErrorHandling(ref3, owner, 12, [value3, refs]);
  } else {
    const _isString = isString$9(ref3);
    const _isRef = isRef(ref3);
    if (_isString || _isRef) {
      const doSet = /* @__PURE__ */ __name(() => {
        if (rawRef.f) {
          const existing = _isString ? canSetSetupRef(ref3) ? setupState[ref3] : refs[ref3] : ref3.value;
          if (isUnmount) {
            isArray$b(existing) && remove$2(existing, refValue);
          } else {
            if (!isArray$b(existing)) {
              if (_isString) {
                refs[ref3] = [refValue];
                if (canSetSetupRef(ref3)) {
                  setupState[ref3] = refs[ref3];
                }
              } else {
                ref3.value = [refValue];
                if (rawRef.k) refs[rawRef.k] = ref3.value;
              }
            } else if (!existing.includes(refValue)) {
              existing.push(refValue);
            }
          }
        } else if (_isString) {
          refs[ref3] = value3;
          if (canSetSetupRef(ref3)) {
            setupState[ref3] = value3;
          }
        } else if (_isRef) {
          ref3.value = value3;
          if (rawRef.k) refs[rawRef.k] = value3;
        } else if (false) {
          warn$1$1("Invalid template ref type:", ref3, `(${typeof ref3})`);
        }
      }, "doSet");
      if (value3) {
        doSet.id = -1;
        queuePostRenderEffect(doSet, parentSuspense);
      } else {
        doSet();
      }
    } else if (false) {
      warn$1$1("Invalid template ref type:", ref3, `(${typeof ref3})`);
    }
  }
}
__name(setRef, "setRef");
let hasLoggedMismatchError = false;
const logMismatchError = /* @__PURE__ */ __name(() => {
  if (hasLoggedMismatchError) {
    return;
  }
  console.error("Hydration completed but contains mismatches.");
  hasLoggedMismatchError = true;
}, "logMismatchError");
const isSVGContainer = /* @__PURE__ */ __name((container) => container.namespaceURI.includes("svg") && container.tagName !== "foreignObject", "isSVGContainer");
const isMathMLContainer = /* @__PURE__ */ __name((container) => container.namespaceURI.includes("MathML"), "isMathMLContainer");
const getContainerType = /* @__PURE__ */ __name((container) => {
  if (container.nodeType !== 1) return void 0;
  if (isSVGContainer(container)) return "svg";
  if (isMathMLContainer(container)) return "mathml";
  return void 0;
}, "getContainerType");
const isComment = /* @__PURE__ */ __name((node3) => node3.nodeType === 8, "isComment");
function createHydrationFunctions(rendererInternals) {
  const {
    mt: mountComponent,
    p: patch2,
    o: {
      patchProp: patchProp2,
      createText,
      nextSibling,
      parentNode: parentNode2,
      remove: remove22,
      insert: insert2,
      createComment
    }
  } = rendererInternals;
  const hydrate2 = /* @__PURE__ */ __name((vnode, container) => {
    if (!container.hasChildNodes()) {
      patch2(null, vnode, container);
      flushPostFlushCbs();
      container._vnode = vnode;
      return;
    }
    hydrateNode(container.firstChild, vnode, null, null, null);
    flushPostFlushCbs();
    container._vnode = vnode;
  }, "hydrate");
  const hydrateNode = /* @__PURE__ */ __name((node3, vnode, parentComponent, parentSuspense, slotScopeIds, optimized = false) => {
    optimized = optimized || !!vnode.dynamicChildren;
    const isFragmentStart = isComment(node3) && node3.data === "[";
    const onMismatch = /* @__PURE__ */ __name(() => handleMismatch(
      node3,
      vnode,
      parentComponent,
      parentSuspense,
      slotScopeIds,
      isFragmentStart
    ), "onMismatch");
    const { type, ref: ref3, shapeFlag, patchFlag } = vnode;
    let domType = node3.nodeType;
    vnode.el = node3;
    if (false) {
      def(node3, "__vnode", vnode, true);
      def(node3, "__vueParentComponent", parentComponent, true);
    }
    if (patchFlag === -2) {
      optimized = false;
      vnode.dynamicChildren = null;
    }
    let nextNode = null;
    switch (type) {
      case Text$4:
        if (domType !== 3) {
          if (vnode.children === "") {
            insert2(vnode.el = createText(""), parentNode2(node3), node3);
            nextNode = node3;
          } else {
            nextNode = onMismatch();
          }
        } else {
          if (node3.data !== vnode.children) {
            logMismatchError();
            node3.data = vnode.children;
          }
          nextNode = nextSibling(node3);
        }
        break;
      case Comment:
        if (isTemplateNode(node3)) {
          nextNode = nextSibling(node3);
          replaceNode(
            vnode.el = node3.content.firstChild,
            node3,
            parentComponent
          );
        } else if (domType !== 8 || isFragmentStart) {
          nextNode = onMismatch();
        } else {
          nextNode = nextSibling(node3);
        }
        break;
      case Static:
        if (isFragmentStart) {
          node3 = nextSibling(node3);
          domType = node3.nodeType;
        }
        if (domType === 1 || domType === 3) {
          nextNode = node3;
          const needToAdoptContent = !vnode.children.length;
          for (let i2 = 0; i2 < vnode.staticCount; i2++) {
            if (needToAdoptContent)
              vnode.children += nextNode.nodeType === 1 ? nextNode.outerHTML : nextNode.data;
            if (i2 === vnode.staticCount - 1) {
              vnode.anchor = nextNode;
            }
            nextNode = nextSibling(nextNode);
          }
          return isFragmentStart ? nextSibling(nextNode) : nextNode;
        } else {
          onMismatch();
        }
        break;
      case Fragment$1:
        if (!isFragmentStart) {
          nextNode = onMismatch();
        } else {
          nextNode = hydrateFragment(
            node3,
            vnode,
            parentComponent,
            parentSuspense,
            slotScopeIds,
            optimized
          );
        }
        break;
      default:
        if (shapeFlag & 1) {
          if ((domType !== 1 || vnode.type.toLowerCase() !== node3.tagName.toLowerCase()) && !isTemplateNode(node3)) {
            nextNode = onMismatch();
          } else {
            nextNode = hydrateElement(
              node3,
              vnode,
              parentComponent,
              parentSuspense,
              slotScopeIds,
              optimized
            );
          }
        } else if (shapeFlag & 6) {
          vnode.slotScopeIds = slotScopeIds;
          const container = parentNode2(node3);
          if (isFragmentStart) {
            nextNode = locateClosingAnchor(node3);
          } else if (isComment(node3) && node3.data === "teleport start") {
            nextNode = locateClosingAnchor(node3, node3.data, "teleport end");
          } else {
            nextNode = nextSibling(node3);
          }
          mountComponent(
            vnode,
            container,
            null,
            parentComponent,
            parentSuspense,
            getContainerType(container),
            optimized
          );
          if (isAsyncWrapper(vnode) && !vnode.type.__asyncResolved) {
            let subTree;
            if (isFragmentStart) {
              subTree = createVNode(Fragment$1);
              subTree.anchor = nextNode ? nextNode.previousSibling : container.lastChild;
            } else {
              subTree = node3.nodeType === 3 ? createTextVNode("") : createVNode("div");
            }
            subTree.el = node3;
            vnode.component.subTree = subTree;
          }
        } else if (shapeFlag & 64) {
          if (domType !== 8) {
            nextNode = onMismatch();
          } else {
            nextNode = vnode.type.hydrate(
              node3,
              vnode,
              parentComponent,
              parentSuspense,
              slotScopeIds,
              optimized,
              rendererInternals,
              hydrateChildren
            );
          }
        } else if (shapeFlag & 128) {
          nextNode = vnode.type.hydrate(
            node3,
            vnode,
            parentComponent,
            parentSuspense,
            getContainerType(parentNode2(node3)),
            slotScopeIds,
            optimized,
            rendererInternals,
            hydrateNode
          );
        } else if (false) {
          warn$1$1("Invalid HostVNode type:", type, `(${typeof type})`);
        }
    }
    if (ref3 != null) {
      setRef(ref3, null, parentSuspense, vnode);
    }
    return nextNode;
  }, "hydrateNode");
  const hydrateElement = /* @__PURE__ */ __name((el, vnode, parentComponent, parentSuspense, slotScopeIds, optimized) => {
    optimized = optimized || !!vnode.dynamicChildren;
    const { type, props, patchFlag, shapeFlag, dirs, transition } = vnode;
    const forcePatch = type === "input" || type === "option";
    if (forcePatch || patchFlag !== -1) {
      if (dirs) {
        invokeDirectiveHook(vnode, null, parentComponent, "created");
      }
      let needCallTransitionHooks = false;
      if (isTemplateNode(el)) {
        needCallTransitionHooks = needTransition(
          null,
          // no need check parentSuspense in hydration
          transition
        ) && parentComponent && parentComponent.vnode.props && parentComponent.vnode.props.appear;
        const content3 = el.content.firstChild;
        if (needCallTransitionHooks) {
          transition.beforeEnter(content3);
        }
        replaceNode(content3, el, parentComponent);
        vnode.el = el = content3;
      }
      if (shapeFlag & 16 && // skip if element has innerHTML / textContent
      !(props && (props.innerHTML || props.textContent))) {
        let next2 = hydrateChildren(
          el.firstChild,
          vnode,
          el,
          parentComponent,
          parentSuspense,
          slotScopeIds,
          optimized
        );
        let hasWarned2 = false;
        while (next2) {
          if (!isMismatchAllowed(
            el,
            1
            /* CHILDREN */
          )) {
            if (false) {
              warn$1$1(
                `Hydration children mismatch on`,
                el,
                `
Server rendered element contains more child nodes than client vdom.`
              );
              hasWarned2 = true;
            }
            logMismatchError();
          }
          const cur = next2;
          next2 = next2.nextSibling;
          remove22(cur);
        }
      } else if (shapeFlag & 8) {
        let clientText = vnode.children;
        if (clientText[0] === "\n" && (el.tagName === "PRE" || el.tagName === "TEXTAREA")) {
          clientText = clientText.slice(1);
        }
        if (el.textContent !== clientText) {
          if (!isMismatchAllowed(
            el,
            0
            /* TEXT */
          )) {
            logMismatchError();
          }
          el.textContent = vnode.children;
        }
      }
      if (props) {
        if (forcePatch || !optimized || patchFlag & (16 | 32)) {
          const isCustomElement = el.tagName.includes("-");
          for (const key in props) {
            if (false) {
              logMismatchError();
            }
            if (forcePatch && (key.endsWith("value") || key === "indeterminate") || isOn(key) && !isReservedProp(key) || // force hydrate v-bind with .prop modifiers
            key[0] === "." || isCustomElement) {
              patchProp2(el, key, null, props[key], void 0, parentComponent);
            }
          }
        } else if (props.onClick) {
          patchProp2(
            el,
            "onClick",
            null,
            props.onClick,
            void 0,
            parentComponent
          );
        } else if (patchFlag & 4 && isReactive(props.style)) {
          for (const key in props.style) props.style[key];
        }
      }
      let vnodeHooks;
      if (vnodeHooks = props && props.onVnodeBeforeMount) {
        invokeVNodeHook(vnodeHooks, parentComponent, vnode);
      }
      if (dirs) {
        invokeDirectiveHook(vnode, null, parentComponent, "beforeMount");
      }
      if ((vnodeHooks = props && props.onVnodeMounted) || dirs || needCallTransitionHooks) {
        queueEffectWithSuspense(() => {
          vnodeHooks && invokeVNodeHook(vnodeHooks, parentComponent, vnode);
          needCallTransitionHooks && transition.enter(el);
          dirs && invokeDirectiveHook(vnode, null, parentComponent, "mounted");
        }, parentSuspense);
      }
    }
    return el.nextSibling;
  }, "hydrateElement");
  const hydrateChildren = /* @__PURE__ */ __name((node3, parentVNode, container, parentComponent, parentSuspense, slotScopeIds, optimized) => {
    optimized = optimized || !!parentVNode.dynamicChildren;
    const children = parentVNode.children;
    const l2 = children.length;
    let hasWarned2 = false;
    for (let i2 = 0; i2 < l2; i2++) {
      const vnode = optimized ? children[i2] : children[i2] = normalizeVNode(children[i2]);
      const isText = vnode.type === Text$4;
      if (node3) {
        if (isText && !optimized) {
          if (i2 + 1 < l2 && normalizeVNode(children[i2 + 1]).type === Text$4) {
            insert2(
              createText(
                node3.data.slice(vnode.children.length)
              ),
              container,
              nextSibling(node3)
            );
            node3.data = vnode.children;
          }
        }
        node3 = hydrateNode(
          node3,
          vnode,
          parentComponent,
          parentSuspense,
          slotScopeIds,
          optimized
        );
      } else if (isText && !vnode.children) {
        insert2(vnode.el = createText(""), container);
      } else {
        if (!isMismatchAllowed(
          container,
          1
          /* CHILDREN */
        )) {
          if (false) {
            warn$1$1(
              `Hydration children mismatch on`,
              container,
              `
Server rendered element contains fewer child nodes than client vdom.`
            );
            hasWarned2 = true;
          }
          logMismatchError();
        }
        patch2(
          null,
          vnode,
          container,
          null,
          parentComponent,
          parentSuspense,
          getContainerType(container),
          slotScopeIds
        );
      }
    }
    return node3;
  }, "hydrateChildren");
  const hydrateFragment = /* @__PURE__ */ __name((node3, vnode, parentComponent, parentSuspense, slotScopeIds, optimized) => {
    const { slotScopeIds: fragmentSlotScopeIds } = vnode;
    if (fragmentSlotScopeIds) {
      slotScopeIds = slotScopeIds ? slotScopeIds.concat(fragmentSlotScopeIds) : fragmentSlotScopeIds;
    }
    const container = parentNode2(node3);
    const next2 = hydrateChildren(
      nextSibling(node3),
      vnode,
      container,
      parentComponent,
      parentSuspense,
      slotScopeIds,
      optimized
    );
    if (next2 && isComment(next2) && next2.data === "]") {
      return nextSibling(vnode.anchor = next2);
    } else {
      logMismatchError();
      insert2(vnode.anchor = createComment(`]`), container, next2);
      return next2;
    }
  }, "hydrateFragment");
  const handleMismatch = /* @__PURE__ */ __name((node3, vnode, parentComponent, parentSuspense, slotScopeIds, isFragment2) => {
    if (!isMismatchAllowed(
      node3.parentElement,
      1
      /* CHILDREN */
    )) {
      logMismatchError();
    }
    vnode.el = null;
    if (isFragment2) {
      const end = locateClosingAnchor(node3);
      while (true) {
        const next22 = nextSibling(node3);
        if (next22 && next22 !== end) {
          remove22(next22);
        } else {
          break;
        }
      }
    }
    const next2 = nextSibling(node3);
    const container = parentNode2(node3);
    remove22(node3);
    patch2(
      null,
      vnode,
      container,
      next2,
      parentComponent,
      parentSuspense,
      getContainerType(container),
      slotScopeIds
    );
    if (parentComponent) {
      parentComponent.vnode.el = vnode.el;
      updateHOCHostEl(parentComponent, vnode.el);
    }
    return next2;
  }, "handleMismatch");
  const locateClosingAnchor = /* @__PURE__ */ __name((node3, open2 = "[", close5 = "]") => {
    let match2 = 0;
    while (node3) {
      node3 = nextSibling(node3);
      if (node3 && isComment(node3)) {
        if (node3.data === open2) match2++;
        if (node3.data === close5) {
          if (match2 === 0) {
            return nextSibling(node3);
          } else {
            match2--;
          }
        }
      }
    }
    return node3;
  }, "locateClosingAnchor");
  const replaceNode = /* @__PURE__ */ __name((newNode, oldNode, parentComponent) => {
    const parentNode22 = oldNode.parentNode;
    if (parentNode22) {
      parentNode22.replaceChild(newNode, oldNode);
    }
    let parent = parentComponent;
    while (parent) {
      if (parent.vnode.el === oldNode) {
        parent.vnode.el = parent.subTree.el = newNode;
      }
      parent = parent.parent;
    }
  }, "replaceNode");
  const isTemplateNode = /* @__PURE__ */ __name((node3) => {
    return node3.nodeType === 1 && node3.tagName === "TEMPLATE";
  }, "isTemplateNode");
  return [hydrate2, hydrateNode];
}
__name(createHydrationFunctions, "createHydrationFunctions");
function propHasMismatch(el, key, clientValue, vnode, instance) {
  let mismatchType;
  let mismatchKey;
  let actual;
  let expected;
  if (key === "class") {
    actual = el.getAttribute("class");
    expected = normalizeClass(clientValue);
    if (!isSetEqual(toClassSet(actual || ""), toClassSet(expected))) {
      mismatchType = 2;
      mismatchKey = `class`;
    }
  } else if (key === "style") {
    actual = el.getAttribute("style") || "";
    expected = isString$9(clientValue) ? clientValue : stringifyStyle(normalizeStyle(clientValue));
    const actualMap = toStyleMap(actual);
    const expectedMap = toStyleMap(expected);
    if (vnode.dirs) {
      for (const { dir, value: value3 } of vnode.dirs) {
        if (dir.name === "show" && !value3) {
          expectedMap.set("display", "none");
        }
      }
    }
    if (instance) {
      resolveCssVars(instance, vnode, expectedMap);
    }
    if (!isMapEqual(actualMap, expectedMap)) {
      mismatchType = 3;
      mismatchKey = "style";
    }
  } else if (el instanceof SVGElement && isKnownSvgAttr(key) || el instanceof HTMLElement && (isBooleanAttr(key) || isKnownHtmlAttr(key))) {
    if (isBooleanAttr(key)) {
      actual = el.hasAttribute(key);
      expected = includeBooleanAttr(clientValue);
    } else if (clientValue == null) {
      actual = el.hasAttribute(key);
      expected = false;
    } else {
      if (el.hasAttribute(key)) {
        actual = el.getAttribute(key);
      } else if (key === "value" && el.tagName === "TEXTAREA") {
        actual = el.value;
      } else {
        actual = false;
      }
      expected = isRenderableAttrValue(clientValue) ? String(clientValue) : false;
    }
    if (actual !== expected) {
      mismatchType = 4;
      mismatchKey = key;
    }
  }
  if (mismatchType != null && !isMismatchAllowed(el, mismatchType)) {
    const format2 = /* @__PURE__ */ __name((v2) => v2 === false ? `(not rendered)` : `${mismatchKey}="${v2}"`, "format");
    const preSegment = `Hydration ${MismatchTypeString[mismatchType]} mismatch on`;
    const postSegment = `
  - rendered on server: ${format2(actual)}
  - expected on client: ${format2(expected)}
  Note: this mismatch is check-only. The DOM will not be rectified in production due to performance overhead.
  You should fix the source of the mismatch.`;
    {
      warn$1$1(preSegment, el, postSegment);
    }
    return true;
  }
  return false;
}
__name(propHasMismatch, "propHasMismatch");
function toClassSet(str) {
  return new Set(str.trim().split(/\s+/));
}
__name(toClassSet, "toClassSet");
function isSetEqual(a2, b2) {
  if (a2.size !== b2.size) {
    return false;
  }
  for (const s2 of a2) {
    if (!b2.has(s2)) {
      return false;
    }
  }
  return true;
}
__name(isSetEqual, "isSetEqual");
function toStyleMap(str) {
  const styleMap = /* @__PURE__ */ new Map();
  for (const item3 of str.split(";")) {
    let [key, value3] = item3.split(":");
    key = key.trim();
    value3 = value3 && value3.trim();
    if (key && value3) {
      styleMap.set(key, value3);
    }
  }
  return styleMap;
}
__name(toStyleMap, "toStyleMap");
function isMapEqual(a2, b2) {
  if (a2.size !== b2.size) {
    return false;
  }
  for (const [key, value3] of a2) {
    if (value3 !== b2.get(key)) {
      return false;
    }
  }
  return true;
}
__name(isMapEqual, "isMapEqual");
function resolveCssVars(instance, vnode, expectedMap) {
  const root34 = instance.subTree;
  if (instance.getCssVars && (vnode === root34 || root34 && root34.type === Fragment$1 && root34.children.includes(vnode))) {
    const cssVars = instance.getCssVars();
    for (const key in cssVars) {
      expectedMap.set(
        `--${getEscapedCssVarName(key, false)}`,
        String(cssVars[key])
      );
    }
  }
  if (vnode === root34 && instance.parent) {
    resolveCssVars(instance.parent, instance.vnode, expectedMap);
  }
}
__name(resolveCssVars, "resolveCssVars");
const allowMismatchAttr = "data-allow-mismatch";
const MismatchTypeString = {
  [
    0
    /* TEXT */
  ]: "text",
  [
    1
    /* CHILDREN */
  ]: "children",
  [
    2
    /* CLASS */
  ]: "class",
  [
    3
    /* STYLE */
  ]: "style",
  [
    4
    /* ATTRIBUTE */
  ]: "attribute"
};
function isMismatchAllowed(el, allowedType) {
  if (allowedType === 0 || allowedType === 1) {
    while (el && !el.hasAttribute(allowMismatchAttr)) {
      el = el.parentElement;
    }
  }
  const allowedAttr = el && el.getAttribute(allowMismatchAttr);
  if (allowedAttr == null) {
    return false;
  } else if (allowedAttr === "") {
    return true;
  } else {
    const list2 = allowedAttr.split(",");
    if (allowedType === 0 && list2.includes("children")) {
      return true;
    }
    return allowedAttr.split(",").includes(MismatchTypeString[allowedType]);
  }
}
__name(isMismatchAllowed, "isMismatchAllowed");
const requestIdleCallback$1 = getGlobalThis$1().requestIdleCallback || ((cb) => setTimeout(cb, 1));
const cancelIdleCallback$1 = getGlobalThis$1().cancelIdleCallback || ((id4) => clearTimeout(id4));
const hydrateOnIdle = /* @__PURE__ */ __name((timeout = 1e4) => (hydrate2) => {
  const id4 = requestIdleCallback$1(hydrate2, { timeout });
  return () => cancelIdleCallback$1(id4);
}, "hydrateOnIdle");
function elementIsVisibleInViewport(el) {
  const { top, left, bottom, right } = el.getBoundingClientRect();
  const { innerHeight: innerHeight2, innerWidth } = window;
  return (top > 0 && top < innerHeight2 || bottom > 0 && bottom < innerHeight2) && (left > 0 && left < innerWidth || right > 0 && right < innerWidth);
}
__name(elementIsVisibleInViewport, "elementIsVisibleInViewport");
const hydrateOnVisible = /* @__PURE__ */ __name((opts) => (hydrate2, forEach3) => {
  const ob = new IntersectionObserver((entries) => {
    for (const e2 of entries) {
      if (!e2.isIntersecting) continue;
      ob.disconnect();
      hydrate2();
      break;
    }
  }, opts);
  forEach3((el) => {
    if (!(el instanceof Element)) return;
    if (elementIsVisibleInViewport(el)) {
      hydrate2();
      ob.disconnect();
      return false;
    }
    ob.observe(el);
  });
  return () => ob.disconnect();
}, "hydrateOnVisible");
const hydrateOnMediaQuery = /* @__PURE__ */ __name((query) => (hydrate2) => {
  if (query) {
    const mql = matchMedia(query);
    if (mql.matches) {
      hydrate2();
    } else {
      mql.addEventListener("change", hydrate2, { once: true });
      return () => mql.removeEventListener("change", hydrate2);
    }
  }
}, "hydrateOnMediaQuery");
const hydrateOnInteraction = /* @__PURE__ */ __name((interactions = []) => (hydrate2, forEach3) => {
  if (isString$9(interactions)) interactions = [interactions];
  let hasHydrated = false;
  const doHydrate = /* @__PURE__ */ __name((e2) => {
    if (!hasHydrated) {
      hasHydrated = true;
      teardown();
      hydrate2();
      e2.target.dispatchEvent(new e2.constructor(e2.type, e2));
    }
  }, "doHydrate");
  const teardown = /* @__PURE__ */ __name(() => {
    forEach3((el) => {
      for (const i2 of interactions) {
        el.removeEventListener(i2, doHydrate);
      }
    });
  }, "teardown");
  forEach3((el) => {
    for (const i2 of interactions) {
      el.addEventListener(i2, doHydrate, { once: true });
    }
  });
  return teardown;
}, "hydrateOnInteraction");
function forEachElement(node3, cb) {
  if (isComment(node3) && node3.data === "[") {
    let depth = 1;
    let next2 = node3.nextSibling;
    while (next2) {
      if (next2.nodeType === 1) {
        const result = cb(next2);
        if (result === false) {
          break;
        }
      } else if (isComment(next2)) {
        if (next2.data === "]") {
          if (--depth === 0) break;
        } else if (next2.data === "[") {
          depth++;
        }
      }
      next2 = next2.nextSibling;
    }
  } else {
    cb(node3);
  }
}
__name(forEachElement, "forEachElement");
const isAsyncWrapper = /* @__PURE__ */ __name((i2) => !!i2.type.__asyncLoader, "isAsyncWrapper");
/*! #__NO_SIDE_EFFECTS__ */
// @__NO_SIDE_EFFECTS__
function defineAsyncComponent(source) {
  if (isFunction$c(source)) {
    source = { loader: source };
  }
  const {
    loader,
    loadingComponent,
    errorComponent,
    delay = 200,
    hydrate: hydrateStrategy,
    timeout,
    // undefined = never times out
    suspensible = true,
    onError: userOnError
  } = source;
  let pendingRequest = null;
  let resolvedComp;
  let retries = 0;
  const retry = /* @__PURE__ */ __name(() => {
    retries++;
    pendingRequest = null;
    return load3();
  }, "retry");
  const load3 = /* @__PURE__ */ __name(() => {
    let thisRequest;
    return pendingRequest || (thisRequest = pendingRequest = loader().catch((err) => {
      err = err instanceof Error ? err : new Error(String(err));
      if (userOnError) {
        return new Promise((resolve2, reject3) => {
          const userRetry = /* @__PURE__ */ __name(() => resolve2(retry()), "userRetry");
          const userFail = /* @__PURE__ */ __name(() => reject3(err), "userFail");
          userOnError(err, userRetry, userFail, retries + 1);
        });
      } else {
        throw err;
      }
    }).then((comp) => {
      if (thisRequest !== pendingRequest && pendingRequest) {
        return pendingRequest;
      }
      if (false) {
        warn$1$1(
          `Async component loader resolved to undefined. If you are using retry(), make sure to return its return value.`
        );
      }
      if (comp && (comp.__esModule || comp[Symbol.toStringTag] === "Module")) {
        comp = comp.default;
      }
      if (false) {
        throw new Error(`Invalid async component load result: ${comp}`);
      }
      resolvedComp = comp;
      return comp;
    }));
  }, "load");
  return /* @__PURE__ */ defineComponent({
    name: "AsyncComponentWrapper",
    __asyncLoader: load3,
    __asyncHydrate(el, instance, hydrate2) {
      const doHydrate = hydrateStrategy ? () => {
        const teardown = hydrateStrategy(
          hydrate2,
          (cb) => forEachElement(el, cb)
        );
        if (teardown) {
          (instance.bum || (instance.bum = [])).push(teardown);
        }
      } : hydrate2;
      if (resolvedComp) {
        doHydrate();
      } else {
        load3().then(() => !instance.isUnmounted && doHydrate());
      }
    },
    get __asyncResolved() {
      return resolvedComp;
    },
    setup() {
      const instance = currentInstance;
      markAsyncBoundary(instance);
      if (resolvedComp) {
        return () => createInnerComp(resolvedComp, instance);
      }
      const onError = /* @__PURE__ */ __name((err) => {
        pendingRequest = null;
        handleError(
          err,
          instance,
          13,
          !errorComponent
        );
      }, "onError");
      if (suspensible && instance.suspense || isInSSRComponentSetup) {
        return load3().then((comp) => {
          return () => createInnerComp(comp, instance);
        }).catch((err) => {
          onError(err);
          return () => errorComponent ? createVNode(errorComponent, {
            error: err
          }) : null;
        });
      }
      const loaded = ref(false);
      const error2 = ref();
      const delayed = ref(!!delay);
      if (delay) {
        setTimeout(() => {
          delayed.value = false;
        }, delay);
      }
      if (timeout != null) {
        setTimeout(() => {
          if (!loaded.value && !error2.value) {
            const err = new Error(
              `Async component timed out after ${timeout}ms.`
            );
            onError(err);
            error2.value = err;
          }
        }, timeout);
      }
      load3().then(() => {
        loaded.value = true;
        if (instance.parent && isKeepAlive(instance.parent.vnode)) {
          instance.parent.update();
        }
      }).catch((err) => {
        onError(err);
        error2.value = err;
      });
      return () => {
        if (loaded.value && resolvedComp) {
          return createInnerComp(resolvedComp, instance);
        } else if (error2.value && errorComponent) {
          return createVNode(errorComponent, {
            error: error2.value
          });
        } else if (loadingComponent && !delayed.value) {
          return createVNode(loadingComponent);
        }
      };
    }
  });
}
__name(defineAsyncComponent, "defineAsyncComponent");
function createInnerComp(comp, parent) {
  const { ref: ref22, props, children, ce } = parent.vnode;
  const vnode = createVNode(comp, props, children);
  vnode.ref = ref22;
  vnode.ce = ce;
  delete parent.vnode.ce;
  return vnode;
}
__name(createInnerComp, "createInnerComp");
const isKeepAlive = /* @__PURE__ */ __name((vnode) => vnode.type.__isKeepAlive, "isKeepAlive");
const KeepAliveImpl = {
  name: `KeepAlive`,
  // Marker for special handling inside the renderer. We are not using a ===
  // check directly on KeepAlive in the renderer, because importing it directly
  // would prevent it from being tree-shaken.
  __isKeepAlive: true,
  props: {
    include: [String, RegExp, Array],
    exclude: [String, RegExp, Array],
    max: [String, Number]
  },
  setup(props, { slots }) {
    const instance = getCurrentInstance();
    const sharedContext = instance.ctx;
    if (!sharedContext.renderer) {
      return () => {
        const children = slots.default && slots.default();
        return children && children.length === 1 ? children[0] : children;
      };
    }
    const cache2 = /* @__PURE__ */ new Map();
    const keys2 = /* @__PURE__ */ new Set();
    let current = null;
    if (false) {
      instance.__v_cache = cache2;
    }
    const parentSuspense = instance.suspense;
    const {
      renderer: {
        p: patch2,
        m: move,
        um: _unmount,
        o: { createElement: createElement2 }
      }
    } = sharedContext;
    const storageContainer = createElement2("div");
    sharedContext.activate = (vnode, container, anchor, namespace, optimized) => {
      const instance2 = vnode.component;
      move(vnode, container, anchor, 0, parentSuspense);
      patch2(
        instance2.vnode,
        vnode,
        container,
        anchor,
        instance2,
        parentSuspense,
        namespace,
        vnode.slotScopeIds,
        optimized
      );
      queuePostRenderEffect(() => {
        instance2.isDeactivated = false;
        if (instance2.a) {
          invokeArrayFns(instance2.a);
        }
        const vnodeHook = vnode.props && vnode.props.onVnodeMounted;
        if (vnodeHook) {
          invokeVNodeHook(vnodeHook, instance2.parent, vnode);
        }
      }, parentSuspense);
      if (false) {
        devtoolsComponentAdded(instance2);
      }
    };
    sharedContext.deactivate = (vnode) => {
      const instance2 = vnode.component;
      invalidateMount(instance2.m);
      invalidateMount(instance2.a);
      move(vnode, storageContainer, null, 1, parentSuspense);
      queuePostRenderEffect(() => {
        if (instance2.da) {
          invokeArrayFns(instance2.da);
        }
        const vnodeHook = vnode.props && vnode.props.onVnodeUnmounted;
        if (vnodeHook) {
          invokeVNodeHook(vnodeHook, instance2.parent, vnode);
        }
        instance2.isDeactivated = true;
      }, parentSuspense);
      if (false) {
        devtoolsComponentAdded(instance2);
      }
    };
    function unmount(vnode) {
      resetShapeFlag(vnode);
      _unmount(vnode, instance, parentSuspense, true);
    }
    __name(unmount, "unmount");
    function pruneCache(filter4) {
      cache2.forEach((vnode, key) => {
        const name2 = getComponentName(vnode.type);
        if (name2 && !filter4(name2)) {
          pruneCacheEntry(key);
        }
      });
    }
    __name(pruneCache, "pruneCache");
    function pruneCacheEntry(key) {
      const cached = cache2.get(key);
      if (cached && (!current || !isSameVNodeType(cached, current))) {
        unmount(cached);
      } else if (current) {
        resetShapeFlag(current);
      }
      cache2.delete(key);
      keys2.delete(key);
    }
    __name(pruneCacheEntry, "pruneCacheEntry");
    watch(
      () => [props.include, props.exclude],
      ([include, exclude]) => {
        include && pruneCache((name2) => matches$1(include, name2));
        exclude && pruneCache((name2) => !matches$1(exclude, name2));
      },
      // prune post-render after `current` has been updated
      { flush: "post", deep: true }
    );
    let pendingCacheKey = null;
    const cacheSubtree = /* @__PURE__ */ __name(() => {
      if (pendingCacheKey != null) {
        if (isSuspense(instance.subTree.type)) {
          queuePostRenderEffect(() => {
            cache2.set(pendingCacheKey, getInnerChild(instance.subTree));
          }, instance.subTree.suspense);
        } else {
          cache2.set(pendingCacheKey, getInnerChild(instance.subTree));
        }
      }
    }, "cacheSubtree");
    onMounted(cacheSubtree);
    onUpdated(cacheSubtree);
    onBeforeUnmount(() => {
      cache2.forEach((cached) => {
        const { subTree, suspense } = instance;
        const vnode = getInnerChild(subTree);
        if (cached.type === vnode.type && cached.key === vnode.key) {
          resetShapeFlag(vnode);
          const da = vnode.component.da;
          da && queuePostRenderEffect(da, suspense);
          return;
        }
        unmount(cached);
      });
    });
    return () => {
      pendingCacheKey = null;
      if (!slots.default) {
        return current = null;
      }
      const children = slots.default();
      const rawVNode = children[0];
      if (children.length > 1) {
        if (false) {
          warn$1$1(`KeepAlive should contain exactly one component child.`);
        }
        current = null;
        return children;
      } else if (!isVNode$1(rawVNode) || !(rawVNode.shapeFlag & 4) && !(rawVNode.shapeFlag & 128)) {
        current = null;
        return rawVNode;
      }
      let vnode = getInnerChild(rawVNode);
      if (vnode.type === Comment) {
        current = null;
        return vnode;
      }
      const comp = vnode.type;
      const name2 = getComponentName(
        isAsyncWrapper(vnode) ? vnode.type.__asyncResolved || {} : comp
      );
      const { include, exclude, max } = props;
      if (include && (!name2 || !matches$1(include, name2)) || exclude && name2 && matches$1(exclude, name2)) {
        vnode.shapeFlag &= ~256;
        current = vnode;
        return rawVNode;
      }
      const key = vnode.key == null ? comp : vnode.key;
      const cachedVNode = cache2.get(key);
      if (vnode.el) {
        vnode = cloneVNode(vnode);
        if (rawVNode.shapeFlag & 128) {
          rawVNode.ssContent = vnode;
        }
      }
      pendingCacheKey = key;
      if (cachedVNode) {
        vnode.el = cachedVNode.el;
        vnode.component = cachedVNode.component;
        if (vnode.transition) {
          setTransitionHooks(vnode, vnode.transition);
        }
        vnode.shapeFlag |= 512;
        keys2.delete(key);
        keys2.add(key);
      } else {
        keys2.add(key);
        if (max && keys2.size > parseInt(max, 10)) {
          pruneCacheEntry(keys2.values().next().value);
        }
      }
      vnode.shapeFlag |= 256;
      current = vnode;
      return isSuspense(rawVNode.type) ? rawVNode : vnode;
    };
  }
};
const KeepAlive = KeepAliveImpl;
function matches$1(pattern, name2) {
  if (isArray$b(pattern)) {
    return pattern.some((p2) => matches$1(p2, name2));
  } else if (isString$9(pattern)) {
    return pattern.split(",").includes(name2);
  } else if (isRegExp$4(pattern)) {
    pattern.lastIndex = 0;
    return pattern.test(name2);
  }
  return false;
}
__name(matches$1, "matches$1");
function onActivated(hook, target2) {
  registerKeepAliveHook(hook, "a", target2);
}
__name(onActivated, "onActivated");
function onDeactivated(hook, target2) {
  registerKeepAliveHook(hook, "da", target2);
}
__name(onDeactivated, "onDeactivated");
function registerKeepAliveHook(hook, type, target2 = currentInstance) {
  const wrappedHook = hook.__wdc || (hook.__wdc = () => {
    let current = target2;
    while (current) {
      if (current.isDeactivated) {
        return;
      }
      current = current.parent;
    }
    return hook();
  });
  injectHook(type, wrappedHook, target2);
  if (target2) {
    let current = target2.parent;
    while (current && current.parent) {
      if (isKeepAlive(current.parent.vnode)) {
        injectToKeepAliveRoot(wrappedHook, type, target2, current);
      }
      current = current.parent;
    }
  }
}
__name(registerKeepAliveHook, "registerKeepAliveHook");
function injectToKeepAliveRoot(hook, type, target2, keepAliveRoot) {
  const injected = injectHook(
    type,
    hook,
    keepAliveRoot,
    true
    /* prepend */
  );
  onUnmounted(() => {
    remove$2(keepAliveRoot[type], injected);
  }, target2);
}
__name(injectToKeepAliveRoot, "injectToKeepAliveRoot");
function resetShapeFlag(vnode) {
  vnode.shapeFlag &= ~256;
  vnode.shapeFlag &= ~512;
}
__name(resetShapeFlag, "resetShapeFlag");
function getInnerChild(vnode) {
  return vnode.shapeFlag & 128 ? vnode.ssContent : vnode;
}
__name(getInnerChild, "getInnerChild");
function injectHook(type, hook, target2 = currentInstance, prepend2 = false) {
  if (target2) {
    const hooks2 = target2[type] || (target2[type] = []);
    const wrappedHook = hook.__weh || (hook.__weh = (...args) => {
      pauseTracking();
      const reset2 = setCurrentInstance(target2);
      const res = callWithAsyncErrorHandling(hook, target2, type, args);
      reset2();
      resetTracking();
      return res;
    });
    if (prepend2) {
      hooks2.unshift(wrappedHook);
    } else {
      hooks2.push(wrappedHook);
    }
    return wrappedHook;
  } else if (false) {
    const apiName = toHandlerKey(ErrorTypeStrings$1[type].replace(/ hook$/, ""));
    warn$1$1(
      `${apiName} is called when there is no active component instance to be associated with. Lifecycle injection APIs can only be used during execution of setup(). If you are using async setup(), make sure to register lifecycle hooks before the first await statement.`
    );
  }
}
__name(injectHook, "injectHook");
const createHook = /* @__PURE__ */ __name((lifecycle2) => (hook, target2 = currentInstance) => {
  if (!isInSSRComponentSetup || lifecycle2 === "sp") {
    injectHook(lifecycle2, (...args) => hook(...args), target2);
  }
}, "createHook");
const onBeforeMount = createHook("bm");
const onMounted = createHook("m");
const onBeforeUpdate = createHook(
  "bu"
);
const onUpdated = createHook("u");
const onBeforeUnmount = createHook(
  "bum"
);
const onUnmounted = createHook("um");
const onServerPrefetch = createHook(
  "sp"
);
const onRenderTriggered = createHook("rtg");
const onRenderTracked = createHook("rtc");
function onErrorCaptured(hook, target2 = currentInstance) {
  injectHook("ec", hook, target2);
}
__name(onErrorCaptured, "onErrorCaptured");
const COMPONENTS = "components";
const DIRECTIVES = "directives";
function resolveComponent(name2, maybeSelfReference) {
  return resolveAsset(COMPONENTS, name2, true, maybeSelfReference) || name2;
}
__name(resolveComponent, "resolveComponent");
const NULL_DYNAMIC_COMPONENT = Symbol.for("v-ndc");
function resolveDynamicComponent(component) {
  if (isString$9(component)) {
    return resolveAsset(COMPONENTS, component, false) || component;
  } else {
    return component || NULL_DYNAMIC_COMPONENT;
  }
}
__name(resolveDynamicComponent, "resolveDynamicComponent");
function resolveDirective(name2) {
  return resolveAsset(DIRECTIVES, name2);
}
__name(resolveDirective, "resolveDirective");
function resolveAsset(type, name2, warnMissing = true, maybeSelfReference = false) {
  const instance = currentRenderingInstance || currentInstance;
  if (instance) {
    const Component = instance.type;
    if (type === COMPONENTS) {
      const selfName = getComponentName(
        Component,
        false
      );
      if (selfName && (selfName === name2 || selfName === camelize$1(name2) || selfName === capitalize$1(camelize$1(name2)))) {
        return Component;
      }
    }
    const res = (
      // local registration
      // check instance[type] first which is resolved for options API
      resolve$2(instance[type] || Component[type], name2) || // global registration
      resolve$2(instance.appContext[type], name2)
    );
    if (!res && maybeSelfReference) {
      return Component;
    }
    if (false) {
      const extra = type === COMPONENTS ? `
If this is a native custom element, make sure to exclude it from component resolution via compilerOptions.isCustomElement.` : ``;
      warn$1$1(`Failed to resolve ${type.slice(0, -1)}: ${name2}${extra}`);
    }
    return res;
  } else if (false) {
    warn$1$1(
      `resolve${capitalize$1(type.slice(0, -1))} can only be used in render() or setup().`
    );
  }
}
__name(resolveAsset, "resolveAsset");
function resolve$2(registry, name2) {
  return registry && (registry[name2] || registry[camelize$1(name2)] || registry[capitalize$1(camelize$1(name2))]);
}
__name(resolve$2, "resolve$2");
function renderList(source, renderItem, cache2, index2) {
  let ret;
  const cached = cache2 && cache2[index2];
  const sourceIsArray = isArray$b(source);
  if (sourceIsArray || isString$9(source)) {
    const sourceIsReactiveArray = sourceIsArray && isReactive(source);
    let needsWrap = false;
    if (sourceIsReactiveArray) {
      needsWrap = !isShallow(source);
      source = shallowReadArray(source);
    }
    ret = new Array(source.length);
    for (let i2 = 0, l2 = source.length; i2 < l2; i2++) {
      ret[i2] = renderItem(
        needsWrap ? toReactive$1(source[i2]) : source[i2],
        i2,
        void 0,
        cached && cached[i2]
      );
    }
  } else if (typeof source === "number") {
    if (false) {
      warn$1$1(`The v-for range expect an integer value but got ${source}.`);
    }
    ret = new Array(source);
    for (let i2 = 0; i2 < source; i2++) {
      ret[i2] = renderItem(i2 + 1, i2, void 0, cached && cached[i2]);
    }
  } else if (isObject$f(source)) {
    if (source[Symbol.iterator]) {
      ret = Array.from(
        source,
        (item3, i2) => renderItem(item3, i2, void 0, cached && cached[i2])
      );
    } else {
      const keys2 = Object.keys(source);
      ret = new Array(keys2.length);
      for (let i2 = 0, l2 = keys2.length; i2 < l2; i2++) {
        const key = keys2[i2];
        ret[i2] = renderItem(source[key], key, i2, cached && cached[i2]);
      }
    }
  } else {
    ret = [];
  }
  if (cache2) {
    cache2[index2] = ret;
  }
  return ret;
}
__name(renderList, "renderList");
function createSlots(slots, dynamicSlots) {
  for (let i2 = 0; i2 < dynamicSlots.length; i2++) {
    const slot = dynamicSlots[i2];
    if (isArray$b(slot)) {
      for (let j2 = 0; j2 < slot.length; j2++) {
        slots[slot[j2].name] = slot[j2].fn;
      }
    } else if (slot) {
      slots[slot.name] = slot.key ? (...args) => {
        const res = slot.fn(...args);
        if (res) res.key = slot.key;
        return res;
      } : slot.fn;
    }
  }
  return slots;
}
__name(createSlots, "createSlots");
function renderSlot(slots, name2, props = {}, fallback, noSlotted) {
  if (currentRenderingInstance.ce || currentRenderingInstance.parent && isAsyncWrapper(currentRenderingInstance.parent) && currentRenderingInstance.parent.ce) {
    if (name2 !== "default") props.name = name2;
    return openBlock(), createBlock(
      Fragment$1,
      null,
      [createVNode("slot", props, fallback && fallback())],
      64
    );
  }
  let slot = slots[name2];
  if (false) {
    warn$1$1(
      `SSR-optimized slot function detected in a non-SSR-optimized render function. You need to mark this component with $dynamic-slots in the parent template.`
    );
    slot = /* @__PURE__ */ __name(() => [], "slot");
  }
  if (slot && slot._c) {
    slot._d = false;
  }
  openBlock();
  const validSlotContent = slot && ensureValidVNode(slot(props));
  const slotKey = props.key || // slot content array of a dynamic conditional slot may have a branch
  // key attached in the `createSlots` helper, respect that
  validSlotContent && validSlotContent.key;
  const rendered = createBlock(
    Fragment$1,
    {
      key: (slotKey && !isSymbol$1(slotKey) ? slotKey : `_${name2}`) + // #7256 force differentiate fallback content from actual content
      (!validSlotContent && fallback ? "_fb" : "")
    },
    validSlotContent || (fallback ? fallback() : []),
    validSlotContent && slots._ === 1 ? 64 : -2
  );
  if (!noSlotted && rendered.scopeId) {
    rendered.slotScopeIds = [rendered.scopeId + "-s"];
  }
  if (slot && slot._c) {
    slot._d = true;
  }
  return rendered;
}
__name(renderSlot, "renderSlot");
function ensureValidVNode(vnodes) {
  return vnodes.some((child) => {
    if (!isVNode$1(child)) return true;
    if (child.type === Comment) return false;
    if (child.type === Fragment$1 && !ensureValidVNode(child.children))
      return false;
    return true;
  }) ? vnodes : null;
}
__name(ensureValidVNode, "ensureValidVNode");
function toHandlers(obj, preserveCaseIfNecessary) {
  const ret = {};
  if (false) {
    warn$1$1(`v-on with no argument expects an object value.`);
    return ret;
  }
  for (const key in obj) {
    ret[preserveCaseIfNecessary && /[A-Z]/.test(key) ? `on:${key}` : toHandlerKey(key)] = obj[key];
  }
  return ret;
}
__name(toHandlers, "toHandlers");
const getPublicInstance = /* @__PURE__ */ __name((i2) => {
  if (!i2) return null;
  if (isStatefulComponent(i2)) return getComponentPublicInstance(i2);
  return getPublicInstance(i2.parent);
}, "getPublicInstance");
const publicPropertiesMap = (
  // Move PURE marker to new line to workaround compiler discarding it
  // due to type annotation
  /* @__PURE__ */ extend$1(/* @__PURE__ */ Object.create(null), {
    $: /* @__PURE__ */ __name((i2) => i2, "$"),
    $el: /* @__PURE__ */ __name((i2) => i2.vnode.el, "$el"),
    $data: /* @__PURE__ */ __name((i2) => i2.data, "$data"),
    $props: /* @__PURE__ */ __name((i2) => false ? shallowReadonly(i2.props) : i2.props, "$props"),
    $attrs: /* @__PURE__ */ __name((i2) => false ? shallowReadonly(i2.attrs) : i2.attrs, "$attrs"),
    $slots: /* @__PURE__ */ __name((i2) => false ? shallowReadonly(i2.slots) : i2.slots, "$slots"),
    $refs: /* @__PURE__ */ __name((i2) => false ? shallowReadonly(i2.refs) : i2.refs, "$refs"),
    $parent: /* @__PURE__ */ __name((i2) => getPublicInstance(i2.parent), "$parent"),
    $root: /* @__PURE__ */ __name((i2) => getPublicInstance(i2.root), "$root"),
    $host: /* @__PURE__ */ __name((i2) => i2.ce, "$host"),
    $emit: /* @__PURE__ */ __name((i2) => i2.emit, "$emit"),
    $options: /* @__PURE__ */ __name((i2) => true ? resolveMergedOptions(i2) : i2.type, "$options"),
    $forceUpdate: /* @__PURE__ */ __name((i2) => i2.f || (i2.f = () => {
      queueJob(i2.update);
    }), "$forceUpdate"),
    $nextTick: /* @__PURE__ */ __name((i2) => i2.n || (i2.n = nextTick.bind(i2.proxy)), "$nextTick"),
    $watch: /* @__PURE__ */ __name((i2) => true ? instanceWatch.bind(i2) : NOOP, "$watch")
  })
);
const isReservedPrefix = /* @__PURE__ */ __name((key) => key === "_" || key === "$", "isReservedPrefix");
const hasSetupBinding = /* @__PURE__ */ __name((state, key) => state !== EMPTY_OBJ && !state.__isScriptSetup && hasOwn$3(state, key), "hasSetupBinding");
const PublicInstanceProxyHandlers = {
  get({ _: instance }, key) {
    if (key === "__v_skip") {
      return true;
    }
    const { ctx, setupState, data: data30, props, accessCache, type, appContext } = instance;
    if (false) {
      return true;
    }
    let normalizedProps;
    if (key[0] !== "$") {
      const n2 = accessCache[key];
      if (n2 !== void 0) {
        switch (n2) {
          case 1:
            return setupState[key];
          case 2:
            return data30[key];
          case 4:
            return ctx[key];
          case 3:
            return props[key];
        }
      } else if (hasSetupBinding(setupState, key)) {
        accessCache[key] = 1;
        return setupState[key];
      } else if (data30 !== EMPTY_OBJ && hasOwn$3(data30, key)) {
        accessCache[key] = 2;
        return data30[key];
      } else if (
        // only cache other properties when instance has declared (thus stable)
        // props
        (normalizedProps = instance.propsOptions[0]) && hasOwn$3(normalizedProps, key)
      ) {
        accessCache[key] = 3;
        return props[key];
      } else if (ctx !== EMPTY_OBJ && hasOwn$3(ctx, key)) {
        accessCache[key] = 4;
        return ctx[key];
      } else if (shouldCacheAccess) {
        accessCache[key] = 0;
      }
    }
    const publicGetter = publicPropertiesMap[key];
    let cssModule, globalProperties;
    if (publicGetter) {
      if (key === "$attrs") {
        track(instance.attrs, "get", "");
      } else if (false) {
        track(instance, "get", key);
      }
      return publicGetter(instance);
    } else if (
      // css module (injected by vue-loader)
      (cssModule = type.__cssModules) && (cssModule = cssModule[key])
    ) {
      return cssModule;
    } else if (ctx !== EMPTY_OBJ && hasOwn$3(ctx, key)) {
      accessCache[key] = 4;
      return ctx[key];
    } else if (
      // global properties
      globalProperties = appContext.config.globalProperties, hasOwn$3(globalProperties, key)
    ) {
      {
        return globalProperties[key];
      }
    } else if (false) {
      if (data30 !== EMPTY_OBJ && isReservedPrefix(key[0]) && hasOwn$3(data30, key)) {
        warn$1$1(
          `Property ${JSON.stringify(
            key
          )} must be accessed via $data because it starts with a reserved character ("$" or "_") and is not proxied on the render context.`
        );
      } else if (instance === currentRenderingInstance) {
        warn$1$1(
          `Property ${JSON.stringify(key)} was accessed during render but is not defined on instance.`
        );
      }
    }
  },
  set({ _: instance }, key, value3) {
    const { data: data30, setupState, ctx } = instance;
    if (hasSetupBinding(setupState, key)) {
      setupState[key] = value3;
      return true;
    } else if (false) {
      warn$1$1(`Cannot mutate <script setup> binding "${key}" from Options API.`);
      return false;
    } else if (data30 !== EMPTY_OBJ && hasOwn$3(data30, key)) {
      data30[key] = value3;
      return true;
    } else if (hasOwn$3(instance.props, key)) {
      return false;
    }
    if (key[0] === "$" && key.slice(1) in instance) {
      return false;
    } else {
      if (false) {
        Object.defineProperty(ctx, key, {
          enumerable: true,
          configurable: true,
          value: value3
        });
      } else {
        ctx[key] = value3;
      }
    }
    return true;
  },
  has({
    _: { data: data30, setupState, accessCache, ctx, appContext, propsOptions }
  }, key) {
    let normalizedProps;
    return !!accessCache[key] || data30 !== EMPTY_OBJ && hasOwn$3(data30, key) || hasSetupBinding(setupState, key) || (normalizedProps = propsOptions[0]) && hasOwn$3(normalizedProps, key) || hasOwn$3(ctx, key) || hasOwn$3(publicPropertiesMap, key) || hasOwn$3(appContext.config.globalProperties, key);
  },
  defineProperty(target2, key, descriptor) {
    if (descriptor.get != null) {
      target2._.accessCache[key] = 0;
    } else if (hasOwn$3(descriptor, "value")) {
      this.set(target2, key, descriptor.value, null);
    }
    return Reflect.defineProperty(target2, key, descriptor);
  }
};
if (false) {
  PublicInstanceProxyHandlers.ownKeys = (target2) => {
    warn$1$1(
      `Avoid app logic that relies on enumerating keys on a component instance. The keys will be empty in production mode to avoid performance overhead.`
    );
    return Reflect.ownKeys(target2);
  };
}
const RuntimeCompiledPublicInstanceProxyHandlers = /* @__PURE__ */ extend$1({}, PublicInstanceProxyHandlers, {
  get(target2, key) {
    if (key === Symbol.unscopables) {
      return;
    }
    return PublicInstanceProxyHandlers.get(target2, key, target2);
  },
  has(_2, key) {
    const has2 = key[0] !== "_" && !isGloballyAllowed(key);
    if (false) {
      warn$1$1(
        `Property ${JSON.stringify(
          key
        )} should not start with _ which is a reserved prefix for Vue internals.`
      );
    }
    return has2;
  }
});
function createDevRenderContext(instance) {
  const target2 = {};
  Object.defineProperty(target2, `_`, {
    configurable: true,
    enumerable: false,
    get: /* @__PURE__ */ __name(() => instance, "get")
  });
  Object.keys(publicPropertiesMap).forEach((key) => {
    Object.defineProperty(target2, key, {
      configurable: true,
      enumerable: false,
      get: /* @__PURE__ */ __name(() => publicPropertiesMap[key](instance), "get"),
      // intercepted by the proxy so no need for implementation,
      // but needed to prevent set errors
      set: NOOP
    });
  });
  return target2;
}
__name(createDevRenderContext, "createDevRenderContext");
function exposePropsOnRenderContext(instance) {
  const {
    ctx,
    propsOptions: [propsOptions]
  } = instance;
  if (propsOptions) {
    Object.keys(propsOptions).forEach((key) => {
      Object.defineProperty(ctx, key, {
        enumerable: true,
        configurable: true,
        get: /* @__PURE__ */ __name(() => instance.props[key], "get"),
        set: NOOP
      });
    });
  }
}
__name(exposePropsOnRenderContext, "exposePropsOnRenderContext");
function exposeSetupStateOnRenderContext(instance) {
  const { ctx, setupState } = instance;
  Object.keys(toRaw(setupState)).forEach((key) => {
    if (!setupState.__isScriptSetup) {
      if (isReservedPrefix(key[0])) {
        warn$1$1(
          `setup() return property ${JSON.stringify(
            key
          )} should not start with "$" or "_" which are reserved prefixes for Vue internals.`
        );
        return;
      }
      Object.defineProperty(ctx, key, {
        enumerable: true,
        configurable: true,
        get: /* @__PURE__ */ __name(() => setupState[key], "get"),
        set: NOOP
      });
    }
  });
}
__name(exposeSetupStateOnRenderContext, "exposeSetupStateOnRenderContext");
const warnRuntimeUsage = /* @__PURE__ */ __name((method) => warn$1$1(
  `${method}() is a compiler-hint helper that is only usable inside <script setup> of a single file component. Its arguments should be compiled away and passing it at runtime has no effect.`
), "warnRuntimeUsage");
function defineProps() {
  if (false) {
    warnRuntimeUsage(`defineProps`);
  }
  return null;
}
__name(defineProps, "defineProps");
function defineEmits() {
  if (false) {
    warnRuntimeUsage(`defineEmits`);
  }
  return null;
}
__name(defineEmits, "defineEmits");
function defineExpose(exposed) {
  if (false) {
    warnRuntimeUsage(`defineExpose`);
  }
}
__name(defineExpose, "defineExpose");
function defineOptions(options5) {
  if (false) {
    warnRuntimeUsage(`defineOptions`);
  }
}
__name(defineOptions, "defineOptions");
function defineSlots() {
  if (false) {
    warnRuntimeUsage(`defineSlots`);
  }
  return null;
}
__name(defineSlots, "defineSlots");
function defineModel() {
  if (false) {
    warnRuntimeUsage("defineModel");
  }
}
__name(defineModel, "defineModel");
function withDefaults(props, defaults2) {
  if (false) {
    warnRuntimeUsage(`withDefaults`);
  }
  return null;
}
__name(withDefaults, "withDefaults");
function useSlots() {
  return getContext().slots;
}
__name(useSlots, "useSlots");
function useAttrs() {
  return getContext().attrs;
}
__name(useAttrs, "useAttrs");
function getContext() {
  const i2 = getCurrentInstance();
  if (false) {
    warn$1$1(`useContext() called without active instance.`);
  }
  return i2.setupContext || (i2.setupContext = createSetupContext(i2));
}
__name(getContext, "getContext");
function normalizePropsOrEmits(props) {
  return isArray$b(props) ? props.reduce(
    (normalized, p2) => (normalized[p2] = null, normalized),
    {}
  ) : props;
}
__name(normalizePropsOrEmits, "normalizePropsOrEmits");
function mergeDefaults(raw, defaults2) {
  const props = normalizePropsOrEmits(raw);
  for (const key in defaults2) {
    if (key.startsWith("__skip")) continue;
    let opt = props[key];
    if (opt) {
      if (isArray$b(opt) || isFunction$c(opt)) {
        opt = props[key] = { type: opt, default: defaults2[key] };
      } else {
        opt.default = defaults2[key];
      }
    } else if (opt === null) {
      opt = props[key] = { default: defaults2[key] };
    } else if (false) {
      warn$1$1(`props default key "${key}" has no corresponding declaration.`);
    }
    if (opt && defaults2[`__skip_${key}`]) {
      opt.skipFactory = true;
    }
  }
  return props;
}
__name(mergeDefaults, "mergeDefaults");
function mergeModels(a2, b2) {
  if (!a2 || !b2) return a2 || b2;
  if (isArray$b(a2) && isArray$b(b2)) return a2.concat(b2);
  return extend$1({}, normalizePropsOrEmits(a2), normalizePropsOrEmits(b2));
}
__name(mergeModels, "mergeModels");
function createPropsRestProxy(props, excludedKeys) {
  const ret = {};
  for (const key in props) {
    if (!excludedKeys.includes(key)) {
      Object.defineProperty(ret, key, {
        enumerable: true,
        get: /* @__PURE__ */ __name(() => props[key], "get")
      });
    }
  }
  return ret;
}
__name(createPropsRestProxy, "createPropsRestProxy");
function withAsyncContext(getAwaitable) {
  const ctx = getCurrentInstance();
  if (false) {
    warn$1$1(
      `withAsyncContext called without active current instance. This is likely a bug.`
    );
  }
  let awaitable = getAwaitable();
  unsetCurrentInstance();
  if (isPromise$1(awaitable)) {
    awaitable = awaitable.catch((e2) => {
      setCurrentInstance(ctx);
      throw e2;
    });
  }
  return [awaitable, () => setCurrentInstance(ctx)];
}
__name(withAsyncContext, "withAsyncContext");
function createDuplicateChecker() {
  const cache2 = /* @__PURE__ */ Object.create(null);
  return (type, key) => {
    if (cache2[key]) {
      warn$1$1(`${type} property "${key}" is already defined in ${cache2[key]}.`);
    } else {
      cache2[key] = type;
    }
  };
}
__name(createDuplicateChecker, "createDuplicateChecker");
let shouldCacheAccess = true;
function applyOptions(instance) {
  const options5 = resolveMergedOptions(instance);
  const publicThis = instance.proxy;
  const ctx = instance.ctx;
  shouldCacheAccess = false;
  if (options5.beforeCreate) {
    callHook$1(options5.beforeCreate, instance, "bc");
  }
  const {
    // state
    data: dataOptions,
    computed: computedOptions,
    methods,
    watch: watchOptions,
    provide: provideOptions,
    inject: injectOptions,
    // lifecycle
    created: created4,
    beforeMount: beforeMount5,
    mounted: mounted30,
    beforeUpdate: beforeUpdate3,
    updated: updated17,
    activated,
    deactivated,
    beforeDestroy,
    beforeUnmount: beforeUnmount19,
    destroyed,
    unmounted: unmounted7,
    render: render2,
    renderTracked,
    renderTriggered,
    errorCaptured,
    serverPrefetch,
    // public API
    expose,
    inheritAttrs,
    // assets
    components,
    directives,
    filters
  } = options5;
  const checkDuplicateProperties = false ? createDuplicateChecker() : null;
  if (false) {
    const [propsOptions] = instance.propsOptions;
    if (propsOptions) {
      for (const key in propsOptions) {
        checkDuplicateProperties("Props", key);
      }
    }
  }
  if (injectOptions) {
    resolveInjections(injectOptions, ctx, checkDuplicateProperties);
  }
  if (methods) {
    for (const key in methods) {
      const methodHandler = methods[key];
      if (isFunction$c(methodHandler)) {
        if (false) {
          Object.defineProperty(ctx, key, {
            value: methodHandler.bind(publicThis),
            configurable: true,
            enumerable: true,
            writable: true
          });
        } else {
          ctx[key] = methodHandler.bind(publicThis);
        }
        if (false) {
          checkDuplicateProperties("Methods", key);
        }
      } else if (false) {
        warn$1$1(
          `Method "${key}" has type "${typeof methodHandler}" in the component definition. Did you reference the function correctly?`
        );
      }
    }
  }
  if (dataOptions) {
    if (false) {
      warn$1$1(
        `The data option must be a function. Plain object usage is no longer supported.`
      );
    }
    const data30 = dataOptions.call(publicThis, publicThis);
    if (false) {
      warn$1$1(
        `data() returned a Promise - note data() cannot be async; If you intend to perform data fetching before component renders, use async setup() + <Suspense>.`
      );
    }
    if (!isObject$f(data30)) {
    } else {
      instance.data = reactive(data30);
      if (false) {
        for (const key in data30) {
          checkDuplicateProperties("Data", key);
          if (!isReservedPrefix(key[0])) {
            Object.defineProperty(ctx, key, {
              configurable: true,
              enumerable: true,
              get: /* @__PURE__ */ __name(() => data30[key], "get"),
              set: NOOP
            });
          }
        }
      }
    }
  }
  shouldCacheAccess = true;
  if (computedOptions) {
    for (const key in computedOptions) {
      const opt = computedOptions[key];
      const get3 = isFunction$c(opt) ? opt.bind(publicThis, publicThis) : isFunction$c(opt.get) ? opt.get.bind(publicThis, publicThis) : NOOP;
      if (false) {
        warn$1$1(`Computed property "${key}" has no getter.`);
      }
      const set3 = !isFunction$c(opt) && isFunction$c(opt.set) ? opt.set.bind(publicThis) : false ? () => {
        warn$1$1(
          `Write operation failed: computed property "${key}" is readonly.`
        );
      } : NOOP;
      const c2 = computed({
        get: get3,
        set: set3
      });
      Object.defineProperty(ctx, key, {
        enumerable: true,
        configurable: true,
        get: /* @__PURE__ */ __name(() => c2.value, "get"),
        set: /* @__PURE__ */ __name((v2) => c2.value = v2, "set")
      });
      if (false) {
        checkDuplicateProperties("Computed", key);
      }
    }
  }
  if (watchOptions) {
    for (const key in watchOptions) {
      createWatcher(watchOptions[key], ctx, publicThis, key);
    }
  }
  if (provideOptions) {
    const provides = isFunction$c(provideOptions) ? provideOptions.call(publicThis) : provideOptions;
    Reflect.ownKeys(provides).forEach((key) => {
      provide(key, provides[key]);
    });
  }
  if (created4) {
    callHook$1(created4, instance, "c");
  }
  function registerLifecycleHook(register3, hook) {
    if (isArray$b(hook)) {
      hook.forEach((_hook4) => register3(_hook4.bind(publicThis)));
    } else if (hook) {
      register3(hook.bind(publicThis));
    }
  }
  __name(registerLifecycleHook, "registerLifecycleHook");
  registerLifecycleHook(onBeforeMount, beforeMount5);
  registerLifecycleHook(onMounted, mounted30);
  registerLifecycleHook(onBeforeUpdate, beforeUpdate3);
  registerLifecycleHook(onUpdated, updated17);
  registerLifecycleHook(onActivated, activated);
  registerLifecycleHook(onDeactivated, deactivated);
  registerLifecycleHook(onErrorCaptured, errorCaptured);
  registerLifecycleHook(onRenderTracked, renderTracked);
  registerLifecycleHook(onRenderTriggered, renderTriggered);
  registerLifecycleHook(onBeforeUnmount, beforeUnmount19);
  registerLifecycleHook(onUnmounted, unmounted7);
  registerLifecycleHook(onServerPrefetch, serverPrefetch);
  if (isArray$b(expose)) {
    if (expose.length) {
      const exposed = instance.exposed || (instance.exposed = {});
      expose.forEach((key) => {
        Object.defineProperty(exposed, key, {
          get: /* @__PURE__ */ __name(() => publicThis[key], "get"),
          set: /* @__PURE__ */ __name((val) => publicThis[key] = val, "set")
        });
      });
    } else if (!instance.exposed) {
      instance.exposed = {};
    }
  }
  if (render2 && instance.render === NOOP) {
    instance.render = render2;
  }
  if (inheritAttrs != null) {
    instance.inheritAttrs = inheritAttrs;
  }
  if (components) instance.components = components;
  if (directives) instance.directives = directives;
  if (serverPrefetch) {
    markAsyncBoundary(instance);
  }
}
__name(applyOptions, "applyOptions");
function resolveInjections(injectOptions, ctx, checkDuplicateProperties = NOOP) {
  if (isArray$b(injectOptions)) {
    injectOptions = normalizeInject(injectOptions);
  }
  for (const key in injectOptions) {
    const opt = injectOptions[key];
    let injected;
    if (isObject$f(opt)) {
      if ("default" in opt) {
        injected = inject(
          opt.from || key,
          opt.default,
          true
        );
      } else {
        injected = inject(opt.from || key);
      }
    } else {
      injected = inject(opt);
    }
    if (isRef(injected)) {
      Object.defineProperty(ctx, key, {
        enumerable: true,
        configurable: true,
        get: /* @__PURE__ */ __name(() => injected.value, "get"),
        set: /* @__PURE__ */ __name((v2) => injected.value = v2, "set")
      });
    } else {
      ctx[key] = injected;
    }
    if (false) {
      checkDuplicateProperties("Inject", key);
    }
  }
}
__name(resolveInjections, "resolveInjections");
function callHook$1(hook, instance, type) {
  callWithAsyncErrorHandling(
    isArray$b(hook) ? hook.map((h2) => h2.bind(instance.proxy)) : hook.bind(instance.proxy),
    instance,
    type
  );
}
__name(callHook$1, "callHook$1");
function createWatcher(raw, ctx, publicThis, key) {
  let getter = key.includes(".") ? createPathGetter(publicThis, key) : () => publicThis[key];
  if (isString$9(raw)) {
    const handler14 = ctx[raw];
    if (isFunction$c(handler14)) {
      {
        watch(getter, handler14);
      }
    } else if (false) {
      warn$1$1(`Invalid watch handler specified by key "${raw}"`, handler14);
    }
  } else if (isFunction$c(raw)) {
    {
      watch(getter, raw.bind(publicThis));
    }
  } else if (isObject$f(raw)) {
    if (isArray$b(raw)) {
      raw.forEach((r2) => createWatcher(r2, ctx, publicThis, key));
    } else {
      const handler14 = isFunction$c(raw.handler) ? raw.handler.bind(publicThis) : ctx[raw.handler];
      if (isFunction$c(handler14)) {
        watch(getter, handler14, raw);
      } else if (false) {
        warn$1$1(`Invalid watch handler specified by key "${raw.handler}"`, handler14);
      }
    }
  } else if (false) {
    warn$1$1(`Invalid watch option: "${key}"`, raw);
  }
}
__name(createWatcher, "createWatcher");
function resolveMergedOptions(instance) {
  const base2 = instance.type;
  const { mixins, extends: extendsOptions } = base2;
  const {
    mixins: globalMixins,
    optionsCache: cache2,
    config: { optionMergeStrategies }
  } = instance.appContext;
  const cached = cache2.get(base2);
  let resolved;
  if (cached) {
    resolved = cached;
  } else if (!globalMixins.length && !mixins && !extendsOptions) {
    {
      resolved = base2;
    }
  } else {
    resolved = {};
    if (globalMixins.length) {
      globalMixins.forEach(
        (m2) => mergeOptions$1(resolved, m2, optionMergeStrategies, true)
      );
    }
    mergeOptions$1(resolved, base2, optionMergeStrategies);
  }
  if (isObject$f(base2)) {
    cache2.set(base2, resolved);
  }
  return resolved;
}
__name(resolveMergedOptions, "resolveMergedOptions");
function mergeOptions$1(to, from2, strats, asMixin = false) {
  const { mixins, extends: extendsOptions } = from2;
  if (extendsOptions) {
    mergeOptions$1(to, extendsOptions, strats, true);
  }
  if (mixins) {
    mixins.forEach(
      (m2) => mergeOptions$1(to, m2, strats, true)
    );
  }
  for (const key in from2) {
    if (asMixin && key === "expose") {
    } else {
      const strat = internalOptionMergeStrats[key] || strats && strats[key];
      to[key] = strat ? strat(to[key], from2[key]) : from2[key];
    }
  }
  return to;
}
__name(mergeOptions$1, "mergeOptions$1");
const internalOptionMergeStrats = {
  data: mergeDataFn,
  props: mergeEmitsOrPropsOptions,
  emits: mergeEmitsOrPropsOptions,
  // objects
  methods: mergeObjectOptions,
  computed: mergeObjectOptions,
  // lifecycle
  beforeCreate: mergeAsArray,
  created: mergeAsArray,
  beforeMount: mergeAsArray,
  mounted: mergeAsArray,
  beforeUpdate: mergeAsArray,
  updated: mergeAsArray,
  beforeDestroy: mergeAsArray,
  beforeUnmount: mergeAsArray,
  destroyed: mergeAsArray,
  unmounted: mergeAsArray,
  activated: mergeAsArray,
  deactivated: mergeAsArray,
  errorCaptured: mergeAsArray,
  serverPrefetch: mergeAsArray,
  // assets
  components: mergeObjectOptions,
  directives: mergeObjectOptions,
  // watch
  watch: mergeWatchOptions,
  // provide / inject
  provide: mergeDataFn,
  inject: mergeInject
};
function mergeDataFn(to, from2) {
  if (!from2) {
    return to;
  }
  if (!to) {
    return from2;
  }
  return /* @__PURE__ */ __name(function mergedDataFn() {
    return extend$1(
      isFunction$c(to) ? to.call(this, this) : to,
      isFunction$c(from2) ? from2.call(this, this) : from2
    );
  }, "mergedDataFn");
}
__name(mergeDataFn, "mergeDataFn");
function mergeInject(to, from2) {
  return mergeObjectOptions(normalizeInject(to), normalizeInject(from2));
}
__name(mergeInject, "mergeInject");
function normalizeInject(raw) {
  if (isArray$b(raw)) {
    const res = {};
    for (let i2 = 0; i2 < raw.length; i2++) {
      res[raw[i2]] = raw[i2];
    }
    return res;
  }
  return raw;
}
__name(normalizeInject, "normalizeInject");
function mergeAsArray(to, from2) {
  return to ? [...new Set([].concat(to, from2))] : from2;
}
__name(mergeAsArray, "mergeAsArray");
function mergeObjectOptions(to, from2) {
  return to ? extend$1(/* @__PURE__ */ Object.create(null), to, from2) : from2;
}
__name(mergeObjectOptions, "mergeObjectOptions");
function mergeEmitsOrPropsOptions(to, from2) {
  if (to) {
    if (isArray$b(to) && isArray$b(from2)) {
      return [.../* @__PURE__ */ new Set([...to, ...from2])];
    }
    return extend$1(
      /* @__PURE__ */ Object.create(null),
      normalizePropsOrEmits(to),
      normalizePropsOrEmits(from2 != null ? from2 : {})
    );
  } else {
    return from2;
  }
}
__name(mergeEmitsOrPropsOptions, "mergeEmitsOrPropsOptions");
function mergeWatchOptions(to, from2) {
  if (!to) return from2;
  if (!from2) return to;
  const merged = extend$1(/* @__PURE__ */ Object.create(null), to);
  for (const key in from2) {
    merged[key] = mergeAsArray(to[key], from2[key]);
  }
  return merged;
}
__name(mergeWatchOptions, "mergeWatchOptions");
function createAppContext() {
  return {
    app: null,
    config: {
      isNativeTag: NO,
      performance: false,
      globalProperties: {},
      optionMergeStrategies: {},
      errorHandler: void 0,
      warnHandler: void 0,
      compilerOptions: {}
    },
    mixins: [],
    components: {},
    directives: {},
    provides: /* @__PURE__ */ Object.create(null),
    optionsCache: /* @__PURE__ */ new WeakMap(),
    propsCache: /* @__PURE__ */ new WeakMap(),
    emitsCache: /* @__PURE__ */ new WeakMap()
  };
}
__name(createAppContext, "createAppContext");
let uid$1 = 0;
function createAppAPI(render2, hydrate2) {
  return /* @__PURE__ */ __name(function createApp2(rootComponent, rootProps = null) {
    if (!isFunction$c(rootComponent)) {
      rootComponent = extend$1({}, rootComponent);
    }
    if (rootProps != null && !isObject$f(rootProps)) {
      rootProps = null;
    }
    const context = createAppContext();
    const installedPlugins = /* @__PURE__ */ new WeakSet();
    const pluginCleanupFns = [];
    let isMounted = false;
    const app2 = context.app = {
      _uid: uid$1++,
      _component: rootComponent,
      _props: rootProps,
      _container: null,
      _context: context,
      _instance: null,
      version,
      get config() {
        return context.config;
      },
      set config(v2) {
        if (false) {
          warn$1$1(
            `app.config cannot be replaced. Modify individual options instead.`
          );
        }
      },
      use(plugin, ...options5) {
        if (installedPlugins.has(plugin)) {
        } else if (plugin && isFunction$c(plugin.install)) {
          installedPlugins.add(plugin);
          plugin.install(app2, ...options5);
        } else if (isFunction$c(plugin)) {
          installedPlugins.add(plugin);
          plugin(app2, ...options5);
        } else if (false) {
          warn$1$1(
            `A plugin must either be a function or an object with an "install" function.`
          );
        }
        return app2;
      },
      mixin(mixin) {
        if (true) {
          if (!context.mixins.includes(mixin)) {
            context.mixins.push(mixin);
          } else if (false) {
            warn$1$1(
              "Mixin has already been applied to target app" + (mixin.name ? `: ${mixin.name}` : "")
            );
          }
        } else if (false) {
          warn$1$1("Mixins are only available in builds supporting Options API");
        }
        return app2;
      },
      component(name2, component) {
        if (false) {
          validateComponentName(name2, context.config);
        }
        if (!component) {
          return context.components[name2];
        }
        if (false) {
          warn$1$1(`Component "${name2}" has already been registered in target app.`);
        }
        context.components[name2] = component;
        return app2;
      },
      directive(name2, directive) {
        if (false) {
          validateDirectiveName(name2);
        }
        if (!directive) {
          return context.directives[name2];
        }
        if (false) {
          warn$1$1(`Directive "${name2}" has already been registered in target app.`);
        }
        context.directives[name2] = directive;
        return app2;
      },
      mount(rootContainer, isHydrate, namespace) {
        if (!isMounted) {
          if (false) {
            warn$1$1(
              `There is already an app instance mounted on the host container.
 If you want to mount another app on the same host container, you need to unmount the previous app by calling \`app.unmount()\` first.`
            );
          }
          const vnode = app2._ceVNode || createVNode(rootComponent, rootProps);
          vnode.appContext = context;
          if (namespace === true) {
            namespace = "svg";
          } else if (namespace === false) {
            namespace = void 0;
          }
          if (false) {
            context.reload = () => {
              render2(
                cloneVNode(vnode),
                rootContainer,
                namespace
              );
            };
          }
          if (isHydrate && hydrate2) {
            hydrate2(vnode, rootContainer);
          } else {
            render2(vnode, rootContainer, namespace);
          }
          isMounted = true;
          app2._container = rootContainer;
          rootContainer.__vue_app__ = app2;
          if (false) {
            app2._instance = vnode.component;
            devtoolsInitApp(app2, version);
          }
          return getComponentPublicInstance(vnode.component);
        } else if (false) {
          warn$1$1(
            `App has already been mounted.
If you want to remount the same app, move your app creation logic into a factory function and create fresh app instances for each mount - e.g. \`const createMyApp = () => createApp(App)\``
          );
        }
      },
      onUnmount(cleanupFn) {
        if (false) {
          warn$1$1(
            `Expected function as first argument to app.onUnmount(), but got ${typeof cleanupFn}`
          );
        }
        pluginCleanupFns.push(cleanupFn);
      },
      unmount() {
        if (isMounted) {
          callWithAsyncErrorHandling(
            pluginCleanupFns,
            app2._instance,
            16
          );
          render2(null, app2._container);
          if (false) {
            app2._instance = null;
            devtoolsUnmountApp(app2);
          }
          delete app2._container.__vue_app__;
        } else if (false) {
          warn$1$1(`Cannot unmount an app that is not mounted.`);
        }
      },
      provide(key, value3) {
        if (false) {
          warn$1$1(
            `App already provides property with key "${String(key)}". It will be overwritten with the new value.`
          );
        }
        context.provides[key] = value3;
        return app2;
      },
      runWithContext(fn) {
        const lastApp = currentApp;
        currentApp = app2;
        try {
          return fn();
        } finally {
          currentApp = lastApp;
        }
      }
    };
    return app2;
  }, "createApp");
}
__name(createAppAPI, "createAppAPI");
let currentApp = null;
function provide(key, value3) {
  if (!currentInstance) {
    if (false) {
      warn$1$1(`provide() can only be used inside setup().`);
    }
  } else {
    let provides = currentInstance.provides;
    const parentProvides = currentInstance.parent && currentInstance.parent.provides;
    if (parentProvides === provides) {
      provides = currentInstance.provides = Object.create(parentProvides);
    }
    provides[key] = value3;
  }
}
__name(provide, "provide");
function inject(key, defaultValue2, treatDefaultAsFactory = false) {
  const instance = currentInstance || currentRenderingInstance;
  if (instance || currentApp) {
    const provides = currentApp ? currentApp._context.provides : instance ? instance.parent == null ? instance.vnode.appContext && instance.vnode.appContext.provides : instance.parent.provides : void 0;
    if (provides && key in provides) {
      return provides[key];
    } else if (arguments.length > 1) {
      return treatDefaultAsFactory && isFunction$c(defaultValue2) ? defaultValue2.call(instance && instance.proxy) : defaultValue2;
    } else if (false) {
      warn$1$1(`injection "${String(key)}" not found.`);
    }
  } else if (false) {
    warn$1$1(`inject() can only be used inside setup() or functional components.`);
  }
}
__name(inject, "inject");
function hasInjectionContext() {
  return !!(currentInstance || currentRenderingInstance || currentApp);
}
__name(hasInjectionContext, "hasInjectionContext");
const internalObjectProto = {};
const createInternalObject = /* @__PURE__ */ __name(() => Object.create(internalObjectProto), "createInternalObject");
const isInternalObject = /* @__PURE__ */ __name((obj) => Object.getPrototypeOf(obj) === internalObjectProto, "isInternalObject");
function initProps(instance, rawProps, isStateful, isSSR = false) {
  const props = {};
  const attrs7 = createInternalObject();
  instance.propsDefaults = /* @__PURE__ */ Object.create(null);
  setFullProps(instance, rawProps, props, attrs7);
  for (const key in instance.propsOptions[0]) {
    if (!(key in props)) {
      props[key] = void 0;
    }
  }
  if (false) {
    validateProps(rawProps || {}, props, instance);
  }
  if (isStateful) {
    instance.props = isSSR ? props : shallowReactive(props);
  } else {
    if (!instance.type.props) {
      instance.props = attrs7;
    } else {
      instance.props = props;
    }
  }
  instance.attrs = attrs7;
}
__name(initProps, "initProps");
function isInHmrContext(instance) {
  while (instance) {
    if (instance.type.__hmrId) return true;
    instance = instance.parent;
  }
}
__name(isInHmrContext, "isInHmrContext");
function updateProps(instance, rawProps, rawPrevProps, optimized) {
  const {
    props,
    attrs: attrs7,
    vnode: { patchFlag }
  } = instance;
  const rawCurrentProps = toRaw(props);
  const [options5] = instance.propsOptions;
  let hasAttrsChanged = false;
  if (
    // always force full diff in dev
    // - #1942 if hmr is enabled with sfc component
    // - vite#872 non-sfc component used by sfc component
    (optimized || patchFlag > 0) && !(patchFlag & 16)
  ) {
    if (patchFlag & 8) {
      const propsToUpdate = instance.vnode.dynamicProps;
      for (let i2 = 0; i2 < propsToUpdate.length; i2++) {
        let key = propsToUpdate[i2];
        if (isEmitListener(instance.emitsOptions, key)) {
          continue;
        }
        const value3 = rawProps[key];
        if (options5) {
          if (hasOwn$3(attrs7, key)) {
            if (value3 !== attrs7[key]) {
              attrs7[key] = value3;
              hasAttrsChanged = true;
            }
          } else {
            const camelizedKey = camelize$1(key);
            props[camelizedKey] = resolvePropValue(
              options5,
              rawCurrentProps,
              camelizedKey,
              value3,
              instance,
              false
            );
          }
        } else {
          if (value3 !== attrs7[key]) {
            attrs7[key] = value3;
            hasAttrsChanged = true;
          }
        }
      }
    }
  } else {
    if (setFullProps(instance, rawProps, props, attrs7)) {
      hasAttrsChanged = true;
    }
    let kebabKey;
    for (const key in rawCurrentProps) {
      if (!rawProps || // for camelCase
      !hasOwn$3(rawProps, key) && // it's possible the original props was passed in as kebab-case
      // and converted to camelCase (#955)
      ((kebabKey = hyphenate$1(key)) === key || !hasOwn$3(rawProps, kebabKey))) {
        if (options5) {
          if (rawPrevProps && // for camelCase
          (rawPrevProps[key] !== void 0 || // for kebab-case
          rawPrevProps[kebabKey] !== void 0)) {
            props[key] = resolvePropValue(
              options5,
              rawCurrentProps,
              key,
              void 0,
              instance,
              true
            );
          }
        } else {
          delete props[key];
        }
      }
    }
    if (attrs7 !== rawCurrentProps) {
      for (const key in attrs7) {
        if (!rawProps || !hasOwn$3(rawProps, key) && true) {
          delete attrs7[key];
          hasAttrsChanged = true;
        }
      }
    }
  }
  if (hasAttrsChanged) {
    trigger(instance.attrs, "set", "");
  }
  if (false) {
    validateProps(rawProps || {}, props, instance);
  }
}
__name(updateProps, "updateProps");
function setFullProps(instance, rawProps, props, attrs7) {
  const [options5, needCastKeys] = instance.propsOptions;
  let hasAttrsChanged = false;
  let rawCastValues;
  if (rawProps) {
    for (let key in rawProps) {
      if (isReservedProp(key)) {
        continue;
      }
      const value3 = rawProps[key];
      let camelKey;
      if (options5 && hasOwn$3(options5, camelKey = camelize$1(key))) {
        if (!needCastKeys || !needCastKeys.includes(camelKey)) {
          props[camelKey] = value3;
        } else {
          (rawCastValues || (rawCastValues = {}))[camelKey] = value3;
        }
      } else if (!isEmitListener(instance.emitsOptions, key)) {
        if (!(key in attrs7) || value3 !== attrs7[key]) {
          attrs7[key] = value3;
          hasAttrsChanged = true;
        }
      }
    }
  }
  if (needCastKeys) {
    const rawCurrentProps = toRaw(props);
    const castValues = rawCastValues || EMPTY_OBJ;
    for (let i2 = 0; i2 < needCastKeys.length; i2++) {
      const key = needCastKeys[i2];
      props[key] = resolvePropValue(
        options5,
        rawCurrentProps,
        key,
        castValues[key],
        instance,
        !hasOwn$3(castValues, key)
      );
    }
  }
  return hasAttrsChanged;
}
__name(setFullProps, "setFullProps");
function resolvePropValue(options5, props, key, value3, instance, isAbsent) {
  const opt = options5[key];
  if (opt != null) {
    const hasDefault = hasOwn$3(opt, "default");
    if (hasDefault && value3 === void 0) {
      const defaultValue2 = opt.default;
      if (opt.type !== Function && !opt.skipFactory && isFunction$c(defaultValue2)) {
        const { propsDefaults } = instance;
        if (key in propsDefaults) {
          value3 = propsDefaults[key];
        } else {
          const reset2 = setCurrentInstance(instance);
          value3 = propsDefaults[key] = defaultValue2.call(
            null,
            props
          );
          reset2();
        }
      } else {
        value3 = defaultValue2;
      }
      if (instance.ce) {
        instance.ce._setProp(key, value3);
      }
    }
    if (opt[
      0
      /* shouldCast */
    ]) {
      if (isAbsent && !hasDefault) {
        value3 = false;
      } else if (opt[
        1
        /* shouldCastTrue */
      ] && (value3 === "" || value3 === hyphenate$1(key))) {
        value3 = true;
      }
    }
  }
  return value3;
}
__name(resolvePropValue, "resolvePropValue");
const mixinPropsCache = /* @__PURE__ */ new WeakMap();
function normalizePropsOptions(comp, appContext, asMixin = false) {
  const cache2 = asMixin ? mixinPropsCache : appContext.propsCache;
  const cached = cache2.get(comp);
  if (cached) {
    return cached;
  }
  const raw = comp.props;
  const normalized = {};
  const needCastKeys = [];
  let hasExtends = false;
  if (!isFunction$c(comp)) {
    const extendProps = /* @__PURE__ */ __name((raw2) => {
      hasExtends = true;
      const [props, keys2] = normalizePropsOptions(raw2, appContext, true);
      extend$1(normalized, props);
      if (keys2) needCastKeys.push(...keys2);
    }, "extendProps");
    if (!asMixin && appContext.mixins.length) {
      appContext.mixins.forEach(extendProps);
    }
    if (comp.extends) {
      extendProps(comp.extends);
    }
    if (comp.mixins) {
      comp.mixins.forEach(extendProps);
    }
  }
  if (!raw && !hasExtends) {
    if (isObject$f(comp)) {
      cache2.set(comp, EMPTY_ARR);
    }
    return EMPTY_ARR;
  }
  if (isArray$b(raw)) {
    for (let i2 = 0; i2 < raw.length; i2++) {
      if (false) {
        warn$1$1(`props must be strings when using array syntax.`, raw[i2]);
      }
      const normalizedKey = camelize$1(raw[i2]);
      if (validatePropName(normalizedKey)) {
        normalized[normalizedKey] = EMPTY_OBJ;
      }
    }
  } else if (raw) {
    if (false) {
      warn$1$1(`invalid props options`, raw);
    }
    for (const key in raw) {
      const normalizedKey = camelize$1(key);
      if (validatePropName(normalizedKey)) {
        const opt = raw[key];
        const prop2 = normalized[normalizedKey] = isArray$b(opt) || isFunction$c(opt) ? { type: opt } : extend$1({}, opt);
        const propType = prop2.type;
        let shouldCast = false;
        let shouldCastTrue = true;
        if (isArray$b(propType)) {
          for (let index2 = 0; index2 < propType.length; ++index2) {
            const type = propType[index2];
            const typeName = isFunction$c(type) && type.name;
            if (typeName === "Boolean") {
              shouldCast = true;
              break;
            } else if (typeName === "String") {
              shouldCastTrue = false;
            }
          }
        } else {
          shouldCast = isFunction$c(propType) && propType.name === "Boolean";
        }
        prop2[
          0
          /* shouldCast */
        ] = shouldCast;
        prop2[
          1
          /* shouldCastTrue */
        ] = shouldCastTrue;
        if (shouldCast || hasOwn$3(prop2, "default")) {
          needCastKeys.push(normalizedKey);
        }
      }
    }
  }
  const res = [normalized, needCastKeys];
  if (isObject$f(comp)) {
    cache2.set(comp, res);
  }
  return res;
}
__name(normalizePropsOptions, "normalizePropsOptions");
function validatePropName(key) {
  if (key[0] !== "$" && !isReservedProp(key)) {
    return true;
  } else if (false) {
    warn$1$1(`Invalid prop name: "${key}" is a reserved property.`);
  }
  return false;
}
__name(validatePropName, "validatePropName");
function getType$1(ctor) {
  if (ctor === null) {
    return "null";
  }
  if (typeof ctor === "function") {
    return ctor.name || "";
  } else if (typeof ctor === "object") {
    const name2 = ctor.constructor && ctor.constructor.name;
    return name2 || "";
  }
  return "";
}
__name(getType$1, "getType$1");
function validateProps(rawProps, props, instance) {
  const resolvedValues = toRaw(props);
  const options5 = instance.propsOptions[0];
  const camelizePropsKey = Object.keys(rawProps).map((key) => camelize$1(key));
  for (const key in options5) {
    let opt = options5[key];
    if (opt == null) continue;
    validateProp(
      key,
      resolvedValues[key],
      opt,
      false ? shallowReadonly(resolvedValues) : resolvedValues,
      !camelizePropsKey.includes(key)
    );
  }
}
__name(validateProps, "validateProps");
function validateProp(name2, value3, prop2, props, isAbsent) {
  const { type, required, validator: validator3, skipCheck } = prop2;
  if (required && isAbsent) {
    warn$1$1('Missing required prop: "' + name2 + '"');
    return;
  }
  if (value3 == null && !required) {
    return;
  }
  if (type != null && type !== true && !skipCheck) {
    let isValid2 = false;
    const types = isArray$b(type) ? type : [type];
    const expectedTypes = [];
    for (let i2 = 0; i2 < types.length && !isValid2; i2++) {
      const { valid, expectedType } = assertType(value3, types[i2]);
      expectedTypes.push(expectedType || "");
      isValid2 = valid;
    }
    if (!isValid2) {
      warn$1$1(getInvalidTypeMessage(name2, value3, expectedTypes));
      return;
    }
  }
  if (validator3 && !validator3(value3, props)) {
    warn$1$1('Invalid prop: custom validator check failed for prop "' + name2 + '".');
  }
}
__name(validateProp, "validateProp");
const isSimpleType = /* @__PURE__ */ makeMap(
  "String,Number,Boolean,Function,Symbol,BigInt"
);
function assertType(value3, type) {
  let valid;
  const expectedType = getType$1(type);
  if (expectedType === "null") {
    valid = value3 === null;
  } else if (isSimpleType(expectedType)) {
    const t2 = typeof value3;
    valid = t2 === expectedType.toLowerCase();
    if (!valid && t2 === "object") {
      valid = value3 instanceof type;
    }
  } else if (expectedType === "Object") {
    valid = isObject$f(value3);
  } else if (expectedType === "Array") {
    valid = isArray$b(value3);
  } else {
    valid = value3 instanceof type;
  }
  return {
    valid,
    expectedType
  };
}
__name(assertType, "assertType");
function getInvalidTypeMessage(name2, value3, expectedTypes) {
  if (expectedTypes.length === 0) {
    return `Prop type [] for prop "${name2}" won't match anything. Did you mean to use type Array instead?`;
  }
  let message3 = `Invalid prop: type check failed for prop "${name2}". Expected ${expectedTypes.map(capitalize$1).join(" | ")}`;
  const expectedType = expectedTypes[0];
  const receivedType = toRawType(value3);
  const expectedValue = styleValue(value3, expectedType);
  const receivedValue = styleValue(value3, receivedType);
  if (expectedTypes.length === 1 && isExplicable(expectedType) && !isBoolean$3(expectedType, receivedType)) {
    message3 += ` with value ${expectedValue}`;
  }
  message3 += `, got ${receivedType} `;
  if (isExplicable(receivedType)) {
    message3 += `with value ${receivedValue}.`;
  }
  return message3;
}
__name(getInvalidTypeMessage, "getInvalidTypeMessage");
function styleValue(value3, type) {
  if (type === "String") {
    return `"${value3}"`;
  } else if (type === "Number") {
    return `${Number(value3)}`;
  } else {
    return `${value3}`;
  }
}
__name(styleValue, "styleValue");
function isExplicable(type) {
  const explicitTypes = ["string", "number", "boolean"];
  return explicitTypes.some((elem) => type.toLowerCase() === elem);
}
__name(isExplicable, "isExplicable");
function isBoolean$3(...args) {
  return args.some((elem) => elem.toLowerCase() === "boolean");
}
__name(isBoolean$3, "isBoolean$3");
const isInternalKey = /* @__PURE__ */ __name((key) => key[0] === "_" || key === "$stable", "isInternalKey");
const normalizeSlotValue = /* @__PURE__ */ __name((value3) => isArray$b(value3) ? value3.map(normalizeVNode) : [normalizeVNode(value3)], "normalizeSlotValue");
const normalizeSlot$1 = /* @__PURE__ */ __name((key, rawSlot, ctx) => {
  if (rawSlot._n) {
    return rawSlot;
  }
  const normalized = withCtx((...args) => {
    if (false) {
      warn$1$1(
        `Slot "${key}" invoked outside of the render function: this will not track dependencies used in the slot. Invoke the slot function inside the render function instead.`
      );
    }
    return normalizeSlotValue(rawSlot(...args));
  }, ctx);
  normalized._c = false;
  return normalized;
}, "normalizeSlot$1");
const normalizeObjectSlots = /* @__PURE__ */ __name((rawSlots, slots, instance) => {
  const ctx = rawSlots._ctx;
  for (const key in rawSlots) {
    if (isInternalKey(key)) continue;
    const value3 = rawSlots[key];
    if (isFunction$c(value3)) {
      slots[key] = normalizeSlot$1(key, value3, ctx);
    } else if (value3 != null) {
      if (false) {
        warn$1$1(
          `Non-function value encountered for slot "${key}". Prefer function slots for better performance.`
        );
      }
      const normalized = normalizeSlotValue(value3);
      slots[key] = () => normalized;
    }
  }
}, "normalizeObjectSlots");
const normalizeVNodeSlots = /* @__PURE__ */ __name((instance, children) => {
  if (false) {
    warn$1$1(
      `Non-function value encountered for default slot. Prefer function slots for better performance.`
    );
  }
  const normalized = normalizeSlotValue(children);
  instance.slots.default = () => normalized;
}, "normalizeVNodeSlots");
const assignSlots = /* @__PURE__ */ __name((slots, children, optimized) => {
  for (const key in children) {
    if (optimized || key !== "_") {
      slots[key] = children[key];
    }
  }
}, "assignSlots");
const initSlots = /* @__PURE__ */ __name((instance, children, optimized) => {
  const slots = instance.slots = createInternalObject();
  if (instance.vnode.shapeFlag & 32) {
    const type = children._;
    if (type) {
      assignSlots(slots, children, optimized);
      if (optimized) {
        def(slots, "_", type, true);
      }
    } else {
      normalizeObjectSlots(children, slots);
    }
  } else if (children) {
    normalizeVNodeSlots(instance, children);
  }
}, "initSlots");
const updateSlots = /* @__PURE__ */ __name((instance, children, optimized) => {
  const { vnode, slots } = instance;
  let needDeletionCheck = true;
  let deletionComparisonTarget = EMPTY_OBJ;
  if (vnode.shapeFlag & 32) {
    const type = children._;
    if (type) {
      if (false) {
        assignSlots(slots, children, optimized);
        trigger(instance, "set", "$slots");
      } else if (optimized && type === 1) {
        needDeletionCheck = false;
      } else {
        assignSlots(slots, children, optimized);
      }
    } else {
      needDeletionCheck = !children.$stable;
      normalizeObjectSlots(children, slots);
    }
    deletionComparisonTarget = children;
  } else if (children) {
    normalizeVNodeSlots(instance, children);
    deletionComparisonTarget = { default: 1 };
  }
  if (needDeletionCheck) {
    for (const key in slots) {
      if (!isInternalKey(key) && deletionComparisonTarget[key] == null) {
        delete slots[key];
      }
    }
  }
}, "updateSlots");
let supported$1;
let perf$1;
function startMeasure(instance, type) {
  if (instance.appContext.config.performance && isSupported()) {
    perf$1.mark(`vue-${type}-${instance.uid}`);
  }
  if (false) {
    devtoolsPerfStart(instance, type, isSupported() ? perf$1.now() : Date.now());
  }
}
__name(startMeasure, "startMeasure");
function endMeasure(instance, type) {
  if (instance.appContext.config.performance && isSupported()) {
    const startTag = `vue-${type}-${instance.uid}`;
    const endTag = startTag + `:end`;
    perf$1.mark(endTag);
    perf$1.measure(
      `<${formatComponentName(instance, instance.type)}> ${type}`,
      startTag,
      endTag
    );
    perf$1.clearMarks(startTag);
    perf$1.clearMarks(endTag);
  }
  if (false) {
    devtoolsPerfEnd(instance, type, isSupported() ? perf$1.now() : Date.now());
  }
}
__name(endMeasure, "endMeasure");
function isSupported() {
  if (supported$1 !== void 0) {
    return supported$1;
  }
  if (typeof window !== "undefined" && window.performance) {
    supported$1 = true;
    perf$1 = window.performance;
  } else {
    supported$1 = false;
  }
  return supported$1;
}
__name(isSupported, "isSupported");
function initFeatureFlags$2() {
  const needWarn = [];
  if (false) {
    getGlobalThis$1().__VUE_OPTIONS_API__ = true;
  }
  if (false) {
    getGlobalThis$1().__VUE_PROD_DEVTOOLS__ = false;
  }
  if (false) {
    getGlobalThis$1().__VUE_PROD_HYDRATION_MISMATCH_DETAILS__ = false;
  }
  if (false) {
    const multi2 = needWarn.length > 1;
    console.warn(
      `Feature flag${multi2 ? `s` : ``} ${needWarn.join(", ")} ${multi2 ? `are` : `is`} not explicitly defined. You are running the esm-bundler build of Vue, which expects these compile-time feature flags to be globally injected via the bundler config in order to get better tree-shaking in the production bundle.

For more details, see https://link.vuejs.org/feature-flags.`
    );
  }
}
__name(initFeatureFlags$2, "initFeatureFlags$2");
const queuePostRenderEffect = queueEffectWithSuspense;
function createRenderer(options5) {
  return baseCreateRenderer(options5);
}
__name(createRenderer, "createRenderer");
function createHydrationRenderer(options5) {
  return baseCreateRenderer(options5, createHydrationFunctions);
}
__name(createHydrationRenderer, "createHydrationRenderer");
function baseCreateRenderer(options5, createHydrationFns) {
  {
    initFeatureFlags$2();
  }
  const target2 = getGlobalThis$1();
  target2.__VUE__ = true;
  if (false) {
    setDevtoolsHook$1(target2.__VUE_DEVTOOLS_GLOBAL_HOOK__, target2);
  }
  const {
    insert: hostInsert,
    remove: hostRemove,
    patchProp: hostPatchProp,
    createElement: hostCreateElement,
    createText: hostCreateText,
    createComment: hostCreateComment,
    setText: hostSetText,
    setElementText: hostSetElementText,
    parentNode: hostParentNode,
    nextSibling: hostNextSibling,
    setScopeId: hostSetScopeId = NOOP,
    insertStaticContent: hostInsertStaticContent
  } = options5;
  const patch2 = /* @__PURE__ */ __name((n1, n2, container, anchor = null, parentComponent = null, parentSuspense = null, namespace = void 0, slotScopeIds = null, optimized = false ? false : !!n2.dynamicChildren) => {
    if (n1 === n2) {
      return;
    }
    if (n1 && !isSameVNodeType(n1, n2)) {
      anchor = getNextHostNode(n1);
      unmount(n1, parentComponent, parentSuspense, true);
      n1 = null;
    }
    if (n2.patchFlag === -2) {
      optimized = false;
      n2.dynamicChildren = null;
    }
    const { type, ref: ref3, shapeFlag } = n2;
    switch (type) {
      case Text$4:
        processText(n1, n2, container, anchor);
        break;
      case Comment:
        processCommentNode(n1, n2, container, anchor);
        break;
      case Static:
        if (n1 == null) {
          mountStaticNode(n2, container, anchor, namespace);
        } else if (false) {
          patchStaticNode(n1, n2, container, namespace);
        }
        break;
      case Fragment$1:
        processFragment(
          n1,
          n2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
        break;
      default:
        if (shapeFlag & 1) {
          processElement(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        } else if (shapeFlag & 6) {
          processComponent(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        } else if (shapeFlag & 64) {
          type.process(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized,
            internals
          );
        } else if (shapeFlag & 128) {
          type.process(
            n1,
            n2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized,
            internals
          );
        } else if (false) {
          warn$1$1("Invalid VNode type:", type, `(${typeof type})`);
        }
    }
    if (ref3 != null && parentComponent) {
      setRef(ref3, n1 && n1.ref, parentSuspense, n2 || n1, !n2);
    }
  }, "patch");
  const processText = /* @__PURE__ */ __name((n1, n2, container, anchor) => {
    if (n1 == null) {
      hostInsert(
        n2.el = hostCreateText(n2.children),
        container,
        anchor
      );
    } else {
      const el = n2.el = n1.el;
      if (n2.children !== n1.children) {
        hostSetText(el, n2.children);
      }
    }
  }, "processText");
  const processCommentNode = /* @__PURE__ */ __name((n1, n2, container, anchor) => {
    if (n1 == null) {
      hostInsert(
        n2.el = hostCreateComment(n2.children || ""),
        container,
        anchor
      );
    } else {
      n2.el = n1.el;
    }
  }, "processCommentNode");
  const mountStaticNode = /* @__PURE__ */ __name((n2, container, anchor, namespace) => {
    [n2.el, n2.anchor] = hostInsertStaticContent(
      n2.children,
      container,
      anchor,
      namespace,
      n2.el,
      n2.anchor
    );
  }, "mountStaticNode");
  const patchStaticNode = /* @__PURE__ */ __name((n1, n2, container, namespace) => {
    if (n2.children !== n1.children) {
      const anchor = hostNextSibling(n1.anchor);
      removeStaticNode(n1);
      [n2.el, n2.anchor] = hostInsertStaticContent(
        n2.children,
        container,
        anchor,
        namespace
      );
    } else {
      n2.el = n1.el;
      n2.anchor = n1.anchor;
    }
  }, "patchStaticNode");
  const moveStaticNode = /* @__PURE__ */ __name(({ el, anchor }, container, nextSibling) => {
    let next2;
    while (el && el !== anchor) {
      next2 = hostNextSibling(el);
      hostInsert(el, container, nextSibling);
      el = next2;
    }
    hostInsert(anchor, container, nextSibling);
  }, "moveStaticNode");
  const removeStaticNode = /* @__PURE__ */ __name(({ el, anchor }) => {
    let next2;
    while (el && el !== anchor) {
      next2 = hostNextSibling(el);
      hostRemove(el);
      el = next2;
    }
    hostRemove(anchor);
  }, "removeStaticNode");
  const processElement = /* @__PURE__ */ __name((n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    if (n2.type === "svg") {
      namespace = "svg";
    } else if (n2.type === "math") {
      namespace = "mathml";
    }
    if (n1 == null) {
      mountElement(
        n2,
        container,
        anchor,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized
      );
    } else {
      patchElement(
        n1,
        n2,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized
      );
    }
  }, "processElement");
  const mountElement = /* @__PURE__ */ __name((vnode, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    let el;
    let vnodeHook;
    const { props, shapeFlag, transition, dirs } = vnode;
    el = vnode.el = hostCreateElement(
      vnode.type,
      namespace,
      props && props.is,
      props
    );
    if (shapeFlag & 8) {
      hostSetElementText(el, vnode.children);
    } else if (shapeFlag & 16) {
      mountChildren(
        vnode.children,
        el,
        null,
        parentComponent,
        parentSuspense,
        resolveChildrenNamespace(vnode, namespace),
        slotScopeIds,
        optimized
      );
    }
    if (dirs) {
      invokeDirectiveHook(vnode, null, parentComponent, "created");
    }
    setScopeId(el, vnode, vnode.scopeId, slotScopeIds, parentComponent);
    if (props) {
      for (const key in props) {
        if (key !== "value" && !isReservedProp(key)) {
          hostPatchProp(el, key, null, props[key], namespace, parentComponent);
        }
      }
      if ("value" in props) {
        hostPatchProp(el, "value", null, props.value, namespace);
      }
      if (vnodeHook = props.onVnodeBeforeMount) {
        invokeVNodeHook(vnodeHook, parentComponent, vnode);
      }
    }
    if (false) {
      def(el, "__vnode", vnode, true);
      def(el, "__vueParentComponent", parentComponent, true);
    }
    if (dirs) {
      invokeDirectiveHook(vnode, null, parentComponent, "beforeMount");
    }
    const needCallTransitionHooks = needTransition(parentSuspense, transition);
    if (needCallTransitionHooks) {
      transition.beforeEnter(el);
    }
    hostInsert(el, container, anchor);
    if ((vnodeHook = props && props.onVnodeMounted) || needCallTransitionHooks || dirs) {
      queuePostRenderEffect(() => {
        vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, vnode);
        needCallTransitionHooks && transition.enter(el);
        dirs && invokeDirectiveHook(vnode, null, parentComponent, "mounted");
      }, parentSuspense);
    }
  }, "mountElement");
  const setScopeId = /* @__PURE__ */ __name((el, vnode, scopeId, slotScopeIds, parentComponent) => {
    if (scopeId) {
      hostSetScopeId(el, scopeId);
    }
    if (slotScopeIds) {
      for (let i2 = 0; i2 < slotScopeIds.length; i2++) {
        hostSetScopeId(el, slotScopeIds[i2]);
      }
    }
    if (parentComponent) {
      let subTree = parentComponent.subTree;
      if (false) {
        subTree = filterSingleRoot(subTree.children) || subTree;
      }
      if (vnode === subTree || isSuspense(subTree.type) && (subTree.ssContent === vnode || subTree.ssFallback === vnode)) {
        const parentVNode = parentComponent.vnode;
        setScopeId(
          el,
          parentVNode,
          parentVNode.scopeId,
          parentVNode.slotScopeIds,
          parentComponent.parent
        );
      }
    }
  }, "setScopeId");
  const mountChildren = /* @__PURE__ */ __name((children, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized, start2 = 0) => {
    for (let i2 = start2; i2 < children.length; i2++) {
      const child = children[i2] = optimized ? cloneIfMounted(children[i2]) : normalizeVNode(children[i2]);
      patch2(
        null,
        child,
        container,
        anchor,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized
      );
    }
  }, "mountChildren");
  const patchElement = /* @__PURE__ */ __name((n1, n2, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    const el = n2.el = n1.el;
    if (false) {
      el.__vnode = n2;
    }
    let { patchFlag, dynamicChildren, dirs } = n2;
    patchFlag |= n1.patchFlag & 16;
    const oldProps = n1.props || EMPTY_OBJ;
    const newProps = n2.props || EMPTY_OBJ;
    let vnodeHook;
    parentComponent && toggleRecurse(parentComponent, false);
    if (vnodeHook = newProps.onVnodeBeforeUpdate) {
      invokeVNodeHook(vnodeHook, parentComponent, n2, n1);
    }
    if (dirs) {
      invokeDirectiveHook(n2, n1, parentComponent, "beforeUpdate");
    }
    parentComponent && toggleRecurse(parentComponent, true);
    if (false) {
      patchFlag = 0;
      optimized = false;
      dynamicChildren = null;
    }
    if (oldProps.innerHTML && newProps.innerHTML == null || oldProps.textContent && newProps.textContent == null) {
      hostSetElementText(el, "");
    }
    if (dynamicChildren) {
      patchBlockChildren(
        n1.dynamicChildren,
        dynamicChildren,
        el,
        parentComponent,
        parentSuspense,
        resolveChildrenNamespace(n2, namespace),
        slotScopeIds
      );
      if (false) {
        traverseStaticChildren(n1, n2);
      }
    } else if (!optimized) {
      patchChildren(
        n1,
        n2,
        el,
        null,
        parentComponent,
        parentSuspense,
        resolveChildrenNamespace(n2, namespace),
        slotScopeIds,
        false
      );
    }
    if (patchFlag > 0) {
      if (patchFlag & 16) {
        patchProps(el, oldProps, newProps, parentComponent, namespace);
      } else {
        if (patchFlag & 2) {
          if (oldProps.class !== newProps.class) {
            hostPatchProp(el, "class", null, newProps.class, namespace);
          }
        }
        if (patchFlag & 4) {
          hostPatchProp(el, "style", oldProps.style, newProps.style, namespace);
        }
        if (patchFlag & 8) {
          const propsToUpdate = n2.dynamicProps;
          for (let i2 = 0; i2 < propsToUpdate.length; i2++) {
            const key = propsToUpdate[i2];
            const prev2 = oldProps[key];
            const next2 = newProps[key];
            if (next2 !== prev2 || key === "value") {
              hostPatchProp(el, key, prev2, next2, namespace, parentComponent);
            }
          }
        }
      }
      if (patchFlag & 1) {
        if (n1.children !== n2.children) {
          hostSetElementText(el, n2.children);
        }
      }
    } else if (!optimized && dynamicChildren == null) {
      patchProps(el, oldProps, newProps, parentComponent, namespace);
    }
    if ((vnodeHook = newProps.onVnodeUpdated) || dirs) {
      queuePostRenderEffect(() => {
        vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, n2, n1);
        dirs && invokeDirectiveHook(n2, n1, parentComponent, "updated");
      }, parentSuspense);
    }
  }, "patchElement");
  const patchBlockChildren = /* @__PURE__ */ __name((oldChildren, newChildren, fallbackContainer, parentComponent, parentSuspense, namespace, slotScopeIds) => {
    for (let i2 = 0; i2 < newChildren.length; i2++) {
      const oldVNode = oldChildren[i2];
      const newVNode = newChildren[i2];
      const container = (
        // oldVNode may be an errored async setup() component inside Suspense
        // which will not have a mounted element
        oldVNode.el && // - In the case of a Fragment, we need to provide the actual parent
        // of the Fragment itself so it can move its children.
        (oldVNode.type === Fragment$1 || // - In the case of different nodes, there is going to be a replacement
        // which also requires the correct parent container
        !isSameVNodeType(oldVNode, newVNode) || // - In the case of a component, it could contain anything.
        oldVNode.shapeFlag & (6 | 64)) ? hostParentNode(oldVNode.el) : (
          // In other cases, the parent container is not actually used so we
          // just pass the block element here to avoid a DOM parentNode call.
          fallbackContainer
        )
      );
      patch2(
        oldVNode,
        newVNode,
        container,
        null,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        true
      );
    }
  }, "patchBlockChildren");
  const patchProps = /* @__PURE__ */ __name((el, oldProps, newProps, parentComponent, namespace) => {
    if (oldProps !== newProps) {
      if (oldProps !== EMPTY_OBJ) {
        for (const key in oldProps) {
          if (!isReservedProp(key) && !(key in newProps)) {
            hostPatchProp(
              el,
              key,
              oldProps[key],
              null,
              namespace,
              parentComponent
            );
          }
        }
      }
      for (const key in newProps) {
        if (isReservedProp(key)) continue;
        const next2 = newProps[key];
        const prev2 = oldProps[key];
        if (next2 !== prev2 && key !== "value") {
          hostPatchProp(el, key, prev2, next2, namespace, parentComponent);
        }
      }
      if ("value" in newProps) {
        hostPatchProp(el, "value", oldProps.value, newProps.value, namespace);
      }
    }
  }, "patchProps");
  const processFragment = /* @__PURE__ */ __name((n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    const fragmentStartAnchor = n2.el = n1 ? n1.el : hostCreateText("");
    const fragmentEndAnchor = n2.anchor = n1 ? n1.anchor : hostCreateText("");
    let { patchFlag, dynamicChildren, slotScopeIds: fragmentSlotScopeIds } = n2;
    if (false) {
      patchFlag = 0;
      optimized = false;
      dynamicChildren = null;
    }
    if (fragmentSlotScopeIds) {
      slotScopeIds = slotScopeIds ? slotScopeIds.concat(fragmentSlotScopeIds) : fragmentSlotScopeIds;
    }
    if (n1 == null) {
      hostInsert(fragmentStartAnchor, container, anchor);
      hostInsert(fragmentEndAnchor, container, anchor);
      mountChildren(
        // #10007
        // such fragment like `<></>` will be compiled into
        // a fragment which doesn't have a children.
        // In this case fallback to an empty array
        n2.children || [],
        container,
        fragmentEndAnchor,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized
      );
    } else {
      if (patchFlag > 0 && patchFlag & 64 && dynamicChildren && // #2715 the previous fragment could've been a BAILed one as a result
      // of renderSlot() with no valid children
      n1.dynamicChildren) {
        patchBlockChildren(
          n1.dynamicChildren,
          dynamicChildren,
          container,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds
        );
        if (false) {
          traverseStaticChildren(n1, n2);
        } else if (
          // #2080 if the stable fragment has a key, it's a <template v-for> that may
          //  get moved around. Make sure all root level vnodes inherit el.
          // #2134 or if it's a component root, it may also get moved around
          // as the component is being moved.
          n2.key != null || parentComponent && n2 === parentComponent.subTree
        ) {
          traverseStaticChildren(
            n1,
            n2,
            true
            /* shallow */
          );
        }
      } else {
        patchChildren(
          n1,
          n2,
          container,
          fragmentEndAnchor,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
      }
    }
  }, "processFragment");
  const processComponent = /* @__PURE__ */ __name((n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    n2.slotScopeIds = slotScopeIds;
    if (n1 == null) {
      if (n2.shapeFlag & 512) {
        parentComponent.ctx.activate(
          n2,
          container,
          anchor,
          namespace,
          optimized
        );
      } else {
        mountComponent(
          n2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          namespace,
          optimized
        );
      }
    } else {
      updateComponent(n1, n2, optimized);
    }
  }, "processComponent");
  const mountComponent = /* @__PURE__ */ __name((initialVNode, container, anchor, parentComponent, parentSuspense, namespace, optimized) => {
    const instance = initialVNode.component = createComponentInstance(
      initialVNode,
      parentComponent,
      parentSuspense
    );
    if (false) {
      registerHMR(instance);
    }
    if (false) {
      pushWarningContext(initialVNode);
      startMeasure(instance, `mount`);
    }
    if (isKeepAlive(initialVNode)) {
      instance.ctx.renderer = internals;
    }
    {
      if (false) {
        startMeasure(instance, `init`);
      }
      setupComponent(instance, false, optimized);
      if (false) {
        endMeasure(instance, `init`);
      }
    }
    if (instance.asyncDep) {
      if (false) initialVNode.el = null;
      parentSuspense && parentSuspense.registerDep(instance, setupRenderEffect, optimized);
      if (!initialVNode.el) {
        const placeholder = instance.subTree = createVNode(Comment);
        processCommentNode(null, placeholder, container, anchor);
      }
    } else {
      setupRenderEffect(
        instance,
        initialVNode,
        container,
        anchor,
        parentSuspense,
        namespace,
        optimized
      );
    }
    if (false) {
      popWarningContext();
      endMeasure(instance, `mount`);
    }
  }, "mountComponent");
  const updateComponent = /* @__PURE__ */ __name((n1, n2, optimized) => {
    const instance = n2.component = n1.component;
    if (shouldUpdateComponent(n1, n2, optimized)) {
      if (instance.asyncDep && !instance.asyncResolved) {
        if (false) {
          pushWarningContext(n2);
        }
        updateComponentPreRender(instance, n2, optimized);
        if (false) {
          popWarningContext();
        }
        return;
      } else {
        instance.next = n2;
        instance.update();
      }
    } else {
      n2.el = n1.el;
      instance.vnode = n2;
    }
  }, "updateComponent");
  const setupRenderEffect = /* @__PURE__ */ __name((instance, initialVNode, container, anchor, parentSuspense, namespace, optimized) => {
    const componentUpdateFn = /* @__PURE__ */ __name(() => {
      if (!instance.isMounted) {
        let vnodeHook;
        const { el, props } = initialVNode;
        const { bm, m: m2, parent, root: root34, type } = instance;
        const isAsyncWrapperVNode = isAsyncWrapper(initialVNode);
        toggleRecurse(instance, false);
        if (bm) {
          invokeArrayFns(bm);
        }
        if (!isAsyncWrapperVNode && (vnodeHook = props && props.onVnodeBeforeMount)) {
          invokeVNodeHook(vnodeHook, parent, initialVNode);
        }
        toggleRecurse(instance, true);
        if (el && hydrateNode) {
          const hydrateSubTree = /* @__PURE__ */ __name(() => {
            if (false) {
              startMeasure(instance, `render`);
            }
            instance.subTree = renderComponentRoot(instance);
            if (false) {
              endMeasure(instance, `render`);
            }
            if (false) {
              startMeasure(instance, `hydrate`);
            }
            hydrateNode(
              el,
              instance.subTree,
              instance,
              parentSuspense,
              null
            );
            if (false) {
              endMeasure(instance, `hydrate`);
            }
          }, "hydrateSubTree");
          if (isAsyncWrapperVNode && type.__asyncHydrate) {
            type.__asyncHydrate(
              el,
              instance,
              hydrateSubTree
            );
          } else {
            hydrateSubTree();
          }
        } else {
          if (root34.ce) {
            root34.ce._injectChildStyle(type);
          }
          if (false) {
            startMeasure(instance, `render`);
          }
          const subTree = instance.subTree = renderComponentRoot(instance);
          if (false) {
            endMeasure(instance, `render`);
          }
          if (false) {
            startMeasure(instance, `patch`);
          }
          patch2(
            null,
            subTree,
            container,
            anchor,
            instance,
            parentSuspense,
            namespace
          );
          if (false) {
            endMeasure(instance, `patch`);
          }
          initialVNode.el = subTree.el;
        }
        if (m2) {
          queuePostRenderEffect(m2, parentSuspense);
        }
        if (!isAsyncWrapperVNode && (vnodeHook = props && props.onVnodeMounted)) {
          const scopedInitialVNode = initialVNode;
          queuePostRenderEffect(
            () => invokeVNodeHook(vnodeHook, parent, scopedInitialVNode),
            parentSuspense
          );
        }
        if (initialVNode.shapeFlag & 256 || parent && isAsyncWrapper(parent.vnode) && parent.vnode.shapeFlag & 256) {
          instance.a && queuePostRenderEffect(instance.a, parentSuspense);
        }
        instance.isMounted = true;
        if (false) {
          devtoolsComponentAdded(instance);
        }
        initialVNode = container = anchor = null;
      } else {
        let { next: next2, bu, u: u2, parent, vnode } = instance;
        {
          const nonHydratedAsyncRoot = locateNonHydratedAsyncRoot(instance);
          if (nonHydratedAsyncRoot) {
            if (next2) {
              next2.el = vnode.el;
              updateComponentPreRender(instance, next2, optimized);
            }
            nonHydratedAsyncRoot.asyncDep.then(() => {
              if (!instance.isUnmounted) {
                componentUpdateFn();
              }
            });
            return;
          }
        }
        let originNext = next2;
        let vnodeHook;
        if (false) {
          pushWarningContext(next2 || instance.vnode);
        }
        toggleRecurse(instance, false);
        if (next2) {
          next2.el = vnode.el;
          updateComponentPreRender(instance, next2, optimized);
        } else {
          next2 = vnode;
        }
        if (bu) {
          invokeArrayFns(bu);
        }
        if (vnodeHook = next2.props && next2.props.onVnodeBeforeUpdate) {
          invokeVNodeHook(vnodeHook, parent, next2, vnode);
        }
        toggleRecurse(instance, true);
        if (false) {
          startMeasure(instance, `render`);
        }
        const nextTree = renderComponentRoot(instance);
        if (false) {
          endMeasure(instance, `render`);
        }
        const prevTree = instance.subTree;
        instance.subTree = nextTree;
        if (false) {
          startMeasure(instance, `patch`);
        }
        patch2(
          prevTree,
          nextTree,
          // parent may have changed if it's in a teleport
          hostParentNode(prevTree.el),
          // anchor may have changed if it's in a fragment
          getNextHostNode(prevTree),
          instance,
          parentSuspense,
          namespace
        );
        if (false) {
          endMeasure(instance, `patch`);
        }
        next2.el = nextTree.el;
        if (originNext === null) {
          updateHOCHostEl(instance, nextTree.el);
        }
        if (u2) {
          queuePostRenderEffect(u2, parentSuspense);
        }
        if (vnodeHook = next2.props && next2.props.onVnodeUpdated) {
          queuePostRenderEffect(
            () => invokeVNodeHook(vnodeHook, parent, next2, vnode),
            parentSuspense
          );
        }
        if (false) {
          devtoolsComponentUpdated(instance);
        }
        if (false) {
          popWarningContext();
        }
      }
    }, "componentUpdateFn");
    instance.scope.on();
    const effect2 = instance.effect = new ReactiveEffect(componentUpdateFn);
    instance.scope.off();
    const update = instance.update = effect2.run.bind(effect2);
    const job = instance.job = effect2.runIfDirty.bind(effect2);
    job.i = instance;
    job.id = instance.uid;
    effect2.scheduler = () => queueJob(job);
    toggleRecurse(instance, true);
    if (false) {
      effect2.onTrack = instance.rtc ? (e2) => invokeArrayFns(instance.rtc, e2) : void 0;
      effect2.onTrigger = instance.rtg ? (e2) => invokeArrayFns(instance.rtg, e2) : void 0;
    }
    update();
  }, "setupRenderEffect");
  const updateComponentPreRender = /* @__PURE__ */ __name((instance, nextVNode, optimized) => {
    nextVNode.component = instance;
    const prevProps = instance.vnode.props;
    instance.vnode = nextVNode;
    instance.next = null;
    updateProps(instance, nextVNode.props, prevProps, optimized);
    updateSlots(instance, nextVNode.children, optimized);
    pauseTracking();
    flushPreFlushCbs(instance);
    resetTracking();
  }, "updateComponentPreRender");
  const patchChildren = /* @__PURE__ */ __name((n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized = false) => {
    const c1 = n1 && n1.children;
    const prevShapeFlag = n1 ? n1.shapeFlag : 0;
    const c2 = n2.children;
    const { patchFlag, shapeFlag } = n2;
    if (patchFlag > 0) {
      if (patchFlag & 128) {
        patchKeyedChildren(
          c1,
          c2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
        return;
      } else if (patchFlag & 256) {
        patchUnkeyedChildren(
          c1,
          c2,
          container,
          anchor,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
        return;
      }
    }
    if (shapeFlag & 8) {
      if (prevShapeFlag & 16) {
        unmountChildren(c1, parentComponent, parentSuspense);
      }
      if (c2 !== c1) {
        hostSetElementText(container, c2);
      }
    } else {
      if (prevShapeFlag & 16) {
        if (shapeFlag & 16) {
          patchKeyedChildren(
            c1,
            c2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        } else {
          unmountChildren(c1, parentComponent, parentSuspense, true);
        }
      } else {
        if (prevShapeFlag & 8) {
          hostSetElementText(container, "");
        }
        if (shapeFlag & 16) {
          mountChildren(
            c2,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        }
      }
    }
  }, "patchChildren");
  const patchUnkeyedChildren = /* @__PURE__ */ __name((c1, c2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    c1 = c1 || EMPTY_ARR;
    c2 = c2 || EMPTY_ARR;
    const oldLength = c1.length;
    const newLength = c2.length;
    const commonLength = Math.min(oldLength, newLength);
    let i2;
    for (i2 = 0; i2 < commonLength; i2++) {
      const nextChild = c2[i2] = optimized ? cloneIfMounted(c2[i2]) : normalizeVNode(c2[i2]);
      patch2(
        c1[i2],
        nextChild,
        container,
        null,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized
      );
    }
    if (oldLength > newLength) {
      unmountChildren(
        c1,
        parentComponent,
        parentSuspense,
        true,
        false,
        commonLength
      );
    } else {
      mountChildren(
        c2,
        container,
        anchor,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized,
        commonLength
      );
    }
  }, "patchUnkeyedChildren");
  const patchKeyedChildren = /* @__PURE__ */ __name((c1, c2, container, parentAnchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized) => {
    let i2 = 0;
    const l2 = c2.length;
    let e1 = c1.length - 1;
    let e2 = l2 - 1;
    while (i2 <= e1 && i2 <= e2) {
      const n1 = c1[i2];
      const n2 = c2[i2] = optimized ? cloneIfMounted(c2[i2]) : normalizeVNode(c2[i2]);
      if (isSameVNodeType(n1, n2)) {
        patch2(
          n1,
          n2,
          container,
          null,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
      } else {
        break;
      }
      i2++;
    }
    while (i2 <= e1 && i2 <= e2) {
      const n1 = c1[e1];
      const n2 = c2[e2] = optimized ? cloneIfMounted(c2[e2]) : normalizeVNode(c2[e2]);
      if (isSameVNodeType(n1, n2)) {
        patch2(
          n1,
          n2,
          container,
          null,
          parentComponent,
          parentSuspense,
          namespace,
          slotScopeIds,
          optimized
        );
      } else {
        break;
      }
      e1--;
      e2--;
    }
    if (i2 > e1) {
      if (i2 <= e2) {
        const nextPos = e2 + 1;
        const anchor = nextPos < l2 ? c2[nextPos].el : parentAnchor;
        while (i2 <= e2) {
          patch2(
            null,
            c2[i2] = optimized ? cloneIfMounted(c2[i2]) : normalizeVNode(c2[i2]),
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
          i2++;
        }
      }
    } else if (i2 > e2) {
      while (i2 <= e1) {
        unmount(c1[i2], parentComponent, parentSuspense, true);
        i2++;
      }
    } else {
      const s1 = i2;
      const s2 = i2;
      const keyToNewIndexMap = /* @__PURE__ */ new Map();
      for (i2 = s2; i2 <= e2; i2++) {
        const nextChild = c2[i2] = optimized ? cloneIfMounted(c2[i2]) : normalizeVNode(c2[i2]);
        if (nextChild.key != null) {
          if (false) {
            warn$1$1(
              `Duplicate keys found during update:`,
              JSON.stringify(nextChild.key),
              `Make sure keys are unique.`
            );
          }
          keyToNewIndexMap.set(nextChild.key, i2);
        }
      }
      let j2;
      let patched = 0;
      const toBePatched = e2 - s2 + 1;
      let moved = false;
      let maxNewIndexSoFar = 0;
      const newIndexToOldIndexMap = new Array(toBePatched);
      for (i2 = 0; i2 < toBePatched; i2++) newIndexToOldIndexMap[i2] = 0;
      for (i2 = s1; i2 <= e1; i2++) {
        const prevChild = c1[i2];
        if (patched >= toBePatched) {
          unmount(prevChild, parentComponent, parentSuspense, true);
          continue;
        }
        let newIndex;
        if (prevChild.key != null) {
          newIndex = keyToNewIndexMap.get(prevChild.key);
        } else {
          for (j2 = s2; j2 <= e2; j2++) {
            if (newIndexToOldIndexMap[j2 - s2] === 0 && isSameVNodeType(prevChild, c2[j2])) {
              newIndex = j2;
              break;
            }
          }
        }
        if (newIndex === void 0) {
          unmount(prevChild, parentComponent, parentSuspense, true);
        } else {
          newIndexToOldIndexMap[newIndex - s2] = i2 + 1;
          if (newIndex >= maxNewIndexSoFar) {
            maxNewIndexSoFar = newIndex;
          } else {
            moved = true;
          }
          patch2(
            prevChild,
            c2[newIndex],
            container,
            null,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
          patched++;
        }
      }
      const increasingNewIndexSequence = moved ? getSequence(newIndexToOldIndexMap) : EMPTY_ARR;
      j2 = increasingNewIndexSequence.length - 1;
      for (i2 = toBePatched - 1; i2 >= 0; i2--) {
        const nextIndex = s2 + i2;
        const nextChild = c2[nextIndex];
        const anchor = nextIndex + 1 < l2 ? c2[nextIndex + 1].el : parentAnchor;
        if (newIndexToOldIndexMap[i2] === 0) {
          patch2(
            null,
            nextChild,
            container,
            anchor,
            parentComponent,
            parentSuspense,
            namespace,
            slotScopeIds,
            optimized
          );
        } else if (moved) {
          if (j2 < 0 || i2 !== increasingNewIndexSequence[j2]) {
            move(nextChild, container, anchor, 2);
          } else {
            j2--;
          }
        }
      }
    }
  }, "patchKeyedChildren");
  const move = /* @__PURE__ */ __name((vnode, container, anchor, moveType, parentSuspense = null) => {
    const { el, type, transition, children, shapeFlag } = vnode;
    if (shapeFlag & 6) {
      move(vnode.component.subTree, container, anchor, moveType);
      return;
    }
    if (shapeFlag & 128) {
      vnode.suspense.move(container, anchor, moveType);
      return;
    }
    if (shapeFlag & 64) {
      type.move(vnode, container, anchor, internals);
      return;
    }
    if (type === Fragment$1) {
      hostInsert(el, container, anchor);
      for (let i2 = 0; i2 < children.length; i2++) {
        move(children[i2], container, anchor, moveType);
      }
      hostInsert(vnode.anchor, container, anchor);
      return;
    }
    if (type === Static) {
      moveStaticNode(vnode, container, anchor);
      return;
    }
    const needTransition2 = moveType !== 2 && shapeFlag & 1 && transition;
    if (needTransition2) {
      if (moveType === 0) {
        transition.beforeEnter(el);
        hostInsert(el, container, anchor);
        queuePostRenderEffect(() => transition.enter(el), parentSuspense);
      } else {
        const { leave, delayLeave, afterLeave } = transition;
        const remove222 = /* @__PURE__ */ __name(() => hostInsert(el, container, anchor), "remove22");
        const performLeave = /* @__PURE__ */ __name(() => {
          leave(el, () => {
            remove222();
            afterLeave && afterLeave();
          });
        }, "performLeave");
        if (delayLeave) {
          delayLeave(el, remove222, performLeave);
        } else {
          performLeave();
        }
      }
    } else {
      hostInsert(el, container, anchor);
    }
  }, "move");
  const unmount = /* @__PURE__ */ __name((vnode, parentComponent, parentSuspense, doRemove = false, optimized = false) => {
    const {
      type,
      props,
      ref: ref3,
      children,
      dynamicChildren,
      shapeFlag,
      patchFlag,
      dirs,
      cacheIndex
    } = vnode;
    if (patchFlag === -2) {
      optimized = false;
    }
    if (ref3 != null) {
      setRef(ref3, null, parentSuspense, vnode, true);
    }
    if (cacheIndex != null) {
      parentComponent.renderCache[cacheIndex] = void 0;
    }
    if (shapeFlag & 256) {
      parentComponent.ctx.deactivate(vnode);
      return;
    }
    const shouldInvokeDirs = shapeFlag & 1 && dirs;
    const shouldInvokeVnodeHook = !isAsyncWrapper(vnode);
    let vnodeHook;
    if (shouldInvokeVnodeHook && (vnodeHook = props && props.onVnodeBeforeUnmount)) {
      invokeVNodeHook(vnodeHook, parentComponent, vnode);
    }
    if (shapeFlag & 6) {
      unmountComponent(vnode.component, parentSuspense, doRemove);
    } else {
      if (shapeFlag & 128) {
        vnode.suspense.unmount(parentSuspense, doRemove);
        return;
      }
      if (shouldInvokeDirs) {
        invokeDirectiveHook(vnode, null, parentComponent, "beforeUnmount");
      }
      if (shapeFlag & 64) {
        vnode.type.remove(
          vnode,
          parentComponent,
          parentSuspense,
          internals,
          doRemove
        );
      } else if (dynamicChildren && // #5154
      // when v-once is used inside a block, setBlockTracking(-1) marks the
      // parent block with hasOnce: true
      // so that it doesn't take the fast path during unmount - otherwise
      // components nested in v-once are never unmounted.
      !dynamicChildren.hasOnce && // #1153: fast path should not be taken for non-stable (v-for) fragments
      (type !== Fragment$1 || patchFlag > 0 && patchFlag & 64)) {
        unmountChildren(
          dynamicChildren,
          parentComponent,
          parentSuspense,
          false,
          true
        );
      } else if (type === Fragment$1 && patchFlag & (128 | 256) || !optimized && shapeFlag & 16) {
        unmountChildren(children, parentComponent, parentSuspense);
      }
      if (doRemove) {
        remove22(vnode);
      }
    }
    if (shouldInvokeVnodeHook && (vnodeHook = props && props.onVnodeUnmounted) || shouldInvokeDirs) {
      queuePostRenderEffect(() => {
        vnodeHook && invokeVNodeHook(vnodeHook, parentComponent, vnode);
        shouldInvokeDirs && invokeDirectiveHook(vnode, null, parentComponent, "unmounted");
      }, parentSuspense);
    }
  }, "unmount");
  const remove22 = /* @__PURE__ */ __name((vnode) => {
    const { type, el, anchor, transition } = vnode;
    if (type === Fragment$1) {
      if (false) {
        vnode.children.forEach((child) => {
          if (child.type === Comment) {
            hostRemove(child.el);
          } else {
            remove22(child);
          }
        });
      } else {
        removeFragment(el, anchor);
      }
      return;
    }
    if (type === Static) {
      removeStaticNode(vnode);
      return;
    }
    const performRemove = /* @__PURE__ */ __name(() => {
      hostRemove(el);
      if (transition && !transition.persisted && transition.afterLeave) {
        transition.afterLeave();
      }
    }, "performRemove");
    if (vnode.shapeFlag & 1 && transition && !transition.persisted) {
      const { leave, delayLeave } = transition;
      const performLeave = /* @__PURE__ */ __name(() => leave(el, performRemove), "performLeave");
      if (delayLeave) {
        delayLeave(vnode.el, performRemove, performLeave);
      } else {
        performLeave();
      }
    } else {
      performRemove();
    }
  }, "remove2");
  const removeFragment = /* @__PURE__ */ __name((cur, end) => {
    let next2;
    while (cur !== end) {
      next2 = hostNextSibling(cur);
      hostRemove(cur);
      cur = next2;
    }
    hostRemove(end);
  }, "removeFragment");
  const unmountComponent = /* @__PURE__ */ __name((instance, parentSuspense, doRemove) => {
    if (false) {
      unregisterHMR(instance);
    }
    const { bum, scope, job, subTree, um, m: m2, a: a2 } = instance;
    invalidateMount(m2);
    invalidateMount(a2);
    if (bum) {
      invokeArrayFns(bum);
    }
    scope.stop();
    if (job) {
      job.flags |= 8;
      unmount(subTree, instance, parentSuspense, doRemove);
    }
    if (um) {
      queuePostRenderEffect(um, parentSuspense);
    }
    queuePostRenderEffect(() => {
      instance.isUnmounted = true;
    }, parentSuspense);
    if (parentSuspense && parentSuspense.pendingBranch && !parentSuspense.isUnmounted && instance.asyncDep && !instance.asyncResolved && instance.suspenseId === parentSuspense.pendingId) {
      parentSuspense.deps--;
      if (parentSuspense.deps === 0) {
        parentSuspense.resolve();
      }
    }
    if (false) {
      devtoolsComponentRemoved(instance);
    }
  }, "unmountComponent");
  const unmountChildren = /* @__PURE__ */ __name((children, parentComponent, parentSuspense, doRemove = false, optimized = false, start2 = 0) => {
    for (let i2 = start2; i2 < children.length; i2++) {
      unmount(children[i2], parentComponent, parentSuspense, doRemove, optimized);
    }
  }, "unmountChildren");
  const getNextHostNode = /* @__PURE__ */ __name((vnode) => {
    if (vnode.shapeFlag & 6) {
      return getNextHostNode(vnode.component.subTree);
    }
    if (vnode.shapeFlag & 128) {
      return vnode.suspense.next();
    }
    const el = hostNextSibling(vnode.anchor || vnode.el);
    const teleportEnd = el && el[TeleportEndKey];
    return teleportEnd ? hostNextSibling(teleportEnd) : el;
  }, "getNextHostNode");
  let isFlushing = false;
  const render2 = /* @__PURE__ */ __name((vnode, container, namespace) => {
    if (vnode == null) {
      if (container._vnode) {
        unmount(container._vnode, null, null, true);
      }
    } else {
      patch2(
        container._vnode || null,
        vnode,
        container,
        null,
        null,
        null,
        namespace
      );
    }
    container._vnode = vnode;
    if (!isFlushing) {
      isFlushing = true;
      flushPreFlushCbs();
      flushPostFlushCbs();
      isFlushing = false;
    }
  }, "render");
  const internals = {
    p: patch2,
    um: unmount,
    m: move,
    r: remove22,
    mt: mountComponent,
    mc: mountChildren,
    pc: patchChildren,
    pbc: patchBlockChildren,
    n: getNextHostNode,
    o: options5
  };
  let hydrate2;
  let hydrateNode;
  if (createHydrationFns) {
    [hydrate2, hydrateNode] = createHydrationFns(
      internals
    );
  }
  return {
    render: render2,
    hydrate: hydrate2,
    createApp: createAppAPI(render2, hydrate2)
  };
}
__name(baseCreateRenderer, "baseCreateRenderer");
function resolveChildrenNamespace({ type, props }, currentNamespace) {
  return currentNamespace === "svg" && type === "foreignObject" || currentNamespace === "mathml" && type === "annotation-xml" && props && props.encoding && props.encoding.includes("html") ? void 0 : currentNamespace;
}
__name(resolveChildrenNamespace, "resolveChildrenNamespace");
function toggleRecurse({ effect: effect2, job }, allowed) {
  if (allowed) {
    effect2.flags |= 32;
    job.flags |= 4;
  } else {
    effect2.flags &= ~32;
    job.flags &= ~4;
  }
}
__name(toggleRecurse, "toggleRecurse");
function needTransition(parentSuspense, transition) {
  return (!parentSuspense || parentSuspense && !parentSuspense.pendingBranch) && transition && !transition.persisted;
}
__name(needTransition, "needTransition");
function traverseStaticChildren(n1, n2, shallow = false) {
  const ch1 = n1.children;
  const ch2 = n2.children;
  if (isArray$b(ch1) && isArray$b(ch2)) {
    for (let i2 = 0; i2 < ch1.length; i2++) {
      const c1 = ch1[i2];
      let c2 = ch2[i2];
      if (c2.shapeFlag & 1 && !c2.dynamicChildren) {
        if (c2.patchFlag <= 0 || c2.patchFlag === 32) {
          c2 = ch2[i2] = cloneIfMounted(ch2[i2]);
          c2.el = c1.el;
        }
        if (!shallow && c2.patchFlag !== -2)
          traverseStaticChildren(c1, c2);
      }
      if (c2.type === Text$4) {
        c2.el = c1.el;
      }
      if (false) {
        c2.el = c1.el;
      }
    }
  }
}
__name(traverseStaticChildren, "traverseStaticChildren");
function getSequence(arr) {
  const p2 = arr.slice();
  const result = [0];
  let i2, j2, u2, v2, c2;
  const len = arr.length;
  for (i2 = 0; i2 < len; i2++) {
    const arrI = arr[i2];
    if (arrI !== 0) {
      j2 = result[result.length - 1];
      if (arr[j2] < arrI) {
        p2[i2] = j2;
        result.push(i2);
        continue;
      }
      u2 = 0;
      v2 = result.length - 1;
      while (u2 < v2) {
        c2 = u2 + v2 >> 1;
        if (arr[result[c2]] < arrI) {
          u2 = c2 + 1;
        } else {
          v2 = c2;
        }
      }
      if (arrI < arr[result[u2]]) {
        if (u2 > 0) {
          p2[i2] = result[u2 - 1];
        }
        result[u2] = i2;
      }
    }
  }
  u2 = result.length;
  v2 = result[u2 - 1];
  while (u2-- > 0) {
    result[u2] = v2;
    v2 = p2[v2];
  }
  return result;
}
__name(getSequence, "getSequence");
function locateNonHydratedAsyncRoot(instance) {
  const subComponent = instance.subTree.component;
  if (subComponent) {
    if (subComponent.asyncDep && !subComponent.asyncResolved) {
      return subComponent;
    } else {
      return locateNonHydratedAsyncRoot(subComponent);
    }
  }
}
__name(locateNonHydratedAsyncRoot, "locateNonHydratedAsyncRoot");
function invalidateMount(hooks2) {
  if (hooks2) {
    for (let i2 = 0; i2 < hooks2.length; i2++)
      hooks2[i2].flags |= 8;
  }
}
__name(invalidateMount, "invalidateMount");
const ssrContextKey = Symbol.for("v-scx");
const useSSRContext = /* @__PURE__ */ __name(() => {
  {
    const ctx = inject(ssrContextKey);
    if (!ctx) {
    }
    return ctx;
  }
}, "useSSRContext");
function watchEffect(effect2, options5) {
  return doWatch(effect2, null, options5);
}
__name(watchEffect, "watchEffect");
function watchPostEffect(effect2, options5) {
  return doWatch(
    effect2,
    null,
    false ? extend$1({}, options5, { flush: "post" }) : { flush: "post" }
  );
}
__name(watchPostEffect, "watchPostEffect");
function watchSyncEffect(effect2, options5) {
  return doWatch(
    effect2,
    null,
    false ? extend$1({}, options5, { flush: "sync" }) : { flush: "sync" }
  );
}
__name(watchSyncEffect, "watchSyncEffect");
function watch(source, cb, options5) {
  if (false) {
    warn$1$1(
      `\`watch(fn, options?)\` signature has been moved to a separate API. Use \`watchEffect(fn, options?)\` instead. \`watch\` now only supports \`watch(source, cb, options?) signature.`
    );
  }
  return doWatch(source, cb, options5);
}
__name(watch, "watch");
function doWatch(source, cb, options5 = EMPTY_OBJ) {
  const { immediate, deep, flush: flush2, once: once2 } = options5;
  if (false) {
    if (immediate !== void 0) {
      warn$1$1(
        `watch() "immediate" option is only respected when using the watch(source, callback, options?) signature.`
      );
    }
    if (deep !== void 0) {
      warn$1$1(
        `watch() "deep" option is only respected when using the watch(source, callback, options?) signature.`
      );
    }
    if (once2 !== void 0) {
      warn$1$1(
        `watch() "once" option is only respected when using the watch(source, callback, options?) signature.`
      );
    }
  }
  const baseWatchOptions = extend$1({}, options5);
  if (false) baseWatchOptions.onWarn = warn$1$1;
  const runsImmediately = cb && immediate || !cb && flush2 !== "post";
  let ssrCleanup;
  if (isInSSRComponentSetup) {
    if (flush2 === "sync") {
      const ctx = useSSRContext();
      ssrCleanup = ctx.__watcherHandles || (ctx.__watcherHandles = []);
    } else if (!runsImmediately) {
      const watchStopHandle = /* @__PURE__ */ __name(() => {
      }, "watchStopHandle");
      watchStopHandle.stop = NOOP;
      watchStopHandle.resume = NOOP;
      watchStopHandle.pause = NOOP;
      return watchStopHandle;
    }
  }
  const instance = currentInstance;
  baseWatchOptions.call = (fn, type, args) => callWithAsyncErrorHandling(fn, instance, type, args);
  let isPre = false;
  if (flush2 === "post") {
    baseWatchOptions.scheduler = (job) => {
      queuePostRenderEffect(job, instance && instance.suspense);
    };
  } else if (flush2 !== "sync") {
    isPre = true;
    baseWatchOptions.scheduler = (job, isFirstRun) => {
      if (isFirstRun) {
        job();
      } else {
        queueJob(job);
      }
    };
  }
  baseWatchOptions.augmentJob = (job) => {
    if (cb) {
      job.flags |= 4;
    }
    if (isPre) {
      job.flags |= 2;
      if (instance) {
        job.id = instance.uid;
        job.i = instance;
      }
    }
  };
  const watchHandle = watch$1(source, cb, baseWatchOptions);
  if (isInSSRComponentSetup) {
    if (ssrCleanup) {
      ssrCleanup.push(watchHandle);
    } else if (runsImmediately) {
      watchHandle();
    }
  }
  return watchHandle;
}
__name(doWatch, "doWatch");
function instanceWatch(source, value3, options5) {
  const publicThis = this.proxy;
  const getter = isString$9(source) ? source.includes(".") ? createPathGetter(publicThis, source) : () => publicThis[source] : source.bind(publicThis, publicThis);
  let cb;
  if (isFunction$c(value3)) {
    cb = value3;
  } else {
    cb = value3.handler;
    options5 = value3;
  }
  const reset2 = setCurrentInstance(this);
  const res = doWatch(getter, cb.bind(publicThis), options5);
  reset2();
  return res;
}
__name(instanceWatch, "instanceWatch");
function createPathGetter(ctx, path) {
  const segments = path.split(".");
  return () => {
    let cur = ctx;
    for (let i2 = 0; i2 < segments.length && cur; i2++) {
      cur = cur[segments[i2]];
    }
    return cur;
  };
}
__name(createPathGetter, "createPathGetter");
function useModel(props, name2, options5 = EMPTY_OBJ) {
  const i2 = getCurrentInstance();
  if (false) {
    warn$1$1(`useModel() called without active instance.`);
    return ref();
  }
  const camelizedName = camelize$1(name2);
  if (false) {
    warn$1$1(`useModel() called with prop "${name2}" which is not declared.`);
    return ref();
  }
  const hyphenatedName = hyphenate$1(name2);
  const modifiers2 = getModelModifiers(props, camelizedName);
  const res = customRef((track2, trigger2) => {
    let localValue;
    let prevSetValue = EMPTY_OBJ;
    let prevEmittedValue;
    watchSyncEffect(() => {
      const propValue = props[camelizedName];
      if (hasChanged(localValue, propValue)) {
        localValue = propValue;
        trigger2();
      }
    });
    return {
      get() {
        track2();
        return options5.get ? options5.get(localValue) : localValue;
      },
      set(value3) {
        const emittedValue = options5.set ? options5.set(value3) : value3;
        if (!hasChanged(emittedValue, localValue) && !(prevSetValue !== EMPTY_OBJ && hasChanged(value3, prevSetValue))) {
          return;
        }
        const rawProps = i2.vnode.props;
        if (!(rawProps && // check if parent has passed v-model
        (name2 in rawProps || camelizedName in rawProps || hyphenatedName in rawProps) && (`onUpdate:${name2}` in rawProps || `onUpdate:${camelizedName}` in rawProps || `onUpdate:${hyphenatedName}` in rawProps))) {
          localValue = value3;
          trigger2();
        }
        i2.emit(`update:${name2}`, emittedValue);
        if (hasChanged(value3, emittedValue) && hasChanged(value3, prevSetValue) && !hasChanged(emittedValue, prevEmittedValue)) {
          trigger2();
        }
        prevSetValue = value3;
        prevEmittedValue = emittedValue;
      }
    };
  });
  res[Symbol.iterator] = () => {
    let i22 = 0;
    return {
      next() {
        if (i22 < 2) {
          return { value: i22++ ? modifiers2 || EMPTY_OBJ : res, done: false };
        } else {
          return { done: true };
        }
      }
    };
  };
  return res;
}
__name(useModel, "useModel");
const getModelModifiers = /* @__PURE__ */ __name((props, modelName) => {
  return modelName === "modelValue" || modelName === "model-value" ? props.modelModifiers : props[`${modelName}Modifiers`] || props[`${camelize$1(modelName)}Modifiers`] || props[`${hyphenate$1(modelName)}Modifiers`];
}, "getModelModifiers");
function emit(instance, event, ...rawArgs) {
  if (instance.isUnmounted) return;
  const props = instance.vnode.props || EMPTY_OBJ;
  if (false) {
    const {
      emitsOptions,
      propsOptions: [propsOptions]
    } = instance;
    if (emitsOptions) {
      if (!(event in emitsOptions) && true) {
        if (!propsOptions || !(toHandlerKey(camelize$1(event)) in propsOptions)) {
          warn$1$1(
            `Component emitted event "${event}" but it is neither declared in the emits option nor as an "${toHandlerKey(camelize$1(event))}" prop.`
          );
        }
      } else {
        const validator3 = emitsOptions[event];
        if (isFunction$c(validator3)) {
          const isValid2 = validator3(...rawArgs);
          if (!isValid2) {
            warn$1$1(
              `Invalid event arguments: event validation failed for event "${event}".`
            );
          }
        }
      }
    }
  }
  let args = rawArgs;
  const isModelListener2 = event.startsWith("update:");
  const modifiers2 = isModelListener2 && getModelModifiers(props, event.slice(7));
  if (modifiers2) {
    if (modifiers2.trim) {
      args = rawArgs.map((a2) => isString$9(a2) ? a2.trim() : a2);
    }
    if (modifiers2.number) {
      args = rawArgs.map(looseToNumber);
    }
  }
  if (false) {
    devtoolsComponentEmit(instance, event, args);
  }
  if (false) {
    const lowerCaseEvent = event.toLowerCase();
    if (lowerCaseEvent !== event && props[toHandlerKey(lowerCaseEvent)]) {
      warn$1$1(
        `Event "${lowerCaseEvent}" is emitted in component ${formatComponentName(
          instance,
          instance.type
        )} but the handler is registered for "${event}". Note that HTML attributes are case-insensitive and you cannot use v-on to listen to camelCase events when using in-DOM templates. You should probably use "${hyphenate$1(
          event
        )}" instead of "${event}".`
      );
    }
  }
  let handlerName;
  let handler14 = props[handlerName = toHandlerKey(event)] || // also try camelCase event handler (#2249)
  props[handlerName = toHandlerKey(camelize$1(event))];
  if (!handler14 && isModelListener2) {
    handler14 = props[handlerName = toHandlerKey(hyphenate$1(event))];
  }
  if (handler14) {
    callWithAsyncErrorHandling(
      handler14,
      instance,
      6,
      args
    );
  }
  const onceHandler = props[handlerName + `Once`];
  if (onceHandler) {
    if (!instance.emitted) {
      instance.emitted = {};
    } else if (instance.emitted[handlerName]) {
      return;
    }
    instance.emitted[handlerName] = true;
    callWithAsyncErrorHandling(
      onceHandler,
      instance,
      6,
      args
    );
  }
}
__name(emit, "emit");
function normalizeEmitsOptions(comp, appContext, asMixin = false) {
  const cache2 = appContext.emitsCache;
  const cached = cache2.get(comp);
  if (cached !== void 0) {
    return cached;
  }
  const raw = comp.emits;
  let normalized = {};
  let hasExtends = false;
  if (!isFunction$c(comp)) {
    const extendEmits = /* @__PURE__ */ __name((raw2) => {
      const normalizedFromExtend = normalizeEmitsOptions(raw2, appContext, true);
      if (normalizedFromExtend) {
        hasExtends = true;
        extend$1(normalized, normalizedFromExtend);
      }
    }, "extendEmits");
    if (!asMixin && appContext.mixins.length) {
      appContext.mixins.forEach(extendEmits);
    }
    if (comp.extends) {
      extendEmits(comp.extends);
    }
    if (comp.mixins) {
      comp.mixins.forEach(extendEmits);
    }
  }
  if (!raw && !hasExtends) {
    if (isObject$f(comp)) {
      cache2.set(comp, null);
    }
    return null;
  }
  if (isArray$b(raw)) {
    raw.forEach((key) => normalized[key] = null);
  } else {
    extend$1(normalized, raw);
  }
  if (isObject$f(comp)) {
    cache2.set(comp, normalized);
  }
  return normalized;
}
__name(normalizeEmitsOptions, "normalizeEmitsOptions");
function isEmitListener(options5, key) {
  if (!options5 || !isOn(key)) {
    return false;
  }
  key = key.slice(2).replace(/Once$/, "");
  return hasOwn$3(options5, key[0].toLowerCase() + key.slice(1)) || hasOwn$3(options5, hyphenate$1(key)) || hasOwn$3(options5, key);
}
__name(isEmitListener, "isEmitListener");
let accessedAttrs = false;
function markAttrsAccessed() {
  accessedAttrs = true;
}
__name(markAttrsAccessed, "markAttrsAccessed");
function renderComponentRoot(instance) {
  const {
    type: Component,
    vnode,
    proxy,
    withProxy,
    propsOptions: [propsOptions],
    slots,
    attrs: attrs7,
    emit: emit2,
    render: render2,
    renderCache,
    props,
    data: data30,
    setupState,
    ctx,
    inheritAttrs
  } = instance;
  const prev2 = setCurrentRenderingInstance(instance);
  let result;
  let fallthroughAttrs;
  if (false) {
    accessedAttrs = false;
  }
  try {
    if (vnode.shapeFlag & 4) {
      const proxyToUse = withProxy || proxy;
      const thisProxy = false ? new Proxy(proxyToUse, {
        get(target2, key, receiver) {
          warn$1$1(
            `Property '${String(
              key
            )}' was accessed via 'this'. Avoid using 'this' in templates.`
          );
          return Reflect.get(target2, key, receiver);
        }
      }) : proxyToUse;
      result = normalizeVNode(
        render2.call(
          thisProxy,
          proxyToUse,
          renderCache,
          false ? shallowReadonly(props) : props,
          setupState,
          data30,
          ctx
        )
      );
      fallthroughAttrs = attrs7;
    } else {
      const render22 = Component;
      if (false) {
        markAttrsAccessed();
      }
      result = normalizeVNode(
        render22.length > 1 ? render22(
          false ? shallowReadonly(props) : props,
          false ? {
            get attrs() {
              markAttrsAccessed();
              return shallowReadonly(attrs7);
            },
            slots,
            emit: emit2
          } : { attrs: attrs7, slots, emit: emit2 }
        ) : render22(
          false ? shallowReadonly(props) : props,
          null
        )
      );
      fallthroughAttrs = Component.props ? attrs7 : getFunctionalFallthrough(attrs7);
    }
  } catch (err) {
    blockStack.length = 0;
    handleError(err, instance, 1);
    result = createVNode(Comment);
  }
  let root34 = result;
  let setRoot = void 0;
  if (false) {
    [root34, setRoot] = getChildRoot(result);
  }
  if (fallthroughAttrs && inheritAttrs !== false) {
    const keys2 = Object.keys(fallthroughAttrs);
    const { shapeFlag } = root34;
    if (keys2.length) {
      if (shapeFlag & (1 | 6)) {
        if (propsOptions && keys2.some(isModelListener)) {
          fallthroughAttrs = filterModelListeners(
            fallthroughAttrs,
            propsOptions
          );
        }
        root34 = cloneVNode(root34, fallthroughAttrs, false, true);
      } else if (false) {
        const allAttrs = Object.keys(attrs7);
        const eventAttrs = [];
        const extraAttrs = [];
        for (let i2 = 0, l2 = allAttrs.length; i2 < l2; i2++) {
          const key = allAttrs[i2];
          if (isOn(key)) {
            if (!isModelListener(key)) {
              eventAttrs.push(key[2].toLowerCase() + key.slice(3));
            }
          } else {
            extraAttrs.push(key);
          }
        }
        if (extraAttrs.length) {
          warn$1$1(
            `Extraneous non-props attributes (${extraAttrs.join(", ")}) were passed to component but could not be automatically inherited because component renders fragment or text or teleport root nodes.`
          );
        }
        if (eventAttrs.length) {
          warn$1$1(
            `Extraneous non-emits event listeners (${eventAttrs.join(", ")}) were passed to component but could not be automatically inherited because component renders fragment or text root nodes. If the listener is intended to be a component custom event listener only, declare it using the "emits" option.`
          );
        }
      }
    }
  }
  if (vnode.dirs) {
    if (false) {
      warn$1$1(
        `Runtime directive used on component with non-element root node. The directives will not function as intended.`
      );
    }
    root34 = cloneVNode(root34, null, false, true);
    root34.dirs = root34.dirs ? root34.dirs.concat(vnode.dirs) : vnode.dirs;
  }
  if (vnode.transition) {
    if (false) {
      warn$1$1(
        `Component inside <Transition> renders non-element root node that cannot be animated.`
      );
    }
    setTransitionHooks(root34, vnode.transition);
  }
  if (false) {
    setRoot(root34);
  } else {
    result = root34;
  }
  setCurrentRenderingInstance(prev2);
  return result;
}
__name(renderComponentRoot, "renderComponentRoot");
const getChildRoot = /* @__PURE__ */ __name((vnode) => {
  const rawChildren = vnode.children;
  const dynamicChildren = vnode.dynamicChildren;
  const childRoot = filterSingleRoot(rawChildren, false);
  if (!childRoot) {
    return [vnode, void 0];
  } else if (false) {
    return getChildRoot(childRoot);
  }
  const index2 = rawChildren.indexOf(childRoot);
  const dynamicIndex = dynamicChildren ? dynamicChildren.indexOf(childRoot) : -1;
  const setRoot = /* @__PURE__ */ __name((updatedRoot) => {
    rawChildren[index2] = updatedRoot;
    if (dynamicChildren) {
      if (dynamicIndex > -1) {
        dynamicChildren[dynamicIndex] = updatedRoot;
      } else if (updatedRoot.patchFlag > 0) {
        vnode.dynamicChildren = [...dynamicChildren, updatedRoot];
      }
    }
  }, "setRoot");
  return [normalizeVNode(childRoot), setRoot];
}, "getChildRoot");
function filterSingleRoot(children, recurse = true) {
  let singleRoot;
  for (let i2 = 0; i2 < children.length; i2++) {
    const child = children[i2];
    if (isVNode$1(child)) {
      if (child.type !== Comment || child.children === "v-if") {
        if (singleRoot) {
          return;
        } else {
          singleRoot = child;
          if (false) {
            return filterSingleRoot(singleRoot.children);
          }
        }
      }
    } else {
      return;
    }
  }
  return singleRoot;
}
__name(filterSingleRoot, "filterSingleRoot");
const getFunctionalFallthrough = /* @__PURE__ */ __name((attrs7) => {
  let res;
  for (const key in attrs7) {
    if (key === "class" || key === "style" || isOn(key)) {
      (res || (res = {}))[key] = attrs7[key];
    }
  }
  return res;
}, "getFunctionalFallthrough");
const filterModelListeners = /* @__PURE__ */ __name((attrs7, props) => {
  const res = {};
  for (const key in attrs7) {
    if (!isModelListener(key) || !(key.slice(9) in props)) {
      res[key] = attrs7[key];
    }
  }
  return res;
}, "filterModelListeners");
const isElementRoot = /* @__PURE__ */ __name((vnode) => {
  return vnode.shapeFlag & (6 | 1) || vnode.type === Comment;
}, "isElementRoot");
function shouldUpdateComponent(prevVNode, nextVNode, optimized) {
  const { props: prevProps, children: prevChildren, component } = prevVNode;
  const { props: nextProps, children: nextChildren, patchFlag } = nextVNode;
  const emits = component.emitsOptions;
  if (false) {
    return true;
  }
  if (nextVNode.dirs || nextVNode.transition) {
    return true;
  }
  if (optimized && patchFlag >= 0) {
    if (patchFlag & 1024) {
      return true;
    }
    if (patchFlag & 16) {
      if (!prevProps) {
        return !!nextProps;
      }
      return hasPropsChanged(prevProps, nextProps, emits);
    } else if (patchFlag & 8) {
      const dynamicProps = nextVNode.dynamicProps;
      for (let i2 = 0; i2 < dynamicProps.length; i2++) {
        const key = dynamicProps[i2];
        if (nextProps[key] !== prevProps[key] && !isEmitListener(emits, key)) {
          return true;
        }
      }
    }
  } else {
    if (prevChildren || nextChildren) {
      if (!nextChildren || !nextChildren.$stable) {
        return true;
      }
    }
    if (prevProps === nextProps) {
      return false;
    }
    if (!prevProps) {
      return !!nextProps;
    }
    if (!nextProps) {
      return true;
    }
    return hasPropsChanged(prevProps, nextProps, emits);
  }
  return false;
}
__name(shouldUpdateComponent, "shouldUpdateComponent");
function hasPropsChanged(prevProps, nextProps, emitsOptions) {
  const nextKeys = Object.keys(nextProps);
  if (nextKeys.length !== Object.keys(prevProps).length) {
    return true;
  }
  for (let i2 = 0; i2 < nextKeys.length; i2++) {
    const key = nextKeys[i2];
    if (nextProps[key] !== prevProps[key] && !isEmitListener(emitsOptions, key)) {
      return true;
    }
  }
  return false;
}
__name(hasPropsChanged, "hasPropsChanged");
function updateHOCHostEl({ vnode, parent }, el) {
  while (parent) {
    const root34 = parent.subTree;
    if (root34.suspense && root34.suspense.activeBranch === vnode) {
      root34.el = vnode.el;
    }
    if (root34 === vnode) {
      (vnode = parent.vnode).el = el;
      parent = parent.parent;
    } else {
      break;
    }
  }
}
__name(updateHOCHostEl, "updateHOCHostEl");
const isSuspense = /* @__PURE__ */ __name((type) => type.__isSuspense, "isSuspense");
let suspenseId = 0;
const SuspenseImpl = {
  name: "Suspense",
  // In order to make Suspense tree-shakable, we need to avoid importing it
  // directly in the renderer. The renderer checks for the __isSuspense flag
  // on a vnode's type and calls the `process` method, passing in renderer
  // internals.
  __isSuspense: true,
  process(n1, n2, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized, rendererInternals) {
    if (n1 == null) {
      mountSuspense(
        n2,
        container,
        anchor,
        parentComponent,
        parentSuspense,
        namespace,
        slotScopeIds,
        optimized,
        rendererInternals
      );
    } else {
      if (parentSuspense && parentSuspense.deps > 0 && !n1.suspense.isInFallback) {
        n2.suspense = n1.suspense;
        n2.suspense.vnode = n2;
        n2.el = n1.el;
        return;
      }
      patchSuspense(
        n1,
        n2,
        container,
        anchor,
        parentComponent,
        namespace,
        slotScopeIds,
        optimized,
        rendererInternals
      );
    }
  },
  hydrate: hydrateSuspense,
  normalize: normalizeSuspenseChildren
};
const Suspense = SuspenseImpl;
function triggerEvent(vnode, name2) {
  const eventListener = vnode.props && vnode.props[name2];
  if (isFunction$c(eventListener)) {
    eventListener();
  }
}
__name(triggerEvent, "triggerEvent");
function mountSuspense(vnode, container, anchor, parentComponent, parentSuspense, namespace, slotScopeIds, optimized, rendererInternals) {
  const {
    p: patch2,
    o: { createElement: createElement2 }
  } = rendererInternals;
  const hiddenContainer = createElement2("div");
  const suspense = vnode.suspense = createSuspenseBoundary(
    vnode,
    parentSuspense,
    parentComponent,
    container,
    hiddenContainer,
    anchor,
    namespace,
    slotScopeIds,
    optimized,
    rendererInternals
  );
  patch2(
    null,
    suspense.pendingBranch = vnode.ssContent,
    hiddenContainer,
    null,
    parentComponent,
    suspense,
    namespace,
    slotScopeIds
  );
  if (suspense.deps > 0) {
    triggerEvent(vnode, "onPending");
    triggerEvent(vnode, "onFallback");
    patch2(
      null,
      vnode.ssFallback,
      container,
      anchor,
      parentComponent,
      null,
      // fallback tree will not have suspense context
      namespace,
      slotScopeIds
    );
    setActiveBranch(suspense, vnode.ssFallback);
  } else {
    suspense.resolve(false, true);
  }
}
__name(mountSuspense, "mountSuspense");
function patchSuspense(n1, n2, container, anchor, parentComponent, namespace, slotScopeIds, optimized, { p: patch2, um: unmount, o: { createElement: createElement2 } }) {
  const suspense = n2.suspense = n1.suspense;
  suspense.vnode = n2;
  n2.el = n1.el;
  const newBranch = n2.ssContent;
  const newFallback = n2.ssFallback;
  const { activeBranch, pendingBranch, isInFallback, isHydrating } = suspense;
  if (pendingBranch) {
    suspense.pendingBranch = newBranch;
    if (isSameVNodeType(newBranch, pendingBranch)) {
      patch2(
        pendingBranch,
        newBranch,
        suspense.hiddenContainer,
        null,
        parentComponent,
        suspense,
        namespace,
        slotScopeIds,
        optimized
      );
      if (suspense.deps <= 0) {
        suspense.resolve();
      } else if (isInFallback) {
        if (!isHydrating) {
          patch2(
            activeBranch,
            newFallback,
            container,
            anchor,
            parentComponent,
            null,
            // fallback tree will not have suspense context
            namespace,
            slotScopeIds,
            optimized
          );
          setActiveBranch(suspense, newFallback);
        }
      }
    } else {
      suspense.pendingId = suspenseId++;
      if (isHydrating) {
        suspense.isHydrating = false;
        suspense.activeBranch = pendingBranch;
      } else {
        unmount(pendingBranch, parentComponent, suspense);
      }
      suspense.deps = 0;
      suspense.effects.length = 0;
      suspense.hiddenContainer = createElement2("div");
      if (isInFallback) {
        patch2(
          null,
          newBranch,
          suspense.hiddenContainer,
          null,
          parentComponent,
          suspense,
          namespace,
          slotScopeIds,
          optimized
        );
        if (suspense.deps <= 0) {
          suspense.resolve();
        } else {
          patch2(
            activeBranch,
            newFallback,
            container,
            anchor,
            parentComponent,
            null,
            // fallback tree will not have suspense context
            namespace,
            slotScopeIds,
            optimized
          );
          setActiveBranch(suspense, newFallback);
        }
      } else if (activeBranch && isSameVNodeType(newBranch, activeBranch)) {
        patch2(
          activeBranch,
          newBranch,
          container,
          anchor,
          parentComponent,
          suspense,
          namespace,
          slotScopeIds,
          optimized
        );
        suspense.resolve(true);
      } else {
        patch2(
          null,
          newBranch,
          suspense.hiddenContainer,
          null,
          parentComponent,
          suspense,
          namespace,
          slotScopeIds,
          optimized
        );
        if (suspense.deps <= 0) {
          suspense.resolve();
        }
      }
    }
  } else {
    if (activeBranch && isSameVNodeType(newBranch, activeBranch)) {
      patch2(
        activeBranch,
        newBranch,
        container,
        anchor,
        parentComponent,
        suspense,
        namespace,
        slotScopeIds,
        optimized
      );
      setActiveBranch(suspense, newBranch);
    } else {
      triggerEvent(n2, "onPending");
      suspense.pendingBranch = newBranch;
      if (newBranch.shapeFlag & 512) {
        suspense.pendingId = newBranch.component.suspenseId;
      } else {
        suspense.pendingId = suspenseId++;
      }
      patch2(
        null,
        newBranch,
        suspense.hiddenContainer,
        null,
        parentComponent,
        suspense,
        namespace,
        slotScopeIds,
        optimized
      );
      if (suspense.deps <= 0) {
        suspense.resolve();
      } else {
        const { timeout, pendingId } = suspense;
        if (timeout > 0) {
          setTimeout(() => {
            if (suspense.pendingId === pendingId) {
              suspense.fallback(newFallback);
            }
          }, timeout);
        } else if (timeout === 0) {
          suspense.fallback(newFallback);
        }
      }
    }
  }
}
__name(patchSuspense, "patchSuspense");
let hasWarned$1 = false;
function createSuspenseBoundary(vnode, parentSuspense, parentComponent, container, hiddenContainer, anchor, namespace, slotScopeIds, optimized, rendererInternals, isHydrating = false) {
  if (false) {
    hasWarned$1 = true;
    console[console.info ? "info" : "log"](
      `<Suspense> is an experimental feature and its API will likely change.`
    );
  }
  const {
    p: patch2,
    m: move,
    um: unmount,
    n: next2,
    o: { parentNode: parentNode2, remove: remove22 }
  } = rendererInternals;
  let parentSuspenseId;
  const isSuspensible = isVNodeSuspensible(vnode);
  if (isSuspensible) {
    if (parentSuspense && parentSuspense.pendingBranch) {
      parentSuspenseId = parentSuspense.pendingId;
      parentSuspense.deps++;
    }
  }
  const timeout = vnode.props ? toNumber(vnode.props.timeout) : void 0;
  if (false) {
    assertNumber(timeout, `Suspense timeout`);
  }
  const initialAnchor = anchor;
  const suspense = {
    vnode,
    parent: parentSuspense,
    parentComponent,
    namespace,
    container,
    hiddenContainer,
    deps: 0,
    pendingId: suspenseId++,
    timeout: typeof timeout === "number" ? timeout : -1,
    activeBranch: null,
    pendingBranch: null,
    isInFallback: !isHydrating,
    isHydrating,
    isUnmounted: false,
    effects: [],
    resolve(resume = false, sync = false) {
      if (false) {
        if (!resume && !suspense.pendingBranch) {
          throw new Error(
            `suspense.resolve() is called without a pending branch.`
          );
        }
        if (suspense.isUnmounted) {
          throw new Error(
            `suspense.resolve() is called on an already unmounted suspense boundary.`
          );
        }
      }
      const {
        vnode: vnode2,
        activeBranch,
        pendingBranch,
        pendingId,
        effects,
        parentComponent: parentComponent2,
        container: container2
      } = suspense;
      let delayEnter = false;
      if (suspense.isHydrating) {
        suspense.isHydrating = false;
      } else if (!resume) {
        delayEnter = activeBranch && pendingBranch.transition && pendingBranch.transition.mode === "out-in";
        if (delayEnter) {
          activeBranch.transition.afterLeave = () => {
            if (pendingId === suspense.pendingId) {
              move(
                pendingBranch,
                container2,
                anchor === initialAnchor ? next2(activeBranch) : anchor,
                0
              );
              queuePostFlushCb(effects);
            }
          };
        }
        if (activeBranch) {
          if (parentNode2(activeBranch.el) === container2) {
            anchor = next2(activeBranch);
          }
          unmount(activeBranch, parentComponent2, suspense, true);
        }
        if (!delayEnter) {
          move(pendingBranch, container2, anchor, 0);
        }
      }
      setActiveBranch(suspense, pendingBranch);
      suspense.pendingBranch = null;
      suspense.isInFallback = false;
      let parent = suspense.parent;
      let hasUnresolvedAncestor = false;
      while (parent) {
        if (parent.pendingBranch) {
          parent.effects.push(...effects);
          hasUnresolvedAncestor = true;
          break;
        }
        parent = parent.parent;
      }
      if (!hasUnresolvedAncestor && !delayEnter) {
        queuePostFlushCb(effects);
      }
      suspense.effects = [];
      if (isSuspensible) {
        if (parentSuspense && parentSuspense.pendingBranch && parentSuspenseId === parentSuspense.pendingId) {
          parentSuspense.deps--;
          if (parentSuspense.deps === 0 && !sync) {
            parentSuspense.resolve();
          }
        }
      }
      triggerEvent(vnode2, "onResolve");
    },
    fallback(fallbackVNode) {
      if (!suspense.pendingBranch) {
        return;
      }
      const { vnode: vnode2, activeBranch, parentComponent: parentComponent2, container: container2, namespace: namespace2 } = suspense;
      triggerEvent(vnode2, "onFallback");
      const anchor2 = next2(activeBranch);
      const mountFallback = /* @__PURE__ */ __name(() => {
        if (!suspense.isInFallback) {
          return;
        }
        patch2(
          null,
          fallbackVNode,
          container2,
          anchor2,
          parentComponent2,
          null,
          // fallback tree will not have suspense context
          namespace2,
          slotScopeIds,
          optimized
        );
        setActiveBranch(suspense, fallbackVNode);
      }, "mountFallback");
      const delayEnter = fallbackVNode.transition && fallbackVNode.transition.mode === "out-in";
      if (delayEnter) {
        activeBranch.transition.afterLeave = mountFallback;
      }
      suspense.isInFallback = true;
      unmount(
        activeBranch,
        parentComponent2,
        null,
        // no suspense so unmount hooks fire now
        true
        // shouldRemove
      );
      if (!delayEnter) {
        mountFallback();
      }
    },
    move(container2, anchor2, type) {
      suspense.activeBranch && move(suspense.activeBranch, container2, anchor2, type);
      suspense.container = container2;
    },
    next() {
      return suspense.activeBranch && next2(suspense.activeBranch);
    },
    registerDep(instance, setupRenderEffect, optimized2) {
      const isInPendingSuspense = !!suspense.pendingBranch;
      if (isInPendingSuspense) {
        suspense.deps++;
      }
      const hydratedEl = instance.vnode.el;
      instance.asyncDep.catch((err) => {
        handleError(err, instance, 0);
      }).then((asyncSetupResult) => {
        if (instance.isUnmounted || suspense.isUnmounted || suspense.pendingId !== instance.suspenseId) {
          return;
        }
        instance.asyncResolved = true;
        const { vnode: vnode2 } = instance;
        if (false) {
          pushWarningContext(vnode2);
        }
        handleSetupResult(instance, asyncSetupResult, false);
        if (hydratedEl) {
          vnode2.el = hydratedEl;
        }
        const placeholder = !hydratedEl && instance.subTree.el;
        setupRenderEffect(
          instance,
          vnode2,
          // component may have been moved before resolve.
          // if this is not a hydration, instance.subTree will be the comment
          // placeholder.
          parentNode2(hydratedEl || instance.subTree.el),
          // anchor will not be used if this is hydration, so only need to
          // consider the comment placeholder case.
          hydratedEl ? null : next2(instance.subTree),
          suspense,
          namespace,
          optimized2
        );
        if (placeholder) {
          remove22(placeholder);
        }
        updateHOCHostEl(instance, vnode2.el);
        if (false) {
          popWarningContext();
        }
        if (isInPendingSuspense && --suspense.deps === 0) {
          suspense.resolve();
        }
      });
    },
    unmount(parentSuspense2, doRemove) {
      suspense.isUnmounted = true;
      if (suspense.activeBranch) {
        unmount(
          suspense.activeBranch,
          parentComponent,
          parentSuspense2,
          doRemove
        );
      }
      if (suspense.pendingBranch) {
        unmount(
          suspense.pendingBranch,
          parentComponent,
          parentSuspense2,
          doRemove
        );
      }
    }
  };
  return suspense;
}
__name(createSuspenseBoundary, "createSuspenseBoundary");
function hydrateSuspense(node3, vnode, parentComponent, parentSuspense, namespace, slotScopeIds, optimized, rendererInternals, hydrateNode) {
  const suspense = vnode.suspense = createSuspenseBoundary(
    vnode,
    parentSuspense,
    parentComponent,
    node3.parentNode,
    // eslint-disable-next-line no-restricted-globals
    document.createElement("div"),
    null,
    namespace,
    slotScopeIds,
    optimized,
    rendererInternals,
    true
  );
  const result = hydrateNode(
    node3,
    suspense.pendingBranch = vnode.ssContent,
    parentComponent,
    suspense,
    slotScopeIds,
    optimized
  );
  if (suspense.deps === 0) {
    suspense.resolve(false, true);
  }
  return result;
}
__name(hydrateSuspense, "hydrateSuspense");
function normalizeSuspenseChildren(vnode) {
  const { shapeFlag, children } = vnode;
  const isSlotChildren = shapeFlag & 32;
  vnode.ssContent = normalizeSuspenseSlot(
    isSlotChildren ? children.default : children
  );
  vnode.ssFallback = isSlotChildren ? normalizeSuspenseSlot(children.fallback) : createVNode(Comment);
}
__name(normalizeSuspenseChildren, "normalizeSuspenseChildren");
function normalizeSuspenseSlot(s2) {
  let block3;
  if (isFunction$c(s2)) {
    const trackBlock = isBlockTreeEnabled && s2._c;
    if (trackBlock) {
      s2._d = false;
      openBlock();
    }
    s2 = s2();
    if (trackBlock) {
      s2._d = true;
      block3 = currentBlock;
      closeBlock();
    }
  }
  if (isArray$b(s2)) {
    const singleChild = filterSingleRoot(s2);
    if (false) {
      warn$1$1(`<Suspense> slots expect a single root node.`);
    }
    s2 = singleChild;
  }
  s2 = normalizeVNode(s2);
  if (block3 && !s2.dynamicChildren) {
    s2.dynamicChildren = block3.filter((c2) => c2 !== s2);
  }
  return s2;
}
__name(normalizeSuspenseSlot, "normalizeSuspenseSlot");
function queueEffectWithSuspense(fn, suspense) {
  if (suspense && suspense.pendingBranch) {
    if (isArray$b(fn)) {
      suspense.effects.push(...fn);
    } else {
      suspense.effects.push(fn);
    }
  } else {
    queuePostFlushCb(fn);
  }
}
__name(queueEffectWithSuspense, "queueEffectWithSuspense");
function setActiveBranch(suspense, branch) {
  suspense.activeBranch = branch;
  const { vnode, parentComponent } = suspense;
  let el = branch.el;
  while (!el && branch.component) {
    branch = branch.component.subTree;
    el = branch.el;
  }
  vnode.el = el;
  if (parentComponent && parentComponent.subTree === vnode) {
    parentComponent.vnode.el = el;
    updateHOCHostEl(parentComponent, el);
  }
}
__name(setActiveBranch, "setActiveBranch");
function isVNodeSuspensible(vnode) {
  const suspensible = vnode.props && vnode.props.suspensible;
  return suspensible != null && suspensible !== false;
}
__name(isVNodeSuspensible, "isVNodeSuspensible");
const Fragment$1 = Symbol.for("v-fgt");
const Text$4 = Symbol.for("v-txt");
const Comment = Symbol.for("v-cmt");
const Static = Symbol.for("v-stc");
const blockStack = [];
let currentBlock = null;
function openBlock(disableTracking = false) {
  blockStack.push(currentBlock = disableTracking ? null : []);
}
__name(openBlock, "openBlock");
function closeBlock() {
  blockStack.pop();
  currentBlock = blockStack[blockStack.length - 1] || null;
}
__name(closeBlock, "closeBlock");
let isBlockTreeEnabled = 1;
function setBlockTracking(value3, inVOnce = false) {
  isBlockTreeEnabled += value3;
  if (value3 < 0 && currentBlock && inVOnce) {
    currentBlock.hasOnce = true;
  }
}
__name(setBlockTracking, "setBlockTracking");
function setupBlock(vnode) {
  vnode.dynamicChildren = isBlockTreeEnabled > 0 ? currentBlock || EMPTY_ARR : null;
  closeBlock();
  if (isBlockTreeEnabled > 0 && currentBlock) {
    currentBlock.push(vnode);
  }
  return vnode;
}
__name(setupBlock, "setupBlock");
function createElementBlock(type, props, children, patchFlag, dynamicProps, shapeFlag) {
  return setupBlock(
    createBaseVNode(
      type,
      props,
      children,
      patchFlag,
      dynamicProps,
      shapeFlag,
      true
    )
  );
}
__name(createElementBlock, "createElementBlock");
function createBlock(type, props, children, patchFlag, dynamicProps) {
  return setupBlock(
    createVNode(
      type,
      props,
      children,
      patchFlag,
      dynamicProps,
      true
    )
  );
}
__name(createBlock, "createBlock");
function isVNode$1(value3) {
  return value3 ? value3.__v_isVNode === true : false;
}
__name(isVNode$1, "isVNode$1");
function isSameVNodeType(n1, n2) {
  if (false) {
    const dirtyInstances = hmrDirtyComponents.get(n2.type);
    if (dirtyInstances && dirtyInstances.has(n1.component)) {
      n1.shapeFlag &= ~256;
      n2.shapeFlag &= ~512;
      return false;
    }
  }
  return n1.type === n2.type && n1.key === n2.key;
}
__name(isSameVNodeType, "isSameVNodeType");
let vnodeArgsTransformer;
function transformVNodeArgs(transformer) {
  vnodeArgsTransformer = transformer;
}
__name(transformVNodeArgs, "transformVNodeArgs");
const createVNodeWithArgsTransform = /* @__PURE__ */ __name((...args) => {
  return _createVNode(
    ...vnodeArgsTransformer ? vnodeArgsTransformer(args, currentRenderingInstance) : args
  );
}, "createVNodeWithArgsTransform");
const normalizeKey = /* @__PURE__ */ __name(({ key }) => key != null ? key : null, "normalizeKey");
const normalizeRef = /* @__PURE__ */ __name(({
  ref: ref3,
  ref_key,
  ref_for
}) => {
  if (typeof ref3 === "number") {
    ref3 = "" + ref3;
  }
  return ref3 != null ? isString$9(ref3) || isRef(ref3) || isFunction$c(ref3) ? { i: currentRenderingInstance, r: ref3, k: ref_key, f: !!ref_for } : ref3 : null;
}, "normalizeRef");
function createBaseVNode(type, props = null, children = null, patchFlag = 0, dynamicProps = null, shapeFlag = type === Fragment$1 ? 0 : 1, isBlockNode2 = false, needFullChildrenNormalization = false) {
  const vnode = {
    __v_isVNode: true,
    __v_skip: true,
    type,
    props,
    key: props && normalizeKey(props),
    ref: props && normalizeRef(props),
    scopeId: currentScopeId,
    slotScopeIds: null,
    children,
    component: null,
    suspense: null,
    ssContent: null,
    ssFallback: null,
    dirs: null,
    transition: null,
    el: null,
    anchor: null,
    target: null,
    targetStart: null,
    targetAnchor: null,
    staticCount: 0,
    shapeFlag,
    patchFlag,
    dynamicProps,
    dynamicChildren: null,
    appContext: null,
    ctx: currentRenderingInstance
  };
  if (needFullChildrenNormalization) {
    normalizeChildren(vnode, children);
    if (shapeFlag & 128) {
      type.normalize(vnode);
    }
  } else if (children) {
    vnode.shapeFlag |= isString$9(children) ? 8 : 16;
  }
  if (false) {
    warn$1$1(`VNode created with invalid key (NaN). VNode type:`, vnode.type);
  }
  if (isBlockTreeEnabled > 0 && // avoid a block node from tracking itself
  !isBlockNode2 && // has current parent block
  currentBlock && // presence of a patch flag indicates this node needs patching on updates.
  // component nodes also should always be patched, because even if the
  // component doesn't need to update, it needs to persist the instance on to
  // the next vnode so that it can be properly unmounted later.
  (vnode.patchFlag > 0 || shapeFlag & 6) && // the EVENTS flag is only for hydration and if it is the only flag, the
  // vnode should not be considered dynamic due to handler caching.
  vnode.patchFlag !== 32) {
    currentBlock.push(vnode);
  }
  return vnode;
}
__name(createBaseVNode, "createBaseVNode");
const createVNode = false ? createVNodeWithArgsTransform : _createVNode;
function _createVNode(type, props = null, children = null, patchFlag = 0, dynamicProps = null, isBlockNode2 = false) {
  if (!type || type === NULL_DYNAMIC_COMPONENT) {
    if (false) {
      warn$1$1(`Invalid vnode type when creating vnode: ${type}.`);
    }
    type = Comment;
  }
  if (isVNode$1(type)) {
    const cloned = cloneVNode(
      type,
      props,
      true
      /* mergeRef: true */
    );
    if (children) {
      normalizeChildren(cloned, children);
    }
    if (isBlockTreeEnabled > 0 && !isBlockNode2 && currentBlock) {
      if (cloned.shapeFlag & 6) {
        currentBlock[currentBlock.indexOf(type)] = cloned;
      } else {
        currentBlock.push(cloned);
      }
    }
    cloned.patchFlag = -2;
    return cloned;
  }
  if (isClassComponent(type)) {
    type = type.__vccOpts;
  }
  if (props) {
    props = guardReactiveProps(props);
    let { class: klass, style: style2 } = props;
    if (klass && !isString$9(klass)) {
      props.class = normalizeClass(klass);
    }
    if (isObject$f(style2)) {
      if (isProxy(style2) && !isArray$b(style2)) {
        style2 = extend$1({}, style2);
      }
      props.style = normalizeStyle(style2);
    }
  }
  const shapeFlag = isString$9(type) ? 1 : isSuspense(type) ? 128 : isTeleport(type) ? 64 : isObject$f(type) ? 4 : isFunction$c(type) ? 2 : 0;
  if (false) {
    type = toRaw(type);
    warn$1$1(
      `Vue received a Component that was made a reactive object. This can lead to unnecessary performance overhead and should be avoided by marking the component with \`markRaw\` or using \`shallowRef\` instead of \`ref\`.`,
      `
Component that was made reactive: `,
      type
    );
  }
  return createBaseVNode(
    type,
    props,
    children,
    patchFlag,
    dynamicProps,
    shapeFlag,
    isBlockNode2,
    true
  );
}
__name(_createVNode, "_createVNode");
function guardReactiveProps(props) {
  if (!props) return null;
  return isProxy(props) || isInternalObject(props) ? extend$1({}, props) : props;
}
__name(guardReactiveProps, "guardReactiveProps");
function cloneVNode(vnode, extraProps, mergeRef = false, cloneTransition = false) {
  const { props, ref: ref3, patchFlag, children, transition } = vnode;
  const mergedProps = extraProps ? mergeProps$2(props || {}, extraProps) : props;
  const cloned = {
    __v_isVNode: true,
    __v_skip: true,
    type: vnode.type,
    props: mergedProps,
    key: mergedProps && normalizeKey(mergedProps),
    ref: extraProps && extraProps.ref ? (
      // #2078 in the case of <component :is="vnode" ref="extra"/>
      // if the vnode itself already has a ref, cloneVNode will need to merge
      // the refs so the single vnode can be set on multiple refs
      mergeRef && ref3 ? isArray$b(ref3) ? ref3.concat(normalizeRef(extraProps)) : [ref3, normalizeRef(extraProps)] : normalizeRef(extraProps)
    ) : ref3,
    scopeId: vnode.scopeId,
    slotScopeIds: vnode.slotScopeIds,
    children: false ? children.map(deepCloneVNode) : children,
    target: vnode.target,
    targetStart: vnode.targetStart,
    targetAnchor: vnode.targetAnchor,
    staticCount: vnode.staticCount,
    shapeFlag: vnode.shapeFlag,
    // if the vnode is cloned with extra props, we can no longer assume its
    // existing patch flag to be reliable and need to add the FULL_PROPS flag.
    // note: preserve flag for fragments since they use the flag for children
    // fast paths only.
    patchFlag: extraProps && vnode.type !== Fragment$1 ? patchFlag === -1 ? 16 : patchFlag | 16 : patchFlag,
    dynamicProps: vnode.dynamicProps,
    dynamicChildren: vnode.dynamicChildren,
    appContext: vnode.appContext,
    dirs: vnode.dirs,
    transition,
    // These should technically only be non-null on mounted VNodes. However,
    // they *should* be copied for kept-alive vnodes. So we just always copy
    // them since them being non-null during a mount doesn't affect the logic as
    // they will simply be overwritten.
    component: vnode.component,
    suspense: vnode.suspense,
    ssContent: vnode.ssContent && cloneVNode(vnode.ssContent),
    ssFallback: vnode.ssFallback && cloneVNode(vnode.ssFallback),
    el: vnode.el,
    anchor: vnode.anchor,
    ctx: vnode.ctx,
    ce: vnode.ce
  };
  if (transition && cloneTransition) {
    setTransitionHooks(
      cloned,
      transition.clone(cloned)
    );
  }
  return cloned;
}
__name(cloneVNode, "cloneVNode");
function deepCloneVNode(vnode) {
  const cloned = cloneVNode(vnode);
  if (isArray$b(vnode.children)) {
    cloned.children = vnode.children.map(deepCloneVNode);
  }
  return cloned;
}
__name(deepCloneVNode, "deepCloneVNode");
function createTextVNode(text2 = " ", flag = 0) {
  return createVNode(Text$4, null, text2, flag);
}
__name(createTextVNode, "createTextVNode");
function createStaticVNode(content3, numberOfNodes) {
  const vnode = createVNode(Static, null, content3);
  vnode.staticCount = numberOfNodes;
  return vnode;
}
__name(createStaticVNode, "createStaticVNode");
function createCommentVNode(text2 = "", asBlock = false) {
  return asBlock ? (openBlock(), createBlock(Comment, null, text2)) : createVNode(Comment, null, text2);
}
__name(createCommentVNode, "createCommentVNode");
function normalizeVNode(child) {
  if (child == null || typeof child === "boolean") {
    return createVNode(Comment);
  } else if (isArray$b(child)) {
    return createVNode(
      Fragment$1,
      null,
      // #3666, avoid reference pollution when reusing vnode
      child.slice()
    );
  } else if (isVNode$1(child)) {
    return cloneIfMounted(child);
  } else {
    return createVNode(Text$4, null, String(child));
  }
}
__name(normalizeVNode, "normalizeVNode");
function cloneIfMounted(child) {
  return child.el === null && child.patchFlag !== -1 || child.memo ? child : cloneVNode(child);
}
__name(cloneIfMounted, "cloneIfMounted");
function normalizeChildren(vnode, children) {
  let type = 0;
  const { shapeFlag } = vnode;
  if (children == null) {
    children = null;
  } else if (isArray$b(children)) {
    type = 16;
  } else if (typeof children === "object") {
    if (shapeFlag & (1 | 64)) {
      const slot = children.default;
      if (slot) {
        slot._c && (slot._d = false);
        normalizeChildren(vnode, slot());
        slot._c && (slot._d = true);
      }
      return;
    } else {
      type = 32;
      const slotFlag = children._;
      if (!slotFlag && !isInternalObject(children)) {
        children._ctx = currentRenderingInstance;
      } else if (slotFlag === 3 && currentRenderingInstance) {
        if (currentRenderingInstance.slots._ === 1) {
          children._ = 1;
        } else {
          children._ = 2;
          vnode.patchFlag |= 1024;
        }
      }
    }
  } else if (isFunction$c(children)) {
    children = { default: children, _ctx: currentRenderingInstance };
    type = 32;
  } else {
    children = String(children);
    if (shapeFlag & 64) {
      type = 16;
      children = [createTextVNode(children)];
    } else {
      type = 8;
    }
  }
  vnode.children = children;
  vnode.shapeFlag |= type;
}
__name(normalizeChildren, "normalizeChildren");
function mergeProps$2(...args) {
  const ret = {};
  for (let i2 = 0; i2 < args.length; i2++) {
    const toMerge = args[i2];
    for (const key in toMerge) {
      if (key === "class") {
        if (ret.class !== toMerge.class) {
          ret.class = normalizeClass([ret.class, toMerge.class]);
        }
      } else if (key === "style") {
        ret.style = normalizeStyle([ret.style, toMerge.style]);
      } else if (isOn(key)) {
        const existing = ret[key];
        const incoming = toMerge[key];
        if (incoming && existing !== incoming && !(isArray$b(existing) && existing.includes(incoming))) {
          ret[key] = existing ? [].concat(existing, incoming) : incoming;
        }
      } else if (key !== "") {
        ret[key] = toMerge[key];
      }
    }
  }
  return ret;
}
__name(mergeProps$2, "mergeProps$2");
function invokeVNodeHook(hook, instance, vnode, prevVNode = null) {
  callWithAsyncErrorHandling(hook, instance, 7, [
    vnode,
    prevVNode
  ]);
}
__name(invokeVNodeHook, "invokeVNodeHook");
const emptyAppContext = createAppContext();
let uid = 0;
function createComponentInstance(vnode, parent, suspense) {
  const type = vnode.type;
  const appContext = (parent ? parent.appContext : vnode.appContext) || emptyAppContext;
  const instance = {
    uid: uid++,
    vnode,
    type,
    parent,
    appContext,
    root: null,
    // to be immediately set
    next: null,
    subTree: null,
    // will be set synchronously right after creation
    effect: null,
    update: null,
    // will be set synchronously right after creation
    job: null,
    scope: new EffectScope(
      true
      /* detached */
    ),
    render: null,
    proxy: null,
    exposed: null,
    exposeProxy: null,
    withProxy: null,
    provides: parent ? parent.provides : Object.create(appContext.provides),
    ids: parent ? parent.ids : ["", 0, 0],
    accessCache: null,
    renderCache: [],
    // local resolved assets
    components: null,
    directives: null,
    // resolved props and emits options
    propsOptions: normalizePropsOptions(type, appContext),
    emitsOptions: normalizeEmitsOptions(type, appContext),
    // emit
    emit: null,
    // to be set immediately
    emitted: null,
    // props default value
    propsDefaults: EMPTY_OBJ,
    // inheritAttrs
    inheritAttrs: type.inheritAttrs,
    // state
    ctx: EMPTY_OBJ,
    data: EMPTY_OBJ,
    props: EMPTY_OBJ,
    attrs: EMPTY_OBJ,
    slots: EMPTY_OBJ,
    refs: EMPTY_OBJ,
    setupState: EMPTY_OBJ,
    setupContext: null,
    // suspense related
    suspense,
    suspenseId: suspense ? suspense.pendingId : 0,
    asyncDep: null,
    asyncResolved: false,
    // lifecycle hooks
    // not using enums here because it results in computed properties
    isMounted: false,
    isUnmounted: false,
    isDeactivated: false,
    bc: null,
    c: null,
    bm: null,
    m: null,
    bu: null,
    u: null,
    um: null,
    bum: null,
    da: null,
    a: null,
    rtg: null,
    rtc: null,
    ec: null,
    sp: null
  };
  if (false) {
    instance.ctx = createDevRenderContext(instance);
  } else {
    instance.ctx = { _: instance };
  }
  instance.root = parent ? parent.root : instance;
  instance.emit = emit.bind(null, instance);
  if (vnode.ce) {
    vnode.ce(instance);
  }
  return instance;
}
__name(createComponentInstance, "createComponentInstance");
let currentInstance = null;
const getCurrentInstance = /* @__PURE__ */ __name(() => currentInstance || currentRenderingInstance, "getCurrentInstance");
let internalSetCurrentInstance;
let setInSSRSetupState;
{
  const g2 = getGlobalThis$1();
  const registerGlobalSetter = /* @__PURE__ */ __name((key, setter) => {
    let setters;
    if (!(setters = g2[key])) setters = g2[key] = [];
    setters.push(setter);
    return (v2) => {
      if (setters.length > 1) setters.forEach((set3) => set3(v2));
      else setters[0](v2);
    };
  }, "registerGlobalSetter");
  internalSetCurrentInstance = registerGlobalSetter(
    `__VUE_INSTANCE_SETTERS__`,
    (v2) => currentInstance = v2
  );
  setInSSRSetupState = registerGlobalSetter(
    `__VUE_SSR_SETTERS__`,
    (v2) => isInSSRComponentSetup = v2
  );
}
const setCurrentInstance = /* @__PURE__ */ __name((instance) => {
  const prev2 = currentInstance;
  internalSetCurrentInstance(instance);
  instance.scope.on();
  return () => {
    instance.scope.off();
    internalSetCurrentInstance(prev2);
  };
}, "setCurrentInstance");
const unsetCurrentInstance = /* @__PURE__ */ __name(() => {
  currentInstance && currentInstance.scope.off();
  internalSetCurrentInstance(null);
}, "unsetCurrentInstance");
const isBuiltInTag = /* @__PURE__ */ makeMap("slot,component");
function validateComponentName(name2, { isNativeTag }) {
  if (isBuiltInTag(name2) || isNativeTag(name2)) {
    warn$1$1(
      "Do not use built-in or reserved HTML elements as component id: " + name2
    );
  }
}
__name(validateComponentName, "validateComponentName");
function isStatefulComponent(instance) {
  return instance.vnode.shapeFlag & 4;
}
__name(isStatefulComponent, "isStatefulComponent");
let isInSSRComponentSetup = false;
function setupComponent(instance, isSSR = false, optimized = false) {
  isSSR && setInSSRSetupState(isSSR);
  const { props, children } = instance.vnode;
  const isStateful = isStatefulComponent(instance);
  initProps(instance, props, isStateful, isSSR);
  initSlots(instance, children, optimized);
  const setupResult = isStateful ? setupStatefulComponent(instance, isSSR) : void 0;
  isSSR && setInSSRSetupState(false);
  return setupResult;
}
__name(setupComponent, "setupComponent");
function setupStatefulComponent(instance, isSSR) {
  var _a2;
  const Component = instance.type;
  if (false) {
    if (Component.name) {
      validateComponentName(Component.name, instance.appContext.config);
    }
    if (Component.components) {
      const names = Object.keys(Component.components);
      for (let i2 = 0; i2 < names.length; i2++) {
        validateComponentName(names[i2], instance.appContext.config);
      }
    }
    if (Component.directives) {
      const names = Object.keys(Component.directives);
      for (let i2 = 0; i2 < names.length; i2++) {
        validateDirectiveName(names[i2]);
      }
    }
    if (Component.compilerOptions && isRuntimeOnly()) {
      warn$1$1(
        `"compilerOptions" is only supported when using a build of Vue that includes the runtime compiler. Since you are using a runtime-only build, the options should be passed via your build tool config instead.`
      );
    }
  }
  instance.accessCache = /* @__PURE__ */ Object.create(null);
  instance.proxy = new Proxy(instance.ctx, PublicInstanceProxyHandlers);
  if (false) {
    exposePropsOnRenderContext(instance);
  }
  const { setup: setup3 } = Component;
  if (setup3) {
    pauseTracking();
    const setupContext = instance.setupContext = setup3.length > 1 ? createSetupContext(instance) : null;
    const reset2 = setCurrentInstance(instance);
    const setupResult = callWithErrorHandling(
      setup3,
      instance,
      0,
      [
        false ? shallowReadonly(instance.props) : instance.props,
        setupContext
      ]
    );
    const isAsyncSetup = isPromise$1(setupResult);
    resetTracking();
    reset2();
    if ((isAsyncSetup || instance.sp) && !isAsyncWrapper(instance)) {
      markAsyncBoundary(instance);
    }
    if (isAsyncSetup) {
      setupResult.then(unsetCurrentInstance, unsetCurrentInstance);
      if (isSSR) {
        return setupResult.then((resolvedResult) => {
          handleSetupResult(instance, resolvedResult, isSSR);
        }).catch((e2) => {
          handleError(e2, instance, 0);
        });
      } else {
        instance.asyncDep = setupResult;
        if (false) {
          const name2 = (_a2 = Component.name) != null ? _a2 : "Anonymous";
          warn$1$1(
            `Component <${name2}>: setup function returned a promise, but no <Suspense> boundary was found in the parent component tree. A component with async setup() must be nested in a <Suspense> in order to be rendered.`
          );
        }
      }
    } else {
      handleSetupResult(instance, setupResult, isSSR);
    }
  } else {
    finishComponentSetup(instance, isSSR);
  }
}
__name(setupStatefulComponent, "setupStatefulComponent");
function handleSetupResult(instance, setupResult, isSSR) {
  if (isFunction$c(setupResult)) {
    if (instance.type.__ssrInlineRender) {
      instance.ssrRender = setupResult;
    } else {
      instance.render = setupResult;
    }
  } else if (isObject$f(setupResult)) {
    if (false) {
      warn$1$1(
        `setup() should not return VNodes directly - return a render function instead.`
      );
    }
    if (false) {
      instance.devtoolsRawSetupState = setupResult;
    }
    instance.setupState = proxyRefs(setupResult);
    if (false) {
      exposeSetupStateOnRenderContext(instance);
    }
  } else if (false) {
    warn$1$1(
      `setup() should return an object. Received: ${setupResult === null ? "null" : typeof setupResult}`
    );
  }
  finishComponentSetup(instance, isSSR);
}
__name(handleSetupResult, "handleSetupResult");
let compile$3;
let installWithProxy;
function registerRuntimeCompiler(_compile) {
  compile$3 = _compile;
  installWithProxy = /* @__PURE__ */ __name((i2) => {
    if (i2.render._rc) {
      i2.withProxy = new Proxy(i2.ctx, RuntimeCompiledPublicInstanceProxyHandlers);
    }
  }, "installWithProxy");
}
__name(registerRuntimeCompiler, "registerRuntimeCompiler");
const isRuntimeOnly = /* @__PURE__ */ __name(() => !compile$3, "isRuntimeOnly");
function finishComponentSetup(instance, isSSR, skipOptions) {
  const Component = instance.type;
  if (!instance.render) {
    if (!isSSR && compile$3 && !Component.render) {
      const template = Component.template || resolveMergedOptions(instance).template;
      if (template) {
        if (false) {
          startMeasure(instance, `compile`);
        }
        const { isCustomElement, compilerOptions } = instance.appContext.config;
        const { delimiters, compilerOptions: componentCompilerOptions } = Component;
        const finalCompilerOptions = extend$1(
          extend$1(
            {
              isCustomElement,
              delimiters
            },
            compilerOptions
          ),
          componentCompilerOptions
        );
        Component.render = compile$3(template, finalCompilerOptions);
        if (false) {
          endMeasure(instance, `compile`);
        }
      }
    }
    instance.render = Component.render || NOOP;
    if (installWithProxy) {
      installWithProxy(instance);
    }
  }
  if (true) {
    const reset2 = setCurrentInstance(instance);
    pauseTracking();
    try {
      applyOptions(instance);
    } finally {
      resetTracking();
      reset2();
    }
  }
  if (false) {
    if (!compile$3 && Component.template) {
      warn$1$1(
        `Component provided template option but runtime compilation is not supported in this build of Vue. Configure your bundler to alias "vue" to "vue/dist/vue.esm-bundler.js".`
      );
    } else {
      warn$1$1(`Component is missing template or render function: `, Component);
    }
  }
}
__name(finishComponentSetup, "finishComponentSetup");
const attrsProxyHandlers = false ? {
  get(target2, key) {
    markAttrsAccessed();
    track(target2, "get", "");
    return target2[key];
  },
  set() {
    warn$1$1(`setupContext.attrs is readonly.`);
    return false;
  },
  deleteProperty() {
    warn$1$1(`setupContext.attrs is readonly.`);
    return false;
  }
} : {
  get(target2, key) {
    track(target2, "get", "");
    return target2[key];
  }
};
function getSlotsProxy(instance) {
  return new Proxy(instance.slots, {
    get(target2, key) {
      track(instance, "get", "$slots");
      return target2[key];
    }
  });
}
__name(getSlotsProxy, "getSlotsProxy");
function createSetupContext(instance) {
  const expose = /* @__PURE__ */ __name((exposed) => {
    if (false) {
      if (instance.exposed) {
        warn$1$1(`expose() should be called only once per setup().`);
      }
      if (exposed != null) {
        let exposedType = typeof exposed;
        if (exposedType === "object") {
          if (isArray$b(exposed)) {
            exposedType = "array";
          } else if (isRef(exposed)) {
            exposedType = "ref";
          }
        }
        if (exposedType !== "object") {
          warn$1$1(
            `expose() should be passed a plain object, received ${exposedType}.`
          );
        }
      }
    }
    instance.exposed = exposed || {};
  }, "expose");
  if (false) {
    let attrsProxy;
    let slotsProxy;
    return Object.freeze({
      get attrs() {
        return attrsProxy || (attrsProxy = new Proxy(instance.attrs, attrsProxyHandlers));
      },
      get slots() {
        return slotsProxy || (slotsProxy = getSlotsProxy(instance));
      },
      get emit() {
        return (event, ...args) => instance.emit(event, ...args);
      },
      expose
    });
  } else {
    return {
      attrs: new Proxy(instance.attrs, attrsProxyHandlers),
      slots: instance.slots,
      emit: instance.emit,
      expose
    };
  }
}
__name(createSetupContext, "createSetupContext");
function getComponentPublicInstance(instance) {
  if (instance.exposed) {
    return instance.exposeProxy || (instance.exposeProxy = new Proxy(proxyRefs(markRaw(instance.exposed)), {
      get(target2, key) {
        if (key in target2) {
          return target2[key];
        } else if (key in publicPropertiesMap) {
          return publicPropertiesMap[key](instance);
        }
      },
      has(target2, key) {
        return key in target2 || key in publicPropertiesMap;
      }
    }));
  } else {
    return instance.proxy;
  }
}
__name(getComponentPublicInstance, "getComponentPublicInstance");
const classifyRE = /(?:^|[-_])(\w)/g;
const classify = /* @__PURE__ */ __name((str) => str.replace(classifyRE, (c2) => c2.toUpperCase()).replace(/[-_]/g, ""), "classify");
function getComponentName(Component, includeInferred = true) {
  return isFunction$c(Component) ? Component.displayName || Component.name : Component.name || includeInferred && Component.__name;
}
__name(getComponentName, "getComponentName");
function formatComponentName(instance, Component, isRoot = false) {
  let name2 = getComponentName(Component);
  if (!name2 && Component.__file) {
    const match2 = Component.__file.match(/([^/\\]+)\.\w+$/);
    if (match2) {
      name2 = match2[1];
    }
  }
  if (!name2 && instance && instance.parent) {
    const inferFromRegistry = /* @__PURE__ */ __name((registry) => {
      for (const key in registry) {
        if (registry[key] === Component) {
          return key;
        }
      }
    }, "inferFromRegistry");
    name2 = inferFromRegistry(
      instance.components || instance.parent.type.components
    ) || inferFromRegistry(instance.appContext.components);
  }
  return name2 ? classify(name2) : isRoot ? `App` : `Anonymous`;
}
__name(formatComponentName, "formatComponentName");
function isClassComponent(value3) {
  return isFunction$c(value3) && "__vccOpts" in value3;
}
__name(isClassComponent, "isClassComponent");
const computed = /* @__PURE__ */ __name((getterOrOptions, debugOptions) => {
  const c2 = computed$1(getterOrOptions, debugOptions, isInSSRComponentSetup);
  if (false) {
    const i2 = getCurrentInstance();
    if (i2 && i2.appContext.config.warnRecursiveComputed) {
      c2._warnRecursive = true;
    }
  }
  return c2;
}, "computed");
function h(type, propsOrChildren, children) {
  const l2 = arguments.length;
  if (l2 === 2) {
    if (isObject$f(propsOrChildren) && !isArray$b(propsOrChildren)) {
      if (isVNode$1(propsOrChildren)) {
        return createVNode(type, null, [propsOrChildren]);
      }
      return createVNode(type, propsOrChildren);
    } else {
      return createVNode(type, null, propsOrChildren);
    }
  } else {
    if (l2 > 3) {
      children = Array.prototype.slice.call(arguments, 2);
    } else if (l2 === 3 && isVNode$1(children)) {
      children = [children];
    }
    return createVNode(type, propsOrChildren, children);
  }
}
__name(h, "h");
function initCustomFormatter() {
  if (true) {
    return;
  }
  const vueStyle = { style: "color:#3ba776" };
  const numberStyle = { style: "color:#1677ff" };
  const stringStyle = { style: "color:#f5222d" };
  const keywordStyle = { style: "color:#eb2f96" };
  const formatter = {
    __vue_custom_formatter: true,
    header(obj) {
      if (!isObject$f(obj)) {
        return null;
      }
      if (obj.__isVue) {
        return ["div", vueStyle, `VueInstance`];
      } else if (isRef(obj)) {
        return [
          "div",
          {},
          ["span", vueStyle, genRefFlag(obj)],
          "<",
          // avoid debugger accessing value affecting behavior
          formatValue2("_value" in obj ? obj._value : obj),
          `>`
        ];
      } else if (isReactive(obj)) {
        return [
          "div",
          {},
          ["span", vueStyle, isShallow(obj) ? "ShallowReactive" : "Reactive"],
          "<",
          formatValue2(obj),
          `>${isReadonly(obj) ? ` (readonly)` : ``}`
        ];
      } else if (isReadonly(obj)) {
        return [
          "div",
          {},
          ["span", vueStyle, isShallow(obj) ? "ShallowReadonly" : "Readonly"],
          "<",
          formatValue2(obj),
          ">"
        ];
      }
      return null;
    },
    hasBody(obj) {
      return obj && obj.__isVue;
    },
    body(obj) {
      if (obj && obj.__isVue) {
        return [
          "div",
          {},
          ...formatInstance(obj.$)
        ];
      }
    }
  };
  function formatInstance(instance) {
    const blocks = [];
    if (instance.type.props && instance.props) {
      blocks.push(createInstanceBlock("props", toRaw(instance.props)));
    }
    if (instance.setupState !== EMPTY_OBJ) {
      blocks.push(createInstanceBlock("setup", instance.setupState));
    }
    if (instance.data !== EMPTY_OBJ) {
      blocks.push(createInstanceBlock("data", toRaw(instance.data)));
    }
    const computed2 = extractKeys(instance, "computed");
    if (computed2) {
      blocks.push(createInstanceBlock("computed", computed2));
    }
    const injected = extractKeys(instance, "inject");
    if (injected) {
      blocks.push(createInstanceBlock("injected", injected));
    }
    blocks.push([
      "div",
      {},
      [
        "span",
        {
          style: keywordStyle.style + ";opacity:0.66"
        },
        "$ (internal): "
      ],
      ["object", { object: instance }]
    ]);
    return blocks;
  }
  __name(formatInstance, "formatInstance");
  function createInstanceBlock(type, target2) {
    target2 = extend$1({}, target2);
    if (!Object.keys(target2).length) {
      return ["span", {}];
    }
    return [
      "div",
      { style: "line-height:1.25em;margin-bottom:0.6em" },
      [
        "div",
        {
          style: "color:#476582"
        },
        type
      ],
      [
        "div",
        {
          style: "padding-left:1.25em"
        },
        ...Object.keys(target2).map((key) => {
          return [
            "div",
            {},
            ["span", keywordStyle, key + ": "],
            formatValue2(target2[key], false)
          ];
        })
      ]
    ];
  }
  __name(createInstanceBlock, "createInstanceBlock");
  function formatValue2(v2, asRaw = true) {
    if (typeof v2 === "number") {
      return ["span", numberStyle, v2];
    } else if (typeof v2 === "string") {
      return ["span", stringStyle, JSON.stringify(v2)];
    } else if (typeof v2 === "boolean") {
      return ["span", keywordStyle, v2];
    } else if (isObject$f(v2)) {
      return ["object", { object: asRaw ? toRaw(v2) : v2 }];
    } else {
      return ["span", stringStyle, String(v2)];
    }
  }
  __name(formatValue2, "formatValue");
  function extractKeys(instance, type) {
    const Comp = instance.type;
    if (isFunction$c(Comp)) {
      return;
    }
    const extracted = {};
    for (const key in instance.ctx) {
      if (isKeyOfType(Comp, key, type)) {
        extracted[key] = instance.ctx[key];
      }
    }
    return extracted;
  }
  __name(extractKeys, "extractKeys");
  function isKeyOfType(Comp, key, type) {
    const opts = Comp[type];
    if (isArray$b(opts) && opts.includes(key) || isObject$f(opts) && key in opts) {
      return true;
    }
    if (Comp.extends && isKeyOfType(Comp.extends, key, type)) {
      return true;
    }
    if (Comp.mixins && Comp.mixins.some((m2) => isKeyOfType(m2, key, type))) {
      return true;
    }
  }
  __name(isKeyOfType, "isKeyOfType");
  function genRefFlag(v2) {
    if (isShallow(v2)) {
      return `ShallowRef`;
    }
    if (v2.effect) {
      return `ComputedRef`;
    }
    return `Ref`;
  }
  __name(genRefFlag, "genRefFlag");
  if (window.devtoolsFormatters) {
    window.devtoolsFormatters.push(formatter);
  } else {
    window.devtoolsFormatters = [formatter];
  }
}
__name(initCustomFormatter, "initCustomFormatter");
function withMemo(memo, render2, cache2, index2) {
  const cached = cache2[index2];
  if (cached && isMemoSame(cached, memo)) {
    return cached;
  }
  const ret = render2();
  ret.memo = memo.slice();
  ret.cacheIndex = index2;
  return cache2[index2] = ret;
}
__name(withMemo, "withMemo");
function isMemoSame(cached, memo) {
  const prev2 = cached.memo;
  if (prev2.length != memo.length) {
    return false;
  }
  for (let i2 = 0; i2 < prev2.length; i2++) {
    if (hasChanged(prev2[i2], memo[i2])) {
      return false;
    }
  }
  if (isBlockTreeEnabled > 0 && currentBlock) {
    currentBlock.push(cached);
  }
  return true;
}
__name(isMemoSame, "isMemoSame");
const version = "3.5.13";
const warn$3 = false ? warn$1$1 : NOOP;
const ErrorTypeStrings = ErrorTypeStrings$1;
const devtools$2 = true ? devtools$1 : void 0;
const setDevtoolsHook = true ? setDevtoolsHook$1 : NOOP;
const _ssrUtils = {
  createComponentInstance,
  setupComponent,
  renderComponentRoot,
  setCurrentRenderingInstance,
  isVNode: isVNode$1,
  normalizeVNode,
  getComponentPublicInstance,
  ensureValidVNode,
  pushWarningContext,
  popWarningContext
};
const ssrUtils = _ssrUtils;
const resolveFilter = null;
const compatUtils = null;
const DeprecationTypes = null;
/**
* @vue/runtime-dom v3.5.13
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/
let policy = void 0;
const tt$1 = typeof window !== "undefined" && window.trustedTypes;
if (tt$1) {
  try {
    policy = /* @__PURE__ */ tt$1.createPolicy("vue", {
      createHTML: /* @__PURE__ */ __name((val) => val, "createHTML")
    });
  } catch (e2) {
  }
}
const unsafeToTrustedHTML = policy ? (val) => policy.createHTML(val) : (val) => val;
const svgNS = "http://www.w3.org/2000/svg";
const mathmlNS = "http://www.w3.org/1998/Math/MathML";
const doc$2 = typeof document !== "undefined" ? document : null;
const templateContainer = doc$2 && /* @__PURE__ */ doc$2.createElement("template");
const nodeOps = {
  insert: /* @__PURE__ */ __name((child, parent, anchor) => {
    parent.insertBefore(child, anchor || null);
  }, "insert"),
  remove: /* @__PURE__ */ __name((child) => {
    const parent = child.parentNode;
    if (parent) {
      parent.removeChild(child);
    }
  }, "remove"),
  createElement: /* @__PURE__ */ __name((tag, namespace, is, props) => {
    const el = namespace === "svg" ? doc$2.createElementNS(svgNS, tag) : namespace === "mathml" ? doc$2.createElementNS(mathmlNS, tag) : is ? doc$2.createElement(tag, { is }) : doc$2.createElement(tag);
    if (tag === "select" && props && props.multiple != null) {
      el.setAttribute("multiple", props.multiple);
    }
    return el;
  }, "createElement"),
  createText: /* @__PURE__ */ __name((text2) => doc$2.createTextNode(text2), "createText"),
  createComment: /* @__PURE__ */ __name((text2) => doc$2.createComment(text2), "createComment"),
  setText: /* @__PURE__ */ __name((node3, text2) => {
    node3.nodeValue = text2;
  }, "setText"),
  setElementText: /* @__PURE__ */ __name((el, text2) => {
    el.textContent = text2;
  }, "setElementText"),
  parentNode: /* @__PURE__ */ __name((node3) => node3.parentNode, "parentNode"),
  nextSibling: /* @__PURE__ */ __name((node3) => node3.nextSibling, "nextSibling"),
  querySelector: /* @__PURE__ */ __name((selector) => doc$2.querySelector(selector), "querySelector"),
  setScopeId(el, id4) {
    el.setAttribute(id4, "");
  },
  // __UNSAFE__
  // Reason: innerHTML.
  // Static content here can only come from compiled templates.
  // As long as the user only uses trusted templates, this is safe.
  insertStaticContent(content3, parent, anchor, namespace, start2, end) {
    const before = anchor ? anchor.previousSibling : parent.lastChild;
    if (start2 && (start2 === end || start2.nextSibling)) {
      while (true) {
        parent.insertBefore(start2.cloneNode(true), anchor);
        if (start2 === end || !(start2 = start2.nextSibling)) break;
      }
    } else {
      templateContainer.innerHTML = unsafeToTrustedHTML(
        namespace === "svg" ? `<svg>${content3}</svg>` : namespace === "mathml" ? `<math>${content3}</math>` : content3
      );
      const template = templateContainer.content;
      if (namespace === "svg" || namespace === "mathml") {
        const wrapper = template.firstChild;
        while (wrapper.firstChild) {
          template.appendChild(wrapper.firstChild);
        }
        template.removeChild(wrapper);
      }
      parent.insertBefore(template, anchor);
    }
    return [
      // first
      before ? before.nextSibling : parent.firstChild,
      // last
      anchor ? anchor.previousSibling : parent.lastChild
    ];
  }
};
const TRANSITION = "transition";
const ANIMATION = "animation";
const vtcKey = Symbol("_vtc");
const DOMTransitionPropsValidators = {
  name: String,
  type: String,
  css: {
    type: Boolean,
    default: true
  },
  duration: [String, Number, Object],
  enterFromClass: String,
  enterActiveClass: String,
  enterToClass: String,
  appearFromClass: String,
  appearActiveClass: String,
  appearToClass: String,
  leaveFromClass: String,
  leaveActiveClass: String,
  leaveToClass: String
};
const TransitionPropsValidators = /* @__PURE__ */ extend$1(
  {},
  BaseTransitionPropsValidators,
  DOMTransitionPropsValidators
);
const decorate$1 = /* @__PURE__ */ __name((t2) => {
  t2.displayName = "Transition";
  t2.props = TransitionPropsValidators;
  return t2;
}, "decorate$1");
const Transition = /* @__PURE__ */ decorate$1(
  (props, { slots }) => h(BaseTransition, resolveTransitionProps(props), slots)
);
const callHook = /* @__PURE__ */ __name((hook, args = []) => {
  if (isArray$b(hook)) {
    hook.forEach((h2) => h2(...args));
  } else if (hook) {
    hook(...args);
  }
}, "callHook");
const hasExplicitCallback = /* @__PURE__ */ __name((hook) => {
  return hook ? isArray$b(hook) ? hook.some((h2) => h2.length > 1) : hook.length > 1 : false;
}, "hasExplicitCallback");
function resolveTransitionProps(rawProps) {
  const baseProps = {};
  for (const key in rawProps) {
    if (!(key in DOMTransitionPropsValidators)) {
      baseProps[key] = rawProps[key];
    }
  }
  if (rawProps.css === false) {
    return baseProps;
  }
  const {
    name: name2 = "v",
    type,
    duration,
    enterFromClass = `${name2}-enter-from`,
    enterActiveClass = `${name2}-enter-active`,
    enterToClass = `${name2}-enter-to`,
    appearFromClass = enterFromClass,
    appearActiveClass = enterActiveClass,
    appearToClass = enterToClass,
    leaveFromClass = `${name2}-leave-from`,
    leaveActiveClass = `${name2}-leave-active`,
    leaveToClass = `${name2}-leave-to`
  } = rawProps;
  const durations = normalizeDuration(duration);
  const enterDuration = durations && durations[0];
  const leaveDuration = durations && durations[1];
  const {
    onBeforeEnter: onBeforeEnter2,
    onEnter: onEnter7,
    onEnterCancelled,
    onLeave: onLeave5,
    onLeaveCancelled,
    onBeforeAppear = onBeforeEnter2,
    onAppear = onEnter7,
    onAppearCancelled = onEnterCancelled
  } = baseProps;
  const finishEnter = /* @__PURE__ */ __name((el, isAppear, done, isCancelled) => {
    el._enterCancelled = isCancelled;
    removeTransitionClass(el, isAppear ? appearToClass : enterToClass);
    removeTransitionClass(el, isAppear ? appearActiveClass : enterActiveClass);
    done && done();
  }, "finishEnter");
  const finishLeave = /* @__PURE__ */ __name((el, done) => {
    el._isLeaving = false;
    removeTransitionClass(el, leaveFromClass);
    removeTransitionClass(el, leaveToClass);
    removeTransitionClass(el, leaveActiveClass);
    done && done();
  }, "finishLeave");
  const makeEnterHook = /* @__PURE__ */ __name((isAppear) => {
    return (el, done) => {
      const hook = isAppear ? onAppear : onEnter7;
      const resolve2 = /* @__PURE__ */ __name(() => finishEnter(el, isAppear, done), "resolve");
      callHook(hook, [el, resolve2]);
      nextFrame(() => {
        removeTransitionClass(el, isAppear ? appearFromClass : enterFromClass);
        addTransitionClass(el, isAppear ? appearToClass : enterToClass);
        if (!hasExplicitCallback(hook)) {
          whenTransitionEnds(el, type, enterDuration, resolve2);
        }
      });
    };
  }, "makeEnterHook");
  return extend$1(baseProps, {
    onBeforeEnter(el) {
      callHook(onBeforeEnter2, [el]);
      addTransitionClass(el, enterFromClass);
      addTransitionClass(el, enterActiveClass);
    },
    onBeforeAppear(el) {
      callHook(onBeforeAppear, [el]);
      addTransitionClass(el, appearFromClass);
      addTransitionClass(el, appearActiveClass);
    },
    onEnter: makeEnterHook(false),
    onAppear: makeEnterHook(true),
    onLeave(el, done) {
      el._isLeaving = true;
      const resolve2 = /* @__PURE__ */ __name(() => finishLeave(el, done), "resolve");
      addTransitionClass(el, leaveFromClass);
      if (!el._enterCancelled) {
        forceReflow();
        addTransitionClass(el, leaveActiveClass);
      } else {
        addTransitionClass(el, leaveActiveClass);
        forceReflow();
      }
      nextFrame(() => {
        if (!el._isLeaving) {
          return;
        }
        removeTransitionClass(el, leaveFromClass);
        addTransitionClass(el, leaveToClass);
        if (!hasExplicitCallback(onLeave5)) {
          whenTransitionEnds(el, type, leaveDuration, resolve2);
        }
      });
      callHook(onLeave5, [el, resolve2]);
    },
    onEnterCancelled(el) {
      finishEnter(el, false, void 0, true);
      callHook(onEnterCancelled, [el]);
    },
    onAppearCancelled(el) {
      finishEnter(el, true, void 0, true);
      callHook(onAppearCancelled, [el]);
    },
    onLeaveCancelled(el) {
      finishLeave(el);
      callHook(onLeaveCancelled, [el]);
    }
  });
}
__name(resolveTransitionProps, "resolveTransitionProps");
function normalizeDuration(duration) {
  if (duration == null) {
    return null;
  } else if (isObject$f(duration)) {
    return [NumberOf(duration.enter), NumberOf(duration.leave)];
  } else {
    const n2 = NumberOf(duration);
    return [n2, n2];
  }
}
__name(normalizeDuration, "normalizeDuration");
function NumberOf(val) {
  const res = toNumber(val);
  if (false) {
    assertNumber(res, "<transition> explicit duration");
  }
  return res;
}
__name(NumberOf, "NumberOf");
function addTransitionClass(el, cls) {
  cls.split(/\s+/).forEach((c2) => c2 && el.classList.add(c2));
  (el[vtcKey] || (el[vtcKey] = /* @__PURE__ */ new Set())).add(cls);
}
__name(addTransitionClass, "addTransitionClass");
function removeTransitionClass(el, cls) {
  cls.split(/\s+/).forEach((c2) => c2 && el.classList.remove(c2));
  const _vtc = el[vtcKey];
  if (_vtc) {
    _vtc.delete(cls);
    if (!_vtc.size) {
      el[vtcKey] = void 0;
    }
  }
}
__name(removeTransitionClass, "removeTransitionClass");
function nextFrame(cb) {
  requestAnimationFrame(() => {
    requestAnimationFrame(cb);
  });
}
__name(nextFrame, "nextFrame");
let endId = 0;
function whenTransitionEnds(el, expectedType, explicitTimeout, resolve2) {
  const id4 = el._endId = ++endId;
  const resolveIfNotStale = /* @__PURE__ */ __name(() => {
    if (id4 === el._endId) {
      resolve2();
    }
  }, "resolveIfNotStale");
  if (explicitTimeout != null) {
    return setTimeout(resolveIfNotStale, explicitTimeout);
  }
  const { type, timeout, propCount } = getTransitionInfo(el, expectedType);
  if (!type) {
    return resolve2();
  }
  const endEvent = type + "end";
  let ended = 0;
  const end = /* @__PURE__ */ __name(() => {
    el.removeEventListener(endEvent, onEnd);
    resolveIfNotStale();
  }, "end");
  const onEnd = /* @__PURE__ */ __name((e2) => {
    if (e2.target === el && ++ended >= propCount) {
      end();
    }
  }, "onEnd");
  setTimeout(() => {
    if (ended < propCount) {
      end();
    }
  }, timeout + 1);
  el.addEventListener(endEvent, onEnd);
}
__name(whenTransitionEnds, "whenTransitionEnds");
function getTransitionInfo(el, expectedType) {
  const styles = window.getComputedStyle(el);
  const getStyleProperties = /* @__PURE__ */ __name((key) => (styles[key] || "").split(", "), "getStyleProperties");
  const transitionDelays = getStyleProperties(`${TRANSITION}Delay`);
  const transitionDurations = getStyleProperties(`${TRANSITION}Duration`);
  const transitionTimeout = getTimeout(transitionDelays, transitionDurations);
  const animationDelays = getStyleProperties(`${ANIMATION}Delay`);
  const animationDurations = getStyleProperties(`${ANIMATION}Duration`);
  const animationTimeout = getTimeout(animationDelays, animationDurations);
  let type = null;
  let timeout = 0;
  let propCount = 0;
  if (expectedType === TRANSITION) {
    if (transitionTimeout > 0) {
      type = TRANSITION;
      timeout = transitionTimeout;
      propCount = transitionDurations.length;
    }
  } else if (expectedType === ANIMATION) {
    if (animationTimeout > 0) {
      type = ANIMATION;
      timeout = animationTimeout;
      propCount = animationDurations.length;
    }
  } else {
    timeout = Math.max(transitionTimeout, animationTimeout);
    type = timeout > 0 ? transitionTimeout > animationTimeout ? TRANSITION : ANIMATION : null;
    propCount = type ? type === TRANSITION ? transitionDurations.length : animationDurations.length : 0;
  }
  const hasTransform = type === TRANSITION && /\b(transform|all)(,|$)/.test(
    getStyleProperties(`${TRANSITION}Property`).toString()
  );
  return {
    type,
    timeout,
    propCount,
    hasTransform
  };
}
__name(getTransitionInfo, "getTransitionInfo");
function getTimeout(delays, durations) {
  while (delays.length < durations.length) {
    delays = delays.concat(delays);
  }
  return Math.max(...durations.map((d2, i2) => toMs(d2) + toMs(delays[i2])));
}
__name(getTimeout, "getTimeout");
function toMs(s2) {
  if (s2 === "auto") return 0;
  return Number(s2.slice(0, -1).replace(",", ".")) * 1e3;
}
__name(toMs, "toMs");
function forceReflow() {
  return document.body.offsetHeight;
}
__name(forceReflow, "forceReflow");
function patchClass(el, value3, isSVG) {
  const transitionClasses = el[vtcKey];
  if (transitionClasses) {
    value3 = (value3 ? [value3, ...transitionClasses] : [...transitionClasses]).join(" ");
  }
  if (value3 == null) {
    el.removeAttribute("class");
  } else if (isSVG) {
    el.setAttribute("class", value3);
  } else {
    el.className = value3;
  }
}
__name(patchClass, "patchClass");
const vShowOriginalDisplay = Symbol("_vod");
const vShowHidden = Symbol("_vsh");
const vShow = {
  beforeMount(el, { value: value3 }, { transition }) {
    el[vShowOriginalDisplay] = el.style.display === "none" ? "" : el.style.display;
    if (transition && value3) {
      transition.beforeEnter(el);
    } else {
      setDisplay(el, value3);
    }
  },
  mounted(el, { value: value3 }, { transition }) {
    if (transition && value3) {
      transition.enter(el);
    }
  },
  updated(el, { value: value3, oldValue }, { transition }) {
    if (!value3 === !oldValue) return;
    if (transition) {
      if (value3) {
        transition.beforeEnter(el);
        setDisplay(el, true);
        transition.enter(el);
      } else {
        transition.leave(el, () => {
          setDisplay(el, false);
        });
      }
    } else {
      setDisplay(el, value3);
    }
  },
  beforeUnmount(el, { value: value3 }) {
    setDisplay(el, value3);
  }
};
if (false) {
  vShow.name = "show";
}
function setDisplay(el, value3) {
  el.style.display = value3 ? el[vShowOriginalDisplay] : "none";
  el[vShowHidden] = !value3;
}
__name(setDisplay, "setDisplay");
function initVShowForSSR() {
  vShow.getSSRProps = ({ value: value3 }) => {
    if (!value3) {
      return { style: { display: "none" } };
    }
  };
}
__name(initVShowForSSR, "initVShowForSSR");
const CSS_VAR_TEXT = Symbol(false ? "CSS_VAR_TEXT" : "");
function useCssVars(getter) {
  const instance = getCurrentInstance();
  if (!instance) {
    return;
  }
  const updateTeleports = instance.ut = (vars = getter(instance.proxy)) => {
    Array.from(
      document.querySelectorAll(`[data-v-owner="${instance.uid}"]`)
    ).forEach((node3) => setVarsOnNode(node3, vars));
  };
  if (false) {
    instance.getCssVars = () => getter(instance.proxy);
  }
  const setVars = /* @__PURE__ */ __name(() => {
    const vars = getter(instance.proxy);
    if (instance.ce) {
      setVarsOnNode(instance.ce, vars);
    } else {
      setVarsOnVNode(instance.subTree, vars);
    }
    updateTeleports(vars);
  }, "setVars");
  onBeforeUpdate(() => {
    queuePostFlushCb(setVars);
  });
  onMounted(() => {
    watch(setVars, NOOP, { flush: "post" });
    const ob = new MutationObserver(setVars);
    ob.observe(instance.subTree.el.parentNode, { childList: true });
    onUnmounted(() => ob.disconnect());
  });
}
__name(useCssVars, "useCssVars");
function setVarsOnVNode(vnode, vars) {
  if (vnode.shapeFlag & 128) {
    const suspense = vnode.suspense;
    vnode = suspense.activeBranch;
    if (suspense.pendingBranch && !suspense.isHydrating) {
      suspense.effects.push(() => {
        setVarsOnVNode(suspense.activeBranch, vars);
      });
    }
  }
  while (vnode.component) {
    vnode = vnode.component.subTree;
  }
  if (vnode.shapeFlag & 1 && vnode.el) {
    setVarsOnNode(vnode.el, vars);
  } else if (vnode.type === Fragment$1) {
    vnode.children.forEach((c2) => setVarsOnVNode(c2, vars));
  } else if (vnode.type === Static) {
    let { el, anchor } = vnode;
    while (el) {
      setVarsOnNode(el, vars);
      if (el === anchor) break;
      el = el.nextSibling;
    }
  }
}
__name(setVarsOnVNode, "setVarsOnVNode");
function setVarsOnNode(el, vars) {
  if (el.nodeType === 1) {
    const style2 = el.style;
    let cssText = "";
    for (const key in vars) {
      style2.setProperty(`--${key}`, vars[key]);
      cssText += `--${key}: ${vars[key]};`;
    }
    style2[CSS_VAR_TEXT] = cssText;
  }
}
__name(setVarsOnNode, "setVarsOnNode");
const displayRE = /(^|;)\s*display\s*:/;
function patchStyle(el, prev2, next2) {
  const style2 = el.style;
  const isCssString = isString$9(next2);
  let hasControlledDisplay = false;
  if (next2 && !isCssString) {
    if (prev2) {
      if (!isString$9(prev2)) {
        for (const key in prev2) {
          if (next2[key] == null) {
            setStyle(style2, key, "");
          }
        }
      } else {
        for (const prevStyle of prev2.split(";")) {
          const key = prevStyle.slice(0, prevStyle.indexOf(":")).trim();
          if (next2[key] == null) {
            setStyle(style2, key, "");
          }
        }
      }
    }
    for (const key in next2) {
      if (key === "display") {
        hasControlledDisplay = true;
      }
      setStyle(style2, key, next2[key]);
    }
  } else {
    if (isCssString) {
      if (prev2 !== next2) {
        const cssVarText = style2[CSS_VAR_TEXT];
        if (cssVarText) {
          next2 += ";" + cssVarText;
        }
        style2.cssText = next2;
        hasControlledDisplay = displayRE.test(next2);
      }
    } else if (prev2) {
      el.removeAttribute("style");
    }
  }
  if (vShowOriginalDisplay in el) {
    el[vShowOriginalDisplay] = hasControlledDisplay ? style2.display : "";
    if (el[vShowHidden]) {
      style2.display = "none";
    }
  }
}
__name(patchStyle, "patchStyle");
const semicolonRE = /[^\\];\s*$/;
const importantRE = /\s*!important$/;
function setStyle(style2, name2, val) {
  if (isArray$b(val)) {
    val.forEach((v2) => setStyle(style2, name2, v2));
  } else {
    if (val == null) val = "";
    if (false) {
      if (semicolonRE.test(val)) {
        warn$3(
          `Unexpected semicolon at the end of '${name2}' style value: '${val}'`
        );
      }
    }
    if (name2.startsWith("--")) {
      style2.setProperty(name2, val);
    } else {
      const prefixed = autoPrefix(style2, name2);
      if (importantRE.test(val)) {
        style2.setProperty(
          hyphenate$1(prefixed),
          val.replace(importantRE, ""),
          "important"
        );
      } else {
        style2[prefixed] = val;
      }
    }
  }
}
__name(setStyle, "setStyle");
const prefixes = ["Webkit", "Moz", "ms"];
const prefixCache = {};
function autoPrefix(style2, rawName) {
  const cached = prefixCache[rawName];
  if (cached) {
    return cached;
  }
  let name2 = camelize$1(rawName);
  if (name2 !== "filter" && name2 in style2) {
    return prefixCache[rawName] = name2;
  }
  name2 = capitalize$1(name2);
  for (let i2 = 0; i2 < prefixes.length; i2++) {
    const prefixed = prefixes[i2] + name2;
    if (prefixed in style2) {
      return prefixCache[rawName] = prefixed;
    }
  }
  return rawName;
}
__name(autoPrefix, "autoPrefix");
const xlinkNS = "http://www.w3.org/1999/xlink";
function patchAttr(el, key, value3, isSVG, instance, isBoolean2 = isSpecialBooleanAttr(key)) {
  if (isSVG && key.startsWith("xlink:")) {
    if (value3 == null) {
      el.removeAttributeNS(xlinkNS, key.slice(6, key.length));
    } else {
      el.setAttributeNS(xlinkNS, key, value3);
    }
  } else {
    if (value3 == null || isBoolean2 && !includeBooleanAttr(value3)) {
      el.removeAttribute(key);
    } else {
      el.setAttribute(
        key,
        isBoolean2 ? "" : isSymbol$1(value3) ? String(value3) : value3
      );
    }
  }
}
__name(patchAttr, "patchAttr");
function patchDOMProp(el, key, value3, parentComponent, attrName) {
  if (key === "innerHTML" || key === "textContent") {
    if (value3 != null) {
      el[key] = key === "innerHTML" ? unsafeToTrustedHTML(value3) : value3;
    }
    return;
  }
  const tag = el.tagName;
  if (key === "value" && tag !== "PROGRESS" && // custom elements may use _value internally
  !tag.includes("-")) {
    const oldValue = tag === "OPTION" ? el.getAttribute("value") || "" : el.value;
    const newValue2 = value3 == null ? (
      // #11647: value should be set as empty string for null and undefined,
      // but <input type="checkbox"> should be set as 'on'.
      el.type === "checkbox" ? "on" : ""
    ) : String(value3);
    if (oldValue !== newValue2 || !("_value" in el)) {
      el.value = newValue2;
    }
    if (value3 == null) {
      el.removeAttribute(key);
    }
    el._value = value3;
    return;
  }
  let needRemove = false;
  if (value3 === "" || value3 == null) {
    const type = typeof el[key];
    if (type === "boolean") {
      value3 = includeBooleanAttr(value3);
    } else if (value3 == null && type === "string") {
      value3 = "";
      needRemove = true;
    } else if (type === "number") {
      value3 = 0;
      needRemove = true;
    }
  }
  try {
    el[key] = value3;
  } catch (e2) {
    if (false) {
      warn$3(
        `Failed setting prop "${key}" on <${tag.toLowerCase()}>: value ${value3} is invalid.`,
        e2
      );
    }
  }
  needRemove && el.removeAttribute(attrName || key);
}
__name(patchDOMProp, "patchDOMProp");
function addEventListener$1(el, event, handler14, options5) {
  el.addEventListener(event, handler14, options5);
}
__name(addEventListener$1, "addEventListener$1");
function removeEventListener$1(el, event, handler14, options5) {
  el.removeEventListener(event, handler14, options5);
}
__name(removeEventListener$1, "removeEventListener$1");
const veiKey = Symbol("_vei");
function patchEvent(el, rawName, prevValue, nextValue, instance = null) {
  const invokers = el[veiKey] || (el[veiKey] = {});
  const existingInvoker = invokers[rawName];
  if (nextValue && existingInvoker) {
    existingInvoker.value = false ? sanitizeEventValue(nextValue, rawName) : nextValue;
  } else {
    const [name2, options5] = parseName(rawName);
    if (nextValue) {
      const invoker = invokers[rawName] = createInvoker(
        false ? sanitizeEventValue(nextValue, rawName) : nextValue,
        instance
      );
      addEventListener$1(el, name2, invoker, options5);
    } else if (existingInvoker) {
      removeEventListener$1(el, name2, existingInvoker, options5);
      invokers[rawName] = void 0;
    }
  }
}
__name(patchEvent, "patchEvent");
const optionsModifierRE = /(?:Once|Passive|Capture)$/;
function parseName(name2) {
  let options5;
  if (optionsModifierRE.test(name2)) {
    options5 = {};
    let m2;
    while (m2 = name2.match(optionsModifierRE)) {
      name2 = name2.slice(0, name2.length - m2[0].length);
      options5[m2[0].toLowerCase()] = true;
    }
  }
  const event = name2[2] === ":" ? name2.slice(3) : hyphenate$1(name2.slice(2));
  return [event, options5];
}
__name(parseName, "parseName");
let cachedNow = 0;
const p = /* @__PURE__ */ Promise.resolve();
const getNow = /* @__PURE__ */ __name(() => cachedNow || (p.then(() => cachedNow = 0), cachedNow = Date.now()), "getNow");
function createInvoker(initialValue, instance) {
  const invoker = /* @__PURE__ */ __name((e2) => {
    if (!e2._vts) {
      e2._vts = Date.now();
    } else if (e2._vts <= invoker.attached) {
      return;
    }
    callWithAsyncErrorHandling(
      patchStopImmediatePropagation(e2, invoker.value),
      instance,
      5,
      [e2]
    );
  }, "invoker");
  invoker.value = initialValue;
  invoker.attached = getNow();
  return invoker;
}
__name(createInvoker, "createInvoker");
function sanitizeEventValue(value3, propName) {
  if (isFunction$c(value3) || isArray$b(value3)) {
    return value3;
  }
  warn$3(
    `Wrong type passed as event handler to ${propName} - did you forget @ or : in front of your prop?
Expected function or array of functions, received type ${typeof value3}.`
  );
  return NOOP;
}
__name(sanitizeEventValue, "sanitizeEventValue");
function patchStopImmediatePropagation(e2, value3) {
  if (isArray$b(value3)) {
    const originalStop = e2.stopImmediatePropagation;
    e2.stopImmediatePropagation = () => {
      originalStop.call(e2);
      e2._stopped = true;
    };
    return value3.map(
      (fn) => (e22) => !e22._stopped && fn && fn(e22)
    );
  } else {
    return value3;
  }
}
__name(patchStopImmediatePropagation, "patchStopImmediatePropagation");
const isNativeOn = /* @__PURE__ */ __name((key) => key.charCodeAt(0) === 111 && key.charCodeAt(1) === 110 && // lowercase letter
key.charCodeAt(2) > 96 && key.charCodeAt(2) < 123, "isNativeOn");
const patchProp = /* @__PURE__ */ __name((el, key, prevValue, nextValue, namespace, parentComponent) => {
  const isSVG = namespace === "svg";
  if (key === "class") {
    patchClass(el, nextValue, isSVG);
  } else if (key === "style") {
    patchStyle(el, prevValue, nextValue);
  } else if (isOn(key)) {
    if (!isModelListener(key)) {
      patchEvent(el, key, prevValue, nextValue, parentComponent);
    }
  } else if (key[0] === "." ? (key = key.slice(1), true) : key[0] === "^" ? (key = key.slice(1), false) : shouldSetAsProp(el, key, nextValue, isSVG)) {
    patchDOMProp(el, key, nextValue);
    if (!el.tagName.includes("-") && (key === "value" || key === "checked" || key === "selected")) {
      patchAttr(el, key, nextValue, isSVG, parentComponent, key !== "value");
    }
  } else if (
    // #11081 force set props for possible async custom element
    el._isVueCE && (/[A-Z]/.test(key) || !isString$9(nextValue))
  ) {
    patchDOMProp(el, camelize$1(key), nextValue, parentComponent, key);
  } else {
    if (key === "true-value") {
      el._trueValue = nextValue;
    } else if (key === "false-value") {
      el._falseValue = nextValue;
    }
    patchAttr(el, key, nextValue, isSVG);
  }
}, "patchProp");
function shouldSetAsProp(el, key, value3, isSVG) {
  if (isSVG) {
    if (key === "innerHTML" || key === "textContent") {
      return true;
    }
    if (key in el && isNativeOn(key) && isFunction$c(value3)) {
      return true;
    }
    return false;
  }
  if (key === "spellcheck" || key === "draggable" || key === "translate") {
    return false;
  }
  if (key === "form") {
    return false;
  }
  if (key === "list" && el.tagName === "INPUT") {
    return false;
  }
  if (key === "type" && el.tagName === "TEXTAREA") {
    return false;
  }
  if (key === "width" || key === "height") {
    const tag = el.tagName;
    if (tag === "IMG" || tag === "VIDEO" || tag === "CANVAS" || tag === "SOURCE") {
      return false;
    }
  }
  if (isNativeOn(key) && isString$9(value3)) {
    return false;
  }
  return key in el;
}
__name(shouldSetAsProp, "shouldSetAsProp");
const REMOVAL = {};
/*! #__NO_SIDE_EFFECTS__ */
// @__NO_SIDE_EFFECTS__
function defineCustomElement(options5, extraOptions, _createApp) {
  const Comp = /* @__PURE__ */ defineComponent(options5, extraOptions);
  if (isPlainObject$4(Comp)) extend$1(Comp, extraOptions);
  class VueCustomElement extends VueElement {
    static {
      __name(this, "VueCustomElement");
    }
    constructor(initialProps) {
      super(Comp, initialProps, _createApp);
    }
  }
  VueCustomElement.def = Comp;
  return VueCustomElement;
}
__name(defineCustomElement, "defineCustomElement");
/*! #__NO_SIDE_EFFECTS__ */
const defineSSRCustomElement = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ (options5, extraOptions) => {
  return /* @__PURE__ */ defineCustomElement(options5, extraOptions, createSSRApp);
}, "defineSSRCustomElement");
const BaseClass = typeof HTMLElement !== "undefined" ? HTMLElement : class {
};
class VueElement extends BaseClass {
  static {
    __name(this, "VueElement");
  }
  constructor(_def, _props = {}, _createApp = createApp) {
    super();
    this._def = _def;
    this._props = _props;
    this._createApp = _createApp;
    this._isVueCE = true;
    this._instance = null;
    this._app = null;
    this._nonce = this._def.nonce;
    this._connected = false;
    this._resolved = false;
    this._numberProps = null;
    this._styleChildren = /* @__PURE__ */ new WeakSet();
    this._ob = null;
    if (this.shadowRoot && _createApp !== createApp) {
      this._root = this.shadowRoot;
    } else {
      if (false) {
        warn$3(
          `Custom element has pre-rendered declarative shadow root but is not defined as hydratable. Use \`defineSSRCustomElement\`.`
        );
      }
      if (_def.shadowRoot !== false) {
        this.attachShadow({ mode: "open" });
        this._root = this.shadowRoot;
      } else {
        this._root = this;
      }
    }
    if (!this._def.__asyncLoader) {
      this._resolveProps(this._def);
    }
  }
  connectedCallback() {
    if (!this.isConnected) return;
    if (!this.shadowRoot) {
      this._parseSlots();
    }
    this._connected = true;
    let parent = this;
    while (parent = parent && (parent.parentNode || parent.host)) {
      if (parent instanceof VueElement) {
        this._parent = parent;
        break;
      }
    }
    if (!this._instance) {
      if (this._resolved) {
        this._setParent();
        this._update();
      } else {
        if (parent && parent._pendingResolve) {
          this._pendingResolve = parent._pendingResolve.then(() => {
            this._pendingResolve = void 0;
            this._resolveDef();
          });
        } else {
          this._resolveDef();
        }
      }
    }
  }
  _setParent(parent = this._parent) {
    if (parent) {
      this._instance.parent = parent._instance;
      this._instance.provides = parent._instance.provides;
    }
  }
  disconnectedCallback() {
    this._connected = false;
    nextTick(() => {
      if (!this._connected) {
        if (this._ob) {
          this._ob.disconnect();
          this._ob = null;
        }
        this._app && this._app.unmount();
        if (this._instance) this._instance.ce = void 0;
        this._app = this._instance = null;
      }
    });
  }
  /**
   * resolve inner component definition (handle possible async component)
   */
  _resolveDef() {
    if (this._pendingResolve) {
      return;
    }
    for (let i2 = 0; i2 < this.attributes.length; i2++) {
      this._setAttr(this.attributes[i2].name);
    }
    this._ob = new MutationObserver((mutations) => {
      for (const m2 of mutations) {
        this._setAttr(m2.attributeName);
      }
    });
    this._ob.observe(this, { attributes: true });
    const resolve2 = /* @__PURE__ */ __name((def2, isAsync2 = false) => {
      this._resolved = true;
      this._pendingResolve = void 0;
      const { props, styles } = def2;
      let numberProps;
      if (props && !isArray$b(props)) {
        for (const key in props) {
          const opt = props[key];
          if (opt === Number || opt && opt.type === Number) {
            if (key in this._props) {
              this._props[key] = toNumber(this._props[key]);
            }
            (numberProps || (numberProps = /* @__PURE__ */ Object.create(null)))[camelize$1(key)] = true;
          }
        }
      }
      this._numberProps = numberProps;
      if (isAsync2) {
        this._resolveProps(def2);
      }
      if (this.shadowRoot) {
        this._applyStyles(styles);
      } else if (false) {
        warn$3(
          "Custom element style injection is not supported when using shadowRoot: false"
        );
      }
      this._mount(def2);
    }, "resolve");
    const asyncDef = this._def.__asyncLoader;
    if (asyncDef) {
      this._pendingResolve = asyncDef().then(
        (def2) => resolve2(this._def = def2, true)
      );
    } else {
      resolve2(this._def);
    }
  }
  _mount(def2) {
    if (false) {
      def2.name = "VueElement";
    }
    this._app = this._createApp(def2);
    if (def2.configureApp) {
      def2.configureApp(this._app);
    }
    this._app._ceVNode = this._createVNode();
    this._app.mount(this._root);
    const exposed = this._instance && this._instance.exposed;
    if (!exposed) return;
    for (const key in exposed) {
      if (!hasOwn$3(this, key)) {
        Object.defineProperty(this, key, {
          // unwrap ref to be consistent with public instance behavior
          get: /* @__PURE__ */ __name(() => unref(exposed[key]), "get")
        });
      } else if (false) {
        warn$3(`Exposed property "${key}" already exists on custom element.`);
      }
    }
  }
  _resolveProps(def2) {
    const { props } = def2;
    const declaredPropKeys = isArray$b(props) ? props : Object.keys(props || {});
    for (const key of Object.keys(this)) {
      if (key[0] !== "_" && declaredPropKeys.includes(key)) {
        this._setProp(key, this[key]);
      }
    }
    for (const key of declaredPropKeys.map(camelize$1)) {
      Object.defineProperty(this, key, {
        get() {
          return this._getProp(key);
        },
        set(val) {
          this._setProp(key, val, true, true);
        }
      });
    }
  }
  _setAttr(key) {
    if (key.startsWith("data-v-")) return;
    const has2 = this.hasAttribute(key);
    let value3 = has2 ? this.getAttribute(key) : REMOVAL;
    const camelKey = camelize$1(key);
    if (has2 && this._numberProps && this._numberProps[camelKey]) {
      value3 = toNumber(value3);
    }
    this._setProp(camelKey, value3, false, true);
  }
  /**
   * @internal
   */
  _getProp(key) {
    return this._props[key];
  }
  /**
   * @internal
   */
  _setProp(key, val, shouldReflect = true, shouldUpdate = false) {
    if (val !== this._props[key]) {
      if (val === REMOVAL) {
        delete this._props[key];
      } else {
        this._props[key] = val;
        if (key === "key" && this._app) {
          this._app._ceVNode.key = val;
        }
      }
      if (shouldUpdate && this._instance) {
        this._update();
      }
      if (shouldReflect) {
        const ob = this._ob;
        ob && ob.disconnect();
        if (val === true) {
          this.setAttribute(hyphenate$1(key), "");
        } else if (typeof val === "string" || typeof val === "number") {
          this.setAttribute(hyphenate$1(key), val + "");
        } else if (!val) {
          this.removeAttribute(hyphenate$1(key));
        }
        ob && ob.observe(this, { attributes: true });
      }
    }
  }
  _update() {
    render$15(this._createVNode(), this._root);
  }
  _createVNode() {
    const baseProps = {};
    if (!this.shadowRoot) {
      baseProps.onVnodeMounted = baseProps.onVnodeUpdated = this._renderSlots.bind(this);
    }
    const vnode = createVNode(this._def, extend$1(baseProps, this._props));
    if (!this._instance) {
      vnode.ce = (instance) => {
        this._instance = instance;
        instance.ce = this;
        instance.isCE = true;
        if (false) {
          instance.ceReload = (newStyles) => {
            if (this._styles) {
              this._styles.forEach((s2) => this._root.removeChild(s2));
              this._styles.length = 0;
            }
            this._applyStyles(newStyles);
            this._instance = null;
            this._update();
          };
        }
        const dispatch = /* @__PURE__ */ __name((event, args) => {
          this.dispatchEvent(
            new CustomEvent(
              event,
              isPlainObject$4(args[0]) ? extend$1({ detail: args }, args[0]) : { detail: args }
            )
          );
        }, "dispatch");
        instance.emit = (event, ...args) => {
          dispatch(event, args);
          if (hyphenate$1(event) !== event) {
            dispatch(hyphenate$1(event), args);
          }
        };
        this._setParent();
      };
    }
    return vnode;
  }
  _applyStyles(styles, owner) {
    if (!styles) return;
    if (owner) {
      if (owner === this._def || this._styleChildren.has(owner)) {
        return;
      }
      this._styleChildren.add(owner);
    }
    const nonce = this._nonce;
    for (let i2 = styles.length - 1; i2 >= 0; i2--) {
      const s2 = document.createElement("style");
      if (nonce) s2.setAttribute("nonce", nonce);
      s2.textContent = styles[i2];
      this.shadowRoot.prepend(s2);
      if (false) {
        if (owner) {
          if (owner.__hmrId) {
            if (!this._childStyles) this._childStyles = /* @__PURE__ */ new Map();
            let entry = this._childStyles.get(owner.__hmrId);
            if (!entry) {
              this._childStyles.set(owner.__hmrId, entry = []);
            }
            entry.push(s2);
          }
        } else {
          (this._styles || (this._styles = [])).push(s2);
        }
      }
    }
  }
  /**
   * Only called when shadowRoot is false
   */
  _parseSlots() {
    const slots = this._slots = {};
    let n2;
    while (n2 = this.firstChild) {
      const slotName = n2.nodeType === 1 && n2.getAttribute("slot") || "default";
      (slots[slotName] || (slots[slotName] = [])).push(n2);
      this.removeChild(n2);
    }
  }
  /**
   * Only called when shadowRoot is false
   */
  _renderSlots() {
    const outlets = (this._teleportTarget || this).querySelectorAll("slot");
    const scopeId = this._instance.type.__scopeId;
    for (let i2 = 0; i2 < outlets.length; i2++) {
      const o2 = outlets[i2];
      const slotName = o2.getAttribute("name") || "default";
      const content3 = this._slots[slotName];
      const parent = o2.parentNode;
      if (content3) {
        for (const n2 of content3) {
          if (scopeId && n2.nodeType === 1) {
            const id4 = scopeId + "-s";
            const walker = document.createTreeWalker(n2, 1);
            n2.setAttribute(id4, "");
            let child;
            while (child = walker.nextNode()) {
              child.setAttribute(id4, "");
            }
          }
          parent.insertBefore(n2, o2);
        }
      } else {
        while (o2.firstChild) parent.insertBefore(o2.firstChild, o2);
      }
      parent.removeChild(o2);
    }
  }
  /**
   * @internal
   */
  _injectChildStyle(comp) {
    this._applyStyles(comp.styles, comp);
  }
  /**
   * @internal
   */
  _removeChildStyle(comp) {
    if (false) {
      this._styleChildren.delete(comp);
      if (this._childStyles && comp.__hmrId) {
        const oldStyles = this._childStyles.get(comp.__hmrId);
        if (oldStyles) {
          oldStyles.forEach((s2) => this._root.removeChild(s2));
          oldStyles.length = 0;
        }
      }
    }
  }
}
function useHost(caller) {
  const instance = getCurrentInstance();
  const el = instance && instance.ce;
  if (el) {
    return el;
  } else if (false) {
    if (!instance) {
      warn$3(
        `${caller || "useHost"} called without an active component instance.`
      );
    } else {
      warn$3(
        `${caller || "useHost"} can only be used in components defined via defineCustomElement.`
      );
    }
  }
  return null;
}
__name(useHost, "useHost");
function useShadowRoot() {
  const el = false ? useHost("useShadowRoot") : useHost();
  return el && el.shadowRoot;
}
__name(useShadowRoot, "useShadowRoot");
function useCssModule(name2 = "$style") {
  {
    const instance = getCurrentInstance();
    if (!instance) {
      return EMPTY_OBJ;
    }
    const modules = instance.type.__cssModules;
    if (!modules) {
      return EMPTY_OBJ;
    }
    const mod = modules[name2];
    if (!mod) {
      return EMPTY_OBJ;
    }
    return mod;
  }
}
__name(useCssModule, "useCssModule");
const positionMap = /* @__PURE__ */ new WeakMap();
const newPositionMap = /* @__PURE__ */ new WeakMap();
const moveCbKey = Symbol("_moveCb");
const enterCbKey = Symbol("_enterCb");
const decorate = /* @__PURE__ */ __name((t2) => {
  delete t2.props.mode;
  return t2;
}, "decorate");
const TransitionGroupImpl = /* @__PURE__ */ decorate({
  name: "TransitionGroup",
  props: /* @__PURE__ */ extend$1({}, TransitionPropsValidators, {
    tag: String,
    moveClass: String
  }),
  setup(props, { slots }) {
    const instance = getCurrentInstance();
    const state = useTransitionState();
    let prevChildren;
    let children;
    onUpdated(() => {
      if (!prevChildren.length) {
        return;
      }
      const moveClass = props.moveClass || `${props.name || "v"}-move`;
      if (!hasCSSTransform(
        prevChildren[0].el,
        instance.vnode.el,
        moveClass
      )) {
        return;
      }
      prevChildren.forEach(callPendingCbs);
      prevChildren.forEach(recordPosition);
      const movedChildren = prevChildren.filter(applyTranslation);
      forceReflow();
      movedChildren.forEach((c2) => {
        const el = c2.el;
        const style2 = el.style;
        addTransitionClass(el, moveClass);
        style2.transform = style2.webkitTransform = style2.transitionDuration = "";
        const cb = el[moveCbKey] = (e2) => {
          if (e2 && e2.target !== el) {
            return;
          }
          if (!e2 || /transform$/.test(e2.propertyName)) {
            el.removeEventListener("transitionend", cb);
            el[moveCbKey] = null;
            removeTransitionClass(el, moveClass);
          }
        };
        el.addEventListener("transitionend", cb);
      });
    });
    return () => {
      const rawProps = toRaw(props);
      const cssTransitionProps = resolveTransitionProps(rawProps);
      let tag = rawProps.tag || Fragment$1;
      prevChildren = [];
      if (children) {
        for (let i2 = 0; i2 < children.length; i2++) {
          const child = children[i2];
          if (child.el && child.el instanceof Element) {
            prevChildren.push(child);
            setTransitionHooks(
              child,
              resolveTransitionHooks(
                child,
                cssTransitionProps,
                state,
                instance
              )
            );
            positionMap.set(
              child,
              child.el.getBoundingClientRect()
            );
          }
        }
      }
      children = slots.default ? getTransitionRawChildren(slots.default()) : [];
      for (let i2 = 0; i2 < children.length; i2++) {
        const child = children[i2];
        if (child.key != null) {
          setTransitionHooks(
            child,
            resolveTransitionHooks(child, cssTransitionProps, state, instance)
          );
        } else if (false) {
          warn$3(`<TransitionGroup> children must be keyed.`);
        }
      }
      return createVNode(tag, null, children);
    };
  }
});
const TransitionGroup = TransitionGroupImpl;
function callPendingCbs(c2) {
  const el = c2.el;
  if (el[moveCbKey]) {
    el[moveCbKey]();
  }
  if (el[enterCbKey]) {
    el[enterCbKey]();
  }
}
__name(callPendingCbs, "callPendingCbs");
function recordPosition(c2) {
  newPositionMap.set(c2, c2.el.getBoundingClientRect());
}
__name(recordPosition, "recordPosition");
function applyTranslation(c2) {
  const oldPos = positionMap.get(c2);
  const newPos = newPositionMap.get(c2);
  const dx = oldPos.left - newPos.left;
  const dy = oldPos.top - newPos.top;
  if (dx || dy) {
    const s2 = c2.el.style;
    s2.transform = s2.webkitTransform = `translate(${dx}px,${dy}px)`;
    s2.transitionDuration = "0s";
    return c2;
  }
}
__name(applyTranslation, "applyTranslation");
function hasCSSTransform(el, root34, moveClass) {
  const clone2 = el.cloneNode();
  const _vtc = el[vtcKey];
  if (_vtc) {
    _vtc.forEach((cls) => {
      cls.split(/\s+/).forEach((c2) => c2 && clone2.classList.remove(c2));
    });
  }
  moveClass.split(/\s+/).forEach((c2) => c2 && clone2.classList.add(c2));
  clone2.style.display = "none";
  const container = root34.nodeType === 1 ? root34 : root34.parentNode;
  container.appendChild(clone2);
  const { hasTransform } = getTransitionInfo(clone2);
  container.removeChild(clone2);
  return hasTransform;
}
__name(hasCSSTransform, "hasCSSTransform");
const getModelAssigner = /* @__PURE__ */ __name((vnode) => {
  const fn = vnode.props["onUpdate:modelValue"] || false;
  return isArray$b(fn) ? (value3) => invokeArrayFns(fn, value3) : fn;
}, "getModelAssigner");
function onCompositionStart(e2) {
  e2.target.composing = true;
}
__name(onCompositionStart, "onCompositionStart");
function onCompositionEnd(e2) {
  const target2 = e2.target;
  if (target2.composing) {
    target2.composing = false;
    target2.dispatchEvent(new Event("input"));
  }
}
__name(onCompositionEnd, "onCompositionEnd");
const assignKey = Symbol("_assign");
const vModelText = {
  created(el, { modifiers: { lazy, trim: trim2, number: number2 } }, vnode) {
    el[assignKey] = getModelAssigner(vnode);
    const castToNumber = number2 || vnode.props && vnode.props.type === "number";
    addEventListener$1(el, lazy ? "change" : "input", (e2) => {
      if (e2.target.composing) return;
      let domValue = el.value;
      if (trim2) {
        domValue = domValue.trim();
      }
      if (castToNumber) {
        domValue = looseToNumber(domValue);
      }
      el[assignKey](domValue);
    });
    if (trim2) {
      addEventListener$1(el, "change", () => {
        el.value = el.value.trim();
      });
    }
    if (!lazy) {
      addEventListener$1(el, "compositionstart", onCompositionStart);
      addEventListener$1(el, "compositionend", onCompositionEnd);
      addEventListener$1(el, "change", onCompositionEnd);
    }
  },
  // set value on mounted so it's after min/max for type="range"
  mounted(el, { value: value3 }) {
    el.value = value3 == null ? "" : value3;
  },
  beforeUpdate(el, { value: value3, oldValue, modifiers: { lazy, trim: trim2, number: number2 } }, vnode) {
    el[assignKey] = getModelAssigner(vnode);
    if (el.composing) return;
    const elValue = (number2 || el.type === "number") && !/^0\d/.test(el.value) ? looseToNumber(el.value) : el.value;
    const newValue2 = value3 == null ? "" : value3;
    if (elValue === newValue2) {
      return;
    }
    if (document.activeElement === el && el.type !== "range") {
      if (lazy && value3 === oldValue) {
        return;
      }
      if (trim2 && el.value.trim() === newValue2) {
        return;
      }
    }
    el.value = newValue2;
  }
};
const vModelCheckbox = {
  // #4096 array checkboxes need to be deep traversed
  deep: true,
  created(el, _2, vnode) {
    el[assignKey] = getModelAssigner(vnode);
    addEventListener$1(el, "change", () => {
      const modelValue3 = el._modelValue;
      const elementValue = getValue$3(el);
      const checked4 = el.checked;
      const assign2 = el[assignKey];
      if (isArray$b(modelValue3)) {
        const index2 = looseIndexOf(modelValue3, elementValue);
        const found2 = index2 !== -1;
        if (checked4 && !found2) {
          assign2(modelValue3.concat(elementValue));
        } else if (!checked4 && found2) {
          const filtered = [...modelValue3];
          filtered.splice(index2, 1);
          assign2(filtered);
        }
      } else if (isSet$3(modelValue3)) {
        const cloned = new Set(modelValue3);
        if (checked4) {
          cloned.add(elementValue);
        } else {
          cloned.delete(elementValue);
        }
        assign2(cloned);
      } else {
        assign2(getCheckboxValue(el, checked4));
      }
    });
  },
  // set initial checked on mount to wait for true-value/false-value
  mounted: setChecked,
  beforeUpdate(el, binding, vnode) {
    el[assignKey] = getModelAssigner(vnode);
    setChecked(el, binding, vnode);
  }
};
function setChecked(el, { value: value3, oldValue }, vnode) {
  el._modelValue = value3;
  let checked4;
  if (isArray$b(value3)) {
    checked4 = looseIndexOf(value3, vnode.props.value) > -1;
  } else if (isSet$3(value3)) {
    checked4 = value3.has(vnode.props.value);
  } else {
    if (value3 === oldValue) return;
    checked4 = looseEqual(value3, getCheckboxValue(el, true));
  }
  if (el.checked !== checked4) {
    el.checked = checked4;
  }
}
__name(setChecked, "setChecked");
const vModelRadio = {
  created(el, { value: value3 }, vnode) {
    el.checked = looseEqual(value3, vnode.props.value);
    el[assignKey] = getModelAssigner(vnode);
    addEventListener$1(el, "change", () => {
      el[assignKey](getValue$3(el));
    });
  },
  beforeUpdate(el, { value: value3, oldValue }, vnode) {
    el[assignKey] = getModelAssigner(vnode);
    if (value3 !== oldValue) {
      el.checked = looseEqual(value3, vnode.props.value);
    }
  }
};
const vModelSelect = {
  // <select multiple> value need to be deep traversed
  deep: true,
  created(el, { value: value3, modifiers: { number: number2 } }, vnode) {
    const isSetModel = isSet$3(value3);
    addEventListener$1(el, "change", () => {
      const selectedVal = Array.prototype.filter.call(el.options, (o2) => o2.selected).map(
        (o2) => number2 ? looseToNumber(getValue$3(o2)) : getValue$3(o2)
      );
      el[assignKey](
        el.multiple ? isSetModel ? new Set(selectedVal) : selectedVal : selectedVal[0]
      );
      el._assigning = true;
      nextTick(() => {
        el._assigning = false;
      });
    });
    el[assignKey] = getModelAssigner(vnode);
  },
  // set value in mounted & updated because <select> relies on its children
  // <option>s.
  mounted(el, { value: value3 }) {
    setSelected(el, value3);
  },
  beforeUpdate(el, _binding, vnode) {
    el[assignKey] = getModelAssigner(vnode);
  },
  updated(el, { value: value3 }) {
    if (!el._assigning) {
      setSelected(el, value3);
    }
  }
};
function setSelected(el, value3) {
  const isMultiple = el.multiple;
  const isArrayValue = isArray$b(value3);
  if (isMultiple && !isArrayValue && !isSet$3(value3)) {
    return;
  }
  for (let i2 = 0, l2 = el.options.length; i2 < l2; i2++) {
    const option5 = el.options[i2];
    const optionValue = getValue$3(option5);
    if (isMultiple) {
      if (isArrayValue) {
        const optionType = typeof optionValue;
        if (optionType === "string" || optionType === "number") {
          option5.selected = value3.some((v2) => String(v2) === String(optionValue));
        } else {
          option5.selected = looseIndexOf(value3, optionValue) > -1;
        }
      } else {
        option5.selected = value3.has(optionValue);
      }
    } else if (looseEqual(getValue$3(option5), value3)) {
      if (el.selectedIndex !== i2) el.selectedIndex = i2;
      return;
    }
  }
  if (!isMultiple && el.selectedIndex !== -1) {
    el.selectedIndex = -1;
  }
}
__name(setSelected, "setSelected");
function getValue$3(el) {
  return "_value" in el ? el._value : el.value;
}
__name(getValue$3, "getValue$3");
function getCheckboxValue(el, checked4) {
  const key = checked4 ? "_trueValue" : "_falseValue";
  return key in el ? el[key] : checked4;
}
__name(getCheckboxValue, "getCheckboxValue");
const vModelDynamic = {
  created(el, binding, vnode) {
    callModelHook(el, binding, vnode, null, "created");
  },
  mounted(el, binding, vnode) {
    callModelHook(el, binding, vnode, null, "mounted");
  },
  beforeUpdate(el, binding, vnode, prevVNode) {
    callModelHook(el, binding, vnode, prevVNode, "beforeUpdate");
  },
  updated(el, binding, vnode, prevVNode) {
    callModelHook(el, binding, vnode, prevVNode, "updated");
  }
};
function resolveDynamicModel(tagName, type) {
  switch (tagName) {
    case "SELECT":
      return vModelSelect;
    case "TEXTAREA":
      return vModelText;
    default:
      switch (type) {
        case "checkbox":
          return vModelCheckbox;
        case "radio":
          return vModelRadio;
        default:
          return vModelText;
      }
  }
}
__name(resolveDynamicModel, "resolveDynamicModel");
function callModelHook(el, binding, vnode, prevVNode, hook) {
  const modelToUse = resolveDynamicModel(
    el.tagName,
    vnode.props && vnode.props.type
  );
  const fn = modelToUse[hook];
  fn && fn(el, binding, vnode, prevVNode);
}
__name(callModelHook, "callModelHook");
function initVModelForSSR() {
  vModelText.getSSRProps = ({ value: value3 }) => ({ value: value3 });
  vModelRadio.getSSRProps = ({ value: value3 }, vnode) => {
    if (vnode.props && looseEqual(vnode.props.value, value3)) {
      return { checked: true };
    }
  };
  vModelCheckbox.getSSRProps = ({ value: value3 }, vnode) => {
    if (isArray$b(value3)) {
      if (vnode.props && looseIndexOf(value3, vnode.props.value) > -1) {
        return { checked: true };
      }
    } else if (isSet$3(value3)) {
      if (vnode.props && value3.has(vnode.props.value)) {
        return { checked: true };
      }
    } else if (value3) {
      return { checked: true };
    }
  };
  vModelDynamic.getSSRProps = (binding, vnode) => {
    if (typeof vnode.type !== "string") {
      return;
    }
    const modelToUse = resolveDynamicModel(
      // resolveDynamicModel expects an uppercase tag name, but vnode.type is lowercase
      vnode.type.toUpperCase(),
      vnode.props && vnode.props.type
    );
    if (modelToUse.getSSRProps) {
      return modelToUse.getSSRProps(binding, vnode);
    }
  };
}
__name(initVModelForSSR, "initVModelForSSR");
const systemModifiers = ["ctrl", "shift", "alt", "meta"];
const modifierGuards = {
  stop: /* @__PURE__ */ __name((e2) => e2.stopPropagation(), "stop"),
  prevent: /* @__PURE__ */ __name((e2) => e2.preventDefault(), "prevent"),
  self: /* @__PURE__ */ __name((e2) => e2.target !== e2.currentTarget, "self"),
  ctrl: /* @__PURE__ */ __name((e2) => !e2.ctrlKey, "ctrl"),
  shift: /* @__PURE__ */ __name((e2) => !e2.shiftKey, "shift"),
  alt: /* @__PURE__ */ __name((e2) => !e2.altKey, "alt"),
  meta: /* @__PURE__ */ __name((e2) => !e2.metaKey, "meta"),
  left: /* @__PURE__ */ __name((e2) => "button" in e2 && e2.button !== 0, "left"),
  middle: /* @__PURE__ */ __name((e2) => "button" in e2 && e2.button !== 1, "middle"),
  right: /* @__PURE__ */ __name((e2) => "button" in e2 && e2.button !== 2, "right"),
  exact: /* @__PURE__ */ __name((e2, modifiers2) => systemModifiers.some((m2) => e2[`${m2}Key`] && !modifiers2.includes(m2)), "exact")
};
const withModifiers = /* @__PURE__ */ __name((fn, modifiers2) => {
  const cache2 = fn._withMods || (fn._withMods = {});
  const cacheKey = modifiers2.join(".");
  return cache2[cacheKey] || (cache2[cacheKey] = (event, ...args) => {
    for (let i2 = 0; i2 < modifiers2.length; i2++) {
      const guard = modifierGuards[modifiers2[i2]];
      if (guard && guard(event, modifiers2)) return;
    }
    return fn(event, ...args);
  });
}, "withModifiers");
const keyNames = {
  esc: "escape",
  space: " ",
  up: "arrow-up",
  left: "arrow-left",
  right: "arrow-right",
  down: "arrow-down",
  delete: "backspace"
};
const withKeys = /* @__PURE__ */ __name((fn, modifiers2) => {
  const cache2 = fn._withKeys || (fn._withKeys = {});
  const cacheKey = modifiers2.join(".");
  return cache2[cacheKey] || (cache2[cacheKey] = (event) => {
    if (!("key" in event)) {
      return;
    }
    const eventKey = hyphenate$1(event.key);
    if (modifiers2.some(
      (k2) => k2 === eventKey || keyNames[k2] === eventKey
    )) {
      return fn(event);
    }
  });
}, "withKeys");
const rendererOptions = /* @__PURE__ */ extend$1({ patchProp }, nodeOps);
let renderer;
let enabledHydration = false;
function ensureRenderer() {
  return renderer || (renderer = createRenderer(rendererOptions));
}
__name(ensureRenderer, "ensureRenderer");
function ensureHydrationRenderer() {
  renderer = enabledHydration ? renderer : createHydrationRenderer(rendererOptions);
  enabledHydration = true;
  return renderer;
}
__name(ensureHydrationRenderer, "ensureHydrationRenderer");
const render$15 = /* @__PURE__ */ __name((...args) => {
  ensureRenderer().render(...args);
}, "render$15");
const hydrate = /* @__PURE__ */ __name((...args) => {
  ensureHydrationRenderer().hydrate(...args);
}, "hydrate");
const createApp = /* @__PURE__ */ __name((...args) => {
  const app2 = ensureRenderer().createApp(...args);
  if (false) {
    injectNativeTagCheck(app2);
    injectCompilerOptionsCheck(app2);
  }
  const { mount: mount2 } = app2;
  app2.mount = (containerOrSelector) => {
    const container = normalizeContainer(containerOrSelector);
    if (!container) return;
    const component = app2._component;
    if (!isFunction$c(component) && !component.render && !component.template) {
      component.template = container.innerHTML;
    }
    if (container.nodeType === 1) {
      container.textContent = "";
    }
    const proxy = mount2(container, false, resolveRootNamespace(container));
    if (container instanceof Element) {
      container.removeAttribute("v-cloak");
      container.setAttribute("data-v-app", "");
    }
    return proxy;
  };
  return app2;
}, "createApp");
const createSSRApp = /* @__PURE__ */ __name((...args) => {
  const app2 = ensureHydrationRenderer().createApp(...args);
  if (false) {
    injectNativeTagCheck(app2);
    injectCompilerOptionsCheck(app2);
  }
  const { mount: mount2 } = app2;
  app2.mount = (containerOrSelector) => {
    const container = normalizeContainer(containerOrSelector);
    if (container) {
      return mount2(container, true, resolveRootNamespace(container));
    }
  };
  return app2;
}, "createSSRApp");
function resolveRootNamespace(container) {
  if (container instanceof SVGElement) {
    return "svg";
  }
  if (typeof MathMLElement === "function" && container instanceof MathMLElement) {
    return "mathml";
  }
}
__name(resolveRootNamespace, "resolveRootNamespace");
function injectNativeTagCheck(app2) {
  Object.defineProperty(app2.config, "isNativeTag", {
    value: /* @__PURE__ */ __name((tag) => isHTMLTag(tag) || isSVGTag(tag) || isMathMLTag(tag), "value"),
    writable: false
  });
}
__name(injectNativeTagCheck, "injectNativeTagCheck");
function injectCompilerOptionsCheck(app2) {
  if (isRuntimeOnly()) {
    const isCustomElement = app2.config.isCustomElement;
    Object.defineProperty(app2.config, "isCustomElement", {
      get() {
        return isCustomElement;
      },
      set() {
        warn$3(
          `The \`isCustomElement\` config option is deprecated. Use \`compilerOptions.isCustomElement\` instead.`
        );
      }
    });
    const compilerOptions = app2.config.compilerOptions;
    const msg = `The \`compilerOptions\` config option is only respected when using a build of Vue.js that includes the runtime compiler (aka "full build"). Since you are using the runtime-only build, \`compilerOptions\` must be passed to \`@vue/compiler-dom\` in the build setup instead.
- For vue-loader: pass it via vue-loader's \`compilerOptions\` loader option.
- For vue-cli: see https://cli.vuejs.org/guide/webpack.html#modifying-options-of-a-loader
- For vite: pass it via @vitejs/plugin-vue options. See https://github.com/vitejs/vite-plugin-vue/tree/main/packages/plugin-vue#example-for-passing-options-to-vuecompiler-sfc`;
    Object.defineProperty(app2.config, "compilerOptions", {
      get() {
        warn$3(msg);
        return compilerOptions;
      },
      set() {
        warn$3(msg);
      }
    });
  }
}
__name(injectCompilerOptionsCheck, "injectCompilerOptionsCheck");
function normalizeContainer(container) {
  if (isString$9(container)) {
    const res = document.querySelector(container);
    if (false) {
      warn$3(
        `Failed to mount app: mount target selector "${container}" returned null.`
      );
    }
    return res;
  }
  if (false) {
    warn$3(
      `mounting on a ShadowRoot with \`{mode: "closed"}\` may lead to unpredictable bugs`
    );
  }
  return container;
}
__name(normalizeContainer, "normalizeContainer");
let ssrDirectiveInitialized = false;
const initDirectivesForSSR = /* @__PURE__ */ __name(() => {
  if (!ssrDirectiveInitialized) {
    ssrDirectiveInitialized = true;
    initVModelForSSR();
    initVShowForSSR();
  }
}, "initDirectivesForSSR");
/**
* vue v3.5.13
* (c) 2018-present Yuxi (Evan) You and Vue contributors
* @license MIT
**/
function initDev() {
  {
    initCustomFormatter();
  }
}
__name(initDev, "initDev");
if (false) {
  initDev();
}
const compile$2 = /* @__PURE__ */ __name(() => {
  if (false) {
    warn$3(
      `Runtime compilation is not supported in this build of Vue. Configure your bundler to alias "vue" to "vue/dist/vue.esm-bundler.js".`
    );
  }
}, "compile$2");
const vue_runtime_esmBundler = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  BaseTransition,
  BaseTransitionPropsValidators,
  Comment,
  DeprecationTypes,
  EffectScope,
  ErrorCodes,
  ErrorTypeStrings,
  Fragment: Fragment$1,
  KeepAlive,
  ReactiveEffect,
  Static,
  Suspense,
  Teleport,
  Text: Text$4,
  TrackOpTypes,
  Transition,
  TransitionGroup,
  TriggerOpTypes,
  VueElement,
  assertNumber,
  callWithAsyncErrorHandling,
  callWithErrorHandling,
  camelize: camelize$1,
  capitalize: capitalize$1,
  cloneVNode,
  compatUtils,
  compile: compile$2,
  computed,
  createApp,
  createBlock,
  createCommentVNode,
  createElementBlock,
  createElementVNode: createBaseVNode,
  createHydrationRenderer,
  createPropsRestProxy,
  createRenderer,
  createSSRApp,
  createSlots,
  createStaticVNode,
  createTextVNode,
  createVNode,
  customRef,
  defineAsyncComponent,
  defineComponent,
  defineCustomElement,
  defineEmits,
  defineExpose,
  defineModel,
  defineOptions,
  defineProps,
  defineSSRCustomElement,
  defineSlots,
  devtools: devtools$2,
  effect,
  effectScope,
  getCurrentInstance,
  getCurrentScope,
  getCurrentWatcher,
  getTransitionRawChildren,
  guardReactiveProps,
  h,
  handleError,
  hasInjectionContext,
  hydrate,
  hydrateOnIdle,
  hydrateOnInteraction,
  hydrateOnMediaQuery,
  hydrateOnVisible,
  initCustomFormatter,
  initDirectivesForSSR,
  inject,
  isMemoSame,
  isProxy,
  isReactive,
  isReadonly,
  isRef,
  isRuntimeOnly,
  isShallow,
  isVNode: isVNode$1,
  markRaw,
  mergeDefaults,
  mergeModels,
  mergeProps: mergeProps$2,
  nextTick,
  normalizeClass,
  normalizeProps,
  normalizeStyle,
  onActivated,
  onBeforeMount,
  onBeforeUnmount,
  onBeforeUpdate,
  onDeactivated,
  onErrorCaptured,
  onMounted,
  onRenderTracked,
  onRenderTriggered,
  onScopeDispose,
  onServerPrefetch,
  onUnmounted,
  onUpdated,
  onWatcherCleanup,
  openBlock,
  popScopeId,
  provide,
  proxyRefs,
  pushScopeId,
  queuePostFlushCb,
  reactive,
  readonly,
  ref,
  registerRuntimeCompiler,
  render: render$15,
  renderList,
  renderSlot,
  resolveComponent,
  resolveDirective,
  resolveDynamicComponent,
  resolveFilter,
  resolveTransitionHooks,
  setBlockTracking,
  setDevtoolsHook,
  setTransitionHooks,
  shallowReactive,
  shallowReadonly,
  shallowRef,
  ssrContextKey,
  ssrUtils,
  stop,
  toDisplayString: toDisplayString$1,
  toHandlerKey,
  toHandlers,
  toRaw,
  toRef: toRef$1,
  toRefs: toRefs$1,
  toValue: toValue$4,
  transformVNodeArgs,
  triggerRef,
  unref,
  useAttrs,
  useCssModule,
  useCssVars,
  useHost,
  useId,
  useModel,
  useSSRContext,
  useShadowRoot,
  useSlots,
  useTemplateRef,
  useTransitionState,
  vModelCheckbox,
  vModelDynamic,
  vModelRadio,
  vModelSelect,
  vModelText,
  vShow,
  version,
  warn: warn$3,
  watch,
  watchEffect,
  watchPostEffect,
  watchSyncEffect,
  withAsyncContext,
  withCtx,
  withDefaults,
  withDirectives,
  withKeys,
  withMemo,
  withModifiers,
  withScopeId
}, Symbol.toStringTag, { value: "Module" }));
var isVue2$2 = false;
var isVue3$2 = true;
var Vue2$2 = void 0;
function install$8() {
}
__name(install$8, "install$8");
function set$3(target2, key, val) {
  if (Array.isArray(target2)) {
    target2.length = Math.max(target2.length, key);
    target2.splice(key, 1, val);
    return val;
  }
  target2[key] = val;
  return val;
}
__name(set$3, "set$3");
function del$3(target2, key) {
  if (Array.isArray(target2)) {
    target2.splice(key, 1);
    return;
  }
  delete target2[key];
}
__name(del$3, "del$3");
function getDevtoolsGlobalHook() {
  return getTarget().__VUE_DEVTOOLS_GLOBAL_HOOK__;
}
__name(getDevtoolsGlobalHook, "getDevtoolsGlobalHook");
function getTarget() {
  return typeof navigator !== "undefined" && typeof window !== "undefined" ? window : typeof globalThis !== "undefined" ? globalThis : {};
}
__name(getTarget, "getTarget");
const isProxyAvailable = typeof Proxy === "function";
const HOOK_SETUP = "devtools-plugin:setup";
const HOOK_PLUGIN_SETTINGS_SET = "plugin:settings:set";
let supported;
let perf;
function isPerformanceSupported() {
  var _a2;
  if (supported !== void 0) {
    return supported;
  }
  if (typeof window !== "undefined" && window.performance) {
    supported = true;
    perf = window.performance;
  } else if (typeof globalThis !== "undefined" && ((_a2 = globalThis.perf_hooks) === null || _a2 === void 0 ? void 0 : _a2.performance)) {
    supported = true;
    perf = globalThis.perf_hooks.performance;
  } else {
    supported = false;
  }
  return supported;
}
__name(isPerformanceSupported, "isPerformanceSupported");
function now$1() {
  return isPerformanceSupported() ? perf.now() : Date.now();
}
__name(now$1, "now$1");
class ApiProxy {
  static {
    __name(this, "ApiProxy");
  }
  constructor(plugin, hook) {
    this.target = null;
    this.targetQueue = [];
    this.onQueue = [];
    this.plugin = plugin;
    this.hook = hook;
    const defaultSettings = {};
    if (plugin.settings) {
      for (const id4 in plugin.settings) {
        const item3 = plugin.settings[id4];
        defaultSettings[id4] = item3.defaultValue;
      }
    }
    const localSettingsSaveId = `__vue-devtools-plugin-settings__${plugin.id}`;
    let currentSettings = Object.assign({}, defaultSettings);
    try {
      const raw = localStorage.getItem(localSettingsSaveId);
      const data30 = JSON.parse(raw);
      Object.assign(currentSettings, data30);
    } catch (e2) {
    }
    this.fallbacks = {
      getSettings() {
        return currentSettings;
      },
      setSettings(value3) {
        try {
          localStorage.setItem(localSettingsSaveId, JSON.stringify(value3));
        } catch (e2) {
        }
        currentSettings = value3;
      },
      now() {
        return now$1();
      }
    };
    if (hook) {
      hook.on(HOOK_PLUGIN_SETTINGS_SET, (pluginId, value3) => {
        if (pluginId === this.plugin.id) {
          this.fallbacks.setSettings(value3);
        }
      });
    }
    this.proxiedOn = new Proxy({}, {
      get: /* @__PURE__ */ __name((_target, prop2) => {
        if (this.target) {
          return this.target.on[prop2];
        } else {
          return (...args) => {
            this.onQueue.push({
              method: prop2,
              args
            });
          };
        }
      }, "get")
    });
    this.proxiedTarget = new Proxy({}, {
      get: /* @__PURE__ */ __name((_target, prop2) => {
        if (this.target) {
          return this.target[prop2];
        } else if (prop2 === "on") {
          return this.proxiedOn;
        } else if (Object.keys(this.fallbacks).includes(prop2)) {
          return (...args) => {
            this.targetQueue.push({
              method: prop2,
              args,
              resolve: /* @__PURE__ */ __name(() => {
              }, "resolve")
            });
            return this.fallbacks[prop2](...args);
          };
        } else {
          return (...args) => {
            return new Promise((resolve2) => {
              this.targetQueue.push({
                method: prop2,
                args,
                resolve: resolve2
              });
            });
          };
        }
      }, "get")
    });
  }
  async setRealTarget(target2) {
    this.target = target2;
    for (const item3 of this.onQueue) {
      this.target.on[item3.method](...item3.args);
    }
    for (const item3 of this.targetQueue) {
      item3.resolve(await this.target[item3.method](...item3.args));
    }
  }
}
function setupDevtoolsPlugin(pluginDescriptor, setupFn) {
  const descriptor = pluginDescriptor;
  const target2 = getTarget();
  const hook = getDevtoolsGlobalHook();
  const enableProxy = isProxyAvailable && descriptor.enableEarlyProxy;
  if (hook && (target2.__VUE_DEVTOOLS_PLUGIN_API_AVAILABLE__ || !enableProxy)) {
    hook.emit(HOOK_SETUP, pluginDescriptor, setupFn);
  } else {
    const proxy = enableProxy ? new ApiProxy(descriptor, hook) : null;
    const list2 = target2.__VUE_DEVTOOLS_PLUGINS__ = target2.__VUE_DEVTOOLS_PLUGINS__ || [];
    list2.push({
      pluginDescriptor: descriptor,
      setupFn,
      proxy
    });
    if (proxy) {
      setupFn(proxy.proxiedTarget);
    }
  }
}
__name(setupDevtoolsPlugin, "setupDevtoolsPlugin");
/*!
 * pinia v2.2.2
 * (c) 2024 Eduardo San Martin Morote
 * @license MIT
 */
let activePinia;
const setActivePinia = /* @__PURE__ */ __name((pinia2) => activePinia = pinia2, "setActivePinia");
const getActivePinia = /* @__PURE__ */ __name(() => hasInjectionContext() && inject(piniaSymbol) || activePinia, "getActivePinia");
const piniaSymbol = false ? Symbol("pinia") : (
  /* istanbul ignore next */
  Symbol()
);
function isPlainObject$3(o2) {
  return o2 && typeof o2 === "object" && Object.prototype.toString.call(o2) === "[object Object]" && typeof o2.toJSON !== "function";
}
__name(isPlainObject$3, "isPlainObject$3");
var MutationType;
(function(MutationType2) {
  MutationType2["direct"] = "direct";
  MutationType2["patchObject"] = "patch object";
  MutationType2["patchFunction"] = "patch function";
})(MutationType || (MutationType = {}));
const IS_CLIENT = typeof window !== "undefined";
const _global$2 = /* @__PURE__ */ (() => typeof window === "object" && window.window === window ? window : typeof self === "object" && self.self === self ? self : typeof global === "object" && global.global === global ? global : typeof globalThis === "object" ? globalThis : { HTMLElement: null })();
function bom(blob, { autoBom = false } = {}) {
  if (autoBom && /^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(blob.type)) {
    return new Blob([String.fromCharCode(65279), blob], { type: blob.type });
  }
  return blob;
}
__name(bom, "bom");
function download(url, name2, opts) {
  const xhr = new XMLHttpRequest();
  xhr.open("GET", url);
  xhr.responseType = "blob";
  xhr.onload = function() {
    saveAs$2(xhr.response, name2, opts);
  };
  xhr.onerror = function() {
    console.error("could not download file");
  };
  xhr.send();
}
__name(download, "download");
function corsEnabled(url) {
  const xhr = new XMLHttpRequest();
  xhr.open("HEAD", url, false);
  try {
    xhr.send();
  } catch (e2) {
  }
  return xhr.status >= 200 && xhr.status <= 299;
}
__name(corsEnabled, "corsEnabled");
function click(node3) {
  try {
    node3.dispatchEvent(new MouseEvent("click"));
  } catch (e2) {
    const evt = document.createEvent("MouseEvents");
    evt.initMouseEvent("click", true, true, window, 0, 0, 0, 80, 20, false, false, false, false, 0, null);
    node3.dispatchEvent(evt);
  }
}
__name(click, "click");
const _navigator$1 = typeof navigator === "object" ? navigator : { userAgent: "" };
const isMacOSWebView = /* @__PURE__ */ (() => /Macintosh/.test(_navigator$1.userAgent) && /AppleWebKit/.test(_navigator$1.userAgent) && !/Safari/.test(_navigator$1.userAgent))();
const saveAs$2 = !IS_CLIENT ? () => {
} : (
  // Use download attribute first if possible (#193 Lumia mobile) unless this is a macOS WebView or mini program
  typeof HTMLAnchorElement !== "undefined" && "download" in HTMLAnchorElement.prototype && !isMacOSWebView ? downloadSaveAs : (
    // Use msSaveOrOpenBlob as a second approach
    "msSaveOrOpenBlob" in _navigator$1 ? msSaveAs : (
      // Fallback to using FileReader and a popup
      fileSaverSaveAs
    )
  )
);
function downloadSaveAs(blob, name2 = "download", opts) {
  const a2 = document.createElement("a");
  a2.download = name2;
  a2.rel = "noopener";
  if (typeof blob === "string") {
    a2.href = blob;
    if (a2.origin !== location.origin) {
      if (corsEnabled(a2.href)) {
        download(blob, name2, opts);
      } else {
        a2.target = "_blank";
        click(a2);
      }
    } else {
      click(a2);
    }
  } else {
    a2.href = URL.createObjectURL(blob);
    setTimeout(function() {
      URL.revokeObjectURL(a2.href);
    }, 4e4);
    setTimeout(function() {
      click(a2);
    }, 0);
  }
}
__name(downloadSaveAs, "downloadSaveAs");
function msSaveAs(blob, name2 = "download", opts) {
  if (typeof blob === "string") {
    if (corsEnabled(blob)) {
      download(blob, name2, opts);
    } else {
      const a2 = document.createElement("a");
      a2.href = blob;
      a2.target = "_blank";
      setTimeout(function() {
        click(a2);
      });
    }
  } else {
    navigator.msSaveOrOpenBlob(bom(blob, opts), name2);
  }
}
__name(msSaveAs, "msSaveAs");
function fileSaverSaveAs(blob, name2, opts, popup) {
  popup = popup || open("", "_blank");
  if (popup) {
    popup.document.title = popup.document.body.innerText = "downloading...";
  }
  if (typeof blob === "string")
    return download(blob, name2, opts);
  const force = blob.type === "application/octet-stream";
  const isSafari3 = /constructor/i.test(String(_global$2.HTMLElement)) || "safari" in _global$2;
  const isChromeIOS = /CriOS\/[\d]+/.test(navigator.userAgent);
  if ((isChromeIOS || force && isSafari3 || isMacOSWebView) && typeof FileReader !== "undefined") {
    const reader = new FileReader();
    reader.onloadend = function() {
      let url = reader.result;
      if (typeof url !== "string") {
        popup = null;
        throw new Error("Wrong reader.result type");
      }
      url = isChromeIOS ? url : url.replace(/^data:[^;]*;/, "data:attachment/file;");
      if (popup) {
        popup.location.href = url;
      } else {
        location.assign(url);
      }
      popup = null;
    };
    reader.readAsDataURL(blob);
  } else {
    const url = URL.createObjectURL(blob);
    if (popup)
      popup.location.assign(url);
    else
      location.href = url;
    popup = null;
    setTimeout(function() {
      URL.revokeObjectURL(url);
    }, 4e4);
  }
}
__name(fileSaverSaveAs, "fileSaverSaveAs");
function toastMessage(message3, type) {
  const piniaMessage = "🍍 " + message3;
  if (typeof __VUE_DEVTOOLS_TOAST__ === "function") {
    __VUE_DEVTOOLS_TOAST__(piniaMessage, type);
  } else if (type === "error") {
    console.error(piniaMessage);
  } else if (type === "warn") {
    console.warn(piniaMessage);
  } else {
    console.log(piniaMessage);
  }
}
__name(toastMessage, "toastMessage");
function isPinia(o2) {
  return "_a" in o2 && "install" in o2;
}
__name(isPinia, "isPinia");
function checkClipboardAccess() {
  if (!("clipboard" in navigator)) {
    toastMessage(`Your browser doesn't support the Clipboard API`, "error");
    return true;
  }
}
__name(checkClipboardAccess, "checkClipboardAccess");
function checkNotFocusedError(error2) {
  if (error2 instanceof Error && error2.message.toLowerCase().includes("document is not focused")) {
    toastMessage('You need to activate the "Emulate a focused page" setting in the "Rendering" panel of devtools.', "warn");
    return true;
  }
  return false;
}
__name(checkNotFocusedError, "checkNotFocusedError");
async function actionGlobalCopyState(pinia2) {
  if (checkClipboardAccess())
    return;
  try {
    await navigator.clipboard.writeText(JSON.stringify(pinia2.state.value));
    toastMessage("Global state copied to clipboard.");
  } catch (error2) {
    if (checkNotFocusedError(error2))
      return;
    toastMessage(`Failed to serialize the state. Check the console for more details.`, "error");
    console.error(error2);
  }
}
__name(actionGlobalCopyState, "actionGlobalCopyState");
async function actionGlobalPasteState(pinia2) {
  if (checkClipboardAccess())
    return;
  try {
    loadStoresState(pinia2, JSON.parse(await navigator.clipboard.readText()));
    toastMessage("Global state pasted from clipboard.");
  } catch (error2) {
    if (checkNotFocusedError(error2))
      return;
    toastMessage(`Failed to deserialize the state from clipboard. Check the console for more details.`, "error");
    console.error(error2);
  }
}
__name(actionGlobalPasteState, "actionGlobalPasteState");
async function actionGlobalSaveState(pinia2) {
  try {
    saveAs$2(new Blob([JSON.stringify(pinia2.state.value)], {
      type: "text/plain;charset=utf-8"
    }), "pinia-state.json");
  } catch (error2) {
    toastMessage(`Failed to export the state as JSON. Check the console for more details.`, "error");
    console.error(error2);
  }
}
__name(actionGlobalSaveState, "actionGlobalSaveState");
let fileInput;
function getFileOpener() {
  if (!fileInput) {
    fileInput = document.createElement("input");
    fileInput.type = "file";
    fileInput.accept = ".json";
  }
  function openFile() {
    return new Promise((resolve2, reject3) => {
      fileInput.onchange = async () => {
        const files = fileInput.files;
        if (!files)
          return resolve2(null);
        const file = files.item(0);
        if (!file)
          return resolve2(null);
        return resolve2({ text: await file.text(), file });
      };
      fileInput.oncancel = () => resolve2(null);
      fileInput.onerror = reject3;
      fileInput.click();
    });
  }
  __name(openFile, "openFile");
  return openFile;
}
__name(getFileOpener, "getFileOpener");
async function actionGlobalOpenStateFile(pinia2) {
  try {
    const open2 = getFileOpener();
    const result = await open2();
    if (!result)
      return;
    const { text: text2, file } = result;
    loadStoresState(pinia2, JSON.parse(text2));
    toastMessage(`Global state imported from "${file.name}".`);
  } catch (error2) {
    toastMessage(`Failed to import the state from JSON. Check the console for more details.`, "error");
    console.error(error2);
  }
}
__name(actionGlobalOpenStateFile, "actionGlobalOpenStateFile");
function loadStoresState(pinia2, state) {
  for (const key in state) {
    const storeState = pinia2.state.value[key];
    if (storeState) {
      Object.assign(storeState, state[key]);
    } else {
      pinia2.state.value[key] = state[key];
    }
  }
}
__name(loadStoresState, "loadStoresState");
function formatDisplay$1(display) {
  return {
    _custom: {
      display
    }
  };
}
__name(formatDisplay$1, "formatDisplay$1");
const PINIA_ROOT_LABEL = "🍍 Pinia (root)";
const PINIA_ROOT_ID = "_root";
function formatStoreForInspectorTree(store) {
  return isPinia(store) ? {
    id: PINIA_ROOT_ID,
    label: PINIA_ROOT_LABEL
  } : {
    id: store.$id,
    label: store.$id
  };
}
__name(formatStoreForInspectorTree, "formatStoreForInspectorTree");
function formatStoreForInspectorState(store) {
  if (isPinia(store)) {
    const storeNames = Array.from(store._s.keys());
    const storeMap = store._s;
    const state2 = {
      state: storeNames.map((storeId) => ({
        editable: true,
        key: storeId,
        value: store.state.value[storeId]
      })),
      getters: storeNames.filter((id4) => storeMap.get(id4)._getters).map((id4) => {
        const store2 = storeMap.get(id4);
        return {
          editable: false,
          key: id4,
          value: store2._getters.reduce((getters, key) => {
            getters[key] = store2[key];
            return getters;
          }, {})
        };
      })
    };
    return state2;
  }
  const state = {
    state: Object.keys(store.$state).map((key) => ({
      editable: true,
      key,
      value: store.$state[key]
    }))
  };
  if (store._getters && store._getters.length) {
    state.getters = store._getters.map((getterName) => ({
      editable: false,
      key: getterName,
      value: store[getterName]
    }));
  }
  if (store._customProperties.size) {
    state.customProperties = Array.from(store._customProperties).map((key) => ({
      editable: true,
      key,
      value: store[key]
    }));
  }
  return state;
}
__name(formatStoreForInspectorState, "formatStoreForInspectorState");
function formatEventData(events2) {
  if (!events2)
    return {};
  if (Array.isArray(events2)) {
    return events2.reduce((data30, event) => {
      data30.keys.push(event.key);
      data30.operations.push(event.type);
      data30.oldValue[event.key] = event.oldValue;
      data30.newValue[event.key] = event.newValue;
      return data30;
    }, {
      oldValue: {},
      keys: [],
      operations: [],
      newValue: {}
    });
  } else {
    return {
      operation: formatDisplay$1(events2.type),
      key: formatDisplay$1(events2.key),
      oldValue: events2.oldValue,
      newValue: events2.newValue
    };
  }
}
__name(formatEventData, "formatEventData");
function formatMutationType(type) {
  switch (type) {
    case MutationType.direct:
      return "mutation";
    case MutationType.patchFunction:
      return "$patch";
    case MutationType.patchObject:
      return "$patch";
    default:
      return "unknown";
  }
}
__name(formatMutationType, "formatMutationType");
let isTimelineActive = true;
const componentStateTypes = [];
const MUTATIONS_LAYER_ID = "pinia:mutations";
const INSPECTOR_ID = "pinia";
const { assign: assign$1$1 } = Object;
const getStoreType = /* @__PURE__ */ __name((id4) => "🍍 " + id4, "getStoreType");
function registerPiniaDevtools(app2, pinia2) {
  setupDevtoolsPlugin({
    id: "dev.esm.pinia",
    label: "Pinia 🍍",
    logo: "https://pinia.vuejs.org/logo.svg",
    packageName: "pinia",
    homepage: "https://pinia.vuejs.org",
    componentStateTypes,
    app: app2
  }, (api2) => {
    if (typeof api2.now !== "function") {
      toastMessage("You seem to be using an outdated version of Vue Devtools. Are you still using the Beta release instead of the stable one? You can find the links at https://devtools.vuejs.org/guide/installation.html.");
    }
    api2.addTimelineLayer({
      id: MUTATIONS_LAYER_ID,
      label: `Pinia 🍍`,
      color: 15064968
    });
    api2.addInspector({
      id: INSPECTOR_ID,
      label: "Pinia 🍍",
      icon: "storage",
      treeFilterPlaceholder: "Search stores",
      actions: [
        {
          icon: "content_copy",
          action: /* @__PURE__ */ __name(() => {
            actionGlobalCopyState(pinia2);
          }, "action"),
          tooltip: "Serialize and copy the state"
        },
        {
          icon: "content_paste",
          action: /* @__PURE__ */ __name(async () => {
            await actionGlobalPasteState(pinia2);
            api2.sendInspectorTree(INSPECTOR_ID);
            api2.sendInspectorState(INSPECTOR_ID);
          }, "action"),
          tooltip: "Replace the state with the content of your clipboard"
        },
        {
          icon: "save",
          action: /* @__PURE__ */ __name(() => {
            actionGlobalSaveState(pinia2);
          }, "action"),
          tooltip: "Save the state as a JSON file"
        },
        {
          icon: "folder_open",
          action: /* @__PURE__ */ __name(async () => {
            await actionGlobalOpenStateFile(pinia2);
            api2.sendInspectorTree(INSPECTOR_ID);
            api2.sendInspectorState(INSPECTOR_ID);
          }, "action"),
          tooltip: "Import the state from a JSON file"
        }
      ],
      nodeActions: [
        {
          icon: "restore",
          tooltip: 'Reset the state (with "$reset")',
          action: /* @__PURE__ */ __name((nodeId) => {
            const store = pinia2._s.get(nodeId);
            if (!store) {
              toastMessage(`Cannot reset "${nodeId}" store because it wasn't found.`, "warn");
            } else if (typeof store.$reset !== "function") {
              toastMessage(`Cannot reset "${nodeId}" store because it doesn't have a "$reset" method implemented.`, "warn");
            } else {
              store.$reset();
              toastMessage(`Store "${nodeId}" reset.`);
            }
          }, "action")
        }
      ]
    });
    api2.on.inspectComponent((payload, ctx) => {
      const proxy = payload.componentInstance && payload.componentInstance.proxy;
      if (proxy && proxy._pStores) {
        const piniaStores = payload.componentInstance.proxy._pStores;
        Object.values(piniaStores).forEach((store) => {
          payload.instanceData.state.push({
            type: getStoreType(store.$id),
            key: "state",
            editable: true,
            value: store._isOptionsAPI ? {
              _custom: {
                value: toRaw(store.$state),
                actions: [
                  {
                    icon: "restore",
                    tooltip: "Reset the state of this store",
                    action: /* @__PURE__ */ __name(() => store.$reset(), "action")
                  }
                ]
              }
            } : (
              // NOTE: workaround to unwrap transferred refs
              Object.keys(store.$state).reduce((state, key) => {
                state[key] = store.$state[key];
                return state;
              }, {})
            )
          });
          if (store._getters && store._getters.length) {
            payload.instanceData.state.push({
              type: getStoreType(store.$id),
              key: "getters",
              editable: false,
              value: store._getters.reduce((getters, key) => {
                try {
                  getters[key] = store[key];
                } catch (error2) {
                  getters[key] = error2;
                }
                return getters;
              }, {})
            });
          }
        });
      }
    });
    api2.on.getInspectorTree((payload) => {
      if (payload.app === app2 && payload.inspectorId === INSPECTOR_ID) {
        let stores = [pinia2];
        stores = stores.concat(Array.from(pinia2._s.values()));
        payload.rootNodes = (payload.filter ? stores.filter((store) => "$id" in store ? store.$id.toLowerCase().includes(payload.filter.toLowerCase()) : PINIA_ROOT_LABEL.toLowerCase().includes(payload.filter.toLowerCase())) : stores).map(formatStoreForInspectorTree);
      }
    });
    globalThis.$pinia = pinia2;
    api2.on.getInspectorState((payload) => {
      if (payload.app === app2 && payload.inspectorId === INSPECTOR_ID) {
        const inspectedStore = payload.nodeId === PINIA_ROOT_ID ? pinia2 : pinia2._s.get(payload.nodeId);
        if (!inspectedStore) {
          return;
        }
        if (inspectedStore) {
          if (payload.nodeId !== PINIA_ROOT_ID)
            globalThis.$store = toRaw(inspectedStore);
          payload.state = formatStoreForInspectorState(inspectedStore);
        }
      }
    });
    api2.on.editInspectorState((payload, ctx) => {
      if (payload.app === app2 && payload.inspectorId === INSPECTOR_ID) {
        const inspectedStore = payload.nodeId === PINIA_ROOT_ID ? pinia2 : pinia2._s.get(payload.nodeId);
        if (!inspectedStore) {
          return toastMessage(`store "${payload.nodeId}" not found`, "error");
        }
        const { path } = payload;
        if (!isPinia(inspectedStore)) {
          if (path.length !== 1 || !inspectedStore._customProperties.has(path[0]) || path[0] in inspectedStore.$state) {
            path.unshift("$state");
          }
        } else {
          path.unshift("state");
        }
        isTimelineActive = false;
        payload.set(inspectedStore, path, payload.state.value);
        isTimelineActive = true;
      }
    });
    api2.on.editComponentState((payload) => {
      if (payload.type.startsWith("🍍")) {
        const storeId = payload.type.replace(/^🍍\s*/, "");
        const store = pinia2._s.get(storeId);
        if (!store) {
          return toastMessage(`store "${storeId}" not found`, "error");
        }
        const { path } = payload;
        if (path[0] !== "state") {
          return toastMessage(`Invalid path for store "${storeId}":
${path}
Only state can be modified.`);
        }
        path[0] = "$state";
        isTimelineActive = false;
        payload.set(store, path, payload.state.value);
        isTimelineActive = true;
      }
    });
  });
}
__name(registerPiniaDevtools, "registerPiniaDevtools");
function addStoreToDevtools(app2, store) {
  if (!componentStateTypes.includes(getStoreType(store.$id))) {
    componentStateTypes.push(getStoreType(store.$id));
  }
  setupDevtoolsPlugin({
    id: "dev.esm.pinia",
    label: "Pinia 🍍",
    logo: "https://pinia.vuejs.org/logo.svg",
    packageName: "pinia",
    homepage: "https://pinia.vuejs.org",
    componentStateTypes,
    app: app2,
    settings: {
      logStoreChanges: {
        label: "Notify about new/deleted stores",
        type: "boolean",
        defaultValue: true
      }
      // useEmojis: {
      //   label: 'Use emojis in messages ⚡️',
      //   type: 'boolean',
      //   defaultValue: true,
      // },
    }
  }, (api2) => {
    const now2 = typeof api2.now === "function" ? api2.now.bind(api2) : Date.now;
    store.$onAction(({ after, onError, name: name2, args }) => {
      const groupId = runningActionId++;
      api2.addTimelineEvent({
        layerId: MUTATIONS_LAYER_ID,
        event: {
          time: now2(),
          title: "🛫 " + name2,
          subtitle: "start",
          data: {
            store: formatDisplay$1(store.$id),
            action: formatDisplay$1(name2),
            args
          },
          groupId
        }
      });
      after((result) => {
        activeAction = void 0;
        api2.addTimelineEvent({
          layerId: MUTATIONS_LAYER_ID,
          event: {
            time: now2(),
            title: "🛬 " + name2,
            subtitle: "end",
            data: {
              store: formatDisplay$1(store.$id),
              action: formatDisplay$1(name2),
              args,
              result
            },
            groupId
          }
        });
      });
      onError((error2) => {
        activeAction = void 0;
        api2.addTimelineEvent({
          layerId: MUTATIONS_LAYER_ID,
          event: {
            time: now2(),
            logType: "error",
            title: "💥 " + name2,
            subtitle: "end",
            data: {
              store: formatDisplay$1(store.$id),
              action: formatDisplay$1(name2),
              args,
              error: error2
            },
            groupId
          }
        });
      });
    }, true);
    store._customProperties.forEach((name2) => {
      watch(() => unref(store[name2]), (newValue2, oldValue) => {
        api2.notifyComponentUpdate();
        api2.sendInspectorState(INSPECTOR_ID);
        if (isTimelineActive) {
          api2.addTimelineEvent({
            layerId: MUTATIONS_LAYER_ID,
            event: {
              time: now2(),
              title: "Change",
              subtitle: name2,
              data: {
                newValue: newValue2,
                oldValue
              },
              groupId: activeAction
            }
          });
        }
      }, { deep: true });
    });
    store.$subscribe(({ events: events2, type }, state) => {
      api2.notifyComponentUpdate();
      api2.sendInspectorState(INSPECTOR_ID);
      if (!isTimelineActive)
        return;
      const eventData = {
        time: now2(),
        title: formatMutationType(type),
        data: assign$1$1({ store: formatDisplay$1(store.$id) }, formatEventData(events2)),
        groupId: activeAction
      };
      if (type === MutationType.patchFunction) {
        eventData.subtitle = "⤵️";
      } else if (type === MutationType.patchObject) {
        eventData.subtitle = "🧩";
      } else if (events2 && !Array.isArray(events2)) {
        eventData.subtitle = events2.type;
      }
      if (events2) {
        eventData.data["rawEvent(s)"] = {
          _custom: {
            display: "DebuggerEvent",
            type: "object",
            tooltip: "raw DebuggerEvent[]",
            value: events2
          }
        };
      }
      api2.addTimelineEvent({
        layerId: MUTATIONS_LAYER_ID,
        event: eventData
      });
    }, { detached: true, flush: "sync" });
    const hotUpdate = store._hotUpdate;
    store._hotUpdate = markRaw((newStore) => {
      hotUpdate(newStore);
      api2.addTimelineEvent({
        layerId: MUTATIONS_LAYER_ID,
        event: {
          time: now2(),
          title: "🔥 " + store.$id,
          subtitle: "HMR update",
          data: {
            store: formatDisplay$1(store.$id),
            info: formatDisplay$1(`HMR update`)
          }
        }
      });
      api2.notifyComponentUpdate();
      api2.sendInspectorTree(INSPECTOR_ID);
      api2.sendInspectorState(INSPECTOR_ID);
    });
    const { $dispose } = store;
    store.$dispose = () => {
      $dispose();
      api2.notifyComponentUpdate();
      api2.sendInspectorTree(INSPECTOR_ID);
      api2.sendInspectorState(INSPECTOR_ID);
      api2.getSettings().logStoreChanges && toastMessage(`Disposed "${store.$id}" store 🗑`);
    };
    api2.notifyComponentUpdate();
    api2.sendInspectorTree(INSPECTOR_ID);
    api2.sendInspectorState(INSPECTOR_ID);
    api2.getSettings().logStoreChanges && toastMessage(`"${store.$id}" store installed 🆕`);
  });
}
__name(addStoreToDevtools, "addStoreToDevtools");
let runningActionId = 0;
let activeAction;
function patchActionForGrouping(store, actionNames, wrapWithProxy) {
  const actions = actionNames.reduce((storeActions, actionName) => {
    storeActions[actionName] = toRaw(store)[actionName];
    return storeActions;
  }, {});
  for (const actionName in actions) {
    store[actionName] = function() {
      const _actionId = runningActionId;
      const trackedStore = wrapWithProxy ? new Proxy(store, {
        get(...args) {
          activeAction = _actionId;
          return Reflect.get(...args);
        },
        set(...args) {
          activeAction = _actionId;
          return Reflect.set(...args);
        }
      }) : store;
      activeAction = _actionId;
      const retValue = actions[actionName].apply(trackedStore, arguments);
      activeAction = void 0;
      return retValue;
    };
  }
}
__name(patchActionForGrouping, "patchActionForGrouping");
function devtoolsPlugin({ app: app2, store, options: options5 }) {
  if (store.$id.startsWith("__hot:")) {
    return;
  }
  store._isOptionsAPI = !!options5.state;
  if (!store._p._testing) {
    patchActionForGrouping(store, Object.keys(options5.actions), store._isOptionsAPI);
    const originalHotUpdate = store._hotUpdate;
    toRaw(store)._hotUpdate = function(newStore) {
      originalHotUpdate.apply(this, arguments);
      patchActionForGrouping(store, Object.keys(newStore._hmrPayload.actions), !!store._isOptionsAPI);
    };
  }
  addStoreToDevtools(
    app2,
    // FIXME: is there a way to allow the assignment from Store<Id, S, G, A> to StoreGeneric?
    store
  );
}
__name(devtoolsPlugin, "devtoolsPlugin");
function createPinia() {
  const scope = effectScope(true);
  const state = scope.run(() => ref({}));
  let _p = [];
  let toBeInstalled = [];
  const pinia2 = markRaw({
    install(app2) {
      setActivePinia(pinia2);
      if (!isVue2$2) {
        pinia2._a = app2;
        app2.provide(piniaSymbol, pinia2);
        app2.config.globalProperties.$pinia = pinia2;
        if (false) {
          registerPiniaDevtools(app2, pinia2);
        }
        toBeInstalled.forEach((plugin) => _p.push(plugin));
        toBeInstalled = [];
      }
    },
    use(plugin) {
      if (!this._a && !isVue2$2) {
        toBeInstalled.push(plugin);
      } else {
        _p.push(plugin);
      }
      return this;
    },
    _p,
    // it's actually undefined here
    // @ts-expect-error
    _a: null,
    _e: scope,
    _s: /* @__PURE__ */ new Map(),
    state
  });
  if (false) {
    pinia2.use(devtoolsPlugin);
  }
  return pinia2;
}
__name(createPinia, "createPinia");
function disposePinia(pinia2) {
  pinia2._e.stop();
  pinia2._s.clear();
  pinia2._p.splice(0);
  pinia2.state.value = {};
  pinia2._a = null;
}
__name(disposePinia, "disposePinia");
const isUseStore = /* @__PURE__ */ __name((fn) => {
  return typeof fn === "function" && typeof fn.$id === "string";
}, "isUseStore");
function patchObject(newState, oldState) {
  for (const key in oldState) {
    const subPatch = oldState[key];
    if (!(key in newState)) {
      continue;
    }
    const targetValue = newState[key];
    if (isPlainObject$3(targetValue) && isPlainObject$3(subPatch) && !isRef(subPatch) && !isReactive(subPatch)) {
      newState[key] = patchObject(targetValue, subPatch);
    } else {
      if (isVue2$2) {
        set$3(newState, key, subPatch);
      } else {
        newState[key] = subPatch;
      }
    }
  }
  return newState;
}
__name(patchObject, "patchObject");
function acceptHMRUpdate(initialUseStore, hot) {
  if (true) {
    return () => {
    };
  }
  return (newModule) => {
    const pinia2 = hot.data.pinia || initialUseStore._pinia;
    if (!pinia2) {
      return;
    }
    hot.data.pinia = pinia2;
    for (const exportName in newModule) {
      const useStore = newModule[exportName];
      if (isUseStore(useStore) && pinia2._s.has(useStore.$id)) {
        const id4 = useStore.$id;
        if (id4 !== initialUseStore.$id) {
          console.warn(`The id of the store changed from "${initialUseStore.$id}" to "${id4}". Reloading.`);
          return hot.invalidate();
        }
        const existingStore = pinia2._s.get(id4);
        if (!existingStore) {
          console.log(`[Pinia]: skipping hmr because store doesn't exist yet`);
          return;
        }
        useStore(pinia2, existingStore);
      }
    }
  };
}
__name(acceptHMRUpdate, "acceptHMRUpdate");
const noop$4 = /* @__PURE__ */ __name(() => {
}, "noop$4");
function addSubscription(subscriptions, callback, detached, onCleanup = noop$4) {
  subscriptions.push(callback);
  const removeSubscription = /* @__PURE__ */ __name(() => {
    const idx = subscriptions.indexOf(callback);
    if (idx > -1) {
      subscriptions.splice(idx, 1);
      onCleanup();
    }
  }, "removeSubscription");
  if (!detached && getCurrentScope()) {
    onScopeDispose(removeSubscription);
  }
  return removeSubscription;
}
__name(addSubscription, "addSubscription");
function triggerSubscriptions(subscriptions, ...args) {
  subscriptions.slice().forEach((callback) => {
    callback(...args);
  });
}
__name(triggerSubscriptions, "triggerSubscriptions");
const fallbackRunWithContext = /* @__PURE__ */ __name((fn) => fn(), "fallbackRunWithContext");
const ACTION_MARKER = Symbol();
const ACTION_NAME = Symbol();
function mergeReactiveObjects(target2, patchToApply) {
  if (target2 instanceof Map && patchToApply instanceof Map) {
    patchToApply.forEach((value3, key) => target2.set(key, value3));
  } else if (target2 instanceof Set && patchToApply instanceof Set) {
    patchToApply.forEach(target2.add, target2);
  }
  for (const key in patchToApply) {
    if (!patchToApply.hasOwnProperty(key))
      continue;
    const subPatch = patchToApply[key];
    const targetValue = target2[key];
    if (isPlainObject$3(targetValue) && isPlainObject$3(subPatch) && target2.hasOwnProperty(key) && !isRef(subPatch) && !isReactive(subPatch)) {
      target2[key] = mergeReactiveObjects(targetValue, subPatch);
    } else {
      target2[key] = subPatch;
    }
  }
  return target2;
}
__name(mergeReactiveObjects, "mergeReactiveObjects");
const skipHydrateSymbol = false ? Symbol("pinia:skipHydration") : (
  /* istanbul ignore next */
  Symbol()
);
const skipHydrateMap = /* @__PURE__ */ new WeakMap();
function skipHydrate(obj) {
  return isVue2$2 ? (
    // in @vue/composition-api, the refs are sealed so defineProperty doesn't work...
    /* istanbul ignore next */
    skipHydrateMap.set(obj, 1) && obj
  ) : Object.defineProperty(obj, skipHydrateSymbol, {});
}
__name(skipHydrate, "skipHydrate");
function shouldHydrate(obj) {
  return isVue2$2 ? (
    /* istanbul ignore next */
    !skipHydrateMap.has(obj)
  ) : !isPlainObject$3(obj) || !obj.hasOwnProperty(skipHydrateSymbol);
}
__name(shouldHydrate, "shouldHydrate");
const { assign: assign$6 } = Object;
function isComputed(o2) {
  return !!(isRef(o2) && o2.effect);
}
__name(isComputed, "isComputed");
function createOptionsStore(id4, options5, pinia2, hot) {
  const { state, actions, getters } = options5;
  const initialState = pinia2.state.value[id4];
  let store;
  function setup3() {
    if (!initialState && true) {
      if (isVue2$2) {
        set$3(pinia2.state.value, id4, state ? state() : {});
      } else {
        pinia2.state.value[id4] = state ? state() : {};
      }
    }
    const localState = false ? (
      // use ref() to unwrap refs inside state TODO: check if this is still necessary
      toRefs$1(ref(state ? state() : {}).value)
    ) : toRefs$1(pinia2.state.value[id4]);
    return assign$6(localState, actions, Object.keys(getters || {}).reduce((computedGetters, name2) => {
      if (false) {
        console.warn(`[🍍]: A getter cannot have the same name as another state property. Rename one of them. Found with "${name2}" in store "${id4}".`);
      }
      computedGetters[name2] = markRaw(computed(() => {
        setActivePinia(pinia2);
        const store2 = pinia2._s.get(id4);
        if (isVue2$2 && !store2._r)
          return;
        return getters[name2].call(store2, store2);
      }));
      return computedGetters;
    }, {}));
  }
  __name(setup3, "setup");
  store = createSetupStore(id4, setup3, options5, pinia2, hot, true);
  return store;
}
__name(createOptionsStore, "createOptionsStore");
function createSetupStore($id, setup3, options5 = {}, pinia2, hot, isOptionsStore) {
  let scope;
  const optionsForPlugin = assign$6({ actions: {} }, options5);
  if (false) {
    throw new Error("Pinia destroyed");
  }
  const $subscribeOptions = { deep: true };
  if (false) {
    $subscribeOptions.onTrigger = (event) => {
      if (isListening) {
        debuggerEvents = event;
      } else if (isListening == false && !store._hotUpdating) {
        if (Array.isArray(debuggerEvents)) {
          debuggerEvents.push(event);
        } else {
          console.error("🍍 debuggerEvents should be an array. This is most likely an internal Pinia bug.");
        }
      }
    };
  }
  let isListening;
  let isSyncListening;
  let subscriptions = [];
  let actionSubscriptions = [];
  let debuggerEvents;
  const initialState = pinia2.state.value[$id];
  if (!isOptionsStore && !initialState && true) {
    if (isVue2$2) {
      set$3(pinia2.state.value, $id, {});
    } else {
      pinia2.state.value[$id] = {};
    }
  }
  const hotState = ref({});
  let activeListener;
  function $patch(partialStateOrMutator) {
    let subscriptionMutation;
    isListening = isSyncListening = false;
    if (false) {
      debuggerEvents = [];
    }
    if (typeof partialStateOrMutator === "function") {
      partialStateOrMutator(pinia2.state.value[$id]);
      subscriptionMutation = {
        type: MutationType.patchFunction,
        storeId: $id,
        events: debuggerEvents
      };
    } else {
      mergeReactiveObjects(pinia2.state.value[$id], partialStateOrMutator);
      subscriptionMutation = {
        type: MutationType.patchObject,
        payload: partialStateOrMutator,
        storeId: $id,
        events: debuggerEvents
      };
    }
    const myListenerId = activeListener = Symbol();
    nextTick().then(() => {
      if (activeListener === myListenerId) {
        isListening = true;
      }
    });
    isSyncListening = true;
    triggerSubscriptions(subscriptions, subscriptionMutation, pinia2.state.value[$id]);
  }
  __name($patch, "$patch");
  const $reset = isOptionsStore ? /* @__PURE__ */ __name(function $reset2() {
    const { state } = options5;
    const newState = state ? state() : {};
    this.$patch(($state) => {
      assign$6($state, newState);
    });
  }, "$reset2") : (
    /* istanbul ignore next */
    false ? () => {
      throw new Error(`🍍: Store "${$id}" is built using the setup syntax and does not implement $reset().`);
    } : noop$4
  );
  function $dispose() {
    scope.stop();
    subscriptions = [];
    actionSubscriptions = [];
    pinia2._s.delete($id);
  }
  __name($dispose, "$dispose");
  const action = /* @__PURE__ */ __name((fn, name2 = "") => {
    if (ACTION_MARKER in fn) {
      fn[ACTION_NAME] = name2;
      return fn;
    }
    const wrappedAction = /* @__PURE__ */ __name(function() {
      setActivePinia(pinia2);
      const args = Array.from(arguments);
      const afterCallbackList = [];
      const onErrorCallbackList = [];
      function after(callback) {
        afterCallbackList.push(callback);
      }
      __name(after, "after");
      function onError(callback) {
        onErrorCallbackList.push(callback);
      }
      __name(onError, "onError");
      triggerSubscriptions(actionSubscriptions, {
        args,
        name: wrappedAction[ACTION_NAME],
        store,
        after,
        onError
      });
      let ret;
      try {
        ret = fn.apply(this && this.$id === $id ? this : store, args);
      } catch (error2) {
        triggerSubscriptions(onErrorCallbackList, error2);
        throw error2;
      }
      if (ret instanceof Promise) {
        return ret.then((value3) => {
          triggerSubscriptions(afterCallbackList, value3);
          return value3;
        }).catch((error2) => {
          triggerSubscriptions(onErrorCallbackList, error2);
          return Promise.reject(error2);
        });
      }
      triggerSubscriptions(afterCallbackList, ret);
      return ret;
    }, "wrappedAction");
    wrappedAction[ACTION_MARKER] = true;
    wrappedAction[ACTION_NAME] = name2;
    return wrappedAction;
  }, "action");
  const _hmrPayload = /* @__PURE__ */ markRaw({
    actions: {},
    getters: {},
    state: [],
    hotState
  });
  const partialStore = {
    _p: pinia2,
    // _s: scope,
    $id,
    $onAction: addSubscription.bind(null, actionSubscriptions),
    $patch,
    $reset,
    $subscribe(callback, options22 = {}) {
      const removeSubscription = addSubscription(subscriptions, callback, options22.detached, () => stopWatcher());
      const stopWatcher = scope.run(() => watch(() => pinia2.state.value[$id], (state) => {
        if (options22.flush === "sync" ? isSyncListening : isListening) {
          callback({
            storeId: $id,
            type: MutationType.direct,
            events: debuggerEvents
          }, state);
        }
      }, assign$6({}, $subscribeOptions, options22)));
      return removeSubscription;
    },
    $dispose
  };
  if (isVue2$2) {
    partialStore._r = false;
  }
  const store = reactive(false ? assign$6(
    {
      _hmrPayload,
      _customProperties: markRaw(/* @__PURE__ */ new Set())
      // devtools custom properties
    },
    partialStore
    // must be added later
    // setupStore
  ) : partialStore);
  pinia2._s.set($id, store);
  const runWithContext = pinia2._a && pinia2._a.runWithContext || fallbackRunWithContext;
  const setupStore = runWithContext(() => pinia2._e.run(() => (scope = effectScope()).run(() => setup3({ action }))));
  for (const key in setupStore) {
    const prop2 = setupStore[key];
    if (isRef(prop2) && !isComputed(prop2) || isReactive(prop2)) {
      if (false) {
        set$3(hotState.value, key, toRef$1(setupStore, key));
      } else if (!isOptionsStore) {
        if (initialState && shouldHydrate(prop2)) {
          if (isRef(prop2)) {
            prop2.value = initialState[key];
          } else {
            mergeReactiveObjects(prop2, initialState[key]);
          }
        }
        if (isVue2$2) {
          set$3(pinia2.state.value[$id], key, prop2);
        } else {
          pinia2.state.value[$id][key] = prop2;
        }
      }
      if (false) {
        _hmrPayload.state.push(key);
      }
    } else if (typeof prop2 === "function") {
      const actionValue = false ? prop2 : action(prop2, key);
      if (isVue2$2) {
        set$3(setupStore, key, actionValue);
      } else {
        setupStore[key] = actionValue;
      }
      if (false) {
        _hmrPayload.actions[key] = prop2;
      }
      optionsForPlugin.actions[key] = prop2;
    } else if (false) {
      if (isComputed(prop2)) {
        _hmrPayload.getters[key] = isOptionsStore ? (
          // @ts-expect-error
          options5.getters[key]
        ) : prop2;
        if (IS_CLIENT) {
          const getters = setupStore._getters || // @ts-expect-error: same
          (setupStore._getters = markRaw([]));
          getters.push(key);
        }
      }
    }
  }
  if (isVue2$2) {
    Object.keys(setupStore).forEach((key) => {
      set$3(store, key, setupStore[key]);
    });
  } else {
    assign$6(store, setupStore);
    assign$6(toRaw(store), setupStore);
  }
  Object.defineProperty(store, "$state", {
    get: /* @__PURE__ */ __name(() => false ? hotState.value : pinia2.state.value[$id], "get"),
    set: /* @__PURE__ */ __name((state) => {
      if (false) {
        throw new Error("cannot set hotState");
      }
      $patch(($state) => {
        assign$6($state, state);
      });
    }, "set")
  });
  if (false) {
    store._hotUpdate = markRaw((newStore) => {
      store._hotUpdating = true;
      newStore._hmrPayload.state.forEach((stateKey) => {
        if (stateKey in store.$state) {
          const newStateTarget = newStore.$state[stateKey];
          const oldStateSource = store.$state[stateKey];
          if (typeof newStateTarget === "object" && isPlainObject$3(newStateTarget) && isPlainObject$3(oldStateSource)) {
            patchObject(newStateTarget, oldStateSource);
          } else {
            newStore.$state[stateKey] = oldStateSource;
          }
        }
        set$3(store, stateKey, toRef$1(newStore.$state, stateKey));
      });
      Object.keys(store.$state).forEach((stateKey) => {
        if (!(stateKey in newStore.$state)) {
          del$3(store, stateKey);
        }
      });
      isListening = false;
      isSyncListening = false;
      pinia2.state.value[$id] = toRef$1(newStore._hmrPayload, "hotState");
      isSyncListening = true;
      nextTick().then(() => {
        isListening = true;
      });
      for (const actionName in newStore._hmrPayload.actions) {
        const actionFn = newStore[actionName];
        set$3(store, actionName, action(actionFn, actionName));
      }
      for (const getterName in newStore._hmrPayload.getters) {
        const getter = newStore._hmrPayload.getters[getterName];
        const getterValue = isOptionsStore ? (
          // special handling of options api
          computed(() => {
            setActivePinia(pinia2);
            return getter.call(store, store);
          })
        ) : getter;
        set$3(store, getterName, getterValue);
      }
      Object.keys(store._hmrPayload.getters).forEach((key) => {
        if (!(key in newStore._hmrPayload.getters)) {
          del$3(store, key);
        }
      });
      Object.keys(store._hmrPayload.actions).forEach((key) => {
        if (!(key in newStore._hmrPayload.actions)) {
          del$3(store, key);
        }
      });
      store._hmrPayload = newStore._hmrPayload;
      store._getters = newStore._getters;
      store._hotUpdating = false;
    });
  }
  if (false) {
    const nonEnumerable = {
      writable: true,
      configurable: true,
      // avoid warning on devtools trying to display this property
      enumerable: false
    };
    ["_p", "_hmrPayload", "_getters", "_customProperties"].forEach((p2) => {
      Object.defineProperty(store, p2, assign$6({ value: store[p2] }, nonEnumerable));
    });
  }
  if (isVue2$2) {
    store._r = true;
  }
  pinia2._p.forEach((extender) => {
    if (false) {
      const extensions = scope.run(() => extender({
        store,
        app: pinia2._a,
        pinia: pinia2,
        options: optionsForPlugin
      }));
      Object.keys(extensions || {}).forEach((key) => store._customProperties.add(key));
      assign$6(store, extensions);
    } else {
      assign$6(store, scope.run(() => extender({
        store,
        app: pinia2._a,
        pinia: pinia2,
        options: optionsForPlugin
      })));
    }
  });
  if (false) {
    console.warn(`[🍍]: The "state" must be a plain object. It cannot be
	state: () => new MyClass()
Found in store "${store.$id}".`);
  }
  if (initialState && isOptionsStore && options5.hydrate) {
    options5.hydrate(store.$state, initialState);
  }
  isListening = true;
  isSyncListening = true;
  return store;
}
__name(createSetupStore, "createSetupStore");
// @__NO_SIDE_EFFECTS__
function defineStore(idOrOptions, setup3, setupOptions) {
  let id4;
  let options5;
  const isSetupStore = typeof setup3 === "function";
  if (typeof idOrOptions === "string") {
    id4 = idOrOptions;
    options5 = isSetupStore ? setupOptions : setup3;
  } else {
    options5 = idOrOptions;
    id4 = idOrOptions.id;
    if (false) {
      throw new Error(`[🍍]: "defineStore()" must be passed a store id as its first argument.`);
    }
  }
  function useStore(pinia2, hot) {
    const hasContext = hasInjectionContext();
    pinia2 = // in test mode, ignore the argument provided as we can always retrieve a
    // pinia instance with getActivePinia()
    (false ? null : pinia2) || (hasContext ? inject(piniaSymbol, null) : null);
    if (pinia2)
      setActivePinia(pinia2);
    if (false) {
      throw new Error(`[🍍]: "getActivePinia()" was called but there was no active Pinia. Are you trying to use a store before calling "app.use(pinia)"?
See https://pinia.vuejs.org/core-concepts/outside-component-usage.html for help.
This will fail in production.`);
    }
    pinia2 = activePinia;
    if (!pinia2._s.has(id4)) {
      if (isSetupStore) {
        createSetupStore(id4, setup3, options5, pinia2);
      } else {
        createOptionsStore(id4, options5, pinia2);
      }
      if (false) {
        useStore._pinia = pinia2;
      }
    }
    const store = pinia2._s.get(id4);
    if (false) {
      const hotId = "__hot:" + id4;
      const newStore = isSetupStore ? createSetupStore(hotId, setup3, options5, pinia2, true) : createOptionsStore(hotId, assign$6({}, options5), pinia2, true);
      hot._hotUpdate(newStore);
      delete pinia2.state.value[hotId];
      pinia2._s.delete(hotId);
    }
    if (false) {
      const currentInstance2 = getCurrentInstance();
      if (currentInstance2 && currentInstance2.proxy && // avoid adding stores that are just built for hot module replacement
      !hot) {
        const vm = currentInstance2.proxy;
        const cache2 = "_pStores" in vm ? vm._pStores : vm._pStores = {};
        cache2[id4] = store;
      }
    }
    return store;
  }
  __name(useStore, "useStore");
  useStore.$id = id4;
  return useStore;
}
__name(defineStore, "defineStore");
let mapStoreSuffix = "Store";
function setMapStoreSuffix(suffix2) {
  mapStoreSuffix = suffix2;
}
__name(setMapStoreSuffix, "setMapStoreSuffix");
function mapStores(...stores) {
  if (false) {
    console.warn(`[🍍]: Directly pass all stores to "mapStores()" without putting them in an array:
Replace
	mapStores([useAuthStore, useCartStore])
with
	mapStores(useAuthStore, useCartStore)
This will fail in production if not fixed.`);
    stores = stores[0];
  }
  return stores.reduce((reduced, useStore) => {
    reduced[useStore.$id + mapStoreSuffix] = function() {
      return useStore(this.$pinia);
    };
    return reduced;
  }, {});
}
__name(mapStores, "mapStores");
function mapState(useStore, keysOrMapper) {
  return Array.isArray(keysOrMapper) ? keysOrMapper.reduce((reduced, key) => {
    reduced[key] = function() {
      return useStore(this.$pinia)[key];
    };
    return reduced;
  }, {}) : Object.keys(keysOrMapper).reduce((reduced, key) => {
    reduced[key] = function() {
      const store = useStore(this.$pinia);
      const storeKey = keysOrMapper[key];
      return typeof storeKey === "function" ? storeKey.call(this, store) : store[storeKey];
    };
    return reduced;
  }, {});
}
__name(mapState, "mapState");
const mapGetters = mapState;
function mapActions(useStore, keysOrMapper) {
  return Array.isArray(keysOrMapper) ? keysOrMapper.reduce((reduced, key) => {
    reduced[key] = function(...args) {
      return useStore(this.$pinia)[key](...args);
    };
    return reduced;
  }, {}) : Object.keys(keysOrMapper).reduce((reduced, key) => {
    reduced[key] = function(...args) {
      return useStore(this.$pinia)[keysOrMapper[key]](...args);
    };
    return reduced;
  }, {});
}
__name(mapActions, "mapActions");
function mapWritableState(useStore, keysOrMapper) {
  return Array.isArray(keysOrMapper) ? keysOrMapper.reduce((reduced, key) => {
    reduced[key] = {
      get() {
        return useStore(this.$pinia)[key];
      },
      set(value3) {
        return useStore(this.$pinia)[key] = value3;
      }
    };
    return reduced;
  }, {}) : Object.keys(keysOrMapper).reduce((reduced, key) => {
    reduced[key] = {
      get() {
        return useStore(this.$pinia)[keysOrMapper[key]];
      },
      set(value3) {
        return useStore(this.$pinia)[keysOrMapper[key]] = value3;
      }
    };
    return reduced;
  }, {});
}
__name(mapWritableState, "mapWritableState");
function storeToRefs(store) {
  if (isVue2$2) {
    return toRefs$1(store);
  } else {
    store = toRaw(store);
    const refs = {};
    for (const key in store) {
      const value3 = store[key];
      if (isRef(value3) || isReactive(value3)) {
        refs[key] = // ---
        toRef$1(store, key);
      }
    }
    return refs;
  }
}
__name(storeToRefs, "storeToRefs");
const PiniaVuePlugin = /* @__PURE__ */ __name(function(_Vue) {
  _Vue.mixin({
    beforeCreate() {
      const options5 = this.$options;
      if (options5.pinia) {
        const pinia2 = options5.pinia;
        if (!this._provided) {
          const provideCache = {};
          Object.defineProperty(this, "_provided", {
            get: /* @__PURE__ */ __name(() => provideCache, "get"),
            set: /* @__PURE__ */ __name((v2) => Object.assign(provideCache, v2), "set")
          });
        }
        this._provided[piniaSymbol] = pinia2;
        if (!this.$pinia) {
          this.$pinia = pinia2;
        }
        pinia2._a = this;
        if (IS_CLIENT) {
          setActivePinia(pinia2);
        }
        if (false) {
          registerPiniaDevtools(pinia2._a, pinia2);
        }
      } else if (!this.$pinia && options5.parent && options5.parent.$pinia) {
        this.$pinia = options5.parent.$pinia;
      }
    },
    destroyed() {
      delete this._pStores;
    }
  });
}, "PiniaVuePlugin");
function classNames$1(...args) {
  if (args) {
    let classes2 = [];
    for (let i2 = 0; i2 < args.length; i2++) {
      let className = args[i2];
      if (!className) {
        continue;
      }
      const type = typeof className;
      if (type === "string" || type === "number") {
        classes2.push(className);
      } else if (type === "object") {
        const _classes = Array.isArray(className) ? [classNames$1(...className)] : Object.entries(className).map(([key, value3]) => value3 ? key : void 0);
        classes2 = _classes.length ? classes2.concat(_classes.filter((c2) => !!c2)) : classes2;
      }
    }
    return classes2.join(" ").trim();
  }
  return void 0;
}
__name(classNames$1, "classNames$1");
function hasClass$1(element, className) {
  if (element) {
    if (element.classList) return element.classList.contains(className);
    else return new RegExp("(^| )" + className + "( |$)", "gi").test(element.className);
  }
  return false;
}
__name(hasClass$1, "hasClass$1");
function addClass$1(element, className) {
  if (element && className) {
    const fn = /* @__PURE__ */ __name((_className) => {
      if (!hasClass$1(element, _className)) {
        if (element.classList) element.classList.add(_className);
        else element.className += " " + _className;
      }
    }, "fn");
    [className].flat().filter(Boolean).forEach((_classNames) => _classNames.split(" ").forEach(fn));
  }
}
__name(addClass$1, "addClass$1");
function calculateBodyScrollbarWidth$1() {
  return window.innerWidth - document.documentElement.offsetWidth;
}
__name(calculateBodyScrollbarWidth$1, "calculateBodyScrollbarWidth$1");
function getCSSVariableByRegex$1(variableRegex) {
  for (const sheet of document == null ? void 0 : document.styleSheets) {
    try {
      for (const rule of sheet == null ? void 0 : sheet.cssRules) {
        for (const property of rule == null ? void 0 : rule.style) {
          if (variableRegex.test(property)) {
            return { name: property, value: rule.style.getPropertyValue(property).trim() };
          }
        }
      }
    } catch (e2) {
    }
  }
  return null;
}
__name(getCSSVariableByRegex$1, "getCSSVariableByRegex$1");
function blockBodyScroll$1(className = "p-overflow-hidden") {
  const variableData = getCSSVariableByRegex$1(/-scrollbar-width$/);
  (variableData == null ? void 0 : variableData.name) && document.body.style.setProperty(variableData.name, calculateBodyScrollbarWidth$1() + "px");
  addClass$1(document.body, className);
}
__name(blockBodyScroll$1, "blockBodyScroll$1");
function saveAs$1(file) {
  if (file) {
    let link2 = document.createElement("a");
    if (link2.download !== void 0) {
      const { name: name2, src } = file;
      link2.setAttribute("href", src);
      link2.setAttribute("download", name2);
      link2.style.display = "none";
      document.body.appendChild(link2);
      link2.click();
      document.body.removeChild(link2);
      return true;
    }
  }
  return false;
}
__name(saveAs$1, "saveAs$1");
function exportCSV$1(csv, filename) {
  let blob = new Blob([csv], {
    type: "application/csv;charset=utf-8;"
  });
  if (window.navigator.msSaveOrOpenBlob) {
    navigator.msSaveOrOpenBlob(blob, filename + ".csv");
  } else {
    const isDownloaded = saveAs$1({ name: filename + ".csv", src: URL.createObjectURL(blob) });
    if (!isDownloaded) {
      csv = "data:text/csv;charset=utf-8," + csv;
      window.open(encodeURI(csv));
    }
  }
}
__name(exportCSV$1, "exportCSV$1");
function removeClass$1(element, className) {
  if (element && className) {
    const fn = /* @__PURE__ */ __name((_className) => {
      if (element.classList) element.classList.remove(_className);
      else element.className = element.className.replace(new RegExp("(^|\\b)" + _className.split(" ").join("|") + "(\\b|$)", "gi"), " ");
    }, "fn");
    [className].flat().filter(Boolean).forEach((_classNames) => _classNames.split(" ").forEach(fn));
  }
}
__name(removeClass$1, "removeClass$1");
function unblockBodyScroll$1(className = "p-overflow-hidden") {
  const variableData = getCSSVariableByRegex$1(/-scrollbar-width$/);
  (variableData == null ? void 0 : variableData.name) && document.body.style.removeProperty(variableData.name);
  removeClass$1(document.body, className);
}
__name(unblockBodyScroll$1, "unblockBodyScroll$1");
function getHiddenElementDimensions$1(element) {
  let dimensions = { width: 0, height: 0 };
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    dimensions.width = element.offsetWidth;
    dimensions.height = element.offsetHeight;
    element.style.display = "none";
    element.style.visibility = "visible";
  }
  return dimensions;
}
__name(getHiddenElementDimensions$1, "getHiddenElementDimensions$1");
function getViewport$1() {
  let win = window, d2 = document, e2 = d2.documentElement, g2 = d2.getElementsByTagName("body")[0], w2 = win.innerWidth || e2.clientWidth || g2.clientWidth, h2 = win.innerHeight || e2.clientHeight || g2.clientHeight;
  return { width: w2, height: h2 };
}
__name(getViewport$1, "getViewport$1");
function getWindowScrollLeft$1() {
  let doc2 = document.documentElement;
  return (window.pageXOffset || doc2.scrollLeft) - (doc2.clientLeft || 0);
}
__name(getWindowScrollLeft$1, "getWindowScrollLeft$1");
function getWindowScrollTop$1() {
  let doc2 = document.documentElement;
  return (window.pageYOffset || doc2.scrollTop) - (doc2.clientTop || 0);
}
__name(getWindowScrollTop$1, "getWindowScrollTop$1");
function absolutePosition$1(element, target2, gutter = true) {
  var _a2, _b, _c, _d;
  if (element) {
    const elementDimensions = element.offsetParent ? { width: element.offsetWidth, height: element.offsetHeight } : getHiddenElementDimensions$1(element);
    const elementOuterHeight = elementDimensions.height;
    const elementOuterWidth = elementDimensions.width;
    const targetOuterHeight = target2.offsetHeight;
    const targetOuterWidth = target2.offsetWidth;
    const targetOffset = target2.getBoundingClientRect();
    const windowScrollTop = getWindowScrollTop$1();
    const windowScrollLeft = getWindowScrollLeft$1();
    const viewport = getViewport$1();
    let top, left, origin2 = "top";
    if (targetOffset.top + targetOuterHeight + elementOuterHeight > viewport.height) {
      top = targetOffset.top + windowScrollTop - elementOuterHeight;
      origin2 = "bottom";
      if (top < 0) {
        top = windowScrollTop;
      }
    } else {
      top = targetOuterHeight + targetOffset.top + windowScrollTop;
    }
    if (targetOffset.left + elementOuterWidth > viewport.width) left = Math.max(0, targetOffset.left + windowScrollLeft + targetOuterWidth - elementOuterWidth);
    else left = targetOffset.left + windowScrollLeft;
    element.style.top = top + "px";
    element.style.left = left + "px";
    element.style.transformOrigin = origin2;
    gutter && (element.style.marginTop = origin2 === "bottom" ? `calc(${(_b = (_a2 = getCSSVariableByRegex$1(/-anchor-gutter$/)) == null ? void 0 : _a2.value) != null ? _b : "2px"} * -1)` : (_d = (_c = getCSSVariableByRegex$1(/-anchor-gutter$/)) == null ? void 0 : _c.value) != null ? _d : "");
  }
}
__name(absolutePosition$1, "absolutePosition$1");
function addStyle$1(element, style2) {
  if (element) {
    if (typeof style2 === "string") {
      element.style.cssText = style2;
    } else {
      Object.entries(style2 || {}).forEach(([key, value3]) => element.style[key] = value3);
    }
  }
}
__name(addStyle$1, "addStyle$1");
function getOuterWidth$1(element, margin) {
  if (element instanceof HTMLElement) {
    let width2 = element.offsetWidth;
    if (margin) {
      let style2 = getComputedStyle(element);
      width2 += parseFloat(style2.marginLeft) + parseFloat(style2.marginRight);
    }
    return width2;
  }
  return 0;
}
__name(getOuterWidth$1, "getOuterWidth$1");
function relativePosition$1(element, target2, gutter = true) {
  var _a2, _b, _c, _d;
  if (element) {
    const elementDimensions = element.offsetParent ? { width: element.offsetWidth, height: element.offsetHeight } : getHiddenElementDimensions$1(element);
    const targetHeight = target2.offsetHeight;
    const targetOffset = target2.getBoundingClientRect();
    const viewport = getViewport$1();
    let top, left, origin2 = "top";
    if (targetOffset.top + targetHeight + elementDimensions.height > viewport.height) {
      top = -1 * elementDimensions.height;
      origin2 = "bottom";
      if (targetOffset.top + top < 0) {
        top = -1 * targetOffset.top;
      }
    } else {
      top = targetHeight;
    }
    if (elementDimensions.width > viewport.width) {
      left = targetOffset.left * -1;
    } else if (targetOffset.left + elementDimensions.width > viewport.width) {
      left = (targetOffset.left + elementDimensions.width - viewport.width) * -1;
    } else {
      left = 0;
    }
    element.style.top = top + "px";
    element.style.left = left + "px";
    element.style.transformOrigin = origin2;
    gutter && (element.style.marginTop = origin2 === "bottom" ? `calc(${(_b = (_a2 = getCSSVariableByRegex$1(/-anchor-gutter$/)) == null ? void 0 : _a2.value) != null ? _b : "2px"} * -1)` : (_d = (_c = getCSSVariableByRegex$1(/-anchor-gutter$/)) == null ? void 0 : _c.value) != null ? _d : "");
  }
}
__name(relativePosition$1, "relativePosition$1");
function alignOverlay$1(overlay, target2, appendTo2, calculateMinWidth = true) {
  if (overlay && target2) {
    if (appendTo2 === "self") {
      relativePosition$1(overlay, target2);
    } else {
      calculateMinWidth && (overlay.style.minWidth = getOuterWidth$1(target2) + "px");
      absolutePosition$1(overlay, target2);
    }
  }
}
__name(alignOverlay$1, "alignOverlay$1");
function isElement$1(element) {
  return typeof HTMLElement === "object" ? element instanceof HTMLElement : element && typeof element === "object" && element !== null && element.nodeType === 1 && typeof element.nodeName === "string";
}
__name(isElement$1, "isElement$1");
function toElement$1(element) {
  let target2 = element;
  if (element && typeof element === "object") {
    if (element.hasOwnProperty("current")) {
      target2 = element.current;
    } else if (element.hasOwnProperty("el")) {
      if (element.el.hasOwnProperty("nativeElement")) {
        target2 = element.el.nativeElement;
      } else {
        target2 = element.el;
      }
    }
  }
  return isElement$1(target2) ? target2 : void 0;
}
__name(toElement$1, "toElement$1");
function appendChild$1(element, child) {
  const target2 = toElement$1(element);
  if (target2) target2.appendChild(child);
  else throw new Error("Cannot append " + child + " to " + element);
}
__name(appendChild$1, "appendChild$1");
var calculatedScrollbarHeight$1 = void 0;
function calculateScrollbarHeight$1(element) {
  if (element) {
    let style2 = getComputedStyle(element);
    return element.offsetHeight - element.clientHeight - parseFloat(style2.borderTopWidth) - parseFloat(style2.borderBottomWidth);
  } else {
    if (calculatedScrollbarHeight$1 != null) return calculatedScrollbarHeight$1;
    let scrollDiv = document.createElement("div");
    addStyle$1(scrollDiv, {
      width: "100px",
      height: "100px",
      overflow: "scroll",
      position: "absolute",
      top: "-9999px"
    });
    document.body.appendChild(scrollDiv);
    let scrollbarHeight = scrollDiv.offsetHeight - scrollDiv.clientHeight;
    document.body.removeChild(scrollDiv);
    calculatedScrollbarHeight$1 = scrollbarHeight;
    return scrollbarHeight;
  }
}
__name(calculateScrollbarHeight$1, "calculateScrollbarHeight$1");
var calculatedScrollbarWidth$1 = void 0;
function calculateScrollbarWidth$1(element) {
  if (element) {
    let style2 = getComputedStyle(element);
    return element.offsetWidth - element.clientWidth - parseFloat(style2.borderLeftWidth) - parseFloat(style2.borderRightWidth);
  } else {
    if (calculatedScrollbarWidth$1 != null) return calculatedScrollbarWidth$1;
    let scrollDiv = document.createElement("div");
    addStyle$1(scrollDiv, {
      width: "100px",
      height: "100px",
      overflow: "scroll",
      position: "absolute",
      top: "-9999px"
    });
    document.body.appendChild(scrollDiv);
    let scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
    document.body.removeChild(scrollDiv);
    calculatedScrollbarWidth$1 = scrollbarWidth;
    return scrollbarWidth;
  }
}
__name(calculateScrollbarWidth$1, "calculateScrollbarWidth$1");
function clearSelection$1() {
  if (window.getSelection) {
    const selection = window.getSelection() || {};
    if (selection.empty) {
      selection.empty();
    } else if (selection.removeAllRanges && selection.rangeCount > 0 && selection.getRangeAt(0).getClientRects().length > 0) {
      selection.removeAllRanges();
    }
  }
}
__name(clearSelection$1, "clearSelection$1");
function setAttributes$1(element, attributes = {}) {
  if (isElement$1(element)) {
    const computedStyles = /* @__PURE__ */ __name((rule, value3) => {
      var _a2, _b;
      const styles = ((_a2 = element == null ? void 0 : element.$attrs) == null ? void 0 : _a2[rule]) ? [(_b = element == null ? void 0 : element.$attrs) == null ? void 0 : _b[rule]] : [];
      return [value3].flat().reduce((cv, v2) => {
        if (v2 !== null && v2 !== void 0) {
          const type = typeof v2;
          if (type === "string" || type === "number") {
            cv.push(v2);
          } else if (type === "object") {
            const _cv = Array.isArray(v2) ? computedStyles(rule, v2) : Object.entries(v2).map(([_k, _v]) => rule === "style" && (!!_v || _v === 0) ? `${_k.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase()}:${_v}` : !!_v ? _k : void 0);
            cv = _cv.length ? cv.concat(_cv.filter((c2) => !!c2)) : cv;
          }
        }
        return cv;
      }, styles);
    }, "computedStyles");
    Object.entries(attributes).forEach(([key, value3]) => {
      if (value3 !== void 0 && value3 !== null) {
        const matchedEvent = key.match(/^on(.+)/);
        if (matchedEvent) {
          element.addEventListener(matchedEvent[1].toLowerCase(), value3);
        } else if (key === "p-bind" || key === "pBind") {
          setAttributes$1(element, value3);
        } else {
          value3 = key === "class" ? [...new Set(computedStyles("class", value3))].join(" ").trim() : key === "style" ? computedStyles("style", value3).join(";").trim() : value3;
          (element.$attrs = element.$attrs || {}) && (element.$attrs[key] = value3);
          element.setAttribute(key, value3);
        }
      }
    });
  }
}
__name(setAttributes$1, "setAttributes$1");
function createElement$1(type, attributes = {}, ...children) {
  if (type) {
    const element = document.createElement(type);
    setAttributes$1(element, attributes);
    element.append(...children);
    return element;
  }
  return void 0;
}
__name(createElement$1, "createElement$1");
function createStyleAsString$1(css4, options5 = {}) {
  return css4 ? `'<style ${Object.entries(options5).reduce((s2, [k2, v2]) => s2 + `${k2}="${v2}"`, " ")}>${css4}</style>'` : "";
}
__name(createStyleAsString$1, "createStyleAsString$1");
function createStyleTag$2(attributes = {}, container) {
  let element = document.createElement("style");
  setAttributes$1(element, attributes);
  if (!container) {
    container = document.head;
  }
  container.appendChild(element);
  return element;
}
__name(createStyleTag$2, "createStyleTag$2");
function fadeIn$1(element, duration) {
  if (element) {
    element.style.opacity = "0";
    let last = +/* @__PURE__ */ new Date();
    let opacity = "0";
    let tick = /* @__PURE__ */ __name(function() {
      opacity = `${+element.style.opacity + ((/* @__PURE__ */ new Date()).getTime() - last) / duration}`;
      element.style.opacity = opacity;
      last = +/* @__PURE__ */ new Date();
      if (+opacity < 1) {
        !!window.requestAnimationFrame && requestAnimationFrame(tick) || setTimeout(tick, 16);
      }
    }, "tick");
    tick();
  }
}
__name(fadeIn$1, "fadeIn$1");
function fadeOut$1(element, duration) {
  if (element) {
    let opacity = 1, interval = 50, gap = interval / duration;
    let fading = setInterval(() => {
      opacity -= gap;
      if (opacity <= 0) {
        opacity = 0;
        clearInterval(fading);
      }
      element.style.opacity = opacity.toString();
    }, interval);
  }
}
__name(fadeOut$1, "fadeOut$1");
function find$2(element, selector) {
  return isElement$1(element) ? Array.from(element.querySelectorAll(selector)) : [];
}
__name(find$2, "find$2");
function findSingle$1(element, selector) {
  return isElement$1(element) ? element.matches(selector) ? element : element.querySelector(selector) : null;
}
__name(findSingle$1, "findSingle$1");
function focus$2(element, options5) {
  element && document.activeElement !== element && element.focus(options5);
}
__name(focus$2, "focus$2");
function getAttribute$1(element, name2) {
  if (isElement$1(element)) {
    const value3 = element.getAttribute(name2);
    if (!isNaN(value3)) {
      return +value3;
    }
    if (value3 === "true" || value3 === "false") {
      return value3 === "true";
    }
    return value3;
  }
  return void 0;
}
__name(getAttribute$1, "getAttribute$1");
function resolveUserAgent$1() {
  let ua = navigator.userAgent.toLowerCase();
  let match2 = /(chrome)[ ]([\w.]+)/.exec(ua) || /(webkit)[ ]([\w.]+)/.exec(ua) || /(opera)(?:.*version|)[ ]([\w.]+)/.exec(ua) || /(msie) ([\w.]+)/.exec(ua) || ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) || [];
  return {
    browser: match2[1] || "",
    version: match2[2] || "0"
  };
}
__name(resolveUserAgent$1, "resolveUserAgent$1");
var browser$1 = null;
function getBrowser$1() {
  if (!browser$1) {
    browser$1 = {};
    let matched = resolveUserAgent$1();
    if (matched.browser) {
      browser$1[matched.browser] = true;
      browser$1["version"] = matched.version;
    }
    if (browser$1["chrome"]) {
      browser$1["webkit"] = true;
    } else if (browser$1["webkit"]) {
      browser$1["safari"] = true;
    }
  }
  return browser$1;
}
__name(getBrowser$1, "getBrowser$1");
function getBrowserLanguage$1() {
  return navigator.languages && navigator.languages.length && navigator.languages[0] || navigator.language || "en";
}
__name(getBrowserLanguage$1, "getBrowserLanguage$1");
function getCSSProperty$1(element, property, inline3) {
  var _a2;
  if (element && property) {
    return inline3 ? (_a2 = element == null ? void 0 : element.style) == null ? void 0 : _a2.getPropertyValue(property) : getComputedStyle(element).getPropertyValue(property);
  }
  return null;
}
__name(getCSSProperty$1, "getCSSProperty$1");
function getCursorOffset$1(element, prevText, nextText, currentText) {
  if (element) {
    let style2 = getComputedStyle(element);
    let ghostDiv = document.createElement("div");
    ghostDiv.style.position = "absolute";
    ghostDiv.style.top = "0px";
    ghostDiv.style.left = "0px";
    ghostDiv.style.visibility = "hidden";
    ghostDiv.style.pointerEvents = "none";
    ghostDiv.style.overflow = style2.overflow;
    ghostDiv.style.width = style2.width;
    ghostDiv.style.height = style2.height;
    ghostDiv.style.padding = style2.padding;
    ghostDiv.style.border = style2.border;
    ghostDiv.style.overflowWrap = style2.overflowWrap;
    ghostDiv.style.whiteSpace = style2.whiteSpace;
    ghostDiv.style.lineHeight = style2.lineHeight;
    ghostDiv.innerHTML = prevText.replace(/\r\n|\r|\n/g, "<br />");
    let ghostSpan = document.createElement("span");
    ghostSpan.textContent = currentText;
    ghostDiv.appendChild(ghostSpan);
    let text2 = document.createTextNode(nextText);
    ghostDiv.appendChild(text2);
    document.body.appendChild(ghostDiv);
    const { offsetLeft, offsetTop, clientHeight } = ghostSpan;
    document.body.removeChild(ghostDiv);
    return {
      left: Math.abs(offsetLeft - element.scrollLeft),
      top: Math.abs(offsetTop - element.scrollTop) + clientHeight
    };
  }
  return {
    top: "auto",
    left: "auto"
  };
}
__name(getCursorOffset$1, "getCursorOffset$1");
function getFocusableElements$1(element, selector = "") {
  let focusableElements = find$2(
    element,
    `button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector}`
  );
  let visibleFocusableElements = [];
  for (let focusableElement of focusableElements) {
    if (getComputedStyle(focusableElement).display != "none" && getComputedStyle(focusableElement).visibility != "hidden") visibleFocusableElements.push(focusableElement);
  }
  return visibleFocusableElements;
}
__name(getFocusableElements$1, "getFocusableElements$1");
function getFirstFocusableElement$1(element, selector) {
  const focusableElements = getFocusableElements$1(element, selector);
  return focusableElements.length > 0 ? focusableElements[0] : null;
}
__name(getFirstFocusableElement$1, "getFirstFocusableElement$1");
function getHeight$1(element) {
  if (element) {
    let height = element.offsetHeight;
    let style2 = getComputedStyle(element);
    height -= parseFloat(style2.paddingTop) + parseFloat(style2.paddingBottom) + parseFloat(style2.borderTopWidth) + parseFloat(style2.borderBottomWidth);
    return height;
  }
  return 0;
}
__name(getHeight$1, "getHeight$1");
function getHiddenElementOuterHeight$1(element) {
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    let elementHeight = element.offsetHeight;
    element.style.display = "none";
    element.style.visibility = "visible";
    return elementHeight;
  }
  return 0;
}
__name(getHiddenElementOuterHeight$1, "getHiddenElementOuterHeight$1");
function getHiddenElementOuterWidth$1(element) {
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    let elementWidth = element.offsetWidth;
    element.style.display = "none";
    element.style.visibility = "visible";
    return elementWidth;
  }
  return 0;
}
__name(getHiddenElementOuterWidth$1, "getHiddenElementOuterWidth$1");
function getParentNode$1(element) {
  if (element) {
    let parent = element.parentNode;
    if (parent && parent instanceof ShadowRoot && parent.host) {
      parent = parent.host;
    }
    return parent;
  }
  return null;
}
__name(getParentNode$1, "getParentNode$1");
function getIndex$1(element) {
  var _a2;
  if (element) {
    let children = (_a2 = getParentNode$1(element)) == null ? void 0 : _a2.childNodes;
    let num = 0;
    if (children) {
      for (let i2 = 0; i2 < children.length; i2++) {
        if (children[i2] === element) return num;
        if (children[i2].nodeType === 1) num++;
      }
    }
  }
  return -1;
}
__name(getIndex$1, "getIndex$1");
function getInnerWidth$1(element) {
  if (element) {
    let width2 = element.offsetWidth;
    let style2 = getComputedStyle(element);
    width2 -= parseFloat(style2.borderLeft) + parseFloat(style2.borderRight);
    return width2;
  }
  return 0;
}
__name(getInnerWidth$1, "getInnerWidth$1");
function getLastFocusableElement$1(element, selector) {
  const focusableElements = getFocusableElements$1(element, selector);
  return focusableElements.length > 0 ? focusableElements[focusableElements.length - 1] : null;
}
__name(getLastFocusableElement$1, "getLastFocusableElement$1");
function getNextElementSibling$1(element, selector) {
  let nextElement = element.nextElementSibling;
  while (nextElement) {
    if (nextElement.matches(selector)) {
      return nextElement;
    } else {
      nextElement = nextElement.nextElementSibling;
    }
  }
  return null;
}
__name(getNextElementSibling$1, "getNextElementSibling$1");
function getNextFocusableElement$1(container, element, selector) {
  const focusableElements = getFocusableElements$1(container, selector);
  const index2 = focusableElements.length > 0 ? focusableElements.findIndex((el) => el === element) : -1;
  const nextIndex = index2 > -1 && focusableElements.length >= index2 + 1 ? index2 + 1 : -1;
  return nextIndex > -1 ? focusableElements[nextIndex] : null;
}
__name(getNextFocusableElement$1, "getNextFocusableElement$1");
function getOffset$1(element) {
  if (element) {
    let rect = element.getBoundingClientRect();
    return {
      top: rect.top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0),
      left: rect.left + (window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft || 0)
    };
  }
  return {
    top: "auto",
    left: "auto"
  };
}
__name(getOffset$1, "getOffset$1");
function getOuterHeight$1(element, margin) {
  if (element) {
    let height = element.offsetHeight;
    if (margin) {
      let style2 = getComputedStyle(element);
      height += parseFloat(style2.marginTop) + parseFloat(style2.marginBottom);
    }
    return height;
  }
  return 0;
}
__name(getOuterHeight$1, "getOuterHeight$1");
function getParents$1(element, parents = []) {
  const parent = getParentNode$1(element);
  return parent === null ? parents : getParents$1(parent, parents.concat([parent]));
}
__name(getParents$1, "getParents$1");
function getPreviousElementSibling$1(element, selector) {
  let previousElement = element.previousElementSibling;
  while (previousElement) {
    if (previousElement.matches(selector)) {
      return previousElement;
    } else {
      previousElement = previousElement.previousElementSibling;
    }
  }
  return null;
}
__name(getPreviousElementSibling$1, "getPreviousElementSibling$1");
function getScrollableParents$1(element) {
  let scrollableParents = [];
  if (element) {
    let parents = getParents$1(element);
    const overflowRegex = /(auto|scroll)/;
    const overflowCheck = /* @__PURE__ */ __name((node3) => {
      try {
        let styleDeclaration = window["getComputedStyle"](node3, null);
        return overflowRegex.test(styleDeclaration.getPropertyValue("overflow")) || overflowRegex.test(styleDeclaration.getPropertyValue("overflowX")) || overflowRegex.test(styleDeclaration.getPropertyValue("overflowY"));
      } catch (err) {
        return false;
      }
    }, "overflowCheck");
    for (let parent of parents) {
      let scrollSelectors = parent.nodeType === 1 && parent.dataset["scrollselectors"];
      if (scrollSelectors) {
        let selectors = scrollSelectors.split(",");
        for (let selector of selectors) {
          let el = findSingle$1(parent, selector);
          if (el && overflowCheck(el)) {
            scrollableParents.push(el);
          }
        }
      }
      if (parent.nodeType !== 9 && overflowCheck(parent)) {
        scrollableParents.push(parent);
      }
    }
  }
  return scrollableParents;
}
__name(getScrollableParents$1, "getScrollableParents$1");
function getSelection$2() {
  if (window.getSelection) return window.getSelection().toString();
  else if (document.getSelection) return document.getSelection().toString();
  return void 0;
}
__name(getSelection$2, "getSelection$2");
function isExist$1(element) {
  return !!(element !== null && typeof element !== "undefined" && element.nodeName && getParentNode$1(element));
}
__name(isExist$1, "isExist$1");
function getTargetElement$1(target2, currentElement) {
  var _a2;
  if (!target2) return void 0;
  switch (target2) {
    case "document":
      return document;
    case "window":
      return window;
    case "body":
      return document.body;
    case "@next":
      return currentElement == null ? void 0 : currentElement.nextElementSibling;
    case "@prev":
      return currentElement == null ? void 0 : currentElement.previousElementSibling;
    case "@parent":
      return currentElement == null ? void 0 : currentElement.parentElement;
    case "@grandparent":
      return (_a2 = currentElement == null ? void 0 : currentElement.parentElement) == null ? void 0 : _a2.parentElement;
    default:
      if (typeof target2 === "string") {
        return document.querySelector(target2);
      }
      const isFunction2 = /* @__PURE__ */ __name((obj) => !!(obj && obj.constructor && obj.call && obj.apply), "isFunction");
      const element = toElement$1(isFunction2(target2) ? target2() : target2);
      return (element == null ? void 0 : element.nodeType) === 9 || isExist$1(element) ? element : void 0;
  }
}
__name(getTargetElement$1, "getTargetElement$1");
function getUserAgent$1() {
  return navigator.userAgent;
}
__name(getUserAgent$1, "getUserAgent$1");
function getWidth$1(element) {
  if (element) {
    let width2 = element.offsetWidth;
    let style2 = getComputedStyle(element);
    width2 -= parseFloat(style2.paddingLeft) + parseFloat(style2.paddingRight) + parseFloat(style2.borderLeftWidth) + parseFloat(style2.borderRightWidth);
    return width2;
  }
  return 0;
}
__name(getWidth$1, "getWidth$1");
function hasCSSAnimation$1(element) {
  if (element) {
    const style2 = getComputedStyle(element);
    const animationDuration = parseFloat(style2.getPropertyValue("animation-duration") || "0");
    return animationDuration > 0;
  }
  return false;
}
__name(hasCSSAnimation$1, "hasCSSAnimation$1");
function hasCSSTransition$1(element) {
  if (element) {
    const style2 = getComputedStyle(element);
    const transitionDuration = parseFloat(style2.getPropertyValue("transition-duration") || "0");
    return transitionDuration > 0;
  }
  return false;
}
__name(hasCSSTransition$1, "hasCSSTransition$1");
function invokeElementMethod$1(element, methodName, args) {
  element[methodName].apply(element, args);
}
__name(invokeElementMethod$1, "invokeElementMethod$1");
function isAndroid$3() {
  return /(android)/i.test(navigator.userAgent);
}
__name(isAndroid$3, "isAndroid$3");
function isAttributeEquals$1(element, name2, value3) {
  return isElement$1(element) ? getAttribute$1(element, name2) === value3 : false;
}
__name(isAttributeEquals$1, "isAttributeEquals$1");
function isAttributeNotEquals$1(element, name2, value3) {
  return !isAttributeEquals$1(element, name2, value3);
}
__name(isAttributeNotEquals$1, "isAttributeNotEquals$1");
function isClickable$1(element) {
  if (element) {
    const targetNode = element.nodeName;
    const parentNode2 = element.parentElement && element.parentElement.nodeName;
    return targetNode === "INPUT" || targetNode === "TEXTAREA" || targetNode === "BUTTON" || targetNode === "A" || parentNode2 === "INPUT" || parentNode2 === "TEXTAREA" || parentNode2 === "BUTTON" || parentNode2 === "A" || !!element.closest(".p-button, .p-checkbox, .p-radiobutton");
  }
  return false;
}
__name(isClickable$1, "isClickable$1");
function isClient$2() {
  return !!(typeof window !== "undefined" && window.document && window.document.createElement);
}
__name(isClient$2, "isClient$2");
function isFocusableElement$1(element, selector = "") {
  return isElement$1(element) ? element.matches(`button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector}`) : false;
}
__name(isFocusableElement$1, "isFocusableElement$1");
function isVisible$1(element) {
  return !!(element && element.offsetParent != null);
}
__name(isVisible$1, "isVisible$1");
function isHidden$1(element) {
  return !isVisible$1(element);
}
__name(isHidden$1, "isHidden$1");
function isIOS$2() {
  return /iPad|iPhone|iPod/.test(navigator.userAgent) && !window["MSStream"];
}
__name(isIOS$2, "isIOS$2");
function isRTL$1(element) {
  return element ? getComputedStyle(element).direction === "rtl" : false;
}
__name(isRTL$1, "isRTL$1");
function isServer$1() {
  return !isClient$2();
}
__name(isServer$1, "isServer$1");
function isTouchDevice$1() {
  return "ontouchstart" in window || navigator.maxTouchPoints > 0 || navigator.msMaxTouchPoints > 0;
}
__name(isTouchDevice$1, "isTouchDevice$1");
function nestedPosition$1(element, level) {
  var _a2, _b;
  if (element) {
    const parentItem = element.parentElement;
    const elementOffset = getOffset$1(parentItem);
    const viewport = getViewport$1();
    const sublistWidth = element.offsetParent ? element.offsetWidth : getHiddenElementOuterWidth$1(element);
    const sublistHeight = element.offsetParent ? element.offsetHeight : getHiddenElementOuterHeight$1(element);
    const itemOuterWidth = getOuterWidth$1((_a2 = parentItem == null ? void 0 : parentItem.children) == null ? void 0 : _a2[0]);
    const itemOuterHeight = getOuterHeight$1((_b = parentItem == null ? void 0 : parentItem.children) == null ? void 0 : _b[0]);
    let left = "";
    let top = "";
    if (elementOffset.left + itemOuterWidth + sublistWidth > viewport.width - calculateScrollbarWidth$1()) {
      if (elementOffset.left < sublistWidth) {
        if (level % 2 === 1) {
          left = elementOffset.left ? "-" + elementOffset.left + "px" : "100%";
        } else if (level % 2 === 0) {
          left = viewport.width - sublistWidth - calculateScrollbarWidth$1() + "px";
        }
      } else {
        left = "-100%";
      }
    } else {
      left = "100%";
    }
    if (element.getBoundingClientRect().top + itemOuterHeight + sublistHeight > viewport.height) {
      top = `-${sublistHeight - itemOuterHeight}px`;
    } else {
      top = "0px";
    }
    element.style.top = top;
    element.style.left = left;
  }
}
__name(nestedPosition$1, "nestedPosition$1");
function remove$1(element) {
  var _a2;
  if (element) {
    if (!("remove" in Element.prototype)) (_a2 = element.parentNode) == null ? void 0 : _a2.removeChild(element);
    else element.remove();
  }
}
__name(remove$1, "remove$1");
function removeChild$1(element, child) {
  const target2 = toElement$1(element);
  if (target2) target2.removeChild(child);
  else throw new Error("Cannot remove " + child + " from " + element);
}
__name(removeChild$1, "removeChild$1");
function removeStyleTag$1(element) {
  var _a2;
  if (isExist$1(element)) {
    try {
      (_a2 = element.parentNode) == null ? void 0 : _a2.removeChild(element);
    } catch (error2) {
    }
    return null;
  }
  return element;
}
__name(removeStyleTag$1, "removeStyleTag$1");
function scrollInView$1(container, item3) {
  let borderTopValue = getComputedStyle(container).getPropertyValue("borderTopWidth");
  let borderTop = borderTopValue ? parseFloat(borderTopValue) : 0;
  let paddingTopValue = getComputedStyle(container).getPropertyValue("paddingTop");
  let paddingTop = paddingTopValue ? parseFloat(paddingTopValue) : 0;
  let containerRect = container.getBoundingClientRect();
  let itemRect = item3.getBoundingClientRect();
  let offset = itemRect.top + document.body.scrollTop - (containerRect.top + document.body.scrollTop) - borderTop - paddingTop;
  let scroll = container.scrollTop;
  let elementHeight = container.clientHeight;
  let itemHeight = getOuterHeight$1(item3);
  if (offset < 0) {
    container.scrollTop = scroll + offset;
  } else if (offset + itemHeight > elementHeight) {
    container.scrollTop = scroll + offset - elementHeight + itemHeight;
  }
}
__name(scrollInView$1, "scrollInView$1");
function setAttribute$1(element, attribute2 = "", value3) {
  if (isElement$1(element) && value3 !== null && value3 !== void 0) {
    element.setAttribute(attribute2, value3);
  }
}
__name(setAttribute$1, "setAttribute$1");
function setCSSProperty$1(element, property, value3 = null, priority) {
  var _a2;
  property && ((_a2 = element == null ? void 0 : element.style) == null ? void 0 : _a2.setProperty(property, value3, priority));
}
__name(setCSSProperty$1, "setCSSProperty$1");
var __defProp$5 = Object.defineProperty;
var __getOwnPropSymbols$4 = Object.getOwnPropertySymbols;
var __hasOwnProp$4 = Object.prototype.hasOwnProperty;
var __propIsEnum$4 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$5 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$5(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$5");
var __spreadValues$4 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$4.call(b2, prop2))
      __defNormalProp$5(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$4)
    for (var prop2 of __getOwnPropSymbols$4(b2)) {
      if (__propIsEnum$4.call(b2, prop2))
        __defNormalProp$5(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$4");
function isFunction$b(value3) {
  return !!(value3 && value3.constructor && value3.call && value3.apply);
}
__name(isFunction$b, "isFunction$b");
function mergeProps$1(...props) {
  return props == null ? void 0 : props.reduce((merged, ps = {}) => {
    for (const key in ps) {
      const value3 = ps[key];
      if (key === "style") {
        merged["style"] = __spreadValues$4(__spreadValues$4({}, merged["style"]), ps["style"]);
      } else if (key === "class") {
        merged["class"] = [merged["class"], ps["class"]].join(" ").trim() || void 0;
      } else if (key === "className") {
        merged["className"] = [merged["className"], ps["className"]].join(" ").trim() || void 0;
      } else if (isFunction$b(value3)) {
        const fn = merged[key];
        merged[key] = fn ? (...args) => {
          fn(...args);
          value3(...args);
        } : value3;
      } else {
        merged[key] = value3;
      }
    }
    return merged;
  }, {});
}
__name(mergeProps$1, "mergeProps$1");
var lastIds$1 = {};
function uuid$1(prefix2 = "pui_id_") {
  if (!lastIds$1.hasOwnProperty(prefix2)) {
    lastIds$1[prefix2] = 0;
  }
  lastIds$1[prefix2]++;
  return `${prefix2}${lastIds$1[prefix2]}`;
}
__name(uuid$1, "uuid$1");
function handler$1() {
  let zIndexes = [];
  const generateZIndex = /* @__PURE__ */ __name((key, autoZIndex, baseZIndex = 999) => {
    const lastZIndex = getLastZIndex(key, autoZIndex, baseZIndex);
    const newZIndex = lastZIndex.value + (lastZIndex.key === key ? 0 : baseZIndex) + 1;
    zIndexes.push({ key, value: newZIndex });
    return newZIndex;
  }, "generateZIndex");
  const revertZIndex = /* @__PURE__ */ __name((zIndex) => {
    zIndexes = zIndexes.filter((obj) => obj.value !== zIndex);
  }, "revertZIndex");
  const getCurrentZIndex = /* @__PURE__ */ __name((key, autoZIndex) => {
    return getLastZIndex(key, autoZIndex).value;
  }, "getCurrentZIndex");
  const getLastZIndex = /* @__PURE__ */ __name((key, autoZIndex, baseZIndex = 0) => {
    return [...zIndexes].reverse().find((obj) => autoZIndex ? true : obj.key === key) || { key, value: baseZIndex };
  }, "getLastZIndex");
  const getZIndex = /* @__PURE__ */ __name((element) => {
    return element ? parseInt(element.style.zIndex, 10) || 0 : 0;
  }, "getZIndex");
  return {
    get: getZIndex,
    set: /* @__PURE__ */ __name((key, element, baseZIndex) => {
      if (element) {
        element.style.zIndex = String(generateZIndex(key, true, baseZIndex));
      }
    }, "set"),
    clear: /* @__PURE__ */ __name((element) => {
      if (element) {
        revertZIndex(getZIndex(element));
        element.style.zIndex = "";
      }
    }, "clear"),
    getCurrent: /* @__PURE__ */ __name((key) => getCurrentZIndex(key, true), "getCurrent")
  };
}
__name(handler$1, "handler$1");
var ZIndex$1 = handler$1();
var FilterMatchMode = {
  STARTS_WITH: "startsWith",
  CONTAINS: "contains",
  NOT_CONTAINS: "notContains",
  ENDS_WITH: "endsWith",
  EQUALS: "equals",
  NOT_EQUALS: "notEquals",
  IN: "in",
  LESS_THAN: "lt",
  LESS_THAN_OR_EQUAL_TO: "lte",
  GREATER_THAN: "gt",
  GREATER_THAN_OR_EQUAL_TO: "gte",
  BETWEEN: "between",
  DATE_IS: "dateIs",
  DATE_IS_NOT: "dateIsNot",
  DATE_BEFORE: "dateBefore",
  DATE_AFTER: "dateAfter"
};
var FilterOperator = {
  AND: "and",
  OR: "or"
};
function _createForOfIteratorHelper$4(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$o(r2)) || e2) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F3() {
      }, "F");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
        throw r3;
      }, "e"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r3 = t2.next();
    return a2 = r3.done, r3;
  }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
    u2 = true, o2 = r3;
  }, "e"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2["return"] || t2["return"]();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper$4, "_createForOfIteratorHelper$4");
function _unsupportedIterableToArray$o(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$o(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$o(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$o, "_unsupportedIterableToArray$o");
function _arrayLikeToArray$o(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$o, "_arrayLikeToArray$o");
var FilterService = {
  filter: /* @__PURE__ */ __name(function filter2(value3, fields, filterValue, filterMatchMode, filterLocale) {
    var filteredItems = [];
    if (!value3) {
      return filteredItems;
    }
    var _iterator = _createForOfIteratorHelper$4(value3), _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done; ) {
        var item3 = _step.value;
        if (typeof item3 === "string") {
          if (this.filters[filterMatchMode](item3, filterValue, filterLocale)) {
            filteredItems.push(item3);
            continue;
          }
        } else {
          var _iterator2 = _createForOfIteratorHelper$4(fields), _step2;
          try {
            for (_iterator2.s(); !(_step2 = _iterator2.n()).done; ) {
              var field2 = _step2.value;
              var fieldValue = resolveFieldData$2(item3, field2);
              if (this.filters[filterMatchMode](fieldValue, filterValue, filterLocale)) {
                filteredItems.push(item3);
                break;
              }
            }
          } catch (err) {
            _iterator2.e(err);
          } finally {
            _iterator2.f();
          }
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return filteredItems;
  }, "filter"),
  filters: {
    startsWith: /* @__PURE__ */ __name(function startsWith(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      var filterValue = removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
      var stringValue = removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale);
      return stringValue.slice(0, filterValue.length) === filterValue;
    }, "startsWith"),
    contains: /* @__PURE__ */ __name(function contains2(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      var filterValue = removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
      var stringValue = removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale);
      return stringValue.indexOf(filterValue) !== -1;
    }, "contains"),
    notContains: /* @__PURE__ */ __name(function notContains(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      var filterValue = removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
      var stringValue = removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale);
      return stringValue.indexOf(filterValue) === -1;
    }, "notContains"),
    endsWith: /* @__PURE__ */ __name(function endsWith2(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      var filterValue = removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
      var stringValue = removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale);
      return stringValue.indexOf(filterValue, stringValue.length - filterValue.length) !== -1;
    }, "endsWith"),
    equals: /* @__PURE__ */ __name(function equals2(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() === filter4.getTime();
      else return removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale) == removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
    }, "equals"),
    notEquals: /* @__PURE__ */ __name(function notEquals(value3, filter4, filterLocale) {
      if (filter4 === void 0 || filter4 === null || filter4 === "") {
        return false;
      }
      if (value3 === void 0 || value3 === null) {
        return true;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() !== filter4.getTime();
      else return removeAccents$2(value3.toString()).toLocaleLowerCase(filterLocale) != removeAccents$2(filter4.toString()).toLocaleLowerCase(filterLocale);
    }, "notEquals"),
    "in": /* @__PURE__ */ __name(function _in(value3, filter4) {
      if (filter4 === void 0 || filter4 === null || filter4.length === 0) {
        return true;
      }
      for (var i2 = 0; i2 < filter4.length; i2++) {
        if (equals$2(value3, filter4[i2])) {
          return true;
        }
      }
      return false;
    }, "_in"),
    between: /* @__PURE__ */ __name(function between(value3, filter4) {
      if (filter4 == null || filter4[0] == null || filter4[1] == null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime) return filter4[0].getTime() <= value3.getTime() && value3.getTime() <= filter4[1].getTime();
      else return filter4[0] <= value3 && value3 <= filter4[1];
    }, "between"),
    lt: /* @__PURE__ */ __name(function lt(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() < filter4.getTime();
      else return value3 < filter4;
    }, "lt"),
    lte: /* @__PURE__ */ __name(function lte(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() <= filter4.getTime();
      else return value3 <= filter4;
    }, "lte"),
    gt: /* @__PURE__ */ __name(function gt(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() > filter4.getTime();
      else return value3 > filter4;
    }, "gt"),
    gte: /* @__PURE__ */ __name(function gte(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      if (value3.getTime && filter4.getTime) return value3.getTime() >= filter4.getTime();
      else return value3 >= filter4;
    }, "gte"),
    dateIs: /* @__PURE__ */ __name(function dateIs(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      return value3.toDateString() === filter4.toDateString();
    }, "dateIs"),
    dateIsNot: /* @__PURE__ */ __name(function dateIsNot(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      return value3.toDateString() !== filter4.toDateString();
    }, "dateIsNot"),
    dateBefore: /* @__PURE__ */ __name(function dateBefore(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      return value3.getTime() < filter4.getTime();
    }, "dateBefore"),
    dateAfter: /* @__PURE__ */ __name(function dateAfter(value3, filter4) {
      if (filter4 === void 0 || filter4 === null) {
        return true;
      }
      if (value3 === void 0 || value3 === null) {
        return false;
      }
      return value3.getTime() > filter4.getTime();
    }, "dateAfter")
  },
  register: /* @__PURE__ */ __name(function register2(rule, fn) {
    this.filters[rule] = fn;
  }, "register")
};
var PrimeIcons = {
  ALIGN_CENTER: "pi pi-align-center",
  ALIGN_JUSTIFY: "pi pi-align-justify",
  ALIGN_LEFT: "pi pi-align-left",
  ALIGN_RIGHT: "pi pi-align-right",
  AMAZON: "pi pi-amazon",
  ANDROID: "pi pi-android",
  ANGLE_DOUBLE_DOWN: "pi pi-angle-double-down",
  ANGLE_DOUBLE_LEFT: "pi pi-angle-double-left",
  ANGLE_DOUBLE_RIGHT: "pi pi-angle-double-right",
  ANGLE_DOUBLE_UP: "pi pi-angle-double-up",
  ANGLE_DOWN: "pi pi-angle-down",
  ANGLE_LEFT: "pi pi-angle-left",
  ANGLE_RIGHT: "pi pi-angle-right",
  ANGLE_UP: "pi pi-angle-up",
  APPLE: "pi pi-apple",
  ARROW_CIRCLE_DOWN: "pi pi-arrow-circle-down",
  ARROW_CIRCLE_LEFT: "pi pi-arrow-circle-left",
  ARROW_CIRCLE_RIGHT: "pi pi-arrow-circle-right",
  ARROW_CIRCLE_UP: "pi pi-arrow-circle-up",
  ARROW_DOWN: "pi pi-arrow-down",
  ARROW_DOWN_LEFT: "pi pi-arrow-down-left",
  ARROW_DOWN_RIGHT: "pi pi-arrow-down-right",
  ARROW_LEFT: "pi pi-arrow-left",
  ARROW_RIGHT: "pi pi-arrow-right",
  ARROW_RIGHT_ARROW_LEFT: "pi pi-arrow-right-arrow-left",
  ARROW_UP: "pi pi-arrow-up",
  ARROW_UP_LEFT: "pi pi-arrow-up-left",
  ARROW_UP_RIGHT: "pi pi-arrow-up-right",
  ARROWS_H: "pi pi-arrows-h",
  ARROWS_V: "pi pi-arrows-v",
  ARROWS_ALT: "pi pi-arrows-alt",
  AT: "pi pi-at",
  BACKWARD: "pi pi-backward",
  BAN: "pi pi-ban",
  BARS: "pi pi-bars",
  BELL: "pi pi-bell",
  BITCOIN: "pi pi-bitcoin",
  BOLT: "pi pi-bolt",
  BOOK: "pi pi-book",
  BOOKMARK: "pi pi-bookmark",
  BOOKMARK_FILL: "pi pi-bookmark-fill",
  BOX: "pi pi-box",
  BRIEFCASE: "pi pi-briefcase",
  BUILDING: "pi pi-building",
  CALENDAR: "pi pi-calendar",
  CALENDAR_MINUS: "pi pi-calendar-minus",
  CALENDAR_PLUS: "pi pi-calendar-plus",
  CALENDAR_TIMES: "pi pi-calendar-times",
  CALCULATOR: "pi pi-calculator",
  CAMERA: "pi pi-camera",
  CAR: "pi pi-car",
  CARET_DOWN: "pi pi-caret-down",
  CARET_LEFT: "pi pi-caret-left",
  CARET_RIGHT: "pi pi-caret-right",
  CARET_UP: "pi pi-caret-up",
  CART_PLUS: "pi pi-cart-plus",
  CHART_BAR: "pi pi-chart-bar",
  CHART_LINE: "pi pi-chart-line",
  CHART_PIE: "pi pi-chart-pie",
  CHECK: "pi pi-check",
  CHECK_CIRCLE: "pi pi-check-circle",
  CHECK_SQUARE: "pi pi-check-square",
  CHEVRON_CIRCLE_DOWN: "pi pi-chevron-circle-down",
  CHEVRON_CIRCLE_LEFT: "pi pi-chevron-circle-left",
  CHEVRON_CIRCLE_RIGHT: "pi pi-chevron-circle-right",
  CHEVRON_CIRCLE_UP: "pi pi-chevron-circle-up",
  CHEVRON_DOWN: "pi pi-chevron-down",
  CHEVRON_LEFT: "pi pi-chevron-left",
  CHEVRON_RIGHT: "pi pi-chevron-right",
  CHEVRON_UP: "pi pi-chevron-up",
  CIRCLE: "pi pi-circle",
  CIRCLE_FILL: "pi pi-circle-fill",
  CLOCK: "pi pi-clock",
  CLONE: "pi pi-clone",
  CLOUD: "pi pi-cloud",
  CLOUD_DOWNLOAD: "pi pi-cloud-download",
  CLOUD_UPLOAD: "pi pi-cloud-upload",
  CODE: "pi pi-code",
  COG: "pi pi-cog",
  COMMENT: "pi pi-comment",
  COMMENTS: "pi pi-comments",
  COMPASS: "pi pi-compass",
  COPY: "pi pi-copy",
  CREDIT_CARD: "pi pi-credit-card",
  DATABASE: "pi pi-database",
  DELETELEFT: "pi pi-delete-left",
  DESKTOP: "pi pi-desktop",
  DIRECTIONS: "pi pi-directions",
  DIRECTIONS_ALT: "pi pi-directions-alt",
  DISCORD: "pi pi-discord",
  DOLLAR: "pi pi-dollar",
  DOWNLOAD: "pi pi-download",
  EJECT: "pi pi-eject",
  ELLIPSIS_H: "pi pi-ellipsis-h",
  ELLIPSIS_V: "pi pi-ellipsis-v",
  ENVELOPE: "pi pi-envelope",
  ERASER: "pi pi-eraser",
  EURO: "pi pi-euro",
  EXCLAMATION_CIRCLE: "pi pi-exclamation-circle",
  EXCLAMATION_TRIANGLE: "pi pi-exclamation-triangle",
  EXTERNAL_LINK: "pi pi-external-link",
  EYE: "pi pi-eye",
  EYE_SLASH: "pi pi-eye-slash",
  FACEBOOK: "pi pi-facebook",
  FAST_BACKWARD: "pi pi-fast-backward",
  FAST_FORWARD: "pi pi-fast-forward",
  FILE: "pi pi-file",
  FILE_EDIT: "pi pi-file-edit",
  FILE_EXCEL: "pi pi-file-excel",
  FILE_EXPORT: "pi pi-file-export",
  FILE_IMPORT: "pi pi-file-import",
  FILE_PDF: "pi pi-file-pdf",
  FILE_WORD: "pi pi-file-word",
  FILTER: "pi pi-filter",
  FILTER_FILL: "pi pi-filter-fill",
  FILTER_SLASH: "pi pi-filter-slash",
  FLAG: "pi pi-flag",
  FLAG_FILL: "pi pi-flag-fill",
  FOLDER: "pi pi-folder",
  FOLDER_OPEN: "pi pi-folder-open",
  FORWARD: "pi pi-forward",
  GIFT: "pi pi-gift",
  GITHUB: "pi pi-github",
  GLOBE: "pi pi-globe",
  GOOGLE: "pi pi-google",
  HASHTAG: "pi pi-hashtag",
  HEART: "pi pi-heart",
  HEART_FILL: "pi pi-heart-fill",
  HISTORY: "pi pi-history",
  HOURGLASS: "pi pi-hourglass",
  HOME: "pi pi-home",
  ID_CARD: "pi pi-id-card",
  IMAGE: "pi pi-image",
  IMAGES: "pi pi-images",
  INBOX: "pi pi-inbox",
  INFO: "pi pi-info",
  INFO_CIRCLE: "pi pi-info-circle",
  INSTAGRAM: "pi pi-instagram",
  KEY: "pi pi-key",
  LANGUAGE: "pi pi-language",
  LINK: "pi pi-link",
  LINKEDIN: "pi pi-linkedin",
  LIST: "pi pi-list",
  LOCK: "pi pi-lock",
  LOCK_OPEN: "pi pi-lock-open",
  MAP: "pi pi-map",
  MAP_MARKER: "pi pi-map-marker",
  MEGAPHONE: "pi pi-megaphone",
  MICROPHONE: "pi pi-microphone",
  MICROSOFT: "pi pi-microsoft",
  MINUS: "pi pi-minus",
  MINUS_CIRCLE: "pi pi-minus-circle",
  MOBILE: "pi pi-mobile",
  MONEY_BILL: "pi pi-money-bill",
  MOON: "pi pi-moon",
  PALETTE: "pi pi-palette",
  PAPERCLIP: "pi pi-paperclip",
  PAUSE: "pi pi-pause",
  PAYPAL: "pi pi-paypal",
  PENCIL: "pi pi-pencil",
  PERCENTAGE: "pi pi-percentage",
  PHONE: "pi pi-phone",
  PLAY: "pi pi-play",
  PLUS: "pi pi-plus",
  PLUS_CIRCLE: "pi pi-plus-circle",
  POUND: "pi pi-pound",
  POWER_OFF: "pi pi-power-off",
  PRIME: "pi pi-prime",
  PRINT: "pi pi-print",
  QRCODE: "pi pi-qrcode",
  QUESTION: "pi pi-question",
  QUESTION_CIRCLE: "pi pi-question-circle",
  REDDIT: "pi pi-reddit",
  REFRESH: "pi pi-refresh",
  REPLAY: "pi pi-replay",
  REPLY: "pi pi-reply",
  SAVE: "pi pi-save",
  SEARCH: "pi pi-search",
  SEARCH_MINUS: "pi pi-search-minus",
  SEARCH_PLUS: "pi pi-search-plus",
  SEND: "pi pi-send",
  SERVER: "pi pi-server",
  SHARE_ALT: "pi pi-share-alt",
  SHIELD: "pi pi-shield",
  SHOPPING_BAG: "pi pi-shopping-bag",
  SHOPPING_CART: "pi pi-shopping-cart",
  SIGN_IN: "pi pi-sign-in",
  SIGN_OUT: "pi pi-sign-out",
  SITEMAP: "pi pi-sitemap",
  SLACK: "pi pi-slack",
  SLIDERS_H: "pi pi-sliders-h",
  SLIDERS_V: "pi pi-sliders-v",
  SORT: "pi pi-sort",
  SORT_ALPHA_DOWN: "pi pi-sort-alpha-down",
  SORT_ALPHA_DOWN_ALT: "pi pi-sort-alpha-down-alt",
  SORT_ALPHA_UP: "pi pi-sort-alpha-up",
  SORT_ALPHA_UP_ALT: "pi pi-sort-alpha-up-alt",
  SORT_ALT: "pi pi-sort-alt",
  SORT_ALT_SLASH: "pi pi-sort-alt-slash",
  SORT_AMOUNT_DOWN: "pi pi-sort-amount-down",
  SORT_AMOUNT_DOWN_ALT: "pi pi-sort-amount-down-alt",
  SORT_AMOUNT_UP: "pi pi-sort-amount-up",
  SORT_AMOUNT_UP_ALT: "pi pi-sort-amount-up-alt",
  SORT_DOWN: "pi pi-sort-down",
  SORT_NUMERIC_DOWN: "pi pi-sort-numeric-down",
  SORT_NUMERIC_DOWN_ALT: "pi pi-sort-numeric-down-alt",
  SORT_NUMERIC_UP: "pi pi-sort-numeric-up",
  SORT_NUMERIC_UP_ALT: "pi pi-sort-numeric-up-alt",
  SORT_UP: "pi pi-sort-up",
  SPINNER: "pi pi-spinner",
  STAR: "pi pi-star",
  STAR_FILL: "pi pi-star-fill",
  STEP_BACKWARD: "pi pi-step-backward",
  STEP_BACKWARD_ALT: "pi pi-step-backward-alt",
  STEP_FORWARD: "pi pi-step-forward",
  STEP_FORWARD_ALT: "pi pi-step-forward-alt",
  STOP: "pi pi-stop",
  STOPWATCH: "pi pi-stopwatch",
  STOP_CIRCLE: "pi pi-stop-circle",
  SUN: "pi pi-sun",
  SYNC: "pi pi-sync",
  TABLE: "pi pi-table",
  TABLET: "pi pi-tablet",
  TAG: "pi pi-tag",
  TAGS: "pi pi-tags",
  TELEGRAM: "pi pi-telegram",
  TH_LARGE: "pi pi-th-large",
  THUMBS_DOWN: "pi pi-thumbs-down",
  THUMBS_DOWN_FILL: "pi pi-thumbs-down-fill",
  THUMBS_UP: "pi pi-thumbs-up",
  THUMBS_UP_FILL: "pi pi-thumbs-up-fill",
  TICKET: "pi pi-ticket",
  TIMES: "pi pi-times",
  TIMES_CIRCLE: "pi pi-times-circle",
  TRASH: "pi pi-trash",
  TRUCK: "pi pi-truck",
  TWITTER: "pi pi-twitter",
  UNDO: "pi pi-undo",
  UNLOCK: "pi pi-unlock",
  UPLOAD: "pi pi-upload",
  USER: "pi pi-user",
  USER_EDIT: "pi pi-user-edit",
  USER_MINUS: "pi pi-user-minus",
  USER_PLUS: "pi pi-user-plus",
  USERS: "pi pi-users",
  VERIFIED: "pi pi-verified",
  VIDEO: "pi pi-video",
  VIMEO: "pi pi-vimeo",
  VOLUME_DOWN: "pi pi-volume-down",
  VOLUME_OFF: "pi pi-volume-off",
  VOLUME_UP: "pi pi-volume-up",
  WALLET: "pi pi-wallet",
  WHATSAPP: "pi pi-whatsapp",
  WIFI: "pi pi-wifi",
  WINDOW_MAXIMIZE: "pi pi-window-maximize",
  WINDOW_MINIMIZE: "pi pi-window-minimize",
  WRENCH: "pi pi-wrench",
  YOUTUBE: "pi pi-youtube"
};
var ToastSeverities = {
  INFO: "info",
  WARN: "warn",
  ERROR: "error",
  SUCCESS: "success"
};
function _typeof$u(o2) {
  "@babel/helpers - typeof";
  return _typeof$u = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$u(o2);
}
__name(_typeof$u, "_typeof$u");
function ownKeys$s(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$s, "ownKeys$s");
function _objectSpread$s(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$s(Object(t2), true).forEach(function(r3) {
      _defineProperty$w(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$s(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$s, "_objectSpread$s");
function _defineProperty$w(e2, r2, t2) {
  return (r2 = _toPropertyKey$t(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$w, "_defineProperty$w");
function _toPropertyKey$t(t2) {
  var i2 = _toPrimitive$t(t2, "string");
  return "symbol" == _typeof$u(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$t, "_toPropertyKey$t");
function _toPrimitive$t(t2, r2) {
  if ("object" != _typeof$u(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$u(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$t, "_toPrimitive$t");
function tryOnMounted$3(fn) {
  var sync = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
  if (getCurrentInstance()) onMounted(fn);
  else if (sync) fn();
  else nextTick(fn);
}
__name(tryOnMounted$3, "tryOnMounted$3");
var _id$2 = 0;
function useStyle$1(css4) {
  var options5 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
  var isLoaded = ref(false);
  var cssRef = ref(css4);
  var styleRef = ref(null);
  var defaultDocument2 = isClient$2() ? window.document : void 0;
  var _options$document = options5.document, document2 = _options$document === void 0 ? defaultDocument2 : _options$document, _options$immediate = options5.immediate, immediate = _options$immediate === void 0 ? true : _options$immediate, _options$manual = options5.manual, manual = _options$manual === void 0 ? false : _options$manual, _options$name = options5.name, name2 = _options$name === void 0 ? "style_".concat(++_id$2) : _options$name, _options$id = options5.id, id4 = _options$id === void 0 ? void 0 : _options$id, _options$media = options5.media, media = _options$media === void 0 ? void 0 : _options$media, _options$nonce = options5.nonce, nonce = _options$nonce === void 0 ? void 0 : _options$nonce, _options$first = options5.first, first2 = _options$first === void 0 ? false : _options$first, _options$onMounted = options5.onMounted, onStyleMounted = _options$onMounted === void 0 ? void 0 : _options$onMounted, _options$onUpdated = options5.onUpdated, onStyleUpdated = _options$onUpdated === void 0 ? void 0 : _options$onUpdated, _options$onLoad = options5.onLoad, onStyleLoaded = _options$onLoad === void 0 ? void 0 : _options$onLoad, _options$props = options5.props, props = _options$props === void 0 ? {} : _options$props;
  var stop2 = /* @__PURE__ */ __name(function stop3() {
  }, "stop");
  var load3 = /* @__PURE__ */ __name(function load4(_css) {
    var _props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (!document2) return;
    var _styleProps = _objectSpread$s(_objectSpread$s({}, props), _props);
    var _name = _styleProps.name || name2, _id2 = _styleProps.id || id4, _nonce = _styleProps.nonce || nonce;
    styleRef.value = document2.querySelector('style[data-primevue-style-id="'.concat(_name, '"]')) || document2.getElementById(_id2) || document2.createElement("style");
    if (!styleRef.value.isConnected) {
      cssRef.value = _css || css4;
      setAttributes$1(styleRef.value, {
        type: "text/css",
        id: _id2,
        media,
        nonce: _nonce
      });
      first2 ? document2.head.prepend(styleRef.value) : document2.head.appendChild(styleRef.value);
      setAttribute$1(styleRef.value, "data-primevue-style-id", _name);
      setAttributes$1(styleRef.value, _styleProps);
      styleRef.value.onload = function(event) {
        return onStyleLoaded === null || onStyleLoaded === void 0 ? void 0 : onStyleLoaded(event, {
          name: _name
        });
      };
      onStyleMounted === null || onStyleMounted === void 0 || onStyleMounted(_name);
    }
    if (isLoaded.value) return;
    stop2 = watch(cssRef, function(value3) {
      styleRef.value.textContent = value3;
      onStyleUpdated === null || onStyleUpdated === void 0 || onStyleUpdated(_name);
    }, {
      immediate: true
    });
    isLoaded.value = true;
  }, "load");
  var unload = /* @__PURE__ */ __name(function unload2() {
    if (!document2 || !isLoaded.value) return;
    stop2();
    isExist$1(styleRef.value) && document2.head.removeChild(styleRef.value);
    isLoaded.value = false;
  }, "unload");
  if (immediate && !manual) tryOnMounted$3(load3);
  return {
    id: id4,
    name: name2,
    el: styleRef,
    css: cssRef,
    unload,
    load: load3,
    isLoaded: readonly(isLoaded)
  };
}
__name(useStyle$1, "useStyle$1");
function _typeof$t(o2) {
  "@babel/helpers - typeof";
  return _typeof$t = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$t(o2);
}
__name(_typeof$t, "_typeof$t");
function _slicedToArray$8(r2, e2) {
  return _arrayWithHoles$8(r2) || _iterableToArrayLimit$8(r2, e2) || _unsupportedIterableToArray$n(r2, e2) || _nonIterableRest$8();
}
__name(_slicedToArray$8, "_slicedToArray$8");
function _nonIterableRest$8() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$8, "_nonIterableRest$8");
function _unsupportedIterableToArray$n(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$n(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$n(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$n, "_unsupportedIterableToArray$n");
function _arrayLikeToArray$n(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$n, "_arrayLikeToArray$n");
function _iterableToArrayLimit$8(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$8, "_iterableToArrayLimit$8");
function _arrayWithHoles$8(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$8, "_arrayWithHoles$8");
function ownKeys$r(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$r, "ownKeys$r");
function _objectSpread$r(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$r(Object(t2), true).forEach(function(r3) {
      _defineProperty$v(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$r(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$r, "_objectSpread$r");
function _defineProperty$v(e2, r2, t2) {
  return (r2 = _toPropertyKey$s(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$v, "_defineProperty$v");
function _toPropertyKey$s(t2) {
  var i2 = _toPrimitive$s(t2, "string");
  return "symbol" == _typeof$t(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$s, "_toPropertyKey$s");
function _toPrimitive$s(t2, r2) {
  if ("object" != _typeof$t(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$t(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$s, "_toPrimitive$s");
var theme$I = /* @__PURE__ */ __name(function theme2(_ref) {
  var dt2 = _ref.dt;
  return "\n*,\n::before,\n::after {\n    box-sizing: border-box;\n}\n\n/* Non vue overlay animations */\n.p-connected-overlay {\n    opacity: 0;\n    transform: scaleY(0.8);\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1),\n        opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-connected-overlay-visible {\n    opacity: 1;\n    transform: scaleY(1);\n}\n\n.p-connected-overlay-hidden {\n    opacity: 0;\n    transform: scaleY(1);\n    transition: opacity 0.1s linear;\n}\n\n/* Vue based overlay animations */\n.p-connected-overlay-enter-from {\n    opacity: 0;\n    transform: scaleY(0.8);\n}\n\n.p-connected-overlay-leave-to {\n    opacity: 0;\n}\n\n.p-connected-overlay-enter-active {\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1),\n        opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-connected-overlay-leave-active {\n    transition: opacity 0.1s linear;\n}\n\n/* Toggleable Content */\n.p-toggleable-content-enter-from,\n.p-toggleable-content-leave-to {\n    max-height: 0;\n}\n\n.p-toggleable-content-enter-to,\n.p-toggleable-content-leave-from {\n    max-height: 1000px;\n}\n\n.p-toggleable-content-leave-active {\n    overflow: hidden;\n    transition: max-height 0.45s cubic-bezier(0, 1, 0, 1);\n}\n\n.p-toggleable-content-enter-active {\n    overflow: hidden;\n    transition: max-height 1s ease-in-out;\n}\n\n.p-disabled,\n.p-disabled * {\n    cursor: default;\n    pointer-events: none;\n    user-select: none;\n}\n\n.p-disabled,\n.p-component:disabled {\n    opacity: ".concat(dt2("disabled.opacity"), ";\n}\n\n.pi {\n    font-size: ").concat(dt2("icon.size"), ";\n}\n\n.p-icon {\n    width: ").concat(dt2("icon.size"), ";\n    height: ").concat(dt2("icon.size"), ";\n}\n\n.p-overlay-mask {\n    background: ").concat(dt2("mask.background"), ";\n    color: ").concat(dt2("mask.color"), ";\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n}\n\n.p-overlay-mask-enter {\n    animation: p-overlay-mask-enter-animation ").concat(dt2("mask.transition.duration"), " forwards;\n}\n\n.p-overlay-mask-leave {\n    animation: p-overlay-mask-leave-animation ").concat(dt2("mask.transition.duration"), " forwards;\n}\n\n@keyframes p-overlay-mask-enter-animation {\n    from {\n        background: transparent;\n    }\n    to {\n        background: ").concat(dt2("mask.background"), ";\n    }\n}\n@keyframes p-overlay-mask-leave-animation {\n    from {\n        background: ").concat(dt2("mask.background"), ";\n    }\n    to {\n        background: transparent;\n    }\n}\n");
}, "theme");
var css$4 = /* @__PURE__ */ __name(function css2(_ref2) {
  var dt2 = _ref2.dt;
  return "\n.p-hidden-accessible {\n    border: 0;\n    clip: rect(0 0 0 0);\n    height: 1px;\n    margin: -1px;\n    overflow: hidden;\n    padding: 0;\n    position: absolute;\n    width: 1px;\n}\n\n.p-hidden-accessible input,\n.p-hidden-accessible select {\n    transform: scale(0);\n}\n\n.p-overflow-hidden {\n    overflow: hidden;\n    padding-right: ".concat(dt2("scrollbar.width"), ";\n}\n");
}, "css");
var classes$O = {};
var inlineStyles$8 = {};
var BaseStyle$1 = {
  name: "base",
  css: css$4,
  theme: theme$I,
  classes: classes$O,
  inlineStyles: inlineStyles$8,
  load: /* @__PURE__ */ __name(function load(style2) {
    var options5 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var transform2 = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : function(cs) {
      return cs;
    };
    var computedStyle = transform2(resolve$4(style2, {
      dt: dt$1
    }));
    return isNotEmpty$2(computedStyle) ? useStyle$1(minifyCSS$2(computedStyle), _objectSpread$r({
      name: this.name
    }, options5)) : {};
  }, "load"),
  loadCSS: /* @__PURE__ */ __name(function loadCSS() {
    var options5 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    return this.load(this.css, options5);
  }, "loadCSS"),
  loadTheme: /* @__PURE__ */ __name(function loadTheme() {
    var _this = this;
    var options5 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var style2 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    return this.load(this.theme, options5, function() {
      var computedStyle = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      return config_default$1.transformCSS(options5.name || _this.name, "".concat(computedStyle).concat(style2));
    });
  }, "loadTheme"),
  getCommonTheme: /* @__PURE__ */ __name(function getCommonTheme(params) {
    return config_default$1.getCommon(this.name, params);
  }, "getCommonTheme"),
  getComponentTheme: /* @__PURE__ */ __name(function getComponentTheme(params) {
    return config_default$1.getComponent(this.name, params);
  }, "getComponentTheme"),
  getDirectiveTheme: /* @__PURE__ */ __name(function getDirectiveTheme(params) {
    return config_default$1.getDirective(this.name, params);
  }, "getDirectiveTheme"),
  getPresetTheme: /* @__PURE__ */ __name(function getPresetTheme(preset, selector, params) {
    return config_default$1.getCustomPreset(this.name, preset, selector, params);
  }, "getPresetTheme"),
  getLayerOrderThemeCSS: /* @__PURE__ */ __name(function getLayerOrderThemeCSS() {
    return config_default$1.getLayerOrderCSS(this.name);
  }, "getLayerOrderThemeCSS"),
  getStyleSheet: /* @__PURE__ */ __name(function getStyleSheet() {
    var extendedCSS = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (this.css) {
      var _css = resolve$4(this.css, {
        dt: dt$1
      }) || "";
      var _style = minifyCSS$2("".concat(_css).concat(extendedCSS));
      var _props = Object.entries(props).reduce(function(acc, _ref3) {
        var _ref4 = _slicedToArray$8(_ref3, 2), k2 = _ref4[0], v2 = _ref4[1];
        return acc.push("".concat(k2, '="').concat(v2, '"')) && acc;
      }, []).join(" ");
      return isNotEmpty$2(_style) ? '<style type="text/css" data-primevue-style-id="'.concat(this.name, '" ').concat(_props, ">").concat(_style, "</style>") : "";
    }
    return "";
  }, "getStyleSheet"),
  getCommonThemeStyleSheet: /* @__PURE__ */ __name(function getCommonThemeStyleSheet(params) {
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    return config_default$1.getCommonStyleSheet(this.name, params, props);
  }, "getCommonThemeStyleSheet"),
  getThemeStyleSheet: /* @__PURE__ */ __name(function getThemeStyleSheet(params) {
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var css4 = [config_default$1.getStyleSheet(this.name, params, props)];
    if (this.theme) {
      var name2 = this.name === "base" ? "global-style" : "".concat(this.name, "-style");
      var _css = resolve$4(this.theme, {
        dt: dt$1
      });
      var _style = minifyCSS$2(config_default$1.transformCSS(name2, _css));
      var _props = Object.entries(props).reduce(function(acc, _ref5) {
        var _ref6 = _slicedToArray$8(_ref5, 2), k2 = _ref6[0], v2 = _ref6[1];
        return acc.push("".concat(k2, '="').concat(v2, '"')) && acc;
      }, []).join(" ");
      isNotEmpty$2(_style) && css4.push('<style type="text/css" data-primevue-style-id="'.concat(name2, '" ').concat(_props, ">").concat(_style, "</style>"));
    }
    return css4.join("");
  }, "getThemeStyleSheet"),
  extend: /* @__PURE__ */ __name(function extend2(style2) {
    return _objectSpread$r(_objectSpread$r({}, this), {}, {
      css: void 0,
      theme: void 0
    }, style2);
  }, "extend")
};
var PrimeVueService = EventBus$1();
function _typeof$s(o2) {
  "@babel/helpers - typeof";
  return _typeof$s = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$s(o2);
}
__name(_typeof$s, "_typeof$s");
function ownKeys$q(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$q, "ownKeys$q");
function _objectSpread$q(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$q(Object(t2), true).forEach(function(r3) {
      _defineProperty$u(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$q(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$q, "_objectSpread$q");
function _defineProperty$u(e2, r2, t2) {
  return (r2 = _toPropertyKey$r(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$u, "_defineProperty$u");
function _toPropertyKey$r(t2) {
  var i2 = _toPrimitive$r(t2, "string");
  return "symbol" == _typeof$s(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$r, "_toPropertyKey$r");
function _toPrimitive$r(t2, r2) {
  if ("object" != _typeof$s(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$s(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$r, "_toPrimitive$r");
var defaultOptions$2 = {
  ripple: false,
  inputStyle: null,
  inputVariant: null,
  locale: {
    startsWith: "Starts with",
    contains: "Contains",
    notContains: "Not contains",
    endsWith: "Ends with",
    equals: "Equals",
    notEquals: "Not equals",
    noFilter: "No Filter",
    lt: "Less than",
    lte: "Less than or equal to",
    gt: "Greater than",
    gte: "Greater than or equal to",
    dateIs: "Date is",
    dateIsNot: "Date is not",
    dateBefore: "Date is before",
    dateAfter: "Date is after",
    clear: "Clear",
    apply: "Apply",
    matchAll: "Match All",
    matchAny: "Match Any",
    addRule: "Add Rule",
    removeRule: "Remove Rule",
    accept: "Yes",
    reject: "No",
    choose: "Choose",
    upload: "Upload",
    cancel: "Cancel",
    completed: "Completed",
    pending: "Pending",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    dayNames: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
    dayNamesShort: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
    dayNamesMin: ["Su", "Mo", "Tu", "We", "Th", "Fr", "Sa"],
    monthNames: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],
    monthNamesShort: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"],
    chooseYear: "Choose Year",
    chooseMonth: "Choose Month",
    chooseDate: "Choose Date",
    prevDecade: "Previous Decade",
    nextDecade: "Next Decade",
    prevYear: "Previous Year",
    nextYear: "Next Year",
    prevMonth: "Previous Month",
    nextMonth: "Next Month",
    prevHour: "Previous Hour",
    nextHour: "Next Hour",
    prevMinute: "Previous Minute",
    nextMinute: "Next Minute",
    prevSecond: "Previous Second",
    nextSecond: "Next Second",
    am: "am",
    pm: "pm",
    today: "Today",
    weekHeader: "Wk",
    firstDayOfWeek: 0,
    showMonthAfterYear: false,
    dateFormat: "mm/dd/yy",
    weak: "Weak",
    medium: "Medium",
    strong: "Strong",
    passwordPrompt: "Enter a password",
    emptyFilterMessage: "No results found",
    searchMessage: "{0} results are available",
    selectionMessage: "{0} items selected",
    emptySelectionMessage: "No selected item",
    emptySearchMessage: "No results found",
    fileChosenMessage: "{0} files",
    noFileChosenMessage: "No file chosen",
    emptyMessage: "No available options",
    aria: {
      trueLabel: "True",
      falseLabel: "False",
      nullLabel: "Not Selected",
      star: "1 star",
      stars: "{star} stars",
      selectAll: "All items selected",
      unselectAll: "All items unselected",
      close: "Close",
      previous: "Previous",
      next: "Next",
      navigation: "Navigation",
      scrollTop: "Scroll Top",
      moveTop: "Move Top",
      moveUp: "Move Up",
      moveDown: "Move Down",
      moveBottom: "Move Bottom",
      moveToTarget: "Move to Target",
      moveToSource: "Move to Source",
      moveAllToTarget: "Move All to Target",
      moveAllToSource: "Move All to Source",
      pageLabel: "Page {page}",
      firstPageLabel: "First Page",
      lastPageLabel: "Last Page",
      nextPageLabel: "Next Page",
      prevPageLabel: "Previous Page",
      rowsPerPageLabel: "Rows per page",
      jumpToPageDropdownLabel: "Jump to Page Dropdown",
      jumpToPageInputLabel: "Jump to Page Input",
      selectRow: "Row Selected",
      unselectRow: "Row Unselected",
      expandRow: "Row Expanded",
      collapseRow: "Row Collapsed",
      showFilterMenu: "Show Filter Menu",
      hideFilterMenu: "Hide Filter Menu",
      filterOperator: "Filter Operator",
      filterConstraint: "Filter Constraint",
      editRow: "Row Edit",
      saveEdit: "Save Edit",
      cancelEdit: "Cancel Edit",
      listView: "List View",
      gridView: "Grid View",
      slide: "Slide",
      slideNumber: "{slideNumber}",
      zoomImage: "Zoom Image",
      zoomIn: "Zoom In",
      zoomOut: "Zoom Out",
      rotateRight: "Rotate Right",
      rotateLeft: "Rotate Left",
      listLabel: "Option List"
    }
  },
  filterMatchModeOptions: {
    text: [FilterMatchMode.STARTS_WITH, FilterMatchMode.CONTAINS, FilterMatchMode.NOT_CONTAINS, FilterMatchMode.ENDS_WITH, FilterMatchMode.EQUALS, FilterMatchMode.NOT_EQUALS],
    numeric: [FilterMatchMode.EQUALS, FilterMatchMode.NOT_EQUALS, FilterMatchMode.LESS_THAN, FilterMatchMode.LESS_THAN_OR_EQUAL_TO, FilterMatchMode.GREATER_THAN, FilterMatchMode.GREATER_THAN_OR_EQUAL_TO],
    date: [FilterMatchMode.DATE_IS, FilterMatchMode.DATE_IS_NOT, FilterMatchMode.DATE_BEFORE, FilterMatchMode.DATE_AFTER]
  },
  zIndex: {
    modal: 1100,
    overlay: 1e3,
    menu: 1e3,
    tooltip: 1100
  },
  theme: void 0,
  unstyled: false,
  pt: void 0,
  ptOptions: {
    mergeSections: true,
    mergeProps: false
  },
  csp: {
    nonce: void 0
  }
};
var PrimeVueSymbol = Symbol();
function usePrimeVue() {
  var PrimeVue2 = inject(PrimeVueSymbol);
  if (!PrimeVue2) {
    throw new Error("PrimeVue is not installed!");
  }
  return PrimeVue2;
}
__name(usePrimeVue, "usePrimeVue");
function setup(app2, options5) {
  var PrimeVue2 = {
    config: reactive(options5)
  };
  app2.config.globalProperties.$primevue = PrimeVue2;
  app2.provide(PrimeVueSymbol, PrimeVue2);
  clearConfig();
  setupConfig(app2, PrimeVue2);
  return PrimeVue2;
}
__name(setup, "setup");
var stopWatchers = [];
function clearConfig() {
  service_default$1.clear();
  stopWatchers.forEach(function(fn) {
    return fn === null || fn === void 0 ? void 0 : fn();
  });
  stopWatchers = [];
}
__name(clearConfig, "clearConfig");
function setupConfig(app2, PrimeVue2) {
  var isThemeChanged = ref(false);
  var loadCommonTheme = /* @__PURE__ */ __name(function loadCommonTheme2() {
    var _PrimeVue$config;
    if (((_PrimeVue$config = PrimeVue2.config) === null || _PrimeVue$config === void 0 ? void 0 : _PrimeVue$config.theme) === "none") return;
    if (!config_default$1.isStyleNameLoaded("common")) {
      var _BaseStyle$getCommonT, _PrimeVue$config2;
      var _ref = ((_BaseStyle$getCommonT = BaseStyle$1.getCommonTheme) === null || _BaseStyle$getCommonT === void 0 ? void 0 : _BaseStyle$getCommonT.call(BaseStyle$1)) || {}, primitive = _ref.primitive, semantic = _ref.semantic, global2 = _ref.global, style2 = _ref.style;
      var styleOptions = {
        nonce: (_PrimeVue$config2 = PrimeVue2.config) === null || _PrimeVue$config2 === void 0 || (_PrimeVue$config2 = _PrimeVue$config2.csp) === null || _PrimeVue$config2 === void 0 ? void 0 : _PrimeVue$config2.nonce
      };
      BaseStyle$1.load(primitive === null || primitive === void 0 ? void 0 : primitive.css, _objectSpread$q({
        name: "primitive-variables"
      }, styleOptions));
      BaseStyle$1.load(semantic === null || semantic === void 0 ? void 0 : semantic.css, _objectSpread$q({
        name: "semantic-variables"
      }, styleOptions));
      BaseStyle$1.load(global2 === null || global2 === void 0 ? void 0 : global2.css, _objectSpread$q({
        name: "global-variables"
      }, styleOptions));
      BaseStyle$1.loadTheme(_objectSpread$q({
        name: "global-style"
      }, styleOptions), style2);
      config_default$1.setLoadedStyleName("common");
    }
  }, "loadCommonTheme");
  service_default$1.on("theme:change", function(newTheme) {
    if (!isThemeChanged.value) {
      app2.config.globalProperties.$primevue.config.theme = newTheme;
      isThemeChanged.value = true;
    }
  });
  var stopConfigWatcher = watch(PrimeVue2.config, function(newValue2, oldValue) {
    PrimeVueService.emit("config:change", {
      newValue: newValue2,
      oldValue
    });
  }, {
    immediate: true,
    deep: true
  });
  var stopRippleWatcher = watch(function() {
    return PrimeVue2.config.ripple;
  }, function(newValue2, oldValue) {
    PrimeVueService.emit("config:ripple:change", {
      newValue: newValue2,
      oldValue
    });
  }, {
    immediate: true,
    deep: true
  });
  var stopThemeWatcher = watch(function() {
    return PrimeVue2.config.theme;
  }, function(newValue2, oldValue) {
    if (!isThemeChanged.value) {
      config_default$1.setTheme(newValue2);
    }
    if (!PrimeVue2.config.unstyled) {
      loadCommonTheme();
    }
    isThemeChanged.value = false;
    PrimeVueService.emit("config:theme:change", {
      newValue: newValue2,
      oldValue
    });
  }, {
    immediate: true,
    deep: false
  });
  var stopUnstyledWatcher = watch(function() {
    return PrimeVue2.config.unstyled;
  }, function(newValue2, oldValue) {
    if (!newValue2 && PrimeVue2.config.theme) {
      loadCommonTheme();
    }
    PrimeVueService.emit("config:unstyled:change", {
      newValue: newValue2,
      oldValue
    });
  }, {
    immediate: true,
    deep: true
  });
  stopWatchers.push(stopConfigWatcher);
  stopWatchers.push(stopRippleWatcher);
  stopWatchers.push(stopThemeWatcher);
  stopWatchers.push(stopUnstyledWatcher);
}
__name(setupConfig, "setupConfig");
var PrimeVue = {
  install: /* @__PURE__ */ __name(function install2(app2, options5) {
    var configOptions = mergeKeys$2(defaultOptions$2, options5);
    setup(app2, configOptions);
  }, "install")
};
var ConfirmationEventBus = EventBus$1();
var PrimeVueConfirmSymbol = Symbol();
function useConfirm() {
  var PrimeVueConfirm = inject(PrimeVueConfirmSymbol);
  if (!PrimeVueConfirm) {
    throw new Error("No PrimeVue Confirmation provided!");
  }
  return PrimeVueConfirm;
}
__name(useConfirm, "useConfirm");
var ConfirmationService = {
  install: /* @__PURE__ */ __name(function install3(app2) {
    var ConfirmationService2 = {
      require: /* @__PURE__ */ __name(function require2(options5) {
        ConfirmationEventBus.emit("confirm", options5);
      }, "require"),
      close: /* @__PURE__ */ __name(function close5() {
        ConfirmationEventBus.emit("close");
      }, "close")
    };
    app2.config.globalProperties.$confirm = ConfirmationService2;
    app2.provide(PrimeVueConfirmSymbol, ConfirmationService2);
  }, "install")
};
var ToastEventBus = EventBus$1();
var PrimeVueToastSymbol = Symbol();
function useToast() {
  var PrimeVueToast = inject(PrimeVueToastSymbol);
  if (!PrimeVueToast) {
    throw new Error("No PrimeVue Toast provided!");
  }
  return PrimeVueToast;
}
__name(useToast, "useToast");
var ToastService = {
  install: /* @__PURE__ */ __name(function install4(app2) {
    var ToastService2 = {
      add: /* @__PURE__ */ __name(function add3(message3) {
        ToastEventBus.emit("add", message3);
      }, "add"),
      remove: /* @__PURE__ */ __name(function remove4(message3) {
        ToastEventBus.emit("remove", message3);
      }, "remove"),
      removeGroup: /* @__PURE__ */ __name(function removeGroup(group) {
        ToastEventBus.emit("remove-group", group);
      }, "removeGroup"),
      removeAllGroups: /* @__PURE__ */ __name(function removeAllGroups() {
        ToastEventBus.emit("remove-all-groups");
      }, "removeAllGroups")
    };
    app2.config.globalProperties.$toast = ToastService2;
    app2.provide(PrimeVueToastSymbol, ToastService2);
  }, "install")
};
function _typeof$1$4(o2) {
  "@babel/helpers - typeof";
  return _typeof$1$4 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$1$4(o2);
}
__name(_typeof$1$4, "_typeof$1$4");
function _classCallCheck$1(a2, n2) {
  if (!(a2 instanceof n2)) throw new TypeError("Cannot call a class as a function");
}
__name(_classCallCheck$1, "_classCallCheck$1");
function _defineProperties$1(e2, r2) {
  for (var t2 = 0; t2 < r2.length; t2++) {
    var o2 = r2[t2];
    o2.enumerable = o2.enumerable || false, o2.configurable = true, "value" in o2 && (o2.writable = true), Object.defineProperty(e2, _toPropertyKey$1$3(o2.key), o2);
  }
}
__name(_defineProperties$1, "_defineProperties$1");
function _createClass$1(e2, r2, t2) {
  return r2 && _defineProperties$1(e2.prototype, r2), Object.defineProperty(e2, "prototype", { writable: false }), e2;
}
__name(_createClass$1, "_createClass$1");
function _toPropertyKey$1$3(t2) {
  var i2 = _toPrimitive$1$3(t2, "string");
  return "symbol" == _typeof$1$4(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$1$3, "_toPropertyKey$1$3");
function _toPrimitive$1$3(t2, r2) {
  if ("object" != _typeof$1$4(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2);
    if ("object" != _typeof$1$4(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return String(t2);
}
__name(_toPrimitive$1$3, "_toPrimitive$1$3");
var ConnectedOverlayScrollHandler = /* @__PURE__ */ function() {
  function ConnectedOverlayScrollHandler2(element) {
    var listener = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : function() {
    };
    _classCallCheck$1(this, ConnectedOverlayScrollHandler2);
    this.element = element;
    this.listener = listener;
  }
  __name(ConnectedOverlayScrollHandler2, "ConnectedOverlayScrollHandler");
  return _createClass$1(ConnectedOverlayScrollHandler2, [{
    key: "bindScrollListener",
    value: /* @__PURE__ */ __name(function bindScrollListener8() {
      this.scrollableParents = getScrollableParents$1(this.element);
      for (var i2 = 0; i2 < this.scrollableParents.length; i2++) {
        this.scrollableParents[i2].addEventListener("scroll", this.listener);
      }
    }, "bindScrollListener")
  }, {
    key: "unbindScrollListener",
    value: /* @__PURE__ */ __name(function unbindScrollListener8() {
      if (this.scrollableParents) {
        for (var i2 = 0; i2 < this.scrollableParents.length; i2++) {
          this.scrollableParents[i2].removeEventListener("scroll", this.listener);
        }
      }
    }, "unbindScrollListener")
  }, {
    key: "destroy",
    value: /* @__PURE__ */ __name(function destroy() {
      this.unbindScrollListener();
      this.element = null;
      this.listener = null;
      this.scrollableParents = null;
    }, "destroy")
  }]);
}();
function _typeof$r(o2) {
  "@babel/helpers - typeof";
  return _typeof$r = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$r(o2);
}
__name(_typeof$r, "_typeof$r");
function _toConsumableArray$d(r2) {
  return _arrayWithoutHoles$d(r2) || _iterableToArray$f(r2) || _unsupportedIterableToArray$m(r2) || _nonIterableSpread$d();
}
__name(_toConsumableArray$d, "_toConsumableArray$d");
function _nonIterableSpread$d() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$d, "_nonIterableSpread$d");
function _unsupportedIterableToArray$m(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$m(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$m(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$m, "_unsupportedIterableToArray$m");
function _iterableToArray$f(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$f, "_iterableToArray$f");
function _arrayWithoutHoles$d(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$m(r2);
}
__name(_arrayWithoutHoles$d, "_arrayWithoutHoles$d");
function _arrayLikeToArray$m(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$m, "_arrayLikeToArray$m");
function _classCallCheck(a2, n2) {
  if (!(a2 instanceof n2)) throw new TypeError("Cannot call a class as a function");
}
__name(_classCallCheck, "_classCallCheck");
function _defineProperties(e2, r2) {
  for (var t2 = 0; t2 < r2.length; t2++) {
    var o2 = r2[t2];
    o2.enumerable = o2.enumerable || false, o2.configurable = true, "value" in o2 && (o2.writable = true), Object.defineProperty(e2, _toPropertyKey$q(o2.key), o2);
  }
}
__name(_defineProperties, "_defineProperties");
function _createClass(e2, r2, t2) {
  return r2 && _defineProperties(e2.prototype, r2), Object.defineProperty(e2, "prototype", { writable: false }), e2;
}
__name(_createClass, "_createClass");
function _defineProperty$t(e2, r2, t2) {
  return (r2 = _toPropertyKey$q(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$t, "_defineProperty$t");
function _toPropertyKey$q(t2) {
  var i2 = _toPrimitive$q(t2, "string");
  return "symbol" == _typeof$r(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$q, "_toPropertyKey$q");
function _toPrimitive$q(t2, r2) {
  if ("object" != _typeof$r(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2);
    if ("object" != _typeof$r(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return String(t2);
}
__name(_toPrimitive$q, "_toPrimitive$q");
var _default = /* @__PURE__ */ function() {
  function _default8(_ref) {
    var init3 = _ref.init, type = _ref.type;
    _classCallCheck(this, _default8);
    _defineProperty$t(this, "helpers", void 0);
    _defineProperty$t(this, "type", void 0);
    this.helpers = new Set(init3);
    this.type = type;
  }
  __name(_default8, "_default");
  return _createClass(_default8, [{
    key: "add",
    value: /* @__PURE__ */ __name(function add3(instance) {
      this.helpers.add(instance);
    }, "add")
  }, {
    key: "update",
    value: /* @__PURE__ */ __name(function update() {
    }, "update")
  }, {
    key: "delete",
    value: /* @__PURE__ */ __name(function _delete(instance) {
      this.helpers["delete"](instance);
    }, "_delete")
  }, {
    key: "clear",
    value: /* @__PURE__ */ __name(function clear() {
      this.helpers.clear();
    }, "clear")
  }, {
    key: "get",
    value: /* @__PURE__ */ __name(function get3(parentInstance, slots) {
      var children = this._get(parentInstance, slots);
      var computed2 = children ? this._recursive(_toConsumableArray$d(this.helpers), children) : null;
      return isNotEmpty$2(computed2) ? computed2 : null;
    }, "get")
  }, {
    key: "_isMatched",
    value: /* @__PURE__ */ __name(function _isMatched(instance, key) {
      var _parent$vnode;
      var parent = instance === null || instance === void 0 ? void 0 : instance.parent;
      return (parent === null || parent === void 0 || (_parent$vnode = parent.vnode) === null || _parent$vnode === void 0 ? void 0 : _parent$vnode.key) === key || parent && this._isMatched(parent, key) || false;
    }, "_isMatched")
  }, {
    key: "_get",
    value: /* @__PURE__ */ __name(function _get(parentInstance, slots) {
      var _ref2, _ref2$default;
      return ((_ref2 = slots || (parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$slots)) === null || _ref2 === void 0 || (_ref2$default = _ref2["default"]) === null || _ref2$default === void 0 ? void 0 : _ref2$default.call(_ref2)) || null;
    }, "_get")
  }, {
    key: "_recursive",
    value: /* @__PURE__ */ __name(function _recursive() {
      var _this = this;
      var helpers2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : [];
      var children = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : [];
      var components = [];
      children.forEach(function(child) {
        if (child.children instanceof Array) {
          components = components.concat(_this._recursive(components, child.children));
        } else if (child.type.name === _this.type) {
          components.push(child);
        } else if (isNotEmpty$2(child.key)) {
          components = components.concat(helpers2.filter(function(c2) {
            return _this._isMatched(c2, child.key);
          }).map(function(c2) {
            return c2.vnode;
          }));
        }
      });
      return components;
    }, "_recursive")
  }]);
}();
function UniqueComponentId() {
  var prefix2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "pv_id_";
  return uuid$1(prefix2);
}
__name(UniqueComponentId, "UniqueComponentId");
function getVNodeProp(vnode, prop2) {
  if (vnode) {
    var props = vnode.props;
    if (props) {
      var kebabProp = prop2.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      var propName = Object.prototype.hasOwnProperty.call(props, kebabProp) ? kebabProp : prop2;
      return vnode.type["extends"].props[prop2].type === Boolean && props[propName] === "" ? true : props[propName];
    }
  }
  return null;
}
__name(getVNodeProp, "getVNodeProp");
var Base$1 = {
  _loadedStyleNames: /* @__PURE__ */ new Set(),
  getLoadedStyleNames: /* @__PURE__ */ __name(function getLoadedStyleNames() {
    return this._loadedStyleNames;
  }, "getLoadedStyleNames"),
  isStyleNameLoaded: /* @__PURE__ */ __name(function isStyleNameLoaded(name2) {
    return this._loadedStyleNames.has(name2);
  }, "isStyleNameLoaded"),
  setLoadedStyleName: /* @__PURE__ */ __name(function setLoadedStyleName(name2) {
    this._loadedStyleNames.add(name2);
  }, "setLoadedStyleName"),
  deleteLoadedStyleName: /* @__PURE__ */ __name(function deleteLoadedStyleName(name2) {
    this._loadedStyleNames["delete"](name2);
  }, "deleteLoadedStyleName"),
  clearLoadedStyleNames: /* @__PURE__ */ __name(function clearLoadedStyleNames() {
    this._loadedStyleNames.clear();
  }, "clearLoadedStyleNames")
};
function _typeof$q(o2) {
  "@babel/helpers - typeof";
  return _typeof$q = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$q(o2);
}
__name(_typeof$q, "_typeof$q");
function _slicedToArray$7(r2, e2) {
  return _arrayWithHoles$7(r2) || _iterableToArrayLimit$7(r2, e2) || _unsupportedIterableToArray$l(r2, e2) || _nonIterableRest$7();
}
__name(_slicedToArray$7, "_slicedToArray$7");
function _nonIterableRest$7() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$7, "_nonIterableRest$7");
function _unsupportedIterableToArray$l(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$l(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$l(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$l, "_unsupportedIterableToArray$l");
function _arrayLikeToArray$l(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$l, "_arrayLikeToArray$l");
function _iterableToArrayLimit$7(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$7, "_iterableToArrayLimit$7");
function _arrayWithHoles$7(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$7, "_arrayWithHoles$7");
function ownKeys$p(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$p, "ownKeys$p");
function _objectSpread$p(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$p(Object(t2), true).forEach(function(r3) {
      _defineProperty$s(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$p(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$p, "_objectSpread$p");
function _defineProperty$s(e2, r2, t2) {
  return (r2 = _toPropertyKey$p(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$s, "_defineProperty$s");
function _toPropertyKey$p(t2) {
  var i2 = _toPrimitive$p(t2, "string");
  return "symbol" == _typeof$q(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$p, "_toPropertyKey$p");
function _toPrimitive$p(t2, r2) {
  if ("object" != _typeof$q(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$q(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$p, "_toPrimitive$p");
var BaseDirective = {
  _getMeta: /* @__PURE__ */ __name(function _getMeta() {
    return [isObject$g(arguments.length <= 0 ? void 0 : arguments[0]) ? void 0 : arguments.length <= 0 ? void 0 : arguments[0], resolve$4(isObject$g(arguments.length <= 0 ? void 0 : arguments[0]) ? arguments.length <= 0 ? void 0 : arguments[0] : arguments.length <= 1 ? void 0 : arguments[1])];
  }, "_getMeta"),
  _getConfig: /* @__PURE__ */ __name(function _getConfig(binding, vnode) {
    var _ref, _binding$instance, _vnode$ctx;
    return (_ref = (binding === null || binding === void 0 || (_binding$instance = binding.instance) === null || _binding$instance === void 0 ? void 0 : _binding$instance.$primevue) || (vnode === null || vnode === void 0 || (_vnode$ctx = vnode.ctx) === null || _vnode$ctx === void 0 || (_vnode$ctx = _vnode$ctx.appContext) === null || _vnode$ctx === void 0 || (_vnode$ctx = _vnode$ctx.config) === null || _vnode$ctx === void 0 || (_vnode$ctx = _vnode$ctx.globalProperties) === null || _vnode$ctx === void 0 ? void 0 : _vnode$ctx.$primevue)) === null || _ref === void 0 ? void 0 : _ref.config;
  }, "_getConfig"),
  _getOptionValue: getKeyValue$2,
  _getPTValue: /* @__PURE__ */ __name(function _getPTValue() {
    var _instance$binding, _instance$$primevueCo;
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var obj = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var key = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "";
    var params = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
    var searchInDefaultPT = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : true;
    var getValue2 = /* @__PURE__ */ __name(function getValue3() {
      var value3 = BaseDirective._getOptionValue.apply(BaseDirective, arguments);
      return isString$b(value3) || isArray$c(value3) ? {
        "class": value3
      } : value3;
    }, "getValue");
    var _ref2 = ((_instance$binding = instance.binding) === null || _instance$binding === void 0 || (_instance$binding = _instance$binding.value) === null || _instance$binding === void 0 ? void 0 : _instance$binding.ptOptions) || ((_instance$$primevueCo = instance.$primevueConfig) === null || _instance$$primevueCo === void 0 ? void 0 : _instance$$primevueCo.ptOptions) || {}, _ref2$mergeSections = _ref2.mergeSections, mergeSections = _ref2$mergeSections === void 0 ? true : _ref2$mergeSections, _ref2$mergeProps = _ref2.mergeProps, useMergeProps = _ref2$mergeProps === void 0 ? false : _ref2$mergeProps;
    var global2 = searchInDefaultPT ? BaseDirective._useDefaultPT(instance, instance.defaultPT(), getValue2, key, params) : void 0;
    var self2 = BaseDirective._usePT(instance, BaseDirective._getPT(obj, instance.$name), getValue2, key, _objectSpread$p(_objectSpread$p({}, params), {}, {
      global: global2 || {}
    }));
    var datasets = BaseDirective._getPTDatasets(instance, key);
    return mergeSections || !mergeSections && self2 ? useMergeProps ? BaseDirective._mergeProps(instance, useMergeProps, global2, self2, datasets) : _objectSpread$p(_objectSpread$p(_objectSpread$p({}, global2), self2), datasets) : _objectSpread$p(_objectSpread$p({}, self2), datasets);
  }, "_getPTValue"),
  _getPTDatasets: /* @__PURE__ */ __name(function _getPTDatasets() {
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    var datasetPrefix = "data-pc-";
    return _objectSpread$p(_objectSpread$p({}, key === "root" && _defineProperty$s({}, "".concat(datasetPrefix, "name"), toFlatCase$2(instance.$name))), {}, _defineProperty$s({}, "".concat(datasetPrefix, "section"), toFlatCase$2(key)));
  }, "_getPTDatasets"),
  _getPT: /* @__PURE__ */ __name(function _getPT(pt) {
    var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    var callback = arguments.length > 2 ? arguments[2] : void 0;
    var getValue2 = /* @__PURE__ */ __name(function getValue3(value3) {
      var _computedValue$_key;
      var computedValue = callback ? callback(value3) : value3;
      var _key = toFlatCase$2(key);
      return (_computedValue$_key = computedValue === null || computedValue === void 0 ? void 0 : computedValue[_key]) !== null && _computedValue$_key !== void 0 ? _computedValue$_key : computedValue;
    }, "getValue");
    return pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept") ? {
      _usept: pt["_usept"],
      originalValue: getValue2(pt.originalValue),
      value: getValue2(pt.value)
    } : getValue2(pt);
  }, "_getPT"),
  _usePT: /* @__PURE__ */ __name(function _usePT() {
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var pt = arguments.length > 1 ? arguments[1] : void 0;
    var callback = arguments.length > 2 ? arguments[2] : void 0;
    var key = arguments.length > 3 ? arguments[3] : void 0;
    var params = arguments.length > 4 ? arguments[4] : void 0;
    var fn = /* @__PURE__ */ __name(function fn2(value4) {
      return callback(value4, key, params);
    }, "fn");
    if (pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept")) {
      var _instance$$primevueCo2;
      var _ref4 = pt["_usept"] || ((_instance$$primevueCo2 = instance.$primevueConfig) === null || _instance$$primevueCo2 === void 0 ? void 0 : _instance$$primevueCo2.ptOptions) || {}, _ref4$mergeSections = _ref4.mergeSections, mergeSections = _ref4$mergeSections === void 0 ? true : _ref4$mergeSections, _ref4$mergeProps = _ref4.mergeProps, useMergeProps = _ref4$mergeProps === void 0 ? false : _ref4$mergeProps;
      var originalValue = fn(pt.originalValue);
      var value3 = fn(pt.value);
      if (originalValue === void 0 && value3 === void 0) return void 0;
      else if (isString$b(value3)) return value3;
      else if (isString$b(originalValue)) return originalValue;
      return mergeSections || !mergeSections && value3 ? useMergeProps ? BaseDirective._mergeProps(instance, useMergeProps, originalValue, value3) : _objectSpread$p(_objectSpread$p({}, originalValue), value3) : value3;
    }
    return fn(pt);
  }, "_usePT"),
  _useDefaultPT: /* @__PURE__ */ __name(function _useDefaultPT() {
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var defaultPT3 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var callback = arguments.length > 2 ? arguments[2] : void 0;
    var key = arguments.length > 3 ? arguments[3] : void 0;
    var params = arguments.length > 4 ? arguments[4] : void 0;
    return BaseDirective._usePT(instance, defaultPT3, callback, key, params);
  }, "_useDefaultPT"),
  _loadStyles: /* @__PURE__ */ __name(function _loadStyles(el, binding, vnode) {
    var _config$csp;
    var config2 = BaseDirective._getConfig(binding, vnode);
    var useStyleOptions = {
      nonce: config2 === null || config2 === void 0 || (_config$csp = config2.csp) === null || _config$csp === void 0 ? void 0 : _config$csp.nonce
    };
    BaseDirective._loadCoreStyles(el.$instance, useStyleOptions);
    BaseDirective._loadThemeStyles(el.$instance, useStyleOptions);
    BaseDirective._loadScopedThemeStyles(el.$instance, useStyleOptions);
    BaseDirective._themeChangeListener(function() {
      return BaseDirective._loadThemeStyles(el.$instance, useStyleOptions);
    });
  }, "_loadStyles"),
  _loadCoreStyles: /* @__PURE__ */ __name(function _loadCoreStyles() {
    var _instance$$style, _instance$$style2;
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var useStyleOptions = arguments.length > 1 ? arguments[1] : void 0;
    if (!Base$1.isStyleNameLoaded((_instance$$style = instance.$style) === null || _instance$$style === void 0 ? void 0 : _instance$$style.name) && (_instance$$style2 = instance.$style) !== null && _instance$$style2 !== void 0 && _instance$$style2.name) {
      var _instance$$style3;
      BaseStyle$1.loadCSS(useStyleOptions);
      (_instance$$style3 = instance.$style) === null || _instance$$style3 === void 0 || _instance$$style3.loadCSS(useStyleOptions);
      Base$1.setLoadedStyleName(instance.$style.name);
    }
  }, "_loadCoreStyles"),
  _loadThemeStyles: /* @__PURE__ */ __name(function _loadThemeStyles() {
    var _instance$theme, _instance$$style5, _instance$$style6;
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var useStyleOptions = arguments.length > 1 ? arguments[1] : void 0;
    if (instance !== null && instance !== void 0 && instance.isUnstyled() || (instance === null || instance === void 0 || (_instance$theme = instance.theme) === null || _instance$theme === void 0 ? void 0 : _instance$theme.call(instance)) === "none") return;
    if (!config_default$1.isStyleNameLoaded("common")) {
      var _instance$$style4, _instance$$style4$get;
      var _ref5 = ((_instance$$style4 = instance.$style) === null || _instance$$style4 === void 0 || (_instance$$style4$get = _instance$$style4.getCommonTheme) === null || _instance$$style4$get === void 0 ? void 0 : _instance$$style4$get.call(_instance$$style4)) || {}, primitive = _ref5.primitive, semantic = _ref5.semantic, global2 = _ref5.global, style2 = _ref5.style;
      BaseStyle$1.load(primitive === null || primitive === void 0 ? void 0 : primitive.css, _objectSpread$p({
        name: "primitive-variables"
      }, useStyleOptions));
      BaseStyle$1.load(semantic === null || semantic === void 0 ? void 0 : semantic.css, _objectSpread$p({
        name: "semantic-variables"
      }, useStyleOptions));
      BaseStyle$1.load(global2 === null || global2 === void 0 ? void 0 : global2.css, _objectSpread$p({
        name: "global-variables"
      }, useStyleOptions));
      BaseStyle$1.loadTheme(_objectSpread$p({
        name: "global-style"
      }, useStyleOptions), style2);
      config_default$1.setLoadedStyleName("common");
    }
    if (!config_default$1.isStyleNameLoaded((_instance$$style5 = instance.$style) === null || _instance$$style5 === void 0 ? void 0 : _instance$$style5.name) && (_instance$$style6 = instance.$style) !== null && _instance$$style6 !== void 0 && _instance$$style6.name) {
      var _instance$$style7, _instance$$style7$get, _instance$$style8, _instance$$style9;
      var _ref6 = ((_instance$$style7 = instance.$style) === null || _instance$$style7 === void 0 || (_instance$$style7$get = _instance$$style7.getDirectiveTheme) === null || _instance$$style7$get === void 0 ? void 0 : _instance$$style7$get.call(_instance$$style7)) || {}, css4 = _ref6.css, _style = _ref6.style;
      (_instance$$style8 = instance.$style) === null || _instance$$style8 === void 0 || _instance$$style8.load(css4, _objectSpread$p({
        name: "".concat(instance.$style.name, "-variables")
      }, useStyleOptions));
      (_instance$$style9 = instance.$style) === null || _instance$$style9 === void 0 || _instance$$style9.loadTheme(_objectSpread$p({
        name: "".concat(instance.$style.name, "-style")
      }, useStyleOptions), _style);
      config_default$1.setLoadedStyleName(instance.$style.name);
    }
    if (!config_default$1.isStyleNameLoaded("layer-order")) {
      var _instance$$style10, _instance$$style10$ge;
      var layerOrder = (_instance$$style10 = instance.$style) === null || _instance$$style10 === void 0 || (_instance$$style10$ge = _instance$$style10.getLayerOrderThemeCSS) === null || _instance$$style10$ge === void 0 ? void 0 : _instance$$style10$ge.call(_instance$$style10);
      BaseStyle$1.load(layerOrder, _objectSpread$p({
        name: "layer-order",
        first: true
      }, useStyleOptions));
      config_default$1.setLoadedStyleName("layer-order");
    }
  }, "_loadThemeStyles"),
  _loadScopedThemeStyles: /* @__PURE__ */ __name(function _loadScopedThemeStyles() {
    var instance = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var useStyleOptions = arguments.length > 1 ? arguments[1] : void 0;
    var preset = instance.preset();
    if (preset && instance.$attrSelector) {
      var _instance$$style11, _instance$$style11$ge, _instance$$style12;
      var _ref7 = ((_instance$$style11 = instance.$style) === null || _instance$$style11 === void 0 || (_instance$$style11$ge = _instance$$style11.getPresetTheme) === null || _instance$$style11$ge === void 0 ? void 0 : _instance$$style11$ge.call(_instance$$style11, preset, "[".concat(instance.$attrSelector, "]"))) || {}, css4 = _ref7.css;
      var scopedStyle = (_instance$$style12 = instance.$style) === null || _instance$$style12 === void 0 ? void 0 : _instance$$style12.load(css4, _objectSpread$p({
        name: "".concat(instance.$attrSelector, "-").concat(instance.$style.name)
      }, useStyleOptions));
      instance.scopedStyleEl = scopedStyle.el;
    }
  }, "_loadScopedThemeStyles"),
  _themeChangeListener: /* @__PURE__ */ __name(function _themeChangeListener() {
    var callback = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : function() {
    };
    Base$1.clearLoadedStyleNames();
    service_default$1.on("theme:change", callback);
  }, "_themeChangeListener"),
  _hook: /* @__PURE__ */ __name(function _hook(directiveName, hookName, el, binding, vnode, prevVnode) {
    var _binding$value, _config$pt;
    var name2 = "on".concat(toCapitalCase$2(hookName));
    var config2 = BaseDirective._getConfig(binding, vnode);
    var instance = el === null || el === void 0 ? void 0 : el.$instance;
    var selfHook = BaseDirective._usePT(instance, BaseDirective._getPT(binding === null || binding === void 0 || (_binding$value = binding.value) === null || _binding$value === void 0 ? void 0 : _binding$value.pt, directiveName), BaseDirective._getOptionValue, "hooks.".concat(name2));
    var defaultHook = BaseDirective._useDefaultPT(instance, config2 === null || config2 === void 0 || (_config$pt = config2.pt) === null || _config$pt === void 0 || (_config$pt = _config$pt.directives) === null || _config$pt === void 0 ? void 0 : _config$pt[directiveName], BaseDirective._getOptionValue, "hooks.".concat(name2));
    var options5 = {
      el,
      binding,
      vnode,
      prevVnode
    };
    selfHook === null || selfHook === void 0 || selfHook(instance, options5);
    defaultHook === null || defaultHook === void 0 || defaultHook(instance, options5);
  }, "_hook"),
  _mergeProps: /* @__PURE__ */ __name(function _mergeProps() {
    var fn = arguments.length > 1 ? arguments[1] : void 0;
    for (var _len = arguments.length, args = new Array(_len > 2 ? _len - 2 : 0), _key2 = 2; _key2 < _len; _key2++) {
      args[_key2 - 2] = arguments[_key2];
    }
    return isFunction$d(fn) ? fn.apply(void 0, args) : mergeProps$2.apply(void 0, args);
  }, "_mergeProps"),
  _extend: /* @__PURE__ */ __name(function _extend(name2) {
    var options5 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var handleHook = /* @__PURE__ */ __name(function handleHook2(hook, el, binding, vnode, prevVnode) {
      var _el$$pd, _el$$instance$hook, _el$$instance9, _el$$pd2;
      el._$instances = el._$instances || {};
      var config2 = BaseDirective._getConfig(binding, vnode);
      var $prevInstance = el._$instances[name2] || {};
      var $options = isEmpty$3($prevInstance) ? _objectSpread$p(_objectSpread$p({}, options5), options5 === null || options5 === void 0 ? void 0 : options5.methods) : {};
      el._$instances[name2] = _objectSpread$p(_objectSpread$p({}, $prevInstance), {}, {
        /* new instance variables to pass in directive methods */
        $name: name2,
        $host: el,
        $binding: binding,
        $modifiers: binding === null || binding === void 0 ? void 0 : binding.modifiers,
        $value: binding === null || binding === void 0 ? void 0 : binding.value,
        $el: $prevInstance["$el"] || el || void 0,
        $style: _objectSpread$p({
          classes: void 0,
          inlineStyles: void 0,
          load: /* @__PURE__ */ __name(function load3() {
          }, "load"),
          loadCSS: /* @__PURE__ */ __name(function loadCSS3() {
          }, "loadCSS"),
          loadTheme: /* @__PURE__ */ __name(function loadTheme3() {
          }, "loadTheme")
        }, options5 === null || options5 === void 0 ? void 0 : options5.style),
        $primevueConfig: config2,
        $attrSelector: (_el$$pd = el.$pd) === null || _el$$pd === void 0 || (_el$$pd = _el$$pd[name2]) === null || _el$$pd === void 0 ? void 0 : _el$$pd.attrSelector,
        /* computed instance variables */
        defaultPT: /* @__PURE__ */ __name(function defaultPT3() {
          return BaseDirective._getPT(config2 === null || config2 === void 0 ? void 0 : config2.pt, void 0, function(value3) {
            var _value$directives;
            return value3 === null || value3 === void 0 || (_value$directives = value3.directives) === null || _value$directives === void 0 ? void 0 : _value$directives[name2];
          });
        }, "defaultPT"),
        isUnstyled: /* @__PURE__ */ __name(function isUnstyled3() {
          var _el$$instance, _el$$instance2;
          return ((_el$$instance = el.$instance) === null || _el$$instance === void 0 || (_el$$instance = _el$$instance.$binding) === null || _el$$instance === void 0 || (_el$$instance = _el$$instance.value) === null || _el$$instance === void 0 ? void 0 : _el$$instance.unstyled) !== void 0 ? (_el$$instance2 = el.$instance) === null || _el$$instance2 === void 0 || (_el$$instance2 = _el$$instance2.$binding) === null || _el$$instance2 === void 0 || (_el$$instance2 = _el$$instance2.value) === null || _el$$instance2 === void 0 ? void 0 : _el$$instance2.unstyled : config2 === null || config2 === void 0 ? void 0 : config2.unstyled;
        }, "isUnstyled"),
        theme: /* @__PURE__ */ __name(function theme47() {
          var _el$$instance3;
          return (_el$$instance3 = el.$instance) === null || _el$$instance3 === void 0 || (_el$$instance3 = _el$$instance3.$primevueConfig) === null || _el$$instance3 === void 0 ? void 0 : _el$$instance3.theme;
        }, "theme"),
        preset: /* @__PURE__ */ __name(function preset() {
          var _el$$instance4;
          return (_el$$instance4 = el.$instance) === null || _el$$instance4 === void 0 || (_el$$instance4 = _el$$instance4.$binding) === null || _el$$instance4 === void 0 || (_el$$instance4 = _el$$instance4.value) === null || _el$$instance4 === void 0 ? void 0 : _el$$instance4.dt;
        }, "preset"),
        /* instance's methods */
        ptm: /* @__PURE__ */ __name(function ptm3() {
          var _el$$instance5;
          var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
          var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
          return BaseDirective._getPTValue(el.$instance, (_el$$instance5 = el.$instance) === null || _el$$instance5 === void 0 || (_el$$instance5 = _el$$instance5.$binding) === null || _el$$instance5 === void 0 || (_el$$instance5 = _el$$instance5.value) === null || _el$$instance5 === void 0 ? void 0 : _el$$instance5.pt, key, _objectSpread$p({}, params));
        }, "ptm"),
        ptmo: /* @__PURE__ */ __name(function ptmo3() {
          var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
          var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
          var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
          return BaseDirective._getPTValue(el.$instance, obj, key, params, false);
        }, "ptmo"),
        cx: /* @__PURE__ */ __name(function cx3() {
          var _el$$instance6, _el$$instance7;
          var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
          var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
          return !((_el$$instance6 = el.$instance) !== null && _el$$instance6 !== void 0 && _el$$instance6.isUnstyled()) ? BaseDirective._getOptionValue((_el$$instance7 = el.$instance) === null || _el$$instance7 === void 0 || (_el$$instance7 = _el$$instance7.$style) === null || _el$$instance7 === void 0 ? void 0 : _el$$instance7.classes, key, _objectSpread$p({}, params)) : void 0;
        }, "cx"),
        sx: /* @__PURE__ */ __name(function sx3() {
          var _el$$instance8;
          var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
          var when = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
          var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
          return when ? BaseDirective._getOptionValue((_el$$instance8 = el.$instance) === null || _el$$instance8 === void 0 || (_el$$instance8 = _el$$instance8.$style) === null || _el$$instance8 === void 0 ? void 0 : _el$$instance8.inlineStyles, key, _objectSpread$p({}, params)) : void 0;
        }, "sx")
      }, $options);
      el.$instance = el._$instances[name2];
      (_el$$instance$hook = (_el$$instance9 = el.$instance)[hook]) === null || _el$$instance$hook === void 0 || _el$$instance$hook.call(_el$$instance9, el, binding, vnode, prevVnode);
      el["$".concat(name2)] = el.$instance;
      BaseDirective._hook(name2, hook, el, binding, vnode, prevVnode);
      el.$pd || (el.$pd = {});
      el.$pd[name2] = _objectSpread$p(_objectSpread$p({}, (_el$$pd2 = el.$pd) === null || _el$$pd2 === void 0 ? void 0 : _el$$pd2[name2]), {}, {
        name: name2,
        instance: el.$instance
      });
    }, "handleHook");
    var handleWatch = /* @__PURE__ */ __name(function handleWatch2(el) {
      var _el$$instance10, _watchers$config, _el$$instance11, _watchers$configRipp, _el$$instance12;
      var watchers = (_el$$instance10 = el.$instance) === null || _el$$instance10 === void 0 ? void 0 : _el$$instance10.watch;
      watchers === null || watchers === void 0 || (_watchers$config = watchers["config"]) === null || _watchers$config === void 0 || _watchers$config.call(el.$instance, (_el$$instance11 = el.$instance) === null || _el$$instance11 === void 0 ? void 0 : _el$$instance11.$primevueConfig);
      PrimeVueService.on("config:change", function(_ref8) {
        var _watchers$config2;
        var newValue2 = _ref8.newValue, oldValue = _ref8.oldValue;
        return watchers === null || watchers === void 0 || (_watchers$config2 = watchers["config"]) === null || _watchers$config2 === void 0 ? void 0 : _watchers$config2.call(el.$instance, newValue2, oldValue);
      });
      watchers === null || watchers === void 0 || (_watchers$configRipp = watchers["config.ripple"]) === null || _watchers$configRipp === void 0 || _watchers$configRipp.call(el.$instance, (_el$$instance12 = el.$instance) === null || _el$$instance12 === void 0 || (_el$$instance12 = _el$$instance12.$primevueConfig) === null || _el$$instance12 === void 0 ? void 0 : _el$$instance12.ripple);
      PrimeVueService.on("config:ripple:change", function(_ref9) {
        var _watchers$configRipp2;
        var newValue2 = _ref9.newValue, oldValue = _ref9.oldValue;
        return watchers === null || watchers === void 0 || (_watchers$configRipp2 = watchers["config.ripple"]) === null || _watchers$configRipp2 === void 0 ? void 0 : _watchers$configRipp2.call(el.$instance, newValue2, oldValue);
      });
    }, "handleWatch");
    return {
      created: /* @__PURE__ */ __name(function created4(el, binding, vnode, prevVnode) {
        el.$pd || (el.$pd = {});
        el.$pd[name2] = {
          name: name2,
          attrSelector: uuid$1("pd")
        };
        handleHook("created", el, binding, vnode, prevVnode);
      }, "created"),
      beforeMount: /* @__PURE__ */ __name(function beforeMount5(el, binding, vnode, prevVnode) {
        BaseDirective._loadStyles(el, binding, vnode);
        handleHook("beforeMount", el, binding, vnode, prevVnode);
        handleWatch(el);
      }, "beforeMount"),
      mounted: /* @__PURE__ */ __name(function mounted30(el, binding, vnode, prevVnode) {
        BaseDirective._loadStyles(el, binding, vnode);
        handleHook("mounted", el, binding, vnode, prevVnode);
      }, "mounted"),
      beforeUpdate: /* @__PURE__ */ __name(function beforeUpdate3(el, binding, vnode, prevVnode) {
        handleHook("beforeUpdate", el, binding, vnode, prevVnode);
      }, "beforeUpdate"),
      updated: /* @__PURE__ */ __name(function updated17(el, binding, vnode, prevVnode) {
        BaseDirective._loadStyles(el, binding, vnode);
        handleHook("updated", el, binding, vnode, prevVnode);
      }, "updated"),
      beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount19(el, binding, vnode, prevVnode) {
        handleHook("beforeUnmount", el, binding, vnode, prevVnode);
      }, "beforeUnmount"),
      unmounted: /* @__PURE__ */ __name(function unmounted7(el, binding, vnode, prevVnode) {
        var _el$$instance13;
        (_el$$instance13 = el.$instance) === null || _el$$instance13 === void 0 || (_el$$instance13 = _el$$instance13.scopedStyleEl) === null || _el$$instance13 === void 0 || (_el$$instance13 = _el$$instance13.value) === null || _el$$instance13 === void 0 || _el$$instance13.remove();
        handleHook("unmounted", el, binding, vnode, prevVnode);
      }, "unmounted")
    };
  }, "_extend"),
  extend: /* @__PURE__ */ __name(function extend3() {
    var _BaseDirective$_getMe = BaseDirective._getMeta.apply(BaseDirective, arguments), _BaseDirective$_getMe2 = _slicedToArray$7(_BaseDirective$_getMe, 2), name2 = _BaseDirective$_getMe2[0], options5 = _BaseDirective$_getMe2[1];
    return _objectSpread$p({
      extend: /* @__PURE__ */ __name(function extend5() {
        var _BaseDirective$_getMe3 = BaseDirective._getMeta.apply(BaseDirective, arguments), _BaseDirective$_getMe4 = _slicedToArray$7(_BaseDirective$_getMe3, 2), _name = _BaseDirective$_getMe4[0], _options = _BaseDirective$_getMe4[1];
        return BaseDirective.extend(_name, _objectSpread$p(_objectSpread$p(_objectSpread$p({}, options5), options5 === null || options5 === void 0 ? void 0 : options5.methods), _options));
      }, "extend")
    }, BaseDirective._extend(name2, options5));
  }, "extend")
};
var theme$H = /* @__PURE__ */ __name(function theme3(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tooltip {\n    position: absolute;\n    display: none;\n    max-width: ".concat(dt2("tooltip.max.width"), ";\n}\n\n.p-tooltip-right,\n.p-tooltip-left {\n    padding: 0 ").concat(dt2("tooltip.gutter"), ";\n}\n\n.p-tooltip-top,\n.p-tooltip-bottom {\n    padding: ").concat(dt2("tooltip.gutter"), " 0;\n}\n\n.p-tooltip-text {\n    white-space: pre-line;\n    word-break: break-word;\n    background: ").concat(dt2("tooltip.background"), ";\n    color: ").concat(dt2("tooltip.color"), ";\n    padding: ").concat(dt2("tooltip.padding"), ";\n    box-shadow: ").concat(dt2("tooltip.shadow"), ";\n    border-radius: ").concat(dt2("tooltip.border.radius"), ";\n}\n\n.p-tooltip-arrow {\n    position: absolute;\n    width: 0;\n    height: 0;\n    border-color: transparent;\n    border-style: solid;\n}\n\n.p-tooltip-right .p-tooltip-arrow {\n    margin-top: calc(-1 * ").concat(dt2("tooltip.gutter"), ");\n    border-width: ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), " 0;\n    border-right-color: ").concat(dt2("tooltip.background"), ";\n}\n\n.p-tooltip-left .p-tooltip-arrow {\n    margin-top: calc(-1 * ").concat(dt2("tooltip.gutter"), ");\n    border-width: ").concat(dt2("tooltip.gutter"), " 0 ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), ";\n    border-left-color: ").concat(dt2("tooltip.background"), ";\n}\n\n.p-tooltip-top .p-tooltip-arrow {\n    margin-left: calc(-1 * ").concat(dt2("tooltip.gutter"), ");\n    border-width: ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), " 0 ").concat(dt2("tooltip.gutter"), ";\n    border-top-color: ").concat(dt2("tooltip.background"), ";\n    border-bottom-color: ").concat(dt2("tooltip.background"), ";\n}\n\n.p-tooltip-bottom .p-tooltip-arrow {\n    margin-left: calc(-1 * ").concat(dt2("tooltip.gutter"), ");\n    border-width: 0 ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), " ").concat(dt2("tooltip.gutter"), ";\n    border-top-color: ").concat(dt2("tooltip.background"), ";\n    border-bottom-color: ").concat(dt2("tooltip.background"), ";\n}\n");
}, "theme");
var classes$N = {
  root: "p-tooltip p-component",
  arrow: "p-tooltip-arrow",
  text: "p-tooltip-text"
};
var TooltipStyle = BaseStyle$1.extend({
  name: "tooltip-directive",
  theme: theme$H,
  classes: classes$N
});
var BaseTooltip = BaseDirective.extend({
  style: TooltipStyle
});
function _slicedToArray$6(r2, e2) {
  return _arrayWithHoles$6(r2) || _iterableToArrayLimit$6(r2, e2) || _unsupportedIterableToArray$k(r2, e2) || _nonIterableRest$6();
}
__name(_slicedToArray$6, "_slicedToArray$6");
function _nonIterableRest$6() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$6, "_nonIterableRest$6");
function _unsupportedIterableToArray$k(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$k(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$k(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$k, "_unsupportedIterableToArray$k");
function _arrayLikeToArray$k(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$k, "_arrayLikeToArray$k");
function _iterableToArrayLimit$6(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$6, "_iterableToArrayLimit$6");
function _arrayWithHoles$6(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$6, "_arrayWithHoles$6");
function _defineProperty$r(e2, r2, t2) {
  return (r2 = _toPropertyKey$o(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$r, "_defineProperty$r");
function _toPropertyKey$o(t2) {
  var i2 = _toPrimitive$o(t2, "string");
  return "symbol" == _typeof$p(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$o, "_toPropertyKey$o");
function _toPrimitive$o(t2, r2) {
  if ("object" != _typeof$p(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$p(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$o, "_toPrimitive$o");
function _typeof$p(o2) {
  "@babel/helpers - typeof";
  return _typeof$p = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$p(o2);
}
__name(_typeof$p, "_typeof$p");
var Tooltip = BaseTooltip.extend("tooltip", {
  beforeMount: /* @__PURE__ */ __name(function beforeMount(el, options5) {
    var _options$instance$$pr;
    var target2 = this.getTarget(el);
    target2.$_ptooltipModifiers = this.getModifiers(options5);
    if (!options5.value) return;
    else if (typeof options5.value === "string") {
      target2.$_ptooltipValue = options5.value;
      target2.$_ptooltipDisabled = false;
      target2.$_ptooltipEscape = true;
      target2.$_ptooltipClass = null;
      target2.$_ptooltipFitContent = true;
      target2.$_ptooltipIdAttr = UniqueComponentId() + "_tooltip";
      target2.$_ptooltipShowDelay = 0;
      target2.$_ptooltipHideDelay = 0;
      target2.$_ptooltipAutoHide = true;
    } else if (_typeof$p(options5.value) === "object" && options5.value) {
      if (isEmpty$3(options5.value.value) || options5.value.value.trim() === "") return;
      else {
        target2.$_ptooltipValue = options5.value.value;
        target2.$_ptooltipDisabled = !!options5.value.disabled === options5.value.disabled ? options5.value.disabled : false;
        target2.$_ptooltipEscape = !!options5.value.escape === options5.value.escape ? options5.value.escape : true;
        target2.$_ptooltipClass = options5.value["class"] || "";
        target2.$_ptooltipFitContent = !!options5.value.fitContent === options5.value.fitContent ? options5.value.fitContent : true;
        target2.$_ptooltipIdAttr = options5.value.id || UniqueComponentId() + "_tooltip";
        target2.$_ptooltipShowDelay = options5.value.showDelay || 0;
        target2.$_ptooltipHideDelay = options5.value.hideDelay || 0;
        target2.$_ptooltipAutoHide = !!options5.value.autoHide === options5.value.autoHide ? options5.value.autoHide : true;
      }
    }
    target2.$_ptooltipZIndex = (_options$instance$$pr = options5.instance.$primevue) === null || _options$instance$$pr === void 0 || (_options$instance$$pr = _options$instance$$pr.config) === null || _options$instance$$pr === void 0 || (_options$instance$$pr = _options$instance$$pr.zIndex) === null || _options$instance$$pr === void 0 ? void 0 : _options$instance$$pr.tooltip;
    this.bindEvents(target2, options5);
    el.setAttribute("data-pd-tooltip", true);
  }, "beforeMount"),
  updated: /* @__PURE__ */ __name(function updated(el, options5) {
    var target2 = this.getTarget(el);
    target2.$_ptooltipModifiers = this.getModifiers(options5);
    this.unbindEvents(target2);
    if (!options5.value) {
      return;
    }
    if (typeof options5.value === "string") {
      target2.$_ptooltipValue = options5.value;
      target2.$_ptooltipDisabled = false;
      target2.$_ptooltipEscape = true;
      target2.$_ptooltipClass = null;
      target2.$_ptooltipIdAttr = target2.$_ptooltipIdAttr || UniqueComponentId() + "_tooltip";
      target2.$_ptooltipShowDelay = 0;
      target2.$_ptooltipHideDelay = 0;
      target2.$_ptooltipAutoHide = true;
      this.bindEvents(target2, options5);
    } else if (_typeof$p(options5.value) === "object" && options5.value) {
      if (isEmpty$3(options5.value.value) || options5.value.value.trim() === "") {
        this.unbindEvents(target2, options5);
        return;
      } else {
        target2.$_ptooltipValue = options5.value.value;
        target2.$_ptooltipDisabled = !!options5.value.disabled === options5.value.disabled ? options5.value.disabled : false;
        target2.$_ptooltipEscape = !!options5.value.escape === options5.value.escape ? options5.value.escape : true;
        target2.$_ptooltipClass = options5.value["class"] || "";
        target2.$_ptooltipFitContent = !!options5.value.fitContent === options5.value.fitContent ? options5.value.fitContent : true;
        target2.$_ptooltipIdAttr = options5.value.id || target2.$_ptooltipIdAttr || UniqueComponentId() + "_tooltip";
        target2.$_ptooltipShowDelay = options5.value.showDelay || 0;
        target2.$_ptooltipHideDelay = options5.value.hideDelay || 0;
        target2.$_ptooltipAutoHide = !!options5.value.autoHide === options5.value.autoHide ? options5.value.autoHide : true;
        this.bindEvents(target2, options5);
      }
    }
  }, "updated"),
  unmounted: /* @__PURE__ */ __name(function unmounted(el, options5) {
    var target2 = this.getTarget(el);
    this.remove(target2);
    this.unbindEvents(target2, options5);
    if (target2.$_ptooltipScrollHandler) {
      target2.$_ptooltipScrollHandler.destroy();
      target2.$_ptooltipScrollHandler = null;
    }
  }, "unmounted"),
  timer: void 0,
  methods: {
    bindEvents: /* @__PURE__ */ __name(function bindEvents(el, options5) {
      var _this = this;
      var modifiers2 = el.$_ptooltipModifiers;
      if (modifiers2.focus) {
        el.$_focusevent = function(event) {
          return _this.onFocus(event, options5);
        };
        el.addEventListener("focus", el.$_focusevent);
        el.addEventListener("blur", this.onBlur.bind(this));
      } else {
        el.$_mouseenterevent = function(event) {
          return _this.onMouseEnter(event, options5);
        };
        el.addEventListener("mouseenter", el.$_mouseenterevent);
        el.addEventListener("mouseleave", this.onMouseLeave.bind(this));
        el.addEventListener("click", this.onClick.bind(this));
      }
      el.addEventListener("keydown", this.onKeydown.bind(this));
    }, "bindEvents"),
    unbindEvents: /* @__PURE__ */ __name(function unbindEvents(el) {
      var modifiers2 = el.$_ptooltipModifiers;
      if (modifiers2.focus) {
        el.removeEventListener("focus", el.$_focusevent);
        el.$_focusevent = null;
        el.removeEventListener("blur", this.onBlur.bind(this));
      } else {
        el.removeEventListener("mouseenter", el.$_mouseenterevent);
        el.$_mouseenterevent = null;
        el.removeEventListener("mouseleave", this.onMouseLeave.bind(this));
        el.removeEventListener("click", this.onClick.bind(this));
      }
      el.removeEventListener("keydown", this.onKeydown.bind(this));
    }, "unbindEvents"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener(el) {
      var _this2 = this;
      if (!el.$_ptooltipScrollHandler) {
        el.$_ptooltipScrollHandler = new ConnectedOverlayScrollHandler(el, function() {
          _this2.hide(el);
        });
      }
      el.$_ptooltipScrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener(el) {
      if (el.$_ptooltipScrollHandler) {
        el.$_ptooltipScrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    onMouseEnter: /* @__PURE__ */ __name(function onMouseEnter(event, options5) {
      var el = event.currentTarget;
      var showDelay = el.$_ptooltipShowDelay;
      this.show(el, options5, showDelay);
    }, "onMouseEnter"),
    onMouseLeave: /* @__PURE__ */ __name(function onMouseLeave(event) {
      var el = event.currentTarget;
      var hideDelay = el.$_ptooltipHideDelay;
      var autoHide = el.$_ptooltipAutoHide;
      if (!autoHide) {
        var valid = getAttribute$1(event.target, "data-pc-name") === "tooltip" || getAttribute$1(event.target, "data-pc-section") === "arrow" || getAttribute$1(event.target, "data-pc-section") === "text" || getAttribute$1(event.relatedTarget, "data-pc-name") === "tooltip" || getAttribute$1(event.relatedTarget, "data-pc-section") === "arrow" || getAttribute$1(event.relatedTarget, "data-pc-section") === "text";
        !valid && this.hide(el, hideDelay);
      } else {
        this.hide(el, hideDelay);
      }
    }, "onMouseLeave"),
    onFocus: /* @__PURE__ */ __name(function onFocus(event, options5) {
      var el = event.currentTarget;
      var showDelay = el.$_ptooltipShowDelay;
      this.show(el, options5, showDelay);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur(event) {
      var el = event.currentTarget;
      var hideDelay = el.$_ptooltipHideDelay;
      this.hide(el, hideDelay);
    }, "onBlur"),
    onClick: /* @__PURE__ */ __name(function onClick(event) {
      var el = event.currentTarget;
      var hideDelay = el.$_ptooltipHideDelay;
      this.hide(el, hideDelay);
    }, "onClick"),
    onKeydown: /* @__PURE__ */ __name(function onKeydown(event) {
      var el = event.currentTarget;
      var hideDelay = el.$_ptooltipHideDelay;
      event.code === "Escape" && this.hide(event.currentTarget, hideDelay);
    }, "onKeydown"),
    tooltipActions: /* @__PURE__ */ __name(function tooltipActions(el, options5) {
      if (el.$_ptooltipDisabled || !isExist$1(el)) {
        return;
      }
      var tooltipElement = this.create(el, options5);
      this.align(el);
      !this.isUnstyled() && fadeIn$1(tooltipElement, 250);
      var $this = this;
      window.addEventListener("resize", /* @__PURE__ */ __name(function onWindowResize() {
        if (!isTouchDevice$1()) {
          $this.hide(el);
        }
        window.removeEventListener("resize", onWindowResize);
      }, "onWindowResize"));
      tooltipElement.addEventListener("mouseleave", /* @__PURE__ */ __name(function onTooltipLeave() {
        $this.hide(el);
        tooltipElement.removeEventListener("mouseleave", onTooltipLeave);
        el.removeEventListener("mouseenter", el.$_mouseenterevent);
        setTimeout(function() {
          return el.addEventListener("mouseenter", el.$_mouseenterevent);
        }, 50);
      }, "onTooltipLeave"));
      this.bindScrollListener(el);
      ZIndex$1.set("tooltip", tooltipElement, el.$_ptooltipZIndex);
    }, "tooltipActions"),
    show: /* @__PURE__ */ __name(function show(el, options5, showDelay) {
      var _this3 = this;
      if (showDelay !== void 0) {
        this.timer = setTimeout(function() {
          return _this3.tooltipActions(el, options5);
        }, showDelay);
      } else {
        this.tooltipActions(el, options5);
      }
    }, "show"),
    tooltipRemoval: /* @__PURE__ */ __name(function tooltipRemoval(el) {
      this.remove(el);
      this.unbindScrollListener(el);
    }, "tooltipRemoval"),
    hide: /* @__PURE__ */ __name(function hide(el, hideDelay) {
      var _this4 = this;
      clearTimeout(this.timer);
      if (hideDelay !== void 0) {
        setTimeout(function() {
          return _this4.tooltipRemoval(el);
        }, hideDelay);
      } else {
        this.tooltipRemoval(el);
      }
    }, "hide"),
    getTooltipElement: /* @__PURE__ */ __name(function getTooltipElement(el) {
      return document.getElementById(el.$_ptooltipId);
    }, "getTooltipElement"),
    create: /* @__PURE__ */ __name(function create2(el) {
      var modifiers2 = el.$_ptooltipModifiers;
      var tooltipArrow = createElement$1("div", {
        "class": !this.isUnstyled() && this.cx("arrow"),
        "p-bind": this.ptm("arrow", {
          context: modifiers2
        })
      });
      var tooltipText = createElement$1("div", {
        "class": !this.isUnstyled() && this.cx("text"),
        "p-bind": this.ptm("text", {
          context: modifiers2
        })
      });
      if (!el.$_ptooltipEscape) {
        tooltipText.innerHTML = el.$_ptooltipValue;
      } else {
        tooltipText.innerHTML = "";
        tooltipText.appendChild(document.createTextNode(el.$_ptooltipValue));
      }
      var container = createElement$1("div", _defineProperty$r(_defineProperty$r({
        id: el.$_ptooltipIdAttr,
        role: "tooltip",
        style: {
          display: "inline-block",
          width: el.$_ptooltipFitContent ? "fit-content" : void 0,
          pointerEvents: !this.isUnstyled() && el.$_ptooltipAutoHide && "none"
        },
        "class": [!this.isUnstyled() && this.cx("root"), el.$_ptooltipClass]
      }, this.$attrSelector, ""), "p-bind", this.ptm("root", {
        context: modifiers2
      })), tooltipArrow, tooltipText);
      document.body.appendChild(container);
      el.$_ptooltipId = container.id;
      this.$el = container;
      return container;
    }, "create"),
    remove: /* @__PURE__ */ __name(function remove2(el) {
      if (el) {
        var tooltipElement = this.getTooltipElement(el);
        if (tooltipElement && tooltipElement.parentElement) {
          ZIndex$1.clear(tooltipElement);
          document.body.removeChild(tooltipElement);
        }
        el.$_ptooltipId = null;
      }
    }, "remove"),
    align: /* @__PURE__ */ __name(function align(el) {
      var modifiers2 = el.$_ptooltipModifiers;
      if (modifiers2.top) {
        this.alignTop(el);
        if (this.isOutOfBounds(el)) {
          this.alignBottom(el);
          if (this.isOutOfBounds(el)) {
            this.alignTop(el);
          }
        }
      } else if (modifiers2.left) {
        this.alignLeft(el);
        if (this.isOutOfBounds(el)) {
          this.alignRight(el);
          if (this.isOutOfBounds(el)) {
            this.alignTop(el);
            if (this.isOutOfBounds(el)) {
              this.alignBottom(el);
              if (this.isOutOfBounds(el)) {
                this.alignLeft(el);
              }
            }
          }
        }
      } else if (modifiers2.bottom) {
        this.alignBottom(el);
        if (this.isOutOfBounds(el)) {
          this.alignTop(el);
          if (this.isOutOfBounds(el)) {
            this.alignBottom(el);
          }
        }
      } else {
        this.alignRight(el);
        if (this.isOutOfBounds(el)) {
          this.alignLeft(el);
          if (this.isOutOfBounds(el)) {
            this.alignTop(el);
            if (this.isOutOfBounds(el)) {
              this.alignBottom(el);
              if (this.isOutOfBounds(el)) {
                this.alignRight(el);
              }
            }
          }
        }
      }
    }, "align"),
    getHostOffset: /* @__PURE__ */ __name(function getHostOffset(el) {
      var offset = el.getBoundingClientRect();
      var targetLeft = offset.left + getWindowScrollLeft$1();
      var targetTop = offset.top + getWindowScrollTop$1();
      return {
        left: targetLeft,
        top: targetTop
      };
    }, "getHostOffset"),
    alignRight: /* @__PURE__ */ __name(function alignRight(el) {
      this.preAlign(el, "right");
      var tooltipElement = this.getTooltipElement(el);
      var hostOffset = this.getHostOffset(el);
      var left = hostOffset.left + getOuterWidth$1(el);
      var top = hostOffset.top + (getOuterHeight$1(el) - getOuterHeight$1(tooltipElement)) / 2;
      tooltipElement.style.left = left + "px";
      tooltipElement.style.top = top + "px";
    }, "alignRight"),
    alignLeft: /* @__PURE__ */ __name(function alignLeft(el) {
      this.preAlign(el, "left");
      var tooltipElement = this.getTooltipElement(el);
      var hostOffset = this.getHostOffset(el);
      var left = hostOffset.left - getOuterWidth$1(tooltipElement);
      var top = hostOffset.top + (getOuterHeight$1(el) - getOuterHeight$1(tooltipElement)) / 2;
      tooltipElement.style.left = left + "px";
      tooltipElement.style.top = top + "px";
    }, "alignLeft"),
    alignTop: /* @__PURE__ */ __name(function alignTop(el) {
      this.preAlign(el, "top");
      var tooltipElement = this.getTooltipElement(el);
      var hostOffset = this.getHostOffset(el);
      var left = hostOffset.left + (getOuterWidth$1(el) - getOuterWidth$1(tooltipElement)) / 2;
      var top = hostOffset.top - getOuterHeight$1(tooltipElement);
      tooltipElement.style.left = left + "px";
      tooltipElement.style.top = top + "px";
    }, "alignTop"),
    alignBottom: /* @__PURE__ */ __name(function alignBottom(el) {
      this.preAlign(el, "bottom");
      var tooltipElement = this.getTooltipElement(el);
      var hostOffset = this.getHostOffset(el);
      var left = hostOffset.left + (getOuterWidth$1(el) - getOuterWidth$1(tooltipElement)) / 2;
      var top = hostOffset.top + getOuterHeight$1(el);
      tooltipElement.style.left = left + "px";
      tooltipElement.style.top = top + "px";
    }, "alignBottom"),
    preAlign: /* @__PURE__ */ __name(function preAlign(el, position3) {
      var tooltipElement = this.getTooltipElement(el);
      tooltipElement.style.left = "-999px";
      tooltipElement.style.top = "-999px";
      removeClass$1(tooltipElement, "p-tooltip-".concat(tooltipElement.$_ptooltipPosition));
      !this.isUnstyled() && addClass$1(tooltipElement, "p-tooltip-".concat(position3));
      tooltipElement.$_ptooltipPosition = position3;
      tooltipElement.setAttribute("data-p-position", position3);
      var arrowElement = findSingle$1(tooltipElement, '[data-pc-section="arrow"]');
      arrowElement.style.top = position3 === "bottom" ? "0" : position3 === "right" || position3 === "left" || position3 !== "right" && position3 !== "left" && position3 !== "top" && position3 !== "bottom" ? "50%" : null;
      arrowElement.style.bottom = position3 === "top" ? "0" : null;
      arrowElement.style.left = position3 === "right" || position3 !== "right" && position3 !== "left" && position3 !== "top" && position3 !== "bottom" ? "0" : position3 === "top" || position3 === "bottom" ? "50%" : null;
      arrowElement.style.right = position3 === "left" ? "0" : null;
    }, "preAlign"),
    isOutOfBounds: /* @__PURE__ */ __name(function isOutOfBounds(el) {
      var tooltipElement = this.getTooltipElement(el);
      var offset = tooltipElement.getBoundingClientRect();
      var targetTop = offset.top;
      var targetLeft = offset.left;
      var width2 = getOuterWidth$1(tooltipElement);
      var height = getOuterHeight$1(tooltipElement);
      var viewport = getViewport$1();
      return targetLeft + width2 > viewport.width || targetLeft < 0 || targetTop < 0 || targetTop + height > viewport.height;
    }, "isOutOfBounds"),
    getTarget: /* @__PURE__ */ __name(function getTarget2(el) {
      var _findSingle;
      return hasClass$1(el, "p-inputwrapper") ? (_findSingle = findSingle$1(el, "input")) !== null && _findSingle !== void 0 ? _findSingle : el : el;
    }, "getTarget"),
    getModifiers: /* @__PURE__ */ __name(function getModifiers(options5) {
      if (options5.modifiers && Object.keys(options5.modifiers).length) {
        return options5.modifiers;
      }
      if (options5.arg && _typeof$p(options5.arg) === "object") {
        return Object.entries(options5.arg).reduce(function(acc, _ref) {
          var _ref2 = _slicedToArray$6(_ref, 2), key = _ref2[0], val = _ref2[1];
          if (key === "event" || key === "position") acc[val] = true;
          return acc;
        }, {});
      }
      return {};
    }, "getModifiers")
  }
});
const scriptRel = "modulepreload";
const assetsURL = /* @__PURE__ */ __name(function(dep, importerUrl) {
  return new URL(dep, importerUrl).href;
}, "assetsURL");
const seen = {};
const __vitePreload = /* @__PURE__ */ __name(function preload(baseModule, deps, importerUrl) {
  let promise = Promise.resolve();
  if (deps && deps.length > 0) {
    const links = document.getElementsByTagName("link");
    const cspNonceMeta = document.querySelector(
      "meta[property=csp-nonce]"
    );
    const cspNonce = cspNonceMeta?.nonce || cspNonceMeta?.getAttribute("nonce");
    promise = Promise.allSettled(
      deps.map((dep) => {
        dep = assetsURL(dep, importerUrl);
        if (dep in seen) return;
        seen[dep] = true;
        const isCss = dep.endsWith(".css");
        const cssSelector = isCss ? '[rel="stylesheet"]' : "";
        const isBaseRelative = !!importerUrl;
        if (isBaseRelative) {
          for (let i2 = links.length - 1; i2 >= 0; i2--) {
            const link22 = links[i2];
            if (link22.href === dep && (!isCss || link22.rel === "stylesheet")) {
              return;
            }
          }
        } else if (document.querySelector(`link[href="${dep}"]${cssSelector}`)) {
          return;
        }
        const link2 = document.createElement("link");
        link2.rel = isCss ? "stylesheet" : scriptRel;
        if (!isCss) {
          link2.as = "script";
        }
        link2.crossOrigin = "";
        link2.href = dep;
        if (cspNonce) {
          link2.setAttribute("nonce", cspNonce);
        }
        document.head.appendChild(link2);
        if (isCss) {
          return new Promise((res, rej) => {
            link2.addEventListener("load", res);
            link2.addEventListener(
              "error",
              () => rej(new Error(`Unable to preload CSS for ${dep}`))
            );
          });
        }
      })
    );
  }
  function handlePreloadError(err) {
    const e2 = new Event("vite:preloadError", {
      cancelable: true
    });
    e2.payload = err;
    window.dispatchEvent(e2);
    if (!e2.defaultPrevented) {
      throw err;
    }
  }
  __name(handlePreloadError, "handlePreloadError");
  return promise.then((res) => {
    for (const item3 of res || []) {
      if (item3.status !== "rejected") continue;
      handlePreloadError(item3.reason);
    }
    return baseModule().catch(handlePreloadError);
  });
}, "preload");
/*!
  * vue-router v4.4.3
  * (c) 2024 Eduardo San Martin Morote
  * @license MIT
  */
const isBrowser = typeof document !== "undefined";
function isESModule(obj) {
  return obj.__esModule || obj[Symbol.toStringTag] === "Module";
}
__name(isESModule, "isESModule");
const assign$5 = Object.assign;
function applyToParams(fn, params) {
  const newParams = {};
  for (const key in params) {
    const value3 = params[key];
    newParams[key] = isArray$a(value3) ? value3.map(fn) : fn(value3);
  }
  return newParams;
}
__name(applyToParams, "applyToParams");
const noop$3 = /* @__PURE__ */ __name(() => {
}, "noop$3");
const isArray$a = Array.isArray;
function warn$2(msg) {
  const args = Array.from(arguments).slice(1);
  console.warn.apply(console, ["[Vue Router warn]: " + msg].concat(args));
}
__name(warn$2, "warn$2");
const HASH_RE = /#/g;
const AMPERSAND_RE = /&/g;
const SLASH_RE = /\//g;
const EQUAL_RE = /=/g;
const IM_RE = /\?/g;
const PLUS_RE = /\+/g;
const ENC_BRACKET_OPEN_RE = /%5B/g;
const ENC_BRACKET_CLOSE_RE = /%5D/g;
const ENC_CARET_RE = /%5E/g;
const ENC_BACKTICK_RE = /%60/g;
const ENC_CURLY_OPEN_RE = /%7B/g;
const ENC_PIPE_RE = /%7C/g;
const ENC_CURLY_CLOSE_RE = /%7D/g;
const ENC_SPACE_RE = /%20/g;
function commonEncode(text2) {
  return encodeURI("" + text2).replace(ENC_PIPE_RE, "|").replace(ENC_BRACKET_OPEN_RE, "[").replace(ENC_BRACKET_CLOSE_RE, "]");
}
__name(commonEncode, "commonEncode");
function encodeHash(text2) {
  return commonEncode(text2).replace(ENC_CURLY_OPEN_RE, "{").replace(ENC_CURLY_CLOSE_RE, "}").replace(ENC_CARET_RE, "^");
}
__name(encodeHash, "encodeHash");
function encodeQueryValue(text2) {
  return commonEncode(text2).replace(PLUS_RE, "%2B").replace(ENC_SPACE_RE, "+").replace(HASH_RE, "%23").replace(AMPERSAND_RE, "%26").replace(ENC_BACKTICK_RE, "`").replace(ENC_CURLY_OPEN_RE, "{").replace(ENC_CURLY_CLOSE_RE, "}").replace(ENC_CARET_RE, "^");
}
__name(encodeQueryValue, "encodeQueryValue");
function encodeQueryKey(text2) {
  return encodeQueryValue(text2).replace(EQUAL_RE, "%3D");
}
__name(encodeQueryKey, "encodeQueryKey");
function encodePath(text2) {
  return commonEncode(text2).replace(HASH_RE, "%23").replace(IM_RE, "%3F");
}
__name(encodePath, "encodePath");
function encodeParam(text2) {
  return text2 == null ? "" : encodePath(text2).replace(SLASH_RE, "%2F");
}
__name(encodeParam, "encodeParam");
function decode$3(text2) {
  try {
    return decodeURIComponent("" + text2);
  } catch (err) {
  }
  return "" + text2;
}
__name(decode$3, "decode$3");
const TRAILING_SLASH_RE = /\/$/;
const removeTrailingSlash = /* @__PURE__ */ __name((path) => path.replace(TRAILING_SLASH_RE, ""), "removeTrailingSlash");
function parseURL(parseQuery2, location2, currentLocation = "/") {
  let path, query = {}, searchString = "", hash = "";
  const hashPos = location2.indexOf("#");
  let searchPos = location2.indexOf("?");
  if (hashPos < searchPos && hashPos >= 0) {
    searchPos = -1;
  }
  if (searchPos > -1) {
    path = location2.slice(0, searchPos);
    searchString = location2.slice(searchPos + 1, hashPos > -1 ? hashPos : location2.length);
    query = parseQuery2(searchString);
  }
  if (hashPos > -1) {
    path = path || location2.slice(0, hashPos);
    hash = location2.slice(hashPos, location2.length);
  }
  path = resolveRelativePath(path != null ? path : location2, currentLocation);
  return {
    fullPath: path + (searchString && "?") + searchString + hash,
    path,
    query,
    hash: decode$3(hash)
  };
}
__name(parseURL, "parseURL");
function stringifyURL(stringifyQuery2, location2) {
  const query = location2.query ? stringifyQuery2(location2.query) : "";
  return location2.path + (query && "?") + query + (location2.hash || "");
}
__name(stringifyURL, "stringifyURL");
function stripBase(pathname, base2) {
  if (!base2 || !pathname.toLowerCase().startsWith(base2.toLowerCase()))
    return pathname;
  return pathname.slice(base2.length) || "/";
}
__name(stripBase, "stripBase");
function isSameRouteLocation(stringifyQuery2, a2, b2) {
  const aLastIndex = a2.matched.length - 1;
  const bLastIndex = b2.matched.length - 1;
  return aLastIndex > -1 && aLastIndex === bLastIndex && isSameRouteRecord(a2.matched[aLastIndex], b2.matched[bLastIndex]) && isSameRouteLocationParams(a2.params, b2.params) && stringifyQuery2(a2.query) === stringifyQuery2(b2.query) && a2.hash === b2.hash;
}
__name(isSameRouteLocation, "isSameRouteLocation");
function isSameRouteRecord(a2, b2) {
  return (a2.aliasOf || a2) === (b2.aliasOf || b2);
}
__name(isSameRouteRecord, "isSameRouteRecord");
function isSameRouteLocationParams(a2, b2) {
  if (Object.keys(a2).length !== Object.keys(b2).length)
    return false;
  for (const key in a2) {
    if (!isSameRouteLocationParamsValue(a2[key], b2[key]))
      return false;
  }
  return true;
}
__name(isSameRouteLocationParams, "isSameRouteLocationParams");
function isSameRouteLocationParamsValue(a2, b2) {
  return isArray$a(a2) ? isEquivalentArray(a2, b2) : isArray$a(b2) ? isEquivalentArray(b2, a2) : a2 === b2;
}
__name(isSameRouteLocationParamsValue, "isSameRouteLocationParamsValue");
function isEquivalentArray(a2, b2) {
  return isArray$a(b2) ? a2.length === b2.length && a2.every((value3, i2) => value3 === b2[i2]) : a2.length === 1 && a2[0] === b2;
}
__name(isEquivalentArray, "isEquivalentArray");
function resolveRelativePath(to, from2) {
  if (to.startsWith("/"))
    return to;
  if (false) {
    warn$2(`Cannot resolve a relative location without an absolute path. Trying to resolve "${to}" from "${from2}". It should look like "/${from2}".`);
    return to;
  }
  if (!to)
    return from2;
  const fromSegments = from2.split("/");
  const toSegments = to.split("/");
  const lastToSegment = toSegments[toSegments.length - 1];
  if (lastToSegment === ".." || lastToSegment === ".") {
    toSegments.push("");
  }
  let position3 = fromSegments.length - 1;
  let toPosition;
  let segment;
  for (toPosition = 0; toPosition < toSegments.length; toPosition++) {
    segment = toSegments[toPosition];
    if (segment === ".")
      continue;
    if (segment === "..") {
      if (position3 > 1)
        position3--;
    } else
      break;
  }
  return fromSegments.slice(0, position3).join("/") + "/" + toSegments.slice(toPosition).join("/");
}
__name(resolveRelativePath, "resolveRelativePath");
const START_LOCATION_NORMALIZED = {
  path: "/",
  // TODO: could we use a symbol in the future?
  name: void 0,
  params: {},
  query: {},
  hash: "",
  fullPath: "/",
  matched: [],
  meta: {},
  redirectedFrom: void 0
};
var NavigationType;
(function(NavigationType2) {
  NavigationType2["pop"] = "pop";
  NavigationType2["push"] = "push";
})(NavigationType || (NavigationType = {}));
var NavigationDirection;
(function(NavigationDirection2) {
  NavigationDirection2["back"] = "back";
  NavigationDirection2["forward"] = "forward";
  NavigationDirection2["unknown"] = "";
})(NavigationDirection || (NavigationDirection = {}));
const START = "";
function normalizeBase(base2) {
  if (!base2) {
    if (isBrowser) {
      const baseEl = document.querySelector("base");
      base2 = baseEl && baseEl.getAttribute("href") || "/";
      base2 = base2.replace(/^\w+:\/\/[^\/]+/, "");
    } else {
      base2 = "/";
    }
  }
  if (base2[0] !== "/" && base2[0] !== "#")
    base2 = "/" + base2;
  return removeTrailingSlash(base2);
}
__name(normalizeBase, "normalizeBase");
const BEFORE_HASH_RE = /^[^#]+#/;
function createHref(base2, location2) {
  return base2.replace(BEFORE_HASH_RE, "#") + location2;
}
__name(createHref, "createHref");
function getElementPosition(el, offset) {
  const docRect = document.documentElement.getBoundingClientRect();
  const elRect = el.getBoundingClientRect();
  return {
    behavior: offset.behavior,
    left: elRect.left - docRect.left - (offset.left || 0),
    top: elRect.top - docRect.top - (offset.top || 0)
  };
}
__name(getElementPosition, "getElementPosition");
const computeScrollPosition = /* @__PURE__ */ __name(() => ({
  left: window.scrollX,
  top: window.scrollY
}), "computeScrollPosition");
function scrollToPosition(position3) {
  let scrollToOptions;
  if ("el" in position3) {
    const positionEl = position3.el;
    const isIdSelector = typeof positionEl === "string" && positionEl.startsWith("#");
    if (false) {
      if (!isIdSelector || !document.getElementById(position3.el.slice(1))) {
        try {
          const foundEl = document.querySelector(position3.el);
          if (isIdSelector && foundEl) {
            warn$2(`The selector "${position3.el}" should be passed as "el: document.querySelector('${position3.el}')" because it starts with "#".`);
            return;
          }
        } catch (err) {
          warn$2(`The selector "${position3.el}" is invalid. If you are using an id selector, make sure to escape it. You can find more information about escaping characters in selectors at https://mathiasbynens.be/notes/css-escapes or use CSS.escape (https://developer.mozilla.org/en-US/docs/Web/API/CSS/escape).`);
          return;
        }
      }
    }
    const el = typeof positionEl === "string" ? isIdSelector ? document.getElementById(positionEl.slice(1)) : document.querySelector(positionEl) : positionEl;
    if (!el) {
      return;
    }
    scrollToOptions = getElementPosition(el, position3);
  } else {
    scrollToOptions = position3;
  }
  if ("scrollBehavior" in document.documentElement.style)
    window.scrollTo(scrollToOptions);
  else {
    window.scrollTo(scrollToOptions.left != null ? scrollToOptions.left : window.scrollX, scrollToOptions.top != null ? scrollToOptions.top : window.scrollY);
  }
}
__name(scrollToPosition, "scrollToPosition");
function getScrollKey(path, delta2) {
  const position3 = history.state ? history.state.position - delta2 : -1;
  return position3 + path;
}
__name(getScrollKey, "getScrollKey");
const scrollPositions = /* @__PURE__ */ new Map();
function saveScrollPosition(key, scrollPosition) {
  scrollPositions.set(key, scrollPosition);
}
__name(saveScrollPosition, "saveScrollPosition");
function getSavedScrollPosition(key) {
  const scroll = scrollPositions.get(key);
  scrollPositions.delete(key);
  return scroll;
}
__name(getSavedScrollPosition, "getSavedScrollPosition");
let createBaseLocation = /* @__PURE__ */ __name(() => location.protocol + "//" + location.host, "createBaseLocation");
function createCurrentLocation(base2, location2) {
  const { pathname, search: search3, hash } = location2;
  const hashPos = base2.indexOf("#");
  if (hashPos > -1) {
    let slicePos = hash.includes(base2.slice(hashPos)) ? base2.slice(hashPos).length : 1;
    let pathFromHash = hash.slice(slicePos);
    if (pathFromHash[0] !== "/")
      pathFromHash = "/" + pathFromHash;
    return stripBase(pathFromHash, "");
  }
  const path = stripBase(pathname, base2);
  return path + search3 + hash;
}
__name(createCurrentLocation, "createCurrentLocation");
function useHistoryListeners(base2, historyState, currentLocation, replace2) {
  let listeners = [];
  let teardowns = [];
  let pauseState = null;
  const popStateHandler = /* @__PURE__ */ __name(({ state }) => {
    const to = createCurrentLocation(base2, location);
    const from2 = currentLocation.value;
    const fromState = historyState.value;
    let delta2 = 0;
    if (state) {
      currentLocation.value = to;
      historyState.value = state;
      if (pauseState && pauseState === from2) {
        pauseState = null;
        return;
      }
      delta2 = fromState ? state.position - fromState.position : 0;
    } else {
      replace2(to);
    }
    listeners.forEach((listener) => {
      listener(currentLocation.value, from2, {
        delta: delta2,
        type: NavigationType.pop,
        direction: delta2 ? delta2 > 0 ? NavigationDirection.forward : NavigationDirection.back : NavigationDirection.unknown
      });
    });
  }, "popStateHandler");
  function pauseListeners() {
    pauseState = currentLocation.value;
  }
  __name(pauseListeners, "pauseListeners");
  function listen(callback) {
    listeners.push(callback);
    const teardown = /* @__PURE__ */ __name(() => {
      const index2 = listeners.indexOf(callback);
      if (index2 > -1)
        listeners.splice(index2, 1);
    }, "teardown");
    teardowns.push(teardown);
    return teardown;
  }
  __name(listen, "listen");
  function beforeUnloadListener() {
    const { history: history2 } = window;
    if (!history2.state)
      return;
    history2.replaceState(assign$5({}, history2.state, { scroll: computeScrollPosition() }), "");
  }
  __name(beforeUnloadListener, "beforeUnloadListener");
  function destroy() {
    for (const teardown of teardowns)
      teardown();
    teardowns = [];
    window.removeEventListener("popstate", popStateHandler);
    window.removeEventListener("beforeunload", beforeUnloadListener);
  }
  __name(destroy, "destroy");
  window.addEventListener("popstate", popStateHandler);
  window.addEventListener("beforeunload", beforeUnloadListener, {
    passive: true
  });
  return {
    pauseListeners,
    listen,
    destroy
  };
}
__name(useHistoryListeners, "useHistoryListeners");
function buildState(back, current, forward, replaced = false, computeScroll = false) {
  return {
    back,
    current,
    forward,
    replaced,
    position: window.history.length,
    scroll: computeScroll ? computeScrollPosition() : null
  };
}
__name(buildState, "buildState");
function useHistoryStateNavigation(base2) {
  const { history: history2, location: location2 } = window;
  const currentLocation = {
    value: createCurrentLocation(base2, location2)
  };
  const historyState = { value: history2.state };
  if (!historyState.value) {
    changeLocation(currentLocation.value, {
      back: null,
      current: currentLocation.value,
      forward: null,
      // the length is off by one, we need to decrease it
      position: history2.length - 1,
      replaced: true,
      // don't add a scroll as the user may have an anchor, and we want
      // scrollBehavior to be triggered without a saved position
      scroll: null
    }, true);
  }
  function changeLocation(to, state, replace22) {
    const hashIndex = base2.indexOf("#");
    const url = hashIndex > -1 ? (location2.host && document.querySelector("base") ? base2 : base2.slice(hashIndex)) + to : createBaseLocation() + base2 + to;
    try {
      history2[replace22 ? "replaceState" : "pushState"](state, "", url);
      historyState.value = state;
    } catch (err) {
      if (false) {
        warn$2("Error with push/replace State", err);
      } else {
        console.error(err);
      }
      location2[replace22 ? "replace" : "assign"](url);
    }
  }
  __name(changeLocation, "changeLocation");
  function replace2(to, data30) {
    const state = assign$5({}, history2.state, buildState(
      historyState.value.back,
      // keep back and forward entries but override current position
      to,
      historyState.value.forward,
      true
    ), data30, { position: historyState.value.position });
    changeLocation(to, state, true);
    currentLocation.value = to;
  }
  __name(replace2, "replace");
  function push2(to, data30) {
    const currentState = assign$5(
      {},
      // use current history state to gracefully handle a wrong call to
      // history.replaceState
      // https://github.com/vuejs/router/issues/366
      historyState.value,
      history2.state,
      {
        forward: to,
        scroll: computeScrollPosition()
      }
    );
    if (false) {
      warn$2(`history.state seems to have been manually replaced without preserving the necessary values. Make sure to preserve existing history state if you are manually calling history.replaceState:

history.replaceState(history.state, '', url)

You can find more information at https://router.vuejs.org/guide/migration/#Usage-of-history-state`);
    }
    changeLocation(currentState.current, currentState, true);
    const state = assign$5({}, buildState(currentLocation.value, to, null), { position: currentState.position + 1 }, data30);
    changeLocation(to, state, false);
    currentLocation.value = to;
  }
  __name(push2, "push");
  return {
    location: currentLocation,
    state: historyState,
    push: push2,
    replace: replace2
  };
}
__name(useHistoryStateNavigation, "useHistoryStateNavigation");
function createWebHistory(base2) {
  base2 = normalizeBase(base2);
  const historyNavigation = useHistoryStateNavigation(base2);
  const historyListeners = useHistoryListeners(base2, historyNavigation.state, historyNavigation.location, historyNavigation.replace);
  function go(delta2, triggerListeners = true) {
    if (!triggerListeners)
      historyListeners.pauseListeners();
    history.go(delta2);
  }
  __name(go, "go");
  const routerHistory = assign$5({
    // it's overridden right after
    location: "",
    base: base2,
    go,
    createHref: createHref.bind(null, base2)
  }, historyNavigation, historyListeners);
  Object.defineProperty(routerHistory, "location", {
    enumerable: true,
    get: /* @__PURE__ */ __name(() => historyNavigation.location.value, "get")
  });
  Object.defineProperty(routerHistory, "state", {
    enumerable: true,
    get: /* @__PURE__ */ __name(() => historyNavigation.state.value, "get")
  });
  return routerHistory;
}
__name(createWebHistory, "createWebHistory");
function createMemoryHistory(base2 = "") {
  let listeners = [];
  let queue2 = [START];
  let position3 = 0;
  base2 = normalizeBase(base2);
  function setLocation(location2) {
    position3++;
    if (position3 !== queue2.length) {
      queue2.splice(position3);
    }
    queue2.push(location2);
  }
  __name(setLocation, "setLocation");
  function triggerListeners(to, from2, { direction, delta: delta2 }) {
    const info = {
      direction,
      delta: delta2,
      type: NavigationType.pop
    };
    for (const callback of listeners) {
      callback(to, from2, info);
    }
  }
  __name(triggerListeners, "triggerListeners");
  const routerHistory = {
    // rewritten by Object.defineProperty
    location: START,
    // TODO: should be kept in queue
    state: {},
    base: base2,
    createHref: createHref.bind(null, base2),
    replace(to) {
      queue2.splice(position3--, 1);
      setLocation(to);
    },
    push(to, data30) {
      setLocation(to);
    },
    listen(callback) {
      listeners.push(callback);
      return () => {
        const index2 = listeners.indexOf(callback);
        if (index2 > -1)
          listeners.splice(index2, 1);
      };
    },
    destroy() {
      listeners = [];
      queue2 = [START];
      position3 = 0;
    },
    go(delta2, shouldTrigger = true) {
      const from2 = this.location;
      const direction = (
        // we are considering delta === 0 going forward, but in abstract mode
        // using 0 for the delta doesn't make sense like it does in html5 where
        // it reloads the page
        delta2 < 0 ? NavigationDirection.back : NavigationDirection.forward
      );
      position3 = Math.max(0, Math.min(position3 + delta2, queue2.length - 1));
      if (shouldTrigger) {
        triggerListeners(this.location, from2, {
          direction,
          delta: delta2
        });
      }
    }
  };
  Object.defineProperty(routerHistory, "location", {
    enumerable: true,
    get: /* @__PURE__ */ __name(() => queue2[position3], "get")
  });
  return routerHistory;
}
__name(createMemoryHistory, "createMemoryHistory");
function createWebHashHistory(base2) {
  base2 = location.host ? base2 || location.pathname + location.search : "";
  if (!base2.includes("#"))
    base2 += "#";
  if (false) {
    warn$2(`A hash base must end with a "#":
"${base2}" should be "${base2.replace(/#.*$/, "#")}".`);
  }
  return createWebHistory(base2);
}
__name(createWebHashHistory, "createWebHashHistory");
function isRouteLocation(route) {
  return typeof route === "string" || route && typeof route === "object";
}
__name(isRouteLocation, "isRouteLocation");
function isRouteName(name2) {
  return typeof name2 === "string" || typeof name2 === "symbol";
}
__name(isRouteName, "isRouteName");
const NavigationFailureSymbol = Symbol(false ? "navigation failure" : "");
var NavigationFailureType;
(function(NavigationFailureType2) {
  NavigationFailureType2[NavigationFailureType2["aborted"] = 4] = "aborted";
  NavigationFailureType2[NavigationFailureType2["cancelled"] = 8] = "cancelled";
  NavigationFailureType2[NavigationFailureType2["duplicated"] = 16] = "duplicated";
})(NavigationFailureType || (NavigationFailureType = {}));
const ErrorTypeMessages = {
  [
    1
    /* ErrorTypes.MATCHER_NOT_FOUND */
  ]({ location: location2, currentLocation }) {
    return `No match for
 ${JSON.stringify(location2)}${currentLocation ? "\nwhile being at\n" + JSON.stringify(currentLocation) : ""}`;
  },
  [
    2
    /* ErrorTypes.NAVIGATION_GUARD_REDIRECT */
  ]({ from: from2, to }) {
    return `Redirected from "${from2.fullPath}" to "${stringifyRoute(to)}" via a navigation guard.`;
  },
  [
    4
    /* ErrorTypes.NAVIGATION_ABORTED */
  ]({ from: from2, to }) {
    return `Navigation aborted from "${from2.fullPath}" to "${to.fullPath}" via a navigation guard.`;
  },
  [
    8
    /* ErrorTypes.NAVIGATION_CANCELLED */
  ]({ from: from2, to }) {
    return `Navigation cancelled from "${from2.fullPath}" to "${to.fullPath}" with a new navigation.`;
  },
  [
    16
    /* ErrorTypes.NAVIGATION_DUPLICATED */
  ]({ from: from2, to }) {
    return `Avoided redundant navigation to current location: "${from2.fullPath}".`;
  }
};
function createRouterError(type, params) {
  if (false) {
    return assign$5(new Error(ErrorTypeMessages[type](params)), {
      type,
      [NavigationFailureSymbol]: true
    }, params);
  } else {
    return assign$5(new Error(), {
      type,
      [NavigationFailureSymbol]: true
    }, params);
  }
}
__name(createRouterError, "createRouterError");
function isNavigationFailure(error2, type) {
  return error2 instanceof Error && NavigationFailureSymbol in error2 && (type == null || !!(error2.type & type));
}
__name(isNavigationFailure, "isNavigationFailure");
const propertiesToLog = ["params", "query", "hash"];
function stringifyRoute(to) {
  if (typeof to === "string")
    return to;
  if (to.path != null)
    return to.path;
  const location2 = {};
  for (const key of propertiesToLog) {
    if (key in to)
      location2[key] = to[key];
  }
  return JSON.stringify(location2, null, 2);
}
__name(stringifyRoute, "stringifyRoute");
const BASE_PARAM_PATTERN = "[^/]+?";
const BASE_PATH_PARSER_OPTIONS = {
  sensitive: false,
  strict: false,
  start: true,
  end: true
};
const REGEX_CHARS_RE = /[.+*?^${}()[\]/\\]/g;
function tokensToParser(segments, extraOptions) {
  const options5 = assign$5({}, BASE_PATH_PARSER_OPTIONS, extraOptions);
  const score = [];
  let pattern = options5.start ? "^" : "";
  const keys2 = [];
  for (const segment of segments) {
    const segmentScores = segment.length ? [] : [
      90
      /* PathScore.Root */
    ];
    if (options5.strict && !segment.length)
      pattern += "/";
    for (let tokenIndex = 0; tokenIndex < segment.length; tokenIndex++) {
      const token = segment[tokenIndex];
      let subSegmentScore = 40 + (options5.sensitive ? 0.25 : 0);
      if (token.type === 0) {
        if (!tokenIndex)
          pattern += "/";
        pattern += token.value.replace(REGEX_CHARS_RE, "\\$&");
        subSegmentScore += 40;
      } else if (token.type === 1) {
        const { value: value3, repeatable, optional, regexp: regexp2 } = token;
        keys2.push({
          name: value3,
          repeatable,
          optional
        });
        const re2 = regexp2 ? regexp2 : BASE_PARAM_PATTERN;
        if (re2 !== BASE_PARAM_PATTERN) {
          subSegmentScore += 10;
          try {
            new RegExp(`(${re2})`);
          } catch (err) {
            throw new Error(`Invalid custom RegExp for param "${value3}" (${re2}): ` + err.message);
          }
        }
        let subPattern = repeatable ? `((?:${re2})(?:/(?:${re2}))*)` : `(${re2})`;
        if (!tokenIndex)
          subPattern = // avoid an optional / if there are more segments e.g. /:p?-static
          // or /:p?-:p2
          optional && segment.length < 2 ? `(?:/${subPattern})` : "/" + subPattern;
        if (optional)
          subPattern += "?";
        pattern += subPattern;
        subSegmentScore += 20;
        if (optional)
          subSegmentScore += -8;
        if (repeatable)
          subSegmentScore += -20;
        if (re2 === ".*")
          subSegmentScore += -50;
      }
      segmentScores.push(subSegmentScore);
    }
    score.push(segmentScores);
  }
  if (options5.strict && options5.end) {
    const i2 = score.length - 1;
    score[i2][score[i2].length - 1] += 0.7000000000000001;
  }
  if (!options5.strict)
    pattern += "/?";
  if (options5.end)
    pattern += "$";
  else if (options5.strict)
    pattern += "(?:/|$)";
  const re = new RegExp(pattern, options5.sensitive ? "" : "i");
  function parse2(path) {
    const match2 = path.match(re);
    const params = {};
    if (!match2)
      return null;
    for (let i2 = 1; i2 < match2.length; i2++) {
      const value3 = match2[i2] || "";
      const key = keys2[i2 - 1];
      params[key.name] = value3 && key.repeatable ? value3.split("/") : value3;
    }
    return params;
  }
  __name(parse2, "parse");
  function stringify2(params) {
    let path = "";
    let avoidDuplicatedSlash = false;
    for (const segment of segments) {
      if (!avoidDuplicatedSlash || !path.endsWith("/"))
        path += "/";
      avoidDuplicatedSlash = false;
      for (const token of segment) {
        if (token.type === 0) {
          path += token.value;
        } else if (token.type === 1) {
          const { value: value3, repeatable, optional } = token;
          const param = value3 in params ? params[value3] : "";
          if (isArray$a(param) && !repeatable) {
            throw new Error(`Provided param "${value3}" is an array but it is not repeatable (* or + modifiers)`);
          }
          const text2 = isArray$a(param) ? param.join("/") : param;
          if (!text2) {
            if (optional) {
              if (segment.length < 2) {
                if (path.endsWith("/"))
                  path = path.slice(0, -1);
                else
                  avoidDuplicatedSlash = true;
              }
            } else
              throw new Error(`Missing required param "${value3}"`);
          }
          path += text2;
        }
      }
    }
    return path || "/";
  }
  __name(stringify2, "stringify");
  return {
    re,
    score,
    keys: keys2,
    parse: parse2,
    stringify: stringify2
  };
}
__name(tokensToParser, "tokensToParser");
function compareScoreArray(a2, b2) {
  let i2 = 0;
  while (i2 < a2.length && i2 < b2.length) {
    const diff2 = b2[i2] - a2[i2];
    if (diff2)
      return diff2;
    i2++;
  }
  if (a2.length < b2.length) {
    return a2.length === 1 && a2[0] === 40 + 40 ? -1 : 1;
  } else if (a2.length > b2.length) {
    return b2.length === 1 && b2[0] === 40 + 40 ? 1 : -1;
  }
  return 0;
}
__name(compareScoreArray, "compareScoreArray");
function comparePathParserScore(a2, b2) {
  let i2 = 0;
  const aScore = a2.score;
  const bScore = b2.score;
  while (i2 < aScore.length && i2 < bScore.length) {
    const comp = compareScoreArray(aScore[i2], bScore[i2]);
    if (comp)
      return comp;
    i2++;
  }
  if (Math.abs(bScore.length - aScore.length) === 1) {
    if (isLastScoreNegative(aScore))
      return 1;
    if (isLastScoreNegative(bScore))
      return -1;
  }
  return bScore.length - aScore.length;
}
__name(comparePathParserScore, "comparePathParserScore");
function isLastScoreNegative(score) {
  const last = score[score.length - 1];
  return score.length > 0 && last[last.length - 1] < 0;
}
__name(isLastScoreNegative, "isLastScoreNegative");
const ROOT_TOKEN = {
  type: 0,
  value: ""
};
const VALID_PARAM_RE = /[a-zA-Z0-9_]/;
function tokenizePath(path) {
  if (!path)
    return [[]];
  if (path === "/")
    return [[ROOT_TOKEN]];
  if (!path.startsWith("/")) {
    throw new Error(false ? `Route paths should start with a "/": "${path}" should be "/${path}".` : `Invalid path "${path}"`);
  }
  function crash(message3) {
    throw new Error(`ERR (${state})/"${buffer2}": ${message3}`);
  }
  __name(crash, "crash");
  let state = 0;
  let previousState = state;
  const tokens = [];
  let segment;
  function finalizeSegment() {
    if (segment)
      tokens.push(segment);
    segment = [];
  }
  __name(finalizeSegment, "finalizeSegment");
  let i2 = 0;
  let char;
  let buffer2 = "";
  let customRe = "";
  function consumeBuffer() {
    if (!buffer2)
      return;
    if (state === 0) {
      segment.push({
        type: 0,
        value: buffer2
      });
    } else if (state === 1 || state === 2 || state === 3) {
      if (segment.length > 1 && (char === "*" || char === "+"))
        crash(`A repeatable param (${buffer2}) must be alone in its segment. eg: '/:ids+.`);
      segment.push({
        type: 1,
        value: buffer2,
        regexp: customRe,
        repeatable: char === "*" || char === "+",
        optional: char === "*" || char === "?"
      });
    } else {
      crash("Invalid state to consume buffer");
    }
    buffer2 = "";
  }
  __name(consumeBuffer, "consumeBuffer");
  function addCharToBuffer() {
    buffer2 += char;
  }
  __name(addCharToBuffer, "addCharToBuffer");
  while (i2 < path.length) {
    char = path[i2++];
    if (char === "\\" && state !== 2) {
      previousState = state;
      state = 4;
      continue;
    }
    switch (state) {
      case 0:
        if (char === "/") {
          if (buffer2) {
            consumeBuffer();
          }
          finalizeSegment();
        } else if (char === ":") {
          consumeBuffer();
          state = 1;
        } else {
          addCharToBuffer();
        }
        break;
      case 4:
        addCharToBuffer();
        state = previousState;
        break;
      case 1:
        if (char === "(") {
          state = 2;
        } else if (VALID_PARAM_RE.test(char)) {
          addCharToBuffer();
        } else {
          consumeBuffer();
          state = 0;
          if (char !== "*" && char !== "?" && char !== "+")
            i2--;
        }
        break;
      case 2:
        if (char === ")") {
          if (customRe[customRe.length - 1] == "\\")
            customRe = customRe.slice(0, -1) + char;
          else
            state = 3;
        } else {
          customRe += char;
        }
        break;
      case 3:
        consumeBuffer();
        state = 0;
        if (char !== "*" && char !== "?" && char !== "+")
          i2--;
        customRe = "";
        break;
      default:
        crash("Unknown state");
        break;
    }
  }
  if (state === 2)
    crash(`Unfinished custom RegExp for param "${buffer2}"`);
  consumeBuffer();
  finalizeSegment();
  return tokens;
}
__name(tokenizePath, "tokenizePath");
function createRouteRecordMatcher(record2, parent, options5) {
  const parser = tokensToParser(tokenizePath(record2.path), options5);
  if (false) {
    const existingKeys = /* @__PURE__ */ new Set();
    for (const key of parser.keys) {
      if (existingKeys.has(key.name))
        warn$2(`Found duplicated params with name "${key.name}" for path "${record2.path}". Only the last one will be available on "$route.params".`);
      existingKeys.add(key.name);
    }
  }
  const matcher = assign$5(parser, {
    record: record2,
    parent,
    // these needs to be populated by the parent
    children: [],
    alias: []
  });
  if (parent) {
    if (!matcher.record.aliasOf === !parent.record.aliasOf)
      parent.children.push(matcher);
  }
  return matcher;
}
__name(createRouteRecordMatcher, "createRouteRecordMatcher");
function createRouterMatcher(routes, globalOptions) {
  const matchers = [];
  const matcherMap = /* @__PURE__ */ new Map();
  globalOptions = mergeOptions({ strict: false, end: true, sensitive: false }, globalOptions);
  function getRecordMatcher(name2) {
    return matcherMap.get(name2);
  }
  __name(getRecordMatcher, "getRecordMatcher");
  function addRoute(record2, parent, originalRecord) {
    const isRootAdd = !originalRecord;
    const mainNormalizedRecord = normalizeRouteRecord(record2);
    if (false) {
      checkChildMissingNameWithEmptyPath(mainNormalizedRecord, parent);
    }
    mainNormalizedRecord.aliasOf = originalRecord && originalRecord.record;
    const options5 = mergeOptions(globalOptions, record2);
    const normalizedRecords = [
      mainNormalizedRecord
    ];
    if ("alias" in record2) {
      const aliases = typeof record2.alias === "string" ? [record2.alias] : record2.alias;
      for (const alias of aliases) {
        normalizedRecords.push(assign$5({}, mainNormalizedRecord, {
          // this allows us to hold a copy of the `components` option
          // so that async components cache is hold on the original record
          components: originalRecord ? originalRecord.record.components : mainNormalizedRecord.components,
          path: alias,
          // we might be the child of an alias
          aliasOf: originalRecord ? originalRecord.record : mainNormalizedRecord
          // the aliases are always of the same kind as the original since they
          // are defined on the same record
        }));
      }
    }
    let matcher;
    let originalMatcher;
    for (const normalizedRecord of normalizedRecords) {
      const { path } = normalizedRecord;
      if (parent && path[0] !== "/") {
        const parentPath = parent.record.path;
        const connectingSlash = parentPath[parentPath.length - 1] === "/" ? "" : "/";
        normalizedRecord.path = parent.record.path + (path && connectingSlash + path);
      }
      if (false) {
        throw new Error('Catch all routes ("*") must now be defined using a param with a custom regexp.\nSee more at https://router.vuejs.org/guide/migration/#Removed-star-or-catch-all-routes.');
      }
      matcher = createRouteRecordMatcher(normalizedRecord, parent, options5);
      if (false)
        checkMissingParamsInAbsolutePath(matcher, parent);
      if (originalRecord) {
        originalRecord.alias.push(matcher);
        if (false) {
          checkSameParams(originalRecord, matcher);
        }
      } else {
        originalMatcher = originalMatcher || matcher;
        if (originalMatcher !== matcher)
          originalMatcher.alias.push(matcher);
        if (isRootAdd && record2.name && !isAliasRecord(matcher))
          removeRoute(record2.name);
      }
      if (isMatchable(matcher)) {
        insertMatcher(matcher);
      }
      if (mainNormalizedRecord.children) {
        const children = mainNormalizedRecord.children;
        for (let i2 = 0; i2 < children.length; i2++) {
          addRoute(children[i2], matcher, originalRecord && originalRecord.children[i2]);
        }
      }
      originalRecord = originalRecord || matcher;
    }
    return originalMatcher ? () => {
      removeRoute(originalMatcher);
    } : noop$3;
  }
  __name(addRoute, "addRoute");
  function removeRoute(matcherRef) {
    if (isRouteName(matcherRef)) {
      const matcher = matcherMap.get(matcherRef);
      if (matcher) {
        matcherMap.delete(matcherRef);
        matchers.splice(matchers.indexOf(matcher), 1);
        matcher.children.forEach(removeRoute);
        matcher.alias.forEach(removeRoute);
      }
    } else {
      const index2 = matchers.indexOf(matcherRef);
      if (index2 > -1) {
        matchers.splice(index2, 1);
        if (matcherRef.record.name)
          matcherMap.delete(matcherRef.record.name);
        matcherRef.children.forEach(removeRoute);
        matcherRef.alias.forEach(removeRoute);
      }
    }
  }
  __name(removeRoute, "removeRoute");
  function getRoutes() {
    return matchers;
  }
  __name(getRoutes, "getRoutes");
  function insertMatcher(matcher) {
    const index2 = findInsertionIndex(matcher, matchers);
    matchers.splice(index2, 0, matcher);
    if (matcher.record.name && !isAliasRecord(matcher))
      matcherMap.set(matcher.record.name, matcher);
  }
  __name(insertMatcher, "insertMatcher");
  function resolve2(location2, currentLocation) {
    let matcher;
    let params = {};
    let path;
    let name2;
    if ("name" in location2 && location2.name) {
      matcher = matcherMap.get(location2.name);
      if (!matcher)
        throw createRouterError(1, {
          location: location2
        });
      if (false) {
        const invalidParams = Object.keys(location2.params || {}).filter((paramName) => !matcher.keys.find((k2) => k2.name === paramName));
        if (invalidParams.length) {
          warn$2(`Discarded invalid param(s) "${invalidParams.join('", "')}" when navigating. See https://github.com/vuejs/router/blob/main/packages/router/CHANGELOG.md#414-2022-08-22 for more details.`);
        }
      }
      name2 = matcher.record.name;
      params = assign$5(
        // paramsFromLocation is a new object
        paramsFromLocation(
          currentLocation.params,
          // only keep params that exist in the resolved location
          // only keep optional params coming from a parent record
          matcher.keys.filter((k2) => !k2.optional).concat(matcher.parent ? matcher.parent.keys.filter((k2) => k2.optional) : []).map((k2) => k2.name)
        ),
        // discard any existing params in the current location that do not exist here
        // #1497 this ensures better active/exact matching
        location2.params && paramsFromLocation(location2.params, matcher.keys.map((k2) => k2.name))
      );
      path = matcher.stringify(params);
    } else if (location2.path != null) {
      path = location2.path;
      if (false) {
        warn$2(`The Matcher cannot resolve relative paths but received "${path}". Unless you directly called \`matcher.resolve("${path}")\`, this is probably a bug in vue-router. Please open an issue at https://github.com/vuejs/router/issues/new/choose.`);
      }
      matcher = matchers.find((m2) => m2.re.test(path));
      if (matcher) {
        params = matcher.parse(path);
        name2 = matcher.record.name;
      }
    } else {
      matcher = currentLocation.name ? matcherMap.get(currentLocation.name) : matchers.find((m2) => m2.re.test(currentLocation.path));
      if (!matcher)
        throw createRouterError(1, {
          location: location2,
          currentLocation
        });
      name2 = matcher.record.name;
      params = assign$5({}, currentLocation.params, location2.params);
      path = matcher.stringify(params);
    }
    const matched = [];
    let parentMatcher = matcher;
    while (parentMatcher) {
      matched.unshift(parentMatcher.record);
      parentMatcher = parentMatcher.parent;
    }
    return {
      name: name2,
      path,
      params,
      matched,
      meta: mergeMetaFields(matched)
    };
  }
  __name(resolve2, "resolve");
  routes.forEach((route) => addRoute(route));
  function clearRoutes() {
    matchers.length = 0;
    matcherMap.clear();
  }
  __name(clearRoutes, "clearRoutes");
  return {
    addRoute,
    resolve: resolve2,
    removeRoute,
    clearRoutes,
    getRoutes,
    getRecordMatcher
  };
}
__name(createRouterMatcher, "createRouterMatcher");
function paramsFromLocation(params, keys2) {
  const newParams = {};
  for (const key of keys2) {
    if (key in params)
      newParams[key] = params[key];
  }
  return newParams;
}
__name(paramsFromLocation, "paramsFromLocation");
function normalizeRouteRecord(record2) {
  return {
    path: record2.path,
    redirect: record2.redirect,
    name: record2.name,
    meta: record2.meta || {},
    aliasOf: void 0,
    beforeEnter: record2.beforeEnter,
    props: normalizeRecordProps(record2),
    children: record2.children || [],
    instances: {},
    leaveGuards: /* @__PURE__ */ new Set(),
    updateGuards: /* @__PURE__ */ new Set(),
    enterCallbacks: {},
    components: "components" in record2 ? record2.components || null : record2.component && { default: record2.component }
  };
}
__name(normalizeRouteRecord, "normalizeRouteRecord");
function normalizeRecordProps(record2) {
  const propsObject = {};
  const props = record2.props || false;
  if ("component" in record2) {
    propsObject.default = props;
  } else {
    for (const name2 in record2.components)
      propsObject[name2] = typeof props === "object" ? props[name2] : props;
  }
  return propsObject;
}
__name(normalizeRecordProps, "normalizeRecordProps");
function isAliasRecord(record2) {
  while (record2) {
    if (record2.record.aliasOf)
      return true;
    record2 = record2.parent;
  }
  return false;
}
__name(isAliasRecord, "isAliasRecord");
function mergeMetaFields(matched) {
  return matched.reduce((meta, record2) => assign$5(meta, record2.meta), {});
}
__name(mergeMetaFields, "mergeMetaFields");
function mergeOptions(defaults2, partialOptions) {
  const options5 = {};
  for (const key in defaults2) {
    options5[key] = key in partialOptions ? partialOptions[key] : defaults2[key];
  }
  return options5;
}
__name(mergeOptions, "mergeOptions");
function isSameParam(a2, b2) {
  return a2.name === b2.name && a2.optional === b2.optional && a2.repeatable === b2.repeatable;
}
__name(isSameParam, "isSameParam");
function checkSameParams(a2, b2) {
  for (const key of a2.keys) {
    if (!key.optional && !b2.keys.find(isSameParam.bind(null, key)))
      return warn$2(`Alias "${b2.record.path}" and the original record: "${a2.record.path}" must have the exact same param named "${key.name}"`);
  }
  for (const key of b2.keys) {
    if (!key.optional && !a2.keys.find(isSameParam.bind(null, key)))
      return warn$2(`Alias "${b2.record.path}" and the original record: "${a2.record.path}" must have the exact same param named "${key.name}"`);
  }
}
__name(checkSameParams, "checkSameParams");
function checkChildMissingNameWithEmptyPath(mainNormalizedRecord, parent) {
  if (parent && parent.record.name && !mainNormalizedRecord.name && !mainNormalizedRecord.path) {
    warn$2(`The route named "${String(parent.record.name)}" has a child without a name and an empty path. Using that name won't render the empty path child so you probably want to move the name to the child instead. If this is intentional, add a name to the child route to remove the warning.`);
  }
}
__name(checkChildMissingNameWithEmptyPath, "checkChildMissingNameWithEmptyPath");
function checkMissingParamsInAbsolutePath(record2, parent) {
  for (const key of parent.keys) {
    if (!record2.keys.find(isSameParam.bind(null, key)))
      return warn$2(`Absolute path "${record2.record.path}" must have the exact same param named "${key.name}" as its parent "${parent.record.path}".`);
  }
}
__name(checkMissingParamsInAbsolutePath, "checkMissingParamsInAbsolutePath");
function findInsertionIndex(matcher, matchers) {
  let lower = 0;
  let upper = matchers.length;
  while (lower !== upper) {
    const mid = lower + upper >> 1;
    const sortOrder = comparePathParserScore(matcher, matchers[mid]);
    if (sortOrder < 0) {
      upper = mid;
    } else {
      lower = mid + 1;
    }
  }
  const insertionAncestor = getInsertionAncestor(matcher);
  if (insertionAncestor) {
    upper = matchers.lastIndexOf(insertionAncestor, upper - 1);
    if (false) {
      warn$2(`Finding ancestor route "${insertionAncestor.record.path}" failed for "${matcher.record.path}"`);
    }
  }
  return upper;
}
__name(findInsertionIndex, "findInsertionIndex");
function getInsertionAncestor(matcher) {
  let ancestor = matcher;
  while (ancestor = ancestor.parent) {
    if (isMatchable(ancestor) && comparePathParserScore(matcher, ancestor) === 0) {
      return ancestor;
    }
  }
  return;
}
__name(getInsertionAncestor, "getInsertionAncestor");
function isMatchable({ record: record2 }) {
  return !!(record2.name || record2.components && Object.keys(record2.components).length || record2.redirect);
}
__name(isMatchable, "isMatchable");
function parseQuery$1(search3) {
  const query = {};
  if (search3 === "" || search3 === "?")
    return query;
  const hasLeadingIM = search3[0] === "?";
  const searchParams = (hasLeadingIM ? search3.slice(1) : search3).split("&");
  for (let i2 = 0; i2 < searchParams.length; ++i2) {
    const searchParam = searchParams[i2].replace(PLUS_RE, " ");
    const eqPos = searchParam.indexOf("=");
    const key = decode$3(eqPos < 0 ? searchParam : searchParam.slice(0, eqPos));
    const value3 = eqPos < 0 ? null : decode$3(searchParam.slice(eqPos + 1));
    if (key in query) {
      let currentValue = query[key];
      if (!isArray$a(currentValue)) {
        currentValue = query[key] = [currentValue];
      }
      currentValue.push(value3);
    } else {
      query[key] = value3;
    }
  }
  return query;
}
__name(parseQuery$1, "parseQuery$1");
function stringifyQuery(query) {
  let search3 = "";
  for (let key in query) {
    const value3 = query[key];
    key = encodeQueryKey(key);
    if (value3 == null) {
      if (value3 !== void 0) {
        search3 += (search3.length ? "&" : "") + key;
      }
      continue;
    }
    const values = isArray$a(value3) ? value3.map((v2) => v2 && encodeQueryValue(v2)) : [value3 && encodeQueryValue(value3)];
    values.forEach((value22) => {
      if (value22 !== void 0) {
        search3 += (search3.length ? "&" : "") + key;
        if (value22 != null)
          search3 += "=" + value22;
      }
    });
  }
  return search3;
}
__name(stringifyQuery, "stringifyQuery");
function normalizeQuery(query) {
  const normalizedQuery = {};
  for (const key in query) {
    const value3 = query[key];
    if (value3 !== void 0) {
      normalizedQuery[key] = isArray$a(value3) ? value3.map((v2) => v2 == null ? null : "" + v2) : value3 == null ? value3 : "" + value3;
    }
  }
  return normalizedQuery;
}
__name(normalizeQuery, "normalizeQuery");
const matchedRouteKey = Symbol(false ? "router view location matched" : "");
const viewDepthKey = Symbol(false ? "router view depth" : "");
const routerKey = Symbol(false ? "router" : "");
const routeLocationKey = Symbol(false ? "route location" : "");
const routerViewLocationKey = Symbol(false ? "router view location" : "");
function useCallbacks() {
  let handlers2 = [];
  function add3(handler14) {
    handlers2.push(handler14);
    return () => {
      const i2 = handlers2.indexOf(handler14);
      if (i2 > -1)
        handlers2.splice(i2, 1);
    };
  }
  __name(add3, "add");
  function reset2() {
    handlers2 = [];
  }
  __name(reset2, "reset");
  return {
    add: add3,
    list: /* @__PURE__ */ __name(() => handlers2.slice(), "list"),
    reset: reset2
  };
}
__name(useCallbacks, "useCallbacks");
function registerGuard(record2, name2, guard) {
  const removeFromList = /* @__PURE__ */ __name(() => {
    record2[name2].delete(guard);
  }, "removeFromList");
  onUnmounted(removeFromList);
  onDeactivated(removeFromList);
  onActivated(() => {
    record2[name2].add(guard);
  });
  record2[name2].add(guard);
}
__name(registerGuard, "registerGuard");
function onBeforeRouteLeave(leaveGuard) {
  if (false) {
    warn$2("getCurrentInstance() returned null. onBeforeRouteLeave() must be called at the top of a setup function");
    return;
  }
  const activeRecord = inject(
    matchedRouteKey,
    // to avoid warning
    {}
  ).value;
  if (!activeRecord) {
    return;
  }
  registerGuard(activeRecord, "leaveGuards", leaveGuard);
}
__name(onBeforeRouteLeave, "onBeforeRouteLeave");
function onBeforeRouteUpdate(updateGuard) {
  if (false) {
    warn$2("getCurrentInstance() returned null. onBeforeRouteUpdate() must be called at the top of a setup function");
    return;
  }
  const activeRecord = inject(
    matchedRouteKey,
    // to avoid warning
    {}
  ).value;
  if (!activeRecord) {
    return;
  }
  registerGuard(activeRecord, "updateGuards", updateGuard);
}
__name(onBeforeRouteUpdate, "onBeforeRouteUpdate");
function guardToPromiseFn(guard, to, from2, record2, name2, runWithContext = (fn) => fn()) {
  const enterCallbackArray = record2 && // name is defined if record is because of the function overload
  (record2.enterCallbacks[name2] = record2.enterCallbacks[name2] || []);
  return () => new Promise((resolve2, reject3) => {
    const next2 = /* @__PURE__ */ __name((valid) => {
      if (valid === false) {
        reject3(createRouterError(4, {
          from: from2,
          to
        }));
      } else if (valid instanceof Error) {
        reject3(valid);
      } else if (isRouteLocation(valid)) {
        reject3(createRouterError(2, {
          from: to,
          to: valid
        }));
      } else {
        if (enterCallbackArray && // since enterCallbackArray is truthy, both record and name also are
        record2.enterCallbacks[name2] === enterCallbackArray && typeof valid === "function") {
          enterCallbackArray.push(valid);
        }
        resolve2();
      }
    }, "next");
    const guardReturn = runWithContext(() => guard.call(record2 && record2.instances[name2], to, from2, false ? canOnlyBeCalledOnce(next2, to, from2) : next2));
    let guardCall = Promise.resolve(guardReturn);
    if (guard.length < 3)
      guardCall = guardCall.then(next2);
    if (false) {
      const message3 = `The "next" callback was never called inside of ${guard.name ? '"' + guard.name + '"' : ""}:
${guard.toString()}
. If you are returning a value instead of calling "next", make sure to remove the "next" parameter from your function.`;
      if (typeof guardReturn === "object" && "then" in guardReturn) {
        guardCall = guardCall.then((resolvedValue) => {
          if (!next2._called) {
            warn$2(message3);
            return Promise.reject(new Error("Invalid navigation guard"));
          }
          return resolvedValue;
        });
      } else if (guardReturn !== void 0) {
        if (!next2._called) {
          warn$2(message3);
          reject3(new Error("Invalid navigation guard"));
          return;
        }
      }
    }
    guardCall.catch((err) => reject3(err));
  });
}
__name(guardToPromiseFn, "guardToPromiseFn");
function canOnlyBeCalledOnce(next2, to, from2) {
  let called = 0;
  return function() {
    if (called++ === 1)
      warn$2(`The "next" callback was called more than once in one navigation guard when going from "${from2.fullPath}" to "${to.fullPath}". It should be called exactly one time in each navigation guard. This will fail in production.`);
    next2._called = true;
    if (called === 1)
      next2.apply(null, arguments);
  };
}
__name(canOnlyBeCalledOnce, "canOnlyBeCalledOnce");
function extractComponentsGuards(matched, guardType, to, from2, runWithContext = (fn) => fn()) {
  const guards = [];
  for (const record2 of matched) {
    if (false) {
      warn$2(`Record with path "${record2.path}" is either missing a "component(s)" or "children" property.`);
    }
    for (const name2 in record2.components) {
      let rawComponent = record2.components[name2];
      if (false) {
        if (!rawComponent || typeof rawComponent !== "object" && typeof rawComponent !== "function") {
          warn$2(`Component "${name2}" in record with path "${record2.path}" is not a valid component. Received "${String(rawComponent)}".`);
          throw new Error("Invalid route component");
        } else if ("then" in rawComponent) {
          warn$2(`Component "${name2}" in record with path "${record2.path}" is a Promise instead of a function that returns a Promise. Did you write "import('./MyPage.vue')" instead of "() => import('./MyPage.vue')" ? This will break in production if not fixed.`);
          const promise = rawComponent;
          rawComponent = /* @__PURE__ */ __name(() => promise, "rawComponent");
        } else if (rawComponent.__asyncLoader && // warn only once per component
        !rawComponent.__warnedDefineAsync) {
          rawComponent.__warnedDefineAsync = true;
          warn$2(`Component "${name2}" in record with path "${record2.path}" is defined using "defineAsyncComponent()". Write "() => import('./MyPage.vue')" instead of "defineAsyncComponent(() => import('./MyPage.vue'))".`);
        }
      }
      if (guardType !== "beforeRouteEnter" && !record2.instances[name2])
        continue;
      if (isRouteComponent(rawComponent)) {
        const options5 = rawComponent.__vccOpts || rawComponent;
        const guard = options5[guardType];
        guard && guards.push(guardToPromiseFn(guard, to, from2, record2, name2, runWithContext));
      } else {
        let componentPromise = rawComponent();
        if (false) {
          warn$2(`Component "${name2}" in record with path "${record2.path}" is a function that does not return a Promise. If you were passing a functional component, make sure to add a "displayName" to the component. This will break in production if not fixed.`);
          componentPromise = Promise.resolve(componentPromise);
        }
        guards.push(() => componentPromise.then((resolved) => {
          if (!resolved)
            return Promise.reject(new Error(`Couldn't resolve component "${name2}" at "${record2.path}"`));
          const resolvedComponent = isESModule(resolved) ? resolved.default : resolved;
          record2.components[name2] = resolvedComponent;
          const options5 = resolvedComponent.__vccOpts || resolvedComponent;
          const guard = options5[guardType];
          return guard && guardToPromiseFn(guard, to, from2, record2, name2, runWithContext)();
        }));
      }
    }
  }
  return guards;
}
__name(extractComponentsGuards, "extractComponentsGuards");
function isRouteComponent(component) {
  return typeof component === "object" || "displayName" in component || "props" in component || "__vccOpts" in component;
}
__name(isRouteComponent, "isRouteComponent");
function loadRouteLocation(route) {
  return route.matched.every((record2) => record2.redirect) ? Promise.reject(new Error("Cannot load a route that redirects.")) : Promise.all(route.matched.map((record2) => record2.components && Promise.all(Object.keys(record2.components).reduce((promises, name2) => {
    const rawComponent = record2.components[name2];
    if (typeof rawComponent === "function" && !("displayName" in rawComponent)) {
      promises.push(rawComponent().then((resolved) => {
        if (!resolved)
          return Promise.reject(new Error(`Couldn't resolve component "${name2}" at "${record2.path}". Ensure you passed a function that returns a promise.`));
        const resolvedComponent = isESModule(resolved) ? resolved.default : resolved;
        record2.components[name2] = resolvedComponent;
        return;
      }));
    }
    return promises;
  }, [])))).then(() => route);
}
__name(loadRouteLocation, "loadRouteLocation");
function useLink(props) {
  const router2 = inject(routerKey);
  const currentRoute = inject(routeLocationKey);
  let hasPrevious = false;
  let previousTo = null;
  const route = computed(() => {
    const to = unref(props.to);
    if (false) {
      if (!isRouteLocation(to)) {
        if (hasPrevious) {
          warn$2(`Invalid value for prop "to" in useLink()
- to:`, to, `
- previous to:`, previousTo, `
- props:`, props);
        } else {
          warn$2(`Invalid value for prop "to" in useLink()
- to:`, to, `
- props:`, props);
        }
      }
      previousTo = to;
      hasPrevious = true;
    }
    return router2.resolve(to);
  });
  const activeRecordIndex = computed(() => {
    const { matched } = route.value;
    const { length } = matched;
    const routeMatched = matched[length - 1];
    const currentMatched = currentRoute.matched;
    if (!routeMatched || !currentMatched.length)
      return -1;
    const index2 = currentMatched.findIndex(isSameRouteRecord.bind(null, routeMatched));
    if (index2 > -1)
      return index2;
    const parentRecordPath = getOriginalPath(matched[length - 2]);
    return (
      // we are dealing with nested routes
      length > 1 && // if the parent and matched route have the same path, this link is
      // referring to the empty child. Or we currently are on a different
      // child of the same parent
      getOriginalPath(routeMatched) === parentRecordPath && // avoid comparing the child with its parent
      currentMatched[currentMatched.length - 1].path !== parentRecordPath ? currentMatched.findIndex(isSameRouteRecord.bind(null, matched[length - 2])) : index2
    );
  });
  const isActive2 = computed(() => activeRecordIndex.value > -1 && includesParams(currentRoute.params, route.value.params));
  const isExactActive = computed(() => activeRecordIndex.value > -1 && activeRecordIndex.value === currentRoute.matched.length - 1 && isSameRouteLocationParams(currentRoute.params, route.value.params));
  function navigate(e2 = {}) {
    if (guardEvent(e2)) {
      return router2[unref(props.replace) ? "replace" : "push"](
        unref(props.to)
        // avoid uncaught errors are they are logged anyway
      ).catch(noop$3);
    }
    return Promise.resolve();
  }
  __name(navigate, "navigate");
  if (false) {
    const instance = getCurrentInstance();
    if (instance) {
      const linkContextDevtools = {
        route: route.value,
        isActive: isActive2.value,
        isExactActive: isExactActive.value,
        error: null
      };
      instance.__vrl_devtools = instance.__vrl_devtools || [];
      instance.__vrl_devtools.push(linkContextDevtools);
      watchEffect(() => {
        linkContextDevtools.route = route.value;
        linkContextDevtools.isActive = isActive2.value;
        linkContextDevtools.isExactActive = isExactActive.value;
        linkContextDevtools.error = isRouteLocation(unref(props.to)) ? null : 'Invalid "to" value';
      }, { flush: "post" });
    }
  }
  return {
    route,
    href: computed(() => route.value.href),
    isActive: isActive2,
    isExactActive,
    navigate
  };
}
__name(useLink, "useLink");
const RouterLinkImpl = /* @__PURE__ */ defineComponent({
  name: "RouterLink",
  compatConfig: { MODE: 3 },
  props: {
    to: {
      type: [String, Object],
      required: true
    },
    replace: Boolean,
    activeClass: String,
    // inactiveClass: String,
    exactActiveClass: String,
    custom: Boolean,
    ariaCurrentValue: {
      type: String,
      default: "page"
    }
  },
  useLink,
  setup(props, { slots }) {
    const link2 = reactive(useLink(props));
    const { options: options5 } = inject(routerKey);
    const elClass = computed(() => ({
      [getLinkClass(props.activeClass, options5.linkActiveClass, "router-link-active")]: link2.isActive,
      // [getLinkClass(
      //   props.inactiveClass,
      //   options.linkInactiveClass,
      //   'router-link-inactive'
      // )]: !link.isExactActive,
      [getLinkClass(props.exactActiveClass, options5.linkExactActiveClass, "router-link-exact-active")]: link2.isExactActive
    }));
    return () => {
      const children = slots.default && slots.default(link2);
      return props.custom ? children : h("a", {
        "aria-current": link2.isExactActive ? props.ariaCurrentValue : null,
        href: link2.href,
        // this would override user added attrs but Vue will still add
        // the listener, so we end up triggering both
        onClick: link2.navigate,
        class: elClass.value
      }, children);
    };
  }
});
const RouterLink = RouterLinkImpl;
function guardEvent(e2) {
  if (e2.metaKey || e2.altKey || e2.ctrlKey || e2.shiftKey)
    return;
  if (e2.defaultPrevented)
    return;
  if (e2.button !== void 0 && e2.button !== 0)
    return;
  if (e2.currentTarget && e2.currentTarget.getAttribute) {
    const target2 = e2.currentTarget.getAttribute("target");
    if (/\b_blank\b/i.test(target2))
      return;
  }
  if (e2.preventDefault)
    e2.preventDefault();
  return true;
}
__name(guardEvent, "guardEvent");
function includesParams(outer, inner) {
  for (const key in inner) {
    const innerValue = inner[key];
    const outerValue = outer[key];
    if (typeof innerValue === "string") {
      if (innerValue !== outerValue)
        return false;
    } else {
      if (!isArray$a(outerValue) || outerValue.length !== innerValue.length || innerValue.some((value3, i2) => value3 !== outerValue[i2]))
        return false;
    }
  }
  return true;
}
__name(includesParams, "includesParams");
function getOriginalPath(record2) {
  return record2 ? record2.aliasOf ? record2.aliasOf.path : record2.path : "";
}
__name(getOriginalPath, "getOriginalPath");
const getLinkClass = /* @__PURE__ */ __name((propClass, globalClass, defaultClass) => propClass != null ? propClass : globalClass != null ? globalClass : defaultClass, "getLinkClass");
const RouterViewImpl = /* @__PURE__ */ defineComponent({
  name: "RouterView",
  // #674 we manually inherit them
  inheritAttrs: false,
  props: {
    name: {
      type: String,
      default: "default"
    },
    route: Object
  },
  // Better compat for @vue/compat users
  // https://github.com/vuejs/router/issues/1315
  compatConfig: { MODE: 3 },
  setup(props, { attrs: attrs7, slots }) {
    const injectedRoute = inject(routerViewLocationKey);
    const routeToDisplay = computed(() => props.route || injectedRoute.value);
    const injectedDepth = inject(viewDepthKey, 0);
    const depth = computed(() => {
      let initialDepth = unref(injectedDepth);
      const { matched } = routeToDisplay.value;
      let matchedRoute;
      while ((matchedRoute = matched[initialDepth]) && !matchedRoute.components) {
        initialDepth++;
      }
      return initialDepth;
    });
    const matchedRouteRef = computed(() => routeToDisplay.value.matched[depth.value]);
    provide(viewDepthKey, computed(() => depth.value + 1));
    provide(matchedRouteKey, matchedRouteRef);
    provide(routerViewLocationKey, routeToDisplay);
    const viewRef = ref();
    watch(() => [viewRef.value, matchedRouteRef.value, props.name], ([instance, to, name2], [oldInstance, from2, oldName]) => {
      if (to) {
        to.instances[name2] = instance;
        if (from2 && from2 !== to && instance && instance === oldInstance) {
          if (!to.leaveGuards.size) {
            to.leaveGuards = from2.leaveGuards;
          }
          if (!to.updateGuards.size) {
            to.updateGuards = from2.updateGuards;
          }
        }
      }
      if (instance && to && // if there is no instance but to and from are the same this might be
      // the first visit
      (!from2 || !isSameRouteRecord(to, from2) || !oldInstance)) {
        (to.enterCallbacks[name2] || []).forEach((callback) => callback(instance));
      }
    }, { flush: "post" });
    return () => {
      const route = routeToDisplay.value;
      const currentName = props.name;
      const matchedRoute = matchedRouteRef.value;
      const ViewComponent = matchedRoute && matchedRoute.components[currentName];
      if (!ViewComponent) {
        return normalizeSlot(slots.default, { Component: ViewComponent, route });
      }
      const routePropsOption = matchedRoute.props[currentName];
      const routeProps = routePropsOption ? routePropsOption === true ? route.params : typeof routePropsOption === "function" ? routePropsOption(route) : routePropsOption : null;
      const onVnodeUnmounted = /* @__PURE__ */ __name((vnode) => {
        if (vnode.component.isUnmounted) {
          matchedRoute.instances[currentName] = null;
        }
      }, "onVnodeUnmounted");
      const component = h(ViewComponent, assign$5({}, routeProps, attrs7, {
        onVnodeUnmounted,
        ref: viewRef
      }));
      if (false) {
        const info = {
          depth: depth.value,
          name: matchedRoute.name,
          path: matchedRoute.path,
          meta: matchedRoute.meta
        };
        const internalInstances = isArray$a(component.ref) ? component.ref.map((r2) => r2.i) : [component.ref.i];
        internalInstances.forEach((instance) => {
          instance.__vrv_devtools = info;
        });
      }
      return (
        // pass the vnode to the slot as a prop.
        // h and <component :is="..."> both accept vnodes
        normalizeSlot(slots.default, { Component: component, route }) || component
      );
    };
  }
});
function normalizeSlot(slot, data30) {
  if (!slot)
    return null;
  const slotContent = slot(data30);
  return slotContent.length === 1 ? slotContent[0] : slotContent;
}
__name(normalizeSlot, "normalizeSlot");
const RouterView = RouterViewImpl;
function warnDeprecatedUsage() {
  const instance = getCurrentInstance();
  const parentName = instance.parent && instance.parent.type.name;
  const parentSubTreeType = instance.parent && instance.parent.subTree && instance.parent.subTree.type;
  if (parentName && (parentName === "KeepAlive" || parentName.includes("Transition")) && typeof parentSubTreeType === "object" && parentSubTreeType.name === "RouterView") {
    const comp = parentName === "KeepAlive" ? "keep-alive" : "transition";
    warn$2(`<router-view> can no longer be used directly inside <transition> or <keep-alive>.
Use slot props instead:

<router-view v-slot="{ Component }">
  <${comp}>
    <component :is="Component" />
  </${comp}>
</router-view>`);
  }
}
__name(warnDeprecatedUsage, "warnDeprecatedUsage");
function formatRouteLocation(routeLocation, tooltip) {
  const copy2 = assign$5({}, routeLocation, {
    // remove variables that can contain vue instances
    matched: routeLocation.matched.map((matched) => omit$2(matched, ["instances", "children", "aliasOf"]))
  });
  return {
    _custom: {
      type: null,
      readOnly: true,
      display: routeLocation.fullPath,
      tooltip,
      value: copy2
    }
  };
}
__name(formatRouteLocation, "formatRouteLocation");
function formatDisplay(display) {
  return {
    _custom: {
      display
    }
  };
}
__name(formatDisplay, "formatDisplay");
let routerId = 0;
function addDevtools(app2, router2, matcher) {
  if (router2.__hasDevtools)
    return;
  router2.__hasDevtools = true;
  const id4 = routerId++;
  setupDevtoolsPlugin({
    id: "org.vuejs.router" + (id4 ? "." + id4 : ""),
    label: "Vue Router",
    packageName: "vue-router",
    homepage: "https://router.vuejs.org",
    logo: "https://router.vuejs.org/logo.png",
    componentStateTypes: ["Routing"],
    app: app2
  }, (api2) => {
    if (typeof api2.now !== "function") {
      console.warn("[Vue Router]: You seem to be using an outdated version of Vue Devtools. Are you still using the Beta release instead of the stable one? You can find the links at https://devtools.vuejs.org/guide/installation.html.");
    }
    api2.on.inspectComponent((payload, ctx) => {
      if (payload.instanceData) {
        payload.instanceData.state.push({
          type: "Routing",
          key: "$route",
          editable: false,
          value: formatRouteLocation(router2.currentRoute.value, "Current Route")
        });
      }
    });
    api2.on.visitComponentTree(({ treeNode: node3, componentInstance }) => {
      if (componentInstance.__vrv_devtools) {
        const info = componentInstance.__vrv_devtools;
        node3.tags.push({
          label: (info.name ? `${info.name.toString()}: ` : "") + info.path,
          textColor: 0,
          tooltip: "This component is rendered by &lt;router-view&gt;",
          backgroundColor: PINK_500
        });
      }
      if (isArray$a(componentInstance.__vrl_devtools)) {
        componentInstance.__devtoolsApi = api2;
        componentInstance.__vrl_devtools.forEach((devtoolsData) => {
          let label8 = devtoolsData.route.path;
          let backgroundColor = ORANGE_400;
          let tooltip = "";
          let textColor = 0;
          if (devtoolsData.error) {
            label8 = devtoolsData.error;
            backgroundColor = RED_100;
            textColor = RED_700;
          } else if (devtoolsData.isExactActive) {
            backgroundColor = LIME_500;
            tooltip = "This is exactly active";
          } else if (devtoolsData.isActive) {
            backgroundColor = BLUE_600;
            tooltip = "This link is active";
          }
          node3.tags.push({
            label: label8,
            textColor,
            tooltip,
            backgroundColor
          });
        });
      }
    });
    watch(router2.currentRoute, () => {
      refreshRoutesView();
      api2.notifyComponentUpdate();
      api2.sendInspectorTree(routerInspectorId);
      api2.sendInspectorState(routerInspectorId);
    });
    const navigationsLayerId = "router:navigations:" + id4;
    api2.addTimelineLayer({
      id: navigationsLayerId,
      label: `Router${id4 ? " " + id4 : ""} Navigations`,
      color: 4237508
    });
    router2.onError((error2, to) => {
      api2.addTimelineEvent({
        layerId: navigationsLayerId,
        event: {
          title: "Error during Navigation",
          subtitle: to.fullPath,
          logType: "error",
          time: api2.now(),
          data: { error: error2 },
          groupId: to.meta.__navigationId
        }
      });
    });
    let navigationId = 0;
    router2.beforeEach((to, from2) => {
      const data30 = {
        guard: formatDisplay("beforeEach"),
        from: formatRouteLocation(from2, "Current Location during this navigation"),
        to: formatRouteLocation(to, "Target location")
      };
      Object.defineProperty(to.meta, "__navigationId", {
        value: navigationId++
      });
      api2.addTimelineEvent({
        layerId: navigationsLayerId,
        event: {
          time: api2.now(),
          title: "Start of navigation",
          subtitle: to.fullPath,
          data: data30,
          groupId: to.meta.__navigationId
        }
      });
    });
    router2.afterEach((to, from2, failure) => {
      const data30 = {
        guard: formatDisplay("afterEach")
      };
      if (failure) {
        data30.failure = {
          _custom: {
            type: Error,
            readOnly: true,
            display: failure ? failure.message : "",
            tooltip: "Navigation Failure",
            value: failure
          }
        };
        data30.status = formatDisplay("❌");
      } else {
        data30.status = formatDisplay("✅");
      }
      data30.from = formatRouteLocation(from2, "Current Location during this navigation");
      data30.to = formatRouteLocation(to, "Target location");
      api2.addTimelineEvent({
        layerId: navigationsLayerId,
        event: {
          title: "End of navigation",
          subtitle: to.fullPath,
          time: api2.now(),
          data: data30,
          logType: failure ? "warning" : "default",
          groupId: to.meta.__navigationId
        }
      });
    });
    const routerInspectorId = "router-inspector:" + id4;
    api2.addInspector({
      id: routerInspectorId,
      label: "Routes" + (id4 ? " " + id4 : ""),
      icon: "book",
      treeFilterPlaceholder: "Search routes"
    });
    function refreshRoutesView() {
      if (!activeRoutesPayload)
        return;
      const payload = activeRoutesPayload;
      let routes = matcher.getRoutes().filter((route) => !route.parent || // these routes have a parent with no component which will not appear in the view
      // therefore we still need to include them
      !route.parent.record.components);
      routes.forEach(resetMatchStateOnRouteRecord);
      if (payload.filter) {
        routes = routes.filter((route) => (
          // save matches state based on the payload
          isRouteMatching(route, payload.filter.toLowerCase())
        ));
      }
      routes.forEach((route) => markRouteRecordActive(route, router2.currentRoute.value));
      payload.rootNodes = routes.map(formatRouteRecordForInspector);
    }
    __name(refreshRoutesView, "refreshRoutesView");
    let activeRoutesPayload;
    api2.on.getInspectorTree((payload) => {
      activeRoutesPayload = payload;
      if (payload.app === app2 && payload.inspectorId === routerInspectorId) {
        refreshRoutesView();
      }
    });
    api2.on.getInspectorState((payload) => {
      if (payload.app === app2 && payload.inspectorId === routerInspectorId) {
        const routes = matcher.getRoutes();
        const route = routes.find((route2) => route2.record.__vd_id === payload.nodeId);
        if (route) {
          payload.state = {
            options: formatRouteRecordMatcherForStateInspector(route)
          };
        }
      }
    });
    api2.sendInspectorTree(routerInspectorId);
    api2.sendInspectorState(routerInspectorId);
  });
}
__name(addDevtools, "addDevtools");
function modifierForKey(key) {
  if (key.optional) {
    return key.repeatable ? "*" : "?";
  } else {
    return key.repeatable ? "+" : "";
  }
}
__name(modifierForKey, "modifierForKey");
function formatRouteRecordMatcherForStateInspector(route) {
  const { record: record2 } = route;
  const fields = [
    { editable: false, key: "path", value: record2.path }
  ];
  if (record2.name != null) {
    fields.push({
      editable: false,
      key: "name",
      value: record2.name
    });
  }
  fields.push({ editable: false, key: "regexp", value: route.re });
  if (route.keys.length) {
    fields.push({
      editable: false,
      key: "keys",
      value: {
        _custom: {
          type: null,
          readOnly: true,
          display: route.keys.map((key) => `${key.name}${modifierForKey(key)}`).join(" "),
          tooltip: "Param keys",
          value: route.keys
        }
      }
    });
  }
  if (record2.redirect != null) {
    fields.push({
      editable: false,
      key: "redirect",
      value: record2.redirect
    });
  }
  if (route.alias.length) {
    fields.push({
      editable: false,
      key: "aliases",
      value: route.alias.map((alias) => alias.record.path)
    });
  }
  if (Object.keys(route.record.meta).length) {
    fields.push({
      editable: false,
      key: "meta",
      value: route.record.meta
    });
  }
  fields.push({
    key: "score",
    editable: false,
    value: {
      _custom: {
        type: null,
        readOnly: true,
        display: route.score.map((score) => score.join(", ")).join(" | "),
        tooltip: "Score used to sort routes",
        value: route.score
      }
    }
  });
  return fields;
}
__name(formatRouteRecordMatcherForStateInspector, "formatRouteRecordMatcherForStateInspector");
const PINK_500 = 15485081;
const BLUE_600 = 2450411;
const LIME_500 = 8702998;
const CYAN_400 = 2282478;
const ORANGE_400 = 16486972;
const DARK = 6710886;
const RED_100 = 16704226;
const RED_700 = 12131356;
function formatRouteRecordForInspector(route) {
  const tags = [];
  const { record: record2 } = route;
  if (record2.name != null) {
    tags.push({
      label: String(record2.name),
      textColor: 0,
      backgroundColor: CYAN_400
    });
  }
  if (record2.aliasOf) {
    tags.push({
      label: "alias",
      textColor: 0,
      backgroundColor: ORANGE_400
    });
  }
  if (route.__vd_match) {
    tags.push({
      label: "matches",
      textColor: 0,
      backgroundColor: PINK_500
    });
  }
  if (route.__vd_exactActive) {
    tags.push({
      label: "exact",
      textColor: 0,
      backgroundColor: LIME_500
    });
  }
  if (route.__vd_active) {
    tags.push({
      label: "active",
      textColor: 0,
      backgroundColor: BLUE_600
    });
  }
  if (record2.redirect) {
    tags.push({
      label: typeof record2.redirect === "string" ? `redirect: ${record2.redirect}` : "redirects",
      textColor: 16777215,
      backgroundColor: DARK
    });
  }
  let id4 = record2.__vd_id;
  if (id4 == null) {
    id4 = String(routeRecordId++);
    record2.__vd_id = id4;
  }
  return {
    id: id4,
    label: record2.path,
    tags,
    children: route.children.map(formatRouteRecordForInspector)
  };
}
__name(formatRouteRecordForInspector, "formatRouteRecordForInspector");
let routeRecordId = 0;
const EXTRACT_REGEXP_RE = /^\/(.*)\/([a-z]*)$/;
function markRouteRecordActive(route, currentRoute) {
  const isExactActive = currentRoute.matched.length && isSameRouteRecord(currentRoute.matched[currentRoute.matched.length - 1], route.record);
  route.__vd_exactActive = route.__vd_active = isExactActive;
  if (!isExactActive) {
    route.__vd_active = currentRoute.matched.some((match2) => isSameRouteRecord(match2, route.record));
  }
  route.children.forEach((childRoute) => markRouteRecordActive(childRoute, currentRoute));
}
__name(markRouteRecordActive, "markRouteRecordActive");
function resetMatchStateOnRouteRecord(route) {
  route.__vd_match = false;
  route.children.forEach(resetMatchStateOnRouteRecord);
}
__name(resetMatchStateOnRouteRecord, "resetMatchStateOnRouteRecord");
function isRouteMatching(route, filter4) {
  const found2 = String(route.re).match(EXTRACT_REGEXP_RE);
  route.__vd_match = false;
  if (!found2 || found2.length < 3) {
    return false;
  }
  const nonEndingRE = new RegExp(found2[1].replace(/\$$/, ""), found2[2]);
  if (nonEndingRE.test(filter4)) {
    route.children.forEach((child) => isRouteMatching(child, filter4));
    if (route.record.path !== "/" || filter4 === "/") {
      route.__vd_match = route.re.test(filter4);
      return true;
    }
    return false;
  }
  const path = route.record.path.toLowerCase();
  const decodedPath = decode$3(path);
  if (!filter4.startsWith("/") && (decodedPath.includes(filter4) || path.includes(filter4)))
    return true;
  if (decodedPath.startsWith(filter4) || path.startsWith(filter4))
    return true;
  if (route.record.name && String(route.record.name).includes(filter4))
    return true;
  return route.children.some((child) => isRouteMatching(child, filter4));
}
__name(isRouteMatching, "isRouteMatching");
function omit$2(obj, keys2) {
  const ret = {};
  for (const key in obj) {
    if (!keys2.includes(key)) {
      ret[key] = obj[key];
    }
  }
  return ret;
}
__name(omit$2, "omit$2");
function createRouter(options5) {
  const matcher = createRouterMatcher(options5.routes, options5);
  const parseQuery$1$1 = options5.parseQuery || parseQuery$1;
  const stringifyQuery$1 = options5.stringifyQuery || stringifyQuery;
  const routerHistory = options5.history;
  if (false)
    throw new Error('Provide the "history" option when calling "createRouter()": https://router.vuejs.org/api/interfaces/RouterOptions.html#history');
  const beforeGuards = useCallbacks();
  const beforeResolveGuards = useCallbacks();
  const afterGuards = useCallbacks();
  const currentRoute = shallowRef(START_LOCATION_NORMALIZED);
  let pendingLocation = START_LOCATION_NORMALIZED;
  if (isBrowser && options5.scrollBehavior && "scrollRestoration" in history) {
    history.scrollRestoration = "manual";
  }
  const normalizeParams = applyToParams.bind(null, (paramValue) => "" + paramValue);
  const encodeParams = applyToParams.bind(null, encodeParam);
  const decodeParams = (
    // @ts-expect-error: intentionally avoid the type check
    applyToParams.bind(null, decode$3)
  );
  function addRoute(parentOrRoute, route) {
    let parent;
    let record2;
    if (isRouteName(parentOrRoute)) {
      parent = matcher.getRecordMatcher(parentOrRoute);
      if (false) {
        warn$2(`Parent route "${String(parentOrRoute)}" not found when adding child route`, route);
      }
      record2 = route;
    } else {
      record2 = parentOrRoute;
    }
    return matcher.addRoute(record2, parent);
  }
  __name(addRoute, "addRoute");
  function removeRoute(name2) {
    const recordMatcher = matcher.getRecordMatcher(name2);
    if (recordMatcher) {
      matcher.removeRoute(recordMatcher);
    } else if (false) {
      warn$2(`Cannot remove non-existent route "${String(name2)}"`);
    }
  }
  __name(removeRoute, "removeRoute");
  function getRoutes() {
    return matcher.getRoutes().map((routeMatcher) => routeMatcher.record);
  }
  __name(getRoutes, "getRoutes");
  function hasRoute(name2) {
    return !!matcher.getRecordMatcher(name2);
  }
  __name(hasRoute, "hasRoute");
  function resolve2(rawLocation, currentLocation) {
    currentLocation = assign$5({}, currentLocation || currentRoute.value);
    if (typeof rawLocation === "string") {
      const locationNormalized = parseURL(parseQuery$1$1, rawLocation, currentLocation.path);
      const matchedRoute2 = matcher.resolve({ path: locationNormalized.path }, currentLocation);
      const href2 = routerHistory.createHref(locationNormalized.fullPath);
      if (false) {
        if (href2.startsWith("//"))
          warn$2(`Location "${rawLocation}" resolved to "${href2}". A resolved location cannot start with multiple slashes.`);
        else if (!matchedRoute2.matched.length) {
          warn$2(`No match found for location with path "${rawLocation}"`);
        }
      }
      return assign$5(locationNormalized, matchedRoute2, {
        params: decodeParams(matchedRoute2.params),
        hash: decode$3(locationNormalized.hash),
        redirectedFrom: void 0,
        href: href2
      });
    }
    if (false) {
      warn$2(`router.resolve() was passed an invalid location. This will fail in production.
- Location:`, rawLocation);
      return resolve2({});
    }
    let matcherLocation;
    if (rawLocation.path != null) {
      if (false) {
        warn$2(`Path "${rawLocation.path}" was passed with params but they will be ignored. Use a named route alongside params instead.`);
      }
      matcherLocation = assign$5({}, rawLocation, {
        path: parseURL(parseQuery$1$1, rawLocation.path, currentLocation.path).path
      });
    } else {
      const targetParams = assign$5({}, rawLocation.params);
      for (const key in targetParams) {
        if (targetParams[key] == null) {
          delete targetParams[key];
        }
      }
      matcherLocation = assign$5({}, rawLocation, {
        params: encodeParams(targetParams)
      });
      currentLocation.params = encodeParams(currentLocation.params);
    }
    const matchedRoute = matcher.resolve(matcherLocation, currentLocation);
    const hash = rawLocation.hash || "";
    if (false) {
      warn$2(`A \`hash\` should always start with the character "#". Replace "${hash}" with "#${hash}".`);
    }
    matchedRoute.params = normalizeParams(decodeParams(matchedRoute.params));
    const fullPath = stringifyURL(stringifyQuery$1, assign$5({}, rawLocation, {
      hash: encodeHash(hash),
      path: matchedRoute.path
    }));
    const href = routerHistory.createHref(fullPath);
    if (false) {
      if (href.startsWith("//")) {
        warn$2(`Location "${rawLocation}" resolved to "${href}". A resolved location cannot start with multiple slashes.`);
      } else if (!matchedRoute.matched.length) {
        warn$2(`No match found for location with path "${rawLocation.path != null ? rawLocation.path : rawLocation}"`);
      }
    }
    return assign$5({
      fullPath,
      // keep the hash encoded so fullPath is effectively path + encodedQuery +
      // hash
      hash,
      query: (
        // if the user is using a custom query lib like qs, we might have
        // nested objects, so we keep the query as is, meaning it can contain
        // numbers at `$route.query`, but at the point, the user will have to
        // use their own type anyway.
        // https://github.com/vuejs/router/issues/328#issuecomment-649481567
        stringifyQuery$1 === stringifyQuery ? normalizeQuery(rawLocation.query) : rawLocation.query || {}
      )
    }, matchedRoute, {
      redirectedFrom: void 0,
      href
    });
  }
  __name(resolve2, "resolve");
  function locationAsObject(to) {
    return typeof to === "string" ? parseURL(parseQuery$1$1, to, currentRoute.value.path) : assign$5({}, to);
  }
  __name(locationAsObject, "locationAsObject");
  function checkCanceledNavigation(to, from2) {
    if (pendingLocation !== to) {
      return createRouterError(8, {
        from: from2,
        to
      });
    }
  }
  __name(checkCanceledNavigation, "checkCanceledNavigation");
  function push2(to) {
    return pushWithRedirect(to);
  }
  __name(push2, "push");
  function replace2(to) {
    return push2(assign$5(locationAsObject(to), { replace: true }));
  }
  __name(replace2, "replace");
  function handleRedirectRecord(to) {
    const lastMatched = to.matched[to.matched.length - 1];
    if (lastMatched && lastMatched.redirect) {
      const { redirect } = lastMatched;
      let newTargetLocation = typeof redirect === "function" ? redirect(to) : redirect;
      if (typeof newTargetLocation === "string") {
        newTargetLocation = newTargetLocation.includes("?") || newTargetLocation.includes("#") ? newTargetLocation = locationAsObject(newTargetLocation) : (
          // force empty params
          { path: newTargetLocation }
        );
        newTargetLocation.params = {};
      }
      if (false) {
        warn$2(`Invalid redirect found:
${JSON.stringify(newTargetLocation, null, 2)}
 when navigating to "${to.fullPath}". A redirect must contain a name or path. This will break in production.`);
        throw new Error("Invalid redirect");
      }
      return assign$5({
        query: to.query,
        hash: to.hash,
        // avoid transferring params if the redirect has a path
        params: newTargetLocation.path != null ? {} : to.params
      }, newTargetLocation);
    }
  }
  __name(handleRedirectRecord, "handleRedirectRecord");
  function pushWithRedirect(to, redirectedFrom) {
    const targetLocation = pendingLocation = resolve2(to);
    const from2 = currentRoute.value;
    const data30 = to.state;
    const force = to.force;
    const replace22 = to.replace === true;
    const shouldRedirect = handleRedirectRecord(targetLocation);
    if (shouldRedirect)
      return pushWithRedirect(
        assign$5(locationAsObject(shouldRedirect), {
          state: typeof shouldRedirect === "object" ? assign$5({}, data30, shouldRedirect.state) : data30,
          force,
          replace: replace22
        }),
        // keep original redirectedFrom if it exists
        redirectedFrom || targetLocation
      );
    const toLocation = targetLocation;
    toLocation.redirectedFrom = redirectedFrom;
    let failure;
    if (!force && isSameRouteLocation(stringifyQuery$1, from2, targetLocation)) {
      failure = createRouterError(16, { to: toLocation, from: from2 });
      handleScroll(
        from2,
        from2,
        // this is a push, the only way for it to be triggered from a
        // history.listen is with a redirect, which makes it become a push
        true,
        // This cannot be the first navigation because the initial location
        // cannot be manually navigated to
        false
      );
    }
    return (failure ? Promise.resolve(failure) : navigate(toLocation, from2)).catch((error2) => isNavigationFailure(error2) ? (
      // navigation redirects still mark the router as ready
      isNavigationFailure(
        error2,
        2
        /* ErrorTypes.NAVIGATION_GUARD_REDIRECT */
      ) ? error2 : markAsReady(error2)
    ) : (
      // reject any unknown error
      triggerError(error2, toLocation, from2)
    )).then((failure2) => {
      if (failure2) {
        if (isNavigationFailure(
          failure2,
          2
          /* ErrorTypes.NAVIGATION_GUARD_REDIRECT */
        )) {
          if (false) {
            warn$2(`Detected a possibly infinite redirection in a navigation guard when going from "${from2.fullPath}" to "${toLocation.fullPath}". Aborting to avoid a Stack Overflow.
 Are you always returning a new location within a navigation guard? That would lead to this error. Only return when redirecting or aborting, that should fix this. This might break in production if not fixed.`);
            return Promise.reject(new Error("Infinite redirect in navigation guard"));
          }
          return pushWithRedirect(
            // keep options
            assign$5({
              // preserve an existing replacement but allow the redirect to override it
              replace: replace22
            }, locationAsObject(failure2.to), {
              state: typeof failure2.to === "object" ? assign$5({}, data30, failure2.to.state) : data30,
              force
            }),
            // preserve the original redirectedFrom if any
            redirectedFrom || toLocation
          );
        }
      } else {
        failure2 = finalizeNavigation(toLocation, from2, true, replace22, data30);
      }
      triggerAfterEach(toLocation, from2, failure2);
      return failure2;
    });
  }
  __name(pushWithRedirect, "pushWithRedirect");
  function checkCanceledNavigationAndReject(to, from2) {
    const error2 = checkCanceledNavigation(to, from2);
    return error2 ? Promise.reject(error2) : Promise.resolve();
  }
  __name(checkCanceledNavigationAndReject, "checkCanceledNavigationAndReject");
  function runWithContext(fn) {
    const app2 = installedApps.values().next().value;
    return app2 && typeof app2.runWithContext === "function" ? app2.runWithContext(fn) : fn();
  }
  __name(runWithContext, "runWithContext");
  function navigate(to, from2) {
    let guards;
    const [leavingRecords, updatingRecords, enteringRecords] = extractChangingRecords(to, from2);
    guards = extractComponentsGuards(leavingRecords.reverse(), "beforeRouteLeave", to, from2);
    for (const record2 of leavingRecords) {
      record2.leaveGuards.forEach((guard) => {
        guards.push(guardToPromiseFn(guard, to, from2));
      });
    }
    const canceledNavigationCheck = checkCanceledNavigationAndReject.bind(null, to, from2);
    guards.push(canceledNavigationCheck);
    return runGuardQueue(guards).then(() => {
      guards = [];
      for (const guard of beforeGuards.list()) {
        guards.push(guardToPromiseFn(guard, to, from2));
      }
      guards.push(canceledNavigationCheck);
      return runGuardQueue(guards);
    }).then(() => {
      guards = extractComponentsGuards(updatingRecords, "beforeRouteUpdate", to, from2);
      for (const record2 of updatingRecords) {
        record2.updateGuards.forEach((guard) => {
          guards.push(guardToPromiseFn(guard, to, from2));
        });
      }
      guards.push(canceledNavigationCheck);
      return runGuardQueue(guards);
    }).then(() => {
      guards = [];
      for (const record2 of enteringRecords) {
        if (record2.beforeEnter) {
          if (isArray$a(record2.beforeEnter)) {
            for (const beforeEnter of record2.beforeEnter)
              guards.push(guardToPromiseFn(beforeEnter, to, from2));
          } else {
            guards.push(guardToPromiseFn(record2.beforeEnter, to, from2));
          }
        }
      }
      guards.push(canceledNavigationCheck);
      return runGuardQueue(guards);
    }).then(() => {
      to.matched.forEach((record2) => record2.enterCallbacks = {});
      guards = extractComponentsGuards(enteringRecords, "beforeRouteEnter", to, from2, runWithContext);
      guards.push(canceledNavigationCheck);
      return runGuardQueue(guards);
    }).then(() => {
      guards = [];
      for (const guard of beforeResolveGuards.list()) {
        guards.push(guardToPromiseFn(guard, to, from2));
      }
      guards.push(canceledNavigationCheck);
      return runGuardQueue(guards);
    }).catch((err) => isNavigationFailure(
      err,
      8
      /* ErrorTypes.NAVIGATION_CANCELLED */
    ) ? err : Promise.reject(err));
  }
  __name(navigate, "navigate");
  function triggerAfterEach(to, from2, failure) {
    afterGuards.list().forEach((guard) => runWithContext(() => guard(to, from2, failure)));
  }
  __name(triggerAfterEach, "triggerAfterEach");
  function finalizeNavigation(toLocation, from2, isPush, replace22, data30) {
    const error2 = checkCanceledNavigation(toLocation, from2);
    if (error2)
      return error2;
    const isFirstNavigation = from2 === START_LOCATION_NORMALIZED;
    const state = !isBrowser ? {} : history.state;
    if (isPush) {
      if (replace22 || isFirstNavigation)
        routerHistory.replace(toLocation.fullPath, assign$5({
          scroll: isFirstNavigation && state && state.scroll
        }, data30));
      else
        routerHistory.push(toLocation.fullPath, data30);
    }
    currentRoute.value = toLocation;
    handleScroll(toLocation, from2, isPush, isFirstNavigation);
    markAsReady();
  }
  __name(finalizeNavigation, "finalizeNavigation");
  let removeHistoryListener;
  function setupListeners() {
    if (removeHistoryListener)
      return;
    removeHistoryListener = routerHistory.listen((to, _from, info) => {
      if (!router2.listening)
        return;
      const toLocation = resolve2(to);
      const shouldRedirect = handleRedirectRecord(toLocation);
      if (shouldRedirect) {
        pushWithRedirect(assign$5(shouldRedirect, { replace: true }), toLocation).catch(noop$3);
        return;
      }
      pendingLocation = toLocation;
      const from2 = currentRoute.value;
      if (isBrowser) {
        saveScrollPosition(getScrollKey(from2.fullPath, info.delta), computeScrollPosition());
      }
      navigate(toLocation, from2).catch((error2) => {
        if (isNavigationFailure(
          error2,
          4 | 8
          /* ErrorTypes.NAVIGATION_CANCELLED */
        )) {
          return error2;
        }
        if (isNavigationFailure(
          error2,
          2
          /* ErrorTypes.NAVIGATION_GUARD_REDIRECT */
        )) {
          pushWithRedirect(
            error2.to,
            toLocation
            // avoid an uncaught rejection, let push call triggerError
          ).then((failure) => {
            if (isNavigationFailure(
              failure,
              4 | 16
              /* ErrorTypes.NAVIGATION_DUPLICATED */
            ) && !info.delta && info.type === NavigationType.pop) {
              routerHistory.go(-1, false);
            }
          }).catch(noop$3);
          return Promise.reject();
        }
        if (info.delta) {
          routerHistory.go(-info.delta, false);
        }
        return triggerError(error2, toLocation, from2);
      }).then((failure) => {
        failure = failure || finalizeNavigation(
          // after navigation, all matched components are resolved
          toLocation,
          from2,
          false
        );
        if (failure) {
          if (info.delta && // a new navigation has been triggered, so we do not want to revert, that will change the current history
          // entry while a different route is displayed
          !isNavigationFailure(
            failure,
            8
            /* ErrorTypes.NAVIGATION_CANCELLED */
          )) {
            routerHistory.go(-info.delta, false);
          } else if (info.type === NavigationType.pop && isNavigationFailure(
            failure,
            4 | 16
            /* ErrorTypes.NAVIGATION_DUPLICATED */
          )) {
            routerHistory.go(-1, false);
          }
        }
        triggerAfterEach(toLocation, from2, failure);
      }).catch(noop$3);
    });
  }
  __name(setupListeners, "setupListeners");
  let readyHandlers = useCallbacks();
  let errorListeners = useCallbacks();
  let ready;
  function triggerError(error2, to, from2) {
    markAsReady(error2);
    const list2 = errorListeners.list();
    if (list2.length) {
      list2.forEach((handler14) => handler14(error2, to, from2));
    } else {
      if (false) {
        warn$2("uncaught error during route navigation:");
      }
      console.error(error2);
    }
    return Promise.reject(error2);
  }
  __name(triggerError, "triggerError");
  function isReady() {
    if (ready && currentRoute.value !== START_LOCATION_NORMALIZED)
      return Promise.resolve();
    return new Promise((resolve22, reject3) => {
      readyHandlers.add([resolve22, reject3]);
    });
  }
  __name(isReady, "isReady");
  function markAsReady(err) {
    if (!ready) {
      ready = !err;
      setupListeners();
      readyHandlers.list().forEach(([resolve22, reject3]) => err ? reject3(err) : resolve22());
      readyHandlers.reset();
    }
    return err;
  }
  __name(markAsReady, "markAsReady");
  function handleScroll(to, from2, isPush, isFirstNavigation) {
    const { scrollBehavior } = options5;
    if (!isBrowser || !scrollBehavior)
      return Promise.resolve();
    const scrollPosition = !isPush && getSavedScrollPosition(getScrollKey(to.fullPath, 0)) || (isFirstNavigation || !isPush) && history.state && history.state.scroll || null;
    return nextTick().then(() => scrollBehavior(to, from2, scrollPosition)).then((position3) => position3 && scrollToPosition(position3)).catch((err) => triggerError(err, to, from2));
  }
  __name(handleScroll, "handleScroll");
  const go = /* @__PURE__ */ __name((delta2) => routerHistory.go(delta2), "go");
  let started;
  const installedApps = /* @__PURE__ */ new Set();
  const router2 = {
    currentRoute,
    listening: true,
    addRoute,
    removeRoute,
    clearRoutes: matcher.clearRoutes,
    hasRoute,
    getRoutes,
    resolve: resolve2,
    options: options5,
    push: push2,
    replace: replace2,
    go,
    back: /* @__PURE__ */ __name(() => go(-1), "back"),
    forward: /* @__PURE__ */ __name(() => go(1), "forward"),
    beforeEach: beforeGuards.add,
    beforeResolve: beforeResolveGuards.add,
    afterEach: afterGuards.add,
    onError: errorListeners.add,
    isReady,
    install(app2) {
      const router22 = this;
      app2.component("RouterLink", RouterLink);
      app2.component("RouterView", RouterView);
      app2.config.globalProperties.$router = router22;
      Object.defineProperty(app2.config.globalProperties, "$route", {
        enumerable: true,
        get: /* @__PURE__ */ __name(() => unref(currentRoute), "get")
      });
      if (isBrowser && // used for the initial navigation client side to avoid pushing
      // multiple times when the router is used in multiple apps
      !started && currentRoute.value === START_LOCATION_NORMALIZED) {
        started = true;
        push2(routerHistory.location).catch((err) => {
          if (false)
            warn$2("Unexpected error when starting the router:", err);
        });
      }
      const reactiveRoute = {};
      for (const key in START_LOCATION_NORMALIZED) {
        Object.defineProperty(reactiveRoute, key, {
          get: /* @__PURE__ */ __name(() => currentRoute.value[key], "get"),
          enumerable: true
        });
      }
      app2.provide(routerKey, router22);
      app2.provide(routeLocationKey, shallowReactive(reactiveRoute));
      app2.provide(routerViewLocationKey, currentRoute);
      const unmountApp = app2.unmount;
      installedApps.add(app2);
      app2.unmount = function() {
        installedApps.delete(app2);
        if (installedApps.size < 1) {
          pendingLocation = START_LOCATION_NORMALIZED;
          removeHistoryListener && removeHistoryListener();
          removeHistoryListener = null;
          currentRoute.value = START_LOCATION_NORMALIZED;
          started = false;
          ready = false;
        }
        unmountApp();
      };
      if (false) {
        addDevtools(app2, router22, matcher);
      }
    }
  };
  function runGuardQueue(guards) {
    return guards.reduce((promise, guard) => promise.then(() => runWithContext(guard)), Promise.resolve());
  }
  __name(runGuardQueue, "runGuardQueue");
  return router2;
}
__name(createRouter, "createRouter");
function extractChangingRecords(to, from2) {
  const leavingRecords = [];
  const updatingRecords = [];
  const enteringRecords = [];
  const len = Math.max(from2.matched.length, to.matched.length);
  for (let i2 = 0; i2 < len; i2++) {
    const recordFrom = from2.matched[i2];
    if (recordFrom) {
      if (to.matched.find((record2) => isSameRouteRecord(record2, recordFrom)))
        updatingRecords.push(recordFrom);
      else
        leavingRecords.push(recordFrom);
    }
    const recordTo = to.matched[i2];
    if (recordTo) {
      if (!from2.matched.find((record2) => isSameRouteRecord(record2, recordTo))) {
        enteringRecords.push(recordTo);
      }
    }
  }
  return [leavingRecords, updatingRecords, enteringRecords];
}
__name(extractChangingRecords, "extractChangingRecords");
function useRouter() {
  return inject(routerKey);
}
__name(useRouter, "useRouter");
function useRoute(_name) {
  return inject(routeLocationKey);
}
__name(useRoute, "useRoute");
const _export_sfc = /* @__PURE__ */ __name((sfc, props) => {
  const target2 = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target2[key] = val;
  }
  return target2;
}, "_export_sfc");
const _sfc_main$1G = {};
const _hoisted_1$1Q = { class: "w-full min-h-screen overflow-hidden relative" };
function _sfc_render$2(_ctx, _cache) {
  const _component_router_view = resolveComponent("router-view");
  return openBlock(), createElementBlock("main", _hoisted_1$1Q, [
    createVNode(_component_router_view)
  ]);
}
__name(_sfc_render$2, "_sfc_render$2");
const LayoutDefault = /* @__PURE__ */ _export_sfc(_sfc_main$1G, [["render", _sfc_render$2]]);
"use strict";
function bind$3(fn, thisArg) {
  return /* @__PURE__ */ __name(function wrap2() {
    return fn.apply(thisArg, arguments);
  }, "wrap");
}
__name(bind$3, "bind$3");
"use strict";
const { toString: toString$2 } = Object.prototype;
const { getPrototypeOf } = Object;
const kindOf = /* @__PURE__ */ ((cache2) => (thing) => {
  const str = toString$2.call(thing);
  return cache2[str] || (cache2[str] = str.slice(8, -1).toLowerCase());
})(/* @__PURE__ */ Object.create(null));
const kindOfTest = /* @__PURE__ */ __name((type) => {
  type = type.toLowerCase();
  return (thing) => kindOf(thing) === type;
}, "kindOfTest");
const typeOfTest = /* @__PURE__ */ __name((type) => (thing) => typeof thing === type, "typeOfTest");
const { isArray: isArray$9 } = Array;
const isUndefined = typeOfTest("undefined");
function isBuffer$4(val) {
  return val !== null && !isUndefined(val) && val.constructor !== null && !isUndefined(val.constructor) && isFunction$a(val.constructor.isBuffer) && val.constructor.isBuffer(val);
}
__name(isBuffer$4, "isBuffer$4");
const isArrayBuffer = kindOfTest("ArrayBuffer");
function isArrayBufferView(val) {
  let result;
  if (typeof ArrayBuffer !== "undefined" && ArrayBuffer.isView) {
    result = ArrayBuffer.isView(val);
  } else {
    result = val && val.buffer && isArrayBuffer(val.buffer);
  }
  return result;
}
__name(isArrayBufferView, "isArrayBufferView");
const isString$8 = typeOfTest("string");
const isFunction$a = typeOfTest("function");
const isNumber$6 = typeOfTest("number");
const isObject$e = /* @__PURE__ */ __name((thing) => thing !== null && typeof thing === "object", "isObject$e");
const isBoolean$2 = /* @__PURE__ */ __name((thing) => thing === true || thing === false, "isBoolean$2");
const isPlainObject$2 = /* @__PURE__ */ __name((val) => {
  if (kindOf(val) !== "object") {
    return false;
  }
  const prototype2 = getPrototypeOf(val);
  return (prototype2 === null || prototype2 === Object.prototype || Object.getPrototypeOf(prototype2) === null) && !(Symbol.toStringTag in val) && !(Symbol.iterator in val);
}, "isPlainObject$2");
const isDate$3 = kindOfTest("Date");
const isFile = kindOfTest("File");
const isBlob = kindOfTest("Blob");
const isFileList = kindOfTest("FileList");
const isStream = /* @__PURE__ */ __name((val) => isObject$e(val) && isFunction$a(val.pipe), "isStream");
const isFormData = /* @__PURE__ */ __name((thing) => {
  let kind;
  return thing && (typeof FormData === "function" && thing instanceof FormData || isFunction$a(thing.append) && ((kind = kindOf(thing)) === "formdata" || // detect form-data instance
  kind === "object" && isFunction$a(thing.toString) && thing.toString() === "[object FormData]"));
}, "isFormData");
const isURLSearchParams = kindOfTest("URLSearchParams");
const [isReadableStream, isRequest, isResponse, isHeaders] = ["ReadableStream", "Request", "Response", "Headers"].map(kindOfTest);
const trim = /* @__PURE__ */ __name((str) => str.trim ? str.trim() : str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, ""), "trim");
function forEach$1(obj, fn, { allOwnKeys = false } = {}) {
  if (obj === null || typeof obj === "undefined") {
    return;
  }
  let i2;
  let l2;
  if (typeof obj !== "object") {
    obj = [obj];
  }
  if (isArray$9(obj)) {
    for (i2 = 0, l2 = obj.length; i2 < l2; i2++) {
      fn.call(null, obj[i2], i2, obj);
    }
  } else {
    const keys2 = allOwnKeys ? Object.getOwnPropertyNames(obj) : Object.keys(obj);
    const len = keys2.length;
    let key;
    for (i2 = 0; i2 < len; i2++) {
      key = keys2[i2];
      fn.call(null, obj[key], key, obj);
    }
  }
}
__name(forEach$1, "forEach$1");
function findKey(obj, key) {
  key = key.toLowerCase();
  const keys2 = Object.keys(obj);
  let i2 = keys2.length;
  let _key;
  while (i2-- > 0) {
    _key = keys2[i2];
    if (key === _key.toLowerCase()) {
      return _key;
    }
  }
  return null;
}
__name(findKey, "findKey");
const _global$1 = (() => {
  if (typeof globalThis !== "undefined") return globalThis;
  return typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : global;
})();
const isContextDefined = /* @__PURE__ */ __name((context) => !isUndefined(context) && context !== _global$1, "isContextDefined");
function merge$1() {
  const { caseless } = isContextDefined(this) && this || {};
  const result = {};
  const assignValue2 = /* @__PURE__ */ __name((val, key) => {
    const targetKey = caseless && findKey(result, key) || key;
    if (isPlainObject$2(result[targetKey]) && isPlainObject$2(val)) {
      result[targetKey] = merge$1(result[targetKey], val);
    } else if (isPlainObject$2(val)) {
      result[targetKey] = merge$1({}, val);
    } else if (isArray$9(val)) {
      result[targetKey] = val.slice();
    } else {
      result[targetKey] = val;
    }
  }, "assignValue");
  for (let i2 = 0, l2 = arguments.length; i2 < l2; i2++) {
    arguments[i2] && forEach$1(arguments[i2], assignValue2);
  }
  return result;
}
__name(merge$1, "merge$1");
const extend = /* @__PURE__ */ __name((a2, b2, thisArg, { allOwnKeys } = {}) => {
  forEach$1(b2, (val, key) => {
    if (thisArg && isFunction$a(val)) {
      a2[key] = bind$3(val, thisArg);
    } else {
      a2[key] = val;
    }
  }, { allOwnKeys });
  return a2;
}, "extend");
const stripBOM = /* @__PURE__ */ __name((content3) => {
  if (content3.charCodeAt(0) === 65279) {
    content3 = content3.slice(1);
  }
  return content3;
}, "stripBOM");
const inherits = /* @__PURE__ */ __name((constructor, superConstructor, props, descriptors2) => {
  constructor.prototype = Object.create(superConstructor.prototype, descriptors2);
  constructor.prototype.constructor = constructor;
  Object.defineProperty(constructor, "super", {
    value: superConstructor.prototype
  });
  props && Object.assign(constructor.prototype, props);
}, "inherits");
const toFlatObject = /* @__PURE__ */ __name((sourceObj, destObj, filter4, propFilter) => {
  let props;
  let i2;
  let prop2;
  const merged = {};
  destObj = destObj || {};
  if (sourceObj == null) return destObj;
  do {
    props = Object.getOwnPropertyNames(sourceObj);
    i2 = props.length;
    while (i2-- > 0) {
      prop2 = props[i2];
      if ((!propFilter || propFilter(prop2, sourceObj, destObj)) && !merged[prop2]) {
        destObj[prop2] = sourceObj[prop2];
        merged[prop2] = true;
      }
    }
    sourceObj = filter4 !== false && getPrototypeOf(sourceObj);
  } while (sourceObj && (!filter4 || filter4(sourceObj, destObj)) && sourceObj !== Object.prototype);
  return destObj;
}, "toFlatObject");
const endsWith = /* @__PURE__ */ __name((str, searchString, position3) => {
  str = String(str);
  if (position3 === void 0 || position3 > str.length) {
    position3 = str.length;
  }
  position3 -= searchString.length;
  const lastIndex = str.indexOf(searchString, position3);
  return lastIndex !== -1 && lastIndex === position3;
}, "endsWith");
const toArray = /* @__PURE__ */ __name((thing) => {
  if (!thing) return null;
  if (isArray$9(thing)) return thing;
  let i2 = thing.length;
  if (!isNumber$6(i2)) return null;
  const arr = new Array(i2);
  while (i2-- > 0) {
    arr[i2] = thing[i2];
  }
  return arr;
}, "toArray");
const isTypedArray$3 = /* @__PURE__ */ ((TypedArray) => {
  return (thing) => {
    return TypedArray && thing instanceof TypedArray;
  };
})(typeof Uint8Array !== "undefined" && getPrototypeOf(Uint8Array));
const forEachEntry = /* @__PURE__ */ __name((obj, fn) => {
  const generator = obj && obj[Symbol.iterator];
  const iterator2 = generator.call(obj);
  let result;
  while ((result = iterator2.next()) && !result.done) {
    const pair = result.value;
    fn.call(obj, pair[0], pair[1]);
  }
}, "forEachEntry");
const matchAll = /* @__PURE__ */ __name((regExp, str) => {
  let matches2;
  const arr = [];
  while ((matches2 = regExp.exec(str)) !== null) {
    arr.push(matches2);
  }
  return arr;
}, "matchAll");
const isHTMLForm = kindOfTest("HTMLFormElement");
const toCamelCase = /* @__PURE__ */ __name((str) => {
  return str.toLowerCase().replace(
    /[-_\s]([a-z\d])(\w*)/g,
    /* @__PURE__ */ __name(function replacer2(m2, p1, p2) {
      return p1.toUpperCase() + p2;
    }, "replacer")
  );
}, "toCamelCase");
const hasOwnProperty$b = (({ hasOwnProperty: hasOwnProperty2 }) => (obj, prop2) => hasOwnProperty2.call(obj, prop2))(Object.prototype);
const isRegExp$3 = kindOfTest("RegExp");
const reduceDescriptors = /* @__PURE__ */ __name((obj, reducer) => {
  const descriptors2 = Object.getOwnPropertyDescriptors(obj);
  const reducedDescriptors = {};
  forEach$1(descriptors2, (descriptor, name2) => {
    let ret;
    if ((ret = reducer(descriptor, name2, obj)) !== false) {
      reducedDescriptors[name2] = ret || descriptor;
    }
  });
  Object.defineProperties(obj, reducedDescriptors);
}, "reduceDescriptors");
const freezeMethods = /* @__PURE__ */ __name((obj) => {
  reduceDescriptors(obj, (descriptor, name2) => {
    if (isFunction$a(obj) && ["arguments", "caller", "callee"].indexOf(name2) !== -1) {
      return false;
    }
    const value3 = obj[name2];
    if (!isFunction$a(value3)) return;
    descriptor.enumerable = false;
    if ("writable" in descriptor) {
      descriptor.writable = false;
      return;
    }
    if (!descriptor.set) {
      descriptor.set = () => {
        throw Error("Can not rewrite read-only method '" + name2 + "'");
      };
    }
  });
}, "freezeMethods");
const toObjectSet = /* @__PURE__ */ __name((arrayOrString, delimiter2) => {
  const obj = {};
  const define = /* @__PURE__ */ __name((arr) => {
    arr.forEach((value3) => {
      obj[value3] = true;
    });
  }, "define");
  isArray$9(arrayOrString) ? define(arrayOrString) : define(String(arrayOrString).split(delimiter2));
  return obj;
}, "toObjectSet");
const noop$2 = /* @__PURE__ */ __name(() => {
}, "noop$2");
const toFiniteNumber = /* @__PURE__ */ __name((value3, defaultValue2) => {
  return value3 != null && Number.isFinite(value3 = +value3) ? value3 : defaultValue2;
}, "toFiniteNumber");
function isSpecCompliantForm(thing) {
  return !!(thing && isFunction$a(thing.append) && thing[Symbol.toStringTag] === "FormData" && thing[Symbol.iterator]);
}
__name(isSpecCompliantForm, "isSpecCompliantForm");
const toJSONObject = /* @__PURE__ */ __name((obj) => {
  const stack2 = new Array(10);
  const visit2 = /* @__PURE__ */ __name((source, i2) => {
    if (isObject$e(source)) {
      if (stack2.indexOf(source) >= 0) {
        return;
      }
      if (!("toJSON" in source)) {
        stack2[i2] = source;
        const target2 = isArray$9(source) ? [] : {};
        forEach$1(source, (value3, key) => {
          const reducedValue = visit2(value3, i2 + 1);
          !isUndefined(reducedValue) && (target2[key] = reducedValue);
        });
        stack2[i2] = void 0;
        return target2;
      }
    }
    return source;
  }, "visit");
  return visit2(obj, 0);
}, "toJSONObject");
const isAsyncFn = kindOfTest("AsyncFunction");
const isThenable = /* @__PURE__ */ __name((thing) => thing && (isObject$e(thing) || isFunction$a(thing)) && isFunction$a(thing.then) && isFunction$a(thing.catch), "isThenable");
const _setImmediate = ((setImmediateSupported, postMessageSupported) => {
  if (setImmediateSupported) {
    return setImmediate;
  }
  return postMessageSupported ? ((token, callbacks) => {
    _global$1.addEventListener("message", ({ source, data: data30 }) => {
      if (source === _global$1 && data30 === token) {
        callbacks.length && callbacks.shift()();
      }
    }, false);
    return (cb) => {
      callbacks.push(cb);
      _global$1.postMessage(token, "*");
    };
  })(`axios@${Math.random()}`, []) : (cb) => setTimeout(cb);
})(
  typeof setImmediate === "function",
  isFunction$a(_global$1.postMessage)
);
const asap = typeof queueMicrotask !== "undefined" ? queueMicrotask.bind(_global$1) : typeof process !== "undefined" && process.nextTick || _setImmediate;
const utils$2 = {
  isArray: isArray$9,
  isArrayBuffer,
  isBuffer: isBuffer$4,
  isFormData,
  isArrayBufferView,
  isString: isString$8,
  isNumber: isNumber$6,
  isBoolean: isBoolean$2,
  isObject: isObject$e,
  isPlainObject: isPlainObject$2,
  isReadableStream,
  isRequest,
  isResponse,
  isHeaders,
  isUndefined,
  isDate: isDate$3,
  isFile,
  isBlob,
  isRegExp: isRegExp$3,
  isFunction: isFunction$a,
  isStream,
  isURLSearchParams,
  isTypedArray: isTypedArray$3,
  isFileList,
  forEach: forEach$1,
  merge: merge$1,
  extend,
  trim,
  stripBOM,
  inherits,
  toFlatObject,
  kindOf,
  kindOfTest,
  endsWith,
  toArray,
  forEachEntry,
  matchAll,
  isHTMLForm,
  hasOwnProperty: hasOwnProperty$b,
  hasOwnProp: hasOwnProperty$b,
  // an alias to avoid ESLint no-prototype-builtins detection
  reduceDescriptors,
  freezeMethods,
  toObjectSet,
  toCamelCase,
  noop: noop$2,
  toFiniteNumber,
  findKey,
  global: _global$1,
  isContextDefined,
  isSpecCompliantForm,
  toJSONObject,
  isAsyncFn,
  isThenable,
  setImmediate: _setImmediate,
  asap
};
"use strict";
function AxiosError$1(message3, code2, config2, request, response) {
  Error.call(this);
  if (Error.captureStackTrace) {
    Error.captureStackTrace(this, this.constructor);
  } else {
    this.stack = new Error().stack;
  }
  this.message = message3;
  this.name = "AxiosError";
  code2 && (this.code = code2);
  config2 && (this.config = config2);
  request && (this.request = request);
  if (response) {
    this.response = response;
    this.status = response.status ? response.status : null;
  }
}
__name(AxiosError$1, "AxiosError$1");
utils$2.inherits(AxiosError$1, Error, {
  toJSON: /* @__PURE__ */ __name(function toJSON() {
    return {
      // Standard
      message: this.message,
      name: this.name,
      // Microsoft
      description: this.description,
      number: this.number,
      // Mozilla
      fileName: this.fileName,
      lineNumber: this.lineNumber,
      columnNumber: this.columnNumber,
      stack: this.stack,
      // Axios
      config: utils$2.toJSONObject(this.config),
      code: this.code,
      status: this.status
    };
  }, "toJSON")
});
const prototype$1 = AxiosError$1.prototype;
const descriptors = {};
[
  "ERR_BAD_OPTION_VALUE",
  "ERR_BAD_OPTION",
  "ECONNABORTED",
  "ETIMEDOUT",
  "ERR_NETWORK",
  "ERR_FR_TOO_MANY_REDIRECTS",
  "ERR_DEPRECATED",
  "ERR_BAD_RESPONSE",
  "ERR_BAD_REQUEST",
  "ERR_CANCELED",
  "ERR_NOT_SUPPORT",
  "ERR_INVALID_URL"
  // eslint-disable-next-line func-names
].forEach((code2) => {
  descriptors[code2] = { value: code2 };
});
Object.defineProperties(AxiosError$1, descriptors);
Object.defineProperty(prototype$1, "isAxiosError", { value: true });
AxiosError$1.from = (error2, code2, config2, request, response, customProps) => {
  const axiosError = Object.create(prototype$1);
  utils$2.toFlatObject(error2, axiosError, /* @__PURE__ */ __name(function filter4(obj) {
    return obj !== Error.prototype;
  }, "filter"), (prop2) => {
    return prop2 !== "isAxiosError";
  });
  AxiosError$1.call(axiosError, error2.message, code2, config2, request, response);
  axiosError.cause = error2;
  axiosError.name = error2.name;
  customProps && Object.assign(axiosError, customProps);
  return axiosError;
};
const httpAdapter = null;
"use strict";
function isVisitable(thing) {
  return utils$2.isPlainObject(thing) || utils$2.isArray(thing);
}
__name(isVisitable, "isVisitable");
function removeBrackets(key) {
  return utils$2.endsWith(key, "[]") ? key.slice(0, -2) : key;
}
__name(removeBrackets, "removeBrackets");
function renderKey(path, key, dots) {
  if (!path) return key;
  return path.concat(key).map(/* @__PURE__ */ __name(function each(token, i2) {
    token = removeBrackets(token);
    return !dots && i2 ? "[" + token + "]" : token;
  }, "each")).join(dots ? "." : "");
}
__name(renderKey, "renderKey");
function isFlatArray(arr) {
  return utils$2.isArray(arr) && !arr.some(isVisitable);
}
__name(isFlatArray, "isFlatArray");
const predicates = utils$2.toFlatObject(utils$2, {}, null, /* @__PURE__ */ __name(function filter3(prop2) {
  return /^is[A-Z]/.test(prop2);
}, "filter"));
function toFormData$1(obj, formData, options5) {
  if (!utils$2.isObject(obj)) {
    throw new TypeError("target must be an object");
  }
  formData = formData || new (httpAdapter || FormData)();
  options5 = utils$2.toFlatObject(options5, {
    metaTokens: true,
    dots: false,
    indexes: false
  }, false, /* @__PURE__ */ __name(function defined(option5, source) {
    return !utils$2.isUndefined(source[option5]);
  }, "defined"));
  const metaTokens = options5.metaTokens;
  const visitor = options5.visitor || defaultVisitor;
  const dots = options5.dots;
  const indexes = options5.indexes;
  const _Blob = options5.Blob || typeof Blob !== "undefined" && Blob;
  const useBlob = _Blob && utils$2.isSpecCompliantForm(formData);
  if (!utils$2.isFunction(visitor)) {
    throw new TypeError("visitor must be a function");
  }
  function convertValue(value3) {
    if (value3 === null) return "";
    if (utils$2.isDate(value3)) {
      return value3.toISOString();
    }
    if (!useBlob && utils$2.isBlob(value3)) {
      throw new AxiosError$1("Blob is not supported. Use a Buffer instead.");
    }
    if (utils$2.isArrayBuffer(value3) || utils$2.isTypedArray(value3)) {
      return useBlob && typeof Blob === "function" ? new Blob([value3]) : Buffer.from(value3);
    }
    return value3;
  }
  __name(convertValue, "convertValue");
  function defaultVisitor(value3, key, path) {
    let arr = value3;
    if (value3 && !path && typeof value3 === "object") {
      if (utils$2.endsWith(key, "{}")) {
        key = metaTokens ? key : key.slice(0, -2);
        value3 = JSON.stringify(value3);
      } else if (utils$2.isArray(value3) && isFlatArray(value3) || (utils$2.isFileList(value3) || utils$2.endsWith(key, "[]")) && (arr = utils$2.toArray(value3))) {
        key = removeBrackets(key);
        arr.forEach(/* @__PURE__ */ __name(function each(el, index2) {
          !(utils$2.isUndefined(el) || el === null) && formData.append(
            // eslint-disable-next-line no-nested-ternary
            indexes === true ? renderKey([key], index2, dots) : indexes === null ? key : key + "[]",
            convertValue(el)
          );
        }, "each"));
        return false;
      }
    }
    if (isVisitable(value3)) {
      return true;
    }
    formData.append(renderKey(path, key, dots), convertValue(value3));
    return false;
  }
  __name(defaultVisitor, "defaultVisitor");
  const stack2 = [];
  const exposedHelpers = Object.assign(predicates, {
    defaultVisitor,
    convertValue,
    isVisitable
  });
  function build(value3, path) {
    if (utils$2.isUndefined(value3)) return;
    if (stack2.indexOf(value3) !== -1) {
      throw Error("Circular reference detected in " + path.join("."));
    }
    stack2.push(value3);
    utils$2.forEach(value3, /* @__PURE__ */ __name(function each(el, key) {
      const result = !(utils$2.isUndefined(el) || el === null) && visitor.call(
        formData,
        el,
        utils$2.isString(key) ? key.trim() : key,
        path,
        exposedHelpers
      );
      if (result === true) {
        build(el, path ? path.concat(key) : [key]);
      }
    }, "each"));
    stack2.pop();
  }
  __name(build, "build");
  if (!utils$2.isObject(obj)) {
    throw new TypeError("data must be an object");
  }
  build(obj);
  return formData;
}
__name(toFormData$1, "toFormData$1");
"use strict";
function encode$4(str) {
  const charMap = {
    "!": "%21",
    "'": "%27",
    "(": "%28",
    ")": "%29",
    "~": "%7E",
    "%20": "+",
    "%00": "\0"
  };
  return encodeURIComponent(str).replace(/[!'()~]|%20|%00/g, /* @__PURE__ */ __name(function replacer2(match2) {
    return charMap[match2];
  }, "replacer"));
}
__name(encode$4, "encode$4");
function AxiosURLSearchParams(params, options5) {
  this._pairs = [];
  params && toFormData$1(params, this, options5);
}
__name(AxiosURLSearchParams, "AxiosURLSearchParams");
const prototype = AxiosURLSearchParams.prototype;
prototype.append = /* @__PURE__ */ __name(function append(name2, value3) {
  this._pairs.push([name2, value3]);
}, "append");
prototype.toString = /* @__PURE__ */ __name(function toString2(encoder) {
  const _encode = encoder ? function(value3) {
    return encoder.call(this, value3, encode$4);
  } : encode$4;
  return this._pairs.map(/* @__PURE__ */ __name(function each(pair) {
    return _encode(pair[0]) + "=" + _encode(pair[1]);
  }, "each"), "").join("&");
}, "toString");
"use strict";
function encode$3(val) {
  return encodeURIComponent(val).replace(/%3A/gi, ":").replace(/%24/g, "$").replace(/%2C/gi, ",").replace(/%20/g, "+").replace(/%5B/gi, "[").replace(/%5D/gi, "]");
}
__name(encode$3, "encode$3");
function buildURL(url, params, options5) {
  if (!params) {
    return url;
  }
  const _encode = options5 && options5.encode || encode$3;
  if (utils$2.isFunction(options5)) {
    options5 = {
      serialize: options5
    };
  }
  const serializeFn = options5 && options5.serialize;
  let serializedParams;
  if (serializeFn) {
    serializedParams = serializeFn(params, options5);
  } else {
    serializedParams = utils$2.isURLSearchParams(params) ? params.toString() : new AxiosURLSearchParams(params, options5).toString(_encode);
  }
  if (serializedParams) {
    const hashmarkIndex = url.indexOf("#");
    if (hashmarkIndex !== -1) {
      url = url.slice(0, hashmarkIndex);
    }
    url += (url.indexOf("?") === -1 ? "?" : "&") + serializedParams;
  }
  return url;
}
__name(buildURL, "buildURL");
"use strict";
class InterceptorManager {
  static {
    __name(this, "InterceptorManager");
  }
  constructor() {
    this.handlers = [];
  }
  /**
   * Add a new interceptor to the stack
   *
   * @param {Function} fulfilled The function to handle `then` for a `Promise`
   * @param {Function} rejected The function to handle `reject` for a `Promise`
   *
   * @return {Number} An ID used to remove interceptor later
   */
  use(fulfilled, rejected, options5) {
    this.handlers.push({
      fulfilled,
      rejected,
      synchronous: options5 ? options5.synchronous : false,
      runWhen: options5 ? options5.runWhen : null
    });
    return this.handlers.length - 1;
  }
  /**
   * Remove an interceptor from the stack
   *
   * @param {Number} id The ID that was returned by `use`
   *
   * @returns {Boolean} `true` if the interceptor was removed, `false` otherwise
   */
  eject(id4) {
    if (this.handlers[id4]) {
      this.handlers[id4] = null;
    }
  }
  /**
   * Clear all interceptors from the stack
   *
   * @returns {void}
   */
  clear() {
    if (this.handlers) {
      this.handlers = [];
    }
  }
  /**
   * Iterate over all the registered interceptors
   *
   * This method is particularly useful for skipping over any
   * interceptors that may have become `null` calling `eject`.
   *
   * @param {Function} fn The function to call for each interceptor
   *
   * @returns {void}
   */
  forEach(fn) {
    utils$2.forEach(this.handlers, /* @__PURE__ */ __name(function forEachHandler(h2) {
      if (h2 !== null) {
        fn(h2);
      }
    }, "forEachHandler"));
  }
}
"use strict";
const transitionalDefaults = {
  silentJSONParsing: true,
  forcedJSONParsing: true,
  clarifyTimeoutError: false
};
"use strict";
const URLSearchParams$1 = typeof URLSearchParams !== "undefined" ? URLSearchParams : AxiosURLSearchParams;
"use strict";
const FormData$1 = typeof FormData !== "undefined" ? FormData : null;
"use strict";
const Blob$1 = typeof Blob !== "undefined" ? Blob : null;
const platform$1 = {
  isBrowser: true,
  classes: {
    URLSearchParams: URLSearchParams$1,
    FormData: FormData$1,
    Blob: Blob$1
  },
  protocols: ["http", "https", "file", "blob", "url", "data"]
};
const hasBrowserEnv = typeof window !== "undefined" && typeof document !== "undefined";
const _navigator = typeof navigator === "object" && navigator || void 0;
const hasStandardBrowserEnv = hasBrowserEnv && (!_navigator || ["ReactNative", "NativeScript", "NS"].indexOf(_navigator.product) < 0);
const hasStandardBrowserWebWorkerEnv = (() => {
  return typeof WorkerGlobalScope !== "undefined" && // eslint-disable-next-line no-undef
  self instanceof WorkerGlobalScope && typeof self.importScripts === "function";
})();
const origin = hasBrowserEnv && window.location.href || "http://localhost";
const utils$1 = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  hasBrowserEnv,
  hasStandardBrowserEnv,
  hasStandardBrowserWebWorkerEnv,
  navigator: _navigator,
  origin
}, Symbol.toStringTag, { value: "Module" }));
const platform = {
  ...utils$1,
  ...platform$1
};
"use strict";
function toURLEncodedForm(data30, options5) {
  return toFormData$1(data30, new platform.classes.URLSearchParams(), Object.assign({
    visitor: /* @__PURE__ */ __name(function(value3, key, path, helpers2) {
      if (platform.isNode && utils$2.isBuffer(value3)) {
        this.append(key, value3.toString("base64"));
        return false;
      }
      return helpers2.defaultVisitor.apply(this, arguments);
    }, "visitor")
  }, options5));
}
__name(toURLEncodedForm, "toURLEncodedForm");
"use strict";
function parsePropPath(name2) {
  return utils$2.matchAll(/\w+|\[(\w*)]/g, name2).map((match2) => {
    return match2[0] === "[]" ? "" : match2[1] || match2[0];
  });
}
__name(parsePropPath, "parsePropPath");
function arrayToObject(arr) {
  const obj = {};
  const keys2 = Object.keys(arr);
  let i2;
  const len = keys2.length;
  let key;
  for (i2 = 0; i2 < len; i2++) {
    key = keys2[i2];
    obj[key] = arr[key];
  }
  return obj;
}
__name(arrayToObject, "arrayToObject");
function formDataToJSON(formData) {
  function buildPath(path, value3, target2, index2) {
    let name2 = path[index2++];
    if (name2 === "__proto__") return true;
    const isNumericKey = Number.isFinite(+name2);
    const isLast = index2 >= path.length;
    name2 = !name2 && utils$2.isArray(target2) ? target2.length : name2;
    if (isLast) {
      if (utils$2.hasOwnProp(target2, name2)) {
        target2[name2] = [target2[name2], value3];
      } else {
        target2[name2] = value3;
      }
      return !isNumericKey;
    }
    if (!target2[name2] || !utils$2.isObject(target2[name2])) {
      target2[name2] = [];
    }
    const result = buildPath(path, value3, target2[name2], index2);
    if (result && utils$2.isArray(target2[name2])) {
      target2[name2] = arrayToObject(target2[name2]);
    }
    return !isNumericKey;
  }
  __name(buildPath, "buildPath");
  if (utils$2.isFormData(formData) && utils$2.isFunction(formData.entries)) {
    const obj = {};
    utils$2.forEachEntry(formData, (name2, value3) => {
      buildPath(parsePropPath(name2), value3, obj, 0);
    });
    return obj;
  }
  return null;
}
__name(formDataToJSON, "formDataToJSON");
"use strict";
function stringifySafely(rawValue, parser, encoder) {
  if (utils$2.isString(rawValue)) {
    try {
      (parser || JSON.parse)(rawValue);
      return utils$2.trim(rawValue);
    } catch (e2) {
      if (e2.name !== "SyntaxError") {
        throw e2;
      }
    }
  }
  return (encoder || JSON.stringify)(rawValue);
}
__name(stringifySafely, "stringifySafely");
const defaults$2 = {
  transitional: transitionalDefaults,
  adapter: ["xhr", "http", "fetch"],
  transformRequest: [/* @__PURE__ */ __name(function transformRequest(data30, headers) {
    const contentType = headers.getContentType() || "";
    const hasJSONContentType = contentType.indexOf("application/json") > -1;
    const isObjectPayload = utils$2.isObject(data30);
    if (isObjectPayload && utils$2.isHTMLForm(data30)) {
      data30 = new FormData(data30);
    }
    const isFormData2 = utils$2.isFormData(data30);
    if (isFormData2) {
      return hasJSONContentType ? JSON.stringify(formDataToJSON(data30)) : data30;
    }
    if (utils$2.isArrayBuffer(data30) || utils$2.isBuffer(data30) || utils$2.isStream(data30) || utils$2.isFile(data30) || utils$2.isBlob(data30) || utils$2.isReadableStream(data30)) {
      return data30;
    }
    if (utils$2.isArrayBufferView(data30)) {
      return data30.buffer;
    }
    if (utils$2.isURLSearchParams(data30)) {
      headers.setContentType("application/x-www-form-urlencoded;charset=utf-8", false);
      return data30.toString();
    }
    let isFileList2;
    if (isObjectPayload) {
      if (contentType.indexOf("application/x-www-form-urlencoded") > -1) {
        return toURLEncodedForm(data30, this.formSerializer).toString();
      }
      if ((isFileList2 = utils$2.isFileList(data30)) || contentType.indexOf("multipart/form-data") > -1) {
        const _FormData = this.env && this.env.FormData;
        return toFormData$1(
          isFileList2 ? { "files[]": data30 } : data30,
          _FormData && new _FormData(),
          this.formSerializer
        );
      }
    }
    if (isObjectPayload || hasJSONContentType) {
      headers.setContentType("application/json", false);
      return stringifySafely(data30);
    }
    return data30;
  }, "transformRequest")],
  transformResponse: [/* @__PURE__ */ __name(function transformResponse(data30) {
    const transitional2 = this.transitional || defaults$2.transitional;
    const forcedJSONParsing = transitional2 && transitional2.forcedJSONParsing;
    const JSONRequested = this.responseType === "json";
    if (utils$2.isResponse(data30) || utils$2.isReadableStream(data30)) {
      return data30;
    }
    if (data30 && utils$2.isString(data30) && (forcedJSONParsing && !this.responseType || JSONRequested)) {
      const silentJSONParsing = transitional2 && transitional2.silentJSONParsing;
      const strictJSONParsing = !silentJSONParsing && JSONRequested;
      try {
        return JSON.parse(data30);
      } catch (e2) {
        if (strictJSONParsing) {
          if (e2.name === "SyntaxError") {
            throw AxiosError$1.from(e2, AxiosError$1.ERR_BAD_RESPONSE, this, null, this.response);
          }
          throw e2;
        }
      }
    }
    return data30;
  }, "transformResponse")],
  /**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
  timeout: 0,
  xsrfCookieName: "XSRF-TOKEN",
  xsrfHeaderName: "X-XSRF-TOKEN",
  maxContentLength: -1,
  maxBodyLength: -1,
  env: {
    FormData: platform.classes.FormData,
    Blob: platform.classes.Blob
  },
  validateStatus: /* @__PURE__ */ __name(function validateStatus(status) {
    return status >= 200 && status < 300;
  }, "validateStatus"),
  headers: {
    common: {
      "Accept": "application/json, text/plain, */*",
      "Content-Type": void 0
    }
  }
};
utils$2.forEach(["delete", "get", "head", "post", "put", "patch"], (method) => {
  defaults$2.headers[method] = {};
});
"use strict";
const ignoreDuplicateOf = utils$2.toObjectSet([
  "age",
  "authorization",
  "content-length",
  "content-type",
  "etag",
  "expires",
  "from",
  "host",
  "if-modified-since",
  "if-unmodified-since",
  "last-modified",
  "location",
  "max-forwards",
  "proxy-authorization",
  "referer",
  "retry-after",
  "user-agent"
]);
const parseHeaders = /* @__PURE__ */ __name((rawHeaders) => {
  const parsed = {};
  let key;
  let val;
  let i2;
  rawHeaders && rawHeaders.split("\n").forEach(/* @__PURE__ */ __name(function parser(line) {
    i2 = line.indexOf(":");
    key = line.substring(0, i2).trim().toLowerCase();
    val = line.substring(i2 + 1).trim();
    if (!key || parsed[key] && ignoreDuplicateOf[key]) {
      return;
    }
    if (key === "set-cookie") {
      if (parsed[key]) {
        parsed[key].push(val);
      } else {
        parsed[key] = [val];
      }
    } else {
      parsed[key] = parsed[key] ? parsed[key] + ", " + val : val;
    }
  }, "parser"));
  return parsed;
}, "parseHeaders");
"use strict";
const $internals = Symbol("internals");
function normalizeHeader(header3) {
  return header3 && String(header3).trim().toLowerCase();
}
__name(normalizeHeader, "normalizeHeader");
function normalizeValue(value3) {
  if (value3 === false || value3 == null) {
    return value3;
  }
  return utils$2.isArray(value3) ? value3.map(normalizeValue) : String(value3);
}
__name(normalizeValue, "normalizeValue");
function parseTokens(str) {
  const tokens = /* @__PURE__ */ Object.create(null);
  const tokensRE = /([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;
  let match2;
  while (match2 = tokensRE.exec(str)) {
    tokens[match2[1]] = match2[2];
  }
  return tokens;
}
__name(parseTokens, "parseTokens");
const isValidHeaderName = /* @__PURE__ */ __name((str) => /^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(str.trim()), "isValidHeaderName");
function matchHeaderValue(context, value3, header3, filter4, isHeaderNameFilter) {
  if (utils$2.isFunction(filter4)) {
    return filter4.call(this, value3, header3);
  }
  if (isHeaderNameFilter) {
    value3 = header3;
  }
  if (!utils$2.isString(value3)) return;
  if (utils$2.isString(filter4)) {
    return value3.indexOf(filter4) !== -1;
  }
  if (utils$2.isRegExp(filter4)) {
    return filter4.test(value3);
  }
}
__name(matchHeaderValue, "matchHeaderValue");
function formatHeader(header3) {
  return header3.trim().toLowerCase().replace(/([a-z\d])(\w*)/g, (w2, char, str) => {
    return char.toUpperCase() + str;
  });
}
__name(formatHeader, "formatHeader");
function buildAccessors(obj, header3) {
  const accessorName = utils$2.toCamelCase(" " + header3);
  ["get", "set", "has"].forEach((methodName) => {
    Object.defineProperty(obj, methodName + accessorName, {
      value: /* @__PURE__ */ __name(function(arg1, arg2, arg3) {
        return this[methodName].call(this, header3, arg1, arg2, arg3);
      }, "value"),
      configurable: true
    });
  });
}
__name(buildAccessors, "buildAccessors");
let AxiosHeaders$1 = class AxiosHeaders2 {
  static {
    __name(this, "AxiosHeaders");
  }
  constructor(headers) {
    headers && this.set(headers);
  }
  set(header3, valueOrRewrite, rewrite) {
    const self2 = this;
    function setHeader(_value, _header, _rewrite) {
      const lHeader = normalizeHeader(_header);
      if (!lHeader) {
        throw new Error("header name must be a non-empty string");
      }
      const key = utils$2.findKey(self2, lHeader);
      if (!key || self2[key] === void 0 || _rewrite === true || _rewrite === void 0 && self2[key] !== false) {
        self2[key || _header] = normalizeValue(_value);
      }
    }
    __name(setHeader, "setHeader");
    const setHeaders = /* @__PURE__ */ __name((headers, _rewrite) => utils$2.forEach(headers, (_value, _header) => setHeader(_value, _header, _rewrite)), "setHeaders");
    if (utils$2.isPlainObject(header3) || header3 instanceof this.constructor) {
      setHeaders(header3, valueOrRewrite);
    } else if (utils$2.isString(header3) && (header3 = header3.trim()) && !isValidHeaderName(header3)) {
      setHeaders(parseHeaders(header3), valueOrRewrite);
    } else if (utils$2.isHeaders(header3)) {
      for (const [key, value3] of header3.entries()) {
        setHeader(value3, key, rewrite);
      }
    } else {
      header3 != null && setHeader(valueOrRewrite, header3, rewrite);
    }
    return this;
  }
  get(header3, parser) {
    header3 = normalizeHeader(header3);
    if (header3) {
      const key = utils$2.findKey(this, header3);
      if (key) {
        const value3 = this[key];
        if (!parser) {
          return value3;
        }
        if (parser === true) {
          return parseTokens(value3);
        }
        if (utils$2.isFunction(parser)) {
          return parser.call(this, value3, key);
        }
        if (utils$2.isRegExp(parser)) {
          return parser.exec(value3);
        }
        throw new TypeError("parser must be boolean|regexp|function");
      }
    }
  }
  has(header3, matcher) {
    header3 = normalizeHeader(header3);
    if (header3) {
      const key = utils$2.findKey(this, header3);
      return !!(key && this[key] !== void 0 && (!matcher || matchHeaderValue(this, this[key], key, matcher)));
    }
    return false;
  }
  delete(header3, matcher) {
    const self2 = this;
    let deleted = false;
    function deleteHeader(_header) {
      _header = normalizeHeader(_header);
      if (_header) {
        const key = utils$2.findKey(self2, _header);
        if (key && (!matcher || matchHeaderValue(self2, self2[key], key, matcher))) {
          delete self2[key];
          deleted = true;
        }
      }
    }
    __name(deleteHeader, "deleteHeader");
    if (utils$2.isArray(header3)) {
      header3.forEach(deleteHeader);
    } else {
      deleteHeader(header3);
    }
    return deleted;
  }
  clear(matcher) {
    const keys2 = Object.keys(this);
    let i2 = keys2.length;
    let deleted = false;
    while (i2--) {
      const key = keys2[i2];
      if (!matcher || matchHeaderValue(this, this[key], key, matcher, true)) {
        delete this[key];
        deleted = true;
      }
    }
    return deleted;
  }
  normalize(format2) {
    const self2 = this;
    const headers = {};
    utils$2.forEach(this, (value3, header3) => {
      const key = utils$2.findKey(headers, header3);
      if (key) {
        self2[key] = normalizeValue(value3);
        delete self2[header3];
        return;
      }
      const normalized = format2 ? formatHeader(header3) : String(header3).trim();
      if (normalized !== header3) {
        delete self2[header3];
      }
      self2[normalized] = normalizeValue(value3);
      headers[normalized] = true;
    });
    return this;
  }
  concat(...targets) {
    return this.constructor.concat(this, ...targets);
  }
  toJSON(asStrings) {
    const obj = /* @__PURE__ */ Object.create(null);
    utils$2.forEach(this, (value3, header3) => {
      value3 != null && value3 !== false && (obj[header3] = asStrings && utils$2.isArray(value3) ? value3.join(", ") : value3);
    });
    return obj;
  }
  [Symbol.iterator]() {
    return Object.entries(this.toJSON())[Symbol.iterator]();
  }
  toString() {
    return Object.entries(this.toJSON()).map(([header3, value3]) => header3 + ": " + value3).join("\n");
  }
  get [Symbol.toStringTag]() {
    return "AxiosHeaders";
  }
  static from(thing) {
    return thing instanceof this ? thing : new this(thing);
  }
  static concat(first2, ...targets) {
    const computed2 = new this(first2);
    targets.forEach((target2) => computed2.set(target2));
    return computed2;
  }
  static accessor(header3) {
    const internals = this[$internals] = this[$internals] = {
      accessors: {}
    };
    const accessors = internals.accessors;
    const prototype2 = this.prototype;
    function defineAccessor(_header) {
      const lHeader = normalizeHeader(_header);
      if (!accessors[lHeader]) {
        buildAccessors(prototype2, _header);
        accessors[lHeader] = true;
      }
    }
    __name(defineAccessor, "defineAccessor");
    utils$2.isArray(header3) ? header3.forEach(defineAccessor) : defineAccessor(header3);
    return this;
  }
};
AxiosHeaders$1.accessor(["Content-Type", "Content-Length", "Accept", "Accept-Encoding", "User-Agent", "Authorization"]);
utils$2.reduceDescriptors(AxiosHeaders$1.prototype, ({ value: value3 }, key) => {
  let mapped = key[0].toUpperCase() + key.slice(1);
  return {
    get: /* @__PURE__ */ __name(() => value3, "get"),
    set(headerValue) {
      this[mapped] = headerValue;
    }
  };
});
utils$2.freezeMethods(AxiosHeaders$1);
"use strict";
function transformData(fns, response) {
  const config2 = this || defaults$2;
  const context = response || config2;
  const headers = AxiosHeaders$1.from(context.headers);
  let data30 = context.data;
  utils$2.forEach(fns, /* @__PURE__ */ __name(function transform2(fn) {
    data30 = fn.call(config2, data30, headers.normalize(), response ? response.status : void 0);
  }, "transform"));
  headers.normalize();
  return data30;
}
__name(transformData, "transformData");
"use strict";
function isCancel$1(value3) {
  return !!(value3 && value3.__CANCEL__);
}
__name(isCancel$1, "isCancel$1");
"use strict";
function CanceledError$1(message3, config2, request) {
  AxiosError$1.call(this, message3 == null ? "canceled" : message3, AxiosError$1.ERR_CANCELED, config2, request);
  this.name = "CanceledError";
}
__name(CanceledError$1, "CanceledError$1");
utils$2.inherits(CanceledError$1, AxiosError$1, {
  __CANCEL__: true
});
"use strict";
function settle(resolve2, reject3, response) {
  const validateStatus2 = response.config.validateStatus;
  if (!response.status || !validateStatus2 || validateStatus2(response.status)) {
    resolve2(response);
  } else {
    reject3(new AxiosError$1(
      "Request failed with status code " + response.status,
      [AxiosError$1.ERR_BAD_REQUEST, AxiosError$1.ERR_BAD_RESPONSE][Math.floor(response.status / 100) - 4],
      response.config,
      response.request,
      response
    ));
  }
}
__name(settle, "settle");
"use strict";
function parseProtocol(url) {
  const match2 = /^([-+\w]{1,25})(:?\/\/|:)/.exec(url);
  return match2 && match2[1] || "";
}
__name(parseProtocol, "parseProtocol");
"use strict";
function speedometer(samplesCount, min) {
  samplesCount = samplesCount || 10;
  const bytes = new Array(samplesCount);
  const timestamps = new Array(samplesCount);
  let head = 0;
  let tail = 0;
  let firstSampleTS;
  min = min !== void 0 ? min : 1e3;
  return /* @__PURE__ */ __name(function push2(chunkLength) {
    const now2 = Date.now();
    const startedAt = timestamps[tail];
    if (!firstSampleTS) {
      firstSampleTS = now2;
    }
    bytes[head] = chunkLength;
    timestamps[head] = now2;
    let i2 = tail;
    let bytesCount = 0;
    while (i2 !== head) {
      bytesCount += bytes[i2++];
      i2 = i2 % samplesCount;
    }
    head = (head + 1) % samplesCount;
    if (head === tail) {
      tail = (tail + 1) % samplesCount;
    }
    if (now2 - firstSampleTS < min) {
      return;
    }
    const passed = startedAt && now2 - startedAt;
    return passed ? Math.round(bytesCount * 1e3 / passed) : void 0;
  }, "push");
}
__name(speedometer, "speedometer");
function throttle(fn, freq) {
  let timestamp2 = 0;
  let threshold = 1e3 / freq;
  let lastArgs;
  let timer;
  const invoke2 = /* @__PURE__ */ __name((args, now2 = Date.now()) => {
    timestamp2 = now2;
    lastArgs = null;
    if (timer) {
      clearTimeout(timer);
      timer = null;
    }
    fn.apply(null, args);
  }, "invoke");
  const throttled = /* @__PURE__ */ __name((...args) => {
    const now2 = Date.now();
    const passed = now2 - timestamp2;
    if (passed >= threshold) {
      invoke2(args, now2);
    } else {
      lastArgs = args;
      if (!timer) {
        timer = setTimeout(() => {
          timer = null;
          invoke2(lastArgs);
        }, threshold - passed);
      }
    }
  }, "throttled");
  const flush2 = /* @__PURE__ */ __name(() => lastArgs && invoke2(lastArgs), "flush");
  return [throttled, flush2];
}
__name(throttle, "throttle");
const progressEventReducer = /* @__PURE__ */ __name((listener, isDownloadStream, freq = 3) => {
  let bytesNotified = 0;
  const _speedometer = speedometer(50, 250);
  return throttle((e2) => {
    const loaded = e2.loaded;
    const total = e2.lengthComputable ? e2.total : void 0;
    const progressBytes = loaded - bytesNotified;
    const rate = _speedometer(progressBytes);
    const inRange = loaded <= total;
    bytesNotified = loaded;
    const data30 = {
      loaded,
      total,
      progress: total ? loaded / total : void 0,
      bytes: progressBytes,
      rate: rate ? rate : void 0,
      estimated: rate && total && inRange ? (total - loaded) / rate : void 0,
      event: e2,
      lengthComputable: total != null,
      [isDownloadStream ? "download" : "upload"]: true
    };
    listener(data30);
  }, freq);
}, "progressEventReducer");
const progressEventDecorator = /* @__PURE__ */ __name((total, throttled) => {
  const lengthComputable = total != null;
  return [(loaded) => throttled[0]({
    lengthComputable,
    total,
    loaded
  }), throttled[1]];
}, "progressEventDecorator");
const asyncDecorator = /* @__PURE__ */ __name((fn) => (...args) => utils$2.asap(() => fn(...args)), "asyncDecorator");
const isURLSameOrigin = platform.hasStandardBrowserEnv ? /* @__PURE__ */ ((origin2, isMSIE) => (url) => {
  url = new URL(url, platform.origin);
  return origin2.protocol === url.protocol && origin2.host === url.host && (isMSIE || origin2.port === url.port);
})(
  new URL(platform.origin),
  platform.navigator && /(msie|trident)/i.test(platform.navigator.userAgent)
) : () => true;
const cookies = platform.hasStandardBrowserEnv ? (
  // Standard browser envs support document.cookie
  {
    write(name2, value3, expires, path, domain2, secure) {
      const cookie = [name2 + "=" + encodeURIComponent(value3)];
      utils$2.isNumber(expires) && cookie.push("expires=" + new Date(expires).toGMTString());
      utils$2.isString(path) && cookie.push("path=" + path);
      utils$2.isString(domain2) && cookie.push("domain=" + domain2);
      secure === true && cookie.push("secure");
      document.cookie = cookie.join("; ");
    },
    read(name2) {
      const match2 = document.cookie.match(new RegExp("(^|;\\s*)(" + name2 + ")=([^;]*)"));
      return match2 ? decodeURIComponent(match2[3]) : null;
    },
    remove(name2) {
      this.write(name2, "", Date.now() - 864e5);
    }
  }
) : (
  // Non-standard browser env (web workers, react-native) lack needed support.
  {
    write() {
    },
    read() {
      return null;
    },
    remove() {
    }
  }
);
"use strict";
function isAbsoluteURL$1(url) {
  return /^([a-z][a-z\d+\-.]*:)?\/\//i.test(url);
}
__name(isAbsoluteURL$1, "isAbsoluteURL$1");
"use strict";
function combineURLs(baseURL, relativeURL) {
  return relativeURL ? baseURL.replace(/\/?\/$/, "") + "/" + relativeURL.replace(/^\/+/, "") : baseURL;
}
__name(combineURLs, "combineURLs");
"use strict";
function buildFullPath(baseURL, requestedURL, allowAbsoluteUrls) {
  let isRelativeUrl = !isAbsoluteURL$1(requestedURL);
  if (baseURL && isRelativeUrl || allowAbsoluteUrls == false) {
    return combineURLs(baseURL, requestedURL);
  }
  return requestedURL;
}
__name(buildFullPath, "buildFullPath");
"use strict";
const headersToObject$1 = /* @__PURE__ */ __name((thing) => thing instanceof AxiosHeaders$1 ? { ...thing } : thing, "headersToObject$1");
function mergeConfig$1(config1, config2) {
  config2 = config2 || {};
  const config3 = {};
  function getMergedValue(target2, source, prop2, caseless) {
    if (utils$2.isPlainObject(target2) && utils$2.isPlainObject(source)) {
      return utils$2.merge.call({ caseless }, target2, source);
    } else if (utils$2.isPlainObject(source)) {
      return utils$2.merge({}, source);
    } else if (utils$2.isArray(source)) {
      return source.slice();
    }
    return source;
  }
  __name(getMergedValue, "getMergedValue");
  function mergeDeepProperties(a2, b2, prop2, caseless) {
    if (!utils$2.isUndefined(b2)) {
      return getMergedValue(a2, b2, prop2, caseless);
    } else if (!utils$2.isUndefined(a2)) {
      return getMergedValue(void 0, a2, prop2, caseless);
    }
  }
  __name(mergeDeepProperties, "mergeDeepProperties");
  function valueFromConfig2(a2, b2) {
    if (!utils$2.isUndefined(b2)) {
      return getMergedValue(void 0, b2);
    }
  }
  __name(valueFromConfig2, "valueFromConfig2");
  function defaultToConfig2(a2, b2) {
    if (!utils$2.isUndefined(b2)) {
      return getMergedValue(void 0, b2);
    } else if (!utils$2.isUndefined(a2)) {
      return getMergedValue(void 0, a2);
    }
  }
  __name(defaultToConfig2, "defaultToConfig2");
  function mergeDirectKeys(a2, b2, prop2) {
    if (prop2 in config2) {
      return getMergedValue(a2, b2);
    } else if (prop2 in config1) {
      return getMergedValue(void 0, a2);
    }
  }
  __name(mergeDirectKeys, "mergeDirectKeys");
  const mergeMap = {
    url: valueFromConfig2,
    method: valueFromConfig2,
    data: valueFromConfig2,
    baseURL: defaultToConfig2,
    transformRequest: defaultToConfig2,
    transformResponse: defaultToConfig2,
    paramsSerializer: defaultToConfig2,
    timeout: defaultToConfig2,
    timeoutMessage: defaultToConfig2,
    withCredentials: defaultToConfig2,
    withXSRFToken: defaultToConfig2,
    adapter: defaultToConfig2,
    responseType: defaultToConfig2,
    xsrfCookieName: defaultToConfig2,
    xsrfHeaderName: defaultToConfig2,
    onUploadProgress: defaultToConfig2,
    onDownloadProgress: defaultToConfig2,
    decompress: defaultToConfig2,
    maxContentLength: defaultToConfig2,
    maxBodyLength: defaultToConfig2,
    beforeRedirect: defaultToConfig2,
    transport: defaultToConfig2,
    httpAgent: defaultToConfig2,
    httpsAgent: defaultToConfig2,
    cancelToken: defaultToConfig2,
    socketPath: defaultToConfig2,
    responseEncoding: defaultToConfig2,
    validateStatus: mergeDirectKeys,
    headers: /* @__PURE__ */ __name((a2, b2, prop2) => mergeDeepProperties(headersToObject$1(a2), headersToObject$1(b2), prop2, true), "headers")
  };
  utils$2.forEach(Object.keys(Object.assign({}, config1, config2)), /* @__PURE__ */ __name(function computeConfigValue(prop2) {
    const merge2 = mergeMap[prop2] || mergeDeepProperties;
    const configValue = merge2(config1[prop2], config2[prop2], prop2);
    utils$2.isUndefined(configValue) && merge2 !== mergeDirectKeys || (config3[prop2] = configValue);
  }, "computeConfigValue"));
  return config3;
}
__name(mergeConfig$1, "mergeConfig$1");
const resolveConfig = /* @__PURE__ */ __name((config2) => {
  const newConfig = mergeConfig$1({}, config2);
  let { data: data30, withXSRFToken, xsrfHeaderName, xsrfCookieName, headers, auth } = newConfig;
  newConfig.headers = headers = AxiosHeaders$1.from(headers);
  newConfig.url = buildURL(buildFullPath(newConfig.baseURL, newConfig.url), config2.params, config2.paramsSerializer);
  if (auth) {
    headers.set(
      "Authorization",
      "Basic " + btoa((auth.username || "") + ":" + (auth.password ? unescape(encodeURIComponent(auth.password)) : ""))
    );
  }
  let contentType;
  if (utils$2.isFormData(data30)) {
    if (platform.hasStandardBrowserEnv || platform.hasStandardBrowserWebWorkerEnv) {
      headers.setContentType(void 0);
    } else if ((contentType = headers.getContentType()) !== false) {
      const [type, ...tokens] = contentType ? contentType.split(";").map((token) => token.trim()).filter(Boolean) : [];
      headers.setContentType([type || "multipart/form-data", ...tokens].join("; "));
    }
  }
  if (platform.hasStandardBrowserEnv) {
    withXSRFToken && utils$2.isFunction(withXSRFToken) && (withXSRFToken = withXSRFToken(newConfig));
    if (withXSRFToken || withXSRFToken !== false && isURLSameOrigin(newConfig.url)) {
      const xsrfValue = xsrfHeaderName && xsrfCookieName && cookies.read(xsrfCookieName);
      if (xsrfValue) {
        headers.set(xsrfHeaderName, xsrfValue);
      }
    }
  }
  return newConfig;
}, "resolveConfig");
const isXHRAdapterSupported = typeof XMLHttpRequest !== "undefined";
const xhrAdapter = isXHRAdapterSupported && function(config2) {
  return new Promise(/* @__PURE__ */ __name(function dispatchXhrRequest(resolve2, reject3) {
    const _config = resolveConfig(config2);
    let requestData = _config.data;
    const requestHeaders = AxiosHeaders$1.from(_config.headers).normalize();
    let { responseType, onUploadProgress, onDownloadProgress } = _config;
    let onCanceled;
    let uploadThrottled, downloadThrottled;
    let flushUpload, flushDownload;
    function done() {
      flushUpload && flushUpload();
      flushDownload && flushDownload();
      _config.cancelToken && _config.cancelToken.unsubscribe(onCanceled);
      _config.signal && _config.signal.removeEventListener("abort", onCanceled);
    }
    __name(done, "done");
    let request = new XMLHttpRequest();
    request.open(_config.method.toUpperCase(), _config.url, true);
    request.timeout = _config.timeout;
    function onloadend() {
      if (!request) {
        return;
      }
      const responseHeaders = AxiosHeaders$1.from(
        "getAllResponseHeaders" in request && request.getAllResponseHeaders()
      );
      const responseData = !responseType || responseType === "text" || responseType === "json" ? request.responseText : request.response;
      const response = {
        data: responseData,
        status: request.status,
        statusText: request.statusText,
        headers: responseHeaders,
        config: config2,
        request
      };
      settle(/* @__PURE__ */ __name(function _resolve(value3) {
        resolve2(value3);
        done();
      }, "_resolve"), /* @__PURE__ */ __name(function _reject(err) {
        reject3(err);
        done();
      }, "_reject"), response);
      request = null;
    }
    __name(onloadend, "onloadend");
    if ("onloadend" in request) {
      request.onloadend = onloadend;
    } else {
      request.onreadystatechange = /* @__PURE__ */ __name(function handleLoad() {
        if (!request || request.readyState !== 4) {
          return;
        }
        if (request.status === 0 && !(request.responseURL && request.responseURL.indexOf("file:") === 0)) {
          return;
        }
        setTimeout(onloadend);
      }, "handleLoad");
    }
    request.onabort = /* @__PURE__ */ __name(function handleAbort() {
      if (!request) {
        return;
      }
      reject3(new AxiosError$1("Request aborted", AxiosError$1.ECONNABORTED, config2, request));
      request = null;
    }, "handleAbort");
    request.onerror = /* @__PURE__ */ __name(function handleError2() {
      reject3(new AxiosError$1("Network Error", AxiosError$1.ERR_NETWORK, config2, request));
      request = null;
    }, "handleError");
    request.ontimeout = /* @__PURE__ */ __name(function handleTimeout() {
      let timeoutErrorMessage = _config.timeout ? "timeout of " + _config.timeout + "ms exceeded" : "timeout exceeded";
      const transitional2 = _config.transitional || transitionalDefaults;
      if (_config.timeoutErrorMessage) {
        timeoutErrorMessage = _config.timeoutErrorMessage;
      }
      reject3(new AxiosError$1(
        timeoutErrorMessage,
        transitional2.clarifyTimeoutError ? AxiosError$1.ETIMEDOUT : AxiosError$1.ECONNABORTED,
        config2,
        request
      ));
      request = null;
    }, "handleTimeout");
    requestData === void 0 && requestHeaders.setContentType(null);
    if ("setRequestHeader" in request) {
      utils$2.forEach(requestHeaders.toJSON(), /* @__PURE__ */ __name(function setRequestHeader(val, key) {
        request.setRequestHeader(key, val);
      }, "setRequestHeader"));
    }
    if (!utils$2.isUndefined(_config.withCredentials)) {
      request.withCredentials = !!_config.withCredentials;
    }
    if (responseType && responseType !== "json") {
      request.responseType = _config.responseType;
    }
    if (onDownloadProgress) {
      [downloadThrottled, flushDownload] = progressEventReducer(onDownloadProgress, true);
      request.addEventListener("progress", downloadThrottled);
    }
    if (onUploadProgress && request.upload) {
      [uploadThrottled, flushUpload] = progressEventReducer(onUploadProgress);
      request.upload.addEventListener("progress", uploadThrottled);
      request.upload.addEventListener("loadend", flushUpload);
    }
    if (_config.cancelToken || _config.signal) {
      onCanceled = /* @__PURE__ */ __name((cancel) => {
        if (!request) {
          return;
        }
        reject3(!cancel || cancel.type ? new CanceledError$1(null, config2, request) : cancel);
        request.abort();
        request = null;
      }, "onCanceled");
      _config.cancelToken && _config.cancelToken.subscribe(onCanceled);
      if (_config.signal) {
        _config.signal.aborted ? onCanceled() : _config.signal.addEventListener("abort", onCanceled);
      }
    }
    const protocol = parseProtocol(_config.url);
    if (protocol && platform.protocols.indexOf(protocol) === -1) {
      reject3(new AxiosError$1("Unsupported protocol " + protocol + ":", AxiosError$1.ERR_BAD_REQUEST, config2));
      return;
    }
    request.send(requestData || null);
  }, "dispatchXhrRequest"));
};
const composeSignals = /* @__PURE__ */ __name((signals, timeout) => {
  const { length } = signals = signals ? signals.filter(Boolean) : [];
  if (timeout || length) {
    let controller = new AbortController();
    let aborted;
    const onabort = /* @__PURE__ */ __name(function(reason) {
      if (!aborted) {
        aborted = true;
        unsubscribe();
        const err = reason instanceof Error ? reason : this.reason;
        controller.abort(err instanceof AxiosError$1 ? err : new CanceledError$1(err instanceof Error ? err.message : err));
      }
    }, "onabort");
    let timer = timeout && setTimeout(() => {
      timer = null;
      onabort(new AxiosError$1(`timeout ${timeout} of ms exceeded`, AxiosError$1.ETIMEDOUT));
    }, timeout);
    const unsubscribe = /* @__PURE__ */ __name(() => {
      if (signals) {
        timer && clearTimeout(timer);
        timer = null;
        signals.forEach((signal2) => {
          signal2.unsubscribe ? signal2.unsubscribe(onabort) : signal2.removeEventListener("abort", onabort);
        });
        signals = null;
      }
    }, "unsubscribe");
    signals.forEach((signal2) => signal2.addEventListener("abort", onabort));
    const { signal } = controller;
    signal.unsubscribe = () => utils$2.asap(unsubscribe);
    return signal;
  }
}, "composeSignals");
const streamChunk = /* @__PURE__ */ __name(function* (chunk, chunkSize) {
  let len = chunk.byteLength;
  if (!chunkSize || len < chunkSize) {
    yield chunk;
    return;
  }
  let pos = 0;
  let end;
  while (pos < len) {
    end = pos + chunkSize;
    yield chunk.slice(pos, end);
    pos = end;
  }
}, "streamChunk");
const readBytes = /* @__PURE__ */ __name(async function* (iterable, chunkSize) {
  for await (const chunk of readStream(iterable)) {
    yield* streamChunk(chunk, chunkSize);
  }
}, "readBytes");
const readStream = /* @__PURE__ */ __name(async function* (stream) {
  if (stream[Symbol.asyncIterator]) {
    yield* stream;
    return;
  }
  const reader = stream.getReader();
  try {
    for (; ; ) {
      const { done, value: value3 } = await reader.read();
      if (done) {
        break;
      }
      yield value3;
    }
  } finally {
    await reader.cancel();
  }
}, "readStream");
const trackStream = /* @__PURE__ */ __name((stream, chunkSize, onProgress, onFinish) => {
  const iterator2 = readBytes(stream, chunkSize);
  let bytes = 0;
  let done;
  let _onFinish = /* @__PURE__ */ __name((e2) => {
    if (!done) {
      done = true;
      onFinish && onFinish(e2);
    }
  }, "_onFinish");
  return new ReadableStream({
    async pull(controller) {
      try {
        const { done: done2, value: value3 } = await iterator2.next();
        if (done2) {
          _onFinish();
          controller.close();
          return;
        }
        let len = value3.byteLength;
        if (onProgress) {
          let loadedBytes = bytes += len;
          onProgress(loadedBytes);
        }
        controller.enqueue(new Uint8Array(value3));
      } catch (err) {
        _onFinish(err);
        throw err;
      }
    },
    cancel(reason) {
      _onFinish(reason);
      return iterator2.return();
    }
  }, {
    highWaterMark: 2
  });
}, "trackStream");
const isFetchSupported = typeof fetch === "function" && typeof Request === "function" && typeof Response === "function";
const isReadableStreamSupported = isFetchSupported && typeof ReadableStream === "function";
const encodeText = isFetchSupported && (typeof TextEncoder === "function" ? /* @__PURE__ */ ((encoder) => (str) => encoder.encode(str))(new TextEncoder()) : async (str) => new Uint8Array(await new Response(str).arrayBuffer()));
const test$1 = /* @__PURE__ */ __name((fn, ...args) => {
  try {
    return !!fn(...args);
  } catch (e2) {
    return false;
  }
}, "test$1");
const supportsRequestStream = isReadableStreamSupported && test$1(() => {
  let duplexAccessed = false;
  const hasContentType = new Request(platform.origin, {
    body: new ReadableStream(),
    method: "POST",
    get duplex() {
      duplexAccessed = true;
      return "half";
    }
  }).headers.has("Content-Type");
  return duplexAccessed && !hasContentType;
});
const DEFAULT_CHUNK_SIZE = 64 * 1024;
const supportsResponseStream = isReadableStreamSupported && test$1(() => utils$2.isReadableStream(new Response("").body));
const resolvers = {
  stream: supportsResponseStream && ((res) => res.body)
};
isFetchSupported && ((res) => {
  ["text", "arrayBuffer", "blob", "formData", "stream"].forEach((type) => {
    !resolvers[type] && (resolvers[type] = utils$2.isFunction(res[type]) ? (res2) => res2[type]() : (_2, config2) => {
      throw new AxiosError$1(`Response type '${type}' is not supported`, AxiosError$1.ERR_NOT_SUPPORT, config2);
    });
  });
})(new Response());
const getBodyLength = /* @__PURE__ */ __name(async (body) => {
  if (body == null) {
    return 0;
  }
  if (utils$2.isBlob(body)) {
    return body.size;
  }
  if (utils$2.isSpecCompliantForm(body)) {
    const _request = new Request(platform.origin, {
      method: "POST",
      body
    });
    return (await _request.arrayBuffer()).byteLength;
  }
  if (utils$2.isArrayBufferView(body) || utils$2.isArrayBuffer(body)) {
    return body.byteLength;
  }
  if (utils$2.isURLSearchParams(body)) {
    body = body + "";
  }
  if (utils$2.isString(body)) {
    return (await encodeText(body)).byteLength;
  }
}, "getBodyLength");
const resolveBodyLength = /* @__PURE__ */ __name(async (headers, body) => {
  const length = utils$2.toFiniteNumber(headers.getContentLength());
  return length == null ? getBodyLength(body) : length;
}, "resolveBodyLength");
const fetchAdapter = isFetchSupported && (async (config2) => {
  let {
    url,
    method,
    data: data30,
    signal,
    cancelToken,
    timeout,
    onDownloadProgress,
    onUploadProgress,
    responseType,
    headers,
    withCredentials = "same-origin",
    fetchOptions
  } = resolveConfig(config2);
  responseType = responseType ? (responseType + "").toLowerCase() : "text";
  let composedSignal = composeSignals([signal, cancelToken && cancelToken.toAbortSignal()], timeout);
  let request;
  const unsubscribe = composedSignal && composedSignal.unsubscribe && (() => {
    composedSignal.unsubscribe();
  });
  let requestContentLength;
  try {
    if (onUploadProgress && supportsRequestStream && method !== "get" && method !== "head" && (requestContentLength = await resolveBodyLength(headers, data30)) !== 0) {
      let _request = new Request(url, {
        method: "POST",
        body: data30,
        duplex: "half"
      });
      let contentTypeHeader;
      if (utils$2.isFormData(data30) && (contentTypeHeader = _request.headers.get("content-type"))) {
        headers.setContentType(contentTypeHeader);
      }
      if (_request.body) {
        const [onProgress, flush2] = progressEventDecorator(
          requestContentLength,
          progressEventReducer(asyncDecorator(onUploadProgress))
        );
        data30 = trackStream(_request.body, DEFAULT_CHUNK_SIZE, onProgress, flush2);
      }
    }
    if (!utils$2.isString(withCredentials)) {
      withCredentials = withCredentials ? "include" : "omit";
    }
    const isCredentialsSupported = "credentials" in Request.prototype;
    request = new Request(url, {
      ...fetchOptions,
      signal: composedSignal,
      method: method.toUpperCase(),
      headers: headers.normalize().toJSON(),
      body: data30,
      duplex: "half",
      credentials: isCredentialsSupported ? withCredentials : void 0
    });
    let response = await fetch(request);
    const isStreamResponse = supportsResponseStream && (responseType === "stream" || responseType === "response");
    if (supportsResponseStream && (onDownloadProgress || isStreamResponse && unsubscribe)) {
      const options5 = {};
      ["status", "statusText", "headers"].forEach((prop2) => {
        options5[prop2] = response[prop2];
      });
      const responseContentLength = utils$2.toFiniteNumber(response.headers.get("content-length"));
      const [onProgress, flush2] = onDownloadProgress && progressEventDecorator(
        responseContentLength,
        progressEventReducer(asyncDecorator(onDownloadProgress), true)
      ) || [];
      response = new Response(
        trackStream(response.body, DEFAULT_CHUNK_SIZE, onProgress, () => {
          flush2 && flush2();
          unsubscribe && unsubscribe();
        }),
        options5
      );
    }
    responseType = responseType || "text";
    let responseData = await resolvers[utils$2.findKey(resolvers, responseType) || "text"](response, config2);
    !isStreamResponse && unsubscribe && unsubscribe();
    return await new Promise((resolve2, reject3) => {
      settle(resolve2, reject3, {
        data: responseData,
        headers: AxiosHeaders$1.from(response.headers),
        status: response.status,
        statusText: response.statusText,
        config: config2,
        request
      });
    });
  } catch (err) {
    unsubscribe && unsubscribe();
    if (err && err.name === "TypeError" && /fetch/i.test(err.message)) {
      throw Object.assign(
        new AxiosError$1("Network Error", AxiosError$1.ERR_NETWORK, config2, request),
        {
          cause: err.cause || err
        }
      );
    }
    throw AxiosError$1.from(err, err && err.code, config2, request);
  }
});
const knownAdapters = {
  http: httpAdapter,
  xhr: xhrAdapter,
  fetch: fetchAdapter
};
utils$2.forEach(knownAdapters, (fn, value3) => {
  if (fn) {
    try {
      Object.defineProperty(fn, "name", { value: value3 });
    } catch (e2) {
    }
    Object.defineProperty(fn, "adapterName", { value: value3 });
  }
});
const renderReason = /* @__PURE__ */ __name((reason) => `- ${reason}`, "renderReason");
const isResolvedHandle = /* @__PURE__ */ __name((adapter2) => utils$2.isFunction(adapter2) || adapter2 === null || adapter2 === false, "isResolvedHandle");
const adapters = {
  getAdapter: /* @__PURE__ */ __name((adapters2) => {
    adapters2 = utils$2.isArray(adapters2) ? adapters2 : [adapters2];
    const { length } = adapters2;
    let nameOrAdapter;
    let adapter2;
    const rejectedReasons = {};
    for (let i2 = 0; i2 < length; i2++) {
      nameOrAdapter = adapters2[i2];
      let id4;
      adapter2 = nameOrAdapter;
      if (!isResolvedHandle(nameOrAdapter)) {
        adapter2 = knownAdapters[(id4 = String(nameOrAdapter)).toLowerCase()];
        if (adapter2 === void 0) {
          throw new AxiosError$1(`Unknown adapter '${id4}'`);
        }
      }
      if (adapter2) {
        break;
      }
      rejectedReasons[id4 || "#" + i2] = adapter2;
    }
    if (!adapter2) {
      const reasons = Object.entries(rejectedReasons).map(
        ([id4, state]) => `adapter ${id4} ` + (state === false ? "is not supported by the environment" : "is not available in the build")
      );
      let s2 = length ? reasons.length > 1 ? "since :\n" + reasons.map(renderReason).join("\n") : " " + renderReason(reasons[0]) : "as no adapter specified";
      throw new AxiosError$1(
        `There is no suitable adapter to dispatch the request ` + s2,
        "ERR_NOT_SUPPORT"
      );
    }
    return adapter2;
  }, "getAdapter"),
  adapters: knownAdapters
};
"use strict";
function throwIfCancellationRequested(config2) {
  if (config2.cancelToken) {
    config2.cancelToken.throwIfRequested();
  }
  if (config2.signal && config2.signal.aborted) {
    throw new CanceledError$1(null, config2);
  }
}
__name(throwIfCancellationRequested, "throwIfCancellationRequested");
function dispatchRequest(config2) {
  throwIfCancellationRequested(config2);
  config2.headers = AxiosHeaders$1.from(config2.headers);
  config2.data = transformData.call(
    config2,
    config2.transformRequest
  );
  if (["post", "put", "patch"].indexOf(config2.method) !== -1) {
    config2.headers.setContentType("application/x-www-form-urlencoded", false);
  }
  const adapter2 = adapters.getAdapter(config2.adapter || defaults$2.adapter);
  return adapter2(config2).then(/* @__PURE__ */ __name(function onAdapterResolution(response) {
    throwIfCancellationRequested(config2);
    response.data = transformData.call(
      config2,
      config2.transformResponse,
      response
    );
    response.headers = AxiosHeaders$1.from(response.headers);
    return response;
  }, "onAdapterResolution"), /* @__PURE__ */ __name(function onAdapterRejection(reason) {
    if (!isCancel$1(reason)) {
      throwIfCancellationRequested(config2);
      if (reason && reason.response) {
        reason.response.data = transformData.call(
          config2,
          config2.transformResponse,
          reason.response
        );
        reason.response.headers = AxiosHeaders$1.from(reason.response.headers);
      }
    }
    return Promise.reject(reason);
  }, "onAdapterRejection"));
}
__name(dispatchRequest, "dispatchRequest");
const VERSION$3 = "1.8.2";
"use strict";
const validators$1 = {};
["object", "boolean", "number", "function", "string", "symbol"].forEach((type, i2) => {
  validators$1[type] = /* @__PURE__ */ __name(function validator3(thing) {
    return typeof thing === type || "a" + (i2 < 1 ? "n " : " ") + type;
  }, "validator");
});
const deprecatedWarnings = {};
validators$1.transitional = /* @__PURE__ */ __name(function transitional(validator3, version2, message3) {
  function formatMessage(opt, desc) {
    return "[Axios v" + VERSION$3 + "] Transitional option '" + opt + "'" + desc + (message3 ? ". " + message3 : "");
  }
  __name(formatMessage, "formatMessage");
  return (value3, opt, opts) => {
    if (validator3 === false) {
      throw new AxiosError$1(
        formatMessage(opt, " has been removed" + (version2 ? " in " + version2 : "")),
        AxiosError$1.ERR_DEPRECATED
      );
    }
    if (version2 && !deprecatedWarnings[opt]) {
      deprecatedWarnings[opt] = true;
      console.warn(
        formatMessage(
          opt,
          " has been deprecated since v" + version2 + " and will be removed in the near future"
        )
      );
    }
    return validator3 ? validator3(value3, opt, opts) : true;
  };
}, "transitional");
validators$1.spelling = /* @__PURE__ */ __name(function spelling(correctSpelling) {
  return (value3, opt) => {
    console.warn(`${opt} is likely a misspelling of ${correctSpelling}`);
    return true;
  };
}, "spelling");
function assertOptions(options5, schema2, allowUnknown) {
  if (typeof options5 !== "object") {
    throw new AxiosError$1("options must be an object", AxiosError$1.ERR_BAD_OPTION_VALUE);
  }
  const keys2 = Object.keys(options5);
  let i2 = keys2.length;
  while (i2-- > 0) {
    const opt = keys2[i2];
    const validator3 = schema2[opt];
    if (validator3) {
      const value3 = options5[opt];
      const result = value3 === void 0 || validator3(value3, opt, options5);
      if (result !== true) {
        throw new AxiosError$1("option " + opt + " must be " + result, AxiosError$1.ERR_BAD_OPTION_VALUE);
      }
      continue;
    }
    if (allowUnknown !== true) {
      throw new AxiosError$1("Unknown option " + opt, AxiosError$1.ERR_BAD_OPTION);
    }
  }
}
__name(assertOptions, "assertOptions");
const validator = {
  assertOptions,
  validators: validators$1
};
"use strict";
const validators = validator.validators;
let Axios$1 = class Axios2 {
  static {
    __name(this, "Axios");
  }
  constructor(instanceConfig) {
    this.defaults = instanceConfig;
    this.interceptors = {
      request: new InterceptorManager(),
      response: new InterceptorManager()
    };
  }
  /**
   * Dispatch a request
   *
   * @param {String|Object} configOrUrl The config specific for this request (merged with this.defaults)
   * @param {?Object} config
   *
   * @returns {Promise} The Promise to be fulfilled
   */
  async request(configOrUrl, config2) {
    try {
      return await this._request(configOrUrl, config2);
    } catch (err) {
      if (err instanceof Error) {
        let dummy = {};
        Error.captureStackTrace ? Error.captureStackTrace(dummy) : dummy = new Error();
        const stack2 = dummy.stack ? dummy.stack.replace(/^.+\n/, "") : "";
        try {
          if (!err.stack) {
            err.stack = stack2;
          } else if (stack2 && !String(err.stack).endsWith(stack2.replace(/^.+\n.+\n/, ""))) {
            err.stack += "\n" + stack2;
          }
        } catch (e2) {
        }
      }
      throw err;
    }
  }
  _request(configOrUrl, config2) {
    if (typeof configOrUrl === "string") {
      config2 = config2 || {};
      config2.url = configOrUrl;
    } else {
      config2 = configOrUrl || {};
    }
    config2 = mergeConfig$1(this.defaults, config2);
    const { transitional: transitional2, paramsSerializer, headers } = config2;
    if (transitional2 !== void 0) {
      validator.assertOptions(transitional2, {
        silentJSONParsing: validators.transitional(validators.boolean),
        forcedJSONParsing: validators.transitional(validators.boolean),
        clarifyTimeoutError: validators.transitional(validators.boolean)
      }, false);
    }
    if (paramsSerializer != null) {
      if (utils$2.isFunction(paramsSerializer)) {
        config2.paramsSerializer = {
          serialize: paramsSerializer
        };
      } else {
        validator.assertOptions(paramsSerializer, {
          encode: validators.function,
          serialize: validators.function
        }, true);
      }
    }
    if (config2.allowAbsoluteUrls !== void 0) {
    } else if (this.defaults.allowAbsoluteUrls !== void 0) {
      config2.allowAbsoluteUrls = this.defaults.allowAbsoluteUrls;
    } else {
      config2.allowAbsoluteUrls = true;
    }
    validator.assertOptions(config2, {
      baseUrl: validators.spelling("baseURL"),
      withXsrfToken: validators.spelling("withXSRFToken")
    }, true);
    config2.method = (config2.method || this.defaults.method || "get").toLowerCase();
    let contextHeaders = headers && utils$2.merge(
      headers.common,
      headers[config2.method]
    );
    headers && utils$2.forEach(
      ["delete", "get", "head", "post", "put", "patch", "common"],
      (method) => {
        delete headers[method];
      }
    );
    config2.headers = AxiosHeaders$1.concat(contextHeaders, headers);
    const requestInterceptorChain = [];
    let synchronousRequestInterceptors = true;
    this.interceptors.request.forEach(/* @__PURE__ */ __name(function unshiftRequestInterceptors(interceptor) {
      if (typeof interceptor.runWhen === "function" && interceptor.runWhen(config2) === false) {
        return;
      }
      synchronousRequestInterceptors = synchronousRequestInterceptors && interceptor.synchronous;
      requestInterceptorChain.unshift(interceptor.fulfilled, interceptor.rejected);
    }, "unshiftRequestInterceptors"));
    const responseInterceptorChain = [];
    this.interceptors.response.forEach(/* @__PURE__ */ __name(function pushResponseInterceptors(interceptor) {
      responseInterceptorChain.push(interceptor.fulfilled, interceptor.rejected);
    }, "pushResponseInterceptors"));
    let promise;
    let i2 = 0;
    let len;
    if (!synchronousRequestInterceptors) {
      const chain = [dispatchRequest.bind(this), void 0];
      chain.unshift.apply(chain, requestInterceptorChain);
      chain.push.apply(chain, responseInterceptorChain);
      len = chain.length;
      promise = Promise.resolve(config2);
      while (i2 < len) {
        promise = promise.then(chain[i2++], chain[i2++]);
      }
      return promise;
    }
    len = requestInterceptorChain.length;
    let newConfig = config2;
    i2 = 0;
    while (i2 < len) {
      const onFulfilled = requestInterceptorChain[i2++];
      const onRejected = requestInterceptorChain[i2++];
      try {
        newConfig = onFulfilled(newConfig);
      } catch (error2) {
        onRejected.call(this, error2);
        break;
      }
    }
    try {
      promise = dispatchRequest.call(this, newConfig);
    } catch (error2) {
      return Promise.reject(error2);
    }
    i2 = 0;
    len = responseInterceptorChain.length;
    while (i2 < len) {
      promise = promise.then(responseInterceptorChain[i2++], responseInterceptorChain[i2++]);
    }
    return promise;
  }
  getUri(config2) {
    config2 = mergeConfig$1(this.defaults, config2);
    const fullPath = buildFullPath(config2.baseURL, config2.url, config2.allowAbsoluteUrls);
    return buildURL(fullPath, config2.params, config2.paramsSerializer);
  }
};
utils$2.forEach(["delete", "get", "head", "options"], /* @__PURE__ */ __name(function forEachMethodNoData(method) {
  Axios$1.prototype[method] = function(url, config2) {
    return this.request(mergeConfig$1(config2 || {}, {
      method,
      url,
      data: (config2 || {}).data
    }));
  };
}, "forEachMethodNoData"));
utils$2.forEach(["post", "put", "patch"], /* @__PURE__ */ __name(function forEachMethodWithData(method) {
  function generateHTTPMethod(isForm) {
    return /* @__PURE__ */ __name(function httpMethod(url, data30, config2) {
      return this.request(mergeConfig$1(config2 || {}, {
        method,
        headers: isForm ? {
          "Content-Type": "multipart/form-data"
        } : {},
        url,
        data: data30
      }));
    }, "httpMethod");
  }
  __name(generateHTTPMethod, "generateHTTPMethod");
  Axios$1.prototype[method] = generateHTTPMethod();
  Axios$1.prototype[method + "Form"] = generateHTTPMethod(true);
}, "forEachMethodWithData"));
"use strict";
let CancelToken$1 = class CancelToken2 {
  static {
    __name(this, "CancelToken");
  }
  constructor(executor) {
    if (typeof executor !== "function") {
      throw new TypeError("executor must be a function.");
    }
    let resolvePromise;
    this.promise = new Promise(/* @__PURE__ */ __name(function promiseExecutor(resolve2) {
      resolvePromise = resolve2;
    }, "promiseExecutor"));
    const token = this;
    this.promise.then((cancel) => {
      if (!token._listeners) return;
      let i2 = token._listeners.length;
      while (i2-- > 0) {
        token._listeners[i2](cancel);
      }
      token._listeners = null;
    });
    this.promise.then = (onfulfilled) => {
      let _resolve;
      const promise = new Promise((resolve2) => {
        token.subscribe(resolve2);
        _resolve = resolve2;
      }).then(onfulfilled);
      promise.cancel = /* @__PURE__ */ __name(function reject3() {
        token.unsubscribe(_resolve);
      }, "reject");
      return promise;
    };
    executor(/* @__PURE__ */ __name(function cancel(message3, config2, request) {
      if (token.reason) {
        return;
      }
      token.reason = new CanceledError$1(message3, config2, request);
      resolvePromise(token.reason);
    }, "cancel"));
  }
  /**
   * Throws a `CanceledError` if cancellation has been requested.
   */
  throwIfRequested() {
    if (this.reason) {
      throw this.reason;
    }
  }
  /**
   * Subscribe to the cancel signal
   */
  subscribe(listener) {
    if (this.reason) {
      listener(this.reason);
      return;
    }
    if (this._listeners) {
      this._listeners.push(listener);
    } else {
      this._listeners = [listener];
    }
  }
  /**
   * Unsubscribe from the cancel signal
   */
  unsubscribe(listener) {
    if (!this._listeners) {
      return;
    }
    const index2 = this._listeners.indexOf(listener);
    if (index2 !== -1) {
      this._listeners.splice(index2, 1);
    }
  }
  toAbortSignal() {
    const controller = new AbortController();
    const abort = /* @__PURE__ */ __name((err) => {
      controller.abort(err);
    }, "abort");
    this.subscribe(abort);
    controller.signal.unsubscribe = () => this.unsubscribe(abort);
    return controller.signal;
  }
  /**
   * Returns an object that contains a new `CancelToken` and a function that, when called,
   * cancels the `CancelToken`.
   */
  static source() {
    let cancel;
    const token = new CancelToken2(/* @__PURE__ */ __name(function executor(c2) {
      cancel = c2;
    }, "executor"));
    return {
      token,
      cancel
    };
  }
};
"use strict";
function spread$1(callback) {
  return /* @__PURE__ */ __name(function wrap2(arr) {
    return callback.apply(null, arr);
  }, "wrap");
}
__name(spread$1, "spread$1");
"use strict";
function isAxiosError$1(payload) {
  return utils$2.isObject(payload) && payload.isAxiosError === true;
}
__name(isAxiosError$1, "isAxiosError$1");
const HttpStatusCode$1 = {
  Continue: 100,
  SwitchingProtocols: 101,
  Processing: 102,
  EarlyHints: 103,
  Ok: 200,
  Created: 201,
  Accepted: 202,
  NonAuthoritativeInformation: 203,
  NoContent: 204,
  ResetContent: 205,
  PartialContent: 206,
  MultiStatus: 207,
  AlreadyReported: 208,
  ImUsed: 226,
  MultipleChoices: 300,
  MovedPermanently: 301,
  Found: 302,
  SeeOther: 303,
  NotModified: 304,
  UseProxy: 305,
  Unused: 306,
  TemporaryRedirect: 307,
  PermanentRedirect: 308,
  BadRequest: 400,
  Unauthorized: 401,
  PaymentRequired: 402,
  Forbidden: 403,
  NotFound: 404,
  MethodNotAllowed: 405,
  NotAcceptable: 406,
  ProxyAuthenticationRequired: 407,
  RequestTimeout: 408,
  Conflict: 409,
  Gone: 410,
  LengthRequired: 411,
  PreconditionFailed: 412,
  PayloadTooLarge: 413,
  UriTooLong: 414,
  UnsupportedMediaType: 415,
  RangeNotSatisfiable: 416,
  ExpectationFailed: 417,
  ImATeapot: 418,
  MisdirectedRequest: 421,
  UnprocessableEntity: 422,
  Locked: 423,
  FailedDependency: 424,
  TooEarly: 425,
  UpgradeRequired: 426,
  PreconditionRequired: 428,
  TooManyRequests: 429,
  RequestHeaderFieldsTooLarge: 431,
  UnavailableForLegalReasons: 451,
  InternalServerError: 500,
  NotImplemented: 501,
  BadGateway: 502,
  ServiceUnavailable: 503,
  GatewayTimeout: 504,
  HttpVersionNotSupported: 505,
  VariantAlsoNegotiates: 506,
  InsufficientStorage: 507,
  LoopDetected: 508,
  NotExtended: 510,
  NetworkAuthenticationRequired: 511
};
Object.entries(HttpStatusCode$1).forEach(([key, value3]) => {
  HttpStatusCode$1[value3] = key;
});
"use strict";
function createInstance(defaultConfig) {
  const context = new Axios$1(defaultConfig);
  const instance = bind$3(Axios$1.prototype.request, context);
  utils$2.extend(instance, Axios$1.prototype, context, { allOwnKeys: true });
  utils$2.extend(instance, context, null, { allOwnKeys: true });
  instance.create = /* @__PURE__ */ __name(function create3(instanceConfig) {
    return createInstance(mergeConfig$1(defaultConfig, instanceConfig));
  }, "create");
  return instance;
}
__name(createInstance, "createInstance");
const axios = createInstance(defaults$2);
axios.Axios = Axios$1;
axios.CanceledError = CanceledError$1;
axios.CancelToken = CancelToken$1;
axios.isCancel = isCancel$1;
axios.VERSION = VERSION$3;
axios.toFormData = toFormData$1;
axios.AxiosError = AxiosError$1;
axios.Cancel = axios.CanceledError;
axios.all = /* @__PURE__ */ __name(function all2(promises) {
  return Promise.all(promises);
}, "all");
axios.spread = spread$1;
axios.isAxiosError = isAxiosError$1;
axios.mergeConfig = mergeConfig$1;
axios.AxiosHeaders = AxiosHeaders$1;
axios.formToJSON = (thing) => formDataToJSON(utils$2.isHTMLForm(thing) ? new FormData(thing) : thing);
axios.getAdapter = adapters.getAdapter;
axios.HttpStatusCode = HttpStatusCode$1;
axios.default = axios;
const {
  Axios,
  AxiosError,
  CanceledError,
  isCancel,
  CancelToken,
  VERSION: VERSION$2,
  all,
  Cancel,
  isAxiosError,
  spread,
  toFormData,
  AxiosHeaders,
  HttpStatusCode,
  formToJSON,
  getAdapter,
  mergeConfig
} = axios;
var util;
(function(util2) {
  util2.assertEqual = (val) => val;
  function assertIs(_arg) {
  }
  __name(assertIs, "assertIs");
  util2.assertIs = assertIs;
  function assertNever(_x) {
    throw new Error();
  }
  __name(assertNever, "assertNever");
  util2.assertNever = assertNever;
  util2.arrayToEnum = (items2) => {
    const obj = {};
    for (const item3 of items2) {
      obj[item3] = item3;
    }
    return obj;
  };
  util2.getValidEnumValues = (obj) => {
    const validKeys = util2.objectKeys(obj).filter((k2) => typeof obj[obj[k2]] !== "number");
    const filtered = {};
    for (const k2 of validKeys) {
      filtered[k2] = obj[k2];
    }
    return util2.objectValues(filtered);
  };
  util2.objectValues = (obj) => {
    return util2.objectKeys(obj).map(function(e2) {
      return obj[e2];
    });
  };
  util2.objectKeys = typeof Object.keys === "function" ? (obj) => Object.keys(obj) : (object) => {
    const keys2 = [];
    for (const key in object) {
      if (Object.prototype.hasOwnProperty.call(object, key)) {
        keys2.push(key);
      }
    }
    return keys2;
  };
  util2.find = (arr, checker) => {
    for (const item3 of arr) {
      if (checker(item3))
        return item3;
    }
    return void 0;
  };
  util2.isInteger = typeof Number.isInteger === "function" ? (val) => Number.isInteger(val) : (val) => typeof val === "number" && isFinite(val) && Math.floor(val) === val;
  function joinValues(array, separator = " | ") {
    return array.map((val) => typeof val === "string" ? `'${val}'` : val).join(separator);
  }
  __name(joinValues, "joinValues");
  util2.joinValues = joinValues;
  util2.jsonStringifyReplacer = (_2, value3) => {
    if (typeof value3 === "bigint") {
      return value3.toString();
    }
    return value3;
  };
})(util || (util = {}));
var objectUtil;
(function(objectUtil2) {
  objectUtil2.mergeShapes = (first2, second) => {
    return {
      ...first2,
      ...second
      // second overwrites first
    };
  };
})(objectUtil || (objectUtil = {}));
const ZodParsedType = util.arrayToEnum([
  "string",
  "nan",
  "number",
  "integer",
  "float",
  "boolean",
  "date",
  "bigint",
  "symbol",
  "function",
  "undefined",
  "null",
  "array",
  "object",
  "unknown",
  "promise",
  "void",
  "never",
  "map",
  "set"
]);
const getParsedType = /* @__PURE__ */ __name((data30) => {
  const t2 = typeof data30;
  switch (t2) {
    case "undefined":
      return ZodParsedType.undefined;
    case "string":
      return ZodParsedType.string;
    case "number":
      return isNaN(data30) ? ZodParsedType.nan : ZodParsedType.number;
    case "boolean":
      return ZodParsedType.boolean;
    case "function":
      return ZodParsedType.function;
    case "bigint":
      return ZodParsedType.bigint;
    case "symbol":
      return ZodParsedType.symbol;
    case "object":
      if (Array.isArray(data30)) {
        return ZodParsedType.array;
      }
      if (data30 === null) {
        return ZodParsedType.null;
      }
      if (data30.then && typeof data30.then === "function" && data30.catch && typeof data30.catch === "function") {
        return ZodParsedType.promise;
      }
      if (typeof Map !== "undefined" && data30 instanceof Map) {
        return ZodParsedType.map;
      }
      if (typeof Set !== "undefined" && data30 instanceof Set) {
        return ZodParsedType.set;
      }
      if (typeof Date !== "undefined" && data30 instanceof Date) {
        return ZodParsedType.date;
      }
      return ZodParsedType.object;
    default:
      return ZodParsedType.unknown;
  }
}, "getParsedType");
const ZodIssueCode = util.arrayToEnum([
  "invalid_type",
  "invalid_literal",
  "custom",
  "invalid_union",
  "invalid_union_discriminator",
  "invalid_enum_value",
  "unrecognized_keys",
  "invalid_arguments",
  "invalid_return_type",
  "invalid_date",
  "invalid_string",
  "too_small",
  "too_big",
  "invalid_intersection_types",
  "not_multiple_of",
  "not_finite"
]);
const quotelessJson = /* @__PURE__ */ __name((obj) => {
  const json = JSON.stringify(obj, null, 2);
  return json.replace(/"([^"]+)":/g, "$1:");
}, "quotelessJson");
class ZodError extends Error {
  static {
    __name(this, "ZodError");
  }
  get errors() {
    return this.issues;
  }
  constructor(issues) {
    super();
    this.issues = [];
    this.addIssue = (sub) => {
      this.issues = [...this.issues, sub];
    };
    this.addIssues = (subs = []) => {
      this.issues = [...this.issues, ...subs];
    };
    const actualProto = new.target.prototype;
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(this, actualProto);
    } else {
      this.__proto__ = actualProto;
    }
    this.name = "ZodError";
    this.issues = issues;
  }
  format(_mapper) {
    const mapper = _mapper || function(issue) {
      return issue.message;
    };
    const fieldErrors = { _errors: [] };
    const processError = /* @__PURE__ */ __name((error2) => {
      for (const issue of error2.issues) {
        if (issue.code === "invalid_union") {
          issue.unionErrors.map(processError);
        } else if (issue.code === "invalid_return_type") {
          processError(issue.returnTypeError);
        } else if (issue.code === "invalid_arguments") {
          processError(issue.argumentsError);
        } else if (issue.path.length === 0) {
          fieldErrors._errors.push(mapper(issue));
        } else {
          let curr = fieldErrors;
          let i2 = 0;
          while (i2 < issue.path.length) {
            const el = issue.path[i2];
            const terminal = i2 === issue.path.length - 1;
            if (!terminal) {
              curr[el] = curr[el] || { _errors: [] };
            } else {
              curr[el] = curr[el] || { _errors: [] };
              curr[el]._errors.push(mapper(issue));
            }
            curr = curr[el];
            i2++;
          }
        }
      }
    }, "processError");
    processError(this);
    return fieldErrors;
  }
  static assert(value3) {
    if (!(value3 instanceof ZodError)) {
      throw new Error(`Not a ZodError: ${value3}`);
    }
  }
  toString() {
    return this.message;
  }
  get message() {
    return JSON.stringify(this.issues, util.jsonStringifyReplacer, 2);
  }
  get isEmpty() {
    return this.issues.length === 0;
  }
  flatten(mapper = (issue) => issue.message) {
    const fieldErrors = {};
    const formErrors = [];
    for (const sub of this.issues) {
      if (sub.path.length > 0) {
        fieldErrors[sub.path[0]] = fieldErrors[sub.path[0]] || [];
        fieldErrors[sub.path[0]].push(mapper(sub));
      } else {
        formErrors.push(mapper(sub));
      }
    }
    return { formErrors, fieldErrors };
  }
  get formErrors() {
    return this.flatten();
  }
}
ZodError.create = (issues) => {
  const error2 = new ZodError(issues);
  return error2;
};
const errorMap$1 = /* @__PURE__ */ __name((issue, _ctx) => {
  let message3;
  switch (issue.code) {
    case ZodIssueCode.invalid_type:
      if (issue.received === ZodParsedType.undefined) {
        message3 = "Required";
      } else {
        message3 = `Expected ${issue.expected}, received ${issue.received}`;
      }
      break;
    case ZodIssueCode.invalid_literal:
      message3 = `Invalid literal value, expected ${JSON.stringify(issue.expected, util.jsonStringifyReplacer)}`;
      break;
    case ZodIssueCode.unrecognized_keys:
      message3 = `Unrecognized key(s) in object: ${util.joinValues(issue.keys, ", ")}`;
      break;
    case ZodIssueCode.invalid_union:
      message3 = `Invalid input`;
      break;
    case ZodIssueCode.invalid_union_discriminator:
      message3 = `Invalid discriminator value. Expected ${util.joinValues(issue.options)}`;
      break;
    case ZodIssueCode.invalid_enum_value:
      message3 = `Invalid enum value. Expected ${util.joinValues(issue.options)}, received '${issue.received}'`;
      break;
    case ZodIssueCode.invalid_arguments:
      message3 = `Invalid function arguments`;
      break;
    case ZodIssueCode.invalid_return_type:
      message3 = `Invalid function return type`;
      break;
    case ZodIssueCode.invalid_date:
      message3 = `Invalid date`;
      break;
    case ZodIssueCode.invalid_string:
      if (typeof issue.validation === "object") {
        if ("includes" in issue.validation) {
          message3 = `Invalid input: must include "${issue.validation.includes}"`;
          if (typeof issue.validation.position === "number") {
            message3 = `${message3} at one or more positions greater than or equal to ${issue.validation.position}`;
          }
        } else if ("startsWith" in issue.validation) {
          message3 = `Invalid input: must start with "${issue.validation.startsWith}"`;
        } else if ("endsWith" in issue.validation) {
          message3 = `Invalid input: must end with "${issue.validation.endsWith}"`;
        } else {
          util.assertNever(issue.validation);
        }
      } else if (issue.validation !== "regex") {
        message3 = `Invalid ${issue.validation}`;
      } else {
        message3 = "Invalid";
      }
      break;
    case ZodIssueCode.too_small:
      if (issue.type === "array")
        message3 = `Array must contain ${issue.exact ? "exactly" : issue.inclusive ? `at least` : `more than`} ${issue.minimum} element(s)`;
      else if (issue.type === "string")
        message3 = `String must contain ${issue.exact ? "exactly" : issue.inclusive ? `at least` : `over`} ${issue.minimum} character(s)`;
      else if (issue.type === "number")
        message3 = `Number must be ${issue.exact ? `exactly equal to ` : issue.inclusive ? `greater than or equal to ` : `greater than `}${issue.minimum}`;
      else if (issue.type === "date")
        message3 = `Date must be ${issue.exact ? `exactly equal to ` : issue.inclusive ? `greater than or equal to ` : `greater than `}${new Date(Number(issue.minimum))}`;
      else
        message3 = "Invalid input";
      break;
    case ZodIssueCode.too_big:
      if (issue.type === "array")
        message3 = `Array must contain ${issue.exact ? `exactly` : issue.inclusive ? `at most` : `less than`} ${issue.maximum} element(s)`;
      else if (issue.type === "string")
        message3 = `String must contain ${issue.exact ? `exactly` : issue.inclusive ? `at most` : `under`} ${issue.maximum} character(s)`;
      else if (issue.type === "number")
        message3 = `Number must be ${issue.exact ? `exactly` : issue.inclusive ? `less than or equal to` : `less than`} ${issue.maximum}`;
      else if (issue.type === "bigint")
        message3 = `BigInt must be ${issue.exact ? `exactly` : issue.inclusive ? `less than or equal to` : `less than`} ${issue.maximum}`;
      else if (issue.type === "date")
        message3 = `Date must be ${issue.exact ? `exactly` : issue.inclusive ? `smaller than or equal to` : `smaller than`} ${new Date(Number(issue.maximum))}`;
      else
        message3 = "Invalid input";
      break;
    case ZodIssueCode.custom:
      message3 = `Invalid input`;
      break;
    case ZodIssueCode.invalid_intersection_types:
      message3 = `Intersection results could not be merged`;
      break;
    case ZodIssueCode.not_multiple_of:
      message3 = `Number must be a multiple of ${issue.multipleOf}`;
      break;
    case ZodIssueCode.not_finite:
      message3 = "Number must be finite";
      break;
    default:
      message3 = _ctx.defaultError;
      util.assertNever(issue);
  }
  return { message: message3 };
}, "errorMap$1");
let overrideErrorMap = errorMap$1;
function setErrorMap(map3) {
  overrideErrorMap = map3;
}
__name(setErrorMap, "setErrorMap");
function getErrorMap() {
  return overrideErrorMap;
}
__name(getErrorMap, "getErrorMap");
const makeIssue = /* @__PURE__ */ __name((params) => {
  const { data: data30, path, errorMaps, issueData } = params;
  const fullPath = [...path, ...issueData.path || []];
  const fullIssue = {
    ...issueData,
    path: fullPath
  };
  if (issueData.message !== void 0) {
    return {
      ...issueData,
      path: fullPath,
      message: issueData.message
    };
  }
  let errorMessage = "";
  const maps = errorMaps.filter((m2) => !!m2).slice().reverse();
  for (const map3 of maps) {
    errorMessage = map3(fullIssue, { data: data30, defaultError: errorMessage }).message;
  }
  return {
    ...issueData,
    path: fullPath,
    message: errorMessage
  };
}, "makeIssue");
const EMPTY_PATH = [];
function addIssueToContext(ctx, issueData) {
  const overrideMap = getErrorMap();
  const issue = makeIssue({
    issueData,
    data: ctx.data,
    path: ctx.path,
    errorMaps: [
      ctx.common.contextualErrorMap,
      // contextual error map is first priority
      ctx.schemaErrorMap,
      // then schema-bound map if available
      overrideMap,
      // then global override map
      overrideMap === errorMap$1 ? void 0 : errorMap$1
      // then global default map
    ].filter((x2) => !!x2)
  });
  ctx.common.issues.push(issue);
}
__name(addIssueToContext, "addIssueToContext");
class ParseStatus {
  static {
    __name(this, "ParseStatus");
  }
  constructor() {
    this.value = "valid";
  }
  dirty() {
    if (this.value === "valid")
      this.value = "dirty";
  }
  abort() {
    if (this.value !== "aborted")
      this.value = "aborted";
  }
  static mergeArray(status, results) {
    const arrayValue = [];
    for (const s2 of results) {
      if (s2.status === "aborted")
        return INVALID;
      if (s2.status === "dirty")
        status.dirty();
      arrayValue.push(s2.value);
    }
    return { status: status.value, value: arrayValue };
  }
  static async mergeObjectAsync(status, pairs) {
    const syncPairs = [];
    for (const pair of pairs) {
      const key = await pair.key;
      const value3 = await pair.value;
      syncPairs.push({
        key,
        value: value3
      });
    }
    return ParseStatus.mergeObjectSync(status, syncPairs);
  }
  static mergeObjectSync(status, pairs) {
    const finalObject = {};
    for (const pair of pairs) {
      const { key, value: value3 } = pair;
      if (key.status === "aborted")
        return INVALID;
      if (value3.status === "aborted")
        return INVALID;
      if (key.status === "dirty")
        status.dirty();
      if (value3.status === "dirty")
        status.dirty();
      if (key.value !== "__proto__" && (typeof value3.value !== "undefined" || pair.alwaysSet)) {
        finalObject[key.value] = value3.value;
      }
    }
    return { status: status.value, value: finalObject };
  }
}
const INVALID = Object.freeze({
  status: "aborted"
});
const DIRTY = /* @__PURE__ */ __name((value3) => ({ status: "dirty", value: value3 }), "DIRTY");
const OK = /* @__PURE__ */ __name((value3) => ({ status: "valid", value: value3 }), "OK");
const isAborted = /* @__PURE__ */ __name((x2) => x2.status === "aborted", "isAborted");
const isDirty = /* @__PURE__ */ __name((x2) => x2.status === "dirty", "isDirty");
const isValid = /* @__PURE__ */ __name((x2) => x2.status === "valid", "isValid");
const isAsync = /* @__PURE__ */ __name((x2) => typeof Promise !== "undefined" && x2 instanceof Promise, "isAsync");
function __classPrivateFieldGet(receiver, state, kind, f2) {
  if (kind === "a" && !f2) throw new TypeError("Private accessor was defined without a getter");
  if (typeof state === "function" ? receiver !== state || !f2 : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
  return kind === "m" ? f2 : kind === "a" ? f2.call(receiver) : f2 ? f2.value : state.get(receiver);
}
__name(__classPrivateFieldGet, "__classPrivateFieldGet");
function __classPrivateFieldSet(receiver, state, value3, kind, f2) {
  if (kind === "m") throw new TypeError("Private method is not writable");
  if (kind === "a" && !f2) throw new TypeError("Private accessor was defined without a setter");
  if (typeof state === "function" ? receiver !== state || !f2 : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
  return kind === "a" ? f2.call(receiver, value3) : f2 ? f2.value = value3 : state.set(receiver, value3), value3;
}
__name(__classPrivateFieldSet, "__classPrivateFieldSet");
typeof SuppressedError === "function" ? SuppressedError : function(error2, suppressed, message3) {
  var e2 = new Error(message3);
  return e2.name = "SuppressedError", e2.error = error2, e2.suppressed = suppressed, e2;
};
var errorUtil;
(function(errorUtil2) {
  errorUtil2.errToObj = (message3) => typeof message3 === "string" ? { message: message3 } : message3 || {};
  errorUtil2.toString = (message3) => typeof message3 === "string" ? message3 : message3 === null || message3 === void 0 ? void 0 : message3.message;
})(errorUtil || (errorUtil = {}));
var _ZodEnum_cache, _ZodNativeEnum_cache;
class ParseInputLazyPath {
  static {
    __name(this, "ParseInputLazyPath");
  }
  constructor(parent, value3, path, key) {
    this._cachedPath = [];
    this.parent = parent;
    this.data = value3;
    this._path = path;
    this._key = key;
  }
  get path() {
    if (!this._cachedPath.length) {
      if (this._key instanceof Array) {
        this._cachedPath.push(...this._path, ...this._key);
      } else {
        this._cachedPath.push(...this._path, this._key);
      }
    }
    return this._cachedPath;
  }
}
const handleResult = /* @__PURE__ */ __name((ctx, result) => {
  if (isValid(result)) {
    return { success: true, data: result.value };
  } else {
    if (!ctx.common.issues.length) {
      throw new Error("Validation failed but no issues detected.");
    }
    return {
      success: false,
      get error() {
        if (this._error)
          return this._error;
        const error2 = new ZodError(ctx.common.issues);
        this._error = error2;
        return this._error;
      }
    };
  }
}, "handleResult");
function processCreateParams(params) {
  if (!params)
    return {};
  const { errorMap: errorMap2, invalid_type_error, required_error, description } = params;
  if (errorMap2 && (invalid_type_error || required_error)) {
    throw new Error(`Can't use "invalid_type_error" or "required_error" in conjunction with custom error map.`);
  }
  if (errorMap2)
    return { errorMap: errorMap2, description };
  const customMap = /* @__PURE__ */ __name((iss, ctx) => {
    var _a2, _b;
    const { message: message3 } = params;
    if (iss.code === "invalid_enum_value") {
      return { message: message3 !== null && message3 !== void 0 ? message3 : ctx.defaultError };
    }
    if (typeof ctx.data === "undefined") {
      return { message: (_a2 = message3 !== null && message3 !== void 0 ? message3 : required_error) !== null && _a2 !== void 0 ? _a2 : ctx.defaultError };
    }
    if (iss.code !== "invalid_type")
      return { message: ctx.defaultError };
    return { message: (_b = message3 !== null && message3 !== void 0 ? message3 : invalid_type_error) !== null && _b !== void 0 ? _b : ctx.defaultError };
  }, "customMap");
  return { errorMap: customMap, description };
}
__name(processCreateParams, "processCreateParams");
class ZodType {
  static {
    __name(this, "ZodType");
  }
  get description() {
    return this._def.description;
  }
  _getType(input) {
    return getParsedType(input.data);
  }
  _getOrReturnCtx(input, ctx) {
    return ctx || {
      common: input.parent.common,
      data: input.data,
      parsedType: getParsedType(input.data),
      schemaErrorMap: this._def.errorMap,
      path: input.path,
      parent: input.parent
    };
  }
  _processInputParams(input) {
    return {
      status: new ParseStatus(),
      ctx: {
        common: input.parent.common,
        data: input.data,
        parsedType: getParsedType(input.data),
        schemaErrorMap: this._def.errorMap,
        path: input.path,
        parent: input.parent
      }
    };
  }
  _parseSync(input) {
    const result = this._parse(input);
    if (isAsync(result)) {
      throw new Error("Synchronous parse encountered promise.");
    }
    return result;
  }
  _parseAsync(input) {
    const result = this._parse(input);
    return Promise.resolve(result);
  }
  parse(data30, params) {
    const result = this.safeParse(data30, params);
    if (result.success)
      return result.data;
    throw result.error;
  }
  safeParse(data30, params) {
    var _a2;
    const ctx = {
      common: {
        issues: [],
        async: (_a2 = params === null || params === void 0 ? void 0 : params.async) !== null && _a2 !== void 0 ? _a2 : false,
        contextualErrorMap: params === null || params === void 0 ? void 0 : params.errorMap
      },
      path: (params === null || params === void 0 ? void 0 : params.path) || [],
      schemaErrorMap: this._def.errorMap,
      parent: null,
      data: data30,
      parsedType: getParsedType(data30)
    };
    const result = this._parseSync({ data: data30, path: ctx.path, parent: ctx });
    return handleResult(ctx, result);
  }
  "~validate"(data30) {
    var _a2, _b;
    const ctx = {
      common: {
        issues: [],
        async: !!this["~standard"].async
      },
      path: [],
      schemaErrorMap: this._def.errorMap,
      parent: null,
      data: data30,
      parsedType: getParsedType(data30)
    };
    if (!this["~standard"].async) {
      try {
        const result = this._parseSync({ data: data30, path: [], parent: ctx });
        return isValid(result) ? {
          value: result.value
        } : {
          issues: ctx.common.issues
        };
      } catch (err) {
        if ((_b = (_a2 = err === null || err === void 0 ? void 0 : err.message) === null || _a2 === void 0 ? void 0 : _a2.toLowerCase()) === null || _b === void 0 ? void 0 : _b.includes("encountered")) {
          this["~standard"].async = true;
        }
        ctx.common = {
          issues: [],
          async: true
        };
      }
    }
    return this._parseAsync({ data: data30, path: [], parent: ctx }).then((result) => isValid(result) ? {
      value: result.value
    } : {
      issues: ctx.common.issues
    });
  }
  async parseAsync(data30, params) {
    const result = await this.safeParseAsync(data30, params);
    if (result.success)
      return result.data;
    throw result.error;
  }
  async safeParseAsync(data30, params) {
    const ctx = {
      common: {
        issues: [],
        contextualErrorMap: params === null || params === void 0 ? void 0 : params.errorMap,
        async: true
      },
      path: (params === null || params === void 0 ? void 0 : params.path) || [],
      schemaErrorMap: this._def.errorMap,
      parent: null,
      data: data30,
      parsedType: getParsedType(data30)
    };
    const maybeAsyncResult = this._parse({ data: data30, path: ctx.path, parent: ctx });
    const result = await (isAsync(maybeAsyncResult) ? maybeAsyncResult : Promise.resolve(maybeAsyncResult));
    return handleResult(ctx, result);
  }
  refine(check, message3) {
    const getIssueProperties = /* @__PURE__ */ __name((val) => {
      if (typeof message3 === "string" || typeof message3 === "undefined") {
        return { message: message3 };
      } else if (typeof message3 === "function") {
        return message3(val);
      } else {
        return message3;
      }
    }, "getIssueProperties");
    return this._refinement((val, ctx) => {
      const result = check(val);
      const setError = /* @__PURE__ */ __name(() => ctx.addIssue({
        code: ZodIssueCode.custom,
        ...getIssueProperties(val)
      }), "setError");
      if (typeof Promise !== "undefined" && result instanceof Promise) {
        return result.then((data30) => {
          if (!data30) {
            setError();
            return false;
          } else {
            return true;
          }
        });
      }
      if (!result) {
        setError();
        return false;
      } else {
        return true;
      }
    });
  }
  refinement(check, refinementData) {
    return this._refinement((val, ctx) => {
      if (!check(val)) {
        ctx.addIssue(typeof refinementData === "function" ? refinementData(val, ctx) : refinementData);
        return false;
      } else {
        return true;
      }
    });
  }
  _refinement(refinement) {
    return new ZodEffects({
      schema: this,
      typeName: ZodFirstPartyTypeKind.ZodEffects,
      effect: { type: "refinement", refinement }
    });
  }
  superRefine(refinement) {
    return this._refinement(refinement);
  }
  constructor(def2) {
    this.spa = this.safeParseAsync;
    this._def = def2;
    this.parse = this.parse.bind(this);
    this.safeParse = this.safeParse.bind(this);
    this.parseAsync = this.parseAsync.bind(this);
    this.safeParseAsync = this.safeParseAsync.bind(this);
    this.spa = this.spa.bind(this);
    this.refine = this.refine.bind(this);
    this.refinement = this.refinement.bind(this);
    this.superRefine = this.superRefine.bind(this);
    this.optional = this.optional.bind(this);
    this.nullable = this.nullable.bind(this);
    this.nullish = this.nullish.bind(this);
    this.array = this.array.bind(this);
    this.promise = this.promise.bind(this);
    this.or = this.or.bind(this);
    this.and = this.and.bind(this);
    this.transform = this.transform.bind(this);
    this.brand = this.brand.bind(this);
    this.default = this.default.bind(this);
    this.catch = this.catch.bind(this);
    this.describe = this.describe.bind(this);
    this.pipe = this.pipe.bind(this);
    this.readonly = this.readonly.bind(this);
    this.isNullable = this.isNullable.bind(this);
    this.isOptional = this.isOptional.bind(this);
    this["~standard"] = {
      version: 1,
      vendor: "zod",
      validate: /* @__PURE__ */ __name((data30) => this["~validate"](data30), "validate")
    };
  }
  optional() {
    return ZodOptional.create(this, this._def);
  }
  nullable() {
    return ZodNullable.create(this, this._def);
  }
  nullish() {
    return this.nullable().optional();
  }
  array() {
    return ZodArray.create(this);
  }
  promise() {
    return ZodPromise.create(this, this._def);
  }
  or(option5) {
    return ZodUnion.create([this, option5], this._def);
  }
  and(incoming) {
    return ZodIntersection.create(this, incoming, this._def);
  }
  transform(transform2) {
    return new ZodEffects({
      ...processCreateParams(this._def),
      schema: this,
      typeName: ZodFirstPartyTypeKind.ZodEffects,
      effect: { type: "transform", transform: transform2 }
    });
  }
  default(def2) {
    const defaultValueFunc = typeof def2 === "function" ? def2 : () => def2;
    return new ZodDefault({
      ...processCreateParams(this._def),
      innerType: this,
      defaultValue: defaultValueFunc,
      typeName: ZodFirstPartyTypeKind.ZodDefault
    });
  }
  brand() {
    return new ZodBranded({
      typeName: ZodFirstPartyTypeKind.ZodBranded,
      type: this,
      ...processCreateParams(this._def)
    });
  }
  catch(def2) {
    const catchValueFunc = typeof def2 === "function" ? def2 : () => def2;
    return new ZodCatch({
      ...processCreateParams(this._def),
      innerType: this,
      catchValue: catchValueFunc,
      typeName: ZodFirstPartyTypeKind.ZodCatch
    });
  }
  describe(description) {
    const This = this.constructor;
    return new This({
      ...this._def,
      description
    });
  }
  pipe(target2) {
    return ZodPipeline.create(this, target2);
  }
  readonly() {
    return ZodReadonly.create(this);
  }
  isOptional() {
    return this.safeParse(void 0).success;
  }
  isNullable() {
    return this.safeParse(null).success;
  }
}
const cuidRegex = /^c[^\s-]{8,}$/i;
const cuid2Regex = /^[0-9a-z]+$/;
const ulidRegex = /^[0-9A-HJKMNP-TV-Z]{26}$/i;
const uuidRegex = /^[0-9a-fA-F]{8}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{4}\b-[0-9a-fA-F]{12}$/i;
const nanoidRegex = /^[a-z0-9_-]{21}$/i;
const jwtRegex = /^[A-Za-z0-9-_]+\.[A-Za-z0-9-_]+\.[A-Za-z0-9-_]*$/;
const durationRegex = /^[-+]?P(?!$)(?:(?:[-+]?\d+Y)|(?:[-+]?\d+[.,]\d+Y$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:(?:[-+]?\d+W)|(?:[-+]?\d+[.,]\d+W$))?(?:(?:[-+]?\d+D)|(?:[-+]?\d+[.,]\d+D$))?(?:T(?=[\d+-])(?:(?:[-+]?\d+H)|(?:[-+]?\d+[.,]\d+H$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:[-+]?\d+(?:[.,]\d+)?S)?)??$/;
const emailRegex = /^(?!\.)(?!.*\.\.)([A-Z0-9_'+\-\.]*)[A-Z0-9_+-]@([A-Z0-9][A-Z0-9\-]*\.)+[A-Z]{2,}$/i;
const _emojiRegex = `^(\\p{Extended_Pictographic}|\\p{Emoji_Component})+$`;
let emojiRegex;
const ipv4Regex = /^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/;
const ipv4CidrRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\/(3[0-2]|[12]?[0-9])$/;
const ipv6Regex = /^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$/;
const ipv6CidrRegex = /^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))\/(12[0-8]|1[01][0-9]|[1-9]?[0-9])$/;
const base64Regex = /^([0-9a-zA-Z+/]{4})*(([0-9a-zA-Z+/]{2}==)|([0-9a-zA-Z+/]{3}=))?$/;
const base64urlRegex = /^([0-9a-zA-Z-_]{4})*(([0-9a-zA-Z-_]{2}(==)?)|([0-9a-zA-Z-_]{3}(=)?))?$/;
const dateRegexSource = `((\\d\\d[2468][048]|\\d\\d[13579][26]|\\d\\d0[48]|[02468][048]00|[13579][26]00)-02-29|\\d{4}-((0[13578]|1[02])-(0[1-9]|[12]\\d|3[01])|(0[469]|11)-(0[1-9]|[12]\\d|30)|(02)-(0[1-9]|1\\d|2[0-8])))`;
const dateRegex = new RegExp(`^${dateRegexSource}$`);
function timeRegexSource(args) {
  let regex2 = `([01]\\d|2[0-3]):[0-5]\\d:[0-5]\\d`;
  if (args.precision) {
    regex2 = `${regex2}\\.\\d{${args.precision}}`;
  } else if (args.precision == null) {
    regex2 = `${regex2}(\\.\\d+)?`;
  }
  return regex2;
}
__name(timeRegexSource, "timeRegexSource");
function timeRegex(args) {
  return new RegExp(`^${timeRegexSource(args)}$`);
}
__name(timeRegex, "timeRegex");
function datetimeRegex(args) {
  let regex2 = `${dateRegexSource}T${timeRegexSource(args)}`;
  const opts = [];
  opts.push(args.local ? `Z?` : `Z`);
  if (args.offset)
    opts.push(`([+-]\\d{2}:?\\d{2})`);
  regex2 = `${regex2}(${opts.join("|")})`;
  return new RegExp(`^${regex2}$`);
}
__name(datetimeRegex, "datetimeRegex");
function isValidIP(ip, version2) {
  if ((version2 === "v4" || !version2) && ipv4Regex.test(ip)) {
    return true;
  }
  if ((version2 === "v6" || !version2) && ipv6Regex.test(ip)) {
    return true;
  }
  return false;
}
__name(isValidIP, "isValidIP");
function isValidJWT(jwt, alg) {
  if (!jwtRegex.test(jwt))
    return false;
  try {
    const [header3] = jwt.split(".");
    const base64 = header3.replace(/-/g, "+").replace(/_/g, "/").padEnd(header3.length + (4 - header3.length % 4) % 4, "=");
    const decoded = JSON.parse(atob(base64));
    if (typeof decoded !== "object" || decoded === null)
      return false;
    if (!decoded.typ || !decoded.alg)
      return false;
    if (alg && decoded.alg !== alg)
      return false;
    return true;
  } catch (_a2) {
    return false;
  }
}
__name(isValidJWT, "isValidJWT");
function isValidCidr(ip, version2) {
  if ((version2 === "v4" || !version2) && ipv4CidrRegex.test(ip)) {
    return true;
  }
  if ((version2 === "v6" || !version2) && ipv6CidrRegex.test(ip)) {
    return true;
  }
  return false;
}
__name(isValidCidr, "isValidCidr");
class ZodString extends ZodType {
  static {
    __name(this, "ZodString");
  }
  _parse(input) {
    if (this._def.coerce) {
      input.data = String(input.data);
    }
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.string) {
      const ctx2 = this._getOrReturnCtx(input);
      addIssueToContext(ctx2, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.string,
        received: ctx2.parsedType
      });
      return INVALID;
    }
    const status = new ParseStatus();
    let ctx = void 0;
    for (const check of this._def.checks) {
      if (check.kind === "min") {
        if (input.data.length < check.value) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_small,
            minimum: check.value,
            type: "string",
            inclusive: true,
            exact: false,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "max") {
        if (input.data.length > check.value) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_big,
            maximum: check.value,
            type: "string",
            inclusive: true,
            exact: false,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "length") {
        const tooBig = input.data.length > check.value;
        const tooSmall = input.data.length < check.value;
        if (tooBig || tooSmall) {
          ctx = this._getOrReturnCtx(input, ctx);
          if (tooBig) {
            addIssueToContext(ctx, {
              code: ZodIssueCode.too_big,
              maximum: check.value,
              type: "string",
              inclusive: true,
              exact: true,
              message: check.message
            });
          } else if (tooSmall) {
            addIssueToContext(ctx, {
              code: ZodIssueCode.too_small,
              minimum: check.value,
              type: "string",
              inclusive: true,
              exact: true,
              message: check.message
            });
          }
          status.dirty();
        }
      } else if (check.kind === "email") {
        if (!emailRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "email",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "emoji") {
        if (!emojiRegex) {
          emojiRegex = new RegExp(_emojiRegex, "u");
        }
        if (!emojiRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "emoji",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "uuid") {
        if (!uuidRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "uuid",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "nanoid") {
        if (!nanoidRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "nanoid",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "cuid") {
        if (!cuidRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "cuid",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "cuid2") {
        if (!cuid2Regex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "cuid2",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "ulid") {
        if (!ulidRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "ulid",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "url") {
        try {
          new URL(input.data);
        } catch (_a2) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "url",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "regex") {
        check.regex.lastIndex = 0;
        const testResult = check.regex.test(input.data);
        if (!testResult) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "regex",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "trim") {
        input.data = input.data.trim();
      } else if (check.kind === "includes") {
        if (!input.data.includes(check.value, check.position)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: { includes: check.value, position: check.position },
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "toLowerCase") {
        input.data = input.data.toLowerCase();
      } else if (check.kind === "toUpperCase") {
        input.data = input.data.toUpperCase();
      } else if (check.kind === "startsWith") {
        if (!input.data.startsWith(check.value)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: { startsWith: check.value },
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "endsWith") {
        if (!input.data.endsWith(check.value)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: { endsWith: check.value },
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "datetime") {
        const regex2 = datetimeRegex(check);
        if (!regex2.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: "datetime",
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "date") {
        const regex2 = dateRegex;
        if (!regex2.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: "date",
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "time") {
        const regex2 = timeRegex(check);
        if (!regex2.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_string,
            validation: "time",
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "duration") {
        if (!durationRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "duration",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "ip") {
        if (!isValidIP(input.data, check.version)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "ip",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "jwt") {
        if (!isValidJWT(input.data, check.alg)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "jwt",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "cidr") {
        if (!isValidCidr(input.data, check.version)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "cidr",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "base64") {
        if (!base64Regex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "base64",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "base64url") {
        if (!base64urlRegex.test(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            validation: "base64url",
            code: ZodIssueCode.invalid_string,
            message: check.message
          });
          status.dirty();
        }
      } else {
        util.assertNever(check);
      }
    }
    return { status: status.value, value: input.data };
  }
  _regex(regex2, validation, message3) {
    return this.refinement((data30) => regex2.test(data30), {
      validation,
      code: ZodIssueCode.invalid_string,
      ...errorUtil.errToObj(message3)
    });
  }
  _addCheck(check) {
    return new ZodString({
      ...this._def,
      checks: [...this._def.checks, check]
    });
  }
  email(message3) {
    return this._addCheck({ kind: "email", ...errorUtil.errToObj(message3) });
  }
  url(message3) {
    return this._addCheck({ kind: "url", ...errorUtil.errToObj(message3) });
  }
  emoji(message3) {
    return this._addCheck({ kind: "emoji", ...errorUtil.errToObj(message3) });
  }
  uuid(message3) {
    return this._addCheck({ kind: "uuid", ...errorUtil.errToObj(message3) });
  }
  nanoid(message3) {
    return this._addCheck({ kind: "nanoid", ...errorUtil.errToObj(message3) });
  }
  cuid(message3) {
    return this._addCheck({ kind: "cuid", ...errorUtil.errToObj(message3) });
  }
  cuid2(message3) {
    return this._addCheck({ kind: "cuid2", ...errorUtil.errToObj(message3) });
  }
  ulid(message3) {
    return this._addCheck({ kind: "ulid", ...errorUtil.errToObj(message3) });
  }
  base64(message3) {
    return this._addCheck({ kind: "base64", ...errorUtil.errToObj(message3) });
  }
  base64url(message3) {
    return this._addCheck({
      kind: "base64url",
      ...errorUtil.errToObj(message3)
    });
  }
  jwt(options5) {
    return this._addCheck({ kind: "jwt", ...errorUtil.errToObj(options5) });
  }
  ip(options5) {
    return this._addCheck({ kind: "ip", ...errorUtil.errToObj(options5) });
  }
  cidr(options5) {
    return this._addCheck({ kind: "cidr", ...errorUtil.errToObj(options5) });
  }
  datetime(options5) {
    var _a2, _b;
    if (typeof options5 === "string") {
      return this._addCheck({
        kind: "datetime",
        precision: null,
        offset: false,
        local: false,
        message: options5
      });
    }
    return this._addCheck({
      kind: "datetime",
      precision: typeof (options5 === null || options5 === void 0 ? void 0 : options5.precision) === "undefined" ? null : options5 === null || options5 === void 0 ? void 0 : options5.precision,
      offset: (_a2 = options5 === null || options5 === void 0 ? void 0 : options5.offset) !== null && _a2 !== void 0 ? _a2 : false,
      local: (_b = options5 === null || options5 === void 0 ? void 0 : options5.local) !== null && _b !== void 0 ? _b : false,
      ...errorUtil.errToObj(options5 === null || options5 === void 0 ? void 0 : options5.message)
    });
  }
  date(message3) {
    return this._addCheck({ kind: "date", message: message3 });
  }
  time(options5) {
    if (typeof options5 === "string") {
      return this._addCheck({
        kind: "time",
        precision: null,
        message: options5
      });
    }
    return this._addCheck({
      kind: "time",
      precision: typeof (options5 === null || options5 === void 0 ? void 0 : options5.precision) === "undefined" ? null : options5 === null || options5 === void 0 ? void 0 : options5.precision,
      ...errorUtil.errToObj(options5 === null || options5 === void 0 ? void 0 : options5.message)
    });
  }
  duration(message3) {
    return this._addCheck({ kind: "duration", ...errorUtil.errToObj(message3) });
  }
  regex(regex2, message3) {
    return this._addCheck({
      kind: "regex",
      regex: regex2,
      ...errorUtil.errToObj(message3)
    });
  }
  includes(value3, options5) {
    return this._addCheck({
      kind: "includes",
      value: value3,
      position: options5 === null || options5 === void 0 ? void 0 : options5.position,
      ...errorUtil.errToObj(options5 === null || options5 === void 0 ? void 0 : options5.message)
    });
  }
  startsWith(value3, message3) {
    return this._addCheck({
      kind: "startsWith",
      value: value3,
      ...errorUtil.errToObj(message3)
    });
  }
  endsWith(value3, message3) {
    return this._addCheck({
      kind: "endsWith",
      value: value3,
      ...errorUtil.errToObj(message3)
    });
  }
  min(minLength, message3) {
    return this._addCheck({
      kind: "min",
      value: minLength,
      ...errorUtil.errToObj(message3)
    });
  }
  max(maxLength, message3) {
    return this._addCheck({
      kind: "max",
      value: maxLength,
      ...errorUtil.errToObj(message3)
    });
  }
  length(len, message3) {
    return this._addCheck({
      kind: "length",
      value: len,
      ...errorUtil.errToObj(message3)
    });
  }
  /**
   * Equivalent to `.min(1)`
   */
  nonempty(message3) {
    return this.min(1, errorUtil.errToObj(message3));
  }
  trim() {
    return new ZodString({
      ...this._def,
      checks: [...this._def.checks, { kind: "trim" }]
    });
  }
  toLowerCase() {
    return new ZodString({
      ...this._def,
      checks: [...this._def.checks, { kind: "toLowerCase" }]
    });
  }
  toUpperCase() {
    return new ZodString({
      ...this._def,
      checks: [...this._def.checks, { kind: "toUpperCase" }]
    });
  }
  get isDatetime() {
    return !!this._def.checks.find((ch) => ch.kind === "datetime");
  }
  get isDate() {
    return !!this._def.checks.find((ch) => ch.kind === "date");
  }
  get isTime() {
    return !!this._def.checks.find((ch) => ch.kind === "time");
  }
  get isDuration() {
    return !!this._def.checks.find((ch) => ch.kind === "duration");
  }
  get isEmail() {
    return !!this._def.checks.find((ch) => ch.kind === "email");
  }
  get isURL() {
    return !!this._def.checks.find((ch) => ch.kind === "url");
  }
  get isEmoji() {
    return !!this._def.checks.find((ch) => ch.kind === "emoji");
  }
  get isUUID() {
    return !!this._def.checks.find((ch) => ch.kind === "uuid");
  }
  get isNANOID() {
    return !!this._def.checks.find((ch) => ch.kind === "nanoid");
  }
  get isCUID() {
    return !!this._def.checks.find((ch) => ch.kind === "cuid");
  }
  get isCUID2() {
    return !!this._def.checks.find((ch) => ch.kind === "cuid2");
  }
  get isULID() {
    return !!this._def.checks.find((ch) => ch.kind === "ulid");
  }
  get isIP() {
    return !!this._def.checks.find((ch) => ch.kind === "ip");
  }
  get isCIDR() {
    return !!this._def.checks.find((ch) => ch.kind === "cidr");
  }
  get isBase64() {
    return !!this._def.checks.find((ch) => ch.kind === "base64");
  }
  get isBase64url() {
    return !!this._def.checks.find((ch) => ch.kind === "base64url");
  }
  get minLength() {
    let min = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "min") {
        if (min === null || ch.value > min)
          min = ch.value;
      }
    }
    return min;
  }
  get maxLength() {
    let max = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "max") {
        if (max === null || ch.value < max)
          max = ch.value;
      }
    }
    return max;
  }
}
ZodString.create = (params) => {
  var _a2;
  return new ZodString({
    checks: [],
    typeName: ZodFirstPartyTypeKind.ZodString,
    coerce: (_a2 = params === null || params === void 0 ? void 0 : params.coerce) !== null && _a2 !== void 0 ? _a2 : false,
    ...processCreateParams(params)
  });
};
function floatSafeRemainder(val, step2) {
  const valDecCount = (val.toString().split(".")[1] || "").length;
  const stepDecCount = (step2.toString().split(".")[1] || "").length;
  const decCount = valDecCount > stepDecCount ? valDecCount : stepDecCount;
  const valInt = parseInt(val.toFixed(decCount).replace(".", ""));
  const stepInt = parseInt(step2.toFixed(decCount).replace(".", ""));
  return valInt % stepInt / Math.pow(10, decCount);
}
__name(floatSafeRemainder, "floatSafeRemainder");
class ZodNumber extends ZodType {
  static {
    __name(this, "ZodNumber");
  }
  constructor() {
    super(...arguments);
    this.min = this.gte;
    this.max = this.lte;
    this.step = this.multipleOf;
  }
  _parse(input) {
    if (this._def.coerce) {
      input.data = Number(input.data);
    }
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.number) {
      const ctx2 = this._getOrReturnCtx(input);
      addIssueToContext(ctx2, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.number,
        received: ctx2.parsedType
      });
      return INVALID;
    }
    let ctx = void 0;
    const status = new ParseStatus();
    for (const check of this._def.checks) {
      if (check.kind === "int") {
        if (!util.isInteger(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.invalid_type,
            expected: "integer",
            received: "float",
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "min") {
        const tooSmall = check.inclusive ? input.data < check.value : input.data <= check.value;
        if (tooSmall) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_small,
            minimum: check.value,
            type: "number",
            inclusive: check.inclusive,
            exact: false,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "max") {
        const tooBig = check.inclusive ? input.data > check.value : input.data >= check.value;
        if (tooBig) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_big,
            maximum: check.value,
            type: "number",
            inclusive: check.inclusive,
            exact: false,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "multipleOf") {
        if (floatSafeRemainder(input.data, check.value) !== 0) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.not_multiple_of,
            multipleOf: check.value,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "finite") {
        if (!Number.isFinite(input.data)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.not_finite,
            message: check.message
          });
          status.dirty();
        }
      } else {
        util.assertNever(check);
      }
    }
    return { status: status.value, value: input.data };
  }
  gte(value3, message3) {
    return this.setLimit("min", value3, true, errorUtil.toString(message3));
  }
  gt(value3, message3) {
    return this.setLimit("min", value3, false, errorUtil.toString(message3));
  }
  lte(value3, message3) {
    return this.setLimit("max", value3, true, errorUtil.toString(message3));
  }
  lt(value3, message3) {
    return this.setLimit("max", value3, false, errorUtil.toString(message3));
  }
  setLimit(kind, value3, inclusive, message3) {
    return new ZodNumber({
      ...this._def,
      checks: [
        ...this._def.checks,
        {
          kind,
          value: value3,
          inclusive,
          message: errorUtil.toString(message3)
        }
      ]
    });
  }
  _addCheck(check) {
    return new ZodNumber({
      ...this._def,
      checks: [...this._def.checks, check]
    });
  }
  int(message3) {
    return this._addCheck({
      kind: "int",
      message: errorUtil.toString(message3)
    });
  }
  positive(message3) {
    return this._addCheck({
      kind: "min",
      value: 0,
      inclusive: false,
      message: errorUtil.toString(message3)
    });
  }
  negative(message3) {
    return this._addCheck({
      kind: "max",
      value: 0,
      inclusive: false,
      message: errorUtil.toString(message3)
    });
  }
  nonpositive(message3) {
    return this._addCheck({
      kind: "max",
      value: 0,
      inclusive: true,
      message: errorUtil.toString(message3)
    });
  }
  nonnegative(message3) {
    return this._addCheck({
      kind: "min",
      value: 0,
      inclusive: true,
      message: errorUtil.toString(message3)
    });
  }
  multipleOf(value3, message3) {
    return this._addCheck({
      kind: "multipleOf",
      value: value3,
      message: errorUtil.toString(message3)
    });
  }
  finite(message3) {
    return this._addCheck({
      kind: "finite",
      message: errorUtil.toString(message3)
    });
  }
  safe(message3) {
    return this._addCheck({
      kind: "min",
      inclusive: true,
      value: Number.MIN_SAFE_INTEGER,
      message: errorUtil.toString(message3)
    })._addCheck({
      kind: "max",
      inclusive: true,
      value: Number.MAX_SAFE_INTEGER,
      message: errorUtil.toString(message3)
    });
  }
  get minValue() {
    let min = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "min") {
        if (min === null || ch.value > min)
          min = ch.value;
      }
    }
    return min;
  }
  get maxValue() {
    let max = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "max") {
        if (max === null || ch.value < max)
          max = ch.value;
      }
    }
    return max;
  }
  get isInt() {
    return !!this._def.checks.find((ch) => ch.kind === "int" || ch.kind === "multipleOf" && util.isInteger(ch.value));
  }
  get isFinite() {
    let max = null, min = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "finite" || ch.kind === "int" || ch.kind === "multipleOf") {
        return true;
      } else if (ch.kind === "min") {
        if (min === null || ch.value > min)
          min = ch.value;
      } else if (ch.kind === "max") {
        if (max === null || ch.value < max)
          max = ch.value;
      }
    }
    return Number.isFinite(min) && Number.isFinite(max);
  }
}
ZodNumber.create = (params) => {
  return new ZodNumber({
    checks: [],
    typeName: ZodFirstPartyTypeKind.ZodNumber,
    coerce: (params === null || params === void 0 ? void 0 : params.coerce) || false,
    ...processCreateParams(params)
  });
};
class ZodBigInt extends ZodType {
  static {
    __name(this, "ZodBigInt");
  }
  constructor() {
    super(...arguments);
    this.min = this.gte;
    this.max = this.lte;
  }
  _parse(input) {
    if (this._def.coerce) {
      try {
        input.data = BigInt(input.data);
      } catch (_a2) {
        return this._getInvalidInput(input);
      }
    }
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.bigint) {
      return this._getInvalidInput(input);
    }
    let ctx = void 0;
    const status = new ParseStatus();
    for (const check of this._def.checks) {
      if (check.kind === "min") {
        const tooSmall = check.inclusive ? input.data < check.value : input.data <= check.value;
        if (tooSmall) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_small,
            type: "bigint",
            minimum: check.value,
            inclusive: check.inclusive,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "max") {
        const tooBig = check.inclusive ? input.data > check.value : input.data >= check.value;
        if (tooBig) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_big,
            type: "bigint",
            maximum: check.value,
            inclusive: check.inclusive,
            message: check.message
          });
          status.dirty();
        }
      } else if (check.kind === "multipleOf") {
        if (input.data % check.value !== BigInt(0)) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.not_multiple_of,
            multipleOf: check.value,
            message: check.message
          });
          status.dirty();
        }
      } else {
        util.assertNever(check);
      }
    }
    return { status: status.value, value: input.data };
  }
  _getInvalidInput(input) {
    const ctx = this._getOrReturnCtx(input);
    addIssueToContext(ctx, {
      code: ZodIssueCode.invalid_type,
      expected: ZodParsedType.bigint,
      received: ctx.parsedType
    });
    return INVALID;
  }
  gte(value3, message3) {
    return this.setLimit("min", value3, true, errorUtil.toString(message3));
  }
  gt(value3, message3) {
    return this.setLimit("min", value3, false, errorUtil.toString(message3));
  }
  lte(value3, message3) {
    return this.setLimit("max", value3, true, errorUtil.toString(message3));
  }
  lt(value3, message3) {
    return this.setLimit("max", value3, false, errorUtil.toString(message3));
  }
  setLimit(kind, value3, inclusive, message3) {
    return new ZodBigInt({
      ...this._def,
      checks: [
        ...this._def.checks,
        {
          kind,
          value: value3,
          inclusive,
          message: errorUtil.toString(message3)
        }
      ]
    });
  }
  _addCheck(check) {
    return new ZodBigInt({
      ...this._def,
      checks: [...this._def.checks, check]
    });
  }
  positive(message3) {
    return this._addCheck({
      kind: "min",
      value: BigInt(0),
      inclusive: false,
      message: errorUtil.toString(message3)
    });
  }
  negative(message3) {
    return this._addCheck({
      kind: "max",
      value: BigInt(0),
      inclusive: false,
      message: errorUtil.toString(message3)
    });
  }
  nonpositive(message3) {
    return this._addCheck({
      kind: "max",
      value: BigInt(0),
      inclusive: true,
      message: errorUtil.toString(message3)
    });
  }
  nonnegative(message3) {
    return this._addCheck({
      kind: "min",
      value: BigInt(0),
      inclusive: true,
      message: errorUtil.toString(message3)
    });
  }
  multipleOf(value3, message3) {
    return this._addCheck({
      kind: "multipleOf",
      value: value3,
      message: errorUtil.toString(message3)
    });
  }
  get minValue() {
    let min = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "min") {
        if (min === null || ch.value > min)
          min = ch.value;
      }
    }
    return min;
  }
  get maxValue() {
    let max = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "max") {
        if (max === null || ch.value < max)
          max = ch.value;
      }
    }
    return max;
  }
}
ZodBigInt.create = (params) => {
  var _a2;
  return new ZodBigInt({
    checks: [],
    typeName: ZodFirstPartyTypeKind.ZodBigInt,
    coerce: (_a2 = params === null || params === void 0 ? void 0 : params.coerce) !== null && _a2 !== void 0 ? _a2 : false,
    ...processCreateParams(params)
  });
};
class ZodBoolean extends ZodType {
  static {
    __name(this, "ZodBoolean");
  }
  _parse(input) {
    if (this._def.coerce) {
      input.data = Boolean(input.data);
    }
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.boolean) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.boolean,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return OK(input.data);
  }
}
ZodBoolean.create = (params) => {
  return new ZodBoolean({
    typeName: ZodFirstPartyTypeKind.ZodBoolean,
    coerce: (params === null || params === void 0 ? void 0 : params.coerce) || false,
    ...processCreateParams(params)
  });
};
class ZodDate extends ZodType {
  static {
    __name(this, "ZodDate");
  }
  _parse(input) {
    if (this._def.coerce) {
      input.data = new Date(input.data);
    }
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.date) {
      const ctx2 = this._getOrReturnCtx(input);
      addIssueToContext(ctx2, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.date,
        received: ctx2.parsedType
      });
      return INVALID;
    }
    if (isNaN(input.data.getTime())) {
      const ctx2 = this._getOrReturnCtx(input);
      addIssueToContext(ctx2, {
        code: ZodIssueCode.invalid_date
      });
      return INVALID;
    }
    const status = new ParseStatus();
    let ctx = void 0;
    for (const check of this._def.checks) {
      if (check.kind === "min") {
        if (input.data.getTime() < check.value) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_small,
            message: check.message,
            inclusive: true,
            exact: false,
            minimum: check.value,
            type: "date"
          });
          status.dirty();
        }
      } else if (check.kind === "max") {
        if (input.data.getTime() > check.value) {
          ctx = this._getOrReturnCtx(input, ctx);
          addIssueToContext(ctx, {
            code: ZodIssueCode.too_big,
            message: check.message,
            inclusive: true,
            exact: false,
            maximum: check.value,
            type: "date"
          });
          status.dirty();
        }
      } else {
        util.assertNever(check);
      }
    }
    return {
      status: status.value,
      value: new Date(input.data.getTime())
    };
  }
  _addCheck(check) {
    return new ZodDate({
      ...this._def,
      checks: [...this._def.checks, check]
    });
  }
  min(minDate, message3) {
    return this._addCheck({
      kind: "min",
      value: minDate.getTime(),
      message: errorUtil.toString(message3)
    });
  }
  max(maxDate, message3) {
    return this._addCheck({
      kind: "max",
      value: maxDate.getTime(),
      message: errorUtil.toString(message3)
    });
  }
  get minDate() {
    let min = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "min") {
        if (min === null || ch.value > min)
          min = ch.value;
      }
    }
    return min != null ? new Date(min) : null;
  }
  get maxDate() {
    let max = null;
    for (const ch of this._def.checks) {
      if (ch.kind === "max") {
        if (max === null || ch.value < max)
          max = ch.value;
      }
    }
    return max != null ? new Date(max) : null;
  }
}
ZodDate.create = (params) => {
  return new ZodDate({
    checks: [],
    coerce: (params === null || params === void 0 ? void 0 : params.coerce) || false,
    typeName: ZodFirstPartyTypeKind.ZodDate,
    ...processCreateParams(params)
  });
};
class ZodSymbol extends ZodType {
  static {
    __name(this, "ZodSymbol");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.symbol) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.symbol,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return OK(input.data);
  }
}
ZodSymbol.create = (params) => {
  return new ZodSymbol({
    typeName: ZodFirstPartyTypeKind.ZodSymbol,
    ...processCreateParams(params)
  });
};
class ZodUndefined extends ZodType {
  static {
    __name(this, "ZodUndefined");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.undefined) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.undefined,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return OK(input.data);
  }
}
ZodUndefined.create = (params) => {
  return new ZodUndefined({
    typeName: ZodFirstPartyTypeKind.ZodUndefined,
    ...processCreateParams(params)
  });
};
class ZodNull extends ZodType {
  static {
    __name(this, "ZodNull");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.null) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.null,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return OK(input.data);
  }
}
ZodNull.create = (params) => {
  return new ZodNull({
    typeName: ZodFirstPartyTypeKind.ZodNull,
    ...processCreateParams(params)
  });
};
class ZodAny extends ZodType {
  static {
    __name(this, "ZodAny");
  }
  constructor() {
    super(...arguments);
    this._any = true;
  }
  _parse(input) {
    return OK(input.data);
  }
}
ZodAny.create = (params) => {
  return new ZodAny({
    typeName: ZodFirstPartyTypeKind.ZodAny,
    ...processCreateParams(params)
  });
};
class ZodUnknown extends ZodType {
  static {
    __name(this, "ZodUnknown");
  }
  constructor() {
    super(...arguments);
    this._unknown = true;
  }
  _parse(input) {
    return OK(input.data);
  }
}
ZodUnknown.create = (params) => {
  return new ZodUnknown({
    typeName: ZodFirstPartyTypeKind.ZodUnknown,
    ...processCreateParams(params)
  });
};
class ZodNever extends ZodType {
  static {
    __name(this, "ZodNever");
  }
  _parse(input) {
    const ctx = this._getOrReturnCtx(input);
    addIssueToContext(ctx, {
      code: ZodIssueCode.invalid_type,
      expected: ZodParsedType.never,
      received: ctx.parsedType
    });
    return INVALID;
  }
}
ZodNever.create = (params) => {
  return new ZodNever({
    typeName: ZodFirstPartyTypeKind.ZodNever,
    ...processCreateParams(params)
  });
};
class ZodVoid extends ZodType {
  static {
    __name(this, "ZodVoid");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.undefined) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.void,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return OK(input.data);
  }
}
ZodVoid.create = (params) => {
  return new ZodVoid({
    typeName: ZodFirstPartyTypeKind.ZodVoid,
    ...processCreateParams(params)
  });
};
class ZodArray extends ZodType {
  static {
    __name(this, "ZodArray");
  }
  _parse(input) {
    const { ctx, status } = this._processInputParams(input);
    const def2 = this._def;
    if (ctx.parsedType !== ZodParsedType.array) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.array,
        received: ctx.parsedType
      });
      return INVALID;
    }
    if (def2.exactLength !== null) {
      const tooBig = ctx.data.length > def2.exactLength.value;
      const tooSmall = ctx.data.length < def2.exactLength.value;
      if (tooBig || tooSmall) {
        addIssueToContext(ctx, {
          code: tooBig ? ZodIssueCode.too_big : ZodIssueCode.too_small,
          minimum: tooSmall ? def2.exactLength.value : void 0,
          maximum: tooBig ? def2.exactLength.value : void 0,
          type: "array",
          inclusive: true,
          exact: true,
          message: def2.exactLength.message
        });
        status.dirty();
      }
    }
    if (def2.minLength !== null) {
      if (ctx.data.length < def2.minLength.value) {
        addIssueToContext(ctx, {
          code: ZodIssueCode.too_small,
          minimum: def2.minLength.value,
          type: "array",
          inclusive: true,
          exact: false,
          message: def2.minLength.message
        });
        status.dirty();
      }
    }
    if (def2.maxLength !== null) {
      if (ctx.data.length > def2.maxLength.value) {
        addIssueToContext(ctx, {
          code: ZodIssueCode.too_big,
          maximum: def2.maxLength.value,
          type: "array",
          inclusive: true,
          exact: false,
          message: def2.maxLength.message
        });
        status.dirty();
      }
    }
    if (ctx.common.async) {
      return Promise.all([...ctx.data].map((item3, i2) => {
        return def2.type._parseAsync(new ParseInputLazyPath(ctx, item3, ctx.path, i2));
      })).then((result2) => {
        return ParseStatus.mergeArray(status, result2);
      });
    }
    const result = [...ctx.data].map((item3, i2) => {
      return def2.type._parseSync(new ParseInputLazyPath(ctx, item3, ctx.path, i2));
    });
    return ParseStatus.mergeArray(status, result);
  }
  get element() {
    return this._def.type;
  }
  min(minLength, message3) {
    return new ZodArray({
      ...this._def,
      minLength: { value: minLength, message: errorUtil.toString(message3) }
    });
  }
  max(maxLength, message3) {
    return new ZodArray({
      ...this._def,
      maxLength: { value: maxLength, message: errorUtil.toString(message3) }
    });
  }
  length(len, message3) {
    return new ZodArray({
      ...this._def,
      exactLength: { value: len, message: errorUtil.toString(message3) }
    });
  }
  nonempty(message3) {
    return this.min(1, message3);
  }
}
ZodArray.create = (schema2, params) => {
  return new ZodArray({
    type: schema2,
    minLength: null,
    maxLength: null,
    exactLength: null,
    typeName: ZodFirstPartyTypeKind.ZodArray,
    ...processCreateParams(params)
  });
};
function deepPartialify(schema2) {
  if (schema2 instanceof ZodObject) {
    const newShape = {};
    for (const key in schema2.shape) {
      const fieldSchema = schema2.shape[key];
      newShape[key] = ZodOptional.create(deepPartialify(fieldSchema));
    }
    return new ZodObject({
      ...schema2._def,
      shape: /* @__PURE__ */ __name(() => newShape, "shape")
    });
  } else if (schema2 instanceof ZodArray) {
    return new ZodArray({
      ...schema2._def,
      type: deepPartialify(schema2.element)
    });
  } else if (schema2 instanceof ZodOptional) {
    return ZodOptional.create(deepPartialify(schema2.unwrap()));
  } else if (schema2 instanceof ZodNullable) {
    return ZodNullable.create(deepPartialify(schema2.unwrap()));
  } else if (schema2 instanceof ZodTuple) {
    return ZodTuple.create(schema2.items.map((item3) => deepPartialify(item3)));
  } else {
    return schema2;
  }
}
__name(deepPartialify, "deepPartialify");
class ZodObject extends ZodType {
  static {
    __name(this, "ZodObject");
  }
  constructor() {
    super(...arguments);
    this._cached = null;
    this.nonstrict = this.passthrough;
    this.augment = this.extend;
  }
  _getCached() {
    if (this._cached !== null)
      return this._cached;
    const shape = this._def.shape();
    const keys2 = util.objectKeys(shape);
    return this._cached = { shape, keys: keys2 };
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.object) {
      const ctx2 = this._getOrReturnCtx(input);
      addIssueToContext(ctx2, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.object,
        received: ctx2.parsedType
      });
      return INVALID;
    }
    const { status, ctx } = this._processInputParams(input);
    const { shape, keys: shapeKeys } = this._getCached();
    const extraKeys = [];
    if (!(this._def.catchall instanceof ZodNever && this._def.unknownKeys === "strip")) {
      for (const key in ctx.data) {
        if (!shapeKeys.includes(key)) {
          extraKeys.push(key);
        }
      }
    }
    const pairs = [];
    for (const key of shapeKeys) {
      const keyValidator = shape[key];
      const value3 = ctx.data[key];
      pairs.push({
        key: { status: "valid", value: key },
        value: keyValidator._parse(new ParseInputLazyPath(ctx, value3, ctx.path, key)),
        alwaysSet: key in ctx.data
      });
    }
    if (this._def.catchall instanceof ZodNever) {
      const unknownKeys = this._def.unknownKeys;
      if (unknownKeys === "passthrough") {
        for (const key of extraKeys) {
          pairs.push({
            key: { status: "valid", value: key },
            value: { status: "valid", value: ctx.data[key] }
          });
        }
      } else if (unknownKeys === "strict") {
        if (extraKeys.length > 0) {
          addIssueToContext(ctx, {
            code: ZodIssueCode.unrecognized_keys,
            keys: extraKeys
          });
          status.dirty();
        }
      } else if (unknownKeys === "strip") ;
      else {
        throw new Error(`Internal ZodObject error: invalid unknownKeys value.`);
      }
    } else {
      const catchall = this._def.catchall;
      for (const key of extraKeys) {
        const value3 = ctx.data[key];
        pairs.push({
          key: { status: "valid", value: key },
          value: catchall._parse(
            new ParseInputLazyPath(ctx, value3, ctx.path, key)
            //, ctx.child(key), value, getParsedType(value)
          ),
          alwaysSet: key in ctx.data
        });
      }
    }
    if (ctx.common.async) {
      return Promise.resolve().then(async () => {
        const syncPairs = [];
        for (const pair of pairs) {
          const key = await pair.key;
          const value3 = await pair.value;
          syncPairs.push({
            key,
            value: value3,
            alwaysSet: pair.alwaysSet
          });
        }
        return syncPairs;
      }).then((syncPairs) => {
        return ParseStatus.mergeObjectSync(status, syncPairs);
      });
    } else {
      return ParseStatus.mergeObjectSync(status, pairs);
    }
  }
  get shape() {
    return this._def.shape();
  }
  strict(message3) {
    errorUtil.errToObj;
    return new ZodObject({
      ...this._def,
      unknownKeys: "strict",
      ...message3 !== void 0 ? {
        errorMap: /* @__PURE__ */ __name((issue, ctx) => {
          var _a2, _b, _c, _d;
          const defaultError = (_c = (_b = (_a2 = this._def).errorMap) === null || _b === void 0 ? void 0 : _b.call(_a2, issue, ctx).message) !== null && _c !== void 0 ? _c : ctx.defaultError;
          if (issue.code === "unrecognized_keys")
            return {
              message: (_d = errorUtil.errToObj(message3).message) !== null && _d !== void 0 ? _d : defaultError
            };
          return {
            message: defaultError
          };
        }, "errorMap")
      } : {}
    });
  }
  strip() {
    return new ZodObject({
      ...this._def,
      unknownKeys: "strip"
    });
  }
  passthrough() {
    return new ZodObject({
      ...this._def,
      unknownKeys: "passthrough"
    });
  }
  // const AugmentFactory =
  //   <Def extends ZodObjectDef>(def: Def) =>
  //   <Augmentation extends ZodRawShape>(
  //     augmentation: Augmentation
  //   ): ZodObject<
  //     extendShape<ReturnType<Def["shape"]>, Augmentation>,
  //     Def["unknownKeys"],
  //     Def["catchall"]
  //   > => {
  //     return new ZodObject({
  //       ...def,
  //       shape: () => ({
  //         ...def.shape(),
  //         ...augmentation,
  //       }),
  //     }) as any;
  //   };
  extend(augmentation) {
    return new ZodObject({
      ...this._def,
      shape: /* @__PURE__ */ __name(() => ({
        ...this._def.shape(),
        ...augmentation
      }), "shape")
    });
  }
  /**
   * Prior to zod@1.0.12 there was a bug in the
   * inferred type of merged objects. Please
   * upgrade if you are experiencing issues.
   */
  merge(merging) {
    const merged = new ZodObject({
      unknownKeys: merging._def.unknownKeys,
      catchall: merging._def.catchall,
      shape: /* @__PURE__ */ __name(() => ({
        ...this._def.shape(),
        ...merging._def.shape()
      }), "shape"),
      typeName: ZodFirstPartyTypeKind.ZodObject
    });
    return merged;
  }
  // merge<
  //   Incoming extends AnyZodObject,
  //   Augmentation extends Incoming["shape"],
  //   NewOutput extends {
  //     [k in keyof Augmentation | keyof Output]: k extends keyof Augmentation
  //       ? Augmentation[k]["_output"]
  //       : k extends keyof Output
  //       ? Output[k]
  //       : never;
  //   },
  //   NewInput extends {
  //     [k in keyof Augmentation | keyof Input]: k extends keyof Augmentation
  //       ? Augmentation[k]["_input"]
  //       : k extends keyof Input
  //       ? Input[k]
  //       : never;
  //   }
  // >(
  //   merging: Incoming
  // ): ZodObject<
  //   extendShape<T, ReturnType<Incoming["_def"]["shape"]>>,
  //   Incoming["_def"]["unknownKeys"],
  //   Incoming["_def"]["catchall"],
  //   NewOutput,
  //   NewInput
  // > {
  //   const merged: any = new ZodObject({
  //     unknownKeys: merging._def.unknownKeys,
  //     catchall: merging._def.catchall,
  //     shape: () =>
  //       objectUtil.mergeShapes(this._def.shape(), merging._def.shape()),
  //     typeName: ZodFirstPartyTypeKind.ZodObject,
  //   }) as any;
  //   return merged;
  // }
  setKey(key, schema2) {
    return this.augment({ [key]: schema2 });
  }
  // merge<Incoming extends AnyZodObject>(
  //   merging: Incoming
  // ): //ZodObject<T & Incoming["_shape"], UnknownKeys, Catchall> = (merging) => {
  // ZodObject<
  //   extendShape<T, ReturnType<Incoming["_def"]["shape"]>>,
  //   Incoming["_def"]["unknownKeys"],
  //   Incoming["_def"]["catchall"]
  // > {
  //   // const mergedShape = objectUtil.mergeShapes(
  //   //   this._def.shape(),
  //   //   merging._def.shape()
  //   // );
  //   const merged: any = new ZodObject({
  //     unknownKeys: merging._def.unknownKeys,
  //     catchall: merging._def.catchall,
  //     shape: () =>
  //       objectUtil.mergeShapes(this._def.shape(), merging._def.shape()),
  //     typeName: ZodFirstPartyTypeKind.ZodObject,
  //   }) as any;
  //   return merged;
  // }
  catchall(index2) {
    return new ZodObject({
      ...this._def,
      catchall: index2
    });
  }
  pick(mask3) {
    const shape = {};
    util.objectKeys(mask3).forEach((key) => {
      if (mask3[key] && this.shape[key]) {
        shape[key] = this.shape[key];
      }
    });
    return new ZodObject({
      ...this._def,
      shape: /* @__PURE__ */ __name(() => shape, "shape")
    });
  }
  omit(mask3) {
    const shape = {};
    util.objectKeys(this.shape).forEach((key) => {
      if (!mask3[key]) {
        shape[key] = this.shape[key];
      }
    });
    return new ZodObject({
      ...this._def,
      shape: /* @__PURE__ */ __name(() => shape, "shape")
    });
  }
  /**
   * @deprecated
   */
  deepPartial() {
    return deepPartialify(this);
  }
  partial(mask3) {
    const newShape = {};
    util.objectKeys(this.shape).forEach((key) => {
      const fieldSchema = this.shape[key];
      if (mask3 && !mask3[key]) {
        newShape[key] = fieldSchema;
      } else {
        newShape[key] = fieldSchema.optional();
      }
    });
    return new ZodObject({
      ...this._def,
      shape: /* @__PURE__ */ __name(() => newShape, "shape")
    });
  }
  required(mask3) {
    const newShape = {};
    util.objectKeys(this.shape).forEach((key) => {
      if (mask3 && !mask3[key]) {
        newShape[key] = this.shape[key];
      } else {
        const fieldSchema = this.shape[key];
        let newField = fieldSchema;
        while (newField instanceof ZodOptional) {
          newField = newField._def.innerType;
        }
        newShape[key] = newField;
      }
    });
    return new ZodObject({
      ...this._def,
      shape: /* @__PURE__ */ __name(() => newShape, "shape")
    });
  }
  keyof() {
    return createZodEnum(util.objectKeys(this.shape));
  }
}
ZodObject.create = (shape, params) => {
  return new ZodObject({
    shape: /* @__PURE__ */ __name(() => shape, "shape"),
    unknownKeys: "strip",
    catchall: ZodNever.create(),
    typeName: ZodFirstPartyTypeKind.ZodObject,
    ...processCreateParams(params)
  });
};
ZodObject.strictCreate = (shape, params) => {
  return new ZodObject({
    shape: /* @__PURE__ */ __name(() => shape, "shape"),
    unknownKeys: "strict",
    catchall: ZodNever.create(),
    typeName: ZodFirstPartyTypeKind.ZodObject,
    ...processCreateParams(params)
  });
};
ZodObject.lazycreate = (shape, params) => {
  return new ZodObject({
    shape,
    unknownKeys: "strip",
    catchall: ZodNever.create(),
    typeName: ZodFirstPartyTypeKind.ZodObject,
    ...processCreateParams(params)
  });
};
class ZodUnion extends ZodType {
  static {
    __name(this, "ZodUnion");
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    const options5 = this._def.options;
    function handleResults(results) {
      for (const result of results) {
        if (result.result.status === "valid") {
          return result.result;
        }
      }
      for (const result of results) {
        if (result.result.status === "dirty") {
          ctx.common.issues.push(...result.ctx.common.issues);
          return result.result;
        }
      }
      const unionErrors = results.map((result) => new ZodError(result.ctx.common.issues));
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_union,
        unionErrors
      });
      return INVALID;
    }
    __name(handleResults, "handleResults");
    if (ctx.common.async) {
      return Promise.all(options5.map(async (option5) => {
        const childCtx = {
          ...ctx,
          common: {
            ...ctx.common,
            issues: []
          },
          parent: null
        };
        return {
          result: await option5._parseAsync({
            data: ctx.data,
            path: ctx.path,
            parent: childCtx
          }),
          ctx: childCtx
        };
      })).then(handleResults);
    } else {
      let dirty = void 0;
      const issues = [];
      for (const option5 of options5) {
        const childCtx = {
          ...ctx,
          common: {
            ...ctx.common,
            issues: []
          },
          parent: null
        };
        const result = option5._parseSync({
          data: ctx.data,
          path: ctx.path,
          parent: childCtx
        });
        if (result.status === "valid") {
          return result;
        } else if (result.status === "dirty" && !dirty) {
          dirty = { result, ctx: childCtx };
        }
        if (childCtx.common.issues.length) {
          issues.push(childCtx.common.issues);
        }
      }
      if (dirty) {
        ctx.common.issues.push(...dirty.ctx.common.issues);
        return dirty.result;
      }
      const unionErrors = issues.map((issues2) => new ZodError(issues2));
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_union,
        unionErrors
      });
      return INVALID;
    }
  }
  get options() {
    return this._def.options;
  }
}
ZodUnion.create = (types, params) => {
  return new ZodUnion({
    options: types,
    typeName: ZodFirstPartyTypeKind.ZodUnion,
    ...processCreateParams(params)
  });
};
const getDiscriminator = /* @__PURE__ */ __name((type) => {
  if (type instanceof ZodLazy) {
    return getDiscriminator(type.schema);
  } else if (type instanceof ZodEffects) {
    return getDiscriminator(type.innerType());
  } else if (type instanceof ZodLiteral) {
    return [type.value];
  } else if (type instanceof ZodEnum) {
    return type.options;
  } else if (type instanceof ZodNativeEnum) {
    return util.objectValues(type.enum);
  } else if (type instanceof ZodDefault) {
    return getDiscriminator(type._def.innerType);
  } else if (type instanceof ZodUndefined) {
    return [void 0];
  } else if (type instanceof ZodNull) {
    return [null];
  } else if (type instanceof ZodOptional) {
    return [void 0, ...getDiscriminator(type.unwrap())];
  } else if (type instanceof ZodNullable) {
    return [null, ...getDiscriminator(type.unwrap())];
  } else if (type instanceof ZodBranded) {
    return getDiscriminator(type.unwrap());
  } else if (type instanceof ZodReadonly) {
    return getDiscriminator(type.unwrap());
  } else if (type instanceof ZodCatch) {
    return getDiscriminator(type._def.innerType);
  } else {
    return [];
  }
}, "getDiscriminator");
class ZodDiscriminatedUnion extends ZodType {
  static {
    __name(this, "ZodDiscriminatedUnion");
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.object) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.object,
        received: ctx.parsedType
      });
      return INVALID;
    }
    const discriminator = this.discriminator;
    const discriminatorValue = ctx.data[discriminator];
    const option5 = this.optionsMap.get(discriminatorValue);
    if (!option5) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_union_discriminator,
        options: Array.from(this.optionsMap.keys()),
        path: [discriminator]
      });
      return INVALID;
    }
    if (ctx.common.async) {
      return option5._parseAsync({
        data: ctx.data,
        path: ctx.path,
        parent: ctx
      });
    } else {
      return option5._parseSync({
        data: ctx.data,
        path: ctx.path,
        parent: ctx
      });
    }
  }
  get discriminator() {
    return this._def.discriminator;
  }
  get options() {
    return this._def.options;
  }
  get optionsMap() {
    return this._def.optionsMap;
  }
  /**
   * The constructor of the discriminated union schema. Its behaviour is very similar to that of the normal z.union() constructor.
   * However, it only allows a union of objects, all of which need to share a discriminator property. This property must
   * have a different value for each object in the union.
   * @param discriminator the name of the discriminator property
   * @param types an array of object schemas
   * @param params
   */
  static create(discriminator, options5, params) {
    const optionsMap = /* @__PURE__ */ new Map();
    for (const type of options5) {
      const discriminatorValues = getDiscriminator(type.shape[discriminator]);
      if (!discriminatorValues.length) {
        throw new Error(`A discriminator value for key \`${discriminator}\` could not be extracted from all schema options`);
      }
      for (const value3 of discriminatorValues) {
        if (optionsMap.has(value3)) {
          throw new Error(`Discriminator property ${String(discriminator)} has duplicate value ${String(value3)}`);
        }
        optionsMap.set(value3, type);
      }
    }
    return new ZodDiscriminatedUnion({
      typeName: ZodFirstPartyTypeKind.ZodDiscriminatedUnion,
      discriminator,
      options: options5,
      optionsMap,
      ...processCreateParams(params)
    });
  }
}
function mergeValues(a2, b2) {
  const aType = getParsedType(a2);
  const bType = getParsedType(b2);
  if (a2 === b2) {
    return { valid: true, data: a2 };
  } else if (aType === ZodParsedType.object && bType === ZodParsedType.object) {
    const bKeys = util.objectKeys(b2);
    const sharedKeys = util.objectKeys(a2).filter((key) => bKeys.indexOf(key) !== -1);
    const newObj = { ...a2, ...b2 };
    for (const key of sharedKeys) {
      const sharedValue = mergeValues(a2[key], b2[key]);
      if (!sharedValue.valid) {
        return { valid: false };
      }
      newObj[key] = sharedValue.data;
    }
    return { valid: true, data: newObj };
  } else if (aType === ZodParsedType.array && bType === ZodParsedType.array) {
    if (a2.length !== b2.length) {
      return { valid: false };
    }
    const newArray = [];
    for (let index2 = 0; index2 < a2.length; index2++) {
      const itemA = a2[index2];
      const itemB = b2[index2];
      const sharedValue = mergeValues(itemA, itemB);
      if (!sharedValue.valid) {
        return { valid: false };
      }
      newArray.push(sharedValue.data);
    }
    return { valid: true, data: newArray };
  } else if (aType === ZodParsedType.date && bType === ZodParsedType.date && +a2 === +b2) {
    return { valid: true, data: a2 };
  } else {
    return { valid: false };
  }
}
__name(mergeValues, "mergeValues");
class ZodIntersection extends ZodType {
  static {
    __name(this, "ZodIntersection");
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    const handleParsed = /* @__PURE__ */ __name((parsedLeft, parsedRight) => {
      if (isAborted(parsedLeft) || isAborted(parsedRight)) {
        return INVALID;
      }
      const merged = mergeValues(parsedLeft.value, parsedRight.value);
      if (!merged.valid) {
        addIssueToContext(ctx, {
          code: ZodIssueCode.invalid_intersection_types
        });
        return INVALID;
      }
      if (isDirty(parsedLeft) || isDirty(parsedRight)) {
        status.dirty();
      }
      return { status: status.value, value: merged.data };
    }, "handleParsed");
    if (ctx.common.async) {
      return Promise.all([
        this._def.left._parseAsync({
          data: ctx.data,
          path: ctx.path,
          parent: ctx
        }),
        this._def.right._parseAsync({
          data: ctx.data,
          path: ctx.path,
          parent: ctx
        })
      ]).then(([left, right]) => handleParsed(left, right));
    } else {
      return handleParsed(this._def.left._parseSync({
        data: ctx.data,
        path: ctx.path,
        parent: ctx
      }), this._def.right._parseSync({
        data: ctx.data,
        path: ctx.path,
        parent: ctx
      }));
    }
  }
}
ZodIntersection.create = (left, right, params) => {
  return new ZodIntersection({
    left,
    right,
    typeName: ZodFirstPartyTypeKind.ZodIntersection,
    ...processCreateParams(params)
  });
};
class ZodTuple extends ZodType {
  static {
    __name(this, "ZodTuple");
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.array) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.array,
        received: ctx.parsedType
      });
      return INVALID;
    }
    if (ctx.data.length < this._def.items.length) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.too_small,
        minimum: this._def.items.length,
        inclusive: true,
        exact: false,
        type: "array"
      });
      return INVALID;
    }
    const rest = this._def.rest;
    if (!rest && ctx.data.length > this._def.items.length) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.too_big,
        maximum: this._def.items.length,
        inclusive: true,
        exact: false,
        type: "array"
      });
      status.dirty();
    }
    const items2 = [...ctx.data].map((item3, itemIndex) => {
      const schema2 = this._def.items[itemIndex] || this._def.rest;
      if (!schema2)
        return null;
      return schema2._parse(new ParseInputLazyPath(ctx, item3, ctx.path, itemIndex));
    }).filter((x2) => !!x2);
    if (ctx.common.async) {
      return Promise.all(items2).then((results) => {
        return ParseStatus.mergeArray(status, results);
      });
    } else {
      return ParseStatus.mergeArray(status, items2);
    }
  }
  get items() {
    return this._def.items;
  }
  rest(rest) {
    return new ZodTuple({
      ...this._def,
      rest
    });
  }
}
ZodTuple.create = (schemas, params) => {
  if (!Array.isArray(schemas)) {
    throw new Error("You must pass an array of schemas to z.tuple([ ... ])");
  }
  return new ZodTuple({
    items: schemas,
    typeName: ZodFirstPartyTypeKind.ZodTuple,
    rest: null,
    ...processCreateParams(params)
  });
};
class ZodRecord extends ZodType {
  static {
    __name(this, "ZodRecord");
  }
  get keySchema() {
    return this._def.keyType;
  }
  get valueSchema() {
    return this._def.valueType;
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.object) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.object,
        received: ctx.parsedType
      });
      return INVALID;
    }
    const pairs = [];
    const keyType = this._def.keyType;
    const valueType = this._def.valueType;
    for (const key in ctx.data) {
      pairs.push({
        key: keyType._parse(new ParseInputLazyPath(ctx, key, ctx.path, key)),
        value: valueType._parse(new ParseInputLazyPath(ctx, ctx.data[key], ctx.path, key)),
        alwaysSet: key in ctx.data
      });
    }
    if (ctx.common.async) {
      return ParseStatus.mergeObjectAsync(status, pairs);
    } else {
      return ParseStatus.mergeObjectSync(status, pairs);
    }
  }
  get element() {
    return this._def.valueType;
  }
  static create(first2, second, third) {
    if (second instanceof ZodType) {
      return new ZodRecord({
        keyType: first2,
        valueType: second,
        typeName: ZodFirstPartyTypeKind.ZodRecord,
        ...processCreateParams(third)
      });
    }
    return new ZodRecord({
      keyType: ZodString.create(),
      valueType: first2,
      typeName: ZodFirstPartyTypeKind.ZodRecord,
      ...processCreateParams(second)
    });
  }
}
class ZodMap extends ZodType {
  static {
    __name(this, "ZodMap");
  }
  get keySchema() {
    return this._def.keyType;
  }
  get valueSchema() {
    return this._def.valueType;
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.map) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.map,
        received: ctx.parsedType
      });
      return INVALID;
    }
    const keyType = this._def.keyType;
    const valueType = this._def.valueType;
    const pairs = [...ctx.data.entries()].map(([key, value3], index2) => {
      return {
        key: keyType._parse(new ParseInputLazyPath(ctx, key, ctx.path, [index2, "key"])),
        value: valueType._parse(new ParseInputLazyPath(ctx, value3, ctx.path, [index2, "value"]))
      };
    });
    if (ctx.common.async) {
      const finalMap = /* @__PURE__ */ new Map();
      return Promise.resolve().then(async () => {
        for (const pair of pairs) {
          const key = await pair.key;
          const value3 = await pair.value;
          if (key.status === "aborted" || value3.status === "aborted") {
            return INVALID;
          }
          if (key.status === "dirty" || value3.status === "dirty") {
            status.dirty();
          }
          finalMap.set(key.value, value3.value);
        }
        return { status: status.value, value: finalMap };
      });
    } else {
      const finalMap = /* @__PURE__ */ new Map();
      for (const pair of pairs) {
        const key = pair.key;
        const value3 = pair.value;
        if (key.status === "aborted" || value3.status === "aborted") {
          return INVALID;
        }
        if (key.status === "dirty" || value3.status === "dirty") {
          status.dirty();
        }
        finalMap.set(key.value, value3.value);
      }
      return { status: status.value, value: finalMap };
    }
  }
}
ZodMap.create = (keyType, valueType, params) => {
  return new ZodMap({
    valueType,
    keyType,
    typeName: ZodFirstPartyTypeKind.ZodMap,
    ...processCreateParams(params)
  });
};
class ZodSet extends ZodType {
  static {
    __name(this, "ZodSet");
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.set) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.set,
        received: ctx.parsedType
      });
      return INVALID;
    }
    const def2 = this._def;
    if (def2.minSize !== null) {
      if (ctx.data.size < def2.minSize.value) {
        addIssueToContext(ctx, {
          code: ZodIssueCode.too_small,
          minimum: def2.minSize.value,
          type: "set",
          inclusive: true,
          exact: false,
          message: def2.minSize.message
        });
        status.dirty();
      }
    }
    if (def2.maxSize !== null) {
      if (ctx.data.size > def2.maxSize.value) {
        addIssueToContext(ctx, {
          code: ZodIssueCode.too_big,
          maximum: def2.maxSize.value,
          type: "set",
          inclusive: true,
          exact: false,
          message: def2.maxSize.message
        });
        status.dirty();
      }
    }
    const valueType = this._def.valueType;
    function finalizeSet(elements2) {
      const parsedSet = /* @__PURE__ */ new Set();
      for (const element of elements2) {
        if (element.status === "aborted")
          return INVALID;
        if (element.status === "dirty")
          status.dirty();
        parsedSet.add(element.value);
      }
      return { status: status.value, value: parsedSet };
    }
    __name(finalizeSet, "finalizeSet");
    const elements = [...ctx.data.values()].map((item3, i2) => valueType._parse(new ParseInputLazyPath(ctx, item3, ctx.path, i2)));
    if (ctx.common.async) {
      return Promise.all(elements).then((elements2) => finalizeSet(elements2));
    } else {
      return finalizeSet(elements);
    }
  }
  min(minSize, message3) {
    return new ZodSet({
      ...this._def,
      minSize: { value: minSize, message: errorUtil.toString(message3) }
    });
  }
  max(maxSize, message3) {
    return new ZodSet({
      ...this._def,
      maxSize: { value: maxSize, message: errorUtil.toString(message3) }
    });
  }
  size(size, message3) {
    return this.min(size, message3).max(size, message3);
  }
  nonempty(message3) {
    return this.min(1, message3);
  }
}
ZodSet.create = (valueType, params) => {
  return new ZodSet({
    valueType,
    minSize: null,
    maxSize: null,
    typeName: ZodFirstPartyTypeKind.ZodSet,
    ...processCreateParams(params)
  });
};
class ZodFunction extends ZodType {
  static {
    __name(this, "ZodFunction");
  }
  constructor() {
    super(...arguments);
    this.validate = this.implement;
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.function) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.function,
        received: ctx.parsedType
      });
      return INVALID;
    }
    function makeArgsIssue(args, error2) {
      return makeIssue({
        data: args,
        path: ctx.path,
        errorMaps: [
          ctx.common.contextualErrorMap,
          ctx.schemaErrorMap,
          getErrorMap(),
          errorMap$1
        ].filter((x2) => !!x2),
        issueData: {
          code: ZodIssueCode.invalid_arguments,
          argumentsError: error2
        }
      });
    }
    __name(makeArgsIssue, "makeArgsIssue");
    function makeReturnsIssue(returns, error2) {
      return makeIssue({
        data: returns,
        path: ctx.path,
        errorMaps: [
          ctx.common.contextualErrorMap,
          ctx.schemaErrorMap,
          getErrorMap(),
          errorMap$1
        ].filter((x2) => !!x2),
        issueData: {
          code: ZodIssueCode.invalid_return_type,
          returnTypeError: error2
        }
      });
    }
    __name(makeReturnsIssue, "makeReturnsIssue");
    const params = { errorMap: ctx.common.contextualErrorMap };
    const fn = ctx.data;
    if (this._def.returns instanceof ZodPromise) {
      const me = this;
      return OK(async function(...args) {
        const error2 = new ZodError([]);
        const parsedArgs = await me._def.args.parseAsync(args, params).catch((e2) => {
          error2.addIssue(makeArgsIssue(args, e2));
          throw error2;
        });
        const result = await Reflect.apply(fn, this, parsedArgs);
        const parsedReturns = await me._def.returns._def.type.parseAsync(result, params).catch((e2) => {
          error2.addIssue(makeReturnsIssue(result, e2));
          throw error2;
        });
        return parsedReturns;
      });
    } else {
      const me = this;
      return OK(function(...args) {
        const parsedArgs = me._def.args.safeParse(args, params);
        if (!parsedArgs.success) {
          throw new ZodError([makeArgsIssue(args, parsedArgs.error)]);
        }
        const result = Reflect.apply(fn, this, parsedArgs.data);
        const parsedReturns = me._def.returns.safeParse(result, params);
        if (!parsedReturns.success) {
          throw new ZodError([makeReturnsIssue(result, parsedReturns.error)]);
        }
        return parsedReturns.data;
      });
    }
  }
  parameters() {
    return this._def.args;
  }
  returnType() {
    return this._def.returns;
  }
  args(...items2) {
    return new ZodFunction({
      ...this._def,
      args: ZodTuple.create(items2).rest(ZodUnknown.create())
    });
  }
  returns(returnType) {
    return new ZodFunction({
      ...this._def,
      returns: returnType
    });
  }
  implement(func) {
    const validatedFunc = this.parse(func);
    return validatedFunc;
  }
  strictImplement(func) {
    const validatedFunc = this.parse(func);
    return validatedFunc;
  }
  static create(args, returns, params) {
    return new ZodFunction({
      args: args ? args : ZodTuple.create([]).rest(ZodUnknown.create()),
      returns: returns || ZodUnknown.create(),
      typeName: ZodFirstPartyTypeKind.ZodFunction,
      ...processCreateParams(params)
    });
  }
}
class ZodLazy extends ZodType {
  static {
    __name(this, "ZodLazy");
  }
  get schema() {
    return this._def.getter();
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    const lazySchema = this._def.getter();
    return lazySchema._parse({ data: ctx.data, path: ctx.path, parent: ctx });
  }
}
ZodLazy.create = (getter, params) => {
  return new ZodLazy({
    getter,
    typeName: ZodFirstPartyTypeKind.ZodLazy,
    ...processCreateParams(params)
  });
};
class ZodLiteral extends ZodType {
  static {
    __name(this, "ZodLiteral");
  }
  _parse(input) {
    if (input.data !== this._def.value) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        received: ctx.data,
        code: ZodIssueCode.invalid_literal,
        expected: this._def.value
      });
      return INVALID;
    }
    return { status: "valid", value: input.data };
  }
  get value() {
    return this._def.value;
  }
}
ZodLiteral.create = (value3, params) => {
  return new ZodLiteral({
    value: value3,
    typeName: ZodFirstPartyTypeKind.ZodLiteral,
    ...processCreateParams(params)
  });
};
function createZodEnum(values, params) {
  return new ZodEnum({
    values,
    typeName: ZodFirstPartyTypeKind.ZodEnum,
    ...processCreateParams(params)
  });
}
__name(createZodEnum, "createZodEnum");
class ZodEnum extends ZodType {
  static {
    __name(this, "ZodEnum");
  }
  constructor() {
    super(...arguments);
    _ZodEnum_cache.set(this, void 0);
  }
  _parse(input) {
    if (typeof input.data !== "string") {
      const ctx = this._getOrReturnCtx(input);
      const expectedValues = this._def.values;
      addIssueToContext(ctx, {
        expected: util.joinValues(expectedValues),
        received: ctx.parsedType,
        code: ZodIssueCode.invalid_type
      });
      return INVALID;
    }
    if (!__classPrivateFieldGet(this, _ZodEnum_cache, "f")) {
      __classPrivateFieldSet(this, _ZodEnum_cache, new Set(this._def.values), "f");
    }
    if (!__classPrivateFieldGet(this, _ZodEnum_cache, "f").has(input.data)) {
      const ctx = this._getOrReturnCtx(input);
      const expectedValues = this._def.values;
      addIssueToContext(ctx, {
        received: ctx.data,
        code: ZodIssueCode.invalid_enum_value,
        options: expectedValues
      });
      return INVALID;
    }
    return OK(input.data);
  }
  get options() {
    return this._def.values;
  }
  get enum() {
    const enumValues = {};
    for (const val of this._def.values) {
      enumValues[val] = val;
    }
    return enumValues;
  }
  get Values() {
    const enumValues = {};
    for (const val of this._def.values) {
      enumValues[val] = val;
    }
    return enumValues;
  }
  get Enum() {
    const enumValues = {};
    for (const val of this._def.values) {
      enumValues[val] = val;
    }
    return enumValues;
  }
  extract(values, newDef = this._def) {
    return ZodEnum.create(values, {
      ...this._def,
      ...newDef
    });
  }
  exclude(values, newDef = this._def) {
    return ZodEnum.create(this.options.filter((opt) => !values.includes(opt)), {
      ...this._def,
      ...newDef
    });
  }
}
_ZodEnum_cache = /* @__PURE__ */ new WeakMap();
ZodEnum.create = createZodEnum;
class ZodNativeEnum extends ZodType {
  static {
    __name(this, "ZodNativeEnum");
  }
  constructor() {
    super(...arguments);
    _ZodNativeEnum_cache.set(this, void 0);
  }
  _parse(input) {
    const nativeEnumValues = util.getValidEnumValues(this._def.values);
    const ctx = this._getOrReturnCtx(input);
    if (ctx.parsedType !== ZodParsedType.string && ctx.parsedType !== ZodParsedType.number) {
      const expectedValues = util.objectValues(nativeEnumValues);
      addIssueToContext(ctx, {
        expected: util.joinValues(expectedValues),
        received: ctx.parsedType,
        code: ZodIssueCode.invalid_type
      });
      return INVALID;
    }
    if (!__classPrivateFieldGet(this, _ZodNativeEnum_cache, "f")) {
      __classPrivateFieldSet(this, _ZodNativeEnum_cache, new Set(util.getValidEnumValues(this._def.values)), "f");
    }
    if (!__classPrivateFieldGet(this, _ZodNativeEnum_cache, "f").has(input.data)) {
      const expectedValues = util.objectValues(nativeEnumValues);
      addIssueToContext(ctx, {
        received: ctx.data,
        code: ZodIssueCode.invalid_enum_value,
        options: expectedValues
      });
      return INVALID;
    }
    return OK(input.data);
  }
  get enum() {
    return this._def.values;
  }
}
_ZodNativeEnum_cache = /* @__PURE__ */ new WeakMap();
ZodNativeEnum.create = (values, params) => {
  return new ZodNativeEnum({
    values,
    typeName: ZodFirstPartyTypeKind.ZodNativeEnum,
    ...processCreateParams(params)
  });
};
class ZodPromise extends ZodType {
  static {
    __name(this, "ZodPromise");
  }
  unwrap() {
    return this._def.type;
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    if (ctx.parsedType !== ZodParsedType.promise && ctx.common.async === false) {
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.promise,
        received: ctx.parsedType
      });
      return INVALID;
    }
    const promisified = ctx.parsedType === ZodParsedType.promise ? ctx.data : Promise.resolve(ctx.data);
    return OK(promisified.then((data30) => {
      return this._def.type.parseAsync(data30, {
        path: ctx.path,
        errorMap: ctx.common.contextualErrorMap
      });
    }));
  }
}
ZodPromise.create = (schema2, params) => {
  return new ZodPromise({
    type: schema2,
    typeName: ZodFirstPartyTypeKind.ZodPromise,
    ...processCreateParams(params)
  });
};
class ZodEffects extends ZodType {
  static {
    __name(this, "ZodEffects");
  }
  innerType() {
    return this._def.schema;
  }
  sourceType() {
    return this._def.schema._def.typeName === ZodFirstPartyTypeKind.ZodEffects ? this._def.schema.sourceType() : this._def.schema;
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    const effect2 = this._def.effect || null;
    const checkCtx = {
      addIssue: /* @__PURE__ */ __name((arg) => {
        addIssueToContext(ctx, arg);
        if (arg.fatal) {
          status.abort();
        } else {
          status.dirty();
        }
      }, "addIssue"),
      get path() {
        return ctx.path;
      }
    };
    checkCtx.addIssue = checkCtx.addIssue.bind(checkCtx);
    if (effect2.type === "preprocess") {
      const processed = effect2.transform(ctx.data, checkCtx);
      if (ctx.common.async) {
        return Promise.resolve(processed).then(async (processed2) => {
          if (status.value === "aborted")
            return INVALID;
          const result = await this._def.schema._parseAsync({
            data: processed2,
            path: ctx.path,
            parent: ctx
          });
          if (result.status === "aborted")
            return INVALID;
          if (result.status === "dirty")
            return DIRTY(result.value);
          if (status.value === "dirty")
            return DIRTY(result.value);
          return result;
        });
      } else {
        if (status.value === "aborted")
          return INVALID;
        const result = this._def.schema._parseSync({
          data: processed,
          path: ctx.path,
          parent: ctx
        });
        if (result.status === "aborted")
          return INVALID;
        if (result.status === "dirty")
          return DIRTY(result.value);
        if (status.value === "dirty")
          return DIRTY(result.value);
        return result;
      }
    }
    if (effect2.type === "refinement") {
      const executeRefinement = /* @__PURE__ */ __name((acc) => {
        const result = effect2.refinement(acc, checkCtx);
        if (ctx.common.async) {
          return Promise.resolve(result);
        }
        if (result instanceof Promise) {
          throw new Error("Async refinement encountered during synchronous parse operation. Use .parseAsync instead.");
        }
        return acc;
      }, "executeRefinement");
      if (ctx.common.async === false) {
        const inner = this._def.schema._parseSync({
          data: ctx.data,
          path: ctx.path,
          parent: ctx
        });
        if (inner.status === "aborted")
          return INVALID;
        if (inner.status === "dirty")
          status.dirty();
        executeRefinement(inner.value);
        return { status: status.value, value: inner.value };
      } else {
        return this._def.schema._parseAsync({ data: ctx.data, path: ctx.path, parent: ctx }).then((inner) => {
          if (inner.status === "aborted")
            return INVALID;
          if (inner.status === "dirty")
            status.dirty();
          return executeRefinement(inner.value).then(() => {
            return { status: status.value, value: inner.value };
          });
        });
      }
    }
    if (effect2.type === "transform") {
      if (ctx.common.async === false) {
        const base2 = this._def.schema._parseSync({
          data: ctx.data,
          path: ctx.path,
          parent: ctx
        });
        if (!isValid(base2))
          return base2;
        const result = effect2.transform(base2.value, checkCtx);
        if (result instanceof Promise) {
          throw new Error(`Asynchronous transform encountered during synchronous parse operation. Use .parseAsync instead.`);
        }
        return { status: status.value, value: result };
      } else {
        return this._def.schema._parseAsync({ data: ctx.data, path: ctx.path, parent: ctx }).then((base2) => {
          if (!isValid(base2))
            return base2;
          return Promise.resolve(effect2.transform(base2.value, checkCtx)).then((result) => ({ status: status.value, value: result }));
        });
      }
    }
    util.assertNever(effect2);
  }
}
ZodEffects.create = (schema2, effect2, params) => {
  return new ZodEffects({
    schema: schema2,
    typeName: ZodFirstPartyTypeKind.ZodEffects,
    effect: effect2,
    ...processCreateParams(params)
  });
};
ZodEffects.createWithPreprocess = (preprocess, schema2, params) => {
  return new ZodEffects({
    schema: schema2,
    effect: { type: "preprocess", transform: preprocess },
    typeName: ZodFirstPartyTypeKind.ZodEffects,
    ...processCreateParams(params)
  });
};
class ZodOptional extends ZodType {
  static {
    __name(this, "ZodOptional");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType === ZodParsedType.undefined) {
      return OK(void 0);
    }
    return this._def.innerType._parse(input);
  }
  unwrap() {
    return this._def.innerType;
  }
}
ZodOptional.create = (type, params) => {
  return new ZodOptional({
    innerType: type,
    typeName: ZodFirstPartyTypeKind.ZodOptional,
    ...processCreateParams(params)
  });
};
class ZodNullable extends ZodType {
  static {
    __name(this, "ZodNullable");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType === ZodParsedType.null) {
      return OK(null);
    }
    return this._def.innerType._parse(input);
  }
  unwrap() {
    return this._def.innerType;
  }
}
ZodNullable.create = (type, params) => {
  return new ZodNullable({
    innerType: type,
    typeName: ZodFirstPartyTypeKind.ZodNullable,
    ...processCreateParams(params)
  });
};
class ZodDefault extends ZodType {
  static {
    __name(this, "ZodDefault");
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    let data30 = ctx.data;
    if (ctx.parsedType === ZodParsedType.undefined) {
      data30 = this._def.defaultValue();
    }
    return this._def.innerType._parse({
      data: data30,
      path: ctx.path,
      parent: ctx
    });
  }
  removeDefault() {
    return this._def.innerType;
  }
}
ZodDefault.create = (type, params) => {
  return new ZodDefault({
    innerType: type,
    typeName: ZodFirstPartyTypeKind.ZodDefault,
    defaultValue: typeof params.default === "function" ? params.default : () => params.default,
    ...processCreateParams(params)
  });
};
class ZodCatch extends ZodType {
  static {
    __name(this, "ZodCatch");
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    const newCtx = {
      ...ctx,
      common: {
        ...ctx.common,
        issues: []
      }
    };
    const result = this._def.innerType._parse({
      data: newCtx.data,
      path: newCtx.path,
      parent: {
        ...newCtx
      }
    });
    if (isAsync(result)) {
      return result.then((result2) => {
        return {
          status: "valid",
          value: result2.status === "valid" ? result2.value : this._def.catchValue({
            get error() {
              return new ZodError(newCtx.common.issues);
            },
            input: newCtx.data
          })
        };
      });
    } else {
      return {
        status: "valid",
        value: result.status === "valid" ? result.value : this._def.catchValue({
          get error() {
            return new ZodError(newCtx.common.issues);
          },
          input: newCtx.data
        })
      };
    }
  }
  removeCatch() {
    return this._def.innerType;
  }
}
ZodCatch.create = (type, params) => {
  return new ZodCatch({
    innerType: type,
    typeName: ZodFirstPartyTypeKind.ZodCatch,
    catchValue: typeof params.catch === "function" ? params.catch : () => params.catch,
    ...processCreateParams(params)
  });
};
class ZodNaN extends ZodType {
  static {
    __name(this, "ZodNaN");
  }
  _parse(input) {
    const parsedType = this._getType(input);
    if (parsedType !== ZodParsedType.nan) {
      const ctx = this._getOrReturnCtx(input);
      addIssueToContext(ctx, {
        code: ZodIssueCode.invalid_type,
        expected: ZodParsedType.nan,
        received: ctx.parsedType
      });
      return INVALID;
    }
    return { status: "valid", value: input.data };
  }
}
ZodNaN.create = (params) => {
  return new ZodNaN({
    typeName: ZodFirstPartyTypeKind.ZodNaN,
    ...processCreateParams(params)
  });
};
const BRAND = Symbol("zod_brand");
class ZodBranded extends ZodType {
  static {
    __name(this, "ZodBranded");
  }
  _parse(input) {
    const { ctx } = this._processInputParams(input);
    const data30 = ctx.data;
    return this._def.type._parse({
      data: data30,
      path: ctx.path,
      parent: ctx
    });
  }
  unwrap() {
    return this._def.type;
  }
}
class ZodPipeline extends ZodType {
  static {
    __name(this, "ZodPipeline");
  }
  _parse(input) {
    const { status, ctx } = this._processInputParams(input);
    if (ctx.common.async) {
      const handleAsync = /* @__PURE__ */ __name(async () => {
        const inResult = await this._def.in._parseAsync({
          data: ctx.data,
          path: ctx.path,
          parent: ctx
        });
        if (inResult.status === "aborted")
          return INVALID;
        if (inResult.status === "dirty") {
          status.dirty();
          return DIRTY(inResult.value);
        } else {
          return this._def.out._parseAsync({
            data: inResult.value,
            path: ctx.path,
            parent: ctx
          });
        }
      }, "handleAsync");
      return handleAsync();
    } else {
      const inResult = this._def.in._parseSync({
        data: ctx.data,
        path: ctx.path,
        parent: ctx
      });
      if (inResult.status === "aborted")
        return INVALID;
      if (inResult.status === "dirty") {
        status.dirty();
        return {
          status: "dirty",
          value: inResult.value
        };
      } else {
        return this._def.out._parseSync({
          data: inResult.value,
          path: ctx.path,
          parent: ctx
        });
      }
    }
  }
  static create(a2, b2) {
    return new ZodPipeline({
      in: a2,
      out: b2,
      typeName: ZodFirstPartyTypeKind.ZodPipeline
    });
  }
}
class ZodReadonly extends ZodType {
  static {
    __name(this, "ZodReadonly");
  }
  _parse(input) {
    const result = this._def.innerType._parse(input);
    const freeze = /* @__PURE__ */ __name((data30) => {
      if (isValid(data30)) {
        data30.value = Object.freeze(data30.value);
      }
      return data30;
    }, "freeze");
    return isAsync(result) ? result.then((data30) => freeze(data30)) : freeze(result);
  }
  unwrap() {
    return this._def.innerType;
  }
}
ZodReadonly.create = (type, params) => {
  return new ZodReadonly({
    innerType: type,
    typeName: ZodFirstPartyTypeKind.ZodReadonly,
    ...processCreateParams(params)
  });
};
function custom(check, params = {}, fatal) {
  if (check)
    return ZodAny.create().superRefine((data30, ctx) => {
      var _a2, _b;
      if (!check(data30)) {
        const p2 = typeof params === "function" ? params(data30) : typeof params === "string" ? { message: params } : params;
        const _fatal = (_b = (_a2 = p2.fatal) !== null && _a2 !== void 0 ? _a2 : fatal) !== null && _b !== void 0 ? _b : true;
        const p22 = typeof p2 === "string" ? { message: p2 } : p2;
        ctx.addIssue({ code: "custom", ...p22, fatal: _fatal });
      }
    });
  return ZodAny.create();
}
__name(custom, "custom");
const late = {
  object: ZodObject.lazycreate
};
var ZodFirstPartyTypeKind;
(function(ZodFirstPartyTypeKind2) {
  ZodFirstPartyTypeKind2["ZodString"] = "ZodString";
  ZodFirstPartyTypeKind2["ZodNumber"] = "ZodNumber";
  ZodFirstPartyTypeKind2["ZodNaN"] = "ZodNaN";
  ZodFirstPartyTypeKind2["ZodBigInt"] = "ZodBigInt";
  ZodFirstPartyTypeKind2["ZodBoolean"] = "ZodBoolean";
  ZodFirstPartyTypeKind2["ZodDate"] = "ZodDate";
  ZodFirstPartyTypeKind2["ZodSymbol"] = "ZodSymbol";
  ZodFirstPartyTypeKind2["ZodUndefined"] = "ZodUndefined";
  ZodFirstPartyTypeKind2["ZodNull"] = "ZodNull";
  ZodFirstPartyTypeKind2["ZodAny"] = "ZodAny";
  ZodFirstPartyTypeKind2["ZodUnknown"] = "ZodUnknown";
  ZodFirstPartyTypeKind2["ZodNever"] = "ZodNever";
  ZodFirstPartyTypeKind2["ZodVoid"] = "ZodVoid";
  ZodFirstPartyTypeKind2["ZodArray"] = "ZodArray";
  ZodFirstPartyTypeKind2["ZodObject"] = "ZodObject";
  ZodFirstPartyTypeKind2["ZodUnion"] = "ZodUnion";
  ZodFirstPartyTypeKind2["ZodDiscriminatedUnion"] = "ZodDiscriminatedUnion";
  ZodFirstPartyTypeKind2["ZodIntersection"] = "ZodIntersection";
  ZodFirstPartyTypeKind2["ZodTuple"] = "ZodTuple";
  ZodFirstPartyTypeKind2["ZodRecord"] = "ZodRecord";
  ZodFirstPartyTypeKind2["ZodMap"] = "ZodMap";
  ZodFirstPartyTypeKind2["ZodSet"] = "ZodSet";
  ZodFirstPartyTypeKind2["ZodFunction"] = "ZodFunction";
  ZodFirstPartyTypeKind2["ZodLazy"] = "ZodLazy";
  ZodFirstPartyTypeKind2["ZodLiteral"] = "ZodLiteral";
  ZodFirstPartyTypeKind2["ZodEnum"] = "ZodEnum";
  ZodFirstPartyTypeKind2["ZodEffects"] = "ZodEffects";
  ZodFirstPartyTypeKind2["ZodNativeEnum"] = "ZodNativeEnum";
  ZodFirstPartyTypeKind2["ZodOptional"] = "ZodOptional";
  ZodFirstPartyTypeKind2["ZodNullable"] = "ZodNullable";
  ZodFirstPartyTypeKind2["ZodDefault"] = "ZodDefault";
  ZodFirstPartyTypeKind2["ZodCatch"] = "ZodCatch";
  ZodFirstPartyTypeKind2["ZodPromise"] = "ZodPromise";
  ZodFirstPartyTypeKind2["ZodBranded"] = "ZodBranded";
  ZodFirstPartyTypeKind2["ZodPipeline"] = "ZodPipeline";
  ZodFirstPartyTypeKind2["ZodReadonly"] = "ZodReadonly";
})(ZodFirstPartyTypeKind || (ZodFirstPartyTypeKind = {}));
const instanceOfType = /* @__PURE__ */ __name((cls, params = {
  message: `Input not instance of ${cls.name}`
}) => custom((data30) => data30 instanceof cls, params), "instanceOfType");
const stringType = ZodString.create;
const numberType = ZodNumber.create;
const nanType = ZodNaN.create;
const bigIntType = ZodBigInt.create;
const booleanType = ZodBoolean.create;
const dateType = ZodDate.create;
const symbolType = ZodSymbol.create;
const undefinedType = ZodUndefined.create;
const nullType = ZodNull.create;
const anyType = ZodAny.create;
const unknownType = ZodUnknown.create;
const neverType = ZodNever.create;
const voidType = ZodVoid.create;
const arrayType = ZodArray.create;
const objectType = ZodObject.create;
const strictObjectType = ZodObject.strictCreate;
const unionType = ZodUnion.create;
const discriminatedUnionType = ZodDiscriminatedUnion.create;
const intersectionType = ZodIntersection.create;
const tupleType = ZodTuple.create;
const recordType = ZodRecord.create;
const mapType = ZodMap.create;
const setType = ZodSet.create;
const functionType = ZodFunction.create;
const lazyType = ZodLazy.create;
const literalType = ZodLiteral.create;
const enumType = ZodEnum.create;
const nativeEnumType = ZodNativeEnum.create;
const promiseType = ZodPromise.create;
const effectsType = ZodEffects.create;
const optionalType = ZodOptional.create;
const nullableType = ZodNullable.create;
const preprocessType = ZodEffects.createWithPreprocess;
const pipelineType = ZodPipeline.create;
const ostring = /* @__PURE__ */ __name(() => stringType().optional(), "ostring");
const onumber = /* @__PURE__ */ __name(() => numberType().optional(), "onumber");
const oboolean = /* @__PURE__ */ __name(() => booleanType().optional(), "oboolean");
const coerce = {
  string: /* @__PURE__ */ __name((arg) => ZodString.create({ ...arg, coerce: true }), "string"),
  number: /* @__PURE__ */ __name((arg) => ZodNumber.create({ ...arg, coerce: true }), "number"),
  boolean: /* @__PURE__ */ __name((arg) => ZodBoolean.create({
    ...arg,
    coerce: true
  }), "boolean"),
  bigint: /* @__PURE__ */ __name((arg) => ZodBigInt.create({ ...arg, coerce: true }), "bigint"),
  date: /* @__PURE__ */ __name((arg) => ZodDate.create({ ...arg, coerce: true }), "date")
};
const NEVER = INVALID;
var z = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  defaultErrorMap: errorMap$1,
  setErrorMap,
  getErrorMap,
  makeIssue,
  EMPTY_PATH,
  addIssueToContext,
  ParseStatus,
  INVALID,
  DIRTY,
  OK,
  isAborted,
  isDirty,
  isValid,
  isAsync,
  get util() {
    return util;
  },
  get objectUtil() {
    return objectUtil;
  },
  ZodParsedType,
  getParsedType,
  ZodType,
  datetimeRegex,
  ZodString,
  ZodNumber,
  ZodBigInt,
  ZodBoolean,
  ZodDate,
  ZodSymbol,
  ZodUndefined,
  ZodNull,
  ZodAny,
  ZodUnknown,
  ZodNever,
  ZodVoid,
  ZodArray,
  ZodObject,
  ZodUnion,
  ZodDiscriminatedUnion,
  ZodIntersection,
  ZodTuple,
  ZodRecord,
  ZodMap,
  ZodSet,
  ZodFunction,
  ZodLazy,
  ZodLiteral,
  ZodEnum,
  ZodNativeEnum,
  ZodPromise,
  ZodEffects,
  ZodTransformer: ZodEffects,
  ZodOptional,
  ZodNullable,
  ZodDefault,
  ZodCatch,
  ZodNaN,
  BRAND,
  ZodBranded,
  ZodPipeline,
  ZodReadonly,
  custom,
  Schema: ZodType,
  ZodSchema: ZodType,
  late,
  get ZodFirstPartyTypeKind() {
    return ZodFirstPartyTypeKind;
  },
  coerce,
  any: anyType,
  array: arrayType,
  bigint: bigIntType,
  boolean: booleanType,
  date: dateType,
  discriminatedUnion: discriminatedUnionType,
  effect: effectsType,
  "enum": enumType,
  "function": functionType,
  "instanceof": instanceOfType,
  intersection: intersectionType,
  lazy: lazyType,
  literal: literalType,
  map: mapType,
  nan: nanType,
  nativeEnum: nativeEnumType,
  never: neverType,
  "null": nullType,
  nullable: nullableType,
  number: numberType,
  object: objectType,
  oboolean,
  onumber,
  optional: optionalType,
  ostring,
  pipeline: pipelineType,
  preprocess: preprocessType,
  promise: promiseType,
  record: recordType,
  set: setType,
  strictObject: strictObjectType,
  string: stringType,
  symbol: symbolType,
  transformer: effectsType,
  tuple: tupleType,
  "undefined": undefinedType,
  union: unionType,
  unknown: unknownType,
  "void": voidType,
  NEVER,
  ZodIssueCode,
  quotelessJson,
  ZodError
});
function isZodErrorLike(err) {
  return err instanceof Error && err.name === "ZodError" && "issues" in err && Array.isArray(err.issues);
}
__name(isZodErrorLike, "isZodErrorLike");
var ValidationError = class extends Error {
  static {
    __name(this, "ValidationError");
  }
  name;
  details;
  constructor(message3, options5) {
    super(message3, options5);
    this.name = "ZodValidationError";
    this.details = getIssuesFromErrorOptions(options5);
  }
  toString() {
    return this.message;
  }
};
function getIssuesFromErrorOptions(options5) {
  if (options5) {
    const cause = options5.cause;
    if (isZodErrorLike(cause)) {
      return cause.issues;
    }
  }
  return [];
}
__name(getIssuesFromErrorOptions, "getIssuesFromErrorOptions");
function isValidationError(err) {
  return err instanceof ValidationError;
}
__name(isValidationError, "isValidationError");
function isValidationErrorLike(err) {
  return err instanceof Error && err.name === "ZodValidationError";
}
__name(isValidationErrorLike, "isValidationErrorLike");
var ISSUE_SEPARATOR = "; ";
var MAX_ISSUES_IN_MESSAGE = 99;
var PREFIX = "Validation error";
var PREFIX_SEPARATOR = ": ";
var UNION_SEPARATOR = ", or ";
function prefixMessage(message3, prefix2, prefixSeparator) {
  if (prefix2 !== null) {
    if (message3.length > 0) {
      return [prefix2, message3].join(prefixSeparator);
    }
    return prefix2;
  }
  if (message3.length > 0) {
    return message3;
  }
  return PREFIX;
}
__name(prefixMessage, "prefixMessage");
var identifierRegex = /[$_\p{ID_Start}][$\u200c\u200d\p{ID_Continue}]*/u;
function joinPath(path) {
  if (path.length === 1) {
    return path[0].toString();
  }
  return path.reduce((acc, item3) => {
    if (typeof item3 === "number") {
      return acc + "[" + item3.toString() + "]";
    }
    if (item3.includes('"')) {
      return acc + '["' + escapeQuotes(item3) + '"]';
    }
    if (!identifierRegex.test(item3)) {
      return acc + '["' + item3 + '"]';
    }
    const separator = acc.length === 0 ? "" : ".";
    return acc + separator + item3;
  }, "");
}
__name(joinPath, "joinPath");
function escapeQuotes(str) {
  return str.replace(/"/g, '\\"');
}
__name(escapeQuotes, "escapeQuotes");
function isNonEmptyArray(value3) {
  return value3.length !== 0;
}
__name(isNonEmptyArray, "isNonEmptyArray");
function getMessageFromZodIssue(props) {
  const { issue, issueSeparator, unionSeparator, includePath } = props;
  if (issue.code === "invalid_union") {
    return issue.unionErrors.reduce((acc, zodError) => {
      const newIssues = zodError.issues.map(
        (issue2) => getMessageFromZodIssue({
          issue: issue2,
          issueSeparator,
          unionSeparator,
          includePath
        })
      ).join(issueSeparator);
      if (!acc.includes(newIssues)) {
        acc.push(newIssues);
      }
      return acc;
    }, []).join(unionSeparator);
  }
  if (issue.code === "invalid_arguments") {
    return [
      issue.message,
      ...issue.argumentsError.issues.map(
        (issue2) => getMessageFromZodIssue({
          issue: issue2,
          issueSeparator,
          unionSeparator,
          includePath
        })
      )
    ].join(issueSeparator);
  }
  if (issue.code === "invalid_return_type") {
    return [
      issue.message,
      ...issue.returnTypeError.issues.map(
        (issue2) => getMessageFromZodIssue({
          issue: issue2,
          issueSeparator,
          unionSeparator,
          includePath
        })
      )
    ].join(issueSeparator);
  }
  if (includePath && isNonEmptyArray(issue.path)) {
    if (issue.path.length === 1) {
      const identifier = issue.path[0];
      if (typeof identifier === "number") {
        return `${issue.message} at index ${identifier}`;
      }
    }
    return `${issue.message} at "${joinPath(issue.path)}"`;
  }
  return issue.message;
}
__name(getMessageFromZodIssue, "getMessageFromZodIssue");
function fromZodIssue(issue, options5 = {}) {
  const {
    issueSeparator = ISSUE_SEPARATOR,
    unionSeparator = UNION_SEPARATOR,
    prefixSeparator = PREFIX_SEPARATOR,
    prefix: prefix2 = PREFIX,
    includePath = true
  } = options5;
  const reason = getMessageFromZodIssue({
    issue,
    issueSeparator,
    unionSeparator,
    includePath
  });
  const message3 = prefixMessage(reason, prefix2, prefixSeparator);
  return new ValidationError(message3, { cause: new ZodError([issue]) });
}
__name(fromZodIssue, "fromZodIssue");
var errorMap = /* @__PURE__ */ __name((issue, ctx) => {
  const error2 = fromZodIssue({
    ...issue,
    // fallback to the default error message
    // when issue does not have a message
    message: issue.message ?? ctx.defaultError
  });
  return {
    message: error2.message
  };
}, "errorMap");
function fromZodError(zodError, options5 = {}) {
  if (!isZodErrorLike(zodError)) {
    throw new TypeError(
      `Invalid zodError param; expected instance of ZodError. Did you mean to use the "${fromError.name}" method instead?`
    );
  }
  return fromZodErrorWithoutRuntimeCheck(zodError, options5);
}
__name(fromZodError, "fromZodError");
function fromZodErrorWithoutRuntimeCheck(zodError, options5 = {}) {
  const {
    maxIssuesInMessage = MAX_ISSUES_IN_MESSAGE,
    issueSeparator = ISSUE_SEPARATOR,
    unionSeparator = UNION_SEPARATOR,
    prefixSeparator = PREFIX_SEPARATOR,
    prefix: prefix2 = PREFIX,
    includePath = true
  } = options5;
  const zodIssues = zodError.errors;
  const reason = zodIssues.length === 0 ? zodError.message : zodIssues.slice(0, maxIssuesInMessage).map(
    (issue) => getMessageFromZodIssue({
      issue,
      issueSeparator,
      unionSeparator,
      includePath
    })
  ).join(issueSeparator);
  const message3 = prefixMessage(reason, prefix2, prefixSeparator);
  return new ValidationError(message3, { cause: zodError });
}
__name(fromZodErrorWithoutRuntimeCheck, "fromZodErrorWithoutRuntimeCheck");
var toValidationError = /* @__PURE__ */ __name((options5 = {}) => (err) => {
  if (isZodErrorLike(err)) {
    return fromZodErrorWithoutRuntimeCheck(err, options5);
  }
  if (err instanceof Error) {
    return new ValidationError(err.message, { cause: err });
  }
  return new ValidationError("Unknown error");
}, "toValidationError");
function fromError(err, options5 = {}) {
  return toValidationError(options5)(err);
}
__name(fromError, "fromError");
const zComboOption = z.union([z.string(), z.number()]);
const zRemoteWidgetConfig = z.object({
  route: z.string().url().or(z.string().startsWith("/")),
  refresh: z.number().gte(128).safe().or(z.number().lte(0).safe()).optional(),
  response_key: z.string().optional(),
  query_params: z.record(z.string(), z.string()).optional(),
  refresh_button: z.boolean().optional(),
  control_after_refresh: z.enum(["first", "last"]).optional(),
  timeout: z.number().gte(0).optional(),
  max_retries: z.number().gte(0).optional()
});
const zMultiSelectOption = z.object({
  placeholder: z.string().optional(),
  chip: z.boolean().optional()
});
const zBaseInputOptions = z.object({
  default: z.any().optional(),
  defaultInput: z.boolean().optional(),
  forceInput: z.boolean().optional(),
  tooltip: z.string().optional(),
  hidden: z.boolean().optional(),
  advanced: z.boolean().optional(),
  /** Backend-only properties. */
  rawLink: z.boolean().optional(),
  lazy: z.boolean().optional()
}).passthrough();
const zNumericInputOptions = zBaseInputOptions.extend({
  min: z.number().optional(),
  max: z.number().optional(),
  step: z.number().optional(),
  // Note: Many node authors are using INT/FLOAT to pass list of INT/FLOAT.
  default: z.union([z.number(), z.array(z.number())]).optional(),
  display: z.enum(["slider", "number", "knob"]).optional()
});
const zIntInputOptions = zNumericInputOptions.extend({
  /**
   * If true, a linked widget will be added to the node to select the mode
   * of `control_after_generate`.
   */
  control_after_generate: z.boolean().optional()
});
const zFloatInputOptions = zNumericInputOptions.extend({
  round: z.union([z.number(), z.literal(false)]).optional()
});
const zBooleanInputOptions = zBaseInputOptions.extend({
  label_on: z.string().optional(),
  label_off: z.string().optional(),
  default: z.boolean().optional()
});
const zStringInputOptions = zBaseInputOptions.extend({
  default: z.string().optional(),
  multiline: z.boolean().optional(),
  dynamicPrompts: z.boolean().optional(),
  // Multiline-only fields
  defaultVal: z.string().optional(),
  placeholder: z.string().optional()
});
const zComboInputOptions = zBaseInputOptions.extend({
  control_after_generate: z.boolean().optional(),
  image_upload: z.boolean().optional(),
  image_folder: z.enum(["input", "output", "temp"]).optional(),
  allow_batch: z.boolean().optional(),
  video_upload: z.boolean().optional(),
  options: z.array(zComboOption).optional(),
  remote: zRemoteWidgetConfig.optional(),
  /** Whether the widget is a multi-select widget. */
  multi_select: zMultiSelectOption.optional()
});
const zIntInputSpec$1 = z.tuple([z.literal("INT"), zIntInputOptions.optional()]);
const zFloatInputSpec$1 = z.tuple([
  z.literal("FLOAT"),
  zFloatInputOptions.optional()
]);
const zBooleanInputSpec$1 = z.tuple([
  z.literal("BOOLEAN"),
  zBooleanInputOptions.optional()
]);
const zStringInputSpec$1 = z.tuple([
  z.literal("STRING"),
  zStringInputOptions.optional()
]);
const zComboInputSpec$1 = z.tuple([
  z.array(zComboOption),
  zComboInputOptions.optional()
]);
const zComboInputSpecV2 = z.tuple([
  z.literal("COMBO"),
  zComboInputOptions.optional()
]);
function isComboInputSpecV1(inputSpec) {
  return Array.isArray(inputSpec[0]);
}
__name(isComboInputSpecV1, "isComboInputSpecV1");
function isIntInputSpec$1(inputSpec) {
  return inputSpec[0] === "INT";
}
__name(isIntInputSpec$1, "isIntInputSpec$1");
function isFloatInputSpec$1(inputSpec) {
  return inputSpec[0] === "FLOAT";
}
__name(isFloatInputSpec$1, "isFloatInputSpec$1");
function isBooleanInputSpec$1(inputSpec) {
  return inputSpec[0] === "BOOLEAN";
}
__name(isBooleanInputSpec$1, "isBooleanInputSpec$1");
function isStringInputSpec$1(inputSpec) {
  return inputSpec[0] === "STRING";
}
__name(isStringInputSpec$1, "isStringInputSpec$1");
function isComboInputSpecV2(inputSpec) {
  return inputSpec[0] === "COMBO";
}
__name(isComboInputSpecV2, "isComboInputSpecV2");
function isCustomInputSpec(inputSpec) {
  return typeof inputSpec[0] === "string" && !excludedLiterals.has(inputSpec[0]);
}
__name(isCustomInputSpec, "isCustomInputSpec");
function isComboInputSpec$1(inputSpec) {
  return isComboInputSpecV1(inputSpec) || isComboInputSpecV2(inputSpec);
}
__name(isComboInputSpec$1, "isComboInputSpec$1");
function getInputSpecType(inputSpec) {
  return isComboInputSpec$1(inputSpec) ? "COMBO" : inputSpec[0];
}
__name(getInputSpecType, "getInputSpecType");
function getComboSpecComboOptions(inputSpec) {
  return (isComboInputSpecV2(inputSpec) ? inputSpec[1]?.options : inputSpec[0]) ?? [];
}
__name(getComboSpecComboOptions, "getComboSpecComboOptions");
const excludedLiterals = /* @__PURE__ */ new Set(["INT", "FLOAT", "BOOLEAN", "STRING", "COMBO"]);
const zCustomInputSpec$1 = z.tuple([
  z.string().refine((value3) => !excludedLiterals.has(value3)),
  zBaseInputOptions.optional()
]);
const zInputSpec$1 = z.union([
  zIntInputSpec$1,
  zFloatInputSpec$1,
  zBooleanInputSpec$1,
  zStringInputSpec$1,
  zComboInputSpec$1,
  zComboInputSpecV2,
  zCustomInputSpec$1
]);
const zComfyInputsSpec = z.object({
  required: z.record(zInputSpec$1).optional(),
  optional: z.record(zInputSpec$1).optional(),
  // Frontend repo is not using it, but some custom nodes are using the
  // hidden field to pass various values.
  hidden: z.record(z.any()).optional()
});
const zComfyNodeDataType = z.string();
const zComfyComboOutput = z.array(zComboOption);
const zComfyOutputTypesSpec = z.array(
  z.union([zComfyNodeDataType, zComfyComboOutput])
);
const zComfyNodeDef$1 = z.object({
  input: zComfyInputsSpec.optional(),
  output: zComfyOutputTypesSpec.optional(),
  output_is_list: z.array(z.boolean()).optional(),
  output_name: z.array(z.string()).optional(),
  output_tooltips: z.array(z.string()).optional(),
  name: z.string(),
  display_name: z.string(),
  description: z.string(),
  category: z.string(),
  output_node: z.boolean(),
  python_module: z.string(),
  deprecated: z.boolean().optional(),
  experimental: z.boolean().optional()
});
function validateComfyNodeDef(data30, onError = console.warn) {
  const result = zComfyNodeDef$1.safeParse(data30);
  if (!result.success) {
    const zodError = fromZodError(result.error);
    onError(
      `Invalid ComfyNodeDef: ${JSON.stringify(data30)}
${zodError.message}`
    );
    return null;
  }
  return result.data;
}
__name(validateComfyNodeDef, "validateComfyNodeDef");
class ComfyApi extends EventTarget {
  static {
    __name(this, "ComfyApi");
  }
  #registered = /* @__PURE__ */ new Set();
  api_host;
  api_base;
  /**
   * The client id from the initial session storage.
   */
  initialClientId;
  /**
   * The current client id from websocket status updates.
   */
  clientId;
  /**
   * The current user id.
   */
  user;
  socket = null;
  reportedUnknownMessageTypes = /* @__PURE__ */ new Set();
  constructor() {
    super();
    this.user = "";
    this.api_host = location.host;
    this.api_base = location.pathname.split("/").slice(0, -1).join("/");
    console.log("Running on", this.api_host);
    this.initialClientId = sessionStorage.getItem("clientId");
  }
  internalURL(route) {
    return this.api_base + "/internal" + route;
  }
  apiURL(route) {
    return this.api_base + "/api" + route;
  }
  fileURL(route) {
    return this.api_base + route;
  }
  fetchApi(route, options5) {
    if (!options5) {
      options5 = {};
    }
    if (!options5.headers) {
      options5.headers = {};
    }
    if (!options5.cache) {
      options5.cache = "no-cache";
    }
    if (Array.isArray(options5.headers)) {
      options5.headers.push(["Comfy-User", this.user]);
    } else if (options5.headers instanceof Headers) {
      options5.headers.set("Comfy-User", this.user);
    } else {
      options5.headers["Comfy-User"] = this.user;
    }
    return fetch(this.apiURL(route), options5);
  }
  addEventListener(type, callback, options5) {
    super.addEventListener(type, callback, options5);
    this.#registered.add(type);
  }
  removeEventListener(type, callback, options5) {
    super.removeEventListener(type, callback, options5);
  }
  dispatchCustomEvent(type, detail) {
    const event = detail === void 0 ? new CustomEvent(type) : new CustomEvent(type, { detail });
    return super.dispatchEvent(event);
  }
  /** @deprecated Use {@link dispatchCustomEvent}. */
  dispatchEvent(event) {
    return super.dispatchEvent(event);
  }
  /**
   * Poll status  for colab and other things that don't support websockets.
   */
  #pollQueue() {
    setInterval(async () => {
      try {
        const resp = await this.fetchApi("/prompt");
        const status = await resp.json();
        this.dispatchCustomEvent("status", status);
      } catch (error2) {
        this.dispatchCustomEvent("status", null);
      }
    }, 1e3);
  }
  /**
   * Creates and connects a WebSocket for realtime updates
   * @param {boolean} isReconnect If the socket is connection is a reconnect attempt
   */
  #createSocket(isReconnect) {
    if (this.socket) {
      return;
    }
    let opened = false;
    let existingSession = window.name;
    if (existingSession) {
      existingSession = "?clientId=" + existingSession;
    }
    this.socket = new WebSocket(
      `ws${window.location.protocol === "https:" ? "s" : ""}://${this.api_host}${this.api_base}/ws${existingSession}`
    );
    this.socket.binaryType = "arraybuffer";
    this.socket.addEventListener("open", () => {
      opened = true;
      if (isReconnect) {
        this.dispatchCustomEvent("reconnected");
      }
    });
    this.socket.addEventListener("error", () => {
      if (this.socket) this.socket.close();
      if (!isReconnect && !opened) {
        this.#pollQueue();
      }
    });
    this.socket.addEventListener("close", () => {
      setTimeout(() => {
        this.socket = null;
        this.#createSocket(true);
      }, 300);
      if (opened) {
        this.dispatchCustomEvent("status", null);
        this.dispatchCustomEvent("reconnecting");
      }
    });
    this.socket.addEventListener("message", (event) => {
      try {
        if (event.data instanceof ArrayBuffer) {
          const view = new DataView(event.data);
          const eventType = view.getUint32(0);
          const buffer2 = event.data.slice(4);
          switch (eventType) {
            case 1:
              const view2 = new DataView(event.data);
              const imageType = view2.getUint32(0);
              let imageMime;
              switch (imageType) {
                case 1:
                default:
                  imageMime = "image/jpeg";
                  break;
                case 2:
                  imageMime = "image/png";
              }
              const imageBlob = new Blob([buffer2.slice(4)], {
                type: imageMime
              });
              this.dispatchCustomEvent("b_preview", imageBlob);
              break;
            default:
              throw new Error(
                `Unknown binary websocket message of type ${eventType}`
              );
          }
        } else {
          const msg = JSON.parse(event.data);
          switch (msg.type) {
            case "status":
              if (msg.data.sid) {
                const clientId = msg.data.sid;
                this.clientId = clientId;
                window.name = clientId;
                sessionStorage.setItem("clientId", clientId);
              }
              this.dispatchCustomEvent("status", msg.data.status ?? null);
              break;
            case "executing":
              this.dispatchCustomEvent(
                "executing",
                msg.data.display_node || msg.data.node
              );
              break;
            case "execution_start":
            case "execution_error":
            case "execution_interrupted":
            case "execution_cached":
            case "execution_success":
            case "progress":
            case "executed":
            case "graphChanged":
            case "promptQueued":
            case "logs":
            case "b_preview":
              this.dispatchCustomEvent(msg.type, msg.data);
              break;
            default:
              if (this.#registered.has(msg.type)) {
                super.dispatchEvent(
                  new CustomEvent(msg.type, { detail: msg.data })
                );
              } else if (!this.reportedUnknownMessageTypes.has(msg.type)) {
                this.reportedUnknownMessageTypes.add(msg.type);
                throw new Error(`Unknown message type ${msg.type}`);
              }
          }
        }
      } catch (error2) {
        console.warn("Unhandled message:", event.data, error2);
      }
    });
  }
  /**
   * Initialises sockets and realtime updates
   */
  init() {
    this.#createSocket();
  }
  /**
   * Gets a list of extension urls
   */
  async getExtensions() {
    const resp = await this.fetchApi("/extensions", { cache: "no-store" });
    return await resp.json();
  }
  /**
   * Gets the available workflow templates from custom nodes.
   * @returns A map of custom_node names and associated template workflow names.
   */
  async getWorkflowTemplates() {
    const res = await this.fetchApi("/workflow_templates");
    return await res.json();
  }
  /**
   * Gets the index of core workflow templates.
   */
  async getCoreWorkflowTemplates() {
    const res = await axios.get(this.fileURL("/templates/index.json"));
    const contentType = res.headers["content-type"];
    return contentType?.includes("application/json") ? res.data : [];
  }
  /**
   * Gets a list of embedding names
   */
  async getEmbeddings() {
    const resp = await this.fetchApi("/embeddings", { cache: "no-store" });
    return await resp.json();
  }
  /**
   * Loads node object definitions for the graph
   * @returns The node definitions
   */
  async getNodeDefs({ validate = false } = {}) {
    const resp = await this.fetchApi("/object_info", { cache: "no-store" });
    const objectInfoUnsafe = await resp.json();
    if (!validate) {
      return objectInfoUnsafe;
    }
    const objectInfo = {};
    for (const key in objectInfoUnsafe) {
      const validatedDef = validateComfyNodeDef(
        objectInfoUnsafe[key],
        /* onError=*/
        (errorMessage) => {
          console.warn(
            `Skipping invalid node definition: ${key}. See debug log for more information.`
          );
          console.debug(errorMessage);
        }
      );
      if (validatedDef !== null) {
        objectInfo[key] = validatedDef;
      }
    }
    return objectInfo;
  }
  /**
   *
   * @param {number} number The index at which to queue the prompt, passing -1 will insert the prompt at the front of the queue
   * @param {object} prompt The prompt data to queue
   */
  async queuePrompt(number2, {
    output,
    workflow
  }) {
    const body = {
      client_id: this.clientId ?? "",
      // TODO: Unify clientId access
      prompt: output,
      extra_data: { extra_pnginfo: { workflow } }
    };
    if (number2 === -1) {
      body.front = true;
    } else if (number2 != 0) {
      body.number = number2;
    }
    const res = await this.fetchApi("/prompt", {
      method: "POST",
      headers: {
        "Content-Type": "application/json"
      },
      body: JSON.stringify(body)
    });
    if (res.status !== 200) {
      throw {
        response: await res.json()
      };
    }
    return await res.json();
  }
  /**
   * Gets a list of model folder keys (eg ['checkpoints', 'loras', ...])
   * @returns The list of model folder keys
   */
  async getModelFolders() {
    const res = await this.fetchApi(`/experiment/models`);
    if (res.status === 404) {
      return [];
    }
    const folderBlacklist = ["configs", "custom_nodes"];
    return (await res.json()).filter(
      (folder) => !folderBlacklist.includes(folder)
    );
  }
  /**
   * Gets a list of models in the specified folder
   * @param {string} folder The folder to list models from, such as 'checkpoints'
   * @returns The list of model filenames within the specified folder
   */
  async getModels(folder) {
    const res = await this.fetchApi(`/experiment/models/${folder}`);
    if (res.status === 404) {
      return [];
    }
    return await res.json();
  }
  /**
   * Gets the metadata for a model
   * @param {string} folder The folder containing the model
   * @param {string} model The model to get metadata for
   * @returns The metadata for the model
   */
  async viewMetadata(folder, model) {
    const res = await this.fetchApi(
      `/view_metadata/${folder}?filename=${encodeURIComponent(model)}`
    );
    const rawResponse = await res.text();
    if (!rawResponse) {
      return null;
    }
    try {
      return JSON.parse(rawResponse);
    } catch (error2) {
      console.error(
        "Error viewing metadata",
        res.status,
        res.statusText,
        rawResponse,
        error2
      );
      return null;
    }
  }
  /**
   * Loads a list of items (queue or history)
   * @param {string} type The type of items to load, queue or history
   * @returns The items of the specified type grouped by their status
   */
  async getItems(type) {
    if (type === "queue") {
      return this.getQueue();
    }
    return this.getHistory();
  }
  /**
   * Gets the current state of the queue
   * @returns The currently running and queued items
   */
  async getQueue() {
    try {
      const res = await this.fetchApi("/queue");
      const data30 = await res.json();
      return {
        // Running action uses a different endpoint for cancelling
        Running: data30.queue_running.map((prompt) => ({
          taskType: "Running",
          prompt,
          remove: { name: "Cancel", cb: /* @__PURE__ */ __name(() => api.interrupt(), "cb") }
        })),
        Pending: data30.queue_pending.map((prompt) => ({
          taskType: "Pending",
          prompt
        }))
      };
    } catch (error2) {
      console.error(error2);
      return { Running: [], Pending: [] };
    }
  }
  /**
   * Gets the prompt execution history
   * @returns Prompt history including node outputs
   */
  async getHistory(max_items = 200) {
    try {
      const res = await this.fetchApi(`/history?max_items=${max_items}`);
      const json = await res.json();
      return {
        History: Object.values(json).map((item3) => ({
          ...item3,
          taskType: "History"
        }))
      };
    } catch (error2) {
      console.error(error2);
      return { History: [] };
    }
  }
  /**
   * Gets system & device stats
   * @returns System stats such as python version, OS, per device info
   */
  async getSystemStats() {
    const res = await this.fetchApi("/system_stats");
    return await res.json();
  }
  /**
   * Sends a POST request to the API
   * @param {*} type The endpoint to post to
   * @param {*} body Optional POST data
   */
  async #postItem(type, body) {
    try {
      await this.fetchApi("/" + type, {
        method: "POST",
        headers: {
          "Content-Type": "application/json"
        },
        body: body ? JSON.stringify(body) : void 0
      });
    } catch (error2) {
      console.error(error2);
    }
  }
  /**
   * Deletes an item from the specified list
   * @param {string} type The type of item to delete, queue or history
   * @param {number} id The id of the item to delete
   */
  async deleteItem(type, id4) {
    await this.#postItem(type, { delete: [id4] });
  }
  /**
   * Clears the specified list
   * @param {string} type The type of list to clear, queue or history
   */
  async clearItems(type) {
    await this.#postItem(type, { clear: true });
  }
  /**
   * Interrupts the execution of the running prompt
   */
  async interrupt() {
    await this.#postItem("interrupt", null);
  }
  /**
   * Gets user configuration data and where data should be stored
   */
  async getUserConfig() {
    return (await this.fetchApi("/users")).json();
  }
  /**
   * Creates a new user
   * @param { string } username
   * @returns The fetch response
   */
  createUser(username) {
    return this.fetchApi("/users", {
      method: "POST",
      headers: {
        "Content-Type": "application/json"
      },
      body: JSON.stringify({ username })
    });
  }
  /**
   * Gets all setting values for the current user
   * @returns { Promise<string, unknown> } A dictionary of id -> value
   */
  async getSettings() {
    return (await this.fetchApi("/settings")).json();
  }
  /**
   * Gets a setting for the current user
   * @param { string } id The id of the setting to fetch
   * @returns { Promise<unknown> } The setting value
   */
  async getSetting(id4) {
    return (await this.fetchApi(`/settings/${encodeURIComponent(id4)}`)).json();
  }
  /**
   * Stores a dictionary of settings for the current user
   */
  async storeSettings(settings) {
    return this.fetchApi(`/settings`, {
      method: "POST",
      body: JSON.stringify(settings)
    });
  }
  /**
   * Stores a setting for the current user
   */
  async storeSetting(id4, value3) {
    return this.fetchApi(`/settings/${encodeURIComponent(id4)}`, {
      method: "POST",
      body: JSON.stringify(value3)
    });
  }
  /**
   * Gets a user data file for the current user
   */
  async getUserData(file, options5) {
    return this.fetchApi(`/userdata/${encodeURIComponent(file)}`, options5);
  }
  /**
   * Stores a user data file for the current user
   * @param { string } file The name of the userdata file to save
   * @param { unknown } data The data to save to the file
   * @param { RequestInit & { stringify?: boolean, throwOnError?: boolean } } [options]
   * @returns { Promise<Response> }
   */
  async storeUserData(file, data30, options5 = {
    overwrite: true,
    stringify: true,
    throwOnError: true,
    full_info: false
  }) {
    const resp = await this.fetchApi(
      `/userdata/${encodeURIComponent(file)}?overwrite=${options5.overwrite}&full_info=${options5.full_info}`,
      {
        method: "POST",
        body: options5?.stringify ? JSON.stringify(data30) : data30,
        ...options5
      }
    );
    if (resp.status !== 200 && options5.throwOnError !== false) {
      throw new Error(
        `Error storing user data file '${file}': ${resp.status} ${(await resp).statusText}`
      );
    }
    return resp;
  }
  /**
   * Deletes a user data file for the current user
   * @param { string } file The name of the userdata file to delete
   */
  async deleteUserData(file) {
    const resp = await this.fetchApi(`/userdata/${encodeURIComponent(file)}`, {
      method: "DELETE"
    });
    return resp;
  }
  /**
   * Move a user data file for the current user
   * @param { string } source The userdata file to move
   * @param { string } dest The destination for the file
   */
  async moveUserData(source, dest, options5 = { overwrite: false }) {
    const resp = await this.fetchApi(
      `/userdata/${encodeURIComponent(source)}/move/${encodeURIComponent(dest)}?overwrite=${options5?.overwrite}`,
      {
        method: "POST"
      }
    );
    return resp;
  }
  /**
   * @deprecated Use `listUserDataFullInfo` instead.
   */
  async listUserData(dir, recurse, split2) {
    const resp = await this.fetchApi(
      `/userdata?${new URLSearchParams({
        recurse: recurse ? "true" : "false",
        dir,
        split: split2 ? "true" : "false"
      })}`
    );
    if (resp.status === 404) return [];
    if (resp.status !== 200) {
      throw new Error(
        `Error getting user data list '${dir}': ${resp.status} ${resp.statusText}`
      );
    }
    return resp.json();
  }
  async listUserDataFullInfo(dir) {
    const resp = await this.fetchApi(
      `/userdata?dir=${encodeURIComponent(dir)}&recurse=true&split=false&full_info=true`
    );
    if (resp.status === 404) return [];
    if (resp.status !== 200) {
      throw new Error(
        `Error getting user data list '${dir}': ${resp.status} ${resp.statusText}`
      );
    }
    return resp.json();
  }
  async getLogs() {
    return (await axios.get(this.internalURL("/logs"))).data;
  }
  async getRawLogs() {
    return (await axios.get(this.internalURL("/logs/raw"))).data;
  }
  async subscribeLogs(enabled) {
    return await axios.patch(this.internalURL("/logs/subscribe"), {
      enabled,
      clientId: this.clientId
    });
  }
  async getFolderPaths() {
    return (await axios.get(this.internalURL("/folder_paths"))).data;
  }
  /**
   * Gets the custom nodes i18n data from the server.
   *
   * @returns The custom nodes i18n data
   */
  async getCustomNodesI18n() {
    return (await axios.get(this.apiURL("/i18n"))).data;
  }
}
const api = new ComfyApi();
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.api = window.comfyAPI.api || {};
window.comfyAPI.api.ComfyApi = ComfyApi;
window.comfyAPI.api.api = api;
const useUserStore = /* @__PURE__ */ defineStore("user", () => {
  const userConfig = ref(null);
  const currentUserId = ref(null);
  const isMultiUserServer = computed(
    () => userConfig.value && "users" in userConfig.value
  );
  const needsLogin = computed(
    () => !currentUserId.value && isMultiUserServer.value
  );
  const users = computed(
    () => Object.entries(userConfig.value?.users ?? {}).map(([userId, username]) => ({
      userId,
      username
    }))
  );
  const currentUser = computed(
    () => users.value.find((user) => user.userId === currentUserId.value) ?? null
  );
  const initialized = computed(() => userConfig.value !== null);
  async function initialize2() {
    userConfig.value = await api.getUserConfig();
    currentUserId.value = localStorage["Comfy.userId"];
  }
  __name(initialize2, "initialize");
  async function createUser(username) {
    const resp = await api.createUser(username);
    const data30 = await resp.json();
    if (resp.status >= 300) {
      throw new Error(
        data30.error ?? "Error creating user: " + resp.status + " " + resp.statusText
      );
    }
    return {
      userId: data30,
      username
    };
  }
  __name(createUser, "createUser");
  async function login({
    userId,
    username
  }) {
    currentUserId.value = userId;
    localStorage["Comfy.userId"] = userId;
    localStorage["Comfy.userName"] = username;
  }
  __name(login, "login");
  watchEffect(() => {
    if (isMultiUserServer.value && currentUserId.value) {
      api.user = currentUserId.value;
    }
  });
  async function logout() {
    delete localStorage["Comfy.userId"];
    delete localStorage["Comfy.userName"];
  }
  __name(logout, "logout");
  return {
    users,
    currentUser,
    isMultiUserServer,
    needsLogin,
    initialized,
    initialize: initialize2,
    createUser,
    login,
    logout
  };
});
function isElectron() {
  return "electronAPI" in window && window.electronAPI !== void 0;
}
__name(isElectron, "isElectron");
function electronAPI() {
  return window.electronAPI;
}
__name(electronAPI, "electronAPI");
function showNativeSystemMenu() {
  electronAPI()?.showContextMenu();
}
__name(showNativeSystemMenu, "showNativeSystemMenu");
function isNativeWindow() {
  return isElectron() && !!window.navigator.windowControlsOverlay?.visible;
}
__name(isNativeWindow, "isNativeWindow");
const isFileProtocol = window.location.protocol === "file:";
const basePath = isElectron() ? "/" : window.location.pathname;
const guardElectronAccess = /* @__PURE__ */ __name((_to, _from, next2) => {
  if (isElectron()) {
    next2();
  } else {
    next2("/");
  }
}, "guardElectronAccess");
const router = createRouter({
  history: isFileProtocol ? createWebHashHistory() : (
    // Base path must be specified to ensure correct relative paths
    // Example: For URL 'http://localhost:7801/ComfyBackendDirect',
    // we need this base path or assets will incorrectly resolve from 'http://localhost:7801/'
    createWebHistory(basePath)
  ),
  routes: [
    {
      path: "/",
      component: LayoutDefault,
      children: [
        {
          path: "",
          name: "GraphView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./GraphView-DIFwgSix.js"), true ? __vite__mapDeps([0,1,2,3,4,5,6]) : void 0, import.meta.url), "component"),
          beforeEnter: /* @__PURE__ */ __name(async (_to, _from, next2) => {
            const userStore = useUserStore();
            await userStore.initialize();
            if (userStore.needsLogin) {
              next2("/user-select");
            } else {
              next2();
            }
          }, "beforeEnter")
        },
        {
          path: "user-select",
          name: "UserSelectView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./UserSelectView-ChoLQX6h.js"), true ? __vite__mapDeps([7,8]) : void 0, import.meta.url), "component")
        },
        {
          path: "server-start",
          name: "ServerStartView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./ServerStartView-L7Ep7wjc.js"), true ? __vite__mapDeps([9,8,10]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "install",
          name: "InstallView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./InstallView-DDRZa2vk.js"), true ? __vite__mapDeps([11,12,13,8,14]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "welcome",
          name: "WelcomeView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./WelcomeView-D5wE9fV3.js"), true ? __vite__mapDeps([15,8,16]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "not-supported",
          name: "NotSupportedView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./NotSupportedView-B5tg2lWn.js"), true ? __vite__mapDeps([17,8,18]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "download-git",
          name: "DownloadGitView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./DownloadGitView-CywmLRmU.js"), true ? __vite__mapDeps([19,8]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "manual-configuration",
          name: "ManualConfigurationView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./ManualConfigurationView-B17itdXq.js"), true ? __vite__mapDeps([20,8,21]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "/metrics-consent",
          name: "MetricsConsentView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./MetricsConsentView-faZwQDjh.js"), true ? __vite__mapDeps([22,8]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "desktop-start",
          name: "DesktopStartView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./DesktopStartView-B36WWhTC.js"), true ? __vite__mapDeps([23,8]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "maintenance",
          name: "MaintenanceView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./MaintenanceView-D5_jO_ss.js"), true ? __vite__mapDeps([24,3,25,1,2,26,27,12,28,8,29]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        },
        {
          path: "desktop-update",
          name: "DesktopUpdateView",
          component: /* @__PURE__ */ __name(() => __vitePreload(() => import("./DesktopUpdateView-snHXsIop.js"), true ? __vite__mapDeps([30,3,28,27,8,31]) : void 0, import.meta.url), "component"),
          beforeEnter: guardElectronAccess
        }
      ]
    }
  ],
  scrollBehavior(_to, _from, savedPosition) {
    if (savedPosition) {
      return savedPosition;
    } else {
      return { top: 0 };
    }
  }
});
var isVue2$1 = false;
var isVue3$1 = true;
var Vue2$1 = void 0;
function install$7() {
}
__name(install$7, "install$7");
function set$2(target2, key, val) {
  if (Array.isArray(target2)) {
    target2.length = Math.max(target2.length, key);
    target2.splice(key, 1, val);
    return val;
  }
  target2[key] = val;
  return val;
}
__name(set$2, "set$2");
function del$2(target2, key) {
  if (Array.isArray(target2)) {
    target2.splice(key, 1);
    return;
  }
  delete target2[key];
}
__name(del$2, "del$2");
function computedEager(fn, options5) {
  var _a2;
  const result = shallowRef();
  watchEffect(() => {
    result.value = fn();
  }, {
    ...options5,
    flush: (_a2 = options5 == null ? void 0 : options5.flush) != null ? _a2 : "sync"
  });
  return readonly(result);
}
__name(computedEager, "computedEager");
function computedWithControl(source, fn) {
  let v2 = void 0;
  let track2;
  let trigger2;
  const dirty = ref(true);
  const update = /* @__PURE__ */ __name(() => {
    dirty.value = true;
    trigger2();
  }, "update");
  watch(source, update, { flush: "sync" });
  const get22 = typeof fn === "function" ? fn : fn.get;
  const set22 = typeof fn === "function" ? void 0 : fn.set;
  const result = customRef((_track, _trigger) => {
    track2 = _track;
    trigger2 = _trigger;
    return {
      get() {
        if (dirty.value) {
          v2 = get22(v2);
          dirty.value = false;
        }
        track2();
        return v2;
      },
      set(v22) {
        set22 == null ? void 0 : set22(v22);
      }
    };
  });
  if (Object.isExtensible(result))
    result.trigger = update;
  return result;
}
__name(computedWithControl, "computedWithControl");
function tryOnScopeDispose(fn) {
  if (getCurrentScope()) {
    onScopeDispose(fn);
    return true;
  }
  return false;
}
__name(tryOnScopeDispose, "tryOnScopeDispose");
function createEventHook() {
  const fns = /* @__PURE__ */ new Set();
  const off = /* @__PURE__ */ __name((fn) => {
    fns.delete(fn);
  }, "off");
  const on2 = /* @__PURE__ */ __name((fn) => {
    fns.add(fn);
    const offFn = /* @__PURE__ */ __name(() => off(fn), "offFn");
    tryOnScopeDispose(offFn);
    return {
      off: offFn
    };
  }, "on");
  const trigger2 = /* @__PURE__ */ __name((...args) => {
    return Promise.all(Array.from(fns).map((fn) => fn(...args)));
  }, "trigger");
  return {
    on: on2,
    off,
    trigger: trigger2
  };
}
__name(createEventHook, "createEventHook");
function createGlobalState(stateFactory) {
  let initialized = false;
  let state;
  const scope = effectScope(true);
  return (...args) => {
    if (!initialized) {
      state = scope.run(() => stateFactory(...args));
      initialized = true;
    }
    return state;
  };
}
__name(createGlobalState, "createGlobalState");
const localProvidedStateMap = /* @__PURE__ */ new WeakMap();
const provideLocal = /* @__PURE__ */ __name((key, value3) => {
  var _a2;
  const instance = (_a2 = getCurrentInstance()) == null ? void 0 : _a2.proxy;
  if (instance == null)
    throw new Error("provideLocal must be called in setup");
  if (!localProvidedStateMap.has(instance))
    localProvidedStateMap.set(instance, /* @__PURE__ */ Object.create(null));
  const localProvidedState = localProvidedStateMap.get(instance);
  localProvidedState[key] = value3;
  provide(key, value3);
}, "provideLocal");
const injectLocal = /* @__PURE__ */ __name((...args) => {
  var _a2;
  const key = args[0];
  const instance = (_a2 = getCurrentInstance()) == null ? void 0 : _a2.proxy;
  if (instance == null)
    throw new Error("injectLocal must be called in setup");
  if (localProvidedStateMap.has(instance) && key in localProvidedStateMap.get(instance))
    return localProvidedStateMap.get(instance)[key];
  return inject(...args);
}, "injectLocal");
function createInjectionState(composable, options5) {
  const key = (options5 == null ? void 0 : options5.injectionKey) || Symbol(composable.name || "InjectionState");
  const defaultValue2 = options5 == null ? void 0 : options5.defaultValue;
  const useProvidingState = /* @__PURE__ */ __name((...args) => {
    const state = composable(...args);
    provideLocal(key, state);
    return state;
  }, "useProvidingState");
  const useInjectedState = /* @__PURE__ */ __name(() => injectLocal(key, defaultValue2), "useInjectedState");
  return [useProvidingState, useInjectedState];
}
__name(createInjectionState, "createInjectionState");
function createSharedComposable(composable) {
  let subscribers = 0;
  let state;
  let scope;
  const dispose = /* @__PURE__ */ __name(() => {
    subscribers -= 1;
    if (scope && subscribers <= 0) {
      scope.stop();
      state = void 0;
      scope = void 0;
    }
  }, "dispose");
  return (...args) => {
    subscribers += 1;
    if (!state) {
      scope = effectScope(true);
      state = scope.run(() => composable(...args));
    }
    tryOnScopeDispose(dispose);
    return state;
  };
}
__name(createSharedComposable, "createSharedComposable");
function extendRef(ref2, extend5, { enumerable = false, unwrap = true } = {}) {
  if (!isVue3$1 && !version.startsWith("2.7.")) {
    if (false)
      throw new Error("[VueUse] extendRef only works in Vue 2.7 or above.");
    return;
  }
  for (const [key, value3] of Object.entries(extend5)) {
    if (key === "value")
      continue;
    if (isRef(value3) && unwrap) {
      Object.defineProperty(ref2, key, {
        get() {
          return value3.value;
        },
        set(v2) {
          value3.value = v2;
        },
        enumerable
      });
    } else {
      Object.defineProperty(ref2, key, { value: value3, enumerable });
    }
  }
  return ref2;
}
__name(extendRef, "extendRef");
function get$2(obj, key) {
  if (key == null)
    return unref(obj);
  return unref(obj)[key];
}
__name(get$2, "get$2");
function isDefined$1(v2) {
  return unref(v2) != null;
}
__name(isDefined$1, "isDefined$1");
function makeDestructurable(obj, arr) {
  if (typeof Symbol !== "undefined") {
    const clone2 = { ...obj };
    Object.defineProperty(clone2, Symbol.iterator, {
      enumerable: false,
      value() {
        let index2 = 0;
        return {
          next: /* @__PURE__ */ __name(() => ({
            value: arr[index2++],
            done: index2 > arr.length
          }), "next")
        };
      }
    });
    return clone2;
  } else {
    return Object.assign([...arr], obj);
  }
}
__name(makeDestructurable, "makeDestructurable");
function toValue$3(r2) {
  return typeof r2 === "function" ? r2() : unref(r2);
}
__name(toValue$3, "toValue$3");
const resolveUnref = toValue$3;
function reactify(fn, options5) {
  const unrefFn = (options5 == null ? void 0 : options5.computedGetter) === false ? unref : toValue$3;
  return function(...args) {
    return computed(() => fn.apply(this, args.map((i2) => unrefFn(i2))));
  };
}
__name(reactify, "reactify");
function reactifyObject(obj, optionsOrKeys = {}) {
  let keys2 = [];
  let options5;
  if (Array.isArray(optionsOrKeys)) {
    keys2 = optionsOrKeys;
  } else {
    options5 = optionsOrKeys;
    const { includeOwnProperties = true } = optionsOrKeys;
    keys2.push(...Object.keys(obj));
    if (includeOwnProperties)
      keys2.push(...Object.getOwnPropertyNames(obj));
  }
  return Object.fromEntries(
    keys2.map((key) => {
      const value3 = obj[key];
      return [
        key,
        typeof value3 === "function" ? reactify(value3.bind(obj), options5) : value3
      ];
    })
  );
}
__name(reactifyObject, "reactifyObject");
function toReactive(objectRef) {
  if (!isRef(objectRef))
    return reactive(objectRef);
  const proxy = new Proxy({}, {
    get(_2, p2, receiver) {
      return unref(Reflect.get(objectRef.value, p2, receiver));
    },
    set(_2, p2, value3) {
      if (isRef(objectRef.value[p2]) && !isRef(value3))
        objectRef.value[p2].value = value3;
      else
        objectRef.value[p2] = value3;
      return true;
    },
    deleteProperty(_2, p2) {
      return Reflect.deleteProperty(objectRef.value, p2);
    },
    has(_2, p2) {
      return Reflect.has(objectRef.value, p2);
    },
    ownKeys() {
      return Object.keys(objectRef.value);
    },
    getOwnPropertyDescriptor() {
      return {
        enumerable: true,
        configurable: true
      };
    }
  });
  return reactive(proxy);
}
__name(toReactive, "toReactive");
function reactiveComputed(fn) {
  return toReactive(computed(fn));
}
__name(reactiveComputed, "reactiveComputed");
function reactiveOmit(obj, ...keys2) {
  const flatKeys = keys2.flat();
  const predicate = flatKeys[0];
  return reactiveComputed(() => typeof predicate === "function" ? Object.fromEntries(Object.entries(toRefs$1(obj)).filter(([k2, v2]) => !predicate(toValue$3(v2), k2))) : Object.fromEntries(Object.entries(toRefs$1(obj)).filter((e2) => !flatKeys.includes(e2[0]))));
}
__name(reactiveOmit, "reactiveOmit");
const isClient$1 = typeof window !== "undefined" && typeof document !== "undefined";
const isWorker = typeof WorkerGlobalScope !== "undefined" && globalThis instanceof WorkerGlobalScope;
const isDef = /* @__PURE__ */ __name((val) => typeof val !== "undefined", "isDef");
const notNullish = /* @__PURE__ */ __name((val) => val != null, "notNullish");
const assert = /* @__PURE__ */ __name((condition, ...infos) => {
  if (!condition)
    console.warn(...infos);
}, "assert");
const toString$1 = Object.prototype.toString;
const isObject$d = /* @__PURE__ */ __name((val) => toString$1.call(val) === "[object Object]", "isObject$d");
const now = /* @__PURE__ */ __name(() => Date.now(), "now");
const timestamp = /* @__PURE__ */ __name(() => +Date.now(), "timestamp");
const clamp$1 = /* @__PURE__ */ __name((n2, min, max) => Math.min(max, Math.max(min, n2)), "clamp$1");
const noop$1 = /* @__PURE__ */ __name(() => {
}, "noop$1");
const rand = /* @__PURE__ */ __name((min, max) => {
  min = Math.ceil(min);
  max = Math.floor(max);
  return Math.floor(Math.random() * (max - min + 1)) + min;
}, "rand");
const hasOwn$2 = /* @__PURE__ */ __name((val, key) => Object.prototype.hasOwnProperty.call(val, key), "hasOwn$2");
const isIOS$1 = /* @__PURE__ */ getIsIOS();
function getIsIOS() {
  var _a2, _b;
  return isClient$1 && ((_a2 = window == null ? void 0 : window.navigator) == null ? void 0 : _a2.userAgent) && (/iP(?:ad|hone|od)/.test(window.navigator.userAgent) || ((_b = window == null ? void 0 : window.navigator) == null ? void 0 : _b.maxTouchPoints) > 2 && /iPad|Macintosh/.test(window == null ? void 0 : window.navigator.userAgent));
}
__name(getIsIOS, "getIsIOS");
function createFilterWrapper(filter4, fn) {
  function wrapper(...args) {
    return new Promise((resolve2, reject3) => {
      Promise.resolve(filter4(() => fn.apply(this, args), { fn, thisArg: this, args })).then(resolve2).catch(reject3);
    });
  }
  __name(wrapper, "wrapper");
  return wrapper;
}
__name(createFilterWrapper, "createFilterWrapper");
const bypassFilter = /* @__PURE__ */ __name((invoke2) => {
  return invoke2();
}, "bypassFilter");
function debounceFilter(ms, options5 = {}) {
  let timer;
  let maxTimer;
  let lastRejector = noop$1;
  const _clearTimeout = /* @__PURE__ */ __name((timer2) => {
    clearTimeout(timer2);
    lastRejector();
    lastRejector = noop$1;
  }, "_clearTimeout");
  const filter4 = /* @__PURE__ */ __name((invoke2) => {
    const duration = toValue$3(ms);
    const maxDuration = toValue$3(options5.maxWait);
    if (timer)
      _clearTimeout(timer);
    if (duration <= 0 || maxDuration !== void 0 && maxDuration <= 0) {
      if (maxTimer) {
        _clearTimeout(maxTimer);
        maxTimer = null;
      }
      return Promise.resolve(invoke2());
    }
    return new Promise((resolve2, reject3) => {
      lastRejector = options5.rejectOnCancel ? reject3 : resolve2;
      if (maxDuration && !maxTimer) {
        maxTimer = setTimeout(() => {
          if (timer)
            _clearTimeout(timer);
          maxTimer = null;
          resolve2(invoke2());
        }, maxDuration);
      }
      timer = setTimeout(() => {
        if (maxTimer)
          _clearTimeout(maxTimer);
        maxTimer = null;
        resolve2(invoke2());
      }, duration);
    });
  }, "filter");
  return filter4;
}
__name(debounceFilter, "debounceFilter");
function throttleFilter(...args) {
  let lastExec = 0;
  let timer;
  let isLeading = true;
  let lastRejector = noop$1;
  let lastValue;
  let ms;
  let trailing;
  let leading;
  let rejectOnCancel;
  if (!isRef(args[0]) && typeof args[0] === "object")
    ({ delay: ms, trailing = true, leading = true, rejectOnCancel = false } = args[0]);
  else
    [ms, trailing = true, leading = true, rejectOnCancel = false] = args;
  const clear = /* @__PURE__ */ __name(() => {
    if (timer) {
      clearTimeout(timer);
      timer = void 0;
      lastRejector();
      lastRejector = noop$1;
    }
  }, "clear");
  const filter4 = /* @__PURE__ */ __name((_invoke) => {
    const duration = toValue$3(ms);
    const elapsed = Date.now() - lastExec;
    const invoke2 = /* @__PURE__ */ __name(() => {
      return lastValue = _invoke();
    }, "invoke2");
    clear();
    if (duration <= 0) {
      lastExec = Date.now();
      return invoke2();
    }
    if (elapsed > duration && (leading || !isLeading)) {
      lastExec = Date.now();
      invoke2();
    } else if (trailing) {
      lastValue = new Promise((resolve2, reject3) => {
        lastRejector = rejectOnCancel ? reject3 : resolve2;
        timer = setTimeout(() => {
          lastExec = Date.now();
          isLeading = true;
          resolve2(invoke2());
          clear();
        }, Math.max(0, duration - elapsed));
      });
    }
    if (!leading && !timer)
      timer = setTimeout(() => isLeading = true, duration);
    isLeading = false;
    return lastValue;
  }, "filter");
  return filter4;
}
__name(throttleFilter, "throttleFilter");
function pausableFilter(extendFilter = bypassFilter) {
  const isActive2 = ref(true);
  function pause() {
    isActive2.value = false;
  }
  __name(pause, "pause");
  function resume() {
    isActive2.value = true;
  }
  __name(resume, "resume");
  const eventFilter = /* @__PURE__ */ __name((...args) => {
    if (isActive2.value)
      extendFilter(...args);
  }, "eventFilter");
  return { isActive: readonly(isActive2), pause, resume, eventFilter };
}
__name(pausableFilter, "pausableFilter");
const directiveHooks = {
  mounted: isVue3$1 ? "mounted" : "inserted",
  updated: isVue3$1 ? "updated" : "componentUpdated",
  unmounted: isVue3$1 ? "unmounted" : "unbind"
};
function cacheStringFunction(fn) {
  const cache2 = /* @__PURE__ */ Object.create(null);
  return (str) => {
    const hit = cache2[str];
    return hit || (cache2[str] = fn(str));
  };
}
__name(cacheStringFunction, "cacheStringFunction");
const hyphenateRE = /\B([A-Z])/g;
const hyphenate = cacheStringFunction((str) => str.replace(hyphenateRE, "-$1").toLowerCase());
const camelizeRE = /-(\w)/g;
const camelize = cacheStringFunction((str) => {
  return str.replace(camelizeRE, (_2, c2) => c2 ? c2.toUpperCase() : "");
});
function promiseTimeout(ms, throwOnTimeout = false, reason = "Timeout") {
  return new Promise((resolve2, reject3) => {
    if (throwOnTimeout)
      setTimeout(() => reject3(reason), ms);
    else
      setTimeout(resolve2, ms);
  });
}
__name(promiseTimeout, "promiseTimeout");
function identity(arg) {
  return arg;
}
__name(identity, "identity");
function createSingletonPromise(fn) {
  let _promise;
  function wrapper() {
    if (!_promise)
      _promise = fn();
    return _promise;
  }
  __name(wrapper, "wrapper");
  wrapper.reset = async () => {
    const _prev = _promise;
    _promise = void 0;
    if (_prev)
      await _prev;
  };
  return wrapper;
}
__name(createSingletonPromise, "createSingletonPromise");
function invoke(fn) {
  return fn();
}
__name(invoke, "invoke");
function containsProp(obj, ...props) {
  return props.some((k2) => k2 in obj);
}
__name(containsProp, "containsProp");
function increaseWithUnit(target2, delta2) {
  var _a2;
  if (typeof target2 === "number")
    return target2 + delta2;
  const value3 = ((_a2 = target2.match(/^-?\d+\.?\d*/)) == null ? void 0 : _a2[0]) || "";
  const unit = target2.slice(value3.length);
  const result = Number.parseFloat(value3) + delta2;
  if (Number.isNaN(result))
    return target2;
  return result + unit;
}
__name(increaseWithUnit, "increaseWithUnit");
function objectPick(obj, keys2, omitUndefined = false) {
  return keys2.reduce((n2, k2) => {
    if (k2 in obj) {
      if (!omitUndefined || obj[k2] !== void 0)
        n2[k2] = obj[k2];
    }
    return n2;
  }, {});
}
__name(objectPick, "objectPick");
function objectOmit(obj, keys2, omitUndefined = false) {
  return Object.fromEntries(Object.entries(obj).filter(([key, value3]) => {
    return (!omitUndefined || value3 !== void 0) && !keys2.includes(key);
  }));
}
__name(objectOmit, "objectOmit");
function objectEntries(obj) {
  return Object.entries(obj);
}
__name(objectEntries, "objectEntries");
function getLifeCycleTarget(target2) {
  return target2 || getCurrentInstance();
}
__name(getLifeCycleTarget, "getLifeCycleTarget");
function toRef(...args) {
  if (args.length !== 1)
    return toRef$1(...args);
  const r2 = args[0];
  return typeof r2 === "function" ? readonly(customRef(() => ({ get: r2, set: noop$1 }))) : ref(r2);
}
__name(toRef, "toRef");
const resolveRef = toRef;
function reactivePick(obj, ...keys2) {
  const flatKeys = keys2.flat();
  const predicate = flatKeys[0];
  return reactiveComputed(() => typeof predicate === "function" ? Object.fromEntries(Object.entries(toRefs$1(obj)).filter(([k2, v2]) => predicate(toValue$3(v2), k2))) : Object.fromEntries(flatKeys.map((k2) => [k2, toRef(obj, k2)])));
}
__name(reactivePick, "reactivePick");
function refAutoReset(defaultValue2, afterMs = 1e4) {
  return customRef((track2, trigger2) => {
    let value3 = toValue$3(defaultValue2);
    let timer;
    const resetAfter = /* @__PURE__ */ __name(() => setTimeout(() => {
      value3 = toValue$3(defaultValue2);
      trigger2();
    }, toValue$3(afterMs)), "resetAfter");
    tryOnScopeDispose(() => {
      clearTimeout(timer);
    });
    return {
      get() {
        track2();
        return value3;
      },
      set(newValue2) {
        value3 = newValue2;
        trigger2();
        clearTimeout(timer);
        timer = resetAfter();
      }
    };
  });
}
__name(refAutoReset, "refAutoReset");
function useDebounceFn(fn, ms = 200, options5 = {}) {
  return createFilterWrapper(
    debounceFilter(ms, options5),
    fn
  );
}
__name(useDebounceFn, "useDebounceFn");
function refDebounced(value3, ms = 200, options5 = {}) {
  const debounced = ref(value3.value);
  const updater = useDebounceFn(() => {
    debounced.value = value3.value;
  }, ms, options5);
  watch(value3, () => updater());
  return debounced;
}
__name(refDebounced, "refDebounced");
function refDefault(source, defaultValue2) {
  return computed({
    get() {
      var _a2;
      return (_a2 = source.value) != null ? _a2 : defaultValue2;
    },
    set(value3) {
      source.value = value3;
    }
  });
}
__name(refDefault, "refDefault");
function useThrottleFn(fn, ms = 200, trailing = false, leading = true, rejectOnCancel = false) {
  return createFilterWrapper(
    throttleFilter(ms, trailing, leading, rejectOnCancel),
    fn
  );
}
__name(useThrottleFn, "useThrottleFn");
function refThrottled(value3, delay = 200, trailing = true, leading = true) {
  if (delay <= 0)
    return value3;
  const throttled = ref(value3.value);
  const updater = useThrottleFn(() => {
    throttled.value = value3.value;
  }, delay, trailing, leading);
  watch(value3, () => updater());
  return throttled;
}
__name(refThrottled, "refThrottled");
function refWithControl(initial, options5 = {}) {
  let source = initial;
  let track2;
  let trigger2;
  const ref2 = customRef((_track, _trigger) => {
    track2 = _track;
    trigger2 = _trigger;
    return {
      get() {
        return get22();
      },
      set(v2) {
        set22(v2);
      }
    };
  });
  function get22(tracking = true) {
    if (tracking)
      track2();
    return source;
  }
  __name(get22, "get2");
  function set22(value3, triggering = true) {
    var _a2, _b;
    if (value3 === source)
      return;
    const old = source;
    if (((_a2 = options5.onBeforeChange) == null ? void 0 : _a2.call(options5, value3, old)) === false)
      return;
    source = value3;
    (_b = options5.onChanged) == null ? void 0 : _b.call(options5, value3, old);
    if (triggering)
      trigger2();
  }
  __name(set22, "set2");
  const untrackedGet = /* @__PURE__ */ __name(() => get22(false), "untrackedGet");
  const silentSet = /* @__PURE__ */ __name((v2) => set22(v2, false), "silentSet");
  const peek = /* @__PURE__ */ __name(() => get22(false), "peek");
  const lay = /* @__PURE__ */ __name((v2) => set22(v2, false), "lay");
  return extendRef(
    ref2,
    {
      get: get22,
      set: set22,
      untrackedGet,
      silentSet,
      peek,
      lay
    },
    { enumerable: true }
  );
}
__name(refWithControl, "refWithControl");
const controlledRef = refWithControl;
function set$1(...args) {
  if (args.length === 2) {
    const [ref2, value3] = args;
    ref2.value = value3;
  }
  if (args.length === 3) {
    if (isVue2$1) {
      set$2(...args);
    } else {
      const [target2, key, value3] = args;
      target2[key] = value3;
    }
  }
}
__name(set$1, "set$1");
function watchWithFilter(source, cb, options5 = {}) {
  const {
    eventFilter = bypassFilter,
    ...watchOptions
  } = options5;
  return watch(
    source,
    createFilterWrapper(
      eventFilter,
      cb
    ),
    watchOptions
  );
}
__name(watchWithFilter, "watchWithFilter");
function watchPausable(source, cb, options5 = {}) {
  const {
    eventFilter: filter4,
    ...watchOptions
  } = options5;
  const { eventFilter, pause, resume, isActive: isActive2 } = pausableFilter(filter4);
  const stop2 = watchWithFilter(
    source,
    cb,
    {
      ...watchOptions,
      eventFilter
    }
  );
  return { stop: stop2, pause, resume, isActive: isActive2 };
}
__name(watchPausable, "watchPausable");
function syncRef(left, right, ...[options5]) {
  const {
    flush: flush2 = "sync",
    deep = false,
    immediate = true,
    direction = "both",
    transform: transform2 = {}
  } = options5 || {};
  const watchers = [];
  const transformLTR = "ltr" in transform2 && transform2.ltr || ((v2) => v2);
  const transformRTL = "rtl" in transform2 && transform2.rtl || ((v2) => v2);
  if (direction === "both" || direction === "ltr") {
    watchers.push(watchPausable(
      left,
      (newValue2) => {
        watchers.forEach((w2) => w2.pause());
        right.value = transformLTR(newValue2);
        watchers.forEach((w2) => w2.resume());
      },
      { flush: flush2, deep, immediate }
    ));
  }
  if (direction === "both" || direction === "rtl") {
    watchers.push(watchPausable(
      right,
      (newValue2) => {
        watchers.forEach((w2) => w2.pause());
        left.value = transformRTL(newValue2);
        watchers.forEach((w2) => w2.resume());
      },
      { flush: flush2, deep, immediate }
    ));
  }
  const stop2 = /* @__PURE__ */ __name(() => {
    watchers.forEach((w2) => w2.stop());
  }, "stop");
  return stop2;
}
__name(syncRef, "syncRef");
function syncRefs(source, targets, options5 = {}) {
  const {
    flush: flush2 = "sync",
    deep = false,
    immediate = true
  } = options5;
  if (!Array.isArray(targets))
    targets = [targets];
  return watch(
    source,
    (newValue2) => targets.forEach((target2) => target2.value = newValue2),
    { flush: flush2, deep, immediate }
  );
}
__name(syncRefs, "syncRefs");
function toRefs(objectRef, options5 = {}) {
  if (!isRef(objectRef))
    return toRefs$1(objectRef);
  const result = Array.isArray(objectRef.value) ? Array.from({ length: objectRef.value.length }) : {};
  for (const key in objectRef.value) {
    result[key] = customRef(() => ({
      get() {
        return objectRef.value[key];
      },
      set(v2) {
        var _a2;
        const replaceRef = (_a2 = toValue$3(options5.replaceRef)) != null ? _a2 : true;
        if (replaceRef) {
          if (Array.isArray(objectRef.value)) {
            const copy2 = [...objectRef.value];
            copy2[key] = v2;
            objectRef.value = copy2;
          } else {
            const newObject = { ...objectRef.value, [key]: v2 };
            Object.setPrototypeOf(newObject, Object.getPrototypeOf(objectRef.value));
            objectRef.value = newObject;
          }
        } else {
          objectRef.value[key] = v2;
        }
      }
    }));
  }
  return result;
}
__name(toRefs, "toRefs");
function tryOnBeforeMount(fn, sync = true, target2) {
  const instance = getLifeCycleTarget(target2);
  if (instance)
    onBeforeMount(fn, target2);
  else if (sync)
    fn();
  else
    nextTick(fn);
}
__name(tryOnBeforeMount, "tryOnBeforeMount");
function tryOnBeforeUnmount(fn, target2) {
  const instance = getLifeCycleTarget(target2);
  if (instance)
    onBeforeUnmount(fn, target2);
}
__name(tryOnBeforeUnmount, "tryOnBeforeUnmount");
function tryOnMounted$2(fn, sync = true, target2) {
  const instance = getLifeCycleTarget();
  if (instance)
    onMounted(fn, target2);
  else if (sync)
    fn();
  else
    nextTick(fn);
}
__name(tryOnMounted$2, "tryOnMounted$2");
function tryOnUnmounted(fn, target2) {
  const instance = getLifeCycleTarget(target2);
  if (instance)
    onUnmounted(fn, target2);
}
__name(tryOnUnmounted, "tryOnUnmounted");
function createUntil(r2, isNot = false) {
  function toMatch(condition, { flush: flush2 = "sync", deep = false, timeout, throwOnTimeout } = {}) {
    let stop2 = null;
    const watcher = new Promise((resolve2) => {
      stop2 = watch(
        r2,
        (v2) => {
          if (condition(v2) !== isNot) {
            if (stop2)
              stop2();
            else
              nextTick(() => stop2 == null ? void 0 : stop2());
            resolve2(v2);
          }
        },
        {
          flush: flush2,
          deep,
          immediate: true
        }
      );
    });
    const promises = [watcher];
    if (timeout != null) {
      promises.push(
        promiseTimeout(timeout, throwOnTimeout).then(() => toValue$3(r2)).finally(() => stop2 == null ? void 0 : stop2())
      );
    }
    return Promise.race(promises);
  }
  __name(toMatch, "toMatch");
  function toBe(value3, options5) {
    if (!isRef(value3))
      return toMatch((v2) => v2 === value3, options5);
    const { flush: flush2 = "sync", deep = false, timeout, throwOnTimeout } = options5 != null ? options5 : {};
    let stop2 = null;
    const watcher = new Promise((resolve2) => {
      stop2 = watch(
        [r2, value3],
        ([v1, v2]) => {
          if (isNot !== (v1 === v2)) {
            if (stop2)
              stop2();
            else
              nextTick(() => stop2 == null ? void 0 : stop2());
            resolve2(v1);
          }
        },
        {
          flush: flush2,
          deep,
          immediate: true
        }
      );
    });
    const promises = [watcher];
    if (timeout != null) {
      promises.push(
        promiseTimeout(timeout, throwOnTimeout).then(() => toValue$3(r2)).finally(() => {
          stop2 == null ? void 0 : stop2();
          return toValue$3(r2);
        })
      );
    }
    return Promise.race(promises);
  }
  __name(toBe, "toBe");
  function toBeTruthy(options5) {
    return toMatch((v2) => Boolean(v2), options5);
  }
  __name(toBeTruthy, "toBeTruthy");
  function toBeNull(options5) {
    return toBe(null, options5);
  }
  __name(toBeNull, "toBeNull");
  function toBeUndefined(options5) {
    return toBe(void 0, options5);
  }
  __name(toBeUndefined, "toBeUndefined");
  function toBeNaN(options5) {
    return toMatch(Number.isNaN, options5);
  }
  __name(toBeNaN, "toBeNaN");
  function toContains(value3, options5) {
    return toMatch((v2) => {
      const array = Array.from(v2);
      return array.includes(value3) || array.includes(toValue$3(value3));
    }, options5);
  }
  __name(toContains, "toContains");
  function changed(options5) {
    return changedTimes(1, options5);
  }
  __name(changed, "changed");
  function changedTimes(n2 = 1, options5) {
    let count = -1;
    return toMatch(() => {
      count += 1;
      return count >= n2;
    }, options5);
  }
  __name(changedTimes, "changedTimes");
  if (Array.isArray(toValue$3(r2))) {
    const instance = {
      toMatch,
      toContains,
      changed,
      changedTimes,
      get not() {
        return createUntil(r2, !isNot);
      }
    };
    return instance;
  } else {
    const instance = {
      toMatch,
      toBe,
      toBeTruthy,
      toBeNull,
      toBeNaN,
      toBeUndefined,
      changed,
      changedTimes,
      get not() {
        return createUntil(r2, !isNot);
      }
    };
    return instance;
  }
}
__name(createUntil, "createUntil");
function until(r2) {
  return createUntil(r2);
}
__name(until, "until");
function defaultComparator(value3, othVal) {
  return value3 === othVal;
}
__name(defaultComparator, "defaultComparator");
function useArrayDifference(...args) {
  var _a2;
  const list2 = args[0];
  const values = args[1];
  let compareFn = (_a2 = args[2]) != null ? _a2 : defaultComparator;
  if (typeof compareFn === "string") {
    const key = compareFn;
    compareFn = /* @__PURE__ */ __name((value3, othVal) => value3[key] === othVal[key], "compareFn");
  }
  return computed(() => toValue$3(list2).filter((x2) => toValue$3(values).findIndex((y2) => compareFn(x2, y2)) === -1));
}
__name(useArrayDifference, "useArrayDifference");
function useArrayEvery(list2, fn) {
  return computed(() => toValue$3(list2).every((element, index2, array) => fn(toValue$3(element), index2, array)));
}
__name(useArrayEvery, "useArrayEvery");
function useArrayFilter(list2, fn) {
  return computed(() => toValue$3(list2).map((i2) => toValue$3(i2)).filter(fn));
}
__name(useArrayFilter, "useArrayFilter");
function useArrayFind(list2, fn) {
  return computed(() => toValue$3(
    toValue$3(list2).find((element, index2, array) => fn(toValue$3(element), index2, array))
  ));
}
__name(useArrayFind, "useArrayFind");
function useArrayFindIndex(list2, fn) {
  return computed(() => toValue$3(list2).findIndex((element, index2, array) => fn(toValue$3(element), index2, array)));
}
__name(useArrayFindIndex, "useArrayFindIndex");
function findLast$2(arr, cb) {
  let index2 = arr.length;
  while (index2-- > 0) {
    if (cb(arr[index2], index2, arr))
      return arr[index2];
  }
  return void 0;
}
__name(findLast$2, "findLast$2");
function useArrayFindLast(list2, fn) {
  return computed(() => toValue$3(
    !Array.prototype.findLast ? findLast$2(toValue$3(list2), (element, index2, array) => fn(toValue$3(element), index2, array)) : toValue$3(list2).findLast((element, index2, array) => fn(toValue$3(element), index2, array))
  ));
}
__name(useArrayFindLast, "useArrayFindLast");
function isArrayIncludesOptions(obj) {
  return isObject$d(obj) && containsProp(obj, "formIndex", "comparator");
}
__name(isArrayIncludesOptions, "isArrayIncludesOptions");
function useArrayIncludes(...args) {
  var _a2;
  const list2 = args[0];
  const value3 = args[1];
  let comparator = args[2];
  let formIndex = 0;
  if (isArrayIncludesOptions(comparator)) {
    formIndex = (_a2 = comparator.fromIndex) != null ? _a2 : 0;
    comparator = comparator.comparator;
  }
  if (typeof comparator === "string") {
    const key = comparator;
    comparator = /* @__PURE__ */ __name((element, value22) => element[key] === toValue$3(value22), "comparator");
  }
  comparator = comparator != null ? comparator : (element, value22) => element === toValue$3(value22);
  return computed(() => toValue$3(list2).slice(formIndex).some((element, index2, array) => comparator(
    toValue$3(element),
    toValue$3(value3),
    index2,
    toValue$3(array)
  )));
}
__name(useArrayIncludes, "useArrayIncludes");
function useArrayJoin(list2, separator) {
  return computed(() => toValue$3(list2).map((i2) => toValue$3(i2)).join(toValue$3(separator)));
}
__name(useArrayJoin, "useArrayJoin");
function useArrayMap(list2, fn) {
  return computed(() => toValue$3(list2).map((i2) => toValue$3(i2)).map(fn));
}
__name(useArrayMap, "useArrayMap");
function useArrayReduce(list2, reducer, ...args) {
  const reduceCallback = /* @__PURE__ */ __name((sum, value3, index2) => reducer(toValue$3(sum), toValue$3(value3), index2), "reduceCallback");
  return computed(() => {
    const resolved = toValue$3(list2);
    return args.length ? resolved.reduce(reduceCallback, toValue$3(args[0])) : resolved.reduce(reduceCallback);
  });
}
__name(useArrayReduce, "useArrayReduce");
function useArraySome(list2, fn) {
  return computed(() => toValue$3(list2).some((element, index2, array) => fn(toValue$3(element), index2, array)));
}
__name(useArraySome, "useArraySome");
function uniq(array) {
  return Array.from(new Set(array));
}
__name(uniq, "uniq");
function uniqueElementsBy(array, fn) {
  return array.reduce((acc, v2) => {
    if (!acc.some((x2) => fn(v2, x2, array)))
      acc.push(v2);
    return acc;
  }, []);
}
__name(uniqueElementsBy, "uniqueElementsBy");
function useArrayUnique(list2, compareFn) {
  return computed(() => {
    const resolvedList = toValue$3(list2).map((element) => toValue$3(element));
    return compareFn ? uniqueElementsBy(resolvedList, compareFn) : uniq(resolvedList);
  });
}
__name(useArrayUnique, "useArrayUnique");
function useCounter(initialValue = 0, options5 = {}) {
  let _initialValue = unref(initialValue);
  const count = ref(initialValue);
  const {
    max = Number.POSITIVE_INFINITY,
    min = Number.NEGATIVE_INFINITY
  } = options5;
  const inc2 = /* @__PURE__ */ __name((delta2 = 1) => count.value = Math.max(Math.min(max, count.value + delta2), min), "inc");
  const dec = /* @__PURE__ */ __name((delta2 = 1) => count.value = Math.min(Math.max(min, count.value - delta2), max), "dec");
  const get22 = /* @__PURE__ */ __name(() => count.value, "get2");
  const set22 = /* @__PURE__ */ __name((val) => count.value = Math.max(min, Math.min(max, val)), "set2");
  const reset2 = /* @__PURE__ */ __name((val = _initialValue) => {
    _initialValue = val;
    return set22(val);
  }, "reset");
  return { count, inc: inc2, dec, get: get22, set: set22, reset: reset2 };
}
__name(useCounter, "useCounter");
const REGEX_PARSE = /^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[T\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/i;
const REGEX_FORMAT = /[YMDHhms]o|\[([^\]]+)\]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a{1,2}|A{1,2}|m{1,2}|s{1,2}|Z{1,2}|SSS/g;
function defaultMeridiem(hours, minutes, isLowercase, hasPeriod) {
  let m2 = hours < 12 ? "AM" : "PM";
  if (hasPeriod)
    m2 = m2.split("").reduce((acc, curr) => acc += `${curr}.`, "");
  return isLowercase ? m2.toLowerCase() : m2;
}
__name(defaultMeridiem, "defaultMeridiem");
function formatOrdinal(num) {
  const suffixes = ["th", "st", "nd", "rd"];
  const v2 = num % 100;
  return num + (suffixes[(v2 - 20) % 10] || suffixes[v2] || suffixes[0]);
}
__name(formatOrdinal, "formatOrdinal");
function formatDate$1(date, formatStr, options5 = {}) {
  var _a2;
  const years = date.getFullYear();
  const month = date.getMonth();
  const days = date.getDate();
  const hours = date.getHours();
  const minutes = date.getMinutes();
  const seconds = date.getSeconds();
  const milliseconds = date.getMilliseconds();
  const day = date.getDay();
  const meridiem = (_a2 = options5.customMeridiem) != null ? _a2 : defaultMeridiem;
  const matches2 = {
    Yo: /* @__PURE__ */ __name(() => formatOrdinal(years), "Yo"),
    YY: /* @__PURE__ */ __name(() => String(years).slice(-2), "YY"),
    YYYY: /* @__PURE__ */ __name(() => years, "YYYY"),
    M: /* @__PURE__ */ __name(() => month + 1, "M"),
    Mo: /* @__PURE__ */ __name(() => formatOrdinal(month + 1), "Mo"),
    MM: /* @__PURE__ */ __name(() => `${month + 1}`.padStart(2, "0"), "MM"),
    MMM: /* @__PURE__ */ __name(() => date.toLocaleDateString(toValue$3(options5.locales), { month: "short" }), "MMM"),
    MMMM: /* @__PURE__ */ __name(() => date.toLocaleDateString(toValue$3(options5.locales), { month: "long" }), "MMMM"),
    D: /* @__PURE__ */ __name(() => String(days), "D"),
    Do: /* @__PURE__ */ __name(() => formatOrdinal(days), "Do"),
    DD: /* @__PURE__ */ __name(() => `${days}`.padStart(2, "0"), "DD"),
    H: /* @__PURE__ */ __name(() => String(hours), "H"),
    Ho: /* @__PURE__ */ __name(() => formatOrdinal(hours), "Ho"),
    HH: /* @__PURE__ */ __name(() => `${hours}`.padStart(2, "0"), "HH"),
    h: /* @__PURE__ */ __name(() => `${hours % 12 || 12}`.padStart(1, "0"), "h"),
    ho: /* @__PURE__ */ __name(() => formatOrdinal(hours % 12 || 12), "ho"),
    hh: /* @__PURE__ */ __name(() => `${hours % 12 || 12}`.padStart(2, "0"), "hh"),
    m: /* @__PURE__ */ __name(() => String(minutes), "m"),
    mo: /* @__PURE__ */ __name(() => formatOrdinal(minutes), "mo"),
    mm: /* @__PURE__ */ __name(() => `${minutes}`.padStart(2, "0"), "mm"),
    s: /* @__PURE__ */ __name(() => String(seconds), "s"),
    so: /* @__PURE__ */ __name(() => formatOrdinal(seconds), "so"),
    ss: /* @__PURE__ */ __name(() => `${seconds}`.padStart(2, "0"), "ss"),
    SSS: /* @__PURE__ */ __name(() => `${milliseconds}`.padStart(3, "0"), "SSS"),
    d: /* @__PURE__ */ __name(() => day, "d"),
    dd: /* @__PURE__ */ __name(() => date.toLocaleDateString(toValue$3(options5.locales), { weekday: "narrow" }), "dd"),
    ddd: /* @__PURE__ */ __name(() => date.toLocaleDateString(toValue$3(options5.locales), { weekday: "short" }), "ddd"),
    dddd: /* @__PURE__ */ __name(() => date.toLocaleDateString(toValue$3(options5.locales), { weekday: "long" }), "dddd"),
    A: /* @__PURE__ */ __name(() => meridiem(hours, minutes), "A"),
    AA: /* @__PURE__ */ __name(() => meridiem(hours, minutes, false, true), "AA"),
    a: /* @__PURE__ */ __name(() => meridiem(hours, minutes, true), "a"),
    aa: /* @__PURE__ */ __name(() => meridiem(hours, minutes, true, true), "aa")
  };
  return formatStr.replace(REGEX_FORMAT, (match2, $1) => {
    var _a22, _b;
    return (_b = $1 != null ? $1 : (_a22 = matches2[match2]) == null ? void 0 : _a22.call(matches2)) != null ? _b : match2;
  });
}
__name(formatDate$1, "formatDate$1");
function normalizeDate(date) {
  if (date === null)
    return new Date(Number.NaN);
  if (date === void 0)
    return /* @__PURE__ */ new Date();
  if (date instanceof Date)
    return new Date(date);
  if (typeof date === "string" && !/Z$/i.test(date)) {
    const d2 = date.match(REGEX_PARSE);
    if (d2) {
      const m2 = d2[2] - 1 || 0;
      const ms = (d2[7] || "0").substring(0, 3);
      return new Date(d2[1], m2, d2[3] || 1, d2[4] || 0, d2[5] || 0, d2[6] || 0, ms);
    }
  }
  return new Date(date);
}
__name(normalizeDate, "normalizeDate");
function useDateFormat(date, formatStr = "HH:mm:ss", options5 = {}) {
  return computed(() => formatDate$1(normalizeDate(toValue$3(date)), toValue$3(formatStr), options5));
}
__name(useDateFormat, "useDateFormat");
function useIntervalFn(cb, interval = 1e3, options5 = {}) {
  const {
    immediate = true,
    immediateCallback = false
  } = options5;
  let timer = null;
  const isActive2 = ref(false);
  function clean() {
    if (timer) {
      clearInterval(timer);
      timer = null;
    }
  }
  __name(clean, "clean");
  function pause() {
    isActive2.value = false;
    clean();
  }
  __name(pause, "pause");
  function resume() {
    const intervalValue = toValue$3(interval);
    if (intervalValue <= 0)
      return;
    isActive2.value = true;
    if (immediateCallback)
      cb();
    clean();
    timer = setInterval(cb, intervalValue);
  }
  __name(resume, "resume");
  if (immediate && isClient$1)
    resume();
  if (isRef(interval) || typeof interval === "function") {
    const stopWatch = watch(interval, () => {
      if (isActive2.value && isClient$1)
        resume();
    });
    tryOnScopeDispose(stopWatch);
  }
  tryOnScopeDispose(pause);
  return {
    isActive: isActive2,
    pause,
    resume
  };
}
__name(useIntervalFn, "useIntervalFn");
function useInterval(interval = 1e3, options5 = {}) {
  const {
    controls: exposeControls = false,
    immediate = true,
    callback
  } = options5;
  const counter = ref(0);
  const update = /* @__PURE__ */ __name(() => counter.value += 1, "update");
  const reset2 = /* @__PURE__ */ __name(() => {
    counter.value = 0;
  }, "reset");
  const controls = useIntervalFn(
    callback ? () => {
      update();
      callback(counter.value);
    } : update,
    interval,
    { immediate }
  );
  if (exposeControls) {
    return {
      counter,
      reset: reset2,
      ...controls
    };
  } else {
    return counter;
  }
}
__name(useInterval, "useInterval");
function useLastChanged(source, options5 = {}) {
  var _a2;
  const ms = ref((_a2 = options5.initialValue) != null ? _a2 : null);
  watch(
    source,
    () => ms.value = timestamp(),
    options5
  );
  return ms;
}
__name(useLastChanged, "useLastChanged");
function useTimeoutFn(cb, interval, options5 = {}) {
  const {
    immediate = true
  } = options5;
  const isPending = ref(false);
  let timer = null;
  function clear() {
    if (timer) {
      clearTimeout(timer);
      timer = null;
    }
  }
  __name(clear, "clear");
  function stop2() {
    isPending.value = false;
    clear();
  }
  __name(stop2, "stop");
  function start2(...args) {
    clear();
    isPending.value = true;
    timer = setTimeout(() => {
      isPending.value = false;
      timer = null;
      cb(...args);
    }, toValue$3(interval));
  }
  __name(start2, "start");
  if (immediate) {
    isPending.value = true;
    if (isClient$1)
      start2();
  }
  tryOnScopeDispose(stop2);
  return {
    isPending: readonly(isPending),
    start: start2,
    stop: stop2
  };
}
__name(useTimeoutFn, "useTimeoutFn");
function useTimeout(interval = 1e3, options5 = {}) {
  const {
    controls: exposeControls = false,
    callback
  } = options5;
  const controls = useTimeoutFn(
    callback != null ? callback : noop$1,
    interval,
    options5
  );
  const ready = computed(() => !controls.isPending.value);
  if (exposeControls) {
    return {
      ready,
      ...controls
    };
  } else {
    return ready;
  }
}
__name(useTimeout, "useTimeout");
function useToNumber(value3, options5 = {}) {
  const {
    method = "parseFloat",
    radix,
    nanToZero
  } = options5;
  return computed(() => {
    let resolved = toValue$3(value3);
    if (typeof resolved === "string")
      resolved = Number[method](resolved, radix);
    if (nanToZero && Number.isNaN(resolved))
      resolved = 0;
    return resolved;
  });
}
__name(useToNumber, "useToNumber");
function useToString(value3) {
  return computed(() => `${toValue$3(value3)}`);
}
__name(useToString, "useToString");
function useToggle(initialValue = false, options5 = {}) {
  const {
    truthyValue = true,
    falsyValue = false
  } = options5;
  const valueIsRef = isRef(initialValue);
  const _value = ref(initialValue);
  function toggle5(value3) {
    if (arguments.length) {
      _value.value = value3;
      return _value.value;
    } else {
      const truthy = toValue$3(truthyValue);
      _value.value = _value.value === truthy ? toValue$3(falsyValue) : truthy;
      return _value.value;
    }
  }
  __name(toggle5, "toggle");
  if (valueIsRef)
    return toggle5;
  else
    return [_value, toggle5];
}
__name(useToggle, "useToggle");
function watchArray(source, cb, options5) {
  let oldList = (options5 == null ? void 0 : options5.immediate) ? [] : [...source instanceof Function ? source() : Array.isArray(source) ? source : toValue$3(source)];
  return watch(source, (newList, _2, onCleanup) => {
    const oldListRemains = Array.from({ length: oldList.length });
    const added = [];
    for (const obj of newList) {
      let found2 = false;
      for (let i2 = 0; i2 < oldList.length; i2++) {
        if (!oldListRemains[i2] && obj === oldList[i2]) {
          oldListRemains[i2] = true;
          found2 = true;
          break;
        }
      }
      if (!found2)
        added.push(obj);
    }
    const removed = oldList.filter((_22, i2) => !oldListRemains[i2]);
    cb(newList, oldList, added, removed, onCleanup);
    oldList = [...newList];
  }, options5);
}
__name(watchArray, "watchArray");
function watchAtMost(source, cb, options5) {
  const {
    count,
    ...watchOptions
  } = options5;
  const current = ref(0);
  const stop2 = watchWithFilter(
    source,
    (...args) => {
      current.value += 1;
      if (current.value >= toValue$3(count))
        nextTick(() => stop2());
      cb(...args);
    },
    watchOptions
  );
  return { count: current, stop: stop2 };
}
__name(watchAtMost, "watchAtMost");
function watchDebounced(source, cb, options5 = {}) {
  const {
    debounce: debounce2 = 0,
    maxWait = void 0,
    ...watchOptions
  } = options5;
  return watchWithFilter(
    source,
    cb,
    {
      ...watchOptions,
      eventFilter: debounceFilter(debounce2, { maxWait })
    }
  );
}
__name(watchDebounced, "watchDebounced");
function watchDeep(source, cb, options5) {
  return watch(
    source,
    cb,
    {
      ...options5,
      deep: true
    }
  );
}
__name(watchDeep, "watchDeep");
function watchIgnorable(source, cb, options5 = {}) {
  const {
    eventFilter = bypassFilter,
    ...watchOptions
  } = options5;
  const filteredCb = createFilterWrapper(
    eventFilter,
    cb
  );
  let ignoreUpdates;
  let ignorePrevAsyncUpdates;
  let stop2;
  if (watchOptions.flush === "sync") {
    const ignore = ref(false);
    ignorePrevAsyncUpdates = /* @__PURE__ */ __name(() => {
    }, "ignorePrevAsyncUpdates");
    ignoreUpdates = /* @__PURE__ */ __name((updater) => {
      ignore.value = true;
      updater();
      ignore.value = false;
    }, "ignoreUpdates");
    stop2 = watch(
      source,
      (...args) => {
        if (!ignore.value)
          filteredCb(...args);
      },
      watchOptions
    );
  } else {
    const disposables = [];
    const ignoreCounter = ref(0);
    const syncCounter = ref(0);
    ignorePrevAsyncUpdates = /* @__PURE__ */ __name(() => {
      ignoreCounter.value = syncCounter.value;
    }, "ignorePrevAsyncUpdates");
    disposables.push(
      watch(
        source,
        () => {
          syncCounter.value++;
        },
        { ...watchOptions, flush: "sync" }
      )
    );
    ignoreUpdates = /* @__PURE__ */ __name((updater) => {
      const syncCounterPrev = syncCounter.value;
      updater();
      ignoreCounter.value += syncCounter.value - syncCounterPrev;
    }, "ignoreUpdates");
    disposables.push(
      watch(
        source,
        (...args) => {
          const ignore = ignoreCounter.value > 0 && ignoreCounter.value === syncCounter.value;
          ignoreCounter.value = 0;
          syncCounter.value = 0;
          if (ignore)
            return;
          filteredCb(...args);
        },
        watchOptions
      )
    );
    stop2 = /* @__PURE__ */ __name(() => {
      disposables.forEach((fn) => fn());
    }, "stop");
  }
  return { stop: stop2, ignoreUpdates, ignorePrevAsyncUpdates };
}
__name(watchIgnorable, "watchIgnorable");
function watchImmediate(source, cb, options5) {
  return watch(
    source,
    cb,
    {
      ...options5,
      immediate: true
    }
  );
}
__name(watchImmediate, "watchImmediate");
function watchOnce(source, cb, options5) {
  const stop2 = watch(source, (...args) => {
    nextTick(() => stop2());
    return cb(...args);
  }, options5);
  return stop2;
}
__name(watchOnce, "watchOnce");
function watchThrottled(source, cb, options5 = {}) {
  const {
    throttle: throttle2 = 0,
    trailing = true,
    leading = true,
    ...watchOptions
  } = options5;
  return watchWithFilter(
    source,
    cb,
    {
      ...watchOptions,
      eventFilter: throttleFilter(throttle2, trailing, leading)
    }
  );
}
__name(watchThrottled, "watchThrottled");
function watchTriggerable(source, cb, options5 = {}) {
  let cleanupFn;
  function onEffect() {
    if (!cleanupFn)
      return;
    const fn = cleanupFn;
    cleanupFn = void 0;
    fn();
  }
  __name(onEffect, "onEffect");
  function onCleanup(callback) {
    cleanupFn = callback;
  }
  __name(onCleanup, "onCleanup");
  const _cb = /* @__PURE__ */ __name((value3, oldValue) => {
    onEffect();
    return cb(value3, oldValue, onCleanup);
  }, "_cb");
  const res = watchIgnorable(source, _cb, options5);
  const { ignoreUpdates } = res;
  const trigger2 = /* @__PURE__ */ __name(() => {
    let res2;
    ignoreUpdates(() => {
      res2 = _cb(getWatchSources(source), getOldValue(source));
    });
    return res2;
  }, "trigger");
  return {
    ...res,
    trigger: trigger2
  };
}
__name(watchTriggerable, "watchTriggerable");
function getWatchSources(sources) {
  if (isReactive(sources))
    return sources;
  if (Array.isArray(sources))
    return sources.map((item3) => toValue$3(item3));
  return toValue$3(sources);
}
__name(getWatchSources, "getWatchSources");
function getOldValue(source) {
  return Array.isArray(source) ? source.map(() => void 0) : void 0;
}
__name(getOldValue, "getOldValue");
function whenever(source, cb, options5) {
  const stop2 = watch(
    source,
    (v2, ov, onInvalidate) => {
      if (v2) {
        if (options5 == null ? void 0 : options5.once)
          nextTick(() => stop2());
        cb(v2, ov, onInvalidate);
      }
    },
    {
      ...options5,
      once: false
    }
  );
  return stop2;
}
__name(whenever, "whenever");
var isVue2 = false;
var isVue3 = true;
var Vue2 = void 0;
function install$6() {
}
__name(install$6, "install$6");
function set(target2, key, val) {
  if (Array.isArray(target2)) {
    target2.length = Math.max(target2.length, key);
    target2.splice(key, 1, val);
    return val;
  }
  target2[key] = val;
  return val;
}
__name(set, "set");
function del$1(target2, key) {
  if (Array.isArray(target2)) {
    target2.splice(key, 1);
    return;
  }
  delete target2[key];
}
__name(del$1, "del$1");
function computedAsync(evaluationCallback, initialState, optionsOrRef) {
  let options5;
  if (isRef(optionsOrRef)) {
    options5 = {
      evaluating: optionsOrRef
    };
  } else {
    options5 = optionsOrRef || {};
  }
  const {
    lazy = false,
    evaluating = void 0,
    shallow = true,
    onError = noop$1
  } = options5;
  const started = ref(!lazy);
  const current = shallow ? shallowRef(initialState) : ref(initialState);
  let counter = 0;
  watchEffect(async (onInvalidate) => {
    if (!started.value)
      return;
    counter++;
    const counterAtBeginning = counter;
    let hasFinished = false;
    if (evaluating) {
      Promise.resolve().then(() => {
        evaluating.value = true;
      });
    }
    try {
      const result = await evaluationCallback((cancelCallback) => {
        onInvalidate(() => {
          if (evaluating)
            evaluating.value = false;
          if (!hasFinished)
            cancelCallback();
        });
      });
      if (counterAtBeginning === counter)
        current.value = result;
    } catch (e2) {
      onError(e2);
    } finally {
      if (evaluating && counterAtBeginning === counter)
        evaluating.value = false;
      hasFinished = true;
    }
  });
  if (lazy) {
    return computed(() => {
      started.value = true;
      return current.value;
    });
  } else {
    return current;
  }
}
__name(computedAsync, "computedAsync");
function computedInject(key, options5, defaultSource, treatDefaultAsFactory) {
  let source = inject(key);
  if (defaultSource)
    source = inject(key, defaultSource);
  if (treatDefaultAsFactory)
    source = inject(key, defaultSource, treatDefaultAsFactory);
  if (typeof options5 === "function") {
    return computed((ctx) => options5(source, ctx));
  } else {
    return computed({
      get: /* @__PURE__ */ __name((ctx) => options5.get(source, ctx), "get"),
      set: options5.set
    });
  }
}
__name(computedInject, "computedInject");
function createReusableTemplate(options5 = {}) {
  if (!isVue3 && !version.startsWith("2.7.")) {
    if (false)
      throw new Error("[VueUse] createReusableTemplate only works in Vue 2.7 or above.");
    return;
  }
  const {
    inheritAttrs = true
  } = options5;
  const render2 = shallowRef();
  const define = /* @__PURE__ */ defineComponent({
    setup(_2, { slots }) {
      return () => {
        render2.value = slots.default;
      };
    }
  });
  const reuse = /* @__PURE__ */ defineComponent({
    inheritAttrs,
    setup(_2, { attrs: attrs7, slots }) {
      return () => {
        var _a2;
        if (!render2.value && false)
          throw new Error("[VueUse] Failed to find the definition of reusable template");
        const vnode = (_a2 = render2.value) == null ? void 0 : _a2.call(render2, { ...keysToCamelKebabCase(attrs7), $slots: slots });
        return inheritAttrs && (vnode == null ? void 0 : vnode.length) === 1 ? vnode[0] : vnode;
      };
    }
  });
  return makeDestructurable(
    { define, reuse },
    [define, reuse]
  );
}
__name(createReusableTemplate, "createReusableTemplate");
function keysToCamelKebabCase(obj) {
  const newObj = {};
  for (const key in obj)
    newObj[camelize(key)] = obj[key];
  return newObj;
}
__name(keysToCamelKebabCase, "keysToCamelKebabCase");
function createTemplatePromise(options5 = {}) {
  if (!isVue3) {
    if (false)
      throw new Error("[VueUse] createTemplatePromise only works in Vue 3 or above.");
    return;
  }
  let index2 = 0;
  const instances = ref([]);
  function create3(...args) {
    const props = shallowReactive({
      key: index2++,
      args,
      promise: void 0,
      resolve: /* @__PURE__ */ __name(() => {
      }, "resolve"),
      reject: /* @__PURE__ */ __name(() => {
      }, "reject"),
      isResolving: false,
      options: options5
    });
    instances.value.push(props);
    props.promise = new Promise((_resolve, _reject) => {
      props.resolve = (v2) => {
        props.isResolving = true;
        return _resolve(v2);
      };
      props.reject = _reject;
    }).finally(() => {
      props.promise = void 0;
      const index22 = instances.value.indexOf(props);
      if (index22 !== -1)
        instances.value.splice(index22, 1);
    });
    return props.promise;
  }
  __name(create3, "create");
  function start2(...args) {
    if (options5.singleton && instances.value.length > 0)
      return instances.value[0].promise;
    return create3(...args);
  }
  __name(start2, "start");
  const component = /* @__PURE__ */ defineComponent((_2, { slots }) => {
    const renderList2 = /* @__PURE__ */ __name(() => instances.value.map((props) => {
      var _a2;
      return h(Fragment$1, { key: props.key }, (_a2 = slots.default) == null ? void 0 : _a2.call(slots, props));
    }), "renderList");
    if (options5.transition)
      return () => h(TransitionGroup, options5.transition, renderList2);
    return renderList2;
  });
  component.start = start2;
  return component;
}
__name(createTemplatePromise, "createTemplatePromise");
function createUnrefFn(fn) {
  return function(...args) {
    return fn.apply(this, args.map((i2) => toValue$3(i2)));
  };
}
__name(createUnrefFn, "createUnrefFn");
function unrefElement(elRef) {
  var _a2;
  const plain = toValue$3(elRef);
  return (_a2 = plain == null ? void 0 : plain.$el) != null ? _a2 : plain;
}
__name(unrefElement, "unrefElement");
const defaultWindow = isClient$1 ? window : void 0;
const defaultDocument = isClient$1 ? window.document : void 0;
const defaultNavigator = isClient$1 ? window.navigator : void 0;
const defaultLocation = isClient$1 ? window.location : void 0;
function useEventListener(...args) {
  let target2;
  let events2;
  let listeners;
  let options5;
  if (typeof args[0] === "string" || Array.isArray(args[0])) {
    [events2, listeners, options5] = args;
    target2 = defaultWindow;
  } else {
    [target2, events2, listeners, options5] = args;
  }
  if (!target2)
    return noop$1;
  if (!Array.isArray(events2))
    events2 = [events2];
  if (!Array.isArray(listeners))
    listeners = [listeners];
  const cleanups = [];
  const cleanup = /* @__PURE__ */ __name(() => {
    cleanups.forEach((fn) => fn());
    cleanups.length = 0;
  }, "cleanup");
  const register3 = /* @__PURE__ */ __name((el, event, listener, options22) => {
    el.addEventListener(event, listener, options22);
    return () => el.removeEventListener(event, listener, options22);
  }, "register");
  const stopWatch = watch(
    () => [unrefElement(target2), toValue$3(options5)],
    ([el, options22]) => {
      cleanup();
      if (!el)
        return;
      const optionsClone = isObject$d(options22) ? { ...options22 } : options22;
      cleanups.push(
        ...events2.flatMap((event) => {
          return listeners.map((listener) => register3(el, event, listener, optionsClone));
        })
      );
    },
    { immediate: true, flush: "post" }
  );
  const stop2 = /* @__PURE__ */ __name(() => {
    stopWatch();
    cleanup();
  }, "stop");
  tryOnScopeDispose(stop2);
  return stop2;
}
__name(useEventListener, "useEventListener");
let _iOSWorkaround = false;
function onClickOutside(target2, handler14, options5 = {}) {
  const { window: window2 = defaultWindow, ignore = [], capture = true, detectIframe = false } = options5;
  if (!window2)
    return noop$1;
  if (isIOS$1 && !_iOSWorkaround) {
    _iOSWorkaround = true;
    Array.from(window2.document.body.children).forEach((el) => el.addEventListener("click", noop$1));
    window2.document.documentElement.addEventListener("click", noop$1);
  }
  let shouldListen = true;
  const shouldIgnore = /* @__PURE__ */ __name((event) => {
    return ignore.some((target22) => {
      if (typeof target22 === "string") {
        return Array.from(window2.document.querySelectorAll(target22)).some((el) => el === event.target || event.composedPath().includes(el));
      } else {
        const el = unrefElement(target22);
        return el && (event.target === el || event.composedPath().includes(el));
      }
    });
  }, "shouldIgnore");
  const listener = /* @__PURE__ */ __name((event) => {
    const el = unrefElement(target2);
    if (!el || el === event.target || event.composedPath().includes(el))
      return;
    if (event.detail === 0)
      shouldListen = !shouldIgnore(event);
    if (!shouldListen) {
      shouldListen = true;
      return;
    }
    handler14(event);
  }, "listener");
  const cleanup = [
    useEventListener(window2, "click", listener, { passive: true, capture }),
    useEventListener(window2, "pointerdown", (e2) => {
      const el = unrefElement(target2);
      shouldListen = !shouldIgnore(e2) && !!(el && !e2.composedPath().includes(el));
    }, { passive: true }),
    detectIframe && useEventListener(window2, "blur", (event) => {
      setTimeout(() => {
        var _a2;
        const el = unrefElement(target2);
        if (((_a2 = window2.document.activeElement) == null ? void 0 : _a2.tagName) === "IFRAME" && !(el == null ? void 0 : el.contains(window2.document.activeElement))) {
          handler14(event);
        }
      }, 0);
    })
  ].filter(Boolean);
  const stop2 = /* @__PURE__ */ __name(() => cleanup.forEach((fn) => fn()), "stop");
  return stop2;
}
__name(onClickOutside, "onClickOutside");
function createKeyPredicate(keyFilter) {
  if (typeof keyFilter === "function")
    return keyFilter;
  else if (typeof keyFilter === "string")
    return (event) => event.key === keyFilter;
  else if (Array.isArray(keyFilter))
    return (event) => keyFilter.includes(event.key);
  return () => true;
}
__name(createKeyPredicate, "createKeyPredicate");
function onKeyStroke(...args) {
  let key;
  let handler14;
  let options5 = {};
  if (args.length === 3) {
    key = args[0];
    handler14 = args[1];
    options5 = args[2];
  } else if (args.length === 2) {
    if (typeof args[1] === "object") {
      key = true;
      handler14 = args[0];
      options5 = args[1];
    } else {
      key = args[0];
      handler14 = args[1];
    }
  } else {
    key = true;
    handler14 = args[0];
  }
  const {
    target: target2 = defaultWindow,
    eventName = "keydown",
    passive = false,
    dedupe = false
  } = options5;
  const predicate = createKeyPredicate(key);
  const listener = /* @__PURE__ */ __name((e2) => {
    if (e2.repeat && toValue$3(dedupe))
      return;
    if (predicate(e2))
      handler14(e2);
  }, "listener");
  return useEventListener(target2, eventName, listener, passive);
}
__name(onKeyStroke, "onKeyStroke");
function onKeyDown(key, handler14, options5 = {}) {
  return onKeyStroke(key, handler14, { ...options5, eventName: "keydown" });
}
__name(onKeyDown, "onKeyDown");
function onKeyPressed(key, handler14, options5 = {}) {
  return onKeyStroke(key, handler14, { ...options5, eventName: "keypress" });
}
__name(onKeyPressed, "onKeyPressed");
function onKeyUp(key, handler14, options5 = {}) {
  return onKeyStroke(key, handler14, { ...options5, eventName: "keyup" });
}
__name(onKeyUp, "onKeyUp");
const DEFAULT_DELAY = 500;
const DEFAULT_THRESHOLD = 10;
function onLongPress(target2, handler14, options5) {
  var _a2, _b;
  const elementRef2 = computed(() => unrefElement(target2));
  let timeout;
  let posStart;
  let startTimestamp;
  let hasLongPressed = false;
  function clear() {
    if (timeout) {
      clearTimeout(timeout);
      timeout = void 0;
    }
    posStart = void 0;
    startTimestamp = void 0;
    hasLongPressed = false;
  }
  __name(clear, "clear");
  function onRelease(ev) {
    var _a22, _b2, _c;
    const [_startTimestamp, _posStart, _hasLongPressed] = [startTimestamp, posStart, hasLongPressed];
    clear();
    if (!(options5 == null ? void 0 : options5.onMouseUp) || !_posStart || !_startTimestamp)
      return;
    if (((_a22 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _a22.self) && ev.target !== elementRef2.value)
      return;
    if ((_b2 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _b2.prevent)
      ev.preventDefault();
    if ((_c = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _c.stop)
      ev.stopPropagation();
    const dx = ev.x - _posStart.x;
    const dy = ev.y - _posStart.y;
    const distance2 = Math.sqrt(dx * dx + dy * dy);
    options5.onMouseUp(ev.timeStamp - _startTimestamp, distance2, _hasLongPressed);
  }
  __name(onRelease, "onRelease");
  function onDown(ev) {
    var _a22, _b2, _c, _d;
    if (((_a22 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _a22.self) && ev.target !== elementRef2.value)
      return;
    clear();
    if ((_b2 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _b2.prevent)
      ev.preventDefault();
    if ((_c = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _c.stop)
      ev.stopPropagation();
    posStart = {
      x: ev.x,
      y: ev.y
    };
    startTimestamp = ev.timeStamp;
    timeout = setTimeout(
      () => {
        hasLongPressed = true;
        handler14(ev);
      },
      (_d = options5 == null ? void 0 : options5.delay) != null ? _d : DEFAULT_DELAY
    );
  }
  __name(onDown, "onDown");
  function onMove(ev) {
    var _a22, _b2, _c, _d;
    if (((_a22 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _a22.self) && ev.target !== elementRef2.value)
      return;
    if (!posStart || (options5 == null ? void 0 : options5.distanceThreshold) === false)
      return;
    if ((_b2 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _b2.prevent)
      ev.preventDefault();
    if ((_c = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _c.stop)
      ev.stopPropagation();
    const dx = ev.x - posStart.x;
    const dy = ev.y - posStart.y;
    const distance2 = Math.sqrt(dx * dx + dy * dy);
    if (distance2 >= ((_d = options5 == null ? void 0 : options5.distanceThreshold) != null ? _d : DEFAULT_THRESHOLD))
      clear();
  }
  __name(onMove, "onMove");
  const listenerOptions = {
    capture: (_a2 = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _a2.capture,
    once: (_b = options5 == null ? void 0 : options5.modifiers) == null ? void 0 : _b.once
  };
  const cleanup = [
    useEventListener(elementRef2, "pointerdown", onDown, listenerOptions),
    useEventListener(elementRef2, "pointermove", onMove, listenerOptions),
    useEventListener(elementRef2, ["pointerup", "pointerleave"], onRelease, listenerOptions)
  ];
  const stop2 = /* @__PURE__ */ __name(() => cleanup.forEach((fn) => fn()), "stop");
  return stop2;
}
__name(onLongPress, "onLongPress");
function isFocusedElementEditable() {
  const { activeElement, body } = document;
  if (!activeElement)
    return false;
  if (activeElement === body)
    return false;
  switch (activeElement.tagName) {
    case "INPUT":
    case "TEXTAREA":
      return true;
  }
  return activeElement.hasAttribute("contenteditable");
}
__name(isFocusedElementEditable, "isFocusedElementEditable");
function isTypedCharValid({
  keyCode,
  metaKey,
  ctrlKey,
  altKey
}) {
  if (metaKey || ctrlKey || altKey)
    return false;
  if (keyCode >= 48 && keyCode <= 57)
    return true;
  if (keyCode >= 65 && keyCode <= 90)
    return true;
  if (keyCode >= 97 && keyCode <= 122)
    return true;
  return false;
}
__name(isTypedCharValid, "isTypedCharValid");
function onStartTyping(callback, options5 = {}) {
  const { document: document2 = defaultDocument } = options5;
  const keydown = /* @__PURE__ */ __name((event) => {
    if (!isFocusedElementEditable() && isTypedCharValid(event)) {
      callback(event);
    }
  }, "keydown");
  if (document2)
    useEventListener(document2, "keydown", keydown, { passive: true });
}
__name(onStartTyping, "onStartTyping");
function templateRef(key, initialValue = null) {
  const instance = getCurrentInstance();
  let _trigger = /* @__PURE__ */ __name(() => {
  }, "_trigger");
  const element = customRef((track2, trigger2) => {
    _trigger = trigger2;
    return {
      get() {
        var _a2, _b;
        track2();
        return (_b = (_a2 = instance == null ? void 0 : instance.proxy) == null ? void 0 : _a2.$refs[key]) != null ? _b : initialValue;
      },
      set() {
      }
    };
  });
  tryOnMounted$2(_trigger);
  onUpdated(_trigger);
  return element;
}
__name(templateRef, "templateRef");
function useMounted() {
  const isMounted = ref(false);
  const instance = getCurrentInstance();
  if (instance) {
    onMounted(() => {
      isMounted.value = true;
    }, isVue2 ? void 0 : instance);
  }
  return isMounted;
}
__name(useMounted, "useMounted");
function useSupported(callback) {
  const isMounted = useMounted();
  return computed(() => {
    isMounted.value;
    return Boolean(callback());
  });
}
__name(useSupported, "useSupported");
function useMutationObserver(target2, callback, options5 = {}) {
  const { window: window2 = defaultWindow, ...mutationOptions } = options5;
  let observer;
  const isSupported2 = useSupported(() => window2 && "MutationObserver" in window2);
  const cleanup = /* @__PURE__ */ __name(() => {
    if (observer) {
      observer.disconnect();
      observer = void 0;
    }
  }, "cleanup");
  const targets = computed(() => {
    const value3 = toValue$3(target2);
    const items2 = (Array.isArray(value3) ? value3 : [value3]).map(unrefElement).filter(notNullish);
    return new Set(items2);
  });
  const stopWatch = watch(
    () => targets.value,
    (targets2) => {
      cleanup();
      if (isSupported2.value && targets2.size) {
        observer = new MutationObserver(callback);
        targets2.forEach((el) => observer.observe(el, mutationOptions));
      }
    },
    { immediate: true, flush: "post" }
  );
  const takeRecords = /* @__PURE__ */ __name(() => {
    return observer == null ? void 0 : observer.takeRecords();
  }, "takeRecords");
  const stop2 = /* @__PURE__ */ __name(() => {
    stopWatch();
    cleanup();
  }, "stop");
  tryOnScopeDispose(stop2);
  return {
    isSupported: isSupported2,
    stop: stop2,
    takeRecords
  };
}
__name(useMutationObserver, "useMutationObserver");
function useActiveElement(options5 = {}) {
  var _a2;
  const {
    window: window2 = defaultWindow,
    deep = true,
    triggerOnRemoval = false
  } = options5;
  const document2 = (_a2 = options5.document) != null ? _a2 : window2 == null ? void 0 : window2.document;
  const getDeepActiveElement = /* @__PURE__ */ __name(() => {
    var _a22;
    let element = document2 == null ? void 0 : document2.activeElement;
    if (deep) {
      while (element == null ? void 0 : element.shadowRoot)
        element = (_a22 = element == null ? void 0 : element.shadowRoot) == null ? void 0 : _a22.activeElement;
    }
    return element;
  }, "getDeepActiveElement");
  const activeElement = ref();
  const trigger2 = /* @__PURE__ */ __name(() => {
    activeElement.value = getDeepActiveElement();
  }, "trigger");
  if (window2) {
    useEventListener(window2, "blur", (event) => {
      if (event.relatedTarget !== null)
        return;
      trigger2();
    }, true);
    useEventListener(window2, "focus", trigger2, true);
  }
  if (triggerOnRemoval) {
    useMutationObserver(document2, (mutations) => {
      mutations.filter((m2) => m2.removedNodes.length).map((n2) => Array.from(n2.removedNodes)).flat().forEach((node3) => {
        if (node3 === activeElement.value)
          trigger2();
      });
    }, {
      childList: true,
      subtree: true
    });
  }
  trigger2();
  return activeElement;
}
__name(useActiveElement, "useActiveElement");
function useRafFn(fn, options5 = {}) {
  const {
    immediate = true,
    fpsLimit = void 0,
    window: window2 = defaultWindow
  } = options5;
  const isActive2 = ref(false);
  const intervalLimit = fpsLimit ? 1e3 / fpsLimit : null;
  let previousFrameTimestamp = 0;
  let rafId = null;
  function loop(timestamp2) {
    if (!isActive2.value || !window2)
      return;
    if (!previousFrameTimestamp)
      previousFrameTimestamp = timestamp2;
    const delta2 = timestamp2 - previousFrameTimestamp;
    if (intervalLimit && delta2 < intervalLimit) {
      rafId = window2.requestAnimationFrame(loop);
      return;
    }
    previousFrameTimestamp = timestamp2;
    fn({ delta: delta2, timestamp: timestamp2 });
    rafId = window2.requestAnimationFrame(loop);
  }
  __name(loop, "loop");
  function resume() {
    if (!isActive2.value && window2) {
      isActive2.value = true;
      previousFrameTimestamp = 0;
      rafId = window2.requestAnimationFrame(loop);
    }
  }
  __name(resume, "resume");
  function pause() {
    isActive2.value = false;
    if (rafId != null && window2) {
      window2.cancelAnimationFrame(rafId);
      rafId = null;
    }
  }
  __name(pause, "pause");
  if (immediate)
    resume();
  tryOnScopeDispose(pause);
  return {
    isActive: readonly(isActive2),
    pause,
    resume
  };
}
__name(useRafFn, "useRafFn");
function useAnimate(target2, keyframes, options5) {
  let config2;
  let animateOptions;
  if (isObject$d(options5)) {
    config2 = options5;
    animateOptions = objectOmit(options5, ["window", "immediate", "commitStyles", "persist", "onReady", "onError"]);
  } else {
    config2 = { duration: options5 };
    animateOptions = options5;
  }
  const {
    window: window2 = defaultWindow,
    immediate = true,
    commitStyles,
    persist,
    playbackRate: _playbackRate = 1,
    onReady,
    onError = /* @__PURE__ */ __name((e2) => {
      console.error(e2);
    }, "onError")
  } = config2;
  const isSupported2 = useSupported(() => window2 && HTMLElement && "animate" in HTMLElement.prototype);
  const animate = shallowRef(void 0);
  const store = shallowReactive({
    startTime: null,
    currentTime: null,
    timeline: null,
    playbackRate: _playbackRate,
    pending: false,
    playState: immediate ? "idle" : "paused",
    replaceState: "active"
  });
  const pending = computed(() => store.pending);
  const playState = computed(() => store.playState);
  const replaceState = computed(() => store.replaceState);
  const startTime = computed({
    get() {
      return store.startTime;
    },
    set(value3) {
      store.startTime = value3;
      if (animate.value)
        animate.value.startTime = value3;
    }
  });
  const currentTime = computed({
    get() {
      return store.currentTime;
    },
    set(value3) {
      store.currentTime = value3;
      if (animate.value) {
        animate.value.currentTime = value3;
        syncResume();
      }
    }
  });
  const timeline = computed({
    get() {
      return store.timeline;
    },
    set(value3) {
      store.timeline = value3;
      if (animate.value)
        animate.value.timeline = value3;
    }
  });
  const playbackRate = computed({
    get() {
      return store.playbackRate;
    },
    set(value3) {
      store.playbackRate = value3;
      if (animate.value)
        animate.value.playbackRate = value3;
    }
  });
  const play = /* @__PURE__ */ __name(() => {
    if (animate.value) {
      try {
        animate.value.play();
        syncResume();
      } catch (e2) {
        syncPause();
        onError(e2);
      }
    } else {
      update();
    }
  }, "play");
  const pause = /* @__PURE__ */ __name(() => {
    var _a2;
    try {
      (_a2 = animate.value) == null ? void 0 : _a2.pause();
      syncPause();
    } catch (e2) {
      onError(e2);
    }
  }, "pause");
  const reverse2 = /* @__PURE__ */ __name(() => {
    var _a2;
    if (!animate.value)
      update();
    try {
      (_a2 = animate.value) == null ? void 0 : _a2.reverse();
      syncResume();
    } catch (e2) {
      syncPause();
      onError(e2);
    }
  }, "reverse");
  const finish = /* @__PURE__ */ __name(() => {
    var _a2;
    try {
      (_a2 = animate.value) == null ? void 0 : _a2.finish();
      syncPause();
    } catch (e2) {
      onError(e2);
    }
  }, "finish");
  const cancel = /* @__PURE__ */ __name(() => {
    var _a2;
    try {
      (_a2 = animate.value) == null ? void 0 : _a2.cancel();
      syncPause();
    } catch (e2) {
      onError(e2);
    }
  }, "cancel");
  watch(() => unrefElement(target2), (el) => {
    if (el)
      update();
  });
  watch(() => keyframes, (value3) => {
    if (animate.value)
      update();
    if (!unrefElement(target2) && animate.value) {
      animate.value.effect = new KeyframeEffect(
        unrefElement(target2),
        toValue$3(value3),
        animateOptions
      );
    }
  }, { deep: true });
  tryOnMounted$2(() => update(true), false);
  tryOnScopeDispose(cancel);
  function update(init3) {
    const el = unrefElement(target2);
    if (!isSupported2.value || !el)
      return;
    if (!animate.value)
      animate.value = el.animate(toValue$3(keyframes), animateOptions);
    if (persist)
      animate.value.persist();
    if (_playbackRate !== 1)
      animate.value.playbackRate = _playbackRate;
    if (init3 && !immediate)
      animate.value.pause();
    else
      syncResume();
    onReady == null ? void 0 : onReady(animate.value);
  }
  __name(update, "update");
  useEventListener(animate, ["cancel", "finish", "remove"], syncPause);
  useEventListener(animate, "finish", () => {
    var _a2;
    if (commitStyles)
      (_a2 = animate.value) == null ? void 0 : _a2.commitStyles();
  });
  const { resume: resumeRef, pause: pauseRef } = useRafFn(() => {
    if (!animate.value)
      return;
    store.pending = animate.value.pending;
    store.playState = animate.value.playState;
    store.replaceState = animate.value.replaceState;
    store.startTime = animate.value.startTime;
    store.currentTime = animate.value.currentTime;
    store.timeline = animate.value.timeline;
    store.playbackRate = animate.value.playbackRate;
  }, { immediate: false });
  function syncResume() {
    if (isSupported2.value)
      resumeRef();
  }
  __name(syncResume, "syncResume");
  function syncPause() {
    if (isSupported2.value && window2)
      window2.requestAnimationFrame(pauseRef);
  }
  __name(syncPause, "syncPause");
  return {
    isSupported: isSupported2,
    animate,
    // actions
    play,
    pause,
    reverse: reverse2,
    finish,
    cancel,
    // state
    pending,
    playState,
    replaceState,
    startTime,
    currentTime,
    timeline,
    playbackRate
  };
}
__name(useAnimate, "useAnimate");
function useAsyncQueue(tasks, options5) {
  const {
    interrupt = true,
    onError = noop$1,
    onFinished = noop$1,
    signal
  } = options5 || {};
  const promiseState = {
    aborted: "aborted",
    fulfilled: "fulfilled",
    pending: "pending",
    rejected: "rejected"
  };
  const initialResult = Array.from(Array.from({ length: tasks.length }), () => ({ state: promiseState.pending, data: null }));
  const result = reactive(initialResult);
  const activeIndex3 = ref(-1);
  if (!tasks || tasks.length === 0) {
    onFinished();
    return {
      activeIndex: activeIndex3,
      result
    };
  }
  function updateResult(state, res) {
    activeIndex3.value++;
    result[activeIndex3.value].data = res;
    result[activeIndex3.value].state = state;
  }
  __name(updateResult, "updateResult");
  tasks.reduce((prev2, curr) => {
    return prev2.then((prevRes) => {
      var _a2;
      if (signal == null ? void 0 : signal.aborted) {
        updateResult(promiseState.aborted, new Error("aborted"));
        return;
      }
      if (((_a2 = result[activeIndex3.value]) == null ? void 0 : _a2.state) === promiseState.rejected && interrupt) {
        onFinished();
        return;
      }
      const done = curr(prevRes).then((currentRes) => {
        updateResult(promiseState.fulfilled, currentRes);
        if (activeIndex3.value === tasks.length - 1)
          onFinished();
        return currentRes;
      });
      if (!signal)
        return done;
      return Promise.race([done, whenAborted(signal)]);
    }).catch((e2) => {
      if (signal == null ? void 0 : signal.aborted) {
        updateResult(promiseState.aborted, e2);
        return e2;
      }
      updateResult(promiseState.rejected, e2);
      onError();
      return e2;
    });
  }, Promise.resolve());
  return {
    activeIndex: activeIndex3,
    result
  };
}
__name(useAsyncQueue, "useAsyncQueue");
function whenAborted(signal) {
  return new Promise((resolve2, reject3) => {
    const error2 = new Error("aborted");
    if (signal.aborted)
      reject3(error2);
    else
      signal.addEventListener("abort", () => reject3(error2), { once: true });
  });
}
__name(whenAborted, "whenAborted");
function useAsyncState(promise, initialState, options5) {
  const {
    immediate = true,
    delay = 0,
    onError = noop$1,
    onSuccess = noop$1,
    resetOnExecute = true,
    shallow = true,
    throwError
  } = options5 != null ? options5 : {};
  const state = shallow ? shallowRef(initialState) : ref(initialState);
  const isReady = ref(false);
  const isLoading = ref(false);
  const error2 = shallowRef(void 0);
  async function execute(delay2 = 0, ...args) {
    if (resetOnExecute)
      state.value = initialState;
    error2.value = void 0;
    isReady.value = false;
    isLoading.value = true;
    if (delay2 > 0)
      await promiseTimeout(delay2);
    const _promise = typeof promise === "function" ? promise(...args) : promise;
    try {
      const data30 = await _promise;
      state.value = data30;
      isReady.value = true;
      onSuccess(data30);
    } catch (e2) {
      error2.value = e2;
      onError(e2);
      if (throwError)
        throw e2;
    } finally {
      isLoading.value = false;
    }
    return state.value;
  }
  __name(execute, "execute");
  if (immediate)
    execute(delay);
  const shell = {
    state,
    isReady,
    isLoading,
    error: error2,
    execute
  };
  function waitUntilIsLoaded() {
    return new Promise((resolve2, reject3) => {
      until(isLoading).toBe(false).then(() => resolve2(shell)).catch(reject3);
    });
  }
  __name(waitUntilIsLoaded, "waitUntilIsLoaded");
  return {
    ...shell,
    then(onFulfilled, onRejected) {
      return waitUntilIsLoaded().then(onFulfilled, onRejected);
    }
  };
}
__name(useAsyncState, "useAsyncState");
const defaults$1 = {
  array: /* @__PURE__ */ __name((v2) => JSON.stringify(v2), "array"),
  object: /* @__PURE__ */ __name((v2) => JSON.stringify(v2), "object"),
  set: /* @__PURE__ */ __name((v2) => JSON.stringify(Array.from(v2)), "set"),
  map: /* @__PURE__ */ __name((v2) => JSON.stringify(Object.fromEntries(v2)), "map"),
  null: /* @__PURE__ */ __name(() => "", "null")
};
function getDefaultSerialization(target2) {
  if (!target2)
    return defaults$1.null;
  if (target2 instanceof Map)
    return defaults$1.map;
  else if (target2 instanceof Set)
    return defaults$1.set;
  else if (Array.isArray(target2))
    return defaults$1.array;
  else
    return defaults$1.object;
}
__name(getDefaultSerialization, "getDefaultSerialization");
function useBase64(target2, options5) {
  const base64 = ref("");
  const promise = ref();
  function execute() {
    if (!isClient$1)
      return;
    promise.value = new Promise((resolve2, reject3) => {
      try {
        const _target = toValue$3(target2);
        if (_target == null) {
          resolve2("");
        } else if (typeof _target === "string") {
          resolve2(blobToBase64(new Blob([_target], { type: "text/plain" })));
        } else if (_target instanceof Blob) {
          resolve2(blobToBase64(_target));
        } else if (_target instanceof ArrayBuffer) {
          resolve2(window.btoa(String.fromCharCode(...new Uint8Array(_target))));
        } else if (_target instanceof HTMLCanvasElement) {
          resolve2(_target.toDataURL(options5 == null ? void 0 : options5.type, options5 == null ? void 0 : options5.quality));
        } else if (_target instanceof HTMLImageElement) {
          const img = _target.cloneNode(false);
          img.crossOrigin = "Anonymous";
          imgLoaded(img).then(() => {
            const canvas2 = document.createElement("canvas");
            const ctx = canvas2.getContext("2d");
            canvas2.width = img.width;
            canvas2.height = img.height;
            ctx.drawImage(img, 0, 0, canvas2.width, canvas2.height);
            resolve2(canvas2.toDataURL(options5 == null ? void 0 : options5.type, options5 == null ? void 0 : options5.quality));
          }).catch(reject3);
        } else if (typeof _target === "object") {
          const _serializeFn = (options5 == null ? void 0 : options5.serializer) || getDefaultSerialization(_target);
          const serialized = _serializeFn(_target);
          return resolve2(blobToBase64(new Blob([serialized], { type: "application/json" })));
        } else {
          reject3(new Error("target is unsupported types"));
        }
      } catch (error2) {
        reject3(error2);
      }
    });
    promise.value.then((res) => base64.value = res);
    return promise.value;
  }
  __name(execute, "execute");
  if (isRef(target2) || typeof target2 === "function")
    watch(target2, execute, { immediate: true });
  else
    execute();
  return {
    base64,
    promise,
    execute
  };
}
__name(useBase64, "useBase64");
function imgLoaded(img) {
  return new Promise((resolve2, reject3) => {
    if (!img.complete) {
      img.onload = () => {
        resolve2();
      };
      img.onerror = reject3;
    } else {
      resolve2();
    }
  });
}
__name(imgLoaded, "imgLoaded");
function blobToBase64(blob) {
  return new Promise((resolve2, reject3) => {
    const fr2 = new FileReader();
    fr2.onload = (e2) => {
      resolve2(e2.target.result);
    };
    fr2.onerror = reject3;
    fr2.readAsDataURL(blob);
  });
}
__name(blobToBase64, "blobToBase64");
function useBattery(options5 = {}) {
  const { navigator: navigator2 = defaultNavigator } = options5;
  const events2 = ["chargingchange", "chargingtimechange", "dischargingtimechange", "levelchange"];
  const isSupported2 = useSupported(() => navigator2 && "getBattery" in navigator2 && typeof navigator2.getBattery === "function");
  const charging = ref(false);
  const chargingTime = ref(0);
  const dischargingTime = ref(0);
  const level = ref(1);
  let battery;
  function updateBatteryInfo() {
    charging.value = this.charging;
    chargingTime.value = this.chargingTime || 0;
    dischargingTime.value = this.dischargingTime || 0;
    level.value = this.level;
  }
  __name(updateBatteryInfo, "updateBatteryInfo");
  if (isSupported2.value) {
    navigator2.getBattery().then((_battery) => {
      battery = _battery;
      updateBatteryInfo.call(battery);
      useEventListener(battery, events2, updateBatteryInfo, { passive: true });
    });
  }
  return {
    isSupported: isSupported2,
    charging,
    chargingTime,
    dischargingTime,
    level
  };
}
__name(useBattery, "useBattery");
function useBluetooth(options5) {
  let {
    acceptAllDevices = false
  } = options5 || {};
  const {
    filters = void 0,
    optionalServices = void 0,
    navigator: navigator2 = defaultNavigator
  } = options5 || {};
  const isSupported2 = useSupported(() => navigator2 && "bluetooth" in navigator2);
  const device = shallowRef(void 0);
  const error2 = shallowRef(null);
  watch(device, () => {
    connectToBluetoothGATTServer();
  });
  async function requestDevice() {
    if (!isSupported2.value)
      return;
    error2.value = null;
    if (filters && filters.length > 0)
      acceptAllDevices = false;
    try {
      device.value = await (navigator2 == null ? void 0 : navigator2.bluetooth.requestDevice({
        acceptAllDevices,
        filters,
        optionalServices
      }));
    } catch (err) {
      error2.value = err;
    }
  }
  __name(requestDevice, "requestDevice");
  const server = ref();
  const isConnected = computed(() => {
    var _a2;
    return ((_a2 = server.value) == null ? void 0 : _a2.connected) || false;
  });
  async function connectToBluetoothGATTServer() {
    error2.value = null;
    if (device.value && device.value.gatt) {
      device.value.addEventListener("gattserverdisconnected", () => {
      });
      try {
        server.value = await device.value.gatt.connect();
      } catch (err) {
        error2.value = err;
      }
    }
  }
  __name(connectToBluetoothGATTServer, "connectToBluetoothGATTServer");
  tryOnMounted$2(() => {
    var _a2;
    if (device.value)
      (_a2 = device.value.gatt) == null ? void 0 : _a2.connect();
  });
  tryOnScopeDispose(() => {
    var _a2;
    if (device.value)
      (_a2 = device.value.gatt) == null ? void 0 : _a2.disconnect();
  });
  return {
    isSupported: isSupported2,
    isConnected,
    // Device:
    device,
    requestDevice,
    // Server:
    server,
    // Errors:
    error: error2
  };
}
__name(useBluetooth, "useBluetooth");
function useMediaQuery(query, options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const isSupported2 = useSupported(() => window2 && "matchMedia" in window2 && typeof window2.matchMedia === "function");
  let mediaQuery;
  const matches2 = ref(false);
  const handler14 = /* @__PURE__ */ __name((event) => {
    matches2.value = event.matches;
  }, "handler");
  const cleanup = /* @__PURE__ */ __name(() => {
    if (!mediaQuery)
      return;
    if ("removeEventListener" in mediaQuery)
      mediaQuery.removeEventListener("change", handler14);
    else
      mediaQuery.removeListener(handler14);
  }, "cleanup");
  const stopWatch = watchEffect(() => {
    if (!isSupported2.value)
      return;
    cleanup();
    mediaQuery = window2.matchMedia(toValue$3(query));
    if ("addEventListener" in mediaQuery)
      mediaQuery.addEventListener("change", handler14);
    else
      mediaQuery.addListener(handler14);
    matches2.value = mediaQuery.matches;
  });
  tryOnScopeDispose(() => {
    stopWatch();
    cleanup();
    mediaQuery = void 0;
  });
  return matches2;
}
__name(useMediaQuery, "useMediaQuery");
const breakpointsTailwind = {
  "sm": 640,
  "md": 768,
  "lg": 1024,
  "xl": 1280,
  "2xl": 1536
};
const breakpointsBootstrapV5 = {
  xs: 0,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400
};
const breakpointsVuetifyV2 = {
  xs: 0,
  sm: 600,
  md: 960,
  lg: 1264,
  xl: 1904
};
const breakpointsVuetifyV3 = {
  xs: 0,
  sm: 600,
  md: 960,
  lg: 1280,
  xl: 1920,
  xxl: 2560
};
const breakpointsVuetify = breakpointsVuetifyV2;
const breakpointsAntDesign = {
  xs: 480,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1600
};
const breakpointsQuasar = {
  xs: 0,
  sm: 600,
  md: 1024,
  lg: 1440,
  xl: 1920
};
const breakpointsSematic = {
  mobileS: 320,
  mobileM: 375,
  mobileL: 425,
  tablet: 768,
  laptop: 1024,
  laptopL: 1440,
  desktop4K: 2560
};
const breakpointsMasterCss = {
  "3xs": 360,
  "2xs": 480,
  "xs": 600,
  "sm": 768,
  "md": 1024,
  "lg": 1280,
  "xl": 1440,
  "2xl": 1600,
  "3xl": 1920,
  "4xl": 2560
};
const breakpointsPrimeFlex = {
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200
};
function useBreakpoints(breakpoints, options5 = {}) {
  function getValue2(k2, delta2) {
    let v2 = toValue$3(breakpoints[toValue$3(k2)]);
    if (delta2 != null)
      v2 = increaseWithUnit(v2, delta2);
    if (typeof v2 === "number")
      v2 = `${v2}px`;
    return v2;
  }
  __name(getValue2, "getValue2");
  const { window: window2 = defaultWindow, strategy = "min-width" } = options5;
  function match2(query) {
    if (!window2)
      return false;
    return window2.matchMedia(query).matches;
  }
  __name(match2, "match");
  const greaterOrEqual = /* @__PURE__ */ __name((k2) => {
    return useMediaQuery(() => `(min-width: ${getValue2(k2)})`, options5);
  }, "greaterOrEqual");
  const smallerOrEqual = /* @__PURE__ */ __name((k2) => {
    return useMediaQuery(() => `(max-width: ${getValue2(k2)})`, options5);
  }, "smallerOrEqual");
  const shortcutMethods = Object.keys(breakpoints).reduce((shortcuts, k2) => {
    Object.defineProperty(shortcuts, k2, {
      get: /* @__PURE__ */ __name(() => strategy === "min-width" ? greaterOrEqual(k2) : smallerOrEqual(k2), "get"),
      enumerable: true,
      configurable: true
    });
    return shortcuts;
  }, {});
  function current() {
    const points = Object.keys(breakpoints).map((i2) => [i2, greaterOrEqual(i2)]);
    return computed(() => points.filter(([, v2]) => v2.value).map(([k2]) => k2));
  }
  __name(current, "current");
  return Object.assign(shortcutMethods, {
    greaterOrEqual,
    smallerOrEqual,
    greater(k2) {
      return useMediaQuery(() => `(min-width: ${getValue2(k2, 0.1)})`, options5);
    },
    smaller(k2) {
      return useMediaQuery(() => `(max-width: ${getValue2(k2, -0.1)})`, options5);
    },
    between(a2, b2) {
      return useMediaQuery(() => `(min-width: ${getValue2(a2)}) and (max-width: ${getValue2(b2, -0.1)})`, options5);
    },
    isGreater(k2) {
      return match2(`(min-width: ${getValue2(k2, 0.1)})`);
    },
    isGreaterOrEqual(k2) {
      return match2(`(min-width: ${getValue2(k2)})`);
    },
    isSmaller(k2) {
      return match2(`(max-width: ${getValue2(k2, -0.1)})`);
    },
    isSmallerOrEqual(k2) {
      return match2(`(max-width: ${getValue2(k2)})`);
    },
    isInBetween(a2, b2) {
      return match2(`(min-width: ${getValue2(a2)}) and (max-width: ${getValue2(b2, -0.1)})`);
    },
    current,
    active() {
      const bps = current();
      return computed(() => bps.value.length === 0 ? "" : bps.value.at(-1));
    }
  });
}
__name(useBreakpoints, "useBreakpoints");
function useBroadcastChannel(options5) {
  const {
    name: name2,
    window: window2 = defaultWindow
  } = options5;
  const isSupported2 = useSupported(() => window2 && "BroadcastChannel" in window2);
  const isClosed = ref(false);
  const channel = ref();
  const data30 = ref();
  const error2 = shallowRef(null);
  const post = /* @__PURE__ */ __name((data210) => {
    if (channel.value)
      channel.value.postMessage(data210);
  }, "post");
  const close5 = /* @__PURE__ */ __name(() => {
    if (channel.value)
      channel.value.close();
    isClosed.value = true;
  }, "close");
  if (isSupported2.value) {
    tryOnMounted$2(() => {
      error2.value = null;
      channel.value = new BroadcastChannel(name2);
      channel.value.addEventListener("message", (e2) => {
        data30.value = e2.data;
      }, { passive: true });
      channel.value.addEventListener("messageerror", (e2) => {
        error2.value = e2;
      }, { passive: true });
      channel.value.addEventListener("close", () => {
        isClosed.value = true;
      });
    });
  }
  tryOnScopeDispose(() => {
    close5();
  });
  return {
    isSupported: isSupported2,
    channel,
    data: data30,
    post,
    close: close5,
    error: error2,
    isClosed
  };
}
__name(useBroadcastChannel, "useBroadcastChannel");
const WRITABLE_PROPERTIES = [
  "hash",
  "host",
  "hostname",
  "href",
  "pathname",
  "port",
  "protocol",
  "search"
];
function useBrowserLocation(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const refs = Object.fromEntries(
    WRITABLE_PROPERTIES.map((key) => [key, ref()])
  );
  for (const [key, ref2] of objectEntries(refs)) {
    watch(ref2, (value3) => {
      if (!(window2 == null ? void 0 : window2.location) || window2.location[key] === value3)
        return;
      window2.location[key] = value3;
    });
  }
  const buildState2 = /* @__PURE__ */ __name((trigger2) => {
    var _a2;
    const { state: state2, length } = (window2 == null ? void 0 : window2.history) || {};
    const { origin: origin2 } = (window2 == null ? void 0 : window2.location) || {};
    for (const key of WRITABLE_PROPERTIES)
      refs[key].value = (_a2 = window2 == null ? void 0 : window2.location) == null ? void 0 : _a2[key];
    return reactive({
      trigger: trigger2,
      state: state2,
      length,
      origin: origin2,
      ...refs
    });
  }, "buildState");
  const state = ref(buildState2("load"));
  if (window2) {
    useEventListener(window2, "popstate", () => state.value = buildState2("popstate"), { passive: true });
    useEventListener(window2, "hashchange", () => state.value = buildState2("hashchange"), { passive: true });
  }
  return state;
}
__name(useBrowserLocation, "useBrowserLocation");
function useCached(refValue, comparator = (a2, b2) => a2 === b2, watchOptions) {
  const cachedValue = ref(refValue.value);
  watch(() => refValue.value, (value3) => {
    if (!comparator(value3, cachedValue.value))
      cachedValue.value = value3;
  }, watchOptions);
  return cachedValue;
}
__name(useCached, "useCached");
function usePermission(permissionDesc, options5 = {}) {
  const {
    controls = false,
    navigator: navigator2 = defaultNavigator
  } = options5;
  const isSupported2 = useSupported(() => navigator2 && "permissions" in navigator2);
  let permissionStatus;
  const desc = typeof permissionDesc === "string" ? { name: permissionDesc } : permissionDesc;
  const state = ref();
  const onChange6 = /* @__PURE__ */ __name(() => {
    if (permissionStatus)
      state.value = permissionStatus.state;
  }, "onChange");
  const query = createSingletonPromise(async () => {
    if (!isSupported2.value)
      return;
    if (!permissionStatus) {
      try {
        permissionStatus = await navigator2.permissions.query(desc);
        useEventListener(permissionStatus, "change", onChange6);
        onChange6();
      } catch (e2) {
        state.value = "prompt";
      }
    }
    return permissionStatus;
  });
  query();
  if (controls) {
    return {
      state,
      isSupported: isSupported2,
      query
    };
  } else {
    return state;
  }
}
__name(usePermission, "usePermission");
function useClipboard(options5 = {}) {
  const {
    navigator: navigator2 = defaultNavigator,
    read = false,
    source,
    copiedDuring = 1500,
    legacy = false
  } = options5;
  const isClipboardApiSupported = useSupported(() => navigator2 && "clipboard" in navigator2);
  const permissionRead = usePermission("clipboard-read");
  const permissionWrite = usePermission("clipboard-write");
  const isSupported2 = computed(() => isClipboardApiSupported.value || legacy);
  const text2 = ref("");
  const copied = ref(false);
  const timeout = useTimeoutFn(() => copied.value = false, copiedDuring);
  function updateText() {
    if (isClipboardApiSupported.value && isAllowed(permissionRead.value)) {
      navigator2.clipboard.readText().then((value3) => {
        text2.value = value3;
      });
    } else {
      text2.value = legacyRead();
    }
  }
  __name(updateText, "updateText");
  if (isSupported2.value && read)
    useEventListener(["copy", "cut"], updateText);
  async function copy2(value3 = toValue$3(source)) {
    if (isSupported2.value && value3 != null) {
      if (isClipboardApiSupported.value && isAllowed(permissionWrite.value))
        await navigator2.clipboard.writeText(value3);
      else
        legacyCopy(value3);
      text2.value = value3;
      copied.value = true;
      timeout.start();
    }
  }
  __name(copy2, "copy");
  function legacyCopy(value3) {
    const ta2 = document.createElement("textarea");
    ta2.value = value3 != null ? value3 : "";
    ta2.style.position = "absolute";
    ta2.style.opacity = "0";
    document.body.appendChild(ta2);
    ta2.select();
    document.execCommand("copy");
    ta2.remove();
  }
  __name(legacyCopy, "legacyCopy");
  function legacyRead() {
    var _a2, _b, _c;
    return (_c = (_b = (_a2 = document == null ? void 0 : document.getSelection) == null ? void 0 : _a2.call(document)) == null ? void 0 : _b.toString()) != null ? _c : "";
  }
  __name(legacyRead, "legacyRead");
  function isAllowed(status) {
    return status === "granted" || status === "prompt";
  }
  __name(isAllowed, "isAllowed");
  return {
    isSupported: isSupported2,
    text: text2,
    copied,
    copy: copy2
  };
}
__name(useClipboard, "useClipboard");
function useClipboardItems(options5 = {}) {
  const {
    navigator: navigator2 = defaultNavigator,
    read = false,
    source,
    copiedDuring = 1500
  } = options5;
  const isSupported2 = useSupported(() => navigator2 && "clipboard" in navigator2);
  const content3 = ref([]);
  const copied = ref(false);
  const timeout = useTimeoutFn(() => copied.value = false, copiedDuring);
  function updateContent() {
    if (isSupported2.value) {
      navigator2.clipboard.read().then((items2) => {
        content3.value = items2;
      });
    }
  }
  __name(updateContent, "updateContent");
  if (isSupported2.value && read)
    useEventListener(["copy", "cut"], updateContent);
  async function copy2(value3 = toValue$3(source)) {
    if (isSupported2.value && value3 != null) {
      await navigator2.clipboard.write(value3);
      content3.value = value3;
      copied.value = true;
      timeout.start();
    }
  }
  __name(copy2, "copy");
  return {
    isSupported: isSupported2,
    content: content3,
    copied,
    copy: copy2
  };
}
__name(useClipboardItems, "useClipboardItems");
function cloneFnJSON(source) {
  return JSON.parse(JSON.stringify(source));
}
__name(cloneFnJSON, "cloneFnJSON");
function useCloned(source, options5 = {}) {
  const cloned = ref({});
  const {
    manual,
    clone: clone2 = cloneFnJSON,
    // watch options
    deep = true,
    immediate = true
  } = options5;
  function sync() {
    cloned.value = clone2(toValue$3(source));
  }
  __name(sync, "sync");
  if (!manual && (isRef(source) || typeof source === "function")) {
    watch(source, sync, {
      ...options5,
      deep,
      immediate
    });
  } else {
    sync();
  }
  return { cloned, sync };
}
__name(useCloned, "useCloned");
const _global = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
const globalKey = "__vueuse_ssr_handlers__";
const handlers$1 = /* @__PURE__ */ getHandlers();
function getHandlers() {
  if (!(globalKey in _global))
    _global[globalKey] = _global[globalKey] || {};
  return _global[globalKey];
}
__name(getHandlers, "getHandlers");
function getSSRHandler(key, fallback) {
  return handlers$1[key] || fallback;
}
__name(getSSRHandler, "getSSRHandler");
function setSSRHandler(key, fn) {
  handlers$1[key] = fn;
}
__name(setSSRHandler, "setSSRHandler");
function guessSerializerType(rawInit) {
  return rawInit == null ? "any" : rawInit instanceof Set ? "set" : rawInit instanceof Map ? "map" : rawInit instanceof Date ? "date" : typeof rawInit === "boolean" ? "boolean" : typeof rawInit === "string" ? "string" : typeof rawInit === "object" ? "object" : !Number.isNaN(rawInit) ? "number" : "any";
}
__name(guessSerializerType, "guessSerializerType");
const StorageSerializers = {
  boolean: {
    read: /* @__PURE__ */ __name((v2) => v2 === "true", "read"),
    write: /* @__PURE__ */ __name((v2) => String(v2), "write")
  },
  object: {
    read: /* @__PURE__ */ __name((v2) => JSON.parse(v2), "read"),
    write: /* @__PURE__ */ __name((v2) => JSON.stringify(v2), "write")
  },
  number: {
    read: /* @__PURE__ */ __name((v2) => Number.parseFloat(v2), "read"),
    write: /* @__PURE__ */ __name((v2) => String(v2), "write")
  },
  any: {
    read: /* @__PURE__ */ __name((v2) => v2, "read"),
    write: /* @__PURE__ */ __name((v2) => String(v2), "write")
  },
  string: {
    read: /* @__PURE__ */ __name((v2) => v2, "read"),
    write: /* @__PURE__ */ __name((v2) => String(v2), "write")
  },
  map: {
    read: /* @__PURE__ */ __name((v2) => new Map(JSON.parse(v2)), "read"),
    write: /* @__PURE__ */ __name((v2) => JSON.stringify(Array.from(v2.entries())), "write")
  },
  set: {
    read: /* @__PURE__ */ __name((v2) => new Set(JSON.parse(v2)), "read"),
    write: /* @__PURE__ */ __name((v2) => JSON.stringify(Array.from(v2)), "write")
  },
  date: {
    read: /* @__PURE__ */ __name((v2) => new Date(v2), "read"),
    write: /* @__PURE__ */ __name((v2) => v2.toISOString(), "write")
  }
};
const customStorageEventName = "vueuse-storage";
function useStorage(key, defaults2, storage, options5 = {}) {
  var _a2;
  const {
    flush: flush2 = "pre",
    deep = true,
    listenToStorageChanges = true,
    writeDefaults = true,
    mergeDefaults: mergeDefaults2 = false,
    shallow,
    window: window2 = defaultWindow,
    eventFilter,
    onError = /* @__PURE__ */ __name((e2) => {
      console.error(e2);
    }, "onError"),
    initOnMounted
  } = options5;
  const data30 = (shallow ? shallowRef : ref)(typeof defaults2 === "function" ? defaults2() : defaults2);
  if (!storage) {
    try {
      storage = getSSRHandler("getDefaultStorage", () => {
        var _a22;
        return (_a22 = defaultWindow) == null ? void 0 : _a22.localStorage;
      })();
    } catch (e2) {
      onError(e2);
    }
  }
  if (!storage)
    return data30;
  const rawInit = toValue$3(defaults2);
  const type = guessSerializerType(rawInit);
  const serializer = (_a2 = options5.serializer) != null ? _a2 : StorageSerializers[type];
  const { pause: pauseWatch, resume: resumeWatch } = watchPausable(
    data30,
    () => write(data30.value),
    { flush: flush2, deep, eventFilter }
  );
  if (window2 && listenToStorageChanges) {
    tryOnMounted$2(() => {
      if (storage instanceof Storage)
        useEventListener(window2, "storage", update);
      else
        useEventListener(window2, customStorageEventName, updateFromCustomEvent);
      if (initOnMounted)
        update();
    });
  }
  if (!initOnMounted)
    update();
  function dispatchWriteEvent(oldValue, newValue2) {
    if (window2 && !(storage instanceof Storage)) {
      window2.dispatchEvent(new CustomEvent(customStorageEventName, {
        detail: {
          key,
          oldValue,
          newValue: newValue2,
          storageArea: storage
        }
      }));
    }
  }
  __name(dispatchWriteEvent, "dispatchWriteEvent");
  function write(v2) {
    try {
      const oldValue = storage.getItem(key);
      if (v2 == null) {
        dispatchWriteEvent(oldValue, null);
        storage.removeItem(key);
      } else {
        const serialized = serializer.write(v2);
        if (oldValue !== serialized) {
          storage.setItem(key, serialized);
          dispatchWriteEvent(oldValue, serialized);
        }
      }
    } catch (e2) {
      onError(e2);
    }
  }
  __name(write, "write");
  function read(event) {
    const rawValue = event ? event.newValue : storage.getItem(key);
    if (rawValue == null) {
      if (writeDefaults && rawInit != null)
        storage.setItem(key, serializer.write(rawInit));
      return rawInit;
    } else if (!event && mergeDefaults2) {
      const value3 = serializer.read(rawValue);
      if (typeof mergeDefaults2 === "function")
        return mergeDefaults2(value3, rawInit);
      else if (type === "object" && !Array.isArray(value3))
        return { ...rawInit, ...value3 };
      return value3;
    } else if (typeof rawValue !== "string") {
      return rawValue;
    } else {
      return serializer.read(rawValue);
    }
  }
  __name(read, "read");
  function update(event) {
    if (event && event.storageArea !== storage)
      return;
    if (event && event.key == null) {
      data30.value = rawInit;
      return;
    }
    if (event && event.key !== key)
      return;
    pauseWatch();
    try {
      if ((event == null ? void 0 : event.newValue) !== serializer.write(data30.value))
        data30.value = read(event);
    } catch (e2) {
      onError(e2);
    } finally {
      if (event)
        nextTick(resumeWatch);
      else
        resumeWatch();
    }
  }
  __name(update, "update");
  function updateFromCustomEvent(event) {
    update(event.detail);
  }
  __name(updateFromCustomEvent, "updateFromCustomEvent");
  return data30;
}
__name(useStorage, "useStorage");
function usePreferredDark(options5) {
  return useMediaQuery("(prefers-color-scheme: dark)", options5);
}
__name(usePreferredDark, "usePreferredDark");
const CSS_DISABLE_TRANS = "*,*::before,*::after{-webkit-transition:none!important;-moz-transition:none!important;-o-transition:none!important;-ms-transition:none!important;transition:none!important}";
function useColorMode(options5 = {}) {
  const {
    selector = "html",
    attribute: attribute2 = "class",
    initialValue = "auto",
    window: window2 = defaultWindow,
    storage,
    storageKey = "vueuse-color-scheme",
    listenToStorageChanges = true,
    storageRef,
    emitAuto,
    disableTransition = true
  } = options5;
  const modes = {
    auto: "",
    light: "light",
    dark: "dark",
    ...options5.modes || {}
  };
  const preferredDark = usePreferredDark({ window: window2 });
  const system = computed(() => preferredDark.value ? "dark" : "light");
  const store = storageRef || (storageKey == null ? toRef(initialValue) : useStorage(storageKey, initialValue, storage, { window: window2, listenToStorageChanges }));
  const state = computed(() => store.value === "auto" ? system.value : store.value);
  const updateHTMLAttrs = getSSRHandler(
    "updateHTMLAttrs",
    (selector2, attribute22, value3) => {
      const el = typeof selector2 === "string" ? window2 == null ? void 0 : window2.document.querySelector(selector2) : unrefElement(selector2);
      if (!el)
        return;
      const classesToAdd = /* @__PURE__ */ new Set();
      const classesToRemove = /* @__PURE__ */ new Set();
      let attributeToChange = null;
      if (attribute22 === "class") {
        const current = value3.split(/\s/g);
        Object.values(modes).flatMap((i2) => (i2 || "").split(/\s/g)).filter(Boolean).forEach((v2) => {
          if (current.includes(v2))
            classesToAdd.add(v2);
          else
            classesToRemove.add(v2);
        });
      } else {
        attributeToChange = { key: attribute22, value: value3 };
      }
      if (classesToAdd.size === 0 && classesToRemove.size === 0 && attributeToChange === null)
        return;
      let style2;
      if (disableTransition) {
        style2 = window2.document.createElement("style");
        style2.appendChild(document.createTextNode(CSS_DISABLE_TRANS));
        window2.document.head.appendChild(style2);
      }
      for (const c2 of classesToAdd) {
        el.classList.add(c2);
      }
      for (const c2 of classesToRemove) {
        el.classList.remove(c2);
      }
      if (attributeToChange) {
        el.setAttribute(attributeToChange.key, attributeToChange.value);
      }
      if (disableTransition) {
        window2.getComputedStyle(style2).opacity;
        document.head.removeChild(style2);
      }
    }
  );
  function defaultOnChanged(mode2) {
    var _a2;
    updateHTMLAttrs(selector, attribute2, (_a2 = modes[mode2]) != null ? _a2 : mode2);
  }
  __name(defaultOnChanged, "defaultOnChanged");
  function onChanged(mode2) {
    if (options5.onChanged)
      options5.onChanged(mode2, defaultOnChanged);
    else
      defaultOnChanged(mode2);
  }
  __name(onChanged, "onChanged");
  watch(state, onChanged, { flush: "post", immediate: true });
  tryOnMounted$2(() => onChanged(state.value));
  const auto = computed({
    get() {
      return emitAuto ? store.value : state.value;
    },
    set(v2) {
      store.value = v2;
    }
  });
  try {
    return Object.assign(auto, { store, system, state });
  } catch (e2) {
    return auto;
  }
}
__name(useColorMode, "useColorMode");
function useConfirmDialog(revealed = ref(false)) {
  const confirmHook = createEventHook();
  const cancelHook = createEventHook();
  const revealHook = createEventHook();
  let _resolve = noop$1;
  const reveal = /* @__PURE__ */ __name((data30) => {
    revealHook.trigger(data30);
    revealed.value = true;
    return new Promise((resolve2) => {
      _resolve = resolve2;
    });
  }, "reveal");
  const confirm2 = /* @__PURE__ */ __name((data30) => {
    revealed.value = false;
    confirmHook.trigger(data30);
    _resolve({ data: data30, isCanceled: false });
  }, "confirm");
  const cancel = /* @__PURE__ */ __name((data30) => {
    revealed.value = false;
    cancelHook.trigger(data30);
    _resolve({ data: data30, isCanceled: true });
  }, "cancel");
  return {
    isRevealed: computed(() => revealed.value),
    reveal,
    confirm: confirm2,
    cancel,
    onReveal: revealHook.on,
    onConfirm: confirmHook.on,
    onCancel: cancelHook.on
  };
}
__name(useConfirmDialog, "useConfirmDialog");
function useCssVar(prop2, target2, options5 = {}) {
  const { window: window2 = defaultWindow, initialValue, observe: observe2 = false } = options5;
  const variable = ref(initialValue);
  const elRef = computed(() => {
    var _a2;
    return unrefElement(target2) || ((_a2 = window2 == null ? void 0 : window2.document) == null ? void 0 : _a2.documentElement);
  });
  function updateCssVar() {
    var _a2;
    const key = toValue$3(prop2);
    const el = toValue$3(elRef);
    if (el && window2 && key) {
      const value3 = (_a2 = window2.getComputedStyle(el).getPropertyValue(key)) == null ? void 0 : _a2.trim();
      variable.value = value3 || initialValue;
    }
  }
  __name(updateCssVar, "updateCssVar");
  if (observe2) {
    useMutationObserver(elRef, updateCssVar, {
      attributeFilter: ["style", "class"],
      window: window2
    });
  }
  watch(
    [elRef, () => toValue$3(prop2)],
    (_2, old) => {
      if (old[0] && old[1] && window2)
        window2.getComputedStyle(old[0]).removeProperty(old[1]);
      updateCssVar();
    },
    { immediate: true }
  );
  watch(
    variable,
    (val) => {
      var _a2;
      const raw_prop = toValue$3(prop2);
      if (((_a2 = elRef.value) == null ? void 0 : _a2.style) && raw_prop) {
        if (val == null)
          elRef.value.style.removeProperty(raw_prop);
        else
          elRef.value.style.setProperty(raw_prop, val);
      }
    }
  );
  return variable;
}
__name(useCssVar, "useCssVar");
function useCurrentElement(rootComponent) {
  const vm = getCurrentInstance();
  const currentElement = computedWithControl(
    () => null,
    () => rootComponent ? unrefElement(rootComponent) : vm.proxy.$el
  );
  onUpdated(currentElement.trigger);
  onMounted(currentElement.trigger);
  return currentElement;
}
__name(useCurrentElement, "useCurrentElement");
function useCycleList(list2, options5) {
  const state = shallowRef(getInitialValue());
  const listRef6 = toRef(list2);
  const index2 = computed({
    get() {
      var _a2;
      const targetList = listRef6.value;
      let index22 = (options5 == null ? void 0 : options5.getIndexOf) ? options5.getIndexOf(state.value, targetList) : targetList.indexOf(state.value);
      if (index22 < 0)
        index22 = (_a2 = options5 == null ? void 0 : options5.fallbackIndex) != null ? _a2 : 0;
      return index22;
    },
    set(v2) {
      set22(v2);
    }
  });
  function set22(i2) {
    const targetList = listRef6.value;
    const length = targetList.length;
    const index22 = (i2 % length + length) % length;
    const value3 = targetList[index22];
    state.value = value3;
    return value3;
  }
  __name(set22, "set2");
  function shift2(delta2 = 1) {
    return set22(index2.value + delta2);
  }
  __name(shift2, "shift");
  function next2(n2 = 1) {
    return shift2(n2);
  }
  __name(next2, "next");
  function prev2(n2 = 1) {
    return shift2(-n2);
  }
  __name(prev2, "prev");
  function getInitialValue() {
    var _a2, _b;
    return (_b = toValue$3((_a2 = options5 == null ? void 0 : options5.initialValue) != null ? _a2 : toValue$3(list2)[0])) != null ? _b : void 0;
  }
  __name(getInitialValue, "getInitialValue");
  watch(listRef6, () => set22(index2.value));
  return {
    state,
    index: index2,
    next: next2,
    prev: prev2,
    go: set22
  };
}
__name(useCycleList, "useCycleList");
function useDark(options5 = {}) {
  const {
    valueDark = "dark",
    valueLight = "",
    window: window2 = defaultWindow
  } = options5;
  const mode2 = useColorMode({
    ...options5,
    onChanged: /* @__PURE__ */ __name((mode22, defaultHandler) => {
      var _a2;
      if (options5.onChanged)
        (_a2 = options5.onChanged) == null ? void 0 : _a2.call(options5, mode22 === "dark", defaultHandler, mode22);
      else
        defaultHandler(mode22);
    }, "onChanged"),
    modes: {
      dark: valueDark,
      light: valueLight
    }
  });
  const system = computed(() => {
    if (mode2.system) {
      return mode2.system.value;
    } else {
      const preferredDark = usePreferredDark({ window: window2 });
      return preferredDark.value ? "dark" : "light";
    }
  });
  const isDark = computed({
    get() {
      return mode2.value === "dark";
    },
    set(v2) {
      const modeVal = v2 ? "dark" : "light";
      if (system.value === modeVal)
        mode2.value = "auto";
      else
        mode2.value = modeVal;
    }
  });
  return isDark;
}
__name(useDark, "useDark");
function fnBypass(v2) {
  return v2;
}
__name(fnBypass, "fnBypass");
function fnSetSource(source, value3) {
  return source.value = value3;
}
__name(fnSetSource, "fnSetSource");
function defaultDump(clone2) {
  return clone2 ? typeof clone2 === "function" ? clone2 : cloneFnJSON : fnBypass;
}
__name(defaultDump, "defaultDump");
function defaultParse(clone2) {
  return clone2 ? typeof clone2 === "function" ? clone2 : cloneFnJSON : fnBypass;
}
__name(defaultParse, "defaultParse");
function useManualRefHistory(source, options5 = {}) {
  const {
    clone: clone2 = false,
    dump = defaultDump(clone2),
    parse: parse2 = defaultParse(clone2),
    setSource = fnSetSource
  } = options5;
  function _createHistoryRecord() {
    return markRaw({
      snapshot: dump(source.value),
      timestamp: timestamp()
    });
  }
  __name(_createHistoryRecord, "_createHistoryRecord");
  const last = ref(_createHistoryRecord());
  const undoStack = ref([]);
  const redoStack = ref([]);
  const _setSource = /* @__PURE__ */ __name((record2) => {
    setSource(source, parse2(record2.snapshot));
    last.value = record2;
  }, "_setSource");
  const commit = /* @__PURE__ */ __name(() => {
    undoStack.value.unshift(last.value);
    last.value = _createHistoryRecord();
    if (options5.capacity && undoStack.value.length > options5.capacity)
      undoStack.value.splice(options5.capacity, Number.POSITIVE_INFINITY);
    if (redoStack.value.length)
      redoStack.value.splice(0, redoStack.value.length);
  }, "commit");
  const clear = /* @__PURE__ */ __name(() => {
    undoStack.value.splice(0, undoStack.value.length);
    redoStack.value.splice(0, redoStack.value.length);
  }, "clear");
  const undo2 = /* @__PURE__ */ __name(() => {
    const state = undoStack.value.shift();
    if (state) {
      redoStack.value.unshift(last.value);
      _setSource(state);
    }
  }, "undo");
  const redo2 = /* @__PURE__ */ __name(() => {
    const state = redoStack.value.shift();
    if (state) {
      undoStack.value.unshift(last.value);
      _setSource(state);
    }
  }, "redo");
  const reset2 = /* @__PURE__ */ __name(() => {
    _setSource(last.value);
  }, "reset");
  const history2 = computed(() => [last.value, ...undoStack.value]);
  const canUndo = computed(() => undoStack.value.length > 0);
  const canRedo = computed(() => redoStack.value.length > 0);
  return {
    source,
    undoStack,
    redoStack,
    last,
    history: history2,
    canUndo,
    canRedo,
    clear,
    commit,
    reset: reset2,
    undo: undo2,
    redo: redo2
  };
}
__name(useManualRefHistory, "useManualRefHistory");
function useRefHistory(source, options5 = {}) {
  const {
    deep = false,
    flush: flush2 = "pre",
    eventFilter
  } = options5;
  const {
    eventFilter: composedFilter,
    pause,
    resume: resumeTracking,
    isActive: isTracking
  } = pausableFilter(eventFilter);
  const {
    ignoreUpdates,
    ignorePrevAsyncUpdates,
    stop: stop2
  } = watchIgnorable(
    source,
    commit,
    { deep, flush: flush2, eventFilter: composedFilter }
  );
  function setSource(source2, value3) {
    ignorePrevAsyncUpdates();
    ignoreUpdates(() => {
      source2.value = value3;
    });
  }
  __name(setSource, "setSource");
  const manualHistory = useManualRefHistory(source, { ...options5, clone: options5.clone || deep, setSource });
  const { clear, commit: manualCommit } = manualHistory;
  function commit() {
    ignorePrevAsyncUpdates();
    manualCommit();
  }
  __name(commit, "commit");
  function resume(commitNow) {
    resumeTracking();
    if (commitNow)
      commit();
  }
  __name(resume, "resume");
  function batch2(fn) {
    let canceled = false;
    const cancel = /* @__PURE__ */ __name(() => canceled = true, "cancel");
    ignoreUpdates(() => {
      fn(cancel);
    });
    if (!canceled)
      commit();
  }
  __name(batch2, "batch");
  function dispose() {
    stop2();
    clear();
  }
  __name(dispose, "dispose");
  return {
    ...manualHistory,
    isTracking,
    pause,
    resume,
    commit,
    batch: batch2,
    dispose
  };
}
__name(useRefHistory, "useRefHistory");
function useDebouncedRefHistory(source, options5 = {}) {
  const filter4 = options5.debounce ? debounceFilter(options5.debounce) : void 0;
  const history2 = useRefHistory(source, { ...options5, eventFilter: filter4 });
  return {
    ...history2
  };
}
__name(useDebouncedRefHistory, "useDebouncedRefHistory");
function useDeviceMotion(options5 = {}) {
  const {
    window: window2 = defaultWindow,
    eventFilter = bypassFilter
  } = options5;
  const acceleration = ref({ x: null, y: null, z: null });
  const rotationRate = ref({ alpha: null, beta: null, gamma: null });
  const interval = ref(0);
  const accelerationIncludingGravity = ref({
    x: null,
    y: null,
    z: null
  });
  if (window2) {
    const onDeviceMotion = createFilterWrapper(
      eventFilter,
      (event) => {
        acceleration.value = event.acceleration;
        accelerationIncludingGravity.value = event.accelerationIncludingGravity;
        rotationRate.value = event.rotationRate;
        interval.value = event.interval;
      }
    );
    useEventListener(window2, "devicemotion", onDeviceMotion);
  }
  return {
    acceleration,
    accelerationIncludingGravity,
    rotationRate,
    interval
  };
}
__name(useDeviceMotion, "useDeviceMotion");
function useDeviceOrientation(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const isSupported2 = useSupported(() => window2 && "DeviceOrientationEvent" in window2);
  const isAbsolute2 = ref(false);
  const alpha2 = ref(null);
  const beta = ref(null);
  const gamma = ref(null);
  if (window2 && isSupported2.value) {
    useEventListener(window2, "deviceorientation", (event) => {
      isAbsolute2.value = event.absolute;
      alpha2.value = event.alpha;
      beta.value = event.beta;
      gamma.value = event.gamma;
    });
  }
  return {
    isSupported: isSupported2,
    isAbsolute: isAbsolute2,
    alpha: alpha2,
    beta,
    gamma
  };
}
__name(useDeviceOrientation, "useDeviceOrientation");
function useDevicePixelRatio(options5 = {}) {
  const {
    window: window2 = defaultWindow
  } = options5;
  const pixelRatio = ref(1);
  if (window2) {
    let observe2 = /* @__PURE__ */ __name(function() {
      pixelRatio.value = window2.devicePixelRatio;
      cleanup2();
      media = window2.matchMedia(`(resolution: ${pixelRatio.value}dppx)`);
      media.addEventListener("change", observe2, { once: true });
    }, "observe2"), cleanup2 = /* @__PURE__ */ __name(function() {
      media == null ? void 0 : media.removeEventListener("change", observe2);
    }, "cleanup2");
    let media;
    observe2();
    tryOnScopeDispose(cleanup2);
  }
  return { pixelRatio };
}
__name(useDevicePixelRatio, "useDevicePixelRatio");
function useDevicesList(options5 = {}) {
  const {
    navigator: navigator2 = defaultNavigator,
    requestPermissions = false,
    constraints = { audio: true, video: true },
    onUpdated: onUpdated2
  } = options5;
  const devices = ref([]);
  const videoInputs = computed(() => devices.value.filter((i2) => i2.kind === "videoinput"));
  const audioInputs = computed(() => devices.value.filter((i2) => i2.kind === "audioinput"));
  const audioOutputs = computed(() => devices.value.filter((i2) => i2.kind === "audiooutput"));
  const isSupported2 = useSupported(() => navigator2 && navigator2.mediaDevices && navigator2.mediaDevices.enumerateDevices);
  const permissionGranted = ref(false);
  let stream;
  async function update() {
    if (!isSupported2.value)
      return;
    devices.value = await navigator2.mediaDevices.enumerateDevices();
    onUpdated2 == null ? void 0 : onUpdated2(devices.value);
    if (stream) {
      stream.getTracks().forEach((t2) => t2.stop());
      stream = null;
    }
  }
  __name(update, "update");
  async function ensurePermissions() {
    if (!isSupported2.value)
      return false;
    if (permissionGranted.value)
      return true;
    const { state, query } = usePermission("camera", { controls: true });
    await query();
    if (state.value !== "granted") {
      stream = await navigator2.mediaDevices.getUserMedia(constraints);
      update();
      permissionGranted.value = true;
    } else {
      permissionGranted.value = true;
    }
    return permissionGranted.value;
  }
  __name(ensurePermissions, "ensurePermissions");
  if (isSupported2.value) {
    if (requestPermissions)
      ensurePermissions();
    useEventListener(navigator2.mediaDevices, "devicechange", update);
    update();
  }
  return {
    devices,
    ensurePermissions,
    permissionGranted,
    videoInputs,
    audioInputs,
    audioOutputs,
    isSupported: isSupported2
  };
}
__name(useDevicesList, "useDevicesList");
function useDisplayMedia(options5 = {}) {
  var _a2;
  const enabled = ref((_a2 = options5.enabled) != null ? _a2 : false);
  const video = options5.video;
  const audio = options5.audio;
  const { navigator: navigator2 = defaultNavigator } = options5;
  const isSupported2 = useSupported(() => {
    var _a22;
    return (_a22 = navigator2 == null ? void 0 : navigator2.mediaDevices) == null ? void 0 : _a22.getDisplayMedia;
  });
  const constraint = { audio, video };
  const stream = shallowRef();
  async function _start() {
    var _a22;
    if (!isSupported2.value || stream.value)
      return;
    stream.value = await navigator2.mediaDevices.getDisplayMedia(constraint);
    (_a22 = stream.value) == null ? void 0 : _a22.getTracks().forEach((t2) => t2.addEventListener("ended", stop2));
    return stream.value;
  }
  __name(_start, "_start");
  async function _stop() {
    var _a22;
    (_a22 = stream.value) == null ? void 0 : _a22.getTracks().forEach((t2) => t2.stop());
    stream.value = void 0;
  }
  __name(_stop, "_stop");
  function stop2() {
    _stop();
    enabled.value = false;
  }
  __name(stop2, "stop");
  async function start2() {
    await _start();
    if (stream.value)
      enabled.value = true;
    return stream.value;
  }
  __name(start2, "start");
  watch(
    enabled,
    (v2) => {
      if (v2)
        _start();
      else
        _stop();
    },
    { immediate: true }
  );
  return {
    isSupported: isSupported2,
    stream,
    start: start2,
    stop: stop2,
    enabled
  };
}
__name(useDisplayMedia, "useDisplayMedia");
function useDocumentVisibility(options5 = {}) {
  const { document: document2 = defaultDocument } = options5;
  if (!document2)
    return ref("visible");
  const visibility = ref(document2.visibilityState);
  useEventListener(document2, "visibilitychange", () => {
    visibility.value = document2.visibilityState;
  });
  return visibility;
}
__name(useDocumentVisibility, "useDocumentVisibility");
function useDraggable(target2, options5 = {}) {
  var _a2, _b;
  const {
    pointerTypes,
    preventDefault: preventDefault2,
    stopPropagation,
    exact,
    onMove,
    onEnd,
    onStart,
    initialValue,
    axis = "both",
    draggingElement = defaultWindow,
    containerElement,
    handle: draggingHandle = target2,
    buttons = [0]
  } = options5;
  const position3 = ref(
    (_a2 = toValue$3(initialValue)) != null ? _a2 : { x: 0, y: 0 }
  );
  const pressedDelta = ref();
  const filterEvent = /* @__PURE__ */ __name((e2) => {
    if (pointerTypes)
      return pointerTypes.includes(e2.pointerType);
    return true;
  }, "filterEvent");
  const handleEvent = /* @__PURE__ */ __name((e2) => {
    if (toValue$3(preventDefault2))
      e2.preventDefault();
    if (toValue$3(stopPropagation))
      e2.stopPropagation();
  }, "handleEvent");
  const start2 = /* @__PURE__ */ __name((e2) => {
    var _a22;
    if (!toValue$3(buttons).includes(e2.button))
      return;
    if (toValue$3(options5.disabled) || !filterEvent(e2))
      return;
    if (toValue$3(exact) && e2.target !== toValue$3(target2))
      return;
    const container = toValue$3(containerElement);
    const containerRect = (_a22 = container == null ? void 0 : container.getBoundingClientRect) == null ? void 0 : _a22.call(container);
    const targetRect = toValue$3(target2).getBoundingClientRect();
    const pos = {
      x: e2.clientX - (container ? targetRect.left - containerRect.left + container.scrollLeft : targetRect.left),
      y: e2.clientY - (container ? targetRect.top - containerRect.top + container.scrollTop : targetRect.top)
    };
    if ((onStart == null ? void 0 : onStart(pos, e2)) === false)
      return;
    pressedDelta.value = pos;
    handleEvent(e2);
  }, "start");
  const move = /* @__PURE__ */ __name((e2) => {
    if (toValue$3(options5.disabled) || !filterEvent(e2))
      return;
    if (!pressedDelta.value)
      return;
    const container = toValue$3(containerElement);
    const targetRect = toValue$3(target2).getBoundingClientRect();
    let { x: x2, y: y2 } = position3.value;
    if (axis === "x" || axis === "both") {
      x2 = e2.clientX - pressedDelta.value.x;
      if (container)
        x2 = Math.min(Math.max(0, x2), container.scrollWidth - targetRect.width);
    }
    if (axis === "y" || axis === "both") {
      y2 = e2.clientY - pressedDelta.value.y;
      if (container)
        y2 = Math.min(Math.max(0, y2), container.scrollHeight - targetRect.height);
    }
    position3.value = {
      x: x2,
      y: y2
    };
    onMove == null ? void 0 : onMove(position3.value, e2);
    handleEvent(e2);
  }, "move");
  const end = /* @__PURE__ */ __name((e2) => {
    if (toValue$3(options5.disabled) || !filterEvent(e2))
      return;
    if (!pressedDelta.value)
      return;
    pressedDelta.value = void 0;
    onEnd == null ? void 0 : onEnd(position3.value, e2);
    handleEvent(e2);
  }, "end");
  if (isClient$1) {
    const config2 = { capture: (_b = options5.capture) != null ? _b : true };
    useEventListener(draggingHandle, "pointerdown", start2, config2);
    useEventListener(draggingElement, "pointermove", move, config2);
    useEventListener(draggingElement, "pointerup", end, config2);
  }
  return {
    ...toRefs(position3),
    position: position3,
    isDragging: computed(() => !!pressedDelta.value),
    style: computed(
      () => `left:${position3.value.x}px;top:${position3.value.y}px;`
    )
  };
}
__name(useDraggable, "useDraggable");
function useDropZone(target2, options5 = {}) {
  const isOverDropZone = ref(false);
  const files = shallowRef(null);
  let counter = 0;
  let isDataTypeIncluded = true;
  if (isClient$1) {
    const _options = typeof options5 === "function" ? { onDrop: options5 } : options5;
    const getFiles = /* @__PURE__ */ __name((event) => {
      var _a2, _b;
      const list2 = Array.from((_b = (_a2 = event.dataTransfer) == null ? void 0 : _a2.files) != null ? _b : []);
      return files.value = list2.length === 0 ? null : list2;
    }, "getFiles");
    useEventListener(target2, "dragenter", (event) => {
      var _a2, _b;
      const types = Array.from(((_a2 = event == null ? void 0 : event.dataTransfer) == null ? void 0 : _a2.items) || []).map((i2) => i2.kind === "file" ? i2.type : null).filter(notNullish);
      if (_options.dataTypes && event.dataTransfer) {
        const dataTypes2 = unref(_options.dataTypes);
        isDataTypeIncluded = typeof dataTypes2 === "function" ? dataTypes2(types) : dataTypes2 ? dataTypes2.some((item3) => types.includes(item3)) : true;
        if (!isDataTypeIncluded)
          return;
      }
      event.preventDefault();
      counter += 1;
      isOverDropZone.value = true;
      (_b = _options.onEnter) == null ? void 0 : _b.call(_options, getFiles(event), event);
    });
    useEventListener(target2, "dragover", (event) => {
      var _a2;
      if (!isDataTypeIncluded)
        return;
      event.preventDefault();
      (_a2 = _options.onOver) == null ? void 0 : _a2.call(_options, getFiles(event), event);
    });
    useEventListener(target2, "dragleave", (event) => {
      var _a2;
      if (!isDataTypeIncluded)
        return;
      event.preventDefault();
      counter -= 1;
      if (counter === 0)
        isOverDropZone.value = false;
      (_a2 = _options.onLeave) == null ? void 0 : _a2.call(_options, getFiles(event), event);
    });
    useEventListener(target2, "drop", (event) => {
      var _a2;
      event.preventDefault();
      counter = 0;
      isOverDropZone.value = false;
      (_a2 = _options.onDrop) == null ? void 0 : _a2.call(_options, getFiles(event), event);
    });
  }
  return {
    files,
    isOverDropZone
  };
}
__name(useDropZone, "useDropZone");
function useResizeObserver(target2, callback, options5 = {}) {
  const { window: window2 = defaultWindow, ...observerOptions } = options5;
  let observer;
  const isSupported2 = useSupported(() => window2 && "ResizeObserver" in window2);
  const cleanup = /* @__PURE__ */ __name(() => {
    if (observer) {
      observer.disconnect();
      observer = void 0;
    }
  }, "cleanup");
  const targets = computed(() => {
    const _targets = toValue$3(target2);
    return Array.isArray(_targets) ? _targets.map((el) => unrefElement(el)) : [unrefElement(_targets)];
  });
  const stopWatch = watch(
    targets,
    (els) => {
      cleanup();
      if (isSupported2.value && window2) {
        observer = new ResizeObserver(callback);
        for (const _el of els) {
          if (_el)
            observer.observe(_el, observerOptions);
        }
      }
    },
    { immediate: true, flush: "post" }
  );
  const stop2 = /* @__PURE__ */ __name(() => {
    cleanup();
    stopWatch();
  }, "stop");
  tryOnScopeDispose(stop2);
  return {
    isSupported: isSupported2,
    stop: stop2
  };
}
__name(useResizeObserver, "useResizeObserver");
function useElementBounding(target2, options5 = {}) {
  const {
    reset: reset2 = true,
    windowResize = true,
    windowScroll = true,
    immediate = true,
    updateTiming = "sync"
  } = options5;
  const height = ref(0);
  const bottom = ref(0);
  const left = ref(0);
  const right = ref(0);
  const top = ref(0);
  const width2 = ref(0);
  const x2 = ref(0);
  const y2 = ref(0);
  function recalculate() {
    const el = unrefElement(target2);
    if (!el) {
      if (reset2) {
        height.value = 0;
        bottom.value = 0;
        left.value = 0;
        right.value = 0;
        top.value = 0;
        width2.value = 0;
        x2.value = 0;
        y2.value = 0;
      }
      return;
    }
    const rect = el.getBoundingClientRect();
    height.value = rect.height;
    bottom.value = rect.bottom;
    left.value = rect.left;
    right.value = rect.right;
    top.value = rect.top;
    width2.value = rect.width;
    x2.value = rect.x;
    y2.value = rect.y;
  }
  __name(recalculate, "recalculate");
  function update() {
    if (updateTiming === "sync")
      recalculate();
    else if (updateTiming === "next-frame")
      requestAnimationFrame(() => recalculate());
  }
  __name(update, "update");
  useResizeObserver(target2, update);
  watch(() => unrefElement(target2), (ele) => !ele && update());
  useMutationObserver(target2, update, {
    attributeFilter: ["style", "class"]
  });
  if (windowScroll)
    useEventListener("scroll", update, { capture: true, passive: true });
  if (windowResize)
    useEventListener("resize", update, { passive: true });
  tryOnMounted$2(() => {
    if (immediate)
      update();
  });
  return {
    height,
    bottom,
    left,
    right,
    top,
    width: width2,
    x: x2,
    y: y2,
    update
  };
}
__name(useElementBounding, "useElementBounding");
function useElementByPoint(options5) {
  const {
    x: x2,
    y: y2,
    document: document2 = defaultDocument,
    multiple,
    interval = "requestAnimationFrame",
    immediate = true
  } = options5;
  const isSupported2 = useSupported(() => {
    if (toValue$3(multiple))
      return document2 && "elementsFromPoint" in document2;
    return document2 && "elementFromPoint" in document2;
  });
  const element = ref(null);
  const cb = /* @__PURE__ */ __name(() => {
    var _a2, _b;
    element.value = toValue$3(multiple) ? (_a2 = document2 == null ? void 0 : document2.elementsFromPoint(toValue$3(x2), toValue$3(y2))) != null ? _a2 : [] : (_b = document2 == null ? void 0 : document2.elementFromPoint(toValue$3(x2), toValue$3(y2))) != null ? _b : null;
  }, "cb");
  const controls = interval === "requestAnimationFrame" ? useRafFn(cb, { immediate }) : useIntervalFn(cb, interval, { immediate });
  return {
    isSupported: isSupported2,
    element,
    ...controls
  };
}
__name(useElementByPoint, "useElementByPoint");
function useElementHover(el, options5 = {}) {
  const {
    delayEnter = 0,
    delayLeave = 0,
    window: window2 = defaultWindow
  } = options5;
  const isHovered = ref(false);
  let timer;
  const toggle5 = /* @__PURE__ */ __name((entering) => {
    const delay = entering ? delayEnter : delayLeave;
    if (timer) {
      clearTimeout(timer);
      timer = void 0;
    }
    if (delay)
      timer = setTimeout(() => isHovered.value = entering, delay);
    else
      isHovered.value = entering;
  }, "toggle");
  if (!window2)
    return isHovered;
  useEventListener(el, "mouseenter", () => toggle5(true), { passive: true });
  useEventListener(el, "mouseleave", () => toggle5(false), { passive: true });
  return isHovered;
}
__name(useElementHover, "useElementHover");
function useElementSize(target2, initialSize = { width: 0, height: 0 }, options5 = {}) {
  const { window: window2 = defaultWindow, box = "content-box" } = options5;
  const isSVG = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = unrefElement(target2)) == null ? void 0 : _a2.namespaceURI) == null ? void 0 : _b.includes("svg");
  });
  const width2 = ref(initialSize.width);
  const height = ref(initialSize.height);
  const { stop: stop1 } = useResizeObserver(
    target2,
    ([entry]) => {
      const boxSize = box === "border-box" ? entry.borderBoxSize : box === "content-box" ? entry.contentBoxSize : entry.devicePixelContentBoxSize;
      if (window2 && isSVG.value) {
        const $elem = unrefElement(target2);
        if ($elem) {
          const rect = $elem.getBoundingClientRect();
          width2.value = rect.width;
          height.value = rect.height;
        }
      } else {
        if (boxSize) {
          const formatBoxSize = Array.isArray(boxSize) ? boxSize : [boxSize];
          width2.value = formatBoxSize.reduce((acc, { inlineSize }) => acc + inlineSize, 0);
          height.value = formatBoxSize.reduce((acc, { blockSize }) => acc + blockSize, 0);
        } else {
          width2.value = entry.contentRect.width;
          height.value = entry.contentRect.height;
        }
      }
    },
    options5
  );
  tryOnMounted$2(() => {
    const ele = unrefElement(target2);
    if (ele) {
      width2.value = "offsetWidth" in ele ? ele.offsetWidth : initialSize.width;
      height.value = "offsetHeight" in ele ? ele.offsetHeight : initialSize.height;
    }
  });
  const stop2 = watch(
    () => unrefElement(target2),
    (ele) => {
      width2.value = ele ? initialSize.width : 0;
      height.value = ele ? initialSize.height : 0;
    }
  );
  function stop3() {
    stop1();
    stop2();
  }
  __name(stop3, "stop");
  return {
    width: width2,
    height,
    stop: stop3
  };
}
__name(useElementSize, "useElementSize");
function useIntersectionObserver(target2, callback, options5 = {}) {
  const {
    root: root34,
    rootMargin = "0px",
    threshold = 0,
    window: window2 = defaultWindow,
    immediate = true
  } = options5;
  const isSupported2 = useSupported(() => window2 && "IntersectionObserver" in window2);
  const targets = computed(() => {
    const _target = toValue$3(target2);
    return (Array.isArray(_target) ? _target : [_target]).map(unrefElement).filter(notNullish);
  });
  let cleanup = noop$1;
  const isActive2 = ref(immediate);
  const stopWatch = isSupported2.value ? watch(
    () => [targets.value, unrefElement(root34), isActive2.value],
    ([targets2, root210]) => {
      cleanup();
      if (!isActive2.value)
        return;
      if (!targets2.length)
        return;
      const observer = new IntersectionObserver(
        callback,
        {
          root: unrefElement(root210),
          rootMargin,
          threshold
        }
      );
      targets2.forEach((el) => el && observer.observe(el));
      cleanup = /* @__PURE__ */ __name(() => {
        observer.disconnect();
        cleanup = noop$1;
      }, "cleanup");
    },
    { immediate, flush: "post" }
  ) : noop$1;
  const stop2 = /* @__PURE__ */ __name(() => {
    cleanup();
    stopWatch();
    isActive2.value = false;
  }, "stop");
  tryOnScopeDispose(stop2);
  return {
    isSupported: isSupported2,
    isActive: isActive2,
    pause() {
      cleanup();
      isActive2.value = false;
    },
    resume() {
      isActive2.value = true;
    },
    stop: stop2
  };
}
__name(useIntersectionObserver, "useIntersectionObserver");
function useElementVisibility(element, options5 = {}) {
  const { window: window2 = defaultWindow, scrollTarget, threshold = 0 } = options5;
  const elementIsVisible = ref(false);
  useIntersectionObserver(
    element,
    (intersectionObserverEntries) => {
      let isIntersecting = elementIsVisible.value;
      let latestTime = 0;
      for (const entry of intersectionObserverEntries) {
        if (entry.time >= latestTime) {
          latestTime = entry.time;
          isIntersecting = entry.isIntersecting;
        }
      }
      elementIsVisible.value = isIntersecting;
    },
    {
      root: scrollTarget,
      window: window2,
      threshold
    }
  );
  return elementIsVisible;
}
__name(useElementVisibility, "useElementVisibility");
const events = /* @__PURE__ */ new Map();
function useEventBus(key) {
  const scope = getCurrentScope();
  function on2(listener) {
    var _a2;
    const listeners = events.get(key) || /* @__PURE__ */ new Set();
    listeners.add(listener);
    events.set(key, listeners);
    const _off = /* @__PURE__ */ __name(() => off(listener), "_off");
    (_a2 = scope == null ? void 0 : scope.cleanups) == null ? void 0 : _a2.push(_off);
    return _off;
  }
  __name(on2, "on");
  function once2(listener) {
    function _listener(...args) {
      off(_listener);
      listener(...args);
    }
    __name(_listener, "_listener");
    return on2(_listener);
  }
  __name(once2, "once");
  function off(listener) {
    const listeners = events.get(key);
    if (!listeners)
      return;
    listeners.delete(listener);
    if (!listeners.size)
      reset2();
  }
  __name(off, "off");
  function reset2() {
    events.delete(key);
  }
  __name(reset2, "reset");
  function emit2(event, payload) {
    var _a2;
    (_a2 = events.get(key)) == null ? void 0 : _a2.forEach((v2) => v2(event, payload));
  }
  __name(emit2, "emit");
  return { on: on2, once: once2, off, emit: emit2, reset: reset2 };
}
__name(useEventBus, "useEventBus");
function resolveNestedOptions$1(options5) {
  if (options5 === true)
    return {};
  return options5;
}
__name(resolveNestedOptions$1, "resolveNestedOptions$1");
function useEventSource(url, events2 = [], options5 = {}) {
  const event = ref(null);
  const data30 = ref(null);
  const status = ref("CONNECTING");
  const eventSource = ref(null);
  const error2 = shallowRef(null);
  const urlRef = toRef(url);
  const lastEventId2 = shallowRef(null);
  let explicitlyClosed = false;
  let retried = 0;
  const {
    withCredentials = false,
    immediate = true
  } = options5;
  const close5 = /* @__PURE__ */ __name(() => {
    if (isClient$1 && eventSource.value) {
      eventSource.value.close();
      eventSource.value = null;
      status.value = "CLOSED";
      explicitlyClosed = true;
    }
  }, "close");
  const _init = /* @__PURE__ */ __name(() => {
    if (explicitlyClosed || typeof urlRef.value === "undefined")
      return;
    const es = new EventSource(urlRef.value, { withCredentials });
    status.value = "CONNECTING";
    eventSource.value = es;
    es.onopen = () => {
      status.value = "OPEN";
      error2.value = null;
    };
    es.onerror = (e2) => {
      status.value = "CLOSED";
      error2.value = e2;
      if (es.readyState === 2 && !explicitlyClosed && options5.autoReconnect) {
        es.close();
        const {
          retries = -1,
          delay = 1e3,
          onFailed
        } = resolveNestedOptions$1(options5.autoReconnect);
        retried += 1;
        if (typeof retries === "number" && (retries < 0 || retried < retries))
          setTimeout(_init, delay);
        else if (typeof retries === "function" && retries())
          setTimeout(_init, delay);
        else
          onFailed == null ? void 0 : onFailed();
      }
    };
    es.onmessage = (e2) => {
      event.value = null;
      data30.value = e2.data;
      lastEventId2.value = e2.lastEventId;
    };
    for (const event_name of events2) {
      useEventListener(es, event_name, (e2) => {
        event.value = event_name;
        data30.value = e2.data || null;
      });
    }
  }, "_init");
  const open2 = /* @__PURE__ */ __name(() => {
    if (!isClient$1)
      return;
    close5();
    explicitlyClosed = false;
    retried = 0;
    _init();
  }, "open");
  if (immediate)
    watch(urlRef, open2, { immediate: true });
  tryOnScopeDispose(close5);
  return {
    eventSource,
    event,
    data: data30,
    status,
    error: error2,
    open: open2,
    close: close5,
    lastEventId: lastEventId2
  };
}
__name(useEventSource, "useEventSource");
function useEyeDropper(options5 = {}) {
  const { initialValue = "" } = options5;
  const isSupported2 = useSupported(() => typeof window !== "undefined" && "EyeDropper" in window);
  const sRGBHex = ref(initialValue);
  async function open2(openOptions) {
    if (!isSupported2.value)
      return;
    const eyeDropper = new window.EyeDropper();
    const result = await eyeDropper.open(openOptions);
    sRGBHex.value = result.sRGBHex;
    return result;
  }
  __name(open2, "open");
  return { isSupported: isSupported2, sRGBHex, open: open2 };
}
__name(useEyeDropper, "useEyeDropper");
function useFavicon(newIcon = null, options5 = {}) {
  const {
    baseUrl = "",
    rel = "icon",
    document: document2 = defaultDocument
  } = options5;
  const favicon = toRef(newIcon);
  const applyIcon = /* @__PURE__ */ __name((icon3) => {
    const elements = document2 == null ? void 0 : document2.head.querySelectorAll(`link[rel*="${rel}"]`);
    if (!elements || elements.length === 0) {
      const link2 = document2 == null ? void 0 : document2.createElement("link");
      if (link2) {
        link2.rel = rel;
        link2.href = `${baseUrl}${icon3}`;
        link2.type = `image/${icon3.split(".").pop()}`;
        document2 == null ? void 0 : document2.head.append(link2);
      }
      return;
    }
    elements == null ? void 0 : elements.forEach((el) => el.href = `${baseUrl}${icon3}`);
  }, "applyIcon");
  watch(
    favicon,
    (i2, o2) => {
      if (typeof i2 === "string" && i2 !== o2)
        applyIcon(i2);
    },
    { immediate: true }
  );
  return favicon;
}
__name(useFavicon, "useFavicon");
const payloadMapping = {
  json: "application/json",
  text: "text/plain"
};
function isFetchOptions(obj) {
  return obj && containsProp(obj, "immediate", "refetch", "initialData", "timeout", "beforeFetch", "afterFetch", "onFetchError", "fetch", "updateDataOnError");
}
__name(isFetchOptions, "isFetchOptions");
const reAbsolute = /^(?:[a-z][a-z\d+\-.]*:)?\/\//i;
function isAbsoluteURL(url) {
  return reAbsolute.test(url);
}
__name(isAbsoluteURL, "isAbsoluteURL");
function headersToObject(headers) {
  if (typeof Headers !== "undefined" && headers instanceof Headers)
    return Object.fromEntries(headers.entries());
  return headers;
}
__name(headersToObject, "headersToObject");
function combineCallbacks(combination, ...callbacks) {
  if (combination === "overwrite") {
    return async (ctx) => {
      const callback = callbacks[callbacks.length - 1];
      if (callback)
        return { ...ctx, ...await callback(ctx) };
      return ctx;
    };
  } else {
    return async (ctx) => {
      for (const callback of callbacks) {
        if (callback)
          ctx = { ...ctx, ...await callback(ctx) };
      }
      return ctx;
    };
  }
}
__name(combineCallbacks, "combineCallbacks");
function createFetch(config2 = {}) {
  const _combination = config2.combination || "chain";
  const _options = config2.options || {};
  const _fetchOptions = config2.fetchOptions || {};
  function useFactoryFetch(url, ...args) {
    const computedUrl = computed(() => {
      const baseUrl = toValue$3(config2.baseUrl);
      const targetUrl = toValue$3(url);
      return baseUrl && !isAbsoluteURL(targetUrl) ? joinPaths(baseUrl, targetUrl) : targetUrl;
    });
    let options5 = _options;
    let fetchOptions = _fetchOptions;
    if (args.length > 0) {
      if (isFetchOptions(args[0])) {
        options5 = {
          ...options5,
          ...args[0],
          beforeFetch: combineCallbacks(_combination, _options.beforeFetch, args[0].beforeFetch),
          afterFetch: combineCallbacks(_combination, _options.afterFetch, args[0].afterFetch),
          onFetchError: combineCallbacks(_combination, _options.onFetchError, args[0].onFetchError)
        };
      } else {
        fetchOptions = {
          ...fetchOptions,
          ...args[0],
          headers: {
            ...headersToObject(fetchOptions.headers) || {},
            ...headersToObject(args[0].headers) || {}
          }
        };
      }
    }
    if (args.length > 1 && isFetchOptions(args[1])) {
      options5 = {
        ...options5,
        ...args[1],
        beforeFetch: combineCallbacks(_combination, _options.beforeFetch, args[1].beforeFetch),
        afterFetch: combineCallbacks(_combination, _options.afterFetch, args[1].afterFetch),
        onFetchError: combineCallbacks(_combination, _options.onFetchError, args[1].onFetchError)
      };
    }
    return useFetch(computedUrl, fetchOptions, options5);
  }
  __name(useFactoryFetch, "useFactoryFetch");
  return useFactoryFetch;
}
__name(createFetch, "createFetch");
function useFetch(url, ...args) {
  var _a2;
  const supportsAbort = typeof AbortController === "function";
  let fetchOptions = {};
  let options5 = {
    immediate: true,
    refetch: false,
    timeout: 0,
    updateDataOnError: false
  };
  const config2 = {
    method: "GET",
    type: "text",
    payload: void 0
  };
  if (args.length > 0) {
    if (isFetchOptions(args[0]))
      options5 = { ...options5, ...args[0] };
    else
      fetchOptions = args[0];
  }
  if (args.length > 1) {
    if (isFetchOptions(args[1]))
      options5 = { ...options5, ...args[1] };
  }
  const {
    fetch: fetch2 = (_a2 = defaultWindow) == null ? void 0 : _a2.fetch,
    initialData,
    timeout
  } = options5;
  const responseEvent = createEventHook();
  const errorEvent = createEventHook();
  const finallyEvent = createEventHook();
  const isFinished = ref(false);
  const isFetching2 = ref(false);
  const aborted = ref(false);
  const statusCode = ref(null);
  const response = shallowRef(null);
  const error2 = shallowRef(null);
  const data30 = shallowRef(initialData || null);
  const canAbort = computed(() => supportsAbort && isFetching2.value);
  let controller;
  let timer;
  const abort = /* @__PURE__ */ __name(() => {
    if (supportsAbort) {
      controller == null ? void 0 : controller.abort();
      controller = new AbortController();
      controller.signal.onabort = () => aborted.value = true;
      fetchOptions = {
        ...fetchOptions,
        signal: controller.signal
      };
    }
  }, "abort");
  const loading2 = /* @__PURE__ */ __name((isLoading) => {
    isFetching2.value = isLoading;
    isFinished.value = !isLoading;
  }, "loading");
  if (timeout)
    timer = useTimeoutFn(abort, timeout, { immediate: false });
  let executeCounter = 0;
  const execute = /* @__PURE__ */ __name(async (throwOnFailed = false) => {
    var _a22, _b;
    abort();
    loading2(true);
    error2.value = null;
    statusCode.value = null;
    aborted.value = false;
    executeCounter += 1;
    const currentExecuteCounter = executeCounter;
    const defaultFetchOptions = {
      method: config2.method,
      headers: {}
    };
    if (config2.payload) {
      const headers = headersToObject(defaultFetchOptions.headers);
      const payload = toValue$3(config2.payload);
      if (!config2.payloadType && payload && Object.getPrototypeOf(payload) === Object.prototype && !(payload instanceof FormData))
        config2.payloadType = "json";
      if (config2.payloadType)
        headers["Content-Type"] = (_a22 = payloadMapping[config2.payloadType]) != null ? _a22 : config2.payloadType;
      defaultFetchOptions.body = config2.payloadType === "json" ? JSON.stringify(payload) : payload;
    }
    let isCanceled = false;
    const context = {
      url: toValue$3(url),
      options: {
        ...defaultFetchOptions,
        ...fetchOptions
      },
      cancel: /* @__PURE__ */ __name(() => {
        isCanceled = true;
      }, "cancel")
    };
    if (options5.beforeFetch)
      Object.assign(context, await options5.beforeFetch(context));
    if (isCanceled || !fetch2) {
      loading2(false);
      return Promise.resolve(null);
    }
    let responseData = null;
    if (timer)
      timer.start();
    return fetch2(
      context.url,
      {
        ...defaultFetchOptions,
        ...context.options,
        headers: {
          ...headersToObject(defaultFetchOptions.headers),
          ...headersToObject((_b = context.options) == null ? void 0 : _b.headers)
        }
      }
    ).then(async (fetchResponse) => {
      response.value = fetchResponse;
      statusCode.value = fetchResponse.status;
      responseData = await fetchResponse.clone()[config2.type]();
      if (!fetchResponse.ok) {
        data30.value = initialData || null;
        throw new Error(fetchResponse.statusText);
      }
      if (options5.afterFetch) {
        ({ data: responseData } = await options5.afterFetch({
          data: responseData,
          response: fetchResponse
        }));
      }
      data30.value = responseData;
      responseEvent.trigger(fetchResponse);
      return fetchResponse;
    }).catch(async (fetchError) => {
      let errorData = fetchError.message || fetchError.name;
      if (options5.onFetchError) {
        ({ error: errorData, data: responseData } = await options5.onFetchError({
          data: responseData,
          error: fetchError,
          response: response.value
        }));
      }
      error2.value = errorData;
      if (options5.updateDataOnError)
        data30.value = responseData;
      errorEvent.trigger(fetchError);
      if (throwOnFailed)
        throw fetchError;
      return null;
    }).finally(() => {
      if (currentExecuteCounter === executeCounter)
        loading2(false);
      if (timer)
        timer.stop();
      finallyEvent.trigger(null);
    });
  }, "execute");
  const refetch = toRef(options5.refetch);
  watch(
    [
      refetch,
      toRef(url)
    ],
    ([refetch2]) => refetch2 && execute(),
    { deep: true }
  );
  const shell = {
    isFinished: readonly(isFinished),
    isFetching: readonly(isFetching2),
    statusCode,
    response,
    error: error2,
    data: data30,
    canAbort,
    aborted,
    abort,
    execute,
    onFetchResponse: responseEvent.on,
    onFetchError: errorEvent.on,
    onFetchFinally: finallyEvent.on,
    // method
    get: setMethod("GET"),
    put: setMethod("PUT"),
    post: setMethod("POST"),
    delete: setMethod("DELETE"),
    patch: setMethod("PATCH"),
    head: setMethod("HEAD"),
    options: setMethod("OPTIONS"),
    // type
    json: setType2("json"),
    text: setType2("text"),
    blob: setType2("blob"),
    arrayBuffer: setType2("arrayBuffer"),
    formData: setType2("formData")
  };
  function setMethod(method) {
    return (payload, payloadType) => {
      if (!isFetching2.value) {
        config2.method = method;
        config2.payload = payload;
        config2.payloadType = payloadType;
        if (isRef(config2.payload)) {
          watch(
            [
              refetch,
              toRef(config2.payload)
            ],
            ([refetch2]) => refetch2 && execute(),
            { deep: true }
          );
        }
        return {
          ...shell,
          then(onFulfilled, onRejected) {
            return waitUntilFinished().then(onFulfilled, onRejected);
          }
        };
      }
      return void 0;
    };
  }
  __name(setMethod, "setMethod");
  function waitUntilFinished() {
    return new Promise((resolve2, reject3) => {
      until(isFinished).toBe(true).then(() => resolve2(shell)).catch((error22) => reject3(error22));
    });
  }
  __name(waitUntilFinished, "waitUntilFinished");
  function setType2(type) {
    return () => {
      if (!isFetching2.value) {
        config2.type = type;
        return {
          ...shell,
          then(onFulfilled, onRejected) {
            return waitUntilFinished().then(onFulfilled, onRejected);
          }
        };
      }
      return void 0;
    };
  }
  __name(setType2, "setType");
  if (options5.immediate)
    Promise.resolve().then(() => execute());
  return {
    ...shell,
    then(onFulfilled, onRejected) {
      return waitUntilFinished().then(onFulfilled, onRejected);
    }
  };
}
__name(useFetch, "useFetch");
function joinPaths(start2, end) {
  if (!start2.endsWith("/") && !end.startsWith("/"))
    return `${start2}/${end}`;
  return `${start2}${end}`;
}
__name(joinPaths, "joinPaths");
const DEFAULT_OPTIONS = {
  multiple: true,
  accept: "*",
  reset: false,
  directory: false
};
function useFileDialog(options5 = {}) {
  const {
    document: document2 = defaultDocument
  } = options5;
  const files = ref(null);
  const { on: onChange6, trigger: trigger2 } = createEventHook();
  let input;
  if (document2) {
    input = document2.createElement("input");
    input.type = "file";
    input.onchange = (event) => {
      const result = event.target;
      files.value = result.files;
      trigger2(files.value);
    };
  }
  const reset2 = /* @__PURE__ */ __name(() => {
    files.value = null;
    if (input && input.value) {
      input.value = "";
      trigger2(null);
    }
  }, "reset");
  const open2 = /* @__PURE__ */ __name((localOptions) => {
    if (!input)
      return;
    const _options = {
      ...DEFAULT_OPTIONS,
      ...options5,
      ...localOptions
    };
    input.multiple = _options.multiple;
    input.accept = _options.accept;
    input.webkitdirectory = _options.directory;
    if (hasOwn$2(_options, "capture"))
      input.capture = _options.capture;
    if (_options.reset)
      reset2();
    input.click();
  }, "open");
  return {
    files: readonly(files),
    open: open2,
    reset: reset2,
    onChange: onChange6
  };
}
__name(useFileDialog, "useFileDialog");
function useFileSystemAccess(options5 = {}) {
  const {
    window: _window = defaultWindow,
    dataType = "Text"
  } = options5;
  const window2 = _window;
  const isSupported2 = useSupported(() => window2 && "showSaveFilePicker" in window2 && "showOpenFilePicker" in window2);
  const fileHandle = ref();
  const data30 = ref();
  const file = ref();
  const fileName = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = file.value) == null ? void 0 : _a2.name) != null ? _b : "";
  });
  const fileMIME = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = file.value) == null ? void 0 : _a2.type) != null ? _b : "";
  });
  const fileSize = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = file.value) == null ? void 0 : _a2.size) != null ? _b : 0;
  });
  const fileLastModified = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = file.value) == null ? void 0 : _a2.lastModified) != null ? _b : 0;
  });
  async function open2(_options = {}) {
    if (!isSupported2.value)
      return;
    const [handle] = await window2.showOpenFilePicker({ ...toValue$3(options5), ..._options });
    fileHandle.value = handle;
    await updateData();
  }
  __name(open2, "open");
  async function create3(_options = {}) {
    if (!isSupported2.value)
      return;
    fileHandle.value = await window2.showSaveFilePicker({ ...options5, ..._options });
    data30.value = void 0;
    await updateData();
  }
  __name(create3, "create");
  async function save(_options = {}) {
    if (!isSupported2.value)
      return;
    if (!fileHandle.value)
      return saveAs2(_options);
    if (data30.value) {
      const writableStream = await fileHandle.value.createWritable();
      await writableStream.write(data30.value);
      await writableStream.close();
    }
    await updateFile();
  }
  __name(save, "save");
  async function saveAs2(_options = {}) {
    if (!isSupported2.value)
      return;
    fileHandle.value = await window2.showSaveFilePicker({ ...options5, ..._options });
    if (data30.value) {
      const writableStream = await fileHandle.value.createWritable();
      await writableStream.write(data30.value);
      await writableStream.close();
    }
    await updateFile();
  }
  __name(saveAs2, "saveAs");
  async function updateFile() {
    var _a2;
    file.value = await ((_a2 = fileHandle.value) == null ? void 0 : _a2.getFile());
  }
  __name(updateFile, "updateFile");
  async function updateData() {
    var _a2, _b;
    await updateFile();
    const type = toValue$3(dataType);
    if (type === "Text")
      data30.value = await ((_a2 = file.value) == null ? void 0 : _a2.text());
    else if (type === "ArrayBuffer")
      data30.value = await ((_b = file.value) == null ? void 0 : _b.arrayBuffer());
    else if (type === "Blob")
      data30.value = file.value;
  }
  __name(updateData, "updateData");
  watch(() => toValue$3(dataType), updateData);
  return {
    isSupported: isSupported2,
    data: data30,
    file,
    fileName,
    fileMIME,
    fileSize,
    fileLastModified,
    open: open2,
    create: create3,
    save,
    saveAs: saveAs2,
    updateData
  };
}
__name(useFileSystemAccess, "useFileSystemAccess");
function useFocus(target2, options5 = {}) {
  const { initialValue = false, focusVisible = false, preventScroll = false } = options5;
  const innerFocused = ref(false);
  const targetElement = computed(() => unrefElement(target2));
  useEventListener(targetElement, "focus", (event) => {
    var _a2, _b;
    if (!focusVisible || ((_b = (_a2 = event.target).matches) == null ? void 0 : _b.call(_a2, ":focus-visible")))
      innerFocused.value = true;
  });
  useEventListener(targetElement, "blur", () => innerFocused.value = false);
  const focused = computed({
    get: /* @__PURE__ */ __name(() => innerFocused.value, "get"),
    set(value3) {
      var _a2, _b;
      if (!value3 && innerFocused.value)
        (_a2 = targetElement.value) == null ? void 0 : _a2.blur();
      else if (value3 && !innerFocused.value)
        (_b = targetElement.value) == null ? void 0 : _b.focus({ preventScroll });
    }
  });
  watch(
    targetElement,
    () => {
      focused.value = initialValue;
    },
    { immediate: true, flush: "post" }
  );
  return { focused };
}
__name(useFocus, "useFocus");
function useFocusWithin(target2, options5 = {}) {
  const activeElement = useActiveElement(options5);
  const targetElement = computed(() => unrefElement(target2));
  const focused = computed(() => targetElement.value && activeElement.value ? targetElement.value.contains(activeElement.value) : false);
  return { focused };
}
__name(useFocusWithin, "useFocusWithin");
function useFps(options5) {
  var _a2;
  const fps = ref(0);
  if (typeof performance === "undefined")
    return fps;
  const every = (_a2 = options5 == null ? void 0 : options5.every) != null ? _a2 : 10;
  let last = performance.now();
  let ticks = 0;
  useRafFn(() => {
    ticks += 1;
    if (ticks >= every) {
      const now2 = performance.now();
      const diff2 = now2 - last;
      fps.value = Math.round(1e3 / (diff2 / ticks));
      last = now2;
      ticks = 0;
    }
  });
  return fps;
}
__name(useFps, "useFps");
const eventHandlers = [
  "fullscreenchange",
  "webkitfullscreenchange",
  "webkitendfullscreen",
  "mozfullscreenchange",
  "MSFullscreenChange"
];
function useFullscreen(target2, options5 = {}) {
  const {
    document: document2 = defaultDocument,
    autoExit = false
  } = options5;
  const targetRef = computed(() => {
    var _a2;
    return (_a2 = unrefElement(target2)) != null ? _a2 : document2 == null ? void 0 : document2.querySelector("html");
  });
  const isFullscreen = ref(false);
  const requestMethod = computed(() => {
    return [
      "requestFullscreen",
      "webkitRequestFullscreen",
      "webkitEnterFullscreen",
      "webkitEnterFullScreen",
      "webkitRequestFullScreen",
      "mozRequestFullScreen",
      "msRequestFullscreen"
    ].find((m2) => document2 && m2 in document2 || targetRef.value && m2 in targetRef.value);
  });
  const exitMethod = computed(() => {
    return [
      "exitFullscreen",
      "webkitExitFullscreen",
      "webkitExitFullScreen",
      "webkitCancelFullScreen",
      "mozCancelFullScreen",
      "msExitFullscreen"
    ].find((m2) => document2 && m2 in document2 || targetRef.value && m2 in targetRef.value);
  });
  const fullscreenEnabled = computed(() => {
    return [
      "fullScreen",
      "webkitIsFullScreen",
      "webkitDisplayingFullscreen",
      "mozFullScreen",
      "msFullscreenElement"
    ].find((m2) => document2 && m2 in document2 || targetRef.value && m2 in targetRef.value);
  });
  const fullscreenElementMethod = [
    "fullscreenElement",
    "webkitFullscreenElement",
    "mozFullScreenElement",
    "msFullscreenElement"
  ].find((m2) => document2 && m2 in document2);
  const isSupported2 = useSupported(() => targetRef.value && document2 && requestMethod.value !== void 0 && exitMethod.value !== void 0 && fullscreenEnabled.value !== void 0);
  const isCurrentElementFullScreen = /* @__PURE__ */ __name(() => {
    if (fullscreenElementMethod)
      return (document2 == null ? void 0 : document2[fullscreenElementMethod]) === targetRef.value;
    return false;
  }, "isCurrentElementFullScreen");
  const isElementFullScreen = /* @__PURE__ */ __name(() => {
    if (fullscreenEnabled.value) {
      if (document2 && document2[fullscreenEnabled.value] != null) {
        return document2[fullscreenEnabled.value];
      } else {
        const target22 = targetRef.value;
        if ((target22 == null ? void 0 : target22[fullscreenEnabled.value]) != null) {
          return Boolean(target22[fullscreenEnabled.value]);
        }
      }
    }
    return false;
  }, "isElementFullScreen");
  async function exit() {
    if (!isSupported2.value || !isFullscreen.value)
      return;
    if (exitMethod.value) {
      if ((document2 == null ? void 0 : document2[exitMethod.value]) != null) {
        await document2[exitMethod.value]();
      } else {
        const target22 = targetRef.value;
        if ((target22 == null ? void 0 : target22[exitMethod.value]) != null)
          await target22[exitMethod.value]();
      }
    }
    isFullscreen.value = false;
  }
  __name(exit, "exit");
  async function enter2() {
    if (!isSupported2.value || isFullscreen.value)
      return;
    if (isElementFullScreen())
      await exit();
    const target22 = targetRef.value;
    if (requestMethod.value && (target22 == null ? void 0 : target22[requestMethod.value]) != null) {
      await target22[requestMethod.value]();
      isFullscreen.value = true;
    }
  }
  __name(enter2, "enter");
  async function toggle5() {
    await (isFullscreen.value ? exit() : enter2());
  }
  __name(toggle5, "toggle");
  const handlerCallback = /* @__PURE__ */ __name(() => {
    const isElementFullScreenValue = isElementFullScreen();
    if (!isElementFullScreenValue || isElementFullScreenValue && isCurrentElementFullScreen())
      isFullscreen.value = isElementFullScreenValue;
  }, "handlerCallback");
  useEventListener(document2, eventHandlers, handlerCallback, false);
  useEventListener(() => unrefElement(targetRef), eventHandlers, handlerCallback, false);
  if (autoExit)
    tryOnScopeDispose(exit);
  return {
    isSupported: isSupported2,
    isFullscreen,
    enter: enter2,
    exit,
    toggle: toggle5
  };
}
__name(useFullscreen, "useFullscreen");
function mapGamepadToXbox360Controller(gamepad) {
  return computed(() => {
    if (gamepad.value) {
      return {
        buttons: {
          a: gamepad.value.buttons[0],
          b: gamepad.value.buttons[1],
          x: gamepad.value.buttons[2],
          y: gamepad.value.buttons[3]
        },
        bumper: {
          left: gamepad.value.buttons[4],
          right: gamepad.value.buttons[5]
        },
        triggers: {
          left: gamepad.value.buttons[6],
          right: gamepad.value.buttons[7]
        },
        stick: {
          left: {
            horizontal: gamepad.value.axes[0],
            vertical: gamepad.value.axes[1],
            button: gamepad.value.buttons[10]
          },
          right: {
            horizontal: gamepad.value.axes[2],
            vertical: gamepad.value.axes[3],
            button: gamepad.value.buttons[11]
          }
        },
        dpad: {
          up: gamepad.value.buttons[12],
          down: gamepad.value.buttons[13],
          left: gamepad.value.buttons[14],
          right: gamepad.value.buttons[15]
        },
        back: gamepad.value.buttons[8],
        start: gamepad.value.buttons[9]
      };
    }
    return null;
  });
}
__name(mapGamepadToXbox360Controller, "mapGamepadToXbox360Controller");
function useGamepad(options5 = {}) {
  const {
    navigator: navigator2 = defaultNavigator
  } = options5;
  const isSupported2 = useSupported(() => navigator2 && "getGamepads" in navigator2);
  const gamepads = ref([]);
  const onConnectedHook = createEventHook();
  const onDisconnectedHook = createEventHook();
  const stateFromGamepad = /* @__PURE__ */ __name((gamepad) => {
    const hapticActuators = [];
    const vibrationActuator = "vibrationActuator" in gamepad ? gamepad.vibrationActuator : null;
    if (vibrationActuator)
      hapticActuators.push(vibrationActuator);
    if (gamepad.hapticActuators)
      hapticActuators.push(...gamepad.hapticActuators);
    return {
      id: gamepad.id,
      index: gamepad.index,
      connected: gamepad.connected,
      mapping: gamepad.mapping,
      timestamp: gamepad.timestamp,
      vibrationActuator: gamepad.vibrationActuator,
      hapticActuators,
      axes: gamepad.axes.map((axes) => axes),
      buttons: gamepad.buttons.map((button) => ({ pressed: button.pressed, touched: button.touched, value: button.value }))
    };
  }, "stateFromGamepad");
  const updateGamepadState = /* @__PURE__ */ __name(() => {
    const _gamepads = (navigator2 == null ? void 0 : navigator2.getGamepads()) || [];
    for (const gamepad of _gamepads) {
      if (gamepad && gamepads.value[gamepad.index])
        gamepads.value[gamepad.index] = stateFromGamepad(gamepad);
    }
  }, "updateGamepadState");
  const { isActive: isActive2, pause, resume } = useRafFn(updateGamepadState);
  const onGamepadConnected = /* @__PURE__ */ __name((gamepad) => {
    if (!gamepads.value.some(({ index: index2 }) => index2 === gamepad.index)) {
      gamepads.value.push(stateFromGamepad(gamepad));
      onConnectedHook.trigger(gamepad.index);
    }
    resume();
  }, "onGamepadConnected");
  const onGamepadDisconnected = /* @__PURE__ */ __name((gamepad) => {
    gamepads.value = gamepads.value.filter((x2) => x2.index !== gamepad.index);
    onDisconnectedHook.trigger(gamepad.index);
  }, "onGamepadDisconnected");
  useEventListener("gamepadconnected", (e2) => onGamepadConnected(e2.gamepad));
  useEventListener("gamepaddisconnected", (e2) => onGamepadDisconnected(e2.gamepad));
  tryOnMounted$2(() => {
    const _gamepads = (navigator2 == null ? void 0 : navigator2.getGamepads()) || [];
    for (const gamepad of _gamepads) {
      if (gamepad && gamepads.value[gamepad.index])
        onGamepadConnected(gamepad);
    }
  });
  pause();
  return {
    isSupported: isSupported2,
    onConnected: onConnectedHook.on,
    onDisconnected: onDisconnectedHook.on,
    gamepads,
    pause,
    resume,
    isActive: isActive2
  };
}
__name(useGamepad, "useGamepad");
function useGeolocation(options5 = {}) {
  const {
    enableHighAccuracy = true,
    maximumAge = 3e4,
    timeout = 27e3,
    navigator: navigator2 = defaultNavigator,
    immediate = true
  } = options5;
  const isSupported2 = useSupported(() => navigator2 && "geolocation" in navigator2);
  const locatedAt = ref(null);
  const error2 = shallowRef(null);
  const coords = ref({
    accuracy: 0,
    latitude: Number.POSITIVE_INFINITY,
    longitude: Number.POSITIVE_INFINITY,
    altitude: null,
    altitudeAccuracy: null,
    heading: null,
    speed: null
  });
  function updatePosition(position3) {
    locatedAt.value = position3.timestamp;
    coords.value = position3.coords;
    error2.value = null;
  }
  __name(updatePosition, "updatePosition");
  let watcher;
  function resume() {
    if (isSupported2.value) {
      watcher = navigator2.geolocation.watchPosition(
        updatePosition,
        (err) => error2.value = err,
        {
          enableHighAccuracy,
          maximumAge,
          timeout
        }
      );
    }
  }
  __name(resume, "resume");
  if (immediate)
    resume();
  function pause() {
    if (watcher && navigator2)
      navigator2.geolocation.clearWatch(watcher);
  }
  __name(pause, "pause");
  tryOnScopeDispose(() => {
    pause();
  });
  return {
    isSupported: isSupported2,
    coords,
    locatedAt,
    error: error2,
    resume,
    pause
  };
}
__name(useGeolocation, "useGeolocation");
const defaultEvents$1 = ["mousemove", "mousedown", "resize", "keydown", "touchstart", "wheel"];
const oneMinute = 6e4;
function useIdle(timeout = oneMinute, options5 = {}) {
  const {
    initialState = false,
    listenForVisibilityChange = true,
    events: events2 = defaultEvents$1,
    window: window2 = defaultWindow,
    eventFilter = throttleFilter(50)
  } = options5;
  const idle = ref(initialState);
  const lastActive = ref(timestamp());
  let timer;
  const reset2 = /* @__PURE__ */ __name(() => {
    idle.value = false;
    clearTimeout(timer);
    timer = setTimeout(() => idle.value = true, timeout);
  }, "reset");
  const onEvent = createFilterWrapper(
    eventFilter,
    () => {
      lastActive.value = timestamp();
      reset2();
    }
  );
  if (window2) {
    const document2 = window2.document;
    for (const event of events2)
      useEventListener(window2, event, onEvent, { passive: true });
    if (listenForVisibilityChange) {
      useEventListener(document2, "visibilitychange", () => {
        if (!document2.hidden)
          onEvent();
      });
    }
    reset2();
  }
  return {
    idle,
    lastActive,
    reset: reset2
  };
}
__name(useIdle, "useIdle");
async function loadImage(options5) {
  return new Promise((resolve2, reject3) => {
    const img = new Image();
    const { src, srcset, sizes, class: clazz, loading: loading2, crossorigin, referrerPolicy } = options5;
    img.src = src;
    if (srcset)
      img.srcset = srcset;
    if (sizes)
      img.sizes = sizes;
    if (clazz)
      img.className = clazz;
    if (loading2)
      img.loading = loading2;
    if (crossorigin)
      img.crossOrigin = crossorigin;
    if (referrerPolicy)
      img.referrerPolicy = referrerPolicy;
    img.onload = () => resolve2(img);
    img.onerror = reject3;
  });
}
__name(loadImage, "loadImage");
function useImage(options5, asyncStateOptions = {}) {
  const state = useAsyncState(
    () => loadImage(toValue$3(options5)),
    void 0,
    {
      resetOnExecute: true,
      ...asyncStateOptions
    }
  );
  watch(
    () => toValue$3(options5),
    () => state.execute(asyncStateOptions.delay),
    { deep: true }
  );
  return state;
}
__name(useImage, "useImage");
const ARRIVED_STATE_THRESHOLD_PIXELS = 1;
function useScroll(element, options5 = {}) {
  const {
    throttle: throttle2 = 0,
    idle = 200,
    onStop = noop$1,
    onScroll: onScroll5 = noop$1,
    offset = {
      left: 0,
      right: 0,
      top: 0,
      bottom: 0
    },
    eventListenerOptions = {
      capture: false,
      passive: true
    },
    behavior = "auto",
    window: window2 = defaultWindow,
    onError = /* @__PURE__ */ __name((e2) => {
      console.error(e2);
    }, "onError")
  } = options5;
  const internalX = ref(0);
  const internalY = ref(0);
  const x2 = computed({
    get() {
      return internalX.value;
    },
    set(x22) {
      scrollTo22(x22, void 0);
    }
  });
  const y2 = computed({
    get() {
      return internalY.value;
    },
    set(y22) {
      scrollTo22(void 0, y22);
    }
  });
  function scrollTo22(_x, _y) {
    var _a2, _b, _c, _d;
    if (!window2)
      return;
    const _element = toValue$3(element);
    if (!_element)
      return;
    (_c = _element instanceof Document ? window2.document.body : _element) == null ? void 0 : _c.scrollTo({
      top: (_a2 = toValue$3(_y)) != null ? _a2 : y2.value,
      left: (_b = toValue$3(_x)) != null ? _b : x2.value,
      behavior: toValue$3(behavior)
    });
    const scrollContainer = ((_d = _element == null ? void 0 : _element.document) == null ? void 0 : _d.documentElement) || (_element == null ? void 0 : _element.documentElement) || _element;
    if (x2 != null)
      internalX.value = scrollContainer.scrollLeft;
    if (y2 != null)
      internalY.value = scrollContainer.scrollTop;
  }
  __name(scrollTo22, "scrollTo2");
  const isScrolling = ref(false);
  const arrivedState = reactive({
    left: true,
    right: false,
    top: true,
    bottom: false
  });
  const directions = reactive({
    left: false,
    right: false,
    top: false,
    bottom: false
  });
  const onScrollEnd = /* @__PURE__ */ __name((e2) => {
    if (!isScrolling.value)
      return;
    isScrolling.value = false;
    directions.left = false;
    directions.right = false;
    directions.top = false;
    directions.bottom = false;
    onStop(e2);
  }, "onScrollEnd");
  const onScrollEndDebounced = useDebounceFn(onScrollEnd, throttle2 + idle);
  const setArrivedState = /* @__PURE__ */ __name((target2) => {
    var _a2;
    if (!window2)
      return;
    const el = ((_a2 = target2 == null ? void 0 : target2.document) == null ? void 0 : _a2.documentElement) || (target2 == null ? void 0 : target2.documentElement) || unrefElement(target2);
    const { display, flexDirection } = getComputedStyle(el);
    const scrollLeft = el.scrollLeft;
    directions.left = scrollLeft < internalX.value;
    directions.right = scrollLeft > internalX.value;
    const left = Math.abs(scrollLeft) <= (offset.left || 0);
    const right = Math.abs(scrollLeft) + el.clientWidth >= el.scrollWidth - (offset.right || 0) - ARRIVED_STATE_THRESHOLD_PIXELS;
    if (display === "flex" && flexDirection === "row-reverse") {
      arrivedState.left = right;
      arrivedState.right = left;
    } else {
      arrivedState.left = left;
      arrivedState.right = right;
    }
    internalX.value = scrollLeft;
    let scrollTop2 = el.scrollTop;
    if (target2 === window2.document && !scrollTop2)
      scrollTop2 = window2.document.body.scrollTop;
    directions.top = scrollTop2 < internalY.value;
    directions.bottom = scrollTop2 > internalY.value;
    const top = Math.abs(scrollTop2) <= (offset.top || 0);
    const bottom = Math.abs(scrollTop2) + el.clientHeight >= el.scrollHeight - (offset.bottom || 0) - ARRIVED_STATE_THRESHOLD_PIXELS;
    if (display === "flex" && flexDirection === "column-reverse") {
      arrivedState.top = bottom;
      arrivedState.bottom = top;
    } else {
      arrivedState.top = top;
      arrivedState.bottom = bottom;
    }
    internalY.value = scrollTop2;
  }, "setArrivedState");
  const onScrollHandler = /* @__PURE__ */ __name((e2) => {
    var _a2;
    if (!window2)
      return;
    const eventTarget = (_a2 = e2.target.documentElement) != null ? _a2 : e2.target;
    setArrivedState(eventTarget);
    isScrolling.value = true;
    onScrollEndDebounced(e2);
    onScroll5(e2);
  }, "onScrollHandler");
  useEventListener(
    element,
    "scroll",
    throttle2 ? useThrottleFn(onScrollHandler, throttle2, true, false) : onScrollHandler,
    eventListenerOptions
  );
  tryOnMounted$2(() => {
    try {
      const _element = toValue$3(element);
      if (!_element)
        return;
      setArrivedState(_element);
    } catch (e2) {
      onError(e2);
    }
  });
  useEventListener(
    element,
    "scrollend",
    onScrollEnd,
    eventListenerOptions
  );
  return {
    x: x2,
    y: y2,
    isScrolling,
    arrivedState,
    directions,
    measure() {
      const _element = toValue$3(element);
      if (window2 && _element)
        setArrivedState(_element);
    }
  };
}
__name(useScroll, "useScroll");
function resolveElement(el) {
  if (typeof Window !== "undefined" && el instanceof Window)
    return el.document.documentElement;
  if (typeof Document !== "undefined" && el instanceof Document)
    return el.documentElement;
  return el;
}
__name(resolveElement, "resolveElement");
function useInfiniteScroll(element, onLoadMore, options5 = {}) {
  var _a2;
  const {
    direction = "bottom",
    interval = 100,
    canLoadMore = /* @__PURE__ */ __name(() => true, "canLoadMore")
  } = options5;
  const state = reactive(useScroll(
    element,
    {
      ...options5,
      offset: {
        [direction]: (_a2 = options5.distance) != null ? _a2 : 0,
        ...options5.offset
      }
    }
  ));
  const promise = ref();
  const isLoading = computed(() => !!promise.value);
  const observedElement = computed(() => {
    return resolveElement(toValue$3(element));
  });
  const isElementVisible = useElementVisibility(observedElement);
  function checkAndLoad() {
    state.measure();
    if (!observedElement.value || !isElementVisible.value || !canLoadMore(observedElement.value))
      return;
    const { scrollHeight: scrollHeight2, clientHeight, scrollWidth: scrollWidth2, clientWidth } = observedElement.value;
    const isNarrower = direction === "bottom" || direction === "top" ? scrollHeight2 <= clientHeight : scrollWidth2 <= clientWidth;
    if (state.arrivedState[direction] || isNarrower) {
      if (!promise.value) {
        promise.value = Promise.all([
          onLoadMore(state),
          new Promise((resolve2) => setTimeout(resolve2, interval))
        ]).finally(() => {
          promise.value = null;
          nextTick(() => checkAndLoad());
        });
      }
    }
  }
  __name(checkAndLoad, "checkAndLoad");
  watch(
    () => [state.arrivedState[direction], isElementVisible.value],
    checkAndLoad,
    { immediate: true }
  );
  return {
    isLoading,
    reset() {
      nextTick(() => checkAndLoad());
    }
  };
}
__name(useInfiniteScroll, "useInfiniteScroll");
const defaultEvents = ["mousedown", "mouseup", "keydown", "keyup"];
function useKeyModifier(modifier, options5 = {}) {
  const {
    events: events2 = defaultEvents,
    document: document2 = defaultDocument,
    initial = null
  } = options5;
  const state = ref(initial);
  if (document2) {
    events2.forEach((listenerEvent) => {
      useEventListener(document2, listenerEvent, (evt) => {
        if (typeof evt.getModifierState === "function")
          state.value = evt.getModifierState(modifier);
      });
    });
  }
  return state;
}
__name(useKeyModifier, "useKeyModifier");
function useLocalStorage(key, initialValue, options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  return useStorage(key, initialValue, window2 == null ? void 0 : window2.localStorage, options5);
}
__name(useLocalStorage, "useLocalStorage");
const DefaultMagicKeysAliasMap = {
  ctrl: "control",
  command: "meta",
  cmd: "meta",
  option: "alt",
  up: "arrowup",
  down: "arrowdown",
  left: "arrowleft",
  right: "arrowright"
};
function useMagicKeys(options5 = {}) {
  const {
    reactive: useReactive = false,
    target: target2 = defaultWindow,
    aliasMap = DefaultMagicKeysAliasMap,
    passive = true,
    onEventFired = noop$1
  } = options5;
  const current = reactive(/* @__PURE__ */ new Set());
  const obj = {
    toJSON() {
      return {};
    },
    current
  };
  const refs = useReactive ? reactive(obj) : obj;
  const metaDeps = /* @__PURE__ */ new Set();
  const usedKeys = /* @__PURE__ */ new Set();
  function setRefs(key, value3) {
    if (key in refs) {
      if (useReactive)
        refs[key] = value3;
      else
        refs[key].value = value3;
    }
  }
  __name(setRefs, "setRefs");
  function reset2() {
    current.clear();
    for (const key of usedKeys)
      setRefs(key, false);
  }
  __name(reset2, "reset");
  function updateRefs(e2, value3) {
    var _a2, _b;
    const key = (_a2 = e2.key) == null ? void 0 : _a2.toLowerCase();
    const code2 = (_b = e2.code) == null ? void 0 : _b.toLowerCase();
    const values = [code2, key].filter(Boolean);
    if (key) {
      if (value3)
        current.add(key);
      else
        current.delete(key);
    }
    for (const key2 of values) {
      usedKeys.add(key2);
      setRefs(key2, value3);
    }
    if (key === "meta" && !value3) {
      metaDeps.forEach((key2) => {
        current.delete(key2);
        setRefs(key2, false);
      });
      metaDeps.clear();
    } else if (typeof e2.getModifierState === "function" && e2.getModifierState("Meta") && value3) {
      [...current, ...values].forEach((key2) => metaDeps.add(key2));
    }
  }
  __name(updateRefs, "updateRefs");
  useEventListener(target2, "keydown", (e2) => {
    updateRefs(e2, true);
    return onEventFired(e2);
  }, { passive });
  useEventListener(target2, "keyup", (e2) => {
    updateRefs(e2, false);
    return onEventFired(e2);
  }, { passive });
  useEventListener("blur", reset2, { passive: true });
  useEventListener("focus", reset2, { passive: true });
  const proxy = new Proxy(
    refs,
    {
      get(target22, prop2, rec) {
        if (typeof prop2 !== "string")
          return Reflect.get(target22, prop2, rec);
        prop2 = prop2.toLowerCase();
        if (prop2 in aliasMap)
          prop2 = aliasMap[prop2];
        if (!(prop2 in refs)) {
          if (/[+_-]/.test(prop2)) {
            const keys2 = prop2.split(/[+_-]/g).map((i2) => i2.trim());
            refs[prop2] = computed(() => keys2.every((key) => toValue$3(proxy[key])));
          } else {
            refs[prop2] = ref(false);
          }
        }
        const r2 = Reflect.get(target22, prop2, rec);
        return useReactive ? toValue$3(r2) : r2;
      }
    }
  );
  return proxy;
}
__name(useMagicKeys, "useMagicKeys");
function usingElRef(source, cb) {
  if (toValue$3(source))
    cb(toValue$3(source));
}
__name(usingElRef, "usingElRef");
function timeRangeToArray(timeRanges) {
  let ranges = [];
  for (let i2 = 0; i2 < timeRanges.length; ++i2)
    ranges = [...ranges, [timeRanges.start(i2), timeRanges.end(i2)]];
  return ranges;
}
__name(timeRangeToArray, "timeRangeToArray");
function tracksToArray(tracks) {
  return Array.from(tracks).map(({ label: label8, kind, language, mode: mode2, activeCues, cues, inBandMetadataTrackDispatchType }, id4) => ({ id: id4, label: label8, kind, language, mode: mode2, activeCues, cues, inBandMetadataTrackDispatchType }));
}
__name(tracksToArray, "tracksToArray");
const defaultOptions$1 = {
  src: "",
  tracks: []
};
function useMediaControls(target2, options5 = {}) {
  target2 = toRef(target2);
  options5 = {
    ...defaultOptions$1,
    ...options5
  };
  const {
    document: document2 = defaultDocument
  } = options5;
  const currentTime = ref(0);
  const duration = ref(0);
  const seeking = ref(false);
  const volume = ref(1);
  const waiting = ref(false);
  const ended = ref(false);
  const playing = ref(false);
  const rate = ref(1);
  const stalled = ref(false);
  const buffered = ref([]);
  const tracks = ref([]);
  const selectedTrack = ref(-1);
  const isPictureInPicture = ref(false);
  const muted = ref(false);
  const supportsPictureInPicture = document2 && "pictureInPictureEnabled" in document2;
  const sourceErrorEvent = createEventHook();
  const disableTrack = /* @__PURE__ */ __name((track2) => {
    usingElRef(target2, (el) => {
      if (track2) {
        const id4 = typeof track2 === "number" ? track2 : track2.id;
        el.textTracks[id4].mode = "disabled";
      } else {
        for (let i2 = 0; i2 < el.textTracks.length; ++i2)
          el.textTracks[i2].mode = "disabled";
      }
      selectedTrack.value = -1;
    });
  }, "disableTrack");
  const enableTrack = /* @__PURE__ */ __name((track2, disableTracks = true) => {
    usingElRef(target2, (el) => {
      const id4 = typeof track2 === "number" ? track2 : track2.id;
      if (disableTracks)
        disableTrack();
      el.textTracks[id4].mode = "showing";
      selectedTrack.value = id4;
    });
  }, "enableTrack");
  const togglePictureInPicture = /* @__PURE__ */ __name(() => {
    return new Promise((resolve2, reject3) => {
      usingElRef(target2, async (el) => {
        if (supportsPictureInPicture) {
          if (!isPictureInPicture.value) {
            el.requestPictureInPicture().then(resolve2).catch(reject3);
          } else {
            document2.exitPictureInPicture().then(resolve2).catch(reject3);
          }
        }
      });
    });
  }, "togglePictureInPicture");
  watchEffect(() => {
    if (!document2)
      return;
    const el = toValue$3(target2);
    if (!el)
      return;
    const src = toValue$3(options5.src);
    let sources = [];
    if (!src)
      return;
    if (typeof src === "string")
      sources = [{ src }];
    else if (Array.isArray(src))
      sources = src;
    else if (isObject$d(src))
      sources = [src];
    el.querySelectorAll("source").forEach((e2) => {
      e2.removeEventListener("error", sourceErrorEvent.trigger);
      e2.remove();
    });
    sources.forEach(({ src: src2, type }) => {
      const source = document2.createElement("source");
      source.setAttribute("src", src2);
      source.setAttribute("type", type || "");
      source.addEventListener("error", sourceErrorEvent.trigger);
      el.appendChild(source);
    });
    el.load();
  });
  tryOnScopeDispose(() => {
    const el = toValue$3(target2);
    if (!el)
      return;
    el.querySelectorAll("source").forEach((e2) => e2.removeEventListener("error", sourceErrorEvent.trigger));
  });
  watch([target2, volume], () => {
    const el = toValue$3(target2);
    if (!el)
      return;
    el.volume = volume.value;
  });
  watch([target2, muted], () => {
    const el = toValue$3(target2);
    if (!el)
      return;
    el.muted = muted.value;
  });
  watch([target2, rate], () => {
    const el = toValue$3(target2);
    if (!el)
      return;
    el.playbackRate = rate.value;
  });
  watchEffect(() => {
    if (!document2)
      return;
    const textTracks = toValue$3(options5.tracks);
    const el = toValue$3(target2);
    if (!textTracks || !textTracks.length || !el)
      return;
    el.querySelectorAll("track").forEach((e2) => e2.remove());
    textTracks.forEach(({ default: isDefault, kind, label: label8, src, srcLang }, i2) => {
      const track2 = document2.createElement("track");
      track2.default = isDefault || false;
      track2.kind = kind;
      track2.label = label8;
      track2.src = src;
      track2.srclang = srcLang;
      if (track2.default)
        selectedTrack.value = i2;
      el.appendChild(track2);
    });
  });
  const { ignoreUpdates: ignoreCurrentTimeUpdates } = watchIgnorable(currentTime, (time) => {
    const el = toValue$3(target2);
    if (!el)
      return;
    el.currentTime = time;
  });
  const { ignoreUpdates: ignorePlayingUpdates } = watchIgnorable(playing, (isPlaying) => {
    const el = toValue$3(target2);
    if (!el)
      return;
    if (isPlaying)
      el.play();
    else
      el.pause();
  });
  useEventListener(target2, "timeupdate", () => ignoreCurrentTimeUpdates(() => currentTime.value = toValue$3(target2).currentTime));
  useEventListener(target2, "durationchange", () => duration.value = toValue$3(target2).duration);
  useEventListener(target2, "progress", () => buffered.value = timeRangeToArray(toValue$3(target2).buffered));
  useEventListener(target2, "seeking", () => seeking.value = true);
  useEventListener(target2, "seeked", () => seeking.value = false);
  useEventListener(target2, ["waiting", "loadstart"], () => {
    waiting.value = true;
    ignorePlayingUpdates(() => playing.value = false);
  });
  useEventListener(target2, "loadeddata", () => waiting.value = false);
  useEventListener(target2, "playing", () => {
    waiting.value = false;
    ended.value = false;
    ignorePlayingUpdates(() => playing.value = true);
  });
  useEventListener(target2, "ratechange", () => rate.value = toValue$3(target2).playbackRate);
  useEventListener(target2, "stalled", () => stalled.value = true);
  useEventListener(target2, "ended", () => ended.value = true);
  useEventListener(target2, "pause", () => ignorePlayingUpdates(() => playing.value = false));
  useEventListener(target2, "play", () => ignorePlayingUpdates(() => playing.value = true));
  useEventListener(target2, "enterpictureinpicture", () => isPictureInPicture.value = true);
  useEventListener(target2, "leavepictureinpicture", () => isPictureInPicture.value = false);
  useEventListener(target2, "volumechange", () => {
    const el = toValue$3(target2);
    if (!el)
      return;
    volume.value = el.volume;
    muted.value = el.muted;
  });
  const listeners = [];
  const stop2 = watch([target2], () => {
    const el = toValue$3(target2);
    if (!el)
      return;
    stop2();
    listeners[0] = useEventListener(el.textTracks, "addtrack", () => tracks.value = tracksToArray(el.textTracks));
    listeners[1] = useEventListener(el.textTracks, "removetrack", () => tracks.value = tracksToArray(el.textTracks));
    listeners[2] = useEventListener(el.textTracks, "change", () => tracks.value = tracksToArray(el.textTracks));
  });
  tryOnScopeDispose(() => listeners.forEach((listener) => listener()));
  return {
    currentTime,
    duration,
    waiting,
    seeking,
    ended,
    stalled,
    buffered,
    playing,
    rate,
    // Volume
    volume,
    muted,
    // Tracks
    tracks,
    selectedTrack,
    enableTrack,
    disableTrack,
    // Picture in Picture
    supportsPictureInPicture,
    togglePictureInPicture,
    isPictureInPicture,
    // Events
    onSourceError: sourceErrorEvent.on
  };
}
__name(useMediaControls, "useMediaControls");
function getMapVue2Compat() {
  const data30 = shallowReactive({});
  return {
    get: /* @__PURE__ */ __name((key) => data30[key], "get"),
    set: /* @__PURE__ */ __name((key, value3) => set(data30, key, value3), "set"),
    has: /* @__PURE__ */ __name((key) => hasOwn$2(data30, key), "has"),
    delete: /* @__PURE__ */ __name((key) => del$1(data30, key), "delete"),
    clear: /* @__PURE__ */ __name(() => {
      Object.keys(data30).forEach((key) => {
        del$1(data30, key);
      });
    }, "clear")
  };
}
__name(getMapVue2Compat, "getMapVue2Compat");
function useMemoize(resolver, options5) {
  const initCache = /* @__PURE__ */ __name(() => {
    if (options5 == null ? void 0 : options5.cache)
      return shallowReactive(options5.cache);
    if (isVue2)
      return getMapVue2Compat();
    return shallowReactive(/* @__PURE__ */ new Map());
  }, "initCache");
  const cache2 = initCache();
  const generateKey = /* @__PURE__ */ __name((...args) => (options5 == null ? void 0 : options5.getKey) ? options5.getKey(...args) : JSON.stringify(args), "generateKey");
  const _loadData = /* @__PURE__ */ __name((key, ...args) => {
    cache2.set(key, resolver(...args));
    return cache2.get(key);
  }, "_loadData");
  const loadData = /* @__PURE__ */ __name((...args) => _loadData(generateKey(...args), ...args), "loadData");
  const deleteData = /* @__PURE__ */ __name((...args) => {
    cache2.delete(generateKey(...args));
  }, "deleteData");
  const clearData = /* @__PURE__ */ __name(() => {
    cache2.clear();
  }, "clearData");
  const memoized = /* @__PURE__ */ __name((...args) => {
    const key = generateKey(...args);
    if (cache2.has(key))
      return cache2.get(key);
    return _loadData(key, ...args);
  }, "memoized");
  memoized.load = loadData;
  memoized.delete = deleteData;
  memoized.clear = clearData;
  memoized.generateKey = generateKey;
  memoized.cache = cache2;
  return memoized;
}
__name(useMemoize, "useMemoize");
function useMemory(options5 = {}) {
  const memory = ref();
  const isSupported2 = useSupported(() => typeof performance !== "undefined" && "memory" in performance);
  if (isSupported2.value) {
    const { interval = 1e3 } = options5;
    useIntervalFn(() => {
      memory.value = performance.memory;
    }, interval, { immediate: options5.immediate, immediateCallback: options5.immediateCallback });
  }
  return { isSupported: isSupported2, memory };
}
__name(useMemory, "useMemory");
const UseMouseBuiltinExtractors = {
  page: /* @__PURE__ */ __name((event) => [event.pageX, event.pageY], "page"),
  client: /* @__PURE__ */ __name((event) => [event.clientX, event.clientY], "client"),
  screen: /* @__PURE__ */ __name((event) => [event.screenX, event.screenY], "screen"),
  movement: /* @__PURE__ */ __name((event) => event instanceof Touch ? null : [event.movementX, event.movementY], "movement")
};
function useMouse(options5 = {}) {
  const {
    type = "page",
    touch = true,
    resetOnTouchEnds = false,
    initialValue = { x: 0, y: 0 },
    window: window2 = defaultWindow,
    target: target2 = window2,
    scroll = true,
    eventFilter
  } = options5;
  let _prevMouseEvent = null;
  const x2 = ref(initialValue.x);
  const y2 = ref(initialValue.y);
  const sourceType = ref(null);
  const extractor = typeof type === "function" ? type : UseMouseBuiltinExtractors[type];
  const mouseHandler = /* @__PURE__ */ __name((event) => {
    const result = extractor(event);
    _prevMouseEvent = event;
    if (result) {
      [x2.value, y2.value] = result;
      sourceType.value = "mouse";
    }
  }, "mouseHandler");
  const touchHandler = /* @__PURE__ */ __name((event) => {
    if (event.touches.length > 0) {
      const result = extractor(event.touches[0]);
      if (result) {
        [x2.value, y2.value] = result;
        sourceType.value = "touch";
      }
    }
  }, "touchHandler");
  const scrollHandler = /* @__PURE__ */ __name(() => {
    if (!_prevMouseEvent || !window2)
      return;
    const pos = extractor(_prevMouseEvent);
    if (_prevMouseEvent instanceof MouseEvent && pos) {
      x2.value = pos[0] + window2.scrollX;
      y2.value = pos[1] + window2.scrollY;
    }
  }, "scrollHandler");
  const reset2 = /* @__PURE__ */ __name(() => {
    x2.value = initialValue.x;
    y2.value = initialValue.y;
  }, "reset");
  const mouseHandlerWrapper = eventFilter ? (event) => eventFilter(() => mouseHandler(event), {}) : (event) => mouseHandler(event);
  const touchHandlerWrapper = eventFilter ? (event) => eventFilter(() => touchHandler(event), {}) : (event) => touchHandler(event);
  const scrollHandlerWrapper = eventFilter ? () => eventFilter(() => scrollHandler(), {}) : () => scrollHandler();
  if (target2) {
    const listenerOptions = { passive: true };
    useEventListener(target2, ["mousemove", "dragover"], mouseHandlerWrapper, listenerOptions);
    if (touch && type !== "movement") {
      useEventListener(target2, ["touchstart", "touchmove"], touchHandlerWrapper, listenerOptions);
      if (resetOnTouchEnds)
        useEventListener(target2, "touchend", reset2, listenerOptions);
    }
    if (scroll && type === "page")
      useEventListener(window2, "scroll", scrollHandlerWrapper, { passive: true });
  }
  return {
    x: x2,
    y: y2,
    sourceType
  };
}
__name(useMouse, "useMouse");
function useMouseInElement(target2, options5 = {}) {
  const {
    handleOutside = true,
    window: window2 = defaultWindow
  } = options5;
  const type = options5.type || "page";
  const { x: x2, y: y2, sourceType } = useMouse(options5);
  const targetRef = ref(target2 != null ? target2 : window2 == null ? void 0 : window2.document.body);
  const elementX = ref(0);
  const elementY = ref(0);
  const elementPositionX = ref(0);
  const elementPositionY = ref(0);
  const elementHeight = ref(0);
  const elementWidth = ref(0);
  const isOutside = ref(true);
  let stop2 = /* @__PURE__ */ __name(() => {
  }, "stop");
  if (window2) {
    stop2 = watch(
      [targetRef, x2, y2],
      () => {
        const el = unrefElement(targetRef);
        if (!el || !(el instanceof HTMLElement))
          return;
        const {
          left,
          top,
          width: width2,
          height
        } = el.getBoundingClientRect();
        elementPositionX.value = left + (type === "page" ? window2.pageXOffset : 0);
        elementPositionY.value = top + (type === "page" ? window2.pageYOffset : 0);
        elementHeight.value = height;
        elementWidth.value = width2;
        const elX = x2.value - elementPositionX.value;
        const elY = y2.value - elementPositionY.value;
        isOutside.value = width2 === 0 || height === 0 || elX < 0 || elY < 0 || elX > width2 || elY > height;
        if (handleOutside || !isOutside.value) {
          elementX.value = elX;
          elementY.value = elY;
        }
      },
      { immediate: true }
    );
    useEventListener(document, "mouseleave", () => {
      isOutside.value = true;
    });
  }
  return {
    x: x2,
    y: y2,
    sourceType,
    elementX,
    elementY,
    elementPositionX,
    elementPositionY,
    elementHeight,
    elementWidth,
    isOutside,
    stop: stop2
  };
}
__name(useMouseInElement, "useMouseInElement");
function useMousePressed(options5 = {}) {
  const {
    touch = true,
    drag = true,
    capture = false,
    initialValue = false,
    window: window2 = defaultWindow
  } = options5;
  const pressed = ref(initialValue);
  const sourceType = ref(null);
  if (!window2) {
    return {
      pressed,
      sourceType
    };
  }
  const onPressed = /* @__PURE__ */ __name((srcType) => () => {
    pressed.value = true;
    sourceType.value = srcType;
  }, "onPressed");
  const onReleased = /* @__PURE__ */ __name(() => {
    pressed.value = false;
    sourceType.value = null;
  }, "onReleased");
  const target2 = computed(() => unrefElement(options5.target) || window2);
  useEventListener(target2, "mousedown", onPressed("mouse"), { passive: true, capture });
  useEventListener(window2, "mouseleave", onReleased, { passive: true, capture });
  useEventListener(window2, "mouseup", onReleased, { passive: true, capture });
  if (drag) {
    useEventListener(target2, "dragstart", onPressed("mouse"), { passive: true, capture });
    useEventListener(window2, "drop", onReleased, { passive: true, capture });
    useEventListener(window2, "dragend", onReleased, { passive: true, capture });
  }
  if (touch) {
    useEventListener(target2, "touchstart", onPressed("touch"), { passive: true, capture });
    useEventListener(window2, "touchend", onReleased, { passive: true, capture });
    useEventListener(window2, "touchcancel", onReleased, { passive: true, capture });
  }
  return {
    pressed,
    sourceType
  };
}
__name(useMousePressed, "useMousePressed");
function useNavigatorLanguage(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const navigator2 = window2 == null ? void 0 : window2.navigator;
  const isSupported2 = useSupported(() => navigator2 && "language" in navigator2);
  const language = ref(navigator2 == null ? void 0 : navigator2.language);
  useEventListener(window2, "languagechange", () => {
    if (navigator2)
      language.value = navigator2.language;
  });
  return {
    isSupported: isSupported2,
    language
  };
}
__name(useNavigatorLanguage, "useNavigatorLanguage");
function useNetwork(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const navigator2 = window2 == null ? void 0 : window2.navigator;
  const isSupported2 = useSupported(() => navigator2 && "connection" in navigator2);
  const isOnline = ref(true);
  const saveData = ref(false);
  const offlineAt = ref(void 0);
  const onlineAt = ref(void 0);
  const downlink = ref(void 0);
  const downlinkMax = ref(void 0);
  const rtt = ref(void 0);
  const effectiveType = ref(void 0);
  const type = ref("unknown");
  const connection = isSupported2.value && navigator2.connection;
  function updateNetworkInformation() {
    if (!navigator2)
      return;
    isOnline.value = navigator2.onLine;
    offlineAt.value = isOnline.value ? void 0 : Date.now();
    onlineAt.value = isOnline.value ? Date.now() : void 0;
    if (connection) {
      downlink.value = connection.downlink;
      downlinkMax.value = connection.downlinkMax;
      effectiveType.value = connection.effectiveType;
      rtt.value = connection.rtt;
      saveData.value = connection.saveData;
      type.value = connection.type;
    }
  }
  __name(updateNetworkInformation, "updateNetworkInformation");
  if (window2) {
    useEventListener(window2, "offline", () => {
      isOnline.value = false;
      offlineAt.value = Date.now();
    });
    useEventListener(window2, "online", () => {
      isOnline.value = true;
      onlineAt.value = Date.now();
    });
  }
  if (connection)
    useEventListener(connection, "change", updateNetworkInformation, false);
  updateNetworkInformation();
  return {
    isSupported: isSupported2,
    isOnline,
    saveData,
    offlineAt,
    onlineAt,
    downlink,
    downlinkMax,
    effectiveType,
    rtt,
    type
  };
}
__name(useNetwork, "useNetwork");
function useNow(options5 = {}) {
  const {
    controls: exposeControls = false,
    interval = "requestAnimationFrame"
  } = options5;
  const now2 = ref(/* @__PURE__ */ new Date());
  const update = /* @__PURE__ */ __name(() => now2.value = /* @__PURE__ */ new Date(), "update");
  const controls = interval === "requestAnimationFrame" ? useRafFn(update, { immediate: true }) : useIntervalFn(update, interval, { immediate: true });
  if (exposeControls) {
    return {
      now: now2,
      ...controls
    };
  } else {
    return now2;
  }
}
__name(useNow, "useNow");
function useObjectUrl(object) {
  const url = ref();
  const release = /* @__PURE__ */ __name(() => {
    if (url.value)
      URL.revokeObjectURL(url.value);
    url.value = void 0;
  }, "release");
  watch(
    () => toValue$3(object),
    (newObject) => {
      release();
      if (newObject)
        url.value = URL.createObjectURL(newObject);
    },
    { immediate: true }
  );
  tryOnScopeDispose(release);
  return readonly(url);
}
__name(useObjectUrl, "useObjectUrl");
function useClamp(value3, min, max) {
  if (typeof value3 === "function" || isReadonly(value3))
    return computed(() => clamp$1(toValue$3(value3), toValue$3(min), toValue$3(max)));
  const _value = ref(value3);
  return computed({
    get() {
      return _value.value = clamp$1(_value.value, toValue$3(min), toValue$3(max));
    },
    set(value22) {
      _value.value = clamp$1(value22, toValue$3(min), toValue$3(max));
    }
  });
}
__name(useClamp, "useClamp");
function useOffsetPagination(options5) {
  const {
    total = Number.POSITIVE_INFINITY,
    pageSize = 10,
    page = 1,
    onPageChange = noop$1,
    onPageSizeChange = noop$1,
    onPageCountChange = noop$1
  } = options5;
  const currentPageSize = useClamp(pageSize, 1, Number.POSITIVE_INFINITY);
  const pageCount = computed(() => Math.max(
    1,
    Math.ceil(toValue$3(total) / toValue$3(currentPageSize))
  ));
  const currentPage = useClamp(page, 1, pageCount);
  const isFirstPage = computed(() => currentPage.value === 1);
  const isLastPage = computed(() => currentPage.value === pageCount.value);
  if (isRef(page)) {
    syncRef(page, currentPage, {
      direction: isReadonly(page) ? "ltr" : "both"
    });
  }
  if (isRef(pageSize)) {
    syncRef(pageSize, currentPageSize, {
      direction: isReadonly(pageSize) ? "ltr" : "both"
    });
  }
  function prev2() {
    currentPage.value--;
  }
  __name(prev2, "prev");
  function next2() {
    currentPage.value++;
  }
  __name(next2, "next");
  const returnValue = {
    currentPage,
    currentPageSize,
    pageCount,
    isFirstPage,
    isLastPage,
    prev: prev2,
    next: next2
  };
  watch(currentPage, () => {
    onPageChange(reactive(returnValue));
  });
  watch(currentPageSize, () => {
    onPageSizeChange(reactive(returnValue));
  });
  watch(pageCount, () => {
    onPageCountChange(reactive(returnValue));
  });
  return returnValue;
}
__name(useOffsetPagination, "useOffsetPagination");
function useOnline(options5 = {}) {
  const { isOnline } = useNetwork(options5);
  return isOnline;
}
__name(useOnline, "useOnline");
function usePageLeave(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  const isLeft = ref(false);
  const handler14 = /* @__PURE__ */ __name((event) => {
    if (!window2)
      return;
    event = event || window2.event;
    const from2 = event.relatedTarget || event.toElement;
    isLeft.value = !from2;
  }, "handler");
  if (window2) {
    useEventListener(window2, "mouseout", handler14, { passive: true });
    useEventListener(window2.document, "mouseleave", handler14, { passive: true });
    useEventListener(window2.document, "mouseenter", handler14, { passive: true });
  }
  return isLeft;
}
__name(usePageLeave, "usePageLeave");
function useScreenOrientation(options5 = {}) {
  const {
    window: window2 = defaultWindow
  } = options5;
  const isSupported2 = useSupported(() => window2 && "screen" in window2 && "orientation" in window2.screen);
  const screenOrientation = isSupported2.value ? window2.screen.orientation : {};
  const orientation2 = ref(screenOrientation.type);
  const angle = ref(screenOrientation.angle || 0);
  if (isSupported2.value) {
    useEventListener(window2, "orientationchange", () => {
      orientation2.value = screenOrientation.type;
      angle.value = screenOrientation.angle;
    });
  }
  const lockOrientation = /* @__PURE__ */ __name((type) => {
    if (isSupported2.value && typeof screenOrientation.lock === "function")
      return screenOrientation.lock(type);
    return Promise.reject(new Error("Not supported"));
  }, "lockOrientation");
  const unlockOrientation = /* @__PURE__ */ __name(() => {
    if (isSupported2.value && typeof screenOrientation.unlock === "function")
      screenOrientation.unlock();
  }, "unlockOrientation");
  return {
    isSupported: isSupported2,
    orientation: orientation2,
    angle,
    lockOrientation,
    unlockOrientation
  };
}
__name(useScreenOrientation, "useScreenOrientation");
function useParallax(target2, options5 = {}) {
  const {
    deviceOrientationTiltAdjust = /* @__PURE__ */ __name((i2) => i2, "deviceOrientationTiltAdjust"),
    deviceOrientationRollAdjust = /* @__PURE__ */ __name((i2) => i2, "deviceOrientationRollAdjust"),
    mouseTiltAdjust = /* @__PURE__ */ __name((i2) => i2, "mouseTiltAdjust"),
    mouseRollAdjust = /* @__PURE__ */ __name((i2) => i2, "mouseRollAdjust"),
    window: window2 = defaultWindow
  } = options5;
  const orientation2 = reactive(useDeviceOrientation({ window: window2 }));
  const screenOrientation = reactive(useScreenOrientation({ window: window2 }));
  const {
    elementX: x2,
    elementY: y2,
    elementWidth: width2,
    elementHeight: height
  } = useMouseInElement(target2, { handleOutside: false, window: window2 });
  const source = computed(() => {
    if (orientation2.isSupported && (orientation2.alpha != null && orientation2.alpha !== 0 || orientation2.gamma != null && orientation2.gamma !== 0)) {
      return "deviceOrientation";
    }
    return "mouse";
  });
  const roll = computed(() => {
    if (source.value === "deviceOrientation") {
      let value3;
      switch (screenOrientation.orientation) {
        case "landscape-primary":
          value3 = orientation2.gamma / 90;
          break;
        case "landscape-secondary":
          value3 = -orientation2.gamma / 90;
          break;
        case "portrait-primary":
          value3 = -orientation2.beta / 90;
          break;
        case "portrait-secondary":
          value3 = orientation2.beta / 90;
          break;
        default:
          value3 = -orientation2.beta / 90;
      }
      return deviceOrientationRollAdjust(value3);
    } else {
      const value3 = -(y2.value - height.value / 2) / height.value;
      return mouseRollAdjust(value3);
    }
  });
  const tilt = computed(() => {
    if (source.value === "deviceOrientation") {
      let value3;
      switch (screenOrientation.orientation) {
        case "landscape-primary":
          value3 = orientation2.beta / 90;
          break;
        case "landscape-secondary":
          value3 = -orientation2.beta / 90;
          break;
        case "portrait-primary":
          value3 = orientation2.gamma / 90;
          break;
        case "portrait-secondary":
          value3 = -orientation2.gamma / 90;
          break;
        default:
          value3 = orientation2.gamma / 90;
      }
      return deviceOrientationTiltAdjust(value3);
    } else {
      const value3 = (x2.value - width2.value / 2) / width2.value;
      return mouseTiltAdjust(value3);
    }
  });
  return { roll, tilt, source };
}
__name(useParallax, "useParallax");
function useParentElement(element = useCurrentElement()) {
  const parentElement = shallowRef();
  const update = /* @__PURE__ */ __name(() => {
    const el = unrefElement(element);
    if (el)
      parentElement.value = el.parentElement;
  }, "update");
  tryOnMounted$2(update);
  watch(() => toValue$3(element), update);
  return parentElement;
}
__name(useParentElement, "useParentElement");
function usePerformanceObserver(options5, callback) {
  const {
    window: window2 = defaultWindow,
    immediate = true,
    ...performanceOptions
  } = options5;
  const isSupported2 = useSupported(() => window2 && "PerformanceObserver" in window2);
  let observer;
  const stop2 = /* @__PURE__ */ __name(() => {
    observer == null ? void 0 : observer.disconnect();
  }, "stop");
  const start2 = /* @__PURE__ */ __name(() => {
    if (isSupported2.value) {
      stop2();
      observer = new PerformanceObserver(callback);
      observer.observe(performanceOptions);
    }
  }, "start");
  tryOnScopeDispose(stop2);
  if (immediate)
    start2();
  return {
    isSupported: isSupported2,
    start: start2,
    stop: stop2
  };
}
__name(usePerformanceObserver, "usePerformanceObserver");
const defaultState = {
  x: 0,
  y: 0,
  pointerId: 0,
  pressure: 0,
  tiltX: 0,
  tiltY: 0,
  width: 0,
  height: 0,
  twist: 0,
  pointerType: null
};
const keys$6 = /* @__PURE__ */ Object.keys(defaultState);
function usePointer(options5 = {}) {
  const {
    target: target2 = defaultWindow
  } = options5;
  const isInside = ref(false);
  const state = ref(options5.initialValue || {});
  Object.assign(state.value, defaultState, state.value);
  const handler14 = /* @__PURE__ */ __name((event) => {
    isInside.value = true;
    if (options5.pointerTypes && !options5.pointerTypes.includes(event.pointerType))
      return;
    state.value = objectPick(event, keys$6, false);
  }, "handler");
  if (target2) {
    const listenerOptions = { passive: true };
    useEventListener(target2, ["pointerdown", "pointermove", "pointerup"], handler14, listenerOptions);
    useEventListener(target2, "pointerleave", () => isInside.value = false, listenerOptions);
  }
  return {
    ...toRefs(state),
    isInside
  };
}
__name(usePointer, "usePointer");
function usePointerLock(target2, options5 = {}) {
  const { document: document2 = defaultDocument } = options5;
  const isSupported2 = useSupported(() => document2 && "pointerLockElement" in document2);
  const element = ref();
  const triggerElement = ref();
  let targetElement;
  if (isSupported2.value) {
    useEventListener(document2, "pointerlockchange", () => {
      var _a2;
      const currentElement = (_a2 = document2.pointerLockElement) != null ? _a2 : element.value;
      if (targetElement && currentElement === targetElement) {
        element.value = document2.pointerLockElement;
        if (!element.value)
          targetElement = triggerElement.value = null;
      }
    });
    useEventListener(document2, "pointerlockerror", () => {
      var _a2;
      const currentElement = (_a2 = document2.pointerLockElement) != null ? _a2 : element.value;
      if (targetElement && currentElement === targetElement) {
        const action = document2.pointerLockElement ? "release" : "acquire";
        throw new Error(`Failed to ${action} pointer lock.`);
      }
    });
  }
  async function lock(e2) {
    var _a2;
    if (!isSupported2.value)
      throw new Error("Pointer Lock API is not supported by your browser.");
    triggerElement.value = e2 instanceof Event ? e2.currentTarget : null;
    targetElement = e2 instanceof Event ? (_a2 = unrefElement(target2)) != null ? _a2 : triggerElement.value : unrefElement(e2);
    if (!targetElement)
      throw new Error("Target element undefined.");
    targetElement.requestPointerLock();
    return await until(element).toBe(targetElement);
  }
  __name(lock, "lock");
  async function unlock() {
    if (!element.value)
      return false;
    document2.exitPointerLock();
    await until(element).toBeNull();
    return true;
  }
  __name(unlock, "unlock");
  return {
    isSupported: isSupported2,
    element,
    triggerElement,
    lock,
    unlock
  };
}
__name(usePointerLock, "usePointerLock");
function usePointerSwipe(target2, options5 = {}) {
  const targetRef = toRef(target2);
  const {
    threshold = 50,
    onSwipe,
    onSwipeEnd,
    onSwipeStart,
    disableTextSelect = false
  } = options5;
  const posStart = reactive({ x: 0, y: 0 });
  const updatePosStart = /* @__PURE__ */ __name((x2, y2) => {
    posStart.x = x2;
    posStart.y = y2;
  }, "updatePosStart");
  const posEnd = reactive({ x: 0, y: 0 });
  const updatePosEnd = /* @__PURE__ */ __name((x2, y2) => {
    posEnd.x = x2;
    posEnd.y = y2;
  }, "updatePosEnd");
  const distanceX = computed(() => posStart.x - posEnd.x);
  const distanceY = computed(() => posStart.y - posEnd.y);
  const { max, abs } = Math;
  const isThresholdExceeded = computed(() => max(abs(distanceX.value), abs(distanceY.value)) >= threshold);
  const isSwiping = ref(false);
  const isPointerDown = ref(false);
  const direction = computed(() => {
    if (!isThresholdExceeded.value)
      return "none";
    if (abs(distanceX.value) > abs(distanceY.value)) {
      return distanceX.value > 0 ? "left" : "right";
    } else {
      return distanceY.value > 0 ? "up" : "down";
    }
  });
  const eventIsAllowed = /* @__PURE__ */ __name((e2) => {
    var _a2, _b, _c;
    const isReleasingButton = e2.buttons === 0;
    const isPrimaryButton = e2.buttons === 1;
    return (_c = (_b = (_a2 = options5.pointerTypes) == null ? void 0 : _a2.includes(e2.pointerType)) != null ? _b : isReleasingButton || isPrimaryButton) != null ? _c : true;
  }, "eventIsAllowed");
  const stops = [
    useEventListener(target2, "pointerdown", (e2) => {
      if (!eventIsAllowed(e2))
        return;
      isPointerDown.value = true;
      const eventTarget = e2.target;
      eventTarget == null ? void 0 : eventTarget.setPointerCapture(e2.pointerId);
      const { clientX: x2, clientY: y2 } = e2;
      updatePosStart(x2, y2);
      updatePosEnd(x2, y2);
      onSwipeStart == null ? void 0 : onSwipeStart(e2);
    }),
    useEventListener(target2, "pointermove", (e2) => {
      if (!eventIsAllowed(e2))
        return;
      if (!isPointerDown.value)
        return;
      const { clientX: x2, clientY: y2 } = e2;
      updatePosEnd(x2, y2);
      if (!isSwiping.value && isThresholdExceeded.value)
        isSwiping.value = true;
      if (isSwiping.value)
        onSwipe == null ? void 0 : onSwipe(e2);
    }),
    useEventListener(target2, "pointerup", (e2) => {
      if (!eventIsAllowed(e2))
        return;
      if (isSwiping.value)
        onSwipeEnd == null ? void 0 : onSwipeEnd(e2, direction.value);
      isPointerDown.value = false;
      isSwiping.value = false;
    })
  ];
  tryOnMounted$2(() => {
    var _a2, _b, _c, _d, _e, _f, _g, _h;
    (_b = (_a2 = targetRef.value) == null ? void 0 : _a2.style) == null ? void 0 : _b.setProperty("touch-action", "none");
    if (disableTextSelect) {
      (_d = (_c = targetRef.value) == null ? void 0 : _c.style) == null ? void 0 : _d.setProperty("-webkit-user-select", "none");
      (_f = (_e = targetRef.value) == null ? void 0 : _e.style) == null ? void 0 : _f.setProperty("-ms-user-select", "none");
      (_h = (_g = targetRef.value) == null ? void 0 : _g.style) == null ? void 0 : _h.setProperty("user-select", "none");
    }
  });
  const stop2 = /* @__PURE__ */ __name(() => stops.forEach((s2) => s2()), "stop");
  return {
    isSwiping: readonly(isSwiping),
    direction: readonly(direction),
    posStart: readonly(posStart),
    posEnd: readonly(posEnd),
    distanceX,
    distanceY,
    stop: stop2
  };
}
__name(usePointerSwipe, "usePointerSwipe");
function usePreferredColorScheme(options5) {
  const isLight = useMediaQuery("(prefers-color-scheme: light)", options5);
  const isDark = useMediaQuery("(prefers-color-scheme: dark)", options5);
  return computed(() => {
    if (isDark.value)
      return "dark";
    if (isLight.value)
      return "light";
    return "no-preference";
  });
}
__name(usePreferredColorScheme, "usePreferredColorScheme");
function usePreferredContrast(options5) {
  const isMore = useMediaQuery("(prefers-contrast: more)", options5);
  const isLess = useMediaQuery("(prefers-contrast: less)", options5);
  const isCustom = useMediaQuery("(prefers-contrast: custom)", options5);
  return computed(() => {
    if (isMore.value)
      return "more";
    if (isLess.value)
      return "less";
    if (isCustom.value)
      return "custom";
    return "no-preference";
  });
}
__name(usePreferredContrast, "usePreferredContrast");
function usePreferredLanguages(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  if (!window2)
    return ref(["en"]);
  const navigator2 = window2.navigator;
  const value3 = ref(navigator2.languages);
  useEventListener(window2, "languagechange", () => {
    value3.value = navigator2.languages;
  });
  return value3;
}
__name(usePreferredLanguages, "usePreferredLanguages");
function usePreferredReducedMotion(options5) {
  const isReduced = useMediaQuery("(prefers-reduced-motion: reduce)", options5);
  return computed(() => {
    if (isReduced.value)
      return "reduce";
    return "no-preference";
  });
}
__name(usePreferredReducedMotion, "usePreferredReducedMotion");
function usePrevious(value3, initialValue) {
  const previous = shallowRef(initialValue);
  watch(
    toRef(value3),
    (_2, oldValue) => {
      previous.value = oldValue;
    },
    { flush: "sync" }
  );
  return readonly(previous);
}
__name(usePrevious, "usePrevious");
const topVarName = "--vueuse-safe-area-top";
const rightVarName = "--vueuse-safe-area-right";
const bottomVarName = "--vueuse-safe-area-bottom";
const leftVarName = "--vueuse-safe-area-left";
function useScreenSafeArea() {
  const top = ref("");
  const right = ref("");
  const bottom = ref("");
  const left = ref("");
  if (isClient$1) {
    const topCssVar = useCssVar(topVarName);
    const rightCssVar = useCssVar(rightVarName);
    const bottomCssVar = useCssVar(bottomVarName);
    const leftCssVar = useCssVar(leftVarName);
    topCssVar.value = "env(safe-area-inset-top, 0px)";
    rightCssVar.value = "env(safe-area-inset-right, 0px)";
    bottomCssVar.value = "env(safe-area-inset-bottom, 0px)";
    leftCssVar.value = "env(safe-area-inset-left, 0px)";
    update();
    useEventListener("resize", useDebounceFn(update));
  }
  function update() {
    top.value = getValue$2(topVarName);
    right.value = getValue$2(rightVarName);
    bottom.value = getValue$2(bottomVarName);
    left.value = getValue$2(leftVarName);
  }
  __name(update, "update");
  return {
    top,
    right,
    bottom,
    left,
    update
  };
}
__name(useScreenSafeArea, "useScreenSafeArea");
function getValue$2(position3) {
  return getComputedStyle(document.documentElement).getPropertyValue(position3);
}
__name(getValue$2, "getValue$2");
function useScriptTag(src, onLoaded = noop$1, options5 = {}) {
  const {
    immediate = true,
    manual = false,
    type = "text/javascript",
    async = true,
    crossOrigin,
    referrerPolicy,
    noModule,
    defer,
    document: document2 = defaultDocument,
    attrs: attrs7 = {}
  } = options5;
  const scriptTag = ref(null);
  let _promise = null;
  const loadScript = /* @__PURE__ */ __name((waitForScriptLoad) => new Promise((resolve2, reject3) => {
    const resolveWithElement = /* @__PURE__ */ __name((el2) => {
      scriptTag.value = el2;
      resolve2(el2);
      return el2;
    }, "resolveWithElement");
    if (!document2) {
      resolve2(false);
      return;
    }
    let shouldAppend = false;
    let el = document2.querySelector(`script[src="${toValue$3(src)}"]`);
    if (!el) {
      el = document2.createElement("script");
      el.type = type;
      el.async = async;
      el.src = toValue$3(src);
      if (defer)
        el.defer = defer;
      if (crossOrigin)
        el.crossOrigin = crossOrigin;
      if (noModule)
        el.noModule = noModule;
      if (referrerPolicy)
        el.referrerPolicy = referrerPolicy;
      Object.entries(attrs7).forEach(([name2, value3]) => el == null ? void 0 : el.setAttribute(name2, value3));
      shouldAppend = true;
    } else if (el.hasAttribute("data-loaded")) {
      resolveWithElement(el);
    }
    el.addEventListener("error", (event) => reject3(event));
    el.addEventListener("abort", (event) => reject3(event));
    el.addEventListener("load", () => {
      el.setAttribute("data-loaded", "true");
      onLoaded(el);
      resolveWithElement(el);
    });
    if (shouldAppend)
      el = document2.head.appendChild(el);
    if (!waitForScriptLoad)
      resolveWithElement(el);
  }), "loadScript");
  const load3 = /* @__PURE__ */ __name((waitForScriptLoad = true) => {
    if (!_promise)
      _promise = loadScript(waitForScriptLoad);
    return _promise;
  }, "load");
  const unload = /* @__PURE__ */ __name(() => {
    if (!document2)
      return;
    _promise = null;
    if (scriptTag.value)
      scriptTag.value = null;
    const el = document2.querySelector(`script[src="${toValue$3(src)}"]`);
    if (el)
      document2.head.removeChild(el);
  }, "unload");
  if (immediate && !manual)
    tryOnMounted$2(load3);
  if (!manual)
    tryOnUnmounted(unload);
  return { scriptTag, load: load3, unload };
}
__name(useScriptTag, "useScriptTag");
function checkOverflowScroll(ele) {
  const style2 = window.getComputedStyle(ele);
  if (style2.overflowX === "scroll" || style2.overflowY === "scroll" || style2.overflowX === "auto" && ele.clientWidth < ele.scrollWidth || style2.overflowY === "auto" && ele.clientHeight < ele.scrollHeight) {
    return true;
  } else {
    const parent = ele.parentNode;
    if (!parent || parent.tagName === "BODY")
      return false;
    return checkOverflowScroll(parent);
  }
}
__name(checkOverflowScroll, "checkOverflowScroll");
function preventDefault(rawEvent) {
  const e2 = rawEvent || window.event;
  const _target = e2.target;
  if (checkOverflowScroll(_target))
    return false;
  if (e2.touches.length > 1)
    return true;
  if (e2.preventDefault)
    e2.preventDefault();
  return false;
}
__name(preventDefault, "preventDefault");
const elInitialOverflow = /* @__PURE__ */ new WeakMap();
function useScrollLock(element, initialState = false) {
  const isLocked = ref(initialState);
  let stopTouchMoveListener = null;
  let initialOverflow = "";
  watch(toRef(element), (el) => {
    const target2 = resolveElement(toValue$3(el));
    if (target2) {
      const ele = target2;
      if (!elInitialOverflow.get(ele))
        elInitialOverflow.set(ele, ele.style.overflow);
      if (ele.style.overflow !== "hidden")
        initialOverflow = ele.style.overflow;
      if (ele.style.overflow === "hidden")
        return isLocked.value = true;
      if (isLocked.value)
        return ele.style.overflow = "hidden";
    }
  }, {
    immediate: true
  });
  const lock = /* @__PURE__ */ __name(() => {
    const el = resolveElement(toValue$3(element));
    if (!el || isLocked.value)
      return;
    if (isIOS$1) {
      stopTouchMoveListener = useEventListener(
        el,
        "touchmove",
        (e2) => {
          preventDefault(e2);
        },
        { passive: false }
      );
    }
    el.style.overflow = "hidden";
    isLocked.value = true;
  }, "lock");
  const unlock = /* @__PURE__ */ __name(() => {
    const el = resolveElement(toValue$3(element));
    if (!el || !isLocked.value)
      return;
    if (isIOS$1)
      stopTouchMoveListener == null ? void 0 : stopTouchMoveListener();
    el.style.overflow = initialOverflow;
    elInitialOverflow.delete(el);
    isLocked.value = false;
  }, "unlock");
  tryOnScopeDispose(unlock);
  return computed({
    get() {
      return isLocked.value;
    },
    set(v2) {
      if (v2)
        lock();
      else unlock();
    }
  });
}
__name(useScrollLock, "useScrollLock");
function useSessionStorage(key, initialValue, options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  return useStorage(key, initialValue, window2 == null ? void 0 : window2.sessionStorage, options5);
}
__name(useSessionStorage, "useSessionStorage");
function useShare(shareOptions = {}, options5 = {}) {
  const { navigator: navigator2 = defaultNavigator } = options5;
  const _navigator2 = navigator2;
  const isSupported2 = useSupported(() => _navigator2 && "canShare" in _navigator2);
  const share = /* @__PURE__ */ __name(async (overrideOptions = {}) => {
    if (isSupported2.value) {
      const data30 = {
        ...toValue$3(shareOptions),
        ...toValue$3(overrideOptions)
      };
      let granted = true;
      if (data30.files && _navigator2.canShare)
        granted = _navigator2.canShare({ files: data30.files });
      if (granted)
        return _navigator2.share(data30);
    }
  }, "share");
  return {
    isSupported: isSupported2,
    share
  };
}
__name(useShare, "useShare");
const defaultSortFn = /* @__PURE__ */ __name((source, compareFn) => source.sort(compareFn), "defaultSortFn");
const defaultCompare = /* @__PURE__ */ __name((a2, b2) => a2 - b2, "defaultCompare");
function useSorted(...args) {
  var _a2, _b, _c, _d;
  const [source] = args;
  let compareFn = defaultCompare;
  let options5 = {};
  if (args.length === 2) {
    if (typeof args[1] === "object") {
      options5 = args[1];
      compareFn = (_a2 = options5.compareFn) != null ? _a2 : defaultCompare;
    } else {
      compareFn = (_b = args[1]) != null ? _b : defaultCompare;
    }
  } else if (args.length > 2) {
    compareFn = (_c = args[1]) != null ? _c : defaultCompare;
    options5 = (_d = args[2]) != null ? _d : {};
  }
  const {
    dirty = false,
    sortFn = defaultSortFn
  } = options5;
  if (!dirty)
    return computed(() => sortFn([...toValue$3(source)], compareFn));
  watchEffect(() => {
    const result = sortFn(toValue$3(source), compareFn);
    if (isRef(source))
      source.value = result;
    else
      source.splice(0, source.length, ...result);
  });
  return source;
}
__name(useSorted, "useSorted");
function useSpeechRecognition(options5 = {}) {
  const {
    interimResults = true,
    continuous = true,
    maxAlternatives = 1,
    window: window2 = defaultWindow
  } = options5;
  const lang = toRef(options5.lang || "en-US");
  const isListening = ref(false);
  const isFinal = ref(false);
  const result = ref("");
  const error2 = shallowRef(void 0);
  const toggle5 = /* @__PURE__ */ __name((value3 = !isListening.value) => {
    isListening.value = value3;
  }, "toggle");
  const start2 = /* @__PURE__ */ __name(() => {
    isListening.value = true;
  }, "start");
  const stop2 = /* @__PURE__ */ __name(() => {
    isListening.value = false;
  }, "stop");
  const SpeechRecognition = window2 && (window2.SpeechRecognition || window2.webkitSpeechRecognition);
  const isSupported2 = useSupported(() => SpeechRecognition);
  let recognition;
  if (isSupported2.value) {
    recognition = new SpeechRecognition();
    recognition.continuous = continuous;
    recognition.interimResults = interimResults;
    recognition.lang = toValue$3(lang);
    recognition.maxAlternatives = maxAlternatives;
    recognition.onstart = () => {
      isFinal.value = false;
    };
    watch(lang, (lang2) => {
      if (recognition && !isListening.value)
        recognition.lang = lang2;
    });
    recognition.onresult = (event) => {
      const currentResult = event.results[event.resultIndex];
      const { transcript } = currentResult[0];
      isFinal.value = currentResult.isFinal;
      result.value = transcript;
      error2.value = void 0;
    };
    recognition.onerror = (event) => {
      error2.value = event;
    };
    recognition.onend = () => {
      isListening.value = false;
      recognition.lang = toValue$3(lang);
    };
    watch(isListening, () => {
      if (isListening.value)
        recognition.start();
      else
        recognition.stop();
    });
  }
  tryOnScopeDispose(() => {
    isListening.value = false;
  });
  return {
    isSupported: isSupported2,
    isListening,
    isFinal,
    recognition,
    result,
    error: error2,
    toggle: toggle5,
    start: start2,
    stop: stop2
  };
}
__name(useSpeechRecognition, "useSpeechRecognition");
function useSpeechSynthesis(text2, options5 = {}) {
  const {
    pitch = 1,
    rate = 1,
    volume = 1,
    window: window2 = defaultWindow
  } = options5;
  const synth = window2 && window2.speechSynthesis;
  const isSupported2 = useSupported(() => synth);
  const isPlaying = ref(false);
  const status = ref("init");
  const spokenText = toRef(text2 || "");
  const lang = toRef(options5.lang || "en-US");
  const error2 = shallowRef(void 0);
  const toggle5 = /* @__PURE__ */ __name((value3 = !isPlaying.value) => {
    isPlaying.value = value3;
  }, "toggle");
  const bindEventsForUtterance = /* @__PURE__ */ __name((utterance2) => {
    utterance2.lang = toValue$3(lang);
    utterance2.voice = toValue$3(options5.voice) || null;
    utterance2.pitch = toValue$3(pitch);
    utterance2.rate = toValue$3(rate);
    utterance2.volume = volume;
    utterance2.onstart = () => {
      isPlaying.value = true;
      status.value = "play";
    };
    utterance2.onpause = () => {
      isPlaying.value = false;
      status.value = "pause";
    };
    utterance2.onresume = () => {
      isPlaying.value = true;
      status.value = "play";
    };
    utterance2.onend = () => {
      isPlaying.value = false;
      status.value = "end";
    };
    utterance2.onerror = (event) => {
      error2.value = event;
    };
  }, "bindEventsForUtterance");
  const utterance = computed(() => {
    isPlaying.value = false;
    status.value = "init";
    const newUtterance = new SpeechSynthesisUtterance(spokenText.value);
    bindEventsForUtterance(newUtterance);
    return newUtterance;
  });
  const speak = /* @__PURE__ */ __name(() => {
    synth.cancel();
    if (utterance)
      synth.speak(utterance.value);
  }, "speak");
  const stop2 = /* @__PURE__ */ __name(() => {
    synth.cancel();
    isPlaying.value = false;
  }, "stop");
  if (isSupported2.value) {
    bindEventsForUtterance(utterance.value);
    watch(lang, (lang2) => {
      if (utterance.value && !isPlaying.value)
        utterance.value.lang = lang2;
    });
    if (options5.voice) {
      watch(options5.voice, () => {
        synth.cancel();
      });
    }
    watch(isPlaying, () => {
      if (isPlaying.value)
        synth.resume();
      else
        synth.pause();
    });
  }
  tryOnScopeDispose(() => {
    isPlaying.value = false;
  });
  return {
    isSupported: isSupported2,
    isPlaying,
    status,
    utterance,
    error: error2,
    stop: stop2,
    toggle: toggle5,
    speak
  };
}
__name(useSpeechSynthesis, "useSpeechSynthesis");
function useStepper(steps, initialStep) {
  const stepsRef = ref(steps);
  const stepNames = computed(() => Array.isArray(stepsRef.value) ? stepsRef.value : Object.keys(stepsRef.value));
  const index2 = ref(stepNames.value.indexOf(initialStep != null ? initialStep : stepNames.value[0]));
  const current = computed(() => at(index2.value));
  const isFirst = computed(() => index2.value === 0);
  const isLast = computed(() => index2.value === stepNames.value.length - 1);
  const next2 = computed(() => stepNames.value[index2.value + 1]);
  const previous = computed(() => stepNames.value[index2.value - 1]);
  function at(index22) {
    if (Array.isArray(stepsRef.value))
      return stepsRef.value[index22];
    return stepsRef.value[stepNames.value[index22]];
  }
  __name(at, "at");
  function get3(step2) {
    if (!stepNames.value.includes(step2))
      return;
    return at(stepNames.value.indexOf(step2));
  }
  __name(get3, "get");
  function goTo(step2) {
    if (stepNames.value.includes(step2))
      index2.value = stepNames.value.indexOf(step2);
  }
  __name(goTo, "goTo");
  function goToNext() {
    if (isLast.value)
      return;
    index2.value++;
  }
  __name(goToNext, "goToNext");
  function goToPrevious() {
    if (isFirst.value)
      return;
    index2.value--;
  }
  __name(goToPrevious, "goToPrevious");
  function goBackTo(step2) {
    if (isAfter(step2))
      goTo(step2);
  }
  __name(goBackTo, "goBackTo");
  function isNext(step2) {
    return stepNames.value.indexOf(step2) === index2.value + 1;
  }
  __name(isNext, "isNext");
  function isPrevious(step2) {
    return stepNames.value.indexOf(step2) === index2.value - 1;
  }
  __name(isPrevious, "isPrevious");
  function isCurrent(step2) {
    return stepNames.value.indexOf(step2) === index2.value;
  }
  __name(isCurrent, "isCurrent");
  function isBefore(step2) {
    return index2.value < stepNames.value.indexOf(step2);
  }
  __name(isBefore, "isBefore");
  function isAfter(step2) {
    return index2.value > stepNames.value.indexOf(step2);
  }
  __name(isAfter, "isAfter");
  return {
    steps: stepsRef,
    stepNames,
    index: index2,
    current,
    next: next2,
    previous,
    isFirst,
    isLast,
    at,
    get: get3,
    goTo,
    goToNext,
    goToPrevious,
    goBackTo,
    isNext,
    isPrevious,
    isCurrent,
    isBefore,
    isAfter
  };
}
__name(useStepper, "useStepper");
function useStorageAsync(key, initialValue, storage, options5 = {}) {
  var _a2;
  const {
    flush: flush2 = "pre",
    deep = true,
    listenToStorageChanges = true,
    writeDefaults = true,
    mergeDefaults: mergeDefaults2 = false,
    shallow,
    window: window2 = defaultWindow,
    eventFilter,
    onError = /* @__PURE__ */ __name((e2) => {
      console.error(e2);
    }, "onError")
  } = options5;
  const rawInit = toValue$3(initialValue);
  const type = guessSerializerType(rawInit);
  const data30 = (shallow ? shallowRef : ref)(initialValue);
  const serializer = (_a2 = options5.serializer) != null ? _a2 : StorageSerializers[type];
  if (!storage) {
    try {
      storage = getSSRHandler("getDefaultStorageAsync", () => {
        var _a22;
        return (_a22 = defaultWindow) == null ? void 0 : _a22.localStorage;
      })();
    } catch (e2) {
      onError(e2);
    }
  }
  async function read(event) {
    if (!storage || event && event.key !== key)
      return;
    try {
      const rawValue = event ? event.newValue : await storage.getItem(key);
      if (rawValue == null) {
        data30.value = rawInit;
        if (writeDefaults && rawInit !== null)
          await storage.setItem(key, await serializer.write(rawInit));
      } else if (mergeDefaults2) {
        const value3 = await serializer.read(rawValue);
        if (typeof mergeDefaults2 === "function")
          data30.value = mergeDefaults2(value3, rawInit);
        else if (type === "object" && !Array.isArray(value3))
          data30.value = { ...rawInit, ...value3 };
        else data30.value = value3;
      } else {
        data30.value = await serializer.read(rawValue);
      }
    } catch (e2) {
      onError(e2);
    }
  }
  __name(read, "read");
  read();
  if (window2 && listenToStorageChanges)
    useEventListener(window2, "storage", (e2) => Promise.resolve().then(() => read(e2)));
  if (storage) {
    watchWithFilter(
      data30,
      async () => {
        try {
          if (data30.value == null)
            await storage.removeItem(key);
          else
            await storage.setItem(key, await serializer.write(data30.value));
        } catch (e2) {
          onError(e2);
        }
      },
      {
        flush: flush2,
        deep,
        eventFilter
      }
    );
  }
  return data30;
}
__name(useStorageAsync, "useStorageAsync");
let _id$1 = 0;
function useStyleTag(css4, options5 = {}) {
  const isLoaded = ref(false);
  const {
    document: document2 = defaultDocument,
    immediate = true,
    manual = false,
    id: id4 = `vueuse_styletag_${++_id$1}`
  } = options5;
  const cssRef = ref(css4);
  let stop2 = /* @__PURE__ */ __name(() => {
  }, "stop");
  const load3 = /* @__PURE__ */ __name(() => {
    if (!document2)
      return;
    const el = document2.getElementById(id4) || document2.createElement("style");
    if (!el.isConnected) {
      el.id = id4;
      if (options5.media)
        el.media = options5.media;
      document2.head.appendChild(el);
    }
    if (isLoaded.value)
      return;
    stop2 = watch(
      cssRef,
      (value3) => {
        el.textContent = value3;
      },
      { immediate: true }
    );
    isLoaded.value = true;
  }, "load");
  const unload = /* @__PURE__ */ __name(() => {
    if (!document2 || !isLoaded.value)
      return;
    stop2();
    document2.head.removeChild(document2.getElementById(id4));
    isLoaded.value = false;
  }, "unload");
  if (immediate && !manual)
    tryOnMounted$2(load3);
  if (!manual)
    tryOnScopeDispose(unload);
  return {
    id: id4,
    css: cssRef,
    unload,
    load: load3,
    isLoaded: readonly(isLoaded)
  };
}
__name(useStyleTag, "useStyleTag");
function useSwipe(target2, options5 = {}) {
  const {
    threshold = 50,
    onSwipe,
    onSwipeEnd,
    onSwipeStart,
    passive = true,
    window: window2 = defaultWindow
  } = options5;
  const coordsStart = reactive({ x: 0, y: 0 });
  const coordsEnd = reactive({ x: 0, y: 0 });
  const diffX = computed(() => coordsStart.x - coordsEnd.x);
  const diffY = computed(() => coordsStart.y - coordsEnd.y);
  const { max, abs } = Math;
  const isThresholdExceeded = computed(() => max(abs(diffX.value), abs(diffY.value)) >= threshold);
  const isSwiping = ref(false);
  const direction = computed(() => {
    if (!isThresholdExceeded.value)
      return "none";
    if (abs(diffX.value) > abs(diffY.value)) {
      return diffX.value > 0 ? "left" : "right";
    } else {
      return diffY.value > 0 ? "up" : "down";
    }
  });
  const getTouchEventCoords = /* @__PURE__ */ __name((e2) => [e2.touches[0].clientX, e2.touches[0].clientY], "getTouchEventCoords");
  const updateCoordsStart = /* @__PURE__ */ __name((x2, y2) => {
    coordsStart.x = x2;
    coordsStart.y = y2;
  }, "updateCoordsStart");
  const updateCoordsEnd = /* @__PURE__ */ __name((x2, y2) => {
    coordsEnd.x = x2;
    coordsEnd.y = y2;
  }, "updateCoordsEnd");
  let listenerOptions;
  const isPassiveEventSupported = checkPassiveEventSupport(window2 == null ? void 0 : window2.document);
  if (!passive)
    listenerOptions = isPassiveEventSupported ? { passive: false, capture: true } : { capture: true };
  else
    listenerOptions = isPassiveEventSupported ? { passive: true } : { capture: false };
  const onTouchEnd4 = /* @__PURE__ */ __name((e2) => {
    if (isSwiping.value)
      onSwipeEnd == null ? void 0 : onSwipeEnd(e2, direction.value);
    isSwiping.value = false;
  }, "onTouchEnd");
  const stops = [
    useEventListener(target2, "touchstart", (e2) => {
      if (e2.touches.length !== 1)
        return;
      if (listenerOptions.capture && !listenerOptions.passive)
        e2.preventDefault();
      const [x2, y2] = getTouchEventCoords(e2);
      updateCoordsStart(x2, y2);
      updateCoordsEnd(x2, y2);
      onSwipeStart == null ? void 0 : onSwipeStart(e2);
    }, listenerOptions),
    useEventListener(target2, "touchmove", (e2) => {
      if (e2.touches.length !== 1)
        return;
      const [x2, y2] = getTouchEventCoords(e2);
      updateCoordsEnd(x2, y2);
      if (!isSwiping.value && isThresholdExceeded.value)
        isSwiping.value = true;
      if (isSwiping.value)
        onSwipe == null ? void 0 : onSwipe(e2);
    }, listenerOptions),
    useEventListener(target2, ["touchend", "touchcancel"], onTouchEnd4, listenerOptions)
  ];
  const stop2 = /* @__PURE__ */ __name(() => stops.forEach((s2) => s2()), "stop");
  return {
    isPassiveEventSupported,
    isSwiping,
    direction,
    coordsStart,
    coordsEnd,
    lengthX: diffX,
    lengthY: diffY,
    stop: stop2
  };
}
__name(useSwipe, "useSwipe");
function checkPassiveEventSupport(document2) {
  if (!document2)
    return false;
  let supportsPassive = false;
  const optionsBlock = {
    get passive() {
      supportsPassive = true;
      return false;
    }
  };
  document2.addEventListener("x", noop$1, optionsBlock);
  document2.removeEventListener("x", noop$1);
  return supportsPassive;
}
__name(checkPassiveEventSupport, "checkPassiveEventSupport");
function useTemplateRefsList() {
  const refs = ref([]);
  refs.value.set = (el) => {
    if (el)
      refs.value.push(el);
  };
  onBeforeUpdate(() => {
    refs.value.length = 0;
  });
  return refs;
}
__name(useTemplateRefsList, "useTemplateRefsList");
function useTextDirection(options5 = {}) {
  const {
    document: document2 = defaultDocument,
    selector = "html",
    observe: observe2 = false,
    initialValue = "ltr"
  } = options5;
  function getValue2() {
    var _a2, _b;
    return (_b = (_a2 = document2 == null ? void 0 : document2.querySelector(selector)) == null ? void 0 : _a2.getAttribute("dir")) != null ? _b : initialValue;
  }
  __name(getValue2, "getValue2");
  const dir = ref(getValue2());
  tryOnMounted$2(() => dir.value = getValue2());
  if (observe2 && document2) {
    useMutationObserver(
      document2.querySelector(selector),
      () => dir.value = getValue2(),
      { attributes: true }
    );
  }
  return computed({
    get() {
      return dir.value;
    },
    set(v2) {
      var _a2, _b;
      dir.value = v2;
      if (!document2)
        return;
      if (dir.value)
        (_a2 = document2.querySelector(selector)) == null ? void 0 : _a2.setAttribute("dir", dir.value);
      else
        (_b = document2.querySelector(selector)) == null ? void 0 : _b.removeAttribute("dir");
    }
  });
}
__name(useTextDirection, "useTextDirection");
function getRangesFromSelection(selection) {
  var _a2;
  const rangeCount = (_a2 = selection.rangeCount) != null ? _a2 : 0;
  return Array.from({ length: rangeCount }, (_2, i2) => selection.getRangeAt(i2));
}
__name(getRangesFromSelection, "getRangesFromSelection");
function useTextSelection(options5 = {}) {
  const {
    window: window2 = defaultWindow
  } = options5;
  const selection = ref(null);
  const text2 = computed(() => {
    var _a2, _b;
    return (_b = (_a2 = selection.value) == null ? void 0 : _a2.toString()) != null ? _b : "";
  });
  const ranges = computed(() => selection.value ? getRangesFromSelection(selection.value) : []);
  const rects = computed(() => ranges.value.map((range2) => range2.getBoundingClientRect()));
  function onSelectionChange() {
    selection.value = null;
    if (window2)
      selection.value = window2.getSelection();
  }
  __name(onSelectionChange, "onSelectionChange");
  if (window2)
    useEventListener(window2.document, "selectionchange", onSelectionChange);
  return {
    text: text2,
    rects,
    ranges,
    selection
  };
}
__name(useTextSelection, "useTextSelection");
function useTextareaAutosize(options5) {
  var _a2;
  const textarea = ref(options5 == null ? void 0 : options5.element);
  const input = ref(options5 == null ? void 0 : options5.input);
  const styleProp = (_a2 = options5 == null ? void 0 : options5.styleProp) != null ? _a2 : "height";
  const textareaScrollHeight = ref(1);
  const textareaOldWidth = ref(0);
  function triggerResize() {
    var _a22;
    if (!textarea.value)
      return;
    let height = "";
    textarea.value.style[styleProp] = "1px";
    textareaScrollHeight.value = (_a22 = textarea.value) == null ? void 0 : _a22.scrollHeight;
    const _styleTarget = toValue$3(options5 == null ? void 0 : options5.styleTarget);
    if (_styleTarget)
      _styleTarget.style[styleProp] = `${textareaScrollHeight.value}px`;
    else
      height = `${textareaScrollHeight.value}px`;
    textarea.value.style[styleProp] = height;
  }
  __name(triggerResize, "triggerResize");
  watch([input, textarea], () => nextTick(triggerResize), { immediate: true });
  watch(textareaScrollHeight, () => {
    var _a22;
    return (_a22 = options5 == null ? void 0 : options5.onResize) == null ? void 0 : _a22.call(options5);
  });
  useResizeObserver(textarea, ([{ contentRect }]) => {
    if (textareaOldWidth.value === contentRect.width)
      return;
    textareaOldWidth.value = contentRect.width;
    triggerResize();
  });
  if (options5 == null ? void 0 : options5.watch)
    watch(options5.watch, triggerResize, { immediate: true, deep: true });
  return {
    textarea,
    input,
    triggerResize
  };
}
__name(useTextareaAutosize, "useTextareaAutosize");
function useThrottledRefHistory(source, options5 = {}) {
  const { throttle: throttle2 = 200, trailing = true } = options5;
  const filter4 = throttleFilter(throttle2, trailing);
  const history2 = useRefHistory(source, { ...options5, eventFilter: filter4 });
  return {
    ...history2
  };
}
__name(useThrottledRefHistory, "useThrottledRefHistory");
const DEFAULT_UNITS = [
  { max: 6e4, value: 1e3, name: "second" },
  { max: 276e4, value: 6e4, name: "minute" },
  { max: 72e6, value: 36e5, name: "hour" },
  { max: 5184e5, value: 864e5, name: "day" },
  { max: 24192e5, value: 6048e5, name: "week" },
  { max: 28512e6, value: 2592e6, name: "month" },
  { max: Number.POSITIVE_INFINITY, value: 31536e6, name: "year" }
];
const DEFAULT_MESSAGES = {
  justNow: "just now",
  past: /* @__PURE__ */ __name((n2) => n2.match(/\d/) ? `${n2} ago` : n2, "past"),
  future: /* @__PURE__ */ __name((n2) => n2.match(/\d/) ? `in ${n2}` : n2, "future"),
  month: /* @__PURE__ */ __name((n2, past) => n2 === 1 ? past ? "last month" : "next month" : `${n2} month${n2 > 1 ? "s" : ""}`, "month"),
  year: /* @__PURE__ */ __name((n2, past) => n2 === 1 ? past ? "last year" : "next year" : `${n2} year${n2 > 1 ? "s" : ""}`, "year"),
  day: /* @__PURE__ */ __name((n2, past) => n2 === 1 ? past ? "yesterday" : "tomorrow" : `${n2} day${n2 > 1 ? "s" : ""}`, "day"),
  week: /* @__PURE__ */ __name((n2, past) => n2 === 1 ? past ? "last week" : "next week" : `${n2} week${n2 > 1 ? "s" : ""}`, "week"),
  hour: /* @__PURE__ */ __name((n2) => `${n2} hour${n2 > 1 ? "s" : ""}`, "hour"),
  minute: /* @__PURE__ */ __name((n2) => `${n2} minute${n2 > 1 ? "s" : ""}`, "minute"),
  second: /* @__PURE__ */ __name((n2) => `${n2} second${n2 > 1 ? "s" : ""}`, "second"),
  invalid: ""
};
function DEFAULT_FORMATTER(date) {
  return date.toISOString().slice(0, 10);
}
__name(DEFAULT_FORMATTER, "DEFAULT_FORMATTER");
function useTimeAgo(time, options5 = {}) {
  const {
    controls: exposeControls = false,
    updateInterval = 3e4
  } = options5;
  const { now: now2, ...controls } = useNow({ interval: updateInterval, controls: true });
  const timeAgo = computed(() => formatTimeAgo(new Date(toValue$3(time)), options5, toValue$3(now2)));
  if (exposeControls) {
    return {
      timeAgo,
      ...controls
    };
  } else {
    return timeAgo;
  }
}
__name(useTimeAgo, "useTimeAgo");
function formatTimeAgo(from2, options5 = {}, now2 = Date.now()) {
  var _a2;
  const {
    max,
    messages: messages2 = DEFAULT_MESSAGES,
    fullDateFormatter = DEFAULT_FORMATTER,
    units = DEFAULT_UNITS,
    showSecond = false,
    rounding = "round"
  } = options5;
  const roundFn = typeof rounding === "number" ? (n2) => +n2.toFixed(rounding) : Math[rounding];
  const diff2 = +now2 - +from2;
  const absDiff = Math.abs(diff2);
  function getValue2(diff22, unit) {
    return roundFn(Math.abs(diff22) / unit.value);
  }
  __name(getValue2, "getValue2");
  function format2(diff22, unit) {
    const val = getValue2(diff22, unit);
    const past = diff22 > 0;
    const str = applyFormat(unit.name, val, past);
    return applyFormat(past ? "past" : "future", str, past);
  }
  __name(format2, "format");
  function applyFormat(name2, val, isPast) {
    const formatter = messages2[name2];
    if (typeof formatter === "function")
      return formatter(val, isPast);
    return formatter.replace("{0}", val.toString());
  }
  __name(applyFormat, "applyFormat");
  if (absDiff < 6e4 && !showSecond)
    return messages2.justNow;
  if (typeof max === "number" && absDiff > max)
    return fullDateFormatter(new Date(from2));
  if (typeof max === "string") {
    const unitMax = (_a2 = units.find((i2) => i2.name === max)) == null ? void 0 : _a2.max;
    if (unitMax && absDiff > unitMax)
      return fullDateFormatter(new Date(from2));
  }
  for (const [idx, unit] of units.entries()) {
    const val = getValue2(diff2, unit);
    if (val <= 0 && units[idx - 1])
      return format2(diff2, units[idx - 1]);
    if (absDiff < unit.max)
      return format2(diff2, unit);
  }
  return messages2.invalid;
}
__name(formatTimeAgo, "formatTimeAgo");
function useTimeoutPoll(fn, interval, timeoutPollOptions) {
  const { start: start2 } = useTimeoutFn(loop, interval, { immediate: false });
  const isActive2 = ref(false);
  async function loop() {
    if (!isActive2.value)
      return;
    await fn();
    start2();
  }
  __name(loop, "loop");
  function resume() {
    if (!isActive2.value) {
      isActive2.value = true;
      loop();
    }
  }
  __name(resume, "resume");
  function pause() {
    isActive2.value = false;
  }
  __name(pause, "pause");
  if (timeoutPollOptions == null ? void 0 : timeoutPollOptions.immediate)
    resume();
  tryOnScopeDispose(pause);
  return {
    isActive: isActive2,
    pause,
    resume
  };
}
__name(useTimeoutPoll, "useTimeoutPoll");
function useTimestamp(options5 = {}) {
  const {
    controls: exposeControls = false,
    offset = 0,
    immediate = true,
    interval = "requestAnimationFrame",
    callback
  } = options5;
  const ts2 = ref(timestamp() + offset);
  const update = /* @__PURE__ */ __name(() => ts2.value = timestamp() + offset, "update");
  const cb = callback ? () => {
    update();
    callback(ts2.value);
  } : update;
  const controls = interval === "requestAnimationFrame" ? useRafFn(cb, { immediate }) : useIntervalFn(cb, interval, { immediate });
  if (exposeControls) {
    return {
      timestamp: ts2,
      ...controls
    };
  } else {
    return ts2;
  }
}
__name(useTimestamp, "useTimestamp");
function useTitle(newTitle = null, options5 = {}) {
  var _a2, _b, _c;
  const {
    document: document2 = defaultDocument,
    restoreOnUnmount = /* @__PURE__ */ __name((t2) => t2, "restoreOnUnmount")
  } = options5;
  const originalTitle = (_a2 = document2 == null ? void 0 : document2.title) != null ? _a2 : "";
  const title = toRef((_b = newTitle != null ? newTitle : document2 == null ? void 0 : document2.title) != null ? _b : null);
  const isReadonly2 = newTitle && typeof newTitle === "function";
  function format2(t2) {
    if (!("titleTemplate" in options5))
      return t2;
    const template = options5.titleTemplate || "%s";
    return typeof template === "function" ? template(t2) : toValue$3(template).replace(/%s/g, t2);
  }
  __name(format2, "format");
  watch(
    title,
    (t2, o2) => {
      if (t2 !== o2 && document2)
        document2.title = format2(typeof t2 === "string" ? t2 : "");
    },
    { immediate: true }
  );
  if (options5.observe && !options5.titleTemplate && document2 && !isReadonly2) {
    useMutationObserver(
      (_c = document2.head) == null ? void 0 : _c.querySelector("title"),
      () => {
        if (document2 && document2.title !== title.value)
          title.value = format2(document2.title);
      },
      { childList: true }
    );
  }
  tryOnBeforeUnmount(() => {
    if (restoreOnUnmount) {
      const restoredTitle = restoreOnUnmount(originalTitle, title.value || "");
      if (restoredTitle != null && document2)
        document2.title = restoredTitle;
    }
  });
  return title;
}
__name(useTitle, "useTitle");
const _TransitionPresets = {
  easeInSine: [0.12, 0, 0.39, 0],
  easeOutSine: [0.61, 1, 0.88, 1],
  easeInOutSine: [0.37, 0, 0.63, 1],
  easeInQuad: [0.11, 0, 0.5, 0],
  easeOutQuad: [0.5, 1, 0.89, 1],
  easeInOutQuad: [0.45, 0, 0.55, 1],
  easeInCubic: [0.32, 0, 0.67, 0],
  easeOutCubic: [0.33, 1, 0.68, 1],
  easeInOutCubic: [0.65, 0, 0.35, 1],
  easeInQuart: [0.5, 0, 0.75, 0],
  easeOutQuart: [0.25, 1, 0.5, 1],
  easeInOutQuart: [0.76, 0, 0.24, 1],
  easeInQuint: [0.64, 0, 0.78, 0],
  easeOutQuint: [0.22, 1, 0.36, 1],
  easeInOutQuint: [0.83, 0, 0.17, 1],
  easeInExpo: [0.7, 0, 0.84, 0],
  easeOutExpo: [0.16, 1, 0.3, 1],
  easeInOutExpo: [0.87, 0, 0.13, 1],
  easeInCirc: [0.55, 0, 1, 0.45],
  easeOutCirc: [0, 0.55, 0.45, 1],
  easeInOutCirc: [0.85, 0, 0.15, 1],
  easeInBack: [0.36, 0, 0.66, -0.56],
  easeOutBack: [0.34, 1.56, 0.64, 1],
  easeInOutBack: [0.68, -0.6, 0.32, 1.6]
};
const TransitionPresets = /* @__PURE__ */ Object.assign({}, { linear: identity }, _TransitionPresets);
function createEasingFunction([p0, p1, p2, p3]) {
  const a2 = /* @__PURE__ */ __name((a1, a22) => 1 - 3 * a22 + 3 * a1, "a");
  const b2 = /* @__PURE__ */ __name((a1, a22) => 3 * a22 - 6 * a1, "b");
  const c2 = /* @__PURE__ */ __name((a1) => 3 * a1, "c");
  const calcBezier = /* @__PURE__ */ __name((t2, a1, a22) => ((a2(a1, a22) * t2 + b2(a1, a22)) * t2 + c2(a1)) * t2, "calcBezier");
  const getSlope = /* @__PURE__ */ __name((t2, a1, a22) => 3 * a2(a1, a22) * t2 * t2 + 2 * b2(a1, a22) * t2 + c2(a1), "getSlope");
  const getTforX = /* @__PURE__ */ __name((x2) => {
    let aGuessT = x2;
    for (let i2 = 0; i2 < 4; ++i2) {
      const currentSlope = getSlope(aGuessT, p0, p2);
      if (currentSlope === 0)
        return aGuessT;
      const currentX = calcBezier(aGuessT, p0, p2) - x2;
      aGuessT -= currentX / currentSlope;
    }
    return aGuessT;
  }, "getTforX");
  return (x2) => p0 === p1 && p2 === p3 ? x2 : calcBezier(getTforX(x2), p1, p3);
}
__name(createEasingFunction, "createEasingFunction");
function lerp(a2, b2, alpha2) {
  return a2 + alpha2 * (b2 - a2);
}
__name(lerp, "lerp");
function toVec(t2) {
  return (typeof t2 === "number" ? [t2] : t2) || [];
}
__name(toVec, "toVec");
function executeTransition(source, from2, to, options5 = {}) {
  var _a2, _b;
  const fromVal = toValue$3(from2);
  const toVal = toValue$3(to);
  const v1 = toVec(fromVal);
  const v2 = toVec(toVal);
  const duration = (_a2 = toValue$3(options5.duration)) != null ? _a2 : 1e3;
  const startedAt = Date.now();
  const endAt = Date.now() + duration;
  const trans = typeof options5.transition === "function" ? options5.transition : (_b = toValue$3(options5.transition)) != null ? _b : identity;
  const ease = typeof trans === "function" ? trans : createEasingFunction(trans);
  return new Promise((resolve2) => {
    source.value = fromVal;
    const tick = /* @__PURE__ */ __name(() => {
      var _a22;
      if ((_a22 = options5.abort) == null ? void 0 : _a22.call(options5)) {
        resolve2();
        return;
      }
      const now2 = Date.now();
      const alpha2 = ease((now2 - startedAt) / duration);
      const arr = toVec(source.value).map((n2, i2) => lerp(v1[i2], v2[i2], alpha2));
      if (Array.isArray(source.value))
        source.value = arr.map((n2, i2) => {
          var _a3, _b2;
          return lerp((_a3 = v1[i2]) != null ? _a3 : 0, (_b2 = v2[i2]) != null ? _b2 : 0, alpha2);
        });
      else if (typeof source.value === "number")
        source.value = arr[0];
      if (now2 < endAt) {
        requestAnimationFrame(tick);
      } else {
        source.value = toVal;
        resolve2();
      }
    }, "tick");
    tick();
  });
}
__name(executeTransition, "executeTransition");
function useTransition(source, options5 = {}) {
  let currentId = 0;
  const sourceVal = /* @__PURE__ */ __name(() => {
    const v2 = toValue$3(source);
    return typeof v2 === "number" ? v2 : v2.map(toValue$3);
  }, "sourceVal");
  const outputRef = ref(sourceVal());
  watch(sourceVal, async (to) => {
    var _a2, _b;
    if (toValue$3(options5.disabled))
      return;
    const id4 = ++currentId;
    if (options5.delay)
      await promiseTimeout(toValue$3(options5.delay));
    if (id4 !== currentId)
      return;
    const toVal = Array.isArray(to) ? to.map(toValue$3) : toValue$3(to);
    (_a2 = options5.onStarted) == null ? void 0 : _a2.call(options5);
    await executeTransition(outputRef, outputRef.value, toVal, {
      ...options5,
      abort: /* @__PURE__ */ __name(() => {
        var _a22;
        return id4 !== currentId || ((_a22 = options5.abort) == null ? void 0 : _a22.call(options5));
      }, "abort")
    });
    (_b = options5.onFinished) == null ? void 0 : _b.call(options5);
  }, { deep: true });
  watch(() => toValue$3(options5.disabled), (disabled3) => {
    if (disabled3) {
      currentId++;
      outputRef.value = sourceVal();
    }
  });
  tryOnScopeDispose(() => {
    currentId++;
  });
  return computed(() => toValue$3(options5.disabled) ? sourceVal() : outputRef.value);
}
__name(useTransition, "useTransition");
function useUrlSearchParams(mode2 = "history", options5 = {}) {
  const {
    initialValue = {},
    removeNullishValues = true,
    removeFalsyValues = false,
    write: enableWrite = true,
    window: window2 = defaultWindow
  } = options5;
  if (!window2)
    return reactive(initialValue);
  const state = reactive({});
  function getRawParams() {
    if (mode2 === "history") {
      return window2.location.search || "";
    } else if (mode2 === "hash") {
      const hash = window2.location.hash || "";
      const index2 = hash.indexOf("?");
      return index2 > 0 ? hash.slice(index2) : "";
    } else {
      return (window2.location.hash || "").replace(/^#/, "");
    }
  }
  __name(getRawParams, "getRawParams");
  function constructQuery(params) {
    const stringified = params.toString();
    if (mode2 === "history")
      return `${stringified ? `?${stringified}` : ""}${window2.location.hash || ""}`;
    if (mode2 === "hash-params")
      return `${window2.location.search || ""}${stringified ? `#${stringified}` : ""}`;
    const hash = window2.location.hash || "#";
    const index2 = hash.indexOf("?");
    if (index2 > 0)
      return `${hash.slice(0, index2)}${stringified ? `?${stringified}` : ""}`;
    return `${hash}${stringified ? `?${stringified}` : ""}`;
  }
  __name(constructQuery, "constructQuery");
  function read() {
    return new URLSearchParams(getRawParams());
  }
  __name(read, "read");
  function updateState(params) {
    const unusedKeys = new Set(Object.keys(state));
    for (const key of params.keys()) {
      const paramsForKey = params.getAll(key);
      state[key] = paramsForKey.length > 1 ? paramsForKey : params.get(key) || "";
      unusedKeys.delete(key);
    }
    Array.from(unusedKeys).forEach((key) => delete state[key]);
  }
  __name(updateState, "updateState");
  const { pause, resume } = watchPausable(
    state,
    () => {
      const params = new URLSearchParams("");
      Object.keys(state).forEach((key) => {
        const mapEntry = state[key];
        if (Array.isArray(mapEntry))
          mapEntry.forEach((value3) => params.append(key, value3));
        else if (removeNullishValues && mapEntry == null)
          params.delete(key);
        else if (removeFalsyValues && !mapEntry)
          params.delete(key);
        else
          params.set(key, mapEntry);
      });
      write(params);
    },
    { deep: true }
  );
  function write(params, shouldUpdate) {
    pause();
    if (shouldUpdate)
      updateState(params);
    window2.history.replaceState(
      window2.history.state,
      window2.document.title,
      window2.location.pathname + constructQuery(params)
    );
    resume();
  }
  __name(write, "write");
  function onChanged() {
    if (!enableWrite)
      return;
    write(read(), true);
  }
  __name(onChanged, "onChanged");
  useEventListener(window2, "popstate", onChanged, false);
  if (mode2 !== "history")
    useEventListener(window2, "hashchange", onChanged, false);
  const initial = read();
  if (initial.keys().next().value)
    updateState(initial);
  else
    Object.assign(state, initialValue);
  return state;
}
__name(useUrlSearchParams, "useUrlSearchParams");
function useUserMedia(options5 = {}) {
  var _a2, _b;
  const enabled = ref((_a2 = options5.enabled) != null ? _a2 : false);
  const autoSwitch = ref((_b = options5.autoSwitch) != null ? _b : true);
  const constraints = ref(options5.constraints);
  const { navigator: navigator2 = defaultNavigator } = options5;
  const isSupported2 = useSupported(() => {
    var _a22;
    return (_a22 = navigator2 == null ? void 0 : navigator2.mediaDevices) == null ? void 0 : _a22.getUserMedia;
  });
  const stream = shallowRef();
  function getDeviceOptions(type) {
    switch (type) {
      case "video": {
        if (constraints.value)
          return constraints.value.video || false;
        break;
      }
      case "audio": {
        if (constraints.value)
          return constraints.value.audio || false;
        break;
      }
    }
  }
  __name(getDeviceOptions, "getDeviceOptions");
  async function _start() {
    if (!isSupported2.value || stream.value)
      return;
    stream.value = await navigator2.mediaDevices.getUserMedia({
      video: getDeviceOptions("video"),
      audio: getDeviceOptions("audio")
    });
    return stream.value;
  }
  __name(_start, "_start");
  function _stop() {
    var _a22;
    (_a22 = stream.value) == null ? void 0 : _a22.getTracks().forEach((t2) => t2.stop());
    stream.value = void 0;
  }
  __name(_stop, "_stop");
  function stop2() {
    _stop();
    enabled.value = false;
  }
  __name(stop2, "stop");
  async function start2() {
    await _start();
    if (stream.value)
      enabled.value = true;
    return stream.value;
  }
  __name(start2, "start");
  async function restart() {
    _stop();
    return await start2();
  }
  __name(restart, "restart");
  watch(
    enabled,
    (v2) => {
      if (v2)
        _start();
      else _stop();
    },
    { immediate: true }
  );
  watch(
    constraints,
    () => {
      if (autoSwitch.value && stream.value)
        restart();
    },
    { immediate: true }
  );
  tryOnScopeDispose(() => {
    stop2();
  });
  return {
    isSupported: isSupported2,
    stream,
    start: start2,
    stop: stop2,
    restart,
    constraints,
    enabled,
    autoSwitch
  };
}
__name(useUserMedia, "useUserMedia");
function useVModel(props, key, emit2, options5 = {}) {
  var _a2, _b, _c, _d, _e;
  const {
    clone: clone2 = false,
    passive = false,
    eventName,
    deep = false,
    defaultValue: defaultValue2,
    shouldEmit
  } = options5;
  const vm = getCurrentInstance();
  const _emit = emit2 || (vm == null ? void 0 : vm.emit) || ((_a2 = vm == null ? void 0 : vm.$emit) == null ? void 0 : _a2.bind(vm)) || ((_c = (_b = vm == null ? void 0 : vm.proxy) == null ? void 0 : _b.$emit) == null ? void 0 : _c.bind(vm == null ? void 0 : vm.proxy));
  let event = eventName;
  if (!key) {
    if (isVue2) {
      const modelOptions = (_e = (_d = vm == null ? void 0 : vm.proxy) == null ? void 0 : _d.$options) == null ? void 0 : _e.model;
      key = (modelOptions == null ? void 0 : modelOptions.value) || "value";
      if (!eventName)
        event = (modelOptions == null ? void 0 : modelOptions.event) || "input";
    } else {
      key = "modelValue";
    }
  }
  event = event || `update:${key.toString()}`;
  const cloneFn = /* @__PURE__ */ __name((val) => !clone2 ? val : typeof clone2 === "function" ? clone2(val) : cloneFnJSON(val), "cloneFn");
  const getValue2 = /* @__PURE__ */ __name(() => isDef(props[key]) ? cloneFn(props[key]) : defaultValue2, "getValue2");
  const triggerEmit = /* @__PURE__ */ __name((value3) => {
    if (shouldEmit) {
      if (shouldEmit(value3))
        _emit(event, value3);
    } else {
      _emit(event, value3);
    }
  }, "triggerEmit");
  if (passive) {
    const initialValue = getValue2();
    const proxy = ref(initialValue);
    let isUpdating = false;
    watch(
      () => props[key],
      (v2) => {
        if (!isUpdating) {
          isUpdating = true;
          proxy.value = cloneFn(v2);
          nextTick(() => isUpdating = false);
        }
      }
    );
    watch(
      proxy,
      (v2) => {
        if (!isUpdating && (v2 !== props[key] || deep))
          triggerEmit(v2);
      },
      { deep }
    );
    return proxy;
  } else {
    return computed({
      get() {
        return getValue2();
      },
      set(value3) {
        triggerEmit(value3);
      }
    });
  }
}
__name(useVModel, "useVModel");
function useVModels(props, emit2, options5 = {}) {
  const ret = {};
  for (const key in props) {
    ret[key] = useVModel(
      props,
      key,
      emit2,
      options5
    );
  }
  return ret;
}
__name(useVModels, "useVModels");
function useVibrate(options5) {
  const {
    pattern = [],
    interval = 0,
    navigator: navigator2 = defaultNavigator
  } = options5 || {};
  const isSupported2 = useSupported(() => typeof navigator2 !== "undefined" && "vibrate" in navigator2);
  const patternRef = toRef(pattern);
  let intervalControls;
  const vibrate = /* @__PURE__ */ __name((pattern2 = patternRef.value) => {
    if (isSupported2.value)
      navigator2.vibrate(pattern2);
  }, "vibrate");
  const stop2 = /* @__PURE__ */ __name(() => {
    if (isSupported2.value)
      navigator2.vibrate(0);
    intervalControls == null ? void 0 : intervalControls.pause();
  }, "stop");
  if (interval > 0) {
    intervalControls = useIntervalFn(
      vibrate,
      interval,
      {
        immediate: false,
        immediateCallback: false
      }
    );
  }
  return {
    isSupported: isSupported2,
    pattern,
    intervalControls,
    vibrate,
    stop: stop2
  };
}
__name(useVibrate, "useVibrate");
function useVirtualList(list2, options5) {
  const { containerStyle: containerStyle2, wrapperProps, scrollTo: scrollTo22, calculateRange, currentList, containerRef: containerRef6 } = "itemHeight" in options5 ? useVerticalVirtualList(options5, list2) : useHorizontalVirtualList(options5, list2);
  return {
    list: currentList,
    scrollTo: scrollTo22,
    containerProps: {
      ref: containerRef6,
      onScroll: /* @__PURE__ */ __name(() => {
        calculateRange();
      }, "onScroll"),
      style: containerStyle2
    },
    wrapperProps
  };
}
__name(useVirtualList, "useVirtualList");
function useVirtualListResources(list2) {
  const containerRef6 = ref(null);
  const size = useElementSize(containerRef6);
  const currentList = ref([]);
  const source = shallowRef(list2);
  const state = ref({ start: 0, end: 10 });
  return { state, source, currentList, size, containerRef: containerRef6 };
}
__name(useVirtualListResources, "useVirtualListResources");
function createGetViewCapacity(state, source, itemSize2) {
  return (containerSize) => {
    if (typeof itemSize2 === "number")
      return Math.ceil(containerSize / itemSize2);
    const { start: start2 = 0 } = state.value;
    let sum = 0;
    let capacity = 0;
    for (let i2 = start2; i2 < source.value.length; i2++) {
      const size = itemSize2(i2);
      sum += size;
      capacity = i2;
      if (sum > containerSize)
        break;
    }
    return capacity - start2;
  };
}
__name(createGetViewCapacity, "createGetViewCapacity");
function createGetOffset(source, itemSize2) {
  return (scrollDirection) => {
    if (typeof itemSize2 === "number")
      return Math.floor(scrollDirection / itemSize2) + 1;
    let sum = 0;
    let offset = 0;
    for (let i2 = 0; i2 < source.value.length; i2++) {
      const size = itemSize2(i2);
      sum += size;
      if (sum >= scrollDirection) {
        offset = i2;
        break;
      }
    }
    return offset + 1;
  };
}
__name(createGetOffset, "createGetOffset");
function createCalculateRange(type, overscan, getOffset2, getViewCapacity, { containerRef: containerRef6, state, currentList, source }) {
  return () => {
    const element = containerRef6.value;
    if (element) {
      const offset = getOffset2(type === "vertical" ? element.scrollTop : element.scrollLeft);
      const viewCapacity = getViewCapacity(type === "vertical" ? element.clientHeight : element.clientWidth);
      const from2 = offset - overscan;
      const to = offset + viewCapacity + overscan;
      state.value = {
        start: from2 < 0 ? 0 : from2,
        end: to > source.value.length ? source.value.length : to
      };
      currentList.value = source.value.slice(state.value.start, state.value.end).map((ele, index2) => ({
        data: ele,
        index: index2 + state.value.start
      }));
    }
  };
}
__name(createCalculateRange, "createCalculateRange");
function createGetDistance(itemSize2, source) {
  return (index2) => {
    if (typeof itemSize2 === "number") {
      const size2 = index2 * itemSize2;
      return size2;
    }
    const size = source.value.slice(0, index2).reduce((sum, _2, i2) => sum + itemSize2(i2), 0);
    return size;
  };
}
__name(createGetDistance, "createGetDistance");
function useWatchForSizes(size, list2, containerRef6, calculateRange) {
  watch([size.width, size.height, list2, containerRef6], () => {
    calculateRange();
  });
}
__name(useWatchForSizes, "useWatchForSizes");
function createComputedTotalSize(itemSize2, source) {
  return computed(() => {
    if (typeof itemSize2 === "number")
      return source.value.length * itemSize2;
    return source.value.reduce((sum, _2, index2) => sum + itemSize2(index2), 0);
  });
}
__name(createComputedTotalSize, "createComputedTotalSize");
const scrollToDictionaryForElementScrollKey = {
  horizontal: "scrollLeft",
  vertical: "scrollTop"
};
function createScrollTo(type, calculateRange, getDistance, containerRef6) {
  return (index2) => {
    if (containerRef6.value) {
      containerRef6.value[scrollToDictionaryForElementScrollKey[type]] = getDistance(index2);
      calculateRange();
    }
  };
}
__name(createScrollTo, "createScrollTo");
function useHorizontalVirtualList(options5, list2) {
  const resources = useVirtualListResources(list2);
  const { state, source, currentList, size, containerRef: containerRef6 } = resources;
  const containerStyle2 = { overflowX: "auto" };
  const { itemWidth, overscan = 5 } = options5;
  const getViewCapacity = createGetViewCapacity(state, source, itemWidth);
  const getOffset2 = createGetOffset(source, itemWidth);
  const calculateRange = createCalculateRange("horizontal", overscan, getOffset2, getViewCapacity, resources);
  const getDistanceLeft = createGetDistance(itemWidth, source);
  const offsetLeft = computed(() => getDistanceLeft(state.value.start));
  const totalWidth = createComputedTotalSize(itemWidth, source);
  useWatchForSizes(size, list2, containerRef6, calculateRange);
  const scrollTo22 = createScrollTo("horizontal", calculateRange, getDistanceLeft, containerRef6);
  const wrapperProps = computed(() => {
    return {
      style: {
        height: "100%",
        width: `${totalWidth.value - offsetLeft.value}px`,
        marginLeft: `${offsetLeft.value}px`,
        display: "flex"
      }
    };
  });
  return {
    scrollTo: scrollTo22,
    calculateRange,
    wrapperProps,
    containerStyle: containerStyle2,
    currentList,
    containerRef: containerRef6
  };
}
__name(useHorizontalVirtualList, "useHorizontalVirtualList");
function useVerticalVirtualList(options5, list2) {
  const resources = useVirtualListResources(list2);
  const { state, source, currentList, size, containerRef: containerRef6 } = resources;
  const containerStyle2 = { overflowY: "auto" };
  const { itemHeight, overscan = 5 } = options5;
  const getViewCapacity = createGetViewCapacity(state, source, itemHeight);
  const getOffset2 = createGetOffset(source, itemHeight);
  const calculateRange = createCalculateRange("vertical", overscan, getOffset2, getViewCapacity, resources);
  const getDistanceTop = createGetDistance(itemHeight, source);
  const offsetTop = computed(() => getDistanceTop(state.value.start));
  const totalHeight = createComputedTotalSize(itemHeight, source);
  useWatchForSizes(size, list2, containerRef6, calculateRange);
  const scrollTo22 = createScrollTo("vertical", calculateRange, getDistanceTop, containerRef6);
  const wrapperProps = computed(() => {
    return {
      style: {
        width: "100%",
        height: `${totalHeight.value - offsetTop.value}px`,
        marginTop: `${offsetTop.value}px`
      }
    };
  });
  return {
    calculateRange,
    scrollTo: scrollTo22,
    containerStyle: containerStyle2,
    wrapperProps,
    currentList,
    containerRef: containerRef6
  };
}
__name(useVerticalVirtualList, "useVerticalVirtualList");
function useWakeLock(options5 = {}) {
  const {
    navigator: navigator2 = defaultNavigator,
    document: document2 = defaultDocument
  } = options5;
  const requestedType = ref(false);
  const sentinel = shallowRef(null);
  const documentVisibility = useDocumentVisibility({ document: document2 });
  const isSupported2 = useSupported(() => navigator2 && "wakeLock" in navigator2);
  const isActive2 = computed(() => !!sentinel.value && documentVisibility.value === "visible");
  if (isSupported2.value) {
    useEventListener(sentinel, "release", () => {
      var _a2, _b;
      requestedType.value = (_b = (_a2 = sentinel.value) == null ? void 0 : _a2.type) != null ? _b : false;
    });
    whenever(
      () => documentVisibility.value === "visible" && (document2 == null ? void 0 : document2.visibilityState) === "visible" && requestedType.value,
      (type) => {
        requestedType.value = false;
        forceRequest(type);
      }
    );
  }
  async function forceRequest(type) {
    var _a2;
    await ((_a2 = sentinel.value) == null ? void 0 : _a2.release());
    sentinel.value = isSupported2.value ? await navigator2.wakeLock.request(type) : null;
  }
  __name(forceRequest, "forceRequest");
  async function request(type) {
    if (documentVisibility.value === "visible")
      await forceRequest(type);
    else
      requestedType.value = type;
  }
  __name(request, "request");
  async function release() {
    requestedType.value = false;
    const s2 = sentinel.value;
    sentinel.value = null;
    await (s2 == null ? void 0 : s2.release());
  }
  __name(release, "release");
  return {
    sentinel,
    isSupported: isSupported2,
    isActive: isActive2,
    request,
    forceRequest,
    release
  };
}
__name(useWakeLock, "useWakeLock");
function useWebNotification(options5 = {}) {
  const {
    window: window2 = defaultWindow,
    requestPermissions: _requestForPermissions = true
  } = options5;
  const defaultWebNotificationOptions = options5;
  const isSupported2 = useSupported(() => {
    if (!window2 || !("Notification" in window2))
      return false;
    try {
      new Notification("");
    } catch (e2) {
      return false;
    }
    return true;
  });
  const permissionGranted = ref(isSupported2.value && "permission" in Notification && Notification.permission === "granted");
  const notification = ref(null);
  const ensurePermissions = /* @__PURE__ */ __name(async () => {
    if (!isSupported2.value)
      return;
    if (!permissionGranted.value && Notification.permission !== "denied") {
      const result = await Notification.requestPermission();
      if (result === "granted")
        permissionGranted.value = true;
    }
    return permissionGranted.value;
  }, "ensurePermissions");
  const { on: onClick5, trigger: clickTrigger } = createEventHook();
  const { on: onShow, trigger: showTrigger } = createEventHook();
  const { on: onError, trigger: errorTrigger } = createEventHook();
  const { on: onClose, trigger: closeTrigger } = createEventHook();
  const show7 = /* @__PURE__ */ __name(async (overrides) => {
    if (!isSupported2.value || !permissionGranted.value)
      return;
    const options22 = Object.assign({}, defaultWebNotificationOptions, overrides);
    notification.value = new Notification(options22.title || "", options22);
    notification.value.onclick = clickTrigger;
    notification.value.onshow = showTrigger;
    notification.value.onerror = errorTrigger;
    notification.value.onclose = closeTrigger;
    return notification.value;
  }, "show");
  const close5 = /* @__PURE__ */ __name(() => {
    if (notification.value)
      notification.value.close();
    notification.value = null;
  }, "close");
  if (_requestForPermissions)
    tryOnMounted$2(ensurePermissions);
  tryOnScopeDispose(close5);
  if (isSupported2.value && window2) {
    const document2 = window2.document;
    useEventListener(document2, "visibilitychange", (e2) => {
      e2.preventDefault();
      if (document2.visibilityState === "visible") {
        close5();
      }
    });
  }
  return {
    isSupported: isSupported2,
    notification,
    ensurePermissions,
    permissionGranted,
    show: show7,
    close: close5,
    onClick: onClick5,
    onShow,
    onError,
    onClose
  };
}
__name(useWebNotification, "useWebNotification");
const DEFAULT_PING_MESSAGE = "ping";
function resolveNestedOptions(options5) {
  if (options5 === true)
    return {};
  return options5;
}
__name(resolveNestedOptions, "resolveNestedOptions");
function useWebSocket(url, options5 = {}) {
  const {
    onConnected,
    onDisconnected,
    onError,
    onMessage,
    immediate = true,
    autoClose = true,
    protocols = []
  } = options5;
  const data30 = ref(null);
  const status = ref("CLOSED");
  const wsRef = ref();
  const urlRef = toRef(url);
  let heartbeatPause;
  let heartbeatResume;
  let explicitlyClosed = false;
  let retried = 0;
  let bufferedData = [];
  let pongTimeoutWait;
  const _sendBuffer = /* @__PURE__ */ __name(() => {
    if (bufferedData.length && wsRef.value && status.value === "OPEN") {
      for (const buffer2 of bufferedData)
        wsRef.value.send(buffer2);
      bufferedData = [];
    }
  }, "_sendBuffer");
  const resetHeartbeat = /* @__PURE__ */ __name(() => {
    clearTimeout(pongTimeoutWait);
    pongTimeoutWait = void 0;
  }, "resetHeartbeat");
  const close5 = /* @__PURE__ */ __name((code2 = 1e3, reason) => {
    if (!isClient$1 || !wsRef.value)
      return;
    explicitlyClosed = true;
    resetHeartbeat();
    heartbeatPause == null ? void 0 : heartbeatPause();
    wsRef.value.close(code2, reason);
    wsRef.value = void 0;
  }, "close");
  const send = /* @__PURE__ */ __name((data210, useBuffer = true) => {
    if (!wsRef.value || status.value !== "OPEN") {
      if (useBuffer)
        bufferedData.push(data210);
      return false;
    }
    _sendBuffer();
    wsRef.value.send(data210);
    return true;
  }, "send");
  const _init = /* @__PURE__ */ __name(() => {
    if (explicitlyClosed || typeof urlRef.value === "undefined")
      return;
    const ws = new WebSocket(urlRef.value, protocols);
    wsRef.value = ws;
    status.value = "CONNECTING";
    ws.onopen = () => {
      status.value = "OPEN";
      onConnected == null ? void 0 : onConnected(ws);
      heartbeatResume == null ? void 0 : heartbeatResume();
      _sendBuffer();
    };
    ws.onclose = (ev) => {
      status.value = "CLOSED";
      onDisconnected == null ? void 0 : onDisconnected(ws, ev);
      if (!explicitlyClosed && options5.autoReconnect) {
        const {
          retries = -1,
          delay = 1e3,
          onFailed
        } = resolveNestedOptions(options5.autoReconnect);
        retried += 1;
        if (typeof retries === "number" && (retries < 0 || retried < retries))
          setTimeout(_init, delay);
        else if (typeof retries === "function" && retries())
          setTimeout(_init, delay);
        else
          onFailed == null ? void 0 : onFailed();
      }
    };
    ws.onerror = (e2) => {
      onError == null ? void 0 : onError(ws, e2);
    };
    ws.onmessage = (e2) => {
      if (options5.heartbeat) {
        resetHeartbeat();
        const {
          message: message3 = DEFAULT_PING_MESSAGE,
          responseMessage = message3
        } = resolveNestedOptions(options5.heartbeat);
        if (e2.data === responseMessage)
          return;
      }
      data30.value = e2.data;
      onMessage == null ? void 0 : onMessage(ws, e2);
    };
  }, "_init");
  if (options5.heartbeat) {
    const {
      message: message3 = DEFAULT_PING_MESSAGE,
      interval = 1e3,
      pongTimeout = 1e3
    } = resolveNestedOptions(options5.heartbeat);
    const { pause, resume } = useIntervalFn(
      () => {
        send(message3, false);
        if (pongTimeoutWait != null)
          return;
        pongTimeoutWait = setTimeout(() => {
          close5();
          explicitlyClosed = false;
        }, pongTimeout);
      },
      interval,
      { immediate: false }
    );
    heartbeatPause = pause;
    heartbeatResume = resume;
  }
  if (autoClose) {
    if (isClient$1)
      useEventListener("beforeunload", () => close5());
    tryOnScopeDispose(close5);
  }
  const open2 = /* @__PURE__ */ __name(() => {
    if (!isClient$1 && !isWorker)
      return;
    close5();
    explicitlyClosed = false;
    retried = 0;
    _init();
  }, "open");
  if (immediate)
    open2();
  watch(urlRef, open2);
  return {
    data: data30,
    status,
    close: close5,
    send,
    open: open2,
    ws: wsRef
  };
}
__name(useWebSocket, "useWebSocket");
function useWebWorker(arg0, workerOptions, options5) {
  const {
    window: window2 = defaultWindow
  } = options5 != null ? options5 : {};
  const data30 = ref(null);
  const worker = shallowRef();
  const post = /* @__PURE__ */ __name((...args) => {
    if (!worker.value)
      return;
    worker.value.postMessage(...args);
  }, "post");
  const terminate = /* @__PURE__ */ __name(function terminate2() {
    if (!worker.value)
      return;
    worker.value.terminate();
  }, "terminate2");
  if (window2) {
    if (typeof arg0 === "string")
      worker.value = new Worker(arg0, workerOptions);
    else if (typeof arg0 === "function")
      worker.value = arg0();
    else
      worker.value = arg0;
    worker.value.onmessage = (e2) => {
      data30.value = e2.data;
    };
    tryOnScopeDispose(() => {
      if (worker.value)
        worker.value.terminate();
    });
  }
  return {
    data: data30,
    post,
    terminate,
    worker
  };
}
__name(useWebWorker, "useWebWorker");
function jobRunner(userFunc) {
  return (e2) => {
    const userFuncArgs = e2.data[0];
    return Promise.resolve(userFunc.apply(void 0, userFuncArgs)).then((result) => {
      postMessage(["SUCCESS", result]);
    }).catch((error2) => {
      postMessage(["ERROR", error2]);
    });
  };
}
__name(jobRunner, "jobRunner");
function depsParser(deps, localDeps) {
  if (deps.length === 0 && localDeps.length === 0)
    return "";
  const depsString = deps.map((dep) => `'${dep}'`).toString();
  const depsFunctionString = localDeps.filter((dep) => typeof dep === "function").map((fn) => {
    const str = fn.toString();
    if (str.trim().startsWith("function")) {
      return str;
    } else {
      const name2 = fn.name;
      return `const ${name2} = ${str}`;
    }
  }).join(";");
  const importString = `importScripts(${depsString});`;
  return `${depsString.trim() === "" ? "" : importString} ${depsFunctionString}`;
}
__name(depsParser, "depsParser");
function createWorkerBlobUrl(fn, deps, localDeps) {
  const blobCode = `${depsParser(deps, localDeps)}; onmessage=(${jobRunner})(${fn})`;
  const blob = new Blob([blobCode], { type: "text/javascript" });
  const url = URL.createObjectURL(blob);
  return url;
}
__name(createWorkerBlobUrl, "createWorkerBlobUrl");
function useWebWorkerFn(fn, options5 = {}) {
  const {
    dependencies = [],
    localDependencies = [],
    timeout,
    window: window2 = defaultWindow
  } = options5;
  const worker = ref();
  const workerStatus = ref("PENDING");
  const promise = ref({});
  const timeoutId = ref();
  const workerTerminate = /* @__PURE__ */ __name((status = "PENDING") => {
    if (worker.value && worker.value._url && window2) {
      worker.value.terminate();
      URL.revokeObjectURL(worker.value._url);
      promise.value = {};
      worker.value = void 0;
      window2.clearTimeout(timeoutId.value);
      workerStatus.value = status;
    }
  }, "workerTerminate");
  workerTerminate();
  tryOnScopeDispose(workerTerminate);
  const generateWorker = /* @__PURE__ */ __name(() => {
    const blobUrl = createWorkerBlobUrl(fn, dependencies, localDependencies);
    const newWorker = new Worker(blobUrl);
    newWorker._url = blobUrl;
    newWorker.onmessage = (e2) => {
      const { resolve: resolve2 = /* @__PURE__ */ __name(() => {
      }, "resolve"), reject: reject3 = /* @__PURE__ */ __name(() => {
      }, "reject") } = promise.value;
      const [status, result] = e2.data;
      switch (status) {
        case "SUCCESS":
          resolve2(result);
          workerTerminate(status);
          break;
        default:
          reject3(result);
          workerTerminate("ERROR");
          break;
      }
    };
    newWorker.onerror = (e2) => {
      const { reject: reject3 = /* @__PURE__ */ __name(() => {
      }, "reject") } = promise.value;
      e2.preventDefault();
      reject3(e2);
      workerTerminate("ERROR");
    };
    if (timeout) {
      timeoutId.value = setTimeout(
        () => workerTerminate("TIMEOUT_EXPIRED"),
        timeout
      );
    }
    return newWorker;
  }, "generateWorker");
  const callWorker = /* @__PURE__ */ __name((...fnArgs) => new Promise((resolve2, reject3) => {
    var _a2;
    promise.value = {
      resolve: resolve2,
      reject: reject3
    };
    (_a2 = worker.value) == null ? void 0 : _a2.postMessage([[...fnArgs]]);
    workerStatus.value = "RUNNING";
  }), "callWorker");
  const workerFn = /* @__PURE__ */ __name((...fnArgs) => {
    if (workerStatus.value === "RUNNING") {
      console.error(
        "[useWebWorkerFn] You can only run one instance of the worker at a time."
      );
      return Promise.reject();
    }
    worker.value = generateWorker();
    return callWorker(...fnArgs);
  }, "workerFn");
  return {
    workerFn,
    workerStatus,
    workerTerminate
  };
}
__name(useWebWorkerFn, "useWebWorkerFn");
function useWindowFocus(options5 = {}) {
  const { window: window2 = defaultWindow } = options5;
  if (!window2)
    return ref(false);
  const focused = ref(window2.document.hasFocus());
  useEventListener(window2, "blur", () => {
    focused.value = false;
  });
  useEventListener(window2, "focus", () => {
    focused.value = true;
  });
  return focused;
}
__name(useWindowFocus, "useWindowFocus");
function useWindowScroll(options5 = {}) {
  const { window: window2 = defaultWindow, behavior = "auto" } = options5;
  if (!window2) {
    return {
      x: ref(0),
      y: ref(0)
    };
  }
  const internalX = ref(window2.scrollX);
  const internalY = ref(window2.scrollY);
  const x2 = computed({
    get() {
      return internalX.value;
    },
    set(x22) {
      scrollTo({ left: x22, behavior });
    }
  });
  const y2 = computed({
    get() {
      return internalY.value;
    },
    set(y22) {
      scrollTo({ top: y22, behavior });
    }
  });
  useEventListener(
    window2,
    "scroll",
    () => {
      internalX.value = window2.scrollX;
      internalY.value = window2.scrollY;
    },
    {
      capture: false,
      passive: true
    }
  );
  return { x: x2, y: y2 };
}
__name(useWindowScroll, "useWindowScroll");
function useWindowSize(options5 = {}) {
  const {
    window: window2 = defaultWindow,
    initialWidth = Number.POSITIVE_INFINITY,
    initialHeight = Number.POSITIVE_INFINITY,
    listenOrientation = true,
    includeScrollbar = true,
    type = "inner"
  } = options5;
  const width2 = ref(initialWidth);
  const height = ref(initialHeight);
  const update = /* @__PURE__ */ __name(() => {
    if (window2) {
      if (type === "outer") {
        width2.value = window2.outerWidth;
        height.value = window2.outerHeight;
      } else if (includeScrollbar) {
        width2.value = window2.innerWidth;
        height.value = window2.innerHeight;
      } else {
        width2.value = window2.document.documentElement.clientWidth;
        height.value = window2.document.documentElement.clientHeight;
      }
    }
  }, "update");
  update();
  tryOnMounted$2(update);
  useEventListener("resize", update, { passive: true });
  if (listenOrientation) {
    const matches2 = useMediaQuery("(orientation: portrait)");
    watch(matches2, () => update());
  }
  return { width: width2, height };
}
__name(useWindowSize, "useWindowSize");
var BaseComponentStyle$2 = BaseStyle$1.extend({
  name: "common"
});
function _typeof$o(o2) {
  "@babel/helpers - typeof";
  return _typeof$o = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$o(o2);
}
__name(_typeof$o, "_typeof$o");
function _toArray$1(r2) {
  return _arrayWithHoles$5(r2) || _iterableToArray$e(r2) || _unsupportedIterableToArray$j(r2) || _nonIterableRest$5();
}
__name(_toArray$1, "_toArray$1");
function _iterableToArray$e(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$e, "_iterableToArray$e");
function _slicedToArray$5(r2, e2) {
  return _arrayWithHoles$5(r2) || _iterableToArrayLimit$5(r2, e2) || _unsupportedIterableToArray$j(r2, e2) || _nonIterableRest$5();
}
__name(_slicedToArray$5, "_slicedToArray$5");
function _nonIterableRest$5() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$5, "_nonIterableRest$5");
function _unsupportedIterableToArray$j(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$j(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$j(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$j, "_unsupportedIterableToArray$j");
function _arrayLikeToArray$j(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$j, "_arrayLikeToArray$j");
function _iterableToArrayLimit$5(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) {
        if (Object(t2) !== t2) return;
        f2 = false;
      } else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$5, "_iterableToArrayLimit$5");
function _arrayWithHoles$5(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$5, "_arrayWithHoles$5");
function ownKeys$o(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$o, "ownKeys$o");
function _objectSpread$o(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$o(Object(t2), true).forEach(function(r3) {
      _defineProperty$q(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$o(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$o, "_objectSpread$o");
function _defineProperty$q(e2, r2, t2) {
  return (r2 = _toPropertyKey$n(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$q, "_defineProperty$q");
function _toPropertyKey$n(t2) {
  var i2 = _toPrimitive$n(t2, "string");
  return "symbol" == _typeof$o(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$n, "_toPropertyKey$n");
function _toPrimitive$n(t2, r2) {
  if ("object" != _typeof$o(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$o(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$n, "_toPrimitive$n");
var script$1b = {
  name: "BaseComponent",
  props: {
    pt: {
      type: Object,
      "default": void 0
    },
    ptOptions: {
      type: Object,
      "default": void 0
    },
    unstyled: {
      type: Boolean,
      "default": void 0
    },
    dt: {
      type: Object,
      "default": void 0
    }
  },
  inject: {
    $parentInstance: {
      "default": void 0
    }
  },
  watch: {
    isUnstyled: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler2(newValue2) {
        if (!newValue2) {
          this._loadCoreStyles();
          this._themeChangeListener(this._loadCoreStyles);
        }
      }, "handler")
    },
    dt: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler3(newValue2) {
        var _this = this;
        if (newValue2) {
          this._loadScopedThemeStyles(newValue2);
          this._themeChangeListener(function() {
            return _this._loadScopedThemeStyles(newValue2);
          });
        } else {
          this._unloadScopedThemeStyles();
        }
      }, "handler")
    }
  },
  scopedStyleEl: void 0,
  rootEl: void 0,
  $attrSelector: void 0,
  beforeCreate: /* @__PURE__ */ __name(function beforeCreate() {
    var _this$pt, _this$pt2, _this$pt3, _ref, _ref$onBeforeCreate, _this$$primevueConfig, _this$$primevue, _this$$primevue2, _this$$primevue3, _ref2, _ref2$onBeforeCreate;
    var _usept = (_this$pt = this.pt) === null || _this$pt === void 0 ? void 0 : _this$pt["_usept"];
    var originalValue = _usept ? (_this$pt2 = this.pt) === null || _this$pt2 === void 0 || (_this$pt2 = _this$pt2.originalValue) === null || _this$pt2 === void 0 ? void 0 : _this$pt2[this.$.type.name] : void 0;
    var value3 = _usept ? (_this$pt3 = this.pt) === null || _this$pt3 === void 0 || (_this$pt3 = _this$pt3.value) === null || _this$pt3 === void 0 ? void 0 : _this$pt3[this.$.type.name] : this.pt;
    (_ref = value3 || originalValue) === null || _ref === void 0 || (_ref = _ref.hooks) === null || _ref === void 0 || (_ref$onBeforeCreate = _ref["onBeforeCreate"]) === null || _ref$onBeforeCreate === void 0 || _ref$onBeforeCreate.call(_ref);
    var _useptInConfig = (_this$$primevueConfig = this.$primevueConfig) === null || _this$$primevueConfig === void 0 || (_this$$primevueConfig = _this$$primevueConfig.pt) === null || _this$$primevueConfig === void 0 ? void 0 : _this$$primevueConfig["_usept"];
    var originalValueInConfig = _useptInConfig ? (_this$$primevue = this.$primevue) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.config) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.pt) === null || _this$$primevue === void 0 ? void 0 : _this$$primevue.originalValue : void 0;
    var valueInConfig = _useptInConfig ? (_this$$primevue2 = this.$primevue) === null || _this$$primevue2 === void 0 || (_this$$primevue2 = _this$$primevue2.config) === null || _this$$primevue2 === void 0 || (_this$$primevue2 = _this$$primevue2.pt) === null || _this$$primevue2 === void 0 ? void 0 : _this$$primevue2.value : (_this$$primevue3 = this.$primevue) === null || _this$$primevue3 === void 0 || (_this$$primevue3 = _this$$primevue3.config) === null || _this$$primevue3 === void 0 ? void 0 : _this$$primevue3.pt;
    (_ref2 = valueInConfig || originalValueInConfig) === null || _ref2 === void 0 || (_ref2 = _ref2[this.$.type.name]) === null || _ref2 === void 0 || (_ref2 = _ref2.hooks) === null || _ref2 === void 0 || (_ref2$onBeforeCreate = _ref2["onBeforeCreate"]) === null || _ref2$onBeforeCreate === void 0 || _ref2$onBeforeCreate.call(_ref2);
    this.$attrSelector = uuid$1("pc");
  }, "beforeCreate"),
  created: /* @__PURE__ */ __name(function created() {
    this._hook("onCreated");
  }, "created"),
  beforeMount: /* @__PURE__ */ __name(function beforeMount2() {
    this.rootEl = findSingle$1(this.$el, '[data-pc-name="'.concat(toFlatCase$2(this.$.type.name), '"]'));
    if (this.rootEl) {
      this.$attrSelector && !this.rootEl.hasAttribute(this.$attrSelector) && this.rootEl.setAttribute(this.$attrSelector, "");
      this.rootEl.$pc = _objectSpread$o({
        name: this.$.type.name,
        attrSelector: this.$attrSelector
      }, this.$params);
    }
    this._loadStyles();
    this._hook("onBeforeMount");
  }, "beforeMount"),
  mounted: /* @__PURE__ */ __name(function mounted() {
    this._hook("onMounted");
  }, "mounted"),
  beforeUpdate: /* @__PURE__ */ __name(function beforeUpdate() {
    this._hook("onBeforeUpdate");
  }, "beforeUpdate"),
  updated: /* @__PURE__ */ __name(function updated2() {
    this._hook("onUpdated");
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount() {
    this._hook("onBeforeUnmount");
  }, "beforeUnmount"),
  unmounted: /* @__PURE__ */ __name(function unmounted2() {
    this._unloadScopedThemeStyles();
    this._hook("onUnmounted");
  }, "unmounted"),
  methods: {
    _hook: /* @__PURE__ */ __name(function _hook2(hookName) {
      if (!this.$options.hostName) {
        var selfHook = this._usePT(this._getPT(this.pt, this.$.type.name), this._getOptionValue, "hooks.".concat(hookName));
        var defaultHook = this._useDefaultPT(this._getOptionValue, "hooks.".concat(hookName));
        selfHook === null || selfHook === void 0 || selfHook();
        defaultHook === null || defaultHook === void 0 || defaultHook();
      }
    }, "_hook"),
    _mergeProps: /* @__PURE__ */ __name(function _mergeProps2(fn) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key2 = 1; _key2 < _len; _key2++) {
        args[_key2 - 1] = arguments[_key2];
      }
      return isFunction$d(fn) ? fn.apply(void 0, args) : mergeProps$2.apply(void 0, args);
    }, "_mergeProps"),
    _loadStyles: /* @__PURE__ */ __name(function _loadStyles2() {
      var _this2 = this;
      var _load = /* @__PURE__ */ __name(function _load2() {
        if (!Base$1.isStyleNameLoaded("base")) {
          BaseStyle$1.loadCSS(_this2.$styleOptions);
          _this2._loadGlobalStyles();
          Base$1.setLoadedStyleName("base");
        }
        _this2._loadThemeStyles();
      }, "_load");
      _load();
      this._themeChangeListener(_load);
    }, "_loadStyles"),
    _loadCoreStyles: /* @__PURE__ */ __name(function _loadCoreStyles2() {
      var _this$$style, _this$$style2;
      if (!Base$1.isStyleNameLoaded((_this$$style = this.$style) === null || _this$$style === void 0 ? void 0 : _this$$style.name) && (_this$$style2 = this.$style) !== null && _this$$style2 !== void 0 && _this$$style2.name) {
        BaseComponentStyle$2.loadCSS(this.$styleOptions);
        this.$options.style && this.$style.loadCSS(this.$styleOptions);
        Base$1.setLoadedStyleName(this.$style.name);
      }
    }, "_loadCoreStyles"),
    _loadGlobalStyles: /* @__PURE__ */ __name(function _loadGlobalStyles() {
      var globalCSS = this._useGlobalPT(this._getOptionValue, "global.css", this.$params);
      isNotEmpty$2(globalCSS) && BaseStyle$1.load(globalCSS, _objectSpread$o({
        name: "global"
      }, this.$styleOptions));
    }, "_loadGlobalStyles"),
    _loadThemeStyles: /* @__PURE__ */ __name(function _loadThemeStyles2() {
      var _this$$style4, _this$$style5;
      if (this.isUnstyled || this.$theme === "none") return;
      if (!config_default$1.isStyleNameLoaded("common")) {
        var _this$$style3, _this$$style3$getComm;
        var _ref3 = ((_this$$style3 = this.$style) === null || _this$$style3 === void 0 || (_this$$style3$getComm = _this$$style3.getCommonTheme) === null || _this$$style3$getComm === void 0 ? void 0 : _this$$style3$getComm.call(_this$$style3)) || {}, primitive = _ref3.primitive, semantic = _ref3.semantic, global2 = _ref3.global, style2 = _ref3.style;
        BaseStyle$1.load(primitive === null || primitive === void 0 ? void 0 : primitive.css, _objectSpread$o({
          name: "primitive-variables"
        }, this.$styleOptions));
        BaseStyle$1.load(semantic === null || semantic === void 0 ? void 0 : semantic.css, _objectSpread$o({
          name: "semantic-variables"
        }, this.$styleOptions));
        BaseStyle$1.load(global2 === null || global2 === void 0 ? void 0 : global2.css, _objectSpread$o({
          name: "global-variables"
        }, this.$styleOptions));
        BaseStyle$1.loadTheme(_objectSpread$o({
          name: "global-style"
        }, this.$styleOptions), style2);
        config_default$1.setLoadedStyleName("common");
      }
      if (!config_default$1.isStyleNameLoaded((_this$$style4 = this.$style) === null || _this$$style4 === void 0 ? void 0 : _this$$style4.name) && (_this$$style5 = this.$style) !== null && _this$$style5 !== void 0 && _this$$style5.name) {
        var _this$$style6, _this$$style6$getComp, _this$$style7, _this$$style8;
        var _ref4 = ((_this$$style6 = this.$style) === null || _this$$style6 === void 0 || (_this$$style6$getComp = _this$$style6.getComponentTheme) === null || _this$$style6$getComp === void 0 ? void 0 : _this$$style6$getComp.call(_this$$style6)) || {}, css4 = _ref4.css, _style = _ref4.style;
        (_this$$style7 = this.$style) === null || _this$$style7 === void 0 || _this$$style7.load(css4, _objectSpread$o({
          name: "".concat(this.$style.name, "-variables")
        }, this.$styleOptions));
        (_this$$style8 = this.$style) === null || _this$$style8 === void 0 || _this$$style8.loadTheme(_objectSpread$o({
          name: "".concat(this.$style.name, "-style")
        }, this.$styleOptions), _style);
        config_default$1.setLoadedStyleName(this.$style.name);
      }
      if (!config_default$1.isStyleNameLoaded("layer-order")) {
        var _this$$style9, _this$$style9$getLaye;
        var layerOrder = (_this$$style9 = this.$style) === null || _this$$style9 === void 0 || (_this$$style9$getLaye = _this$$style9.getLayerOrderThemeCSS) === null || _this$$style9$getLaye === void 0 ? void 0 : _this$$style9$getLaye.call(_this$$style9);
        BaseStyle$1.load(layerOrder, _objectSpread$o({
          name: "layer-order",
          first: true
        }, this.$styleOptions));
        config_default$1.setLoadedStyleName("layer-order");
      }
    }, "_loadThemeStyles"),
    _loadScopedThemeStyles: /* @__PURE__ */ __name(function _loadScopedThemeStyles2(preset) {
      var _this$$style10, _this$$style10$getPre, _this$$style11;
      var _ref5 = ((_this$$style10 = this.$style) === null || _this$$style10 === void 0 || (_this$$style10$getPre = _this$$style10.getPresetTheme) === null || _this$$style10$getPre === void 0 ? void 0 : _this$$style10$getPre.call(_this$$style10, preset, "[".concat(this.$attrSelector, "]"))) || {}, css4 = _ref5.css;
      var scopedStyle = (_this$$style11 = this.$style) === null || _this$$style11 === void 0 ? void 0 : _this$$style11.load(css4, _objectSpread$o({
        name: "".concat(this.$attrSelector, "-").concat(this.$style.name)
      }, this.$styleOptions));
      this.scopedStyleEl = scopedStyle.el;
    }, "_loadScopedThemeStyles"),
    _unloadScopedThemeStyles: /* @__PURE__ */ __name(function _unloadScopedThemeStyles() {
      var _this$scopedStyleEl;
      (_this$scopedStyleEl = this.scopedStyleEl) === null || _this$scopedStyleEl === void 0 || (_this$scopedStyleEl = _this$scopedStyleEl.value) === null || _this$scopedStyleEl === void 0 || _this$scopedStyleEl.remove();
    }, "_unloadScopedThemeStyles"),
    _themeChangeListener: /* @__PURE__ */ __name(function _themeChangeListener2() {
      var callback = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : function() {
      };
      Base$1.clearLoadedStyleNames();
      service_default$1.on("theme:change", callback);
    }, "_themeChangeListener"),
    _getHostInstance: /* @__PURE__ */ __name(function _getHostInstance(instance) {
      return instance ? this.$options.hostName ? instance.$.type.name === this.$options.hostName ? instance : this._getHostInstance(instance.$parentInstance) : instance.$parentInstance : void 0;
    }, "_getHostInstance"),
    _getPropValue: /* @__PURE__ */ __name(function _getPropValue(name2) {
      var _this$_getHostInstanc;
      return this[name2] || ((_this$_getHostInstanc = this._getHostInstance(this)) === null || _this$_getHostInstanc === void 0 ? void 0 : _this$_getHostInstanc[name2]);
    }, "_getPropValue"),
    _getOptionValue: /* @__PURE__ */ __name(function _getOptionValue(options5) {
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      return getKeyValue$2(options5, key, params);
    }, "_getOptionValue"),
    _getPTValue: /* @__PURE__ */ __name(function _getPTValue2() {
      var _this$$primevueConfig2;
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      var searchInDefaultPT = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true;
      var searchOut = /./g.test(key) && !!params[key.split(".")[0]];
      var _ref6 = this._getPropValue("ptOptions") || ((_this$$primevueConfig2 = this.$primevueConfig) === null || _this$$primevueConfig2 === void 0 ? void 0 : _this$$primevueConfig2.ptOptions) || {}, _ref6$mergeSections = _ref6.mergeSections, mergeSections = _ref6$mergeSections === void 0 ? true : _ref6$mergeSections, _ref6$mergeProps = _ref6.mergeProps, useMergeProps = _ref6$mergeProps === void 0 ? false : _ref6$mergeProps;
      var global2 = searchInDefaultPT ? searchOut ? this._useGlobalPT(this._getPTClassValue, key, params) : this._useDefaultPT(this._getPTClassValue, key, params) : void 0;
      var self2 = searchOut ? void 0 : this._getPTSelf(obj, this._getPTClassValue, key, _objectSpread$o(_objectSpread$o({}, params), {}, {
        global: global2 || {}
      }));
      var datasets = this._getPTDatasets(key);
      return mergeSections || !mergeSections && self2 ? useMergeProps ? this._mergeProps(useMergeProps, global2, self2, datasets) : _objectSpread$o(_objectSpread$o(_objectSpread$o({}, global2), self2), datasets) : _objectSpread$o(_objectSpread$o({}, self2), datasets);
    }, "_getPTValue"),
    _getPTSelf: /* @__PURE__ */ __name(function _getPTSelf() {
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key3 = 1; _key3 < _len2; _key3++) {
        args[_key3 - 1] = arguments[_key3];
      }
      return mergeProps$2(
        this._usePT.apply(this, [this._getPT(obj, this.$name)].concat(args)),
        // Exp; <component :pt="{}"
        this._usePT.apply(this, [this.$_attrsPT].concat(args))
        // Exp; <component :pt:[passthrough_key]:[attribute]="{value}" or <component :pt:[passthrough_key]="() =>{value}"
      );
    }, "_getPTSelf"),
    _getPTDatasets: /* @__PURE__ */ __name(function _getPTDatasets2() {
      var _this$pt4, _this$pt5;
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var datasetPrefix = "data-pc-";
      var isExtended = key === "root" && isNotEmpty$2((_this$pt4 = this.pt) === null || _this$pt4 === void 0 ? void 0 : _this$pt4["data-pc-section"]);
      return key !== "transition" && _objectSpread$o(_objectSpread$o({}, key === "root" && _objectSpread$o(_objectSpread$o(_defineProperty$q({}, "".concat(datasetPrefix, "name"), toFlatCase$2(isExtended ? (_this$pt5 = this.pt) === null || _this$pt5 === void 0 ? void 0 : _this$pt5["data-pc-section"] : this.$.type.name)), isExtended && _defineProperty$q({}, "".concat(datasetPrefix, "extend"), toFlatCase$2(this.$.type.name))), isClient$2() && _defineProperty$q({}, "".concat(this.$attrSelector), ""))), {}, _defineProperty$q({}, "".concat(datasetPrefix, "section"), toFlatCase$2(key)));
    }, "_getPTDatasets"),
    _getPTClassValue: /* @__PURE__ */ __name(function _getPTClassValue() {
      var value3 = this._getOptionValue.apply(this, arguments);
      return isString$b(value3) || isArray$c(value3) ? {
        "class": value3
      } : value3;
    }, "_getPTClassValue"),
    _getPT: /* @__PURE__ */ __name(function _getPT2(pt) {
      var _this3 = this;
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var callback = arguments.length > 2 ? arguments[2] : void 0;
      var getValue2 = /* @__PURE__ */ __name(function getValue3(value3) {
        var _ref9;
        var checkSameKey = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
        var computedValue = callback ? callback(value3) : value3;
        var _key = toFlatCase$2(key);
        var _cKey = toFlatCase$2(_this3.$name);
        return (_ref9 = checkSameKey ? _key !== _cKey ? computedValue === null || computedValue === void 0 ? void 0 : computedValue[_key] : void 0 : computedValue === null || computedValue === void 0 ? void 0 : computedValue[_key]) !== null && _ref9 !== void 0 ? _ref9 : computedValue;
      }, "getValue");
      return pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept") ? {
        _usept: pt["_usept"],
        originalValue: getValue2(pt.originalValue),
        value: getValue2(pt.value)
      } : getValue2(pt, true);
    }, "_getPT"),
    _usePT: /* @__PURE__ */ __name(function _usePT2(pt, callback, key, params) {
      var fn = /* @__PURE__ */ __name(function fn2(value4) {
        return callback(value4, key, params);
      }, "fn");
      if (pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept")) {
        var _this$$primevueConfig3;
        var _ref10 = pt["_usept"] || ((_this$$primevueConfig3 = this.$primevueConfig) === null || _this$$primevueConfig3 === void 0 ? void 0 : _this$$primevueConfig3.ptOptions) || {}, _ref10$mergeSections = _ref10.mergeSections, mergeSections = _ref10$mergeSections === void 0 ? true : _ref10$mergeSections, _ref10$mergeProps = _ref10.mergeProps, useMergeProps = _ref10$mergeProps === void 0 ? false : _ref10$mergeProps;
        var originalValue = fn(pt.originalValue);
        var value3 = fn(pt.value);
        if (originalValue === void 0 && value3 === void 0) return void 0;
        else if (isString$b(value3)) return value3;
        else if (isString$b(originalValue)) return originalValue;
        return mergeSections || !mergeSections && value3 ? useMergeProps ? this._mergeProps(useMergeProps, originalValue, value3) : _objectSpread$o(_objectSpread$o({}, originalValue), value3) : value3;
      }
      return fn(pt);
    }, "_usePT"),
    _useGlobalPT: /* @__PURE__ */ __name(function _useGlobalPT(callback, key, params) {
      return this._usePT(this.globalPT, callback, key, params);
    }, "_useGlobalPT"),
    _useDefaultPT: /* @__PURE__ */ __name(function _useDefaultPT2(callback, key, params) {
      return this._usePT(this.defaultPT, callback, key, params);
    }, "_useDefaultPT"),
    ptm: /* @__PURE__ */ __name(function ptm() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return this._getPTValue(this.pt, key, _objectSpread$o(_objectSpread$o({}, this.$params), params));
    }, "ptm"),
    ptmi: /* @__PURE__ */ __name(function ptmi() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return mergeProps$2(this.$_attrsWithoutPT, this.ptm(key, params));
    }, "ptmi"),
    ptmo: /* @__PURE__ */ __name(function ptmo() {
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      return this._getPTValue(obj, key, _objectSpread$o({
        instance: this
      }, params), false);
    }, "ptmo"),
    cx: /* @__PURE__ */ __name(function cx() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return !this.isUnstyled ? this._getOptionValue(this.$style.classes, key, _objectSpread$o(_objectSpread$o({}, this.$params), params)) : void 0;
    }, "cx"),
    sx: /* @__PURE__ */ __name(function sx() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var when = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      if (when) {
        var self2 = this._getOptionValue(this.$style.inlineStyles, key, _objectSpread$o(_objectSpread$o({}, this.$params), params));
        var base2 = this._getOptionValue(BaseComponentStyle$2.inlineStyles, key, _objectSpread$o(_objectSpread$o({}, this.$params), params));
        return [base2, self2];
      }
      return void 0;
    }, "sx")
  },
  computed: {
    globalPT: /* @__PURE__ */ __name(function globalPT() {
      var _this$$primevueConfig4, _this4 = this;
      return this._getPT((_this$$primevueConfig4 = this.$primevueConfig) === null || _this$$primevueConfig4 === void 0 ? void 0 : _this$$primevueConfig4.pt, void 0, function(value3) {
        return resolve$4(value3, {
          instance: _this4
        });
      });
    }, "globalPT"),
    defaultPT: /* @__PURE__ */ __name(function defaultPT() {
      var _this$$primevueConfig5, _this5 = this;
      return this._getPT((_this$$primevueConfig5 = this.$primevueConfig) === null || _this$$primevueConfig5 === void 0 ? void 0 : _this$$primevueConfig5.pt, void 0, function(value3) {
        return _this5._getOptionValue(value3, _this5.$name, _objectSpread$o({}, _this5.$params)) || resolve$4(value3, _objectSpread$o({}, _this5.$params));
      });
    }, "defaultPT"),
    isUnstyled: /* @__PURE__ */ __name(function isUnstyled() {
      var _this$$primevueConfig6;
      return this.unstyled !== void 0 ? this.unstyled : (_this$$primevueConfig6 = this.$primevueConfig) === null || _this$$primevueConfig6 === void 0 ? void 0 : _this$$primevueConfig6.unstyled;
    }, "isUnstyled"),
    $inProps: /* @__PURE__ */ __name(function $inProps() {
      var _this$$$vnode;
      var nodePropKeys = Object.keys(((_this$$$vnode = this.$.vnode) === null || _this$$$vnode === void 0 ? void 0 : _this$$$vnode.props) || {});
      return Object.fromEntries(Object.entries(this.$props).filter(function(_ref11) {
        var _ref12 = _slicedToArray$5(_ref11, 1), k2 = _ref12[0];
        return nodePropKeys === null || nodePropKeys === void 0 ? void 0 : nodePropKeys.includes(k2);
      }));
    }, "$inProps"),
    $theme: /* @__PURE__ */ __name(function $theme() {
      var _this$$primevueConfig7;
      return (_this$$primevueConfig7 = this.$primevueConfig) === null || _this$$primevueConfig7 === void 0 ? void 0 : _this$$primevueConfig7.theme;
    }, "$theme"),
    $style: /* @__PURE__ */ __name(function $style() {
      return _objectSpread$o(_objectSpread$o({
        classes: void 0,
        inlineStyles: void 0,
        load: /* @__PURE__ */ __name(function load3() {
        }, "load"),
        loadCSS: /* @__PURE__ */ __name(function loadCSS3() {
        }, "loadCSS"),
        loadTheme: /* @__PURE__ */ __name(function loadTheme3() {
        }, "loadTheme")
      }, (this._getHostInstance(this) || {}).$style), this.$options.style);
    }, "$style"),
    $styleOptions: /* @__PURE__ */ __name(function $styleOptions() {
      var _this$$primevueConfig8;
      return {
        nonce: (_this$$primevueConfig8 = this.$primevueConfig) === null || _this$$primevueConfig8 === void 0 || (_this$$primevueConfig8 = _this$$primevueConfig8.csp) === null || _this$$primevueConfig8 === void 0 ? void 0 : _this$$primevueConfig8.nonce
      };
    }, "$styleOptions"),
    $primevueConfig: /* @__PURE__ */ __name(function $primevueConfig() {
      var _this$$primevue4;
      return (_this$$primevue4 = this.$primevue) === null || _this$$primevue4 === void 0 ? void 0 : _this$$primevue4.config;
    }, "$primevueConfig"),
    $name: /* @__PURE__ */ __name(function $name() {
      return this.$options.hostName || this.$.type.name;
    }, "$name"),
    $params: /* @__PURE__ */ __name(function $params() {
      var parentInstance = this._getHostInstance(this) || this.$parent;
      return {
        instance: this,
        props: this.$props,
        state: this.$data,
        attrs: this.$attrs,
        parent: {
          instance: parentInstance,
          props: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$props,
          state: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$data,
          attrs: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$attrs
        }
      };
    }, "$params"),
    $_attrsPT: /* @__PURE__ */ __name(function $_attrsPT() {
      return Object.entries(this.$attrs || {}).filter(function(_ref13) {
        var _ref14 = _slicedToArray$5(_ref13, 1), key = _ref14[0];
        return key === null || key === void 0 ? void 0 : key.startsWith("pt:");
      }).reduce(function(result, _ref15) {
        var _ref16 = _slicedToArray$5(_ref15, 2), key = _ref16[0], value3 = _ref16[1];
        var _key$split = key.split(":"), _key$split2 = _toArray$1(_key$split), rest = _key$split2.slice(1);
        rest === null || rest === void 0 || rest.reduce(function(currentObj, nestedKey, index2, array) {
          !currentObj[nestedKey] && (currentObj[nestedKey] = index2 === array.length - 1 ? value3 : {});
          return currentObj[nestedKey];
        }, result);
        return result;
      }, {});
    }, "$_attrsPT"),
    $_attrsWithoutPT: /* @__PURE__ */ __name(function $_attrsWithoutPT() {
      return Object.entries(this.$attrs || {}).filter(function(_ref17) {
        var _ref18 = _slicedToArray$5(_ref17, 1), key = _ref18[0];
        return !(key !== null && key !== void 0 && key.startsWith("pt:"));
      }).reduce(function(acc, _ref19) {
        var _ref20 = _slicedToArray$5(_ref19, 2), key = _ref20[0], value3 = _ref20[1];
        acc[key] = value3;
        return acc;
      }, {});
    }, "$_attrsWithoutPT")
  }
};
var theme$G = /* @__PURE__ */ __name(function theme4(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-blockui {\n    position: relative;\n}\n\n.p-blockui-mask {\n    border-radius: ".concat(dt2("blockui.border.radius"), ";\n}\n\n.p-blockui-mask.p-overlay-mask {\n    position: absolute;\n}\n\n.p-blockui-mask-document.p-overlay-mask {\n    position: fixed;\n}\n");
}, "theme");
var classes$M = {
  root: "p-blockui"
};
var BlockUIStyle = BaseStyle$1.extend({
  name: "blockui",
  theme: theme$G,
  classes: classes$M
});
var script$1$L = {
  name: "BaseBlockUI",
  "extends": script$1b,
  props: {
    blocked: {
      type: Boolean,
      "default": false
    },
    fullScreen: {
      type: Boolean,
      "default": false
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    autoZIndex: {
      type: Boolean,
      "default": true
    }
  },
  style: BlockUIStyle,
  provide: /* @__PURE__ */ __name(function provide2() {
    return {
      $pcBlockUI: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$1a = {
  name: "BlockUI",
  "extends": script$1$L,
  inheritAttrs: false,
  emits: ["block", "unblock"],
  mask: null,
  data: /* @__PURE__ */ __name(function data() {
    return {
      isBlocked: false
    };
  }, "data"),
  watch: {
    blocked: /* @__PURE__ */ __name(function blocked(newValue2) {
      if (newValue2 === true) this.block();
      else this.unblock();
    }, "blocked")
  },
  mounted: /* @__PURE__ */ __name(function mounted2() {
    if (this.blocked) {
      this.block();
    }
  }, "mounted"),
  methods: {
    block: /* @__PURE__ */ __name(function block2() {
      var styleClass = "p-blockui-mask p-overlay-mask p-overlay-mask-enter";
      if (this.fullScreen) {
        styleClass += " p-blockui-mask-document";
        this.mask = createElement$1("div", {
          style: {
            position: "fixed",
            top: "0",
            left: "0",
            width: "100%",
            height: "100%"
          },
          "class": !this.isUnstyled && styleClass,
          "p-bind": this.ptm("mask")
        });
        document.body.appendChild(this.mask);
        blockBodyScroll$1();
        document.activeElement.blur();
      } else {
        this.mask = createElement$1("div", {
          style: {
            position: "absolute",
            top: "0",
            left: "0",
            width: "100%",
            height: "100%"
          },
          "class": !this.isUnstyled && styleClass,
          "p-bind": this.ptm("mask")
        });
        this.$refs.container.appendChild(this.mask);
      }
      if (this.autoZIndex) {
        ZIndex$1.set("modal", this.mask, this.baseZIndex + this.$primevue.config.zIndex.modal);
      }
      this.isBlocked = true;
      this.$emit("block");
    }, "block"),
    unblock: /* @__PURE__ */ __name(function unblock() {
      var _this = this;
      !this.isUnstyled && addClass$1(this.mask, "p-overlay-mask-leave");
      if (hasCSSAnimation$1(this.mask) > 0) {
        this.mask.addEventListener("animationend", function() {
          _this.removeMask();
        });
      } else {
        this.removeMask();
      }
    }, "unblock"),
    removeMask: /* @__PURE__ */ __name(function removeMask() {
      ZIndex$1.clear(this.mask);
      if (this.fullScreen) {
        document.body.removeChild(this.mask);
        unblockBodyScroll$1();
      } else {
        var _this$$refs$container;
        (_this$$refs$container = this.$refs.container) === null || _this$$refs$container === void 0 || _this$$refs$container.removeChild(this.mask);
      }
      this.isBlocked = false;
      this.$emit("unblock");
    }, "removeMask")
  }
};
var _hoisted_1$1P = ["aria-busy"];
function render$14(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "container",
    "class": _ctx.cx("root"),
    "aria-busy": $data.isBlocked
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16, _hoisted_1$1P);
}
__name(render$14, "render$14");
script$1a.render = render$14;
var theme$F = /* @__PURE__ */ __name(function theme5(_ref) {
  var dt2 = _ref.dt;
  return '\n.p-progressspinner {\n    position: relative;\n    margin: 0 auto;\n    width: 100px;\n    height: 100px;\n    display: inline-block;\n}\n\n.p-progressspinner::before {\n    content: "";\n    display: block;\n    padding-top: 100%;\n}\n\n.p-progressspinner-spin {\n    height: 100%;\n    transform-origin: center center;\n    width: 100%;\n    position: absolute;\n    top: 0;\n    bottom: 0;\n    left: 0;\n    right: 0;\n    margin: auto;\n    animation: p-progressspinner-rotate 2s linear infinite;\n}\n\n.p-progressspinner-circle {\n    stroke-dasharray: 89, 200;\n    stroke-dashoffset: 0;\n    stroke: '.concat(dt2("progressspinner.color.1"), ";\n    animation: p-progressspinner-dash 1.5s ease-in-out infinite, p-progressspinner-color 6s ease-in-out infinite;\n    stroke-linecap: round;\n}\n\n@keyframes p-progressspinner-rotate {\n    100% {\n        transform: rotate(360deg);\n    }\n}\n@keyframes p-progressspinner-dash {\n    0% {\n        stroke-dasharray: 1, 200;\n        stroke-dashoffset: 0;\n    }\n    50% {\n        stroke-dasharray: 89, 200;\n        stroke-dashoffset: -35px;\n    }\n    100% {\n        stroke-dasharray: 89, 200;\n        stroke-dashoffset: -124px;\n    }\n}\n@keyframes p-progressspinner-color {\n    100%,\n    0% {\n        stroke: ").concat(dt2("progressspinner.color.1"), ";\n    }\n    40% {\n        stroke: ").concat(dt2("progressspinner.color.2"), ";\n    }\n    66% {\n        stroke: ").concat(dt2("progressspinner.color.3"), ";\n    }\n    80%,\n    90% {\n        stroke: ").concat(dt2("progressspinner.color.4"), ";\n    }\n}\n");
}, "theme");
var classes$L = {
  root: "p-progressspinner",
  spin: "p-progressspinner-spin",
  circle: "p-progressspinner-circle"
};
var ProgressSpinnerStyle = BaseStyle$1.extend({
  name: "progressspinner",
  theme: theme$F,
  classes: classes$L
});
var script$1$K = {
  name: "BaseProgressSpinner",
  "extends": script$1b,
  props: {
    strokeWidth: {
      type: String,
      "default": "2"
    },
    fill: {
      type: String,
      "default": "none"
    },
    animationDuration: {
      type: String,
      "default": "2s"
    }
  },
  style: ProgressSpinnerStyle,
  provide: /* @__PURE__ */ __name(function provide3() {
    return {
      $pcProgressSpinner: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$19 = {
  name: "ProgressSpinner",
  "extends": script$1$K,
  inheritAttrs: false,
  computed: {
    svgStyle: /* @__PURE__ */ __name(function svgStyle() {
      return {
        "animation-duration": this.animationDuration
      };
    }, "svgStyle")
  }
};
var _hoisted_1$1O = ["fill", "stroke-width"];
function render$13(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    role: "progressbar"
  }, _ctx.ptmi("root")), [(openBlock(), createElementBlock("svg", mergeProps$2({
    "class": _ctx.cx("spin"),
    viewBox: "25 25 50 50",
    style: $options.svgStyle
  }, _ctx.ptm("spin")), [createBaseVNode("circle", mergeProps$2({
    "class": _ctx.cx("circle"),
    cx: "50",
    cy: "50",
    r: "20",
    fill: _ctx.fill,
    "stroke-width": _ctx.strokeWidth,
    strokeMiterlimit: "10"
  }, _ctx.ptm("circle")), null, 16, _hoisted_1$1O)], 16))], 16);
}
__name(render$13, "render$13");
script$19.render = render$13;
var BaseComponentStyle$1 = BaseStyle$1.extend({
  name: "common"
});
var script$18 = {
  name: "BaseEditableHolder",
  "extends": script$1b,
  emits: ["update:modelValue", "value-change"],
  props: {
    modelValue: {
      type: null,
      "default": void 0
    },
    defaultValue: {
      type: null,
      "default": void 0
    },
    name: {
      type: String,
      "default": void 0
    },
    invalid: {
      type: Boolean,
      "default": void 0
    },
    disabled: {
      type: Boolean,
      "default": false
    },
    formControl: {
      type: Object,
      "default": void 0
    }
  },
  inject: {
    $parentInstance: {
      "default": void 0
    },
    $pcForm: {
      "default": void 0
    },
    $pcFormField: {
      "default": void 0
    }
  },
  data: /* @__PURE__ */ __name(function data2() {
    return {
      d_value: this.defaultValue || this.modelValue
    };
  }, "data"),
  watch: {
    modelValue: /* @__PURE__ */ __name(function modelValue(newValue2) {
      this.d_value = newValue2;
    }, "modelValue"),
    defaultValue: /* @__PURE__ */ __name(function defaultValue(newValue2) {
      this.d_value = newValue2;
    }, "defaultValue"),
    $formName: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler4(newValue2) {
        var _this$$pcForm, _this$$pcForm$registe;
        this.formField = ((_this$$pcForm = this.$pcForm) === null || _this$$pcForm === void 0 || (_this$$pcForm$registe = _this$$pcForm.register) === null || _this$$pcForm$registe === void 0 ? void 0 : _this$$pcForm$registe.call(_this$$pcForm, newValue2, this.$formControl)) || {};
      }, "handler")
    },
    $formControl: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler5(newValue2) {
        var _this$$pcForm2, _this$$pcForm2$regist;
        this.formField = ((_this$$pcForm2 = this.$pcForm) === null || _this$$pcForm2 === void 0 || (_this$$pcForm2$regist = _this$$pcForm2.register) === null || _this$$pcForm2$regist === void 0 ? void 0 : _this$$pcForm2$regist.call(_this$$pcForm2, this.$formName, newValue2)) || {};
      }, "handler")
    },
    $formDefaultValue: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler6(newValue2) {
        this.d_value !== newValue2 && (this.d_value = newValue2);
      }, "handler")
    }
  },
  formField: {},
  methods: {
    writeValue: /* @__PURE__ */ __name(function writeValue(value3, event) {
      var _this$formField$onCha, _this$formField;
      if (this.controlled) {
        this.d_value = value3;
        this.$emit("update:modelValue", value3);
      }
      this.$emit("value-change", value3);
      (_this$formField$onCha = (_this$formField = this.formField).onChange) === null || _this$formField$onCha === void 0 || _this$formField$onCha.call(_this$formField, {
        originalEvent: event,
        value: value3
      });
    }, "writeValue")
  },
  computed: {
    $filled: /* @__PURE__ */ __name(function $filled() {
      return isNotEmpty$2(this.d_value);
    }, "$filled"),
    $invalid: /* @__PURE__ */ __name(function $invalid() {
      var _ref, _this$invalid, _this$$pcFormField, _this$$pcForm3;
      return (_ref = (_this$invalid = this.invalid) !== null && _this$invalid !== void 0 ? _this$invalid : (_this$$pcFormField = this.$pcFormField) === null || _this$$pcFormField === void 0 || (_this$$pcFormField = _this$$pcFormField.$field) === null || _this$$pcFormField === void 0 ? void 0 : _this$$pcFormField.invalid) !== null && _ref !== void 0 ? _ref : (_this$$pcForm3 = this.$pcForm) === null || _this$$pcForm3 === void 0 || (_this$$pcForm3 = _this$$pcForm3.states) === null || _this$$pcForm3 === void 0 || (_this$$pcForm3 = _this$$pcForm3[this.$formName]) === null || _this$$pcForm3 === void 0 ? void 0 : _this$$pcForm3.invalid;
    }, "$invalid"),
    $formName: /* @__PURE__ */ __name(function $formName() {
      var _this$$formControl;
      return this.name || ((_this$$formControl = this.$formControl) === null || _this$$formControl === void 0 ? void 0 : _this$$formControl.name);
    }, "$formName"),
    $formControl: /* @__PURE__ */ __name(function $formControl() {
      var _this$$pcFormField2;
      return this.formControl || ((_this$$pcFormField2 = this.$pcFormField) === null || _this$$pcFormField2 === void 0 ? void 0 : _this$$pcFormField2.formControl);
    }, "$formControl"),
    $formDefaultValue: /* @__PURE__ */ __name(function $formDefaultValue() {
      var _ref2, _this$d_value, _this$$pcFormField3, _this$$pcForm4;
      return (_ref2 = (_this$d_value = this.d_value) !== null && _this$d_value !== void 0 ? _this$d_value : (_this$$pcFormField3 = this.$pcFormField) === null || _this$$pcFormField3 === void 0 ? void 0 : _this$$pcFormField3.initialValue) !== null && _ref2 !== void 0 ? _ref2 : (_this$$pcForm4 = this.$pcForm) === null || _this$$pcForm4 === void 0 || (_this$$pcForm4 = _this$$pcForm4.initialValues) === null || _this$$pcForm4 === void 0 ? void 0 : _this$$pcForm4[this.$formName];
    }, "$formDefaultValue"),
    controlled: /* @__PURE__ */ __name(function controlled() {
      return this.$inProps.hasOwnProperty("modelValue") || !this.$inProps.hasOwnProperty("modelValue") && !this.$inProps.hasOwnProperty("defaultValue");
    }, "controlled"),
    // @deprecated use $filled instead
    filled: /* @__PURE__ */ __name(function filled() {
      return this.$filled;
    }, "filled")
  }
};
var script$17 = {
  name: "BaseInput",
  "extends": script$18,
  props: {
    size: {
      type: String,
      "default": null
    },
    fluid: {
      type: Boolean,
      "default": null
    },
    variant: {
      type: String,
      "default": null
    }
  },
  inject: {
    $parentInstance: {
      "default": void 0
    },
    $pcFluid: {
      "default": void 0
    }
  },
  computed: {
    $variant: /* @__PURE__ */ __name(function $variant() {
      var _this$variant;
      return (_this$variant = this.variant) !== null && _this$variant !== void 0 ? _this$variant : this.$primevue.config.inputStyle || this.$primevue.config.inputVariant;
    }, "$variant"),
    $fluid: /* @__PURE__ */ __name(function $fluid() {
      var _this$fluid;
      return (_this$fluid = this.fluid) !== null && _this$fluid !== void 0 ? _this$fluid : !!this.$pcFluid;
    }, "$fluid"),
    // @deprecated use $fluid instead
    hasFluid: /* @__PURE__ */ __name(function hasFluid() {
      return this.$fluid;
    }, "hasFluid")
  }
};
var css$3 = "\n.p-icon {\n    display: inline-block;\n    vertical-align: baseline;\n}\n\n.p-icon-spin {\n    -webkit-animation: p-icon-spin 2s infinite linear;\n    animation: p-icon-spin 2s infinite linear;\n}\n\n@-webkit-keyframes p-icon-spin {\n    0% {\n        -webkit-transform: rotate(0deg);\n        transform: rotate(0deg);\n    }\n    100% {\n        -webkit-transform: rotate(359deg);\n        transform: rotate(359deg);\n    }\n}\n\n@keyframes p-icon-spin {\n    0% {\n        -webkit-transform: rotate(0deg);\n        transform: rotate(0deg);\n    }\n    100% {\n        -webkit-transform: rotate(359deg);\n        transform: rotate(359deg);\n    }\n}\n";
var BaseIconStyle = BaseStyle$1.extend({
  name: "baseicon",
  css: css$3
});
function _typeof$n(o2) {
  "@babel/helpers - typeof";
  return _typeof$n = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$n(o2);
}
__name(_typeof$n, "_typeof$n");
function ownKeys$n(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$n, "ownKeys$n");
function _objectSpread$n(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$n(Object(t2), true).forEach(function(r3) {
      _defineProperty$p(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$n(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$n, "_objectSpread$n");
function _defineProperty$p(e2, r2, t2) {
  return (r2 = _toPropertyKey$m(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$p, "_defineProperty$p");
function _toPropertyKey$m(t2) {
  var i2 = _toPrimitive$m(t2, "string");
  return "symbol" == _typeof$n(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$m, "_toPropertyKey$m");
function _toPrimitive$m(t2, r2) {
  if ("object" != _typeof$n(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$n(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$m, "_toPrimitive$m");
var script$16 = {
  name: "BaseIcon",
  "extends": script$1b,
  props: {
    label: {
      type: String,
      "default": void 0
    },
    spin: {
      type: Boolean,
      "default": false
    }
  },
  style: BaseIconStyle,
  provide: /* @__PURE__ */ __name(function provide4() {
    return {
      $pcIcon: this,
      $parentInstance: this
    };
  }, "provide"),
  methods: {
    pti: /* @__PURE__ */ __name(function pti() {
      var isLabelEmpty = isEmpty$3(this.label);
      return _objectSpread$n(_objectSpread$n({}, !this.isUnstyled && {
        "class": ["p-icon", {
          "p-icon-spin": this.spin
        }]
      }), {}, {
        role: !isLabelEmpty ? "img" : void 0,
        "aria-label": !isLabelEmpty ? this.label : void 0,
        "aria-hidden": isLabelEmpty
      });
    }, "pti")
  }
};
var script$15 = {
  name: "TimesIcon",
  "extends": script$16
};
function render$12(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M8.01186 7.00933L12.27 2.75116C12.341 2.68501 12.398 2.60524 12.4375 2.51661C12.4769 2.42798 12.4982 2.3323 12.4999 2.23529C12.5016 2.13827 12.4838 2.0419 12.4474 1.95194C12.4111 1.86197 12.357 1.78024 12.2884 1.71163C12.2198 1.64302 12.138 1.58893 12.0481 1.55259C11.9581 1.51625 11.8617 1.4984 11.7647 1.50011C11.6677 1.50182 11.572 1.52306 11.4834 1.56255C11.3948 1.60204 11.315 1.65898 11.2488 1.72997L6.99067 5.98814L2.7325 1.72997C2.59553 1.60234 2.41437 1.53286 2.22718 1.53616C2.03999 1.53946 1.8614 1.61529 1.72901 1.74767C1.59663 1.88006 1.5208 2.05865 1.5175 2.24584C1.5142 2.43303 1.58368 2.61419 1.71131 2.75116L5.96948 7.00933L1.71131 11.2675C1.576 11.403 1.5 11.5866 1.5 11.7781C1.5 11.9696 1.576 12.1532 1.71131 12.2887C1.84679 12.424 2.03043 12.5 2.2219 12.5C2.41338 12.5 2.59702 12.424 2.7325 12.2887L6.99067 8.03052L11.2488 12.2887C11.3843 12.424 11.568 12.5 11.7594 12.5C11.9509 12.5 12.1346 12.424 12.27 12.2887C12.4053 12.1532 12.4813 11.9696 12.4813 11.7781C12.4813 11.5866 12.4053 11.403 12.27 11.2675L8.01186 7.00933Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$12, "render$12");
script$15.render = render$12;
var script$14 = {
  name: "WindowMaximizeIcon",
  "extends": script$16
};
function render$11(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    "fill-rule": "evenodd",
    "clip-rule": "evenodd",
    d: "M7 14H11.8C12.3835 14 12.9431 13.7682 13.3556 13.3556C13.7682 12.9431 14 12.3835 14 11.8V2.2C14 1.61652 13.7682 1.05694 13.3556 0.644365C12.9431 0.231785 12.3835 0 11.8 0H2.2C1.61652 0 1.05694 0.231785 0.644365 0.644365C0.231785 1.05694 0 1.61652 0 2.2V7C0 7.15913 0.063214 7.31174 0.175736 7.42426C0.288258 7.53679 0.44087 7.6 0.6 7.6C0.75913 7.6 0.911742 7.53679 1.02426 7.42426C1.13679 7.31174 1.2 7.15913 1.2 7V2.2C1.2 1.93478 1.30536 1.68043 1.49289 1.49289C1.68043 1.30536 1.93478 1.2 2.2 1.2H11.8C12.0652 1.2 12.3196 1.30536 12.5071 1.49289C12.6946 1.68043 12.8 1.93478 12.8 2.2V11.8C12.8 12.0652 12.6946 12.3196 12.5071 12.5071C12.3196 12.6946 12.0652 12.8 11.8 12.8H7C6.84087 12.8 6.68826 12.8632 6.57574 12.9757C6.46321 13.0883 6.4 13.2409 6.4 13.4C6.4 13.5591 6.46321 13.7117 6.57574 13.8243C6.68826 13.9368 6.84087 14 7 14ZM9.77805 7.42192C9.89013 7.534 10.0415 7.59788 10.2 7.59995C10.3585 7.59788 10.5099 7.534 10.622 7.42192C10.7341 7.30985 10.798 7.15844 10.8 6.99995V3.94242C10.8066 3.90505 10.8096 3.86689 10.8089 3.82843C10.8079 3.77159 10.7988 3.7157 10.7824 3.6623C10.756 3.55552 10.701 3.45698 10.622 3.37798C10.5099 3.2659 10.3585 3.20202 10.2 3.19995H7.00002C6.84089 3.19995 6.68828 3.26317 6.57576 3.37569C6.46324 3.48821 6.40002 3.64082 6.40002 3.79995C6.40002 3.95908 6.46324 4.11169 6.57576 4.22422C6.68828 4.33674 6.84089 4.39995 7.00002 4.39995H8.80006L6.19997 7.00005C6.10158 7.11005 6.04718 7.25246 6.04718 7.40005C6.04718 7.54763 6.10158 7.69004 6.19997 7.80005C6.30202 7.91645 6.44561 7.98824 6.59997 8.00005C6.75432 7.98824 6.89791 7.91645 6.99997 7.80005L9.60002 5.26841V6.99995C9.6021 7.15844 9.66598 7.30985 9.77805 7.42192ZM1.4 14H3.8C4.17066 13.9979 4.52553 13.8498 4.78763 13.5877C5.04973 13.3256 5.1979 12.9707 5.2 12.6V10.2C5.1979 9.82939 5.04973 9.47452 4.78763 9.21242C4.52553 8.95032 4.17066 8.80215 3.8 8.80005H1.4C1.02934 8.80215 0.674468 8.95032 0.412371 9.21242C0.150274 9.47452 0.00210008 9.82939 0 10.2V12.6C0.00210008 12.9707 0.150274 13.3256 0.412371 13.5877C0.674468 13.8498 1.02934 13.9979 1.4 14ZM1.25858 10.0586C1.29609 10.0211 1.34696 10 1.4 10H3.8C3.85304 10 3.90391 10.0211 3.94142 10.0586C3.97893 10.0961 4 10.147 4 10.2V12.6C4 12.6531 3.97893 12.704 3.94142 12.7415C3.90391 12.779 3.85304 12.8 3.8 12.8H1.4C1.34696 12.8 1.29609 12.779 1.25858 12.7415C1.22107 12.704 1.2 12.6531 1.2 12.6V10.2C1.2 10.147 1.22107 10.0961 1.25858 10.0586Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$11, "render$11");
script$14.render = render$11;
var script$13 = {
  name: "WindowMinimizeIcon",
  "extends": script$16
};
function render$10(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    "fill-rule": "evenodd",
    "clip-rule": "evenodd",
    d: "M11.8 0H2.2C1.61652 0 1.05694 0.231785 0.644365 0.644365C0.231785 1.05694 0 1.61652 0 2.2V7C0 7.15913 0.063214 7.31174 0.175736 7.42426C0.288258 7.53679 0.44087 7.6 0.6 7.6C0.75913 7.6 0.911742 7.53679 1.02426 7.42426C1.13679 7.31174 1.2 7.15913 1.2 7V2.2C1.2 1.93478 1.30536 1.68043 1.49289 1.49289C1.68043 1.30536 1.93478 1.2 2.2 1.2H11.8C12.0652 1.2 12.3196 1.30536 12.5071 1.49289C12.6946 1.68043 12.8 1.93478 12.8 2.2V11.8C12.8 12.0652 12.6946 12.3196 12.5071 12.5071C12.3196 12.6946 12.0652 12.8 11.8 12.8H7C6.84087 12.8 6.68826 12.8632 6.57574 12.9757C6.46321 13.0883 6.4 13.2409 6.4 13.4C6.4 13.5591 6.46321 13.7117 6.57574 13.8243C6.68826 13.9368 6.84087 14 7 14H11.8C12.3835 14 12.9431 13.7682 13.3556 13.3556C13.7682 12.9431 14 12.3835 14 11.8V2.2C14 1.61652 13.7682 1.05694 13.3556 0.644365C12.9431 0.231785 12.3835 0 11.8 0ZM6.368 7.952C6.44137 7.98326 6.52025 7.99958 6.6 8H9.8C9.95913 8 10.1117 7.93678 10.2243 7.82426C10.3368 7.71174 10.4 7.55913 10.4 7.4C10.4 7.24087 10.3368 7.08826 10.2243 6.97574C10.1117 6.86321 9.95913 6.8 9.8 6.8H8.048L10.624 4.224C10.73 4.11026 10.7877 3.95982 10.7849 3.80438C10.7822 3.64894 10.7192 3.50063 10.6093 3.3907C10.4994 3.28077 10.3511 3.2178 10.1956 3.21506C10.0402 3.21232 9.88974 3.27002 9.776 3.376L7.2 5.952V4.2C7.2 4.04087 7.13679 3.88826 7.02426 3.77574C6.91174 3.66321 6.75913 3.6 6.6 3.6C6.44087 3.6 6.28826 3.66321 6.17574 3.77574C6.06321 3.88826 6 4.04087 6 4.2V7.4C6.00042 7.47975 6.01674 7.55862 6.048 7.632C6.07656 7.70442 6.11971 7.7702 6.17475 7.82524C6.2298 7.88029 6.29558 7.92344 6.368 7.952ZM1.4 8.80005H3.8C4.17066 8.80215 4.52553 8.95032 4.78763 9.21242C5.04973 9.47452 5.1979 9.82939 5.2 10.2V12.6C5.1979 12.9707 5.04973 13.3256 4.78763 13.5877C4.52553 13.8498 4.17066 13.9979 3.8 14H1.4C1.02934 13.9979 0.674468 13.8498 0.412371 13.5877C0.150274 13.3256 0.00210008 12.9707 0 12.6V10.2C0.00210008 9.82939 0.150274 9.47452 0.412371 9.21242C0.674468 8.95032 1.02934 8.80215 1.4 8.80005ZM3.94142 12.7415C3.97893 12.704 4 12.6531 4 12.6V10.2C4 10.147 3.97893 10.0961 3.94142 10.0586C3.90391 10.0211 3.85304 10 3.8 10H1.4C1.34696 10 1.29609 10.0211 1.25858 10.0586C1.22107 10.0961 1.2 10.147 1.2 10.2V12.6C1.2 12.6531 1.22107 12.704 1.25858 12.7415C1.29609 12.779 1.34696 12.8 1.4 12.8H3.8C3.85304 12.8 3.90391 12.779 3.94142 12.7415Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$10, "render$10");
script$13.render = render$10;
var script$12 = {
  name: "SpinnerIcon",
  "extends": script$16
};
function render$$(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M6.99701 14C5.85441 13.999 4.72939 13.7186 3.72012 13.1832C2.71084 12.6478 1.84795 11.8737 1.20673 10.9284C0.565504 9.98305 0.165424 8.89526 0.041387 7.75989C-0.0826496 6.62453 0.073125 5.47607 0.495122 4.4147C0.917119 3.35333 1.59252 2.4113 2.46241 1.67077C3.33229 0.930247 4.37024 0.413729 5.4857 0.166275C6.60117 -0.0811796 7.76026 -0.0520535 8.86188 0.251112C9.9635 0.554278 10.9742 1.12227 11.8057 1.90555C11.915 2.01493 11.9764 2.16319 11.9764 2.31778C11.9764 2.47236 11.915 2.62062 11.8057 2.73C11.7521 2.78503 11.688 2.82877 11.6171 2.85864C11.5463 2.8885 11.4702 2.90389 11.3933 2.90389C11.3165 2.90389 11.2404 2.8885 11.1695 2.85864C11.0987 2.82877 11.0346 2.78503 10.9809 2.73C9.9998 1.81273 8.73246 1.26138 7.39226 1.16876C6.05206 1.07615 4.72086 1.44794 3.62279 2.22152C2.52471 2.99511 1.72683 4.12325 1.36345 5.41602C1.00008 6.70879 1.09342 8.08723 1.62775 9.31926C2.16209 10.5513 3.10478 11.5617 4.29713 12.1803C5.48947 12.7989 6.85865 12.988 8.17414 12.7157C9.48963 12.4435 10.6711 11.7264 11.5196 10.6854C12.3681 9.64432 12.8319 8.34282 12.8328 7C12.8328 6.84529 12.8943 6.69692 13.0038 6.58752C13.1132 6.47812 13.2616 6.41667 13.4164 6.41667C13.5712 6.41667 13.7196 6.47812 13.8291 6.58752C13.9385 6.69692 14 6.84529 14 7C14 8.85651 13.2622 10.637 11.9489 11.9497C10.6356 13.2625 8.85432 14 6.99701 14Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$$, "render$$");
script$12.render = render$$;
var theme$E = /* @__PURE__ */ __name(function theme6(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-badge {\n    display: inline-flex;\n    border-radius: ".concat(dt2("badge.border.radius"), ";\n    align-items: center;\n    justify-content: center;\n    padding: ").concat(dt2("badge.padding"), ";\n    background: ").concat(dt2("badge.primary.background"), ";\n    color: ").concat(dt2("badge.primary.color"), ";\n    font-size: ").concat(dt2("badge.font.size"), ";\n    font-weight: ").concat(dt2("badge.font.weight"), ";\n    min-width: ").concat(dt2("badge.min.width"), ";\n    height: ").concat(dt2("badge.height"), ";\n}\n\n.p-badge-dot {\n    width: ").concat(dt2("badge.dot.size"), ";\n    min-width: ").concat(dt2("badge.dot.size"), ";\n    height: ").concat(dt2("badge.dot.size"), ";\n    border-radius: 50%;\n    padding: 0;\n}\n\n.p-badge-circle {\n    padding: 0;\n    border-radius: 50%;\n}\n\n.p-badge-secondary {\n    background: ").concat(dt2("badge.secondary.background"), ";\n    color: ").concat(dt2("badge.secondary.color"), ";\n}\n\n.p-badge-success {\n    background: ").concat(dt2("badge.success.background"), ";\n    color: ").concat(dt2("badge.success.color"), ";\n}\n\n.p-badge-info {\n    background: ").concat(dt2("badge.info.background"), ";\n    color: ").concat(dt2("badge.info.color"), ";\n}\n\n.p-badge-warn {\n    background: ").concat(dt2("badge.warn.background"), ";\n    color: ").concat(dt2("badge.warn.color"), ";\n}\n\n.p-badge-danger {\n    background: ").concat(dt2("badge.danger.background"), ";\n    color: ").concat(dt2("badge.danger.color"), ";\n}\n\n.p-badge-contrast {\n    background: ").concat(dt2("badge.contrast.background"), ";\n    color: ").concat(dt2("badge.contrast.color"), ";\n}\n\n.p-badge-sm {\n    font-size: ").concat(dt2("badge.sm.font.size"), ";\n    min-width: ").concat(dt2("badge.sm.min.width"), ";\n    height: ").concat(dt2("badge.sm.height"), ";\n}\n\n.p-badge-lg {\n    font-size: ").concat(dt2("badge.lg.font.size"), ";\n    min-width: ").concat(dt2("badge.lg.min.width"), ";\n    height: ").concat(dt2("badge.lg.height"), ";\n}\n\n.p-badge-xl {\n    font-size: ").concat(dt2("badge.xl.font.size"), ";\n    min-width: ").concat(dt2("badge.xl.min.width"), ";\n    height: ").concat(dt2("badge.xl.height"), ";\n}\n");
}, "theme");
var classes$K = {
  root: /* @__PURE__ */ __name(function root2(_ref2) {
    var props = _ref2.props, instance = _ref2.instance;
    return ["p-badge p-component", {
      "p-badge-circle": isNotEmpty$2(props.value) && String(props.value).length === 1,
      "p-badge-dot": isEmpty$3(props.value) && !instance.$slots["default"],
      "p-badge-sm": props.size === "small",
      "p-badge-lg": props.size === "large",
      "p-badge-xl": props.size === "xlarge",
      "p-badge-info": props.severity === "info",
      "p-badge-success": props.severity === "success",
      "p-badge-warn": props.severity === "warn",
      "p-badge-danger": props.severity === "danger",
      "p-badge-secondary": props.severity === "secondary",
      "p-badge-contrast": props.severity === "contrast"
    }];
  }, "root")
};
var BadgeStyle = BaseStyle$1.extend({
  name: "badge",
  theme: theme$E,
  classes: classes$K
});
var script$1$J = {
  name: "BaseBadge",
  "extends": script$1b,
  props: {
    value: {
      type: [String, Number],
      "default": null
    },
    severity: {
      type: String,
      "default": null
    },
    size: {
      type: String,
      "default": null
    }
  },
  style: BadgeStyle,
  provide: /* @__PURE__ */ __name(function provide5() {
    return {
      $pcBadge: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$11 = {
  name: "Badge",
  "extends": script$1$J,
  inheritAttrs: false
};
function render$_(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("span", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default", {}, function() {
    return [createTextVNode(toDisplayString$1(_ctx.value), 1)];
  })], 16);
}
__name(render$_, "render$_");
script$11.render = render$_;
var theme$D = /* @__PURE__ */ __name(function theme7(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-ink {\n    display: block;\n    position: absolute;\n    background: ".concat(dt2("ripple.background"), ";\n    border-radius: 100%;\n    transform: scale(0);\n    pointer-events: none;\n}\n\n.p-ink-active {\n    animation: ripple 0.4s linear;\n}\n\n@keyframes ripple {\n    100% {\n        opacity: 0;\n        transform: scale(2.5);\n    }\n}\n");
}, "theme");
var classes$J = {
  root: "p-ink"
};
var RippleStyle = BaseStyle$1.extend({
  name: "ripple-directive",
  theme: theme$D,
  classes: classes$J
});
var BaseRipple = BaseDirective.extend({
  style: RippleStyle
});
function _typeof$m(o2) {
  "@babel/helpers - typeof";
  return _typeof$m = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$m(o2);
}
__name(_typeof$m, "_typeof$m");
function _toConsumableArray$c(r2) {
  return _arrayWithoutHoles$c(r2) || _iterableToArray$d(r2) || _unsupportedIterableToArray$i(r2) || _nonIterableSpread$c();
}
__name(_toConsumableArray$c, "_toConsumableArray$c");
function _nonIterableSpread$c() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$c, "_nonIterableSpread$c");
function _unsupportedIterableToArray$i(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$i(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$i(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$i, "_unsupportedIterableToArray$i");
function _iterableToArray$d(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$d, "_iterableToArray$d");
function _arrayWithoutHoles$c(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$i(r2);
}
__name(_arrayWithoutHoles$c, "_arrayWithoutHoles$c");
function _arrayLikeToArray$i(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$i, "_arrayLikeToArray$i");
function _defineProperty$o(e2, r2, t2) {
  return (r2 = _toPropertyKey$l(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$o, "_defineProperty$o");
function _toPropertyKey$l(t2) {
  var i2 = _toPrimitive$l(t2, "string");
  return "symbol" == _typeof$m(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$l, "_toPropertyKey$l");
function _toPrimitive$l(t2, r2) {
  if ("object" != _typeof$m(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$m(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$l, "_toPrimitive$l");
var Ripple = BaseRipple.extend("ripple", {
  watch: {
    "config.ripple": /* @__PURE__ */ __name(function configRipple(newValue2) {
      if (newValue2) {
        this.createRipple(this.$host);
        this.bindEvents(this.$host);
        this.$host.setAttribute("data-pd-ripple", true);
        this.$host.style["overflow"] = "hidden";
        this.$host.style["position"] = "relative";
      } else {
        this.remove(this.$host);
        this.$host.removeAttribute("data-pd-ripple");
      }
    }, "configRipple")
  },
  unmounted: /* @__PURE__ */ __name(function unmounted3(el) {
    this.remove(el);
  }, "unmounted"),
  timeout: void 0,
  methods: {
    bindEvents: /* @__PURE__ */ __name(function bindEvents2(el) {
      el.addEventListener("mousedown", this.onMouseDown.bind(this));
    }, "bindEvents"),
    unbindEvents: /* @__PURE__ */ __name(function unbindEvents2(el) {
      el.removeEventListener("mousedown", this.onMouseDown.bind(this));
    }, "unbindEvents"),
    createRipple: /* @__PURE__ */ __name(function createRipple(el) {
      var ink = createElement$1("span", _defineProperty$o(_defineProperty$o({
        role: "presentation",
        "aria-hidden": true,
        "data-p-ink": true,
        "data-p-ink-active": false,
        "class": !this.isUnstyled() && this.cx("root"),
        onAnimationEnd: this.onAnimationEnd.bind(this)
      }, this.$attrSelector, ""), "p-bind", this.ptm("root")));
      el.appendChild(ink);
      this.$el = ink;
    }, "createRipple"),
    remove: /* @__PURE__ */ __name(function remove3(el) {
      var ink = this.getInk(el);
      if (ink) {
        this.$host.style["overflow"] = "";
        this.$host.style["position"] = "";
        this.unbindEvents(el);
        ink.removeEventListener("animationend", this.onAnimationEnd);
        ink.remove();
      }
    }, "remove"),
    onMouseDown: /* @__PURE__ */ __name(function onMouseDown(event) {
      var _this = this;
      var target2 = event.currentTarget;
      var ink = this.getInk(target2);
      if (!ink || getComputedStyle(ink, null).display === "none") {
        return;
      }
      !this.isUnstyled() && removeClass$1(ink, "p-ink-active");
      ink.setAttribute("data-p-ink-active", "false");
      if (!getHeight$1(ink) && !getWidth$1(ink)) {
        var d2 = Math.max(getOuterWidth$1(target2), getOuterHeight$1(target2));
        ink.style.height = d2 + "px";
        ink.style.width = d2 + "px";
      }
      var offset = getOffset$1(target2);
      var x2 = event.pageX - offset.left + document.body.scrollTop - getWidth$1(ink) / 2;
      var y2 = event.pageY - offset.top + document.body.scrollLeft - getHeight$1(ink) / 2;
      ink.style.top = y2 + "px";
      ink.style.left = x2 + "px";
      !this.isUnstyled() && addClass$1(ink, "p-ink-active");
      ink.setAttribute("data-p-ink-active", "true");
      this.timeout = setTimeout(function() {
        if (ink) {
          !_this.isUnstyled() && removeClass$1(ink, "p-ink-active");
          ink.setAttribute("data-p-ink-active", "false");
        }
      }, 401);
    }, "onMouseDown"),
    onAnimationEnd: /* @__PURE__ */ __name(function onAnimationEnd(event) {
      if (this.timeout) {
        clearTimeout(this.timeout);
      }
      !this.isUnstyled() && removeClass$1(event.currentTarget, "p-ink-active");
      event.currentTarget.setAttribute("data-p-ink-active", "false");
    }, "onAnimationEnd"),
    getInk: /* @__PURE__ */ __name(function getInk(el) {
      return el && el.children ? _toConsumableArray$c(el.children).find(function(child) {
        return getAttribute$1(child, "data-pc-name") === "ripple";
      }) : void 0;
    }, "getInk")
  }
});
function _typeof$l(o2) {
  "@babel/helpers - typeof";
  return _typeof$l = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$l(o2);
}
__name(_typeof$l, "_typeof$l");
function _defineProperty$n(e2, r2, t2) {
  return (r2 = _toPropertyKey$k(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$n, "_defineProperty$n");
function _toPropertyKey$k(t2) {
  var i2 = _toPrimitive$k(t2, "string");
  return "symbol" == _typeof$l(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$k, "_toPropertyKey$k");
function _toPrimitive$k(t2, r2) {
  if ("object" != _typeof$l(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$l(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$k, "_toPrimitive$k");
var theme$C = /* @__PURE__ */ __name(function theme8(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-button {\n    display: inline-flex;\n    cursor: pointer;\n    user-select: none;\n    align-items: center;\n    justify-content: center;\n    overflow: hidden;\n    position: relative;\n    color: ".concat(dt2("button.primary.color"), ";\n    background: ").concat(dt2("button.primary.background"), ";\n    border: 1px solid ").concat(dt2("button.primary.border.color"), ";\n    padding: ").concat(dt2("button.padding.y"), " ").concat(dt2("button.padding.x"), ";\n    font-size: 1rem;\n    font-family: inherit;\n    font-feature-settings: inherit;\n    transition: background ").concat(dt2("button.transition.duration"), ", color ").concat(dt2("button.transition.duration"), ", border-color ").concat(dt2("button.transition.duration"), ",\n            outline-color ").concat(dt2("button.transition.duration"), ", box-shadow ").concat(dt2("button.transition.duration"), ";\n    border-radius: ").concat(dt2("button.border.radius"), ";\n    outline-color: transparent;\n    gap: ").concat(dt2("button.gap"), ";\n}\n\n.p-button:disabled {\n    cursor: default;\n}\n\n.p-button-icon-right {\n    order: 1;\n}\n\n.p-button-icon-right:dir(rtl) {\n    order: -1;\n}\n\n.p-button:not(.p-button-vertical) .p-button-icon:not(.p-button-icon-right):dir(rtl) {\n    order: 1;\n}\n\n.p-button-icon-bottom {\n    order: 2;\n}\n\n.p-button-icon-only {\n    width: ").concat(dt2("button.icon.only.width"), ";\n    padding-inline-start: 0;\n    padding-inline-end: 0;\n    gap: 0;\n}\n\n.p-button-icon-only.p-button-rounded {\n    border-radius: 50%;\n    height: ").concat(dt2("button.icon.only.width"), ";\n}\n\n.p-button-icon-only .p-button-label {\n    visibility: hidden;\n    width: 0;\n}\n\n.p-button-sm {\n    font-size: ").concat(dt2("button.sm.font.size"), ";\n    padding: ").concat(dt2("button.sm.padding.y"), " ").concat(dt2("button.sm.padding.x"), ";\n}\n\n.p-button-sm .p-button-icon {\n    font-size: ").concat(dt2("button.sm.font.size"), ";\n}\n\n.p-button-lg {\n    font-size: ").concat(dt2("button.lg.font.size"), ";\n    padding: ").concat(dt2("button.lg.padding.y"), " ").concat(dt2("button.lg.padding.x"), ";\n}\n\n.p-button-lg .p-button-icon {\n    font-size: ").concat(dt2("button.lg.font.size"), ";\n}\n\n.p-button-vertical {\n    flex-direction: column;\n}\n\n.p-button-label {\n    font-weight: ").concat(dt2("button.label.font.weight"), ";\n}\n\n.p-button-fluid {\n    width: 100%;\n}\n\n.p-button-fluid.p-button-icon-only {\n    width: ").concat(dt2("button.icon.only.width"), ";\n}\n\n.p-button:not(:disabled):hover {\n    background: ").concat(dt2("button.primary.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.primary.hover.border.color"), ";\n    color: ").concat(dt2("button.primary.hover.color"), ";\n}\n\n.p-button:not(:disabled):active {\n    background: ").concat(dt2("button.primary.active.background"), ";\n    border: 1px solid ").concat(dt2("button.primary.active.border.color"), ";\n    color: ").concat(dt2("button.primary.active.color"), ";\n}\n\n.p-button:focus-visible {\n    box-shadow: ").concat(dt2("button.primary.focus.ring.shadow"), ";\n    outline: ").concat(dt2("button.focus.ring.width"), " ").concat(dt2("button.focus.ring.style"), " ").concat(dt2("button.primary.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("button.focus.ring.offset"), ";\n}\n\n.p-button .p-badge {\n    min-width: ").concat(dt2("button.badge.size"), ";\n    height: ").concat(dt2("button.badge.size"), ";\n    line-height: ").concat(dt2("button.badge.size"), ";\n}\n\n.p-button-raised {\n    box-shadow: ").concat(dt2("button.raised.shadow"), ";\n}\n\n.p-button-rounded {\n    border-radius: ").concat(dt2("button.rounded.border.radius"), ";\n}\n\n.p-button-secondary {\n    background: ").concat(dt2("button.secondary.background"), ";\n    border: 1px solid ").concat(dt2("button.secondary.border.color"), ";\n    color: ").concat(dt2("button.secondary.color"), ";\n}\n\n.p-button-secondary:not(:disabled):hover {\n    background: ").concat(dt2("button.secondary.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.secondary.hover.border.color"), ";\n    color: ").concat(dt2("button.secondary.hover.color"), ";\n}\n\n.p-button-secondary:not(:disabled):active {\n    background: ").concat(dt2("button.secondary.active.background"), ";\n    border: 1px solid ").concat(dt2("button.secondary.active.border.color"), ";\n    color: ").concat(dt2("button.secondary.active.color"), ";\n}\n\n.p-button-secondary:focus-visible {\n    outline-color: ").concat(dt2("button.secondary.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.secondary.focus.ring.shadow"), ";\n}\n\n.p-button-success {\n    background: ").concat(dt2("button.success.background"), ";\n    border: 1px solid ").concat(dt2("button.success.border.color"), ";\n    color: ").concat(dt2("button.success.color"), ";\n}\n\n.p-button-success:not(:disabled):hover {\n    background: ").concat(dt2("button.success.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.success.hover.border.color"), ";\n    color: ").concat(dt2("button.success.hover.color"), ";\n}\n\n.p-button-success:not(:disabled):active {\n    background: ").concat(dt2("button.success.active.background"), ";\n    border: 1px solid ").concat(dt2("button.success.active.border.color"), ";\n    color: ").concat(dt2("button.success.active.color"), ";\n}\n\n.p-button-success:focus-visible {\n    outline-color: ").concat(dt2("button.success.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.success.focus.ring.shadow"), ";\n}\n\n.p-button-info {\n    background: ").concat(dt2("button.info.background"), ";\n    border: 1px solid ").concat(dt2("button.info.border.color"), ";\n    color: ").concat(dt2("button.info.color"), ";\n}\n\n.p-button-info:not(:disabled):hover {\n    background: ").concat(dt2("button.info.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.info.hover.border.color"), ";\n    color: ").concat(dt2("button.info.hover.color"), ";\n}\n\n.p-button-info:not(:disabled):active {\n    background: ").concat(dt2("button.info.active.background"), ";\n    border: 1px solid ").concat(dt2("button.info.active.border.color"), ";\n    color: ").concat(dt2("button.info.active.color"), ";\n}\n\n.p-button-info:focus-visible {\n    outline-color: ").concat(dt2("button.info.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.info.focus.ring.shadow"), ";\n}\n\n.p-button-warn {\n    background: ").concat(dt2("button.warn.background"), ";\n    border: 1px solid ").concat(dt2("button.warn.border.color"), ";\n    color: ").concat(dt2("button.warn.color"), ";\n}\n\n.p-button-warn:not(:disabled):hover {\n    background: ").concat(dt2("button.warn.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.warn.hover.border.color"), ";\n    color: ").concat(dt2("button.warn.hover.color"), ";\n}\n\n.p-button-warn:not(:disabled):active {\n    background: ").concat(dt2("button.warn.active.background"), ";\n    border: 1px solid ").concat(dt2("button.warn.active.border.color"), ";\n    color: ").concat(dt2("button.warn.active.color"), ";\n}\n\n.p-button-warn:focus-visible {\n    outline-color: ").concat(dt2("button.warn.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.warn.focus.ring.shadow"), ";\n}\n\n.p-button-help {\n    background: ").concat(dt2("button.help.background"), ";\n    border: 1px solid ").concat(dt2("button.help.border.color"), ";\n    color: ").concat(dt2("button.help.color"), ";\n}\n\n.p-button-help:not(:disabled):hover {\n    background: ").concat(dt2("button.help.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.help.hover.border.color"), ";\n    color: ").concat(dt2("button.help.hover.color"), ";\n}\n\n.p-button-help:not(:disabled):active {\n    background: ").concat(dt2("button.help.active.background"), ";\n    border: 1px solid ").concat(dt2("button.help.active.border.color"), ";\n    color: ").concat(dt2("button.help.active.color"), ";\n}\n\n.p-button-help:focus-visible {\n    outline-color: ").concat(dt2("button.help.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.help.focus.ring.shadow"), ";\n}\n\n.p-button-danger {\n    background: ").concat(dt2("button.danger.background"), ";\n    border: 1px solid ").concat(dt2("button.danger.border.color"), ";\n    color: ").concat(dt2("button.danger.color"), ";\n}\n\n.p-button-danger:not(:disabled):hover {\n    background: ").concat(dt2("button.danger.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.danger.hover.border.color"), ";\n    color: ").concat(dt2("button.danger.hover.color"), ";\n}\n\n.p-button-danger:not(:disabled):active {\n    background: ").concat(dt2("button.danger.active.background"), ";\n    border: 1px solid ").concat(dt2("button.danger.active.border.color"), ";\n    color: ").concat(dt2("button.danger.active.color"), ";\n}\n\n.p-button-danger:focus-visible {\n    outline-color: ").concat(dt2("button.danger.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.danger.focus.ring.shadow"), ";\n}\n\n.p-button-contrast {\n    background: ").concat(dt2("button.contrast.background"), ";\n    border: 1px solid ").concat(dt2("button.contrast.border.color"), ";\n    color: ").concat(dt2("button.contrast.color"), ";\n}\n\n.p-button-contrast:not(:disabled):hover {\n    background: ").concat(dt2("button.contrast.hover.background"), ";\n    border: 1px solid ").concat(dt2("button.contrast.hover.border.color"), ";\n    color: ").concat(dt2("button.contrast.hover.color"), ";\n}\n\n.p-button-contrast:not(:disabled):active {\n    background: ").concat(dt2("button.contrast.active.background"), ";\n    border: 1px solid ").concat(dt2("button.contrast.active.border.color"), ";\n    color: ").concat(dt2("button.contrast.active.color"), ";\n}\n\n.p-button-contrast:focus-visible {\n    outline-color: ").concat(dt2("button.contrast.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("button.contrast.focus.ring.shadow"), ";\n}\n\n.p-button-outlined {\n    background: transparent;\n    border-color: ").concat(dt2("button.outlined.primary.border.color"), ";\n    color: ").concat(dt2("button.outlined.primary.color"), ";\n}\n\n.p-button-outlined:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.primary.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.primary.border.color"), ";\n    color: ").concat(dt2("button.outlined.primary.color"), ";\n}\n\n.p-button-outlined:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.primary.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.primary.border.color"), ";\n    color: ").concat(dt2("button.outlined.primary.color"), ";\n}\n\n.p-button-outlined.p-button-secondary {\n    border-color: ").concat(dt2("button.outlined.secondary.border.color"), ";\n    color: ").concat(dt2("button.outlined.secondary.color"), ";\n}\n\n.p-button-outlined.p-button-secondary:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.secondary.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.secondary.border.color"), ";\n    color: ").concat(dt2("button.outlined.secondary.color"), ";\n}\n\n.p-button-outlined.p-button-secondary:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.secondary.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.secondary.border.color"), ";\n    color: ").concat(dt2("button.outlined.secondary.color"), ";\n}\n\n.p-button-outlined.p-button-success {\n    border-color: ").concat(dt2("button.outlined.success.border.color"), ";\n    color: ").concat(dt2("button.outlined.success.color"), ";\n}\n\n.p-button-outlined.p-button-success:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.success.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.success.border.color"), ";\n    color: ").concat(dt2("button.outlined.success.color"), ";\n}\n\n.p-button-outlined.p-button-success:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.success.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.success.border.color"), ";\n    color: ").concat(dt2("button.outlined.success.color"), ";\n}\n\n.p-button-outlined.p-button-info {\n    border-color: ").concat(dt2("button.outlined.info.border.color"), ";\n    color: ").concat(dt2("button.outlined.info.color"), ";\n}\n\n.p-button-outlined.p-button-info:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.info.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.info.border.color"), ";\n    color: ").concat(dt2("button.outlined.info.color"), ";\n}\n\n.p-button-outlined.p-button-info:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.info.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.info.border.color"), ";\n    color: ").concat(dt2("button.outlined.info.color"), ";\n}\n\n.p-button-outlined.p-button-warn {\n    border-color: ").concat(dt2("button.outlined.warn.border.color"), ";\n    color: ").concat(dt2("button.outlined.warn.color"), ";\n}\n\n.p-button-outlined.p-button-warn:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.warn.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.warn.border.color"), ";\n    color: ").concat(dt2("button.outlined.warn.color"), ";\n}\n\n.p-button-outlined.p-button-warn:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.warn.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.warn.border.color"), ";\n    color: ").concat(dt2("button.outlined.warn.color"), ";\n}\n\n.p-button-outlined.p-button-help {\n    border-color: ").concat(dt2("button.outlined.help.border.color"), ";\n    color: ").concat(dt2("button.outlined.help.color"), ";\n}\n\n.p-button-outlined.p-button-help:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.help.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.help.border.color"), ";\n    color: ").concat(dt2("button.outlined.help.color"), ";\n}\n\n.p-button-outlined.p-button-help:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.help.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.help.border.color"), ";\n    color: ").concat(dt2("button.outlined.help.color"), ";\n}\n\n.p-button-outlined.p-button-danger {\n    border-color: ").concat(dt2("button.outlined.danger.border.color"), ";\n    color: ").concat(dt2("button.outlined.danger.color"), ";\n}\n\n.p-button-outlined.p-button-danger:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.danger.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.danger.border.color"), ";\n    color: ").concat(dt2("button.outlined.danger.color"), ";\n}\n\n.p-button-outlined.p-button-danger:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.danger.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.danger.border.color"), ";\n    color: ").concat(dt2("button.outlined.danger.color"), ";\n}\n\n.p-button-outlined.p-button-contrast {\n    border-color: ").concat(dt2("button.outlined.contrast.border.color"), ";\n    color: ").concat(dt2("button.outlined.contrast.color"), ";\n}\n\n.p-button-outlined.p-button-contrast:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.contrast.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.contrast.border.color"), ";\n    color: ").concat(dt2("button.outlined.contrast.color"), ";\n}\n\n.p-button-outlined.p-button-contrast:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.contrast.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.contrast.border.color"), ";\n    color: ").concat(dt2("button.outlined.contrast.color"), ";\n}\n\n.p-button-outlined.p-button-plain {\n    border-color: ").concat(dt2("button.outlined.plain.border.color"), ";\n    color: ").concat(dt2("button.outlined.plain.color"), ";\n}\n\n.p-button-outlined.p-button-plain:not(:disabled):hover {\n    background: ").concat(dt2("button.outlined.plain.hover.background"), ";\n    border-color: ").concat(dt2("button.outlined.plain.border.color"), ";\n    color: ").concat(dt2("button.outlined.plain.color"), ";\n}\n\n.p-button-outlined.p-button-plain:not(:disabled):active {\n    background: ").concat(dt2("button.outlined.plain.active.background"), ";\n    border-color: ").concat(dt2("button.outlined.plain.border.color"), ";\n    color: ").concat(dt2("button.outlined.plain.color"), ";\n}\n\n.p-button-text {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.primary.color"), ";\n}\n\n.p-button-text:not(:disabled):hover {\n    background: ").concat(dt2("button.text.primary.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.primary.color"), ";\n}\n\n.p-button-text:not(:disabled):active {\n    background: ").concat(dt2("button.text.primary.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.primary.color"), ";\n}\n\n.p-button-text.p-button-secondary {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.secondary.color"), ";\n}\n\n.p-button-text.p-button-secondary:not(:disabled):hover {\n    background: ").concat(dt2("button.text.secondary.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.secondary.color"), ";\n}\n\n.p-button-text.p-button-secondary:not(:disabled):active {\n    background: ").concat(dt2("button.text.secondary.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.secondary.color"), ";\n}\n\n.p-button-text.p-button-success {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.success.color"), ";\n}\n\n.p-button-text.p-button-success:not(:disabled):hover {\n    background: ").concat(dt2("button.text.success.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.success.color"), ";\n}\n\n.p-button-text.p-button-success:not(:disabled):active {\n    background: ").concat(dt2("button.text.success.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.success.color"), ";\n}\n\n.p-button-text.p-button-info {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.info.color"), ";\n}\n\n.p-button-text.p-button-info:not(:disabled):hover {\n    background: ").concat(dt2("button.text.info.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.info.color"), ";\n}\n\n.p-button-text.p-button-info:not(:disabled):active {\n    background: ").concat(dt2("button.text.info.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.info.color"), ";\n}\n\n.p-button-text.p-button-warn {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.warn.color"), ";\n}\n\n.p-button-text.p-button-warn:not(:disabled):hover {\n    background: ").concat(dt2("button.text.warn.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.warn.color"), ";\n}\n\n.p-button-text.p-button-warn:not(:disabled):active {\n    background: ").concat(dt2("button.text.warn.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.warn.color"), ";\n}\n\n.p-button-text.p-button-help {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.help.color"), ";\n}\n\n.p-button-text.p-button-help:not(:disabled):hover {\n    background: ").concat(dt2("button.text.help.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.help.color"), ";\n}\n\n.p-button-text.p-button-help:not(:disabled):active {\n    background: ").concat(dt2("button.text.help.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.help.color"), ";\n}\n\n.p-button-text.p-button-danger {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.danger.color"), ";\n}\n\n.p-button-text.p-button-danger:not(:disabled):hover {\n    background: ").concat(dt2("button.text.danger.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.danger.color"), ";\n}\n\n.p-button-text.p-button-danger:not(:disabled):active {\n    background: ").concat(dt2("button.text.danger.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.danger.color"), ";\n}\n\n.p-button-text.p-button-contrast {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.contrast.color"), ";\n}\n\n.p-button-text.p-button-contrast:not(:disabled):hover {\n    background: ").concat(dt2("button.text.contrast.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.contrast.color"), ";\n}\n\n.p-button-text.p-button-contrast:not(:disabled):active {\n    background: ").concat(dt2("button.text.contrast.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.contrast.color"), ";\n}\n\n.p-button-text.p-button-plain {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.text.plain.color"), ";\n}\n\n.p-button-text.p-button-plain:not(:disabled):hover {\n    background: ").concat(dt2("button.text.plain.hover.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.plain.color"), ";\n}\n\n.p-button-text.p-button-plain:not(:disabled):active {\n    background: ").concat(dt2("button.text.plain.active.background"), ";\n    border-color: transparent;\n    color: ").concat(dt2("button.text.plain.color"), ";\n}\n\n.p-button-link {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.link.color"), ";\n}\n\n.p-button-link:not(:disabled):hover {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.link.hover.color"), ";\n}\n\n.p-button-link:not(:disabled):hover .p-button-label {\n    text-decoration: underline;\n}\n\n.p-button-link:not(:disabled):active {\n    background: transparent;\n    border-color: transparent;\n    color: ").concat(dt2("button.link.active.color"), ";\n}\n");
}, "theme");
var classes$I = {
  root: /* @__PURE__ */ __name(function root3(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-button p-component", _defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n(_defineProperty$n({
      "p-button-icon-only": instance.hasIcon && !props.label && !props.badge,
      "p-button-vertical": (props.iconPos === "top" || props.iconPos === "bottom") && props.label,
      "p-button-loading": props.loading,
      "p-button-link": props.link || props.variant === "link"
    }, "p-button-".concat(props.severity), props.severity), "p-button-raised", props.raised), "p-button-rounded", props.rounded), "p-button-text", props.text || props.variant === "text"), "p-button-outlined", props.outlined || props.variant === "outlined"), "p-button-sm", props.size === "small"), "p-button-lg", props.size === "large"), "p-button-plain", props.plain), "p-button-fluid", instance.hasFluid)];
  }, "root"),
  loadingIcon: "p-button-loading-icon",
  icon: /* @__PURE__ */ __name(function icon2(_ref4) {
    var props = _ref4.props;
    return ["p-button-icon", _defineProperty$n({}, "p-button-icon-".concat(props.iconPos), props.label)];
  }, "icon"),
  label: "p-button-label"
};
var ButtonStyle = BaseStyle$1.extend({
  name: "button",
  theme: theme$C,
  classes: classes$I
});
var script$1$I = {
  name: "BaseButton",
  "extends": script$1b,
  props: {
    label: {
      type: String,
      "default": null
    },
    icon: {
      type: String,
      "default": null
    },
    iconPos: {
      type: String,
      "default": "left"
    },
    iconClass: {
      type: [String, Object],
      "default": null
    },
    badge: {
      type: String,
      "default": null
    },
    badgeClass: {
      type: [String, Object],
      "default": null
    },
    badgeSeverity: {
      type: String,
      "default": "secondary"
    },
    loading: {
      type: Boolean,
      "default": false
    },
    loadingIcon: {
      type: String,
      "default": void 0
    },
    as: {
      type: [String, Object],
      "default": "BUTTON"
    },
    asChild: {
      type: Boolean,
      "default": false
    },
    link: {
      type: Boolean,
      "default": false
    },
    severity: {
      type: String,
      "default": null
    },
    raised: {
      type: Boolean,
      "default": false
    },
    rounded: {
      type: Boolean,
      "default": false
    },
    text: {
      type: Boolean,
      "default": false
    },
    outlined: {
      type: Boolean,
      "default": false
    },
    size: {
      type: String,
      "default": null
    },
    variant: {
      type: String,
      "default": null
    },
    plain: {
      type: Boolean,
      "default": false
    },
    fluid: {
      type: Boolean,
      "default": null
    }
  },
  style: ButtonStyle,
  provide: /* @__PURE__ */ __name(function provide6() {
    return {
      $pcButton: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$10 = {
  name: "Button",
  "extends": script$1$I,
  inheritAttrs: false,
  inject: {
    $pcFluid: {
      "default": null
    }
  },
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions(key) {
      var _ptm = key === "root" ? this.ptmi : this.ptm;
      return _ptm(key, {
        context: {
          disabled: this.disabled
        }
      });
    }, "getPTOptions")
  },
  computed: {
    disabled: /* @__PURE__ */ __name(function disabled() {
      return this.$attrs.disabled || this.$attrs.disabled === "" || this.loading;
    }, "disabled"),
    defaultAriaLabel: /* @__PURE__ */ __name(function defaultAriaLabel() {
      return this.label ? this.label + (this.badge ? " " + this.badge : "") : this.$attrs.ariaLabel;
    }, "defaultAriaLabel"),
    hasIcon: /* @__PURE__ */ __name(function hasIcon() {
      return this.icon || this.$slots.icon;
    }, "hasIcon"),
    attrs: /* @__PURE__ */ __name(function attrs2() {
      return mergeProps$2(this.asAttrs, this.a11yAttrs, this.getPTOptions("root"));
    }, "attrs"),
    asAttrs: /* @__PURE__ */ __name(function asAttrs() {
      return this.as === "BUTTON" ? {
        type: "button",
        disabled: this.disabled
      } : void 0;
    }, "asAttrs"),
    a11yAttrs: /* @__PURE__ */ __name(function a11yAttrs() {
      return {
        "aria-label": this.defaultAriaLabel,
        "data-pc-name": "button",
        "data-p-disabled": this.disabled,
        "data-p-severity": this.severity
      };
    }, "a11yAttrs"),
    hasFluid: /* @__PURE__ */ __name(function hasFluid2() {
      return isEmpty$3(this.fluid) ? !!this.$pcFluid : this.fluid;
    }, "hasFluid")
  },
  components: {
    SpinnerIcon: script$12,
    Badge: script$11
  },
  directives: {
    ripple: Ripple
  }
};
function render$Z(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_Badge = resolveComponent("Badge");
  var _directive_ripple = resolveDirective("ripple");
  return !_ctx.asChild ? withDirectives((openBlock(), createBlock(resolveDynamicComponent(_ctx.as), mergeProps$2({
    key: 0,
    "class": _ctx.cx("root")
  }, $options.attrs), {
    "default": withCtx(function() {
      return [renderSlot(_ctx.$slots, "default", {}, function() {
        return [_ctx.loading ? renderSlot(_ctx.$slots, "loadingicon", mergeProps$2({
          key: 0,
          "class": [_ctx.cx("loadingIcon"), _ctx.cx("icon")]
        }, _ctx.ptm("loadingIcon")), function() {
          return [_ctx.loadingIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
            key: 0,
            "class": [_ctx.cx("loadingIcon"), _ctx.cx("icon"), _ctx.loadingIcon]
          }, _ctx.ptm("loadingIcon")), null, 16)) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
            key: 1,
            "class": [_ctx.cx("loadingIcon"), _ctx.cx("icon")],
            spin: ""
          }, _ctx.ptm("loadingIcon")), null, 16, ["class"]))];
        }) : renderSlot(_ctx.$slots, "icon", mergeProps$2({
          key: 1,
          "class": [_ctx.cx("icon")]
        }, _ctx.ptm("icon")), function() {
          return [_ctx.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
            key: 0,
            "class": [_ctx.cx("icon"), _ctx.icon, _ctx.iconClass]
          }, _ctx.ptm("icon")), null, 16)) : createCommentVNode("", true)];
        }), createBaseVNode("span", mergeProps$2({
          "class": _ctx.cx("label")
        }, _ctx.ptm("label")), toDisplayString$1(_ctx.label || " "), 17), _ctx.badge ? (openBlock(), createBlock(_component_Badge, {
          key: 2,
          value: _ctx.badge,
          "class": normalizeClass(_ctx.badgeClass),
          severity: _ctx.badgeSeverity,
          unstyled: _ctx.unstyled,
          pt: _ctx.ptm("pcBadge")
        }, null, 8, ["value", "class", "severity", "unstyled", "pt"])) : createCommentVNode("", true)];
      })];
    }),
    _: 3
  }, 16, ["class"])), [[_directive_ripple]]) : renderSlot(_ctx.$slots, "default", {
    key: 1,
    "class": normalizeClass(_ctx.cx("root")),
    a11yAttrs: $options.a11yAttrs
  });
}
__name(render$Z, "render$Z");
script$10.render = render$Z;
var FocusTrapStyle = BaseStyle$1.extend({
  name: "focustrap-directive"
});
var BaseFocusTrap = BaseDirective.extend({
  style: FocusTrapStyle
});
function _typeof$k(o2) {
  "@babel/helpers - typeof";
  return _typeof$k = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$k(o2);
}
__name(_typeof$k, "_typeof$k");
function ownKeys$m(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$m, "ownKeys$m");
function _objectSpread$m(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$m(Object(t2), true).forEach(function(r3) {
      _defineProperty$m(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$m(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$m, "_objectSpread$m");
function _defineProperty$m(e2, r2, t2) {
  return (r2 = _toPropertyKey$j(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$m, "_defineProperty$m");
function _toPropertyKey$j(t2) {
  var i2 = _toPrimitive$j(t2, "string");
  return "symbol" == _typeof$k(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$j, "_toPropertyKey$j");
function _toPrimitive$j(t2, r2) {
  if ("object" != _typeof$k(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$k(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$j, "_toPrimitive$j");
var FocusTrap = BaseFocusTrap.extend("focustrap", {
  mounted: /* @__PURE__ */ __name(function mounted3(el, binding) {
    var _ref = binding.value || {}, disabled3 = _ref.disabled;
    if (!disabled3) {
      this.createHiddenFocusableElements(el, binding);
      this.bind(el, binding);
      this.autoElementFocus(el, binding);
    }
    el.setAttribute("data-pd-focustrap", true);
    this.$el = el;
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated3(el, binding) {
    var _ref2 = binding.value || {}, disabled3 = _ref2.disabled;
    disabled3 && this.unbind(el);
  }, "updated"),
  unmounted: /* @__PURE__ */ __name(function unmounted4(el) {
    this.unbind(el);
  }, "unmounted"),
  methods: {
    getComputedSelector: /* @__PURE__ */ __name(function getComputedSelector(selector) {
      return ':not(.p-hidden-focusable):not([data-p-hidden-focusable="true"])'.concat(selector !== null && selector !== void 0 ? selector : "");
    }, "getComputedSelector"),
    bind: /* @__PURE__ */ __name(function bind2(el, binding) {
      var _this = this;
      var _ref3 = binding.value || {}, onFocusIn = _ref3.onFocusIn, onFocusOut = _ref3.onFocusOut;
      el.$_pfocustrap_mutationobserver = new MutationObserver(function(mutationList) {
        mutationList.forEach(function(mutation) {
          if (mutation.type === "childList" && !el.contains(document.activeElement)) {
            var _findNextFocusableElement = /* @__PURE__ */ __name(function findNextFocusableElement(_el) {
              var focusableElement = isFocusableElement$1(_el) ? isFocusableElement$1(_el, _this.getComputedSelector(el.$_pfocustrap_focusableselector)) ? _el : getFirstFocusableElement$1(el, _this.getComputedSelector(el.$_pfocustrap_focusableselector)) : getFirstFocusableElement$1(_el);
              return isNotEmpty$2(focusableElement) ? focusableElement : _el.nextSibling && _findNextFocusableElement(_el.nextSibling);
            }, "findNextFocusableElement");
            focus$2(_findNextFocusableElement(mutation.nextSibling));
          }
        });
      });
      el.$_pfocustrap_mutationobserver.disconnect();
      el.$_pfocustrap_mutationobserver.observe(el, {
        childList: true
      });
      el.$_pfocustrap_focusinlistener = function(event) {
        return onFocusIn && onFocusIn(event);
      };
      el.$_pfocustrap_focusoutlistener = function(event) {
        return onFocusOut && onFocusOut(event);
      };
      el.addEventListener("focusin", el.$_pfocustrap_focusinlistener);
      el.addEventListener("focusout", el.$_pfocustrap_focusoutlistener);
    }, "bind"),
    unbind: /* @__PURE__ */ __name(function unbind(el) {
      el.$_pfocustrap_mutationobserver && el.$_pfocustrap_mutationobserver.disconnect();
      el.$_pfocustrap_focusinlistener && el.removeEventListener("focusin", el.$_pfocustrap_focusinlistener) && (el.$_pfocustrap_focusinlistener = null);
      el.$_pfocustrap_focusoutlistener && el.removeEventListener("focusout", el.$_pfocustrap_focusoutlistener) && (el.$_pfocustrap_focusoutlistener = null);
    }, "unbind"),
    autoFocus: /* @__PURE__ */ __name(function autoFocus(options5) {
      this.autoElementFocus(this.$el, {
        value: _objectSpread$m(_objectSpread$m({}, options5), {}, {
          autoFocus: true
        })
      });
    }, "autoFocus"),
    autoElementFocus: /* @__PURE__ */ __name(function autoElementFocus(el, binding) {
      var _ref4 = binding.value || {}, _ref4$autoFocusSelect = _ref4.autoFocusSelector, autoFocusSelector = _ref4$autoFocusSelect === void 0 ? "" : _ref4$autoFocusSelect, _ref4$firstFocusableS = _ref4.firstFocusableSelector, firstFocusableSelector = _ref4$firstFocusableS === void 0 ? "" : _ref4$firstFocusableS, _ref4$autoFocus = _ref4.autoFocus, autoFocus2 = _ref4$autoFocus === void 0 ? false : _ref4$autoFocus;
      var focusableElement = getFirstFocusableElement$1(el, "[autofocus]".concat(this.getComputedSelector(autoFocusSelector)));
      autoFocus2 && !focusableElement && (focusableElement = getFirstFocusableElement$1(el, this.getComputedSelector(firstFocusableSelector)));
      focus$2(focusableElement);
    }, "autoElementFocus"),
    onFirstHiddenElementFocus: /* @__PURE__ */ __name(function onFirstHiddenElementFocus(event) {
      var _this$$el;
      var currentTarget = event.currentTarget, relatedTarget = event.relatedTarget;
      var focusableElement = relatedTarget === currentTarget.$_pfocustrap_lasthiddenfocusableelement || !((_this$$el = this.$el) !== null && _this$$el !== void 0 && _this$$el.contains(relatedTarget)) ? getFirstFocusableElement$1(currentTarget.parentElement, this.getComputedSelector(currentTarget.$_pfocustrap_focusableselector)) : currentTarget.$_pfocustrap_lasthiddenfocusableelement;
      focus$2(focusableElement);
    }, "onFirstHiddenElementFocus"),
    onLastHiddenElementFocus: /* @__PURE__ */ __name(function onLastHiddenElementFocus(event) {
      var _this$$el2;
      var currentTarget = event.currentTarget, relatedTarget = event.relatedTarget;
      var focusableElement = relatedTarget === currentTarget.$_pfocustrap_firsthiddenfocusableelement || !((_this$$el2 = this.$el) !== null && _this$$el2 !== void 0 && _this$$el2.contains(relatedTarget)) ? getLastFocusableElement$1(currentTarget.parentElement, this.getComputedSelector(currentTarget.$_pfocustrap_focusableselector)) : currentTarget.$_pfocustrap_firsthiddenfocusableelement;
      focus$2(focusableElement);
    }, "onLastHiddenElementFocus"),
    createHiddenFocusableElements: /* @__PURE__ */ __name(function createHiddenFocusableElements(el, binding) {
      var _this2 = this;
      var _ref5 = binding.value || {}, _ref5$tabIndex = _ref5.tabIndex, tabIndex = _ref5$tabIndex === void 0 ? 0 : _ref5$tabIndex, _ref5$firstFocusableS = _ref5.firstFocusableSelector, firstFocusableSelector = _ref5$firstFocusableS === void 0 ? "" : _ref5$firstFocusableS, _ref5$lastFocusableSe = _ref5.lastFocusableSelector, lastFocusableSelector = _ref5$lastFocusableSe === void 0 ? "" : _ref5$lastFocusableSe;
      var createFocusableElement = /* @__PURE__ */ __name(function createFocusableElement2(onFocus10) {
        return createElement$1("span", {
          "class": "p-hidden-accessible p-hidden-focusable",
          tabIndex,
          role: "presentation",
          "aria-hidden": true,
          "data-p-hidden-accessible": true,
          "data-p-hidden-focusable": true,
          onFocus: onFocus10 === null || onFocus10 === void 0 ? void 0 : onFocus10.bind(_this2)
        });
      }, "createFocusableElement");
      var firstFocusableElement = createFocusableElement(this.onFirstHiddenElementFocus);
      var lastFocusableElement = createFocusableElement(this.onLastHiddenElementFocus);
      firstFocusableElement.$_pfocustrap_lasthiddenfocusableelement = lastFocusableElement;
      firstFocusableElement.$_pfocustrap_focusableselector = firstFocusableSelector;
      firstFocusableElement.setAttribute("data-pc-section", "firstfocusableelement");
      lastFocusableElement.$_pfocustrap_firsthiddenfocusableelement = firstFocusableElement;
      lastFocusableElement.$_pfocustrap_focusableselector = lastFocusableSelector;
      lastFocusableElement.setAttribute("data-pc-section", "lastfocusableelement");
      el.prepend(firstFocusableElement);
      el.append(lastFocusableElement);
    }, "createHiddenFocusableElements")
  }
});
var script$$ = {
  name: "Portal",
  props: {
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    disabled: {
      type: Boolean,
      "default": false
    }
  },
  data: /* @__PURE__ */ __name(function data3() {
    return {
      mounted: false
    };
  }, "data"),
  mounted: /* @__PURE__ */ __name(function mounted4() {
    this.mounted = isClient$2();
  }, "mounted"),
  computed: {
    inline: /* @__PURE__ */ __name(function inline2() {
      return this.disabled || this.appendTo === "self";
    }, "inline")
  }
};
function render$Y(_ctx, _cache, $props, $setup, $data, $options) {
  return $options.inline ? renderSlot(_ctx.$slots, "default", {
    key: 0
  }) : $data.mounted ? (openBlock(), createBlock(Teleport, {
    key: 1,
    to: $props.appendTo
  }, [renderSlot(_ctx.$slots, "default")], 8, ["to"])) : createCommentVNode("", true);
}
__name(render$Y, "render$Y");
script$$.render = render$Y;
var theme$B = /* @__PURE__ */ __name(function theme9(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-dialog {\n    max-height: 90%;\n    transform: scale(1);\n    border-radius: ".concat(dt2("dialog.border.radius"), ";\n    box-shadow: ").concat(dt2("dialog.shadow"), ";\n    background: ").concat(dt2("dialog.background"), ";\n    border: 1px solid ").concat(dt2("dialog.border.color"), ";\n    color: ").concat(dt2("dialog.color"), ";\n}\n\n.p-dialog-content {\n    overflow-y: auto;\n    padding: ").concat(dt2("dialog.content.padding"), ";\n}\n\n.p-dialog-header {\n    display: flex;\n    align-items: center;\n    justify-content: space-between;\n    flex-shrink: 0;\n    padding: ").concat(dt2("dialog.header.padding"), ";\n}\n\n.p-dialog-title {\n    font-weight: ").concat(dt2("dialog.title.font.weight"), ";\n    font-size: ").concat(dt2("dialog.title.font.size"), ";\n}\n\n.p-dialog-footer {\n    flex-shrink: 0;\n    padding: ").concat(dt2("dialog.footer.padding"), ";\n    display: flex;\n    justify-content: flex-end;\n    gap: ").concat(dt2("dialog.footer.gap"), ";\n}\n\n.p-dialog-header-actions {\n    display: flex;\n    align-items: center;\n    gap: ").concat(dt2("dialog.header.gap"), ";\n}\n\n.p-dialog-enter-active {\n    transition: all 150ms cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-dialog-leave-active {\n    transition: all 150ms cubic-bezier(0.4, 0, 0.2, 1);\n}\n\n.p-dialog-enter-from,\n.p-dialog-leave-to {\n    opacity: 0;\n    transform: scale(0.7);\n}\n\n.p-dialog-top .p-dialog,\n.p-dialog-bottom .p-dialog,\n.p-dialog-left .p-dialog,\n.p-dialog-right .p-dialog,\n.p-dialog-topleft .p-dialog,\n.p-dialog-topright .p-dialog,\n.p-dialog-bottomleft .p-dialog,\n.p-dialog-bottomright .p-dialog {\n    margin: 0.75rem;\n    transform: translate3d(0px, 0px, 0px);\n}\n\n.p-dialog-top .p-dialog-enter-active,\n.p-dialog-top .p-dialog-leave-active,\n.p-dialog-bottom .p-dialog-enter-active,\n.p-dialog-bottom .p-dialog-leave-active,\n.p-dialog-left .p-dialog-enter-active,\n.p-dialog-left .p-dialog-leave-active,\n.p-dialog-right .p-dialog-enter-active,\n.p-dialog-right .p-dialog-leave-active,\n.p-dialog-topleft .p-dialog-enter-active,\n.p-dialog-topleft .p-dialog-leave-active,\n.p-dialog-topright .p-dialog-enter-active,\n.p-dialog-topright .p-dialog-leave-active,\n.p-dialog-bottomleft .p-dialog-enter-active,\n.p-dialog-bottomleft .p-dialog-leave-active,\n.p-dialog-bottomright .p-dialog-enter-active,\n.p-dialog-bottomright .p-dialog-leave-active {\n    transition: all 0.3s ease-out;\n}\n\n.p-dialog-top .p-dialog-enter-from,\n.p-dialog-top .p-dialog-leave-to {\n    transform: translate3d(0px, -100%, 0px);\n}\n\n.p-dialog-bottom .p-dialog-enter-from,\n.p-dialog-bottom .p-dialog-leave-to {\n    transform: translate3d(0px, 100%, 0px);\n}\n\n.p-dialog-left .p-dialog-enter-from,\n.p-dialog-left .p-dialog-leave-to,\n.p-dialog-topleft .p-dialog-enter-from,\n.p-dialog-topleft .p-dialog-leave-to,\n.p-dialog-bottomleft .p-dialog-enter-from,\n.p-dialog-bottomleft .p-dialog-leave-to {\n    transform: translate3d(-100%, 0px, 0px);\n}\n\n.p-dialog-right .p-dialog-enter-from,\n.p-dialog-right .p-dialog-leave-to,\n.p-dialog-topright .p-dialog-enter-from,\n.p-dialog-topright .p-dialog-leave-to,\n.p-dialog-bottomright .p-dialog-enter-from,\n.p-dialog-bottomright .p-dialog-leave-to {\n    transform: translate3d(100%, 0px, 0px);\n}\n\n.p-dialog-left:dir(rtl) .p-dialog-enter-from,\n.p-dialog-left:dir(rtl) .p-dialog-leave-to,\n.p-dialog-topleft:dir(rtl) .p-dialog-enter-from,\n.p-dialog-topleft:dir(rtl) .p-dialog-leave-to,\n.p-dialog-bottomleft:dir(rtl) .p-dialog-enter-from,\n.p-dialog-bottomleft:dir(rtl) .p-dialog-leave-to {\n    transform: translate3d(100%, 0px, 0px);\n}\n\n.p-dialog-right:dir(rtl) .p-dialog-enter-from,\n.p-dialog-right:dir(rtl) .p-dialog-leave-to,\n.p-dialog-topright:dir(rtl) .p-dialog-enter-from,\n.p-dialog-topright:dir(rtl) .p-dialog-leave-to,\n.p-dialog-bottomright:dir(rtl) .p-dialog-enter-from,\n.p-dialog-bottomright:dir(rtl) .p-dialog-leave-to {\n    transform: translate3d(-100%, 0px, 0px);\n}\n\n.p-dialog-maximized {\n    width: 100vw !important;\n    height: 100vh !important;\n    top: 0px !important;\n    left: 0px !important;\n    max-height: 100%;\n    height: 100%;\n    border-radius: 0;\n}\n\n.p-dialog-maximized .p-dialog-content {\n    flex-grow: 1;\n}\n");
}, "theme");
var inlineStyles$7 = {
  mask: /* @__PURE__ */ __name(function mask(_ref2) {
    var position3 = _ref2.position, modal2 = _ref2.modal;
    return {
      position: "fixed",
      height: "100%",
      width: "100%",
      left: 0,
      top: 0,
      display: "flex",
      justifyContent: position3 === "left" || position3 === "topleft" || position3 === "bottomleft" ? "flex-start" : position3 === "right" || position3 === "topright" || position3 === "bottomright" ? "flex-end" : "center",
      alignItems: position3 === "top" || position3 === "topleft" || position3 === "topright" ? "flex-start" : position3 === "bottom" || position3 === "bottomleft" || position3 === "bottomright" ? "flex-end" : "center",
      pointerEvents: modal2 ? "auto" : "none"
    };
  }, "mask"),
  root: {
    display: "flex",
    flexDirection: "column",
    pointerEvents: "auto"
  }
};
var classes$H = {
  mask: /* @__PURE__ */ __name(function mask2(_ref3) {
    var props = _ref3.props;
    var positions = ["left", "right", "top", "topleft", "topright", "bottom", "bottomleft", "bottomright"];
    var pos = positions.find(function(item3) {
      return item3 === props.position;
    });
    return ["p-dialog-mask", {
      "p-overlay-mask p-overlay-mask-enter": props.modal
    }, pos ? "p-dialog-".concat(pos) : ""];
  }, "mask"),
  root: /* @__PURE__ */ __name(function root4(_ref4) {
    var props = _ref4.props, instance = _ref4.instance;
    return ["p-dialog p-component", {
      "p-dialog-maximized": props.maximizable && instance.maximized
    }];
  }, "root"),
  header: "p-dialog-header",
  title: "p-dialog-title",
  headerActions: "p-dialog-header-actions",
  pcMaximizeButton: "p-dialog-maximize-button",
  pcCloseButton: "p-dialog-close-button",
  content: "p-dialog-content",
  footer: "p-dialog-footer"
};
var DialogStyle = BaseStyle$1.extend({
  name: "dialog",
  theme: theme$B,
  classes: classes$H,
  inlineStyles: inlineStyles$7
});
var script$1$H = {
  name: "BaseDialog",
  "extends": script$1b,
  props: {
    header: {
      type: null,
      "default": null
    },
    footer: {
      type: null,
      "default": null
    },
    visible: {
      type: Boolean,
      "default": false
    },
    modal: {
      type: Boolean,
      "default": null
    },
    contentStyle: {
      type: null,
      "default": null
    },
    contentClass: {
      type: String,
      "default": null
    },
    contentProps: {
      type: null,
      "default": null
    },
    maximizable: {
      type: Boolean,
      "default": false
    },
    dismissableMask: {
      type: Boolean,
      "default": false
    },
    closable: {
      type: Boolean,
      "default": true
    },
    closeOnEscape: {
      type: Boolean,
      "default": true
    },
    showHeader: {
      type: Boolean,
      "default": true
    },
    blockScroll: {
      type: Boolean,
      "default": false
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    autoZIndex: {
      type: Boolean,
      "default": true
    },
    position: {
      type: String,
      "default": "center"
    },
    breakpoints: {
      type: Object,
      "default": null
    },
    draggable: {
      type: Boolean,
      "default": true
    },
    keepInViewport: {
      type: Boolean,
      "default": true
    },
    minX: {
      type: Number,
      "default": 0
    },
    minY: {
      type: Number,
      "default": 0
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    closeIcon: {
      type: String,
      "default": void 0
    },
    maximizeIcon: {
      type: String,
      "default": void 0
    },
    minimizeIcon: {
      type: String,
      "default": void 0
    },
    closeButtonProps: {
      type: Object,
      "default": /* @__PURE__ */ __name(function _default2() {
        return {
          severity: "secondary",
          text: true,
          rounded: true
        };
      }, "_default")
    },
    maximizeButtonProps: {
      type: Object,
      "default": /* @__PURE__ */ __name(function _default3() {
        return {
          severity: "secondary",
          text: true,
          rounded: true
        };
      }, "_default")
    },
    _instance: null
  },
  style: DialogStyle,
  provide: /* @__PURE__ */ __name(function provide7() {
    return {
      $pcDialog: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$_ = {
  name: "Dialog",
  "extends": script$1$H,
  inheritAttrs: false,
  emits: ["update:visible", "show", "hide", "after-hide", "maximize", "unmaximize", "dragstart", "dragend"],
  provide: /* @__PURE__ */ __name(function provide8() {
    var _this = this;
    return {
      dialogRef: computed(function() {
        return _this._instance;
      })
    };
  }, "provide"),
  data: /* @__PURE__ */ __name(function data4() {
    return {
      id: this.$attrs.id,
      containerVisible: this.visible,
      maximized: false,
      focusableMax: null,
      focusableClose: null,
      target: null
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId")
  },
  documentKeydownListener: null,
  container: null,
  mask: null,
  content: null,
  headerContainer: null,
  footerContainer: null,
  maximizableButton: null,
  closeButton: null,
  styleElement: null,
  dragging: null,
  documentDragListener: null,
  documentDragEndListener: null,
  lastPageX: null,
  lastPageY: null,
  maskMouseDownTarget: null,
  updated: /* @__PURE__ */ __name(function updated4() {
    if (this.visible) {
      this.containerVisible = this.visible;
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount2() {
    this.unbindDocumentState();
    this.unbindGlobalListeners();
    this.destroyStyle();
    if (this.mask && this.autoZIndex) {
      ZIndex$1.clear(this.mask);
    }
    this.container = null;
    this.mask = null;
  }, "beforeUnmount"),
  mounted: /* @__PURE__ */ __name(function mounted5() {
    this.id = this.id || UniqueComponentId();
    if (this.breakpoints) {
      this.createStyle();
    }
  }, "mounted"),
  methods: {
    close: /* @__PURE__ */ __name(function close2() {
      this.$emit("update:visible", false);
    }, "close"),
    onEnter: /* @__PURE__ */ __name(function onEnter() {
      this.$emit("show");
      this.target = document.activeElement;
      this.enableDocumentSettings();
      this.bindGlobalListeners();
      if (this.autoZIndex) {
        ZIndex$1.set("modal", this.mask, this.baseZIndex + this.$primevue.config.zIndex.modal);
      }
    }, "onEnter"),
    onAfterEnter: /* @__PURE__ */ __name(function onAfterEnter() {
      this.focus();
    }, "onAfterEnter"),
    onBeforeLeave: /* @__PURE__ */ __name(function onBeforeLeave() {
      if (this.modal) {
        !this.isUnstyled && addClass$1(this.mask, "p-overlay-mask-leave");
      }
      if (this.dragging && this.documentDragEndListener) {
        this.documentDragEndListener();
      }
    }, "onBeforeLeave"),
    onLeave: /* @__PURE__ */ __name(function onLeave() {
      this.$emit("hide");
      focus$2(this.target);
      this.target = null;
      this.focusableClose = null;
      this.focusableMax = null;
    }, "onLeave"),
    onAfterLeave: /* @__PURE__ */ __name(function onAfterLeave() {
      if (this.autoZIndex) {
        ZIndex$1.clear(this.mask);
      }
      this.containerVisible = false;
      this.unbindDocumentState();
      this.unbindGlobalListeners();
      this.$emit("after-hide");
    }, "onAfterLeave"),
    onMaskMouseDown: /* @__PURE__ */ __name(function onMaskMouseDown(event) {
      this.maskMouseDownTarget = event.target;
    }, "onMaskMouseDown"),
    onMaskMouseUp: /* @__PURE__ */ __name(function onMaskMouseUp() {
      if (this.dismissableMask && this.modal && this.mask === this.maskMouseDownTarget) {
        this.close();
      }
    }, "onMaskMouseUp"),
    focus: /* @__PURE__ */ __name(function focus$12() {
      var findFocusableElement = /* @__PURE__ */ __name(function findFocusableElement2(container) {
        return container && container.querySelector("[autofocus]");
      }, "findFocusableElement");
      var focusTarget = this.$slots.footer && findFocusableElement(this.footerContainer);
      if (!focusTarget) {
        focusTarget = this.$slots.header && findFocusableElement(this.headerContainer);
        if (!focusTarget) {
          focusTarget = this.$slots["default"] && findFocusableElement(this.content);
          if (!focusTarget) {
            if (this.maximizable) {
              this.focusableMax = true;
              focusTarget = this.maximizableButton;
            } else {
              this.focusableClose = true;
              focusTarget = this.closeButton;
            }
          }
        }
      }
      if (focusTarget) {
        focus$2(focusTarget, {
          focusVisible: true
        });
      }
    }, "focus$1"),
    maximize: /* @__PURE__ */ __name(function maximize(event) {
      if (this.maximized) {
        this.maximized = false;
        this.$emit("unmaximize", event);
      } else {
        this.maximized = true;
        this.$emit("maximize", event);
      }
      if (!this.modal) {
        this.maximized ? blockBodyScroll$1() : unblockBodyScroll$1();
      }
    }, "maximize"),
    enableDocumentSettings: /* @__PURE__ */ __name(function enableDocumentSettings() {
      if (this.modal || !this.modal && this.blockScroll || this.maximizable && this.maximized) {
        blockBodyScroll$1();
      }
    }, "enableDocumentSettings"),
    unbindDocumentState: /* @__PURE__ */ __name(function unbindDocumentState() {
      if (this.modal || !this.modal && this.blockScroll || this.maximizable && this.maximized) {
        unblockBodyScroll$1();
      }
    }, "unbindDocumentState"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown2(event) {
      if (event.code === "Escape" && this.closeOnEscape) {
        this.close();
      }
    }, "onKeyDown"),
    bindDocumentKeyDownListener: /* @__PURE__ */ __name(function bindDocumentKeyDownListener() {
      if (!this.documentKeydownListener) {
        this.documentKeydownListener = this.onKeyDown.bind(this);
        window.document.addEventListener("keydown", this.documentKeydownListener);
      }
    }, "bindDocumentKeyDownListener"),
    unbindDocumentKeyDownListener: /* @__PURE__ */ __name(function unbindDocumentKeyDownListener() {
      if (this.documentKeydownListener) {
        window.document.removeEventListener("keydown", this.documentKeydownListener);
        this.documentKeydownListener = null;
      }
    }, "unbindDocumentKeyDownListener"),
    containerRef: /* @__PURE__ */ __name(function containerRef(el) {
      this.container = el;
    }, "containerRef"),
    maskRef: /* @__PURE__ */ __name(function maskRef(el) {
      this.mask = el;
    }, "maskRef"),
    contentRef: /* @__PURE__ */ __name(function contentRef(el) {
      this.content = el;
    }, "contentRef"),
    headerContainerRef: /* @__PURE__ */ __name(function headerContainerRef(el) {
      this.headerContainer = el;
    }, "headerContainerRef"),
    footerContainerRef: /* @__PURE__ */ __name(function footerContainerRef(el) {
      this.footerContainer = el;
    }, "footerContainerRef"),
    maximizableRef: /* @__PURE__ */ __name(function maximizableRef(el) {
      this.maximizableButton = el ? el.$el : void 0;
    }, "maximizableRef"),
    closeButtonRef: /* @__PURE__ */ __name(function closeButtonRef(el) {
      this.closeButton = el ? el.$el : void 0;
    }, "closeButtonRef"),
    createStyle: /* @__PURE__ */ __name(function createStyle() {
      if (!this.styleElement && !this.isUnstyled) {
        var _this$$primevue;
        this.styleElement = document.createElement("style");
        this.styleElement.type = "text/css";
        setAttribute$1(this.styleElement, "nonce", (_this$$primevue = this.$primevue) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.config) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.csp) === null || _this$$primevue === void 0 ? void 0 : _this$$primevue.nonce);
        document.head.appendChild(this.styleElement);
        var innerHTML = "";
        for (var breakpoint in this.breakpoints) {
          innerHTML += "\n                        @media screen and (max-width: ".concat(breakpoint, ") {\n                            .p-dialog[").concat(this.$attrSelector, "] {\n                                width: ").concat(this.breakpoints[breakpoint], " !important;\n                            }\n                        }\n                    ");
        }
        this.styleElement.innerHTML = innerHTML;
      }
    }, "createStyle"),
    destroyStyle: /* @__PURE__ */ __name(function destroyStyle() {
      if (this.styleElement) {
        document.head.removeChild(this.styleElement);
        this.styleElement = null;
      }
    }, "destroyStyle"),
    initDrag: /* @__PURE__ */ __name(function initDrag(event) {
      if (event.target.closest("div").getAttribute("data-pc-section") === "headeractions") {
        return;
      }
      if (this.draggable) {
        this.dragging = true;
        this.lastPageX = event.pageX;
        this.lastPageY = event.pageY;
        this.container.style.margin = "0";
        document.body.setAttribute("data-p-unselectable-text", "true");
        !this.isUnstyled && addStyle$1(document.body, {
          "user-select": "none"
        });
        this.$emit("dragstart", event);
      }
    }, "initDrag"),
    bindGlobalListeners: /* @__PURE__ */ __name(function bindGlobalListeners() {
      if (this.draggable) {
        this.bindDocumentDragListener();
        this.bindDocumentDragEndListener();
      }
      if (this.closeOnEscape && this.closable) {
        this.bindDocumentKeyDownListener();
      }
    }, "bindGlobalListeners"),
    unbindGlobalListeners: /* @__PURE__ */ __name(function unbindGlobalListeners() {
      this.unbindDocumentDragListener();
      this.unbindDocumentDragEndListener();
      this.unbindDocumentKeyDownListener();
    }, "unbindGlobalListeners"),
    bindDocumentDragListener: /* @__PURE__ */ __name(function bindDocumentDragListener() {
      var _this2 = this;
      this.documentDragListener = function(event) {
        if (_this2.dragging) {
          var width2 = getOuterWidth$1(_this2.container);
          var height = getOuterHeight$1(_this2.container);
          var deltaX = event.pageX - _this2.lastPageX;
          var deltaY = event.pageY - _this2.lastPageY;
          var offset = _this2.container.getBoundingClientRect();
          var leftPos = offset.left + deltaX;
          var topPos = offset.top + deltaY;
          var viewport = getViewport$1();
          var containerComputedStyle = getComputedStyle(_this2.container);
          var marginLeft = parseFloat(containerComputedStyle.marginLeft);
          var marginTop = parseFloat(containerComputedStyle.marginTop);
          _this2.container.style.position = "fixed";
          if (_this2.keepInViewport) {
            if (leftPos >= _this2.minX && leftPos + width2 < viewport.width) {
              _this2.lastPageX = event.pageX;
              _this2.container.style.left = leftPos - marginLeft + "px";
            }
            if (topPos >= _this2.minY && topPos + height < viewport.height) {
              _this2.lastPageY = event.pageY;
              _this2.container.style.top = topPos - marginTop + "px";
            }
          } else {
            _this2.lastPageX = event.pageX;
            _this2.container.style.left = leftPos - marginLeft + "px";
            _this2.lastPageY = event.pageY;
            _this2.container.style.top = topPos - marginTop + "px";
          }
        }
      };
      window.document.addEventListener("mousemove", this.documentDragListener);
    }, "bindDocumentDragListener"),
    unbindDocumentDragListener: /* @__PURE__ */ __name(function unbindDocumentDragListener() {
      if (this.documentDragListener) {
        window.document.removeEventListener("mousemove", this.documentDragListener);
        this.documentDragListener = null;
      }
    }, "unbindDocumentDragListener"),
    bindDocumentDragEndListener: /* @__PURE__ */ __name(function bindDocumentDragEndListener() {
      var _this3 = this;
      this.documentDragEndListener = function(event) {
        if (_this3.dragging) {
          _this3.dragging = false;
          document.body.removeAttribute("data-p-unselectable-text");
          !_this3.isUnstyled && (document.body.style["user-select"] = "");
          _this3.$emit("dragend", event);
        }
      };
      window.document.addEventListener("mouseup", this.documentDragEndListener);
    }, "bindDocumentDragEndListener"),
    unbindDocumentDragEndListener: /* @__PURE__ */ __name(function unbindDocumentDragEndListener() {
      if (this.documentDragEndListener) {
        window.document.removeEventListener("mouseup", this.documentDragEndListener);
        this.documentDragEndListener = null;
      }
    }, "unbindDocumentDragEndListener")
  },
  computed: {
    maximizeIconComponent: /* @__PURE__ */ __name(function maximizeIconComponent() {
      return this.maximized ? this.minimizeIcon ? "span" : "WindowMinimizeIcon" : this.maximizeIcon ? "span" : "WindowMaximizeIcon";
    }, "maximizeIconComponent"),
    ariaLabelledById: /* @__PURE__ */ __name(function ariaLabelledById() {
      return this.header != null || this.$attrs["aria-labelledby"] !== null ? this.id + "_header" : null;
    }, "ariaLabelledById"),
    closeAriaLabel: /* @__PURE__ */ __name(function closeAriaLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.close : void 0;
    }, "closeAriaLabel")
  },
  directives: {
    ripple: Ripple,
    focustrap: FocusTrap
  },
  components: {
    Button: script$10,
    Portal: script$$,
    WindowMinimizeIcon: script$13,
    WindowMaximizeIcon: script$14,
    TimesIcon: script$15
  }
};
function _typeof$j(o2) {
  "@babel/helpers - typeof";
  return _typeof$j = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$j(o2);
}
__name(_typeof$j, "_typeof$j");
function ownKeys$l(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$l, "ownKeys$l");
function _objectSpread$l(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$l(Object(t2), true).forEach(function(r3) {
      _defineProperty$l(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$l(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$l, "_objectSpread$l");
function _defineProperty$l(e2, r2, t2) {
  return (r2 = _toPropertyKey$i(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$l, "_defineProperty$l");
function _toPropertyKey$i(t2) {
  var i2 = _toPrimitive$i(t2, "string");
  return "symbol" == _typeof$j(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$i, "_toPropertyKey$i");
function _toPrimitive$i(t2, r2) {
  if ("object" != _typeof$j(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$j(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$i, "_toPrimitive$i");
var _hoisted_1$1N = ["aria-labelledby", "aria-modal"];
var _hoisted_2$1g = ["id"];
function render$X(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Button = resolveComponent("Button");
  var _component_Portal = resolveComponent("Portal");
  var _directive_focustrap = resolveDirective("focustrap");
  return openBlock(), createBlock(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [$data.containerVisible ? (openBlock(), createElementBlock("div", mergeProps$2({
        key: 0,
        ref: $options.maskRef,
        "class": _ctx.cx("mask"),
        style: _ctx.sx("mask", true, {
          position: _ctx.position,
          modal: _ctx.modal
        }),
        onMousedown: _cache[1] || (_cache[1] = function() {
          return $options.onMaskMouseDown && $options.onMaskMouseDown.apply($options, arguments);
        }),
        onMouseup: _cache[2] || (_cache[2] = function() {
          return $options.onMaskMouseUp && $options.onMaskMouseUp.apply($options, arguments);
        })
      }, _ctx.ptm("mask")), [createVNode(Transition, mergeProps$2({
        name: "p-dialog",
        onEnter: $options.onEnter,
        onAfterEnter: $options.onAfterEnter,
        onBeforeLeave: $options.onBeforeLeave,
        onLeave: $options.onLeave,
        onAfterLeave: $options.onAfterLeave,
        appear: ""
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [_ctx.visible ? withDirectives((openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.containerRef,
            "class": _ctx.cx("root"),
            style: _ctx.sx("root"),
            role: "dialog",
            "aria-labelledby": $options.ariaLabelledById,
            "aria-modal": _ctx.modal
          }, _ctx.ptmi("root")), [_ctx.$slots.container ? renderSlot(_ctx.$slots, "container", {
            key: 0,
            closeCallback: $options.close,
            maximizeCallback: /* @__PURE__ */ __name(function maximizeCallback(event) {
              return $options.maximize(event);
            }, "maximizeCallback")
          }) : (openBlock(), createElementBlock(Fragment$1, {
            key: 1
          }, [_ctx.showHeader ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.headerContainerRef,
            "class": _ctx.cx("header"),
            onMousedown: _cache[0] || (_cache[0] = function() {
              return $options.initDrag && $options.initDrag.apply($options, arguments);
            })
          }, _ctx.ptm("header")), [renderSlot(_ctx.$slots, "header", {
            "class": normalizeClass(_ctx.cx("title"))
          }, function() {
            return [_ctx.header ? (openBlock(), createElementBlock("span", mergeProps$2({
              key: 0,
              id: $options.ariaLabelledById,
              "class": _ctx.cx("title")
            }, _ctx.ptm("title")), toDisplayString$1(_ctx.header), 17, _hoisted_2$1g)) : createCommentVNode("", true)];
          }), createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("headerActions")
          }, _ctx.ptm("headerActions")), [_ctx.maximizable ? (openBlock(), createBlock(_component_Button, mergeProps$2({
            key: 0,
            ref: $options.maximizableRef,
            autofocus: $data.focusableMax,
            "class": _ctx.cx("pcMaximizeButton"),
            onClick: $options.maximize,
            tabindex: _ctx.maximizable ? "0" : "-1",
            unstyled: _ctx.unstyled
          }, _ctx.maximizeButtonProps, {
            pt: _ctx.ptm("pcMaximizeButton"),
            "data-pc-group-section": "headericon"
          }), {
            icon: withCtx(function(slotProps) {
              return [renderSlot(_ctx.$slots, "maximizeicon", {
                maximized: $data.maximized
              }, function() {
                return [(openBlock(), createBlock(resolveDynamicComponent($options.maximizeIconComponent), mergeProps$2({
                  "class": [slotProps["class"], $data.maximized ? _ctx.minimizeIcon : _ctx.maximizeIcon]
                }, _ctx.ptm("pcMaximizeButton")["icon"]), null, 16, ["class"]))];
              })];
            }),
            _: 3
          }, 16, ["autofocus", "class", "onClick", "tabindex", "unstyled", "pt"])) : createCommentVNode("", true), _ctx.closable ? (openBlock(), createBlock(_component_Button, mergeProps$2({
            key: 1,
            ref: $options.closeButtonRef,
            autofocus: $data.focusableClose,
            "class": _ctx.cx("pcCloseButton"),
            onClick: $options.close,
            "aria-label": $options.closeAriaLabel,
            unstyled: _ctx.unstyled
          }, _ctx.closeButtonProps, {
            pt: _ctx.ptm("pcCloseButton"),
            "data-pc-group-section": "headericon"
          }), {
            icon: withCtx(function(slotProps) {
              return [renderSlot(_ctx.$slots, "closeicon", {}, function() {
                return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.closeIcon ? "span" : "TimesIcon"), mergeProps$2({
                  "class": [_ctx.closeIcon, slotProps["class"]]
                }, _ctx.ptm("pcCloseButton")["icon"]), null, 16, ["class"]))];
              })];
            }),
            _: 3
          }, 16, ["autofocus", "class", "onClick", "aria-label", "unstyled", "pt"])) : createCommentVNode("", true)], 16)], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
            ref: $options.contentRef,
            "class": [_ctx.cx("content"), _ctx.contentClass],
            style: _ctx.contentStyle
          }, _objectSpread$l(_objectSpread$l({}, _ctx.contentProps), _ctx.ptm("content"))), [renderSlot(_ctx.$slots, "default")], 16), _ctx.footer || _ctx.$slots.footer ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 1,
            ref: $options.footerContainerRef,
            "class": _ctx.cx("footer")
          }, _ctx.ptm("footer")), [renderSlot(_ctx.$slots, "footer", {}, function() {
            return [createTextVNode(toDisplayString$1(_ctx.footer), 1)];
          })], 16)) : createCommentVNode("", true)], 64))], 16, _hoisted_1$1N)), [[_directive_focustrap, {
            disabled: !_ctx.modal
          }]]) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onAfterEnter", "onBeforeLeave", "onLeave", "onAfterLeave"])], 16)) : createCommentVNode("", true)];
    }),
    _: 3
  }, 8, ["appendTo"]);
}
__name(render$X, "render$X");
script$_.render = render$X;
var commonjsGlobal = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
function getDefaultExportFromCjs(x2) {
  return x2 && x2.__esModule && Object.prototype.hasOwnProperty.call(x2, "default") ? x2["default"] : x2;
}
__name(getDefaultExportFromCjs, "getDefaultExportFromCjs");
function getDefaultExportFromNamespaceIfPresent(n2) {
  return n2 && Object.prototype.hasOwnProperty.call(n2, "default") ? n2["default"] : n2;
}
__name(getDefaultExportFromNamespaceIfPresent, "getDefaultExportFromNamespaceIfPresent");
function getDefaultExportFromNamespaceIfNotNamed(n2) {
  return n2 && Object.prototype.hasOwnProperty.call(n2, "default") && Object.keys(n2).length === 1 ? n2["default"] : n2;
}
__name(getDefaultExportFromNamespaceIfNotNamed, "getDefaultExportFromNamespaceIfNotNamed");
function getAugmentedNamespace(n2) {
  if (n2.__esModule) return n2;
  var f2 = n2.default;
  if (typeof f2 == "function") {
    var a2 = /* @__PURE__ */ __name(function a3() {
      if (this instanceof a3) {
        return Reflect.construct(f2, arguments, this.constructor);
      }
      return f2.apply(this, arguments);
    }, "a");
    a2.prototype = f2.prototype;
  } else a2 = {};
  Object.defineProperty(a2, "__esModule", { value: true });
  Object.keys(n2).forEach(function(k2) {
    var d2 = Object.getOwnPropertyDescriptor(n2, k2);
    Object.defineProperty(a2, k2, d2.get ? d2 : {
      enumerable: true,
      get: /* @__PURE__ */ __name(function() {
        return n2[k2];
      }, "get")
    });
  });
  return a2;
}
__name(getAugmentedNamespace, "getAugmentedNamespace");
var lodash$1 = { exports: {} };
/**
 * @license
 * Lodash <https://lodash.com/>
 * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */
var lodash = lodash$1.exports;
(function(module2, exports) {
  ;
  (function() {
    var undefined$1;
    var VERSION2 = "4.17.21";
    var LARGE_ARRAY_SIZE2 = 200;
    var CORE_ERROR_TEXT = "Unsupported core-js use. Try https://npms.io/search?q=ponyfill.", FUNC_ERROR_TEXT = "Expected a function", INVALID_TEMPL_VAR_ERROR_TEXT = "Invalid `variable` option passed into `_.template`";
    var HASH_UNDEFINED2 = "__lodash_hash_undefined__";
    var MAX_MEMOIZE_SIZE = 500;
    var PLACEHOLDER = "__lodash_placeholder__";
    var CLONE_DEEP_FLAG2 = 1, CLONE_FLAT_FLAG2 = 2, CLONE_SYMBOLS_FLAG2 = 4;
    var COMPARE_PARTIAL_FLAG = 1, COMPARE_UNORDERED_FLAG = 2;
    var WRAP_BIND_FLAG = 1, WRAP_BIND_KEY_FLAG = 2, WRAP_CURRY_BOUND_FLAG = 4, WRAP_CURRY_FLAG = 8, WRAP_CURRY_RIGHT_FLAG = 16, WRAP_PARTIAL_FLAG = 32, WRAP_PARTIAL_RIGHT_FLAG = 64, WRAP_ARY_FLAG = 128, WRAP_REARG_FLAG = 256, WRAP_FLIP_FLAG = 512;
    var DEFAULT_TRUNC_LENGTH = 30, DEFAULT_TRUNC_OMISSION = "...";
    var HOT_COUNT = 800, HOT_SPAN = 16;
    var LAZY_FILTER_FLAG = 1, LAZY_MAP_FLAG = 2, LAZY_WHILE_FLAG = 3;
    var INFINITY2 = 1 / 0, MAX_SAFE_INTEGER2 = 9007199254740991, MAX_INTEGER = 17976931348623157e292, NAN = 0 / 0;
    var MAX_ARRAY_LENGTH = 4294967295, MAX_ARRAY_INDEX = MAX_ARRAY_LENGTH - 1, HALF_MAX_ARRAY_LENGTH = MAX_ARRAY_LENGTH >>> 1;
    var wrapFlags = [
      ["ary", WRAP_ARY_FLAG],
      ["bind", WRAP_BIND_FLAG],
      ["bindKey", WRAP_BIND_KEY_FLAG],
      ["curry", WRAP_CURRY_FLAG],
      ["curryRight", WRAP_CURRY_RIGHT_FLAG],
      ["flip", WRAP_FLIP_FLAG],
      ["partial", WRAP_PARTIAL_FLAG],
      ["partialRight", WRAP_PARTIAL_RIGHT_FLAG],
      ["rearg", WRAP_REARG_FLAG]
    ];
    var argsTag2 = "[object Arguments]", arrayTag2 = "[object Array]", asyncTag2 = "[object AsyncFunction]", boolTag2 = "[object Boolean]", dateTag2 = "[object Date]", domExcTag = "[object DOMException]", errorTag2 = "[object Error]", funcTag2 = "[object Function]", genTag2 = "[object GeneratorFunction]", mapTag2 = "[object Map]", numberTag2 = "[object Number]", nullTag2 = "[object Null]", objectTag2 = "[object Object]", promiseTag2 = "[object Promise]", proxyTag2 = "[object Proxy]", regexpTag2 = "[object RegExp]", setTag2 = "[object Set]", stringTag2 = "[object String]", symbolTag2 = "[object Symbol]", undefinedTag2 = "[object Undefined]", weakMapTag2 = "[object WeakMap]", weakSetTag = "[object WeakSet]";
    var arrayBufferTag2 = "[object ArrayBuffer]", dataViewTag2 = "[object DataView]", float32Tag2 = "[object Float32Array]", float64Tag2 = "[object Float64Array]", int8Tag2 = "[object Int8Array]", int16Tag2 = "[object Int16Array]", int32Tag2 = "[object Int32Array]", uint8Tag2 = "[object Uint8Array]", uint8ClampedTag2 = "[object Uint8ClampedArray]", uint16Tag2 = "[object Uint16Array]", uint32Tag2 = "[object Uint32Array]";
    var reEmptyStringLeading = /\b__p \+= '';/g, reEmptyStringMiddle = /\b(__p \+=) '' \+/g, reEmptyStringTrailing = /(__e\(.*?\)|\b__t\)) \+\n'';/g;
    var reEscapedHtml = /&(?:amp|lt|gt|quot|#39);/g, reUnescapedHtml = /[&<>"']/g, reHasEscapedHtml = RegExp(reEscapedHtml.source), reHasUnescapedHtml = RegExp(reUnescapedHtml.source);
    var reEscape = /<%-([\s\S]+?)%>/g, reEvaluate = /<%([\s\S]+?)%>/g, reInterpolate = /<%=([\s\S]+?)%>/g;
    var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, reIsPlainProp = /^\w*$/, rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g;
    var reRegExpChar2 = /[\\^$.*+?()[\]{}|]/g, reHasRegExpChar = RegExp(reRegExpChar2.source);
    var reTrimStart = /^\s+/;
    var reWhitespace = /\s/;
    var reWrapComment = /\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/, reWrapDetails = /\{\n\/\* \[wrapped with (.+)\] \*/, reSplitDetails = /,? & /;
    var reAsciiWord = /[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g;
    var reForbiddenIdentifierChars = /[()=,{}\[\]\/\s]/;
    var reEscapeChar = /\\(\\)?/g;
    var reEsTemplate = /\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g;
    var reFlags2 = /\w*$/;
    var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
    var reIsBinary = /^0b[01]+$/i;
    var reIsHostCtor2 = /^\[object .+?Constructor\]$/;
    var reIsOctal = /^0o[0-7]+$/i;
    var reIsUint2 = /^(?:0|[1-9]\d*)$/;
    var reLatin = /[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g;
    var reNoMatch = /($^)/;
    var reUnescapedString = /['\n\r\u2028\u2029\\]/g;
    var rsAstralRange = "\\ud800-\\udfff", rsComboMarksRange = "\\u0300-\\u036f", reComboHalfMarksRange = "\\ufe20-\\ufe2f", rsComboSymbolsRange = "\\u20d0-\\u20ff", rsComboRange = rsComboMarksRange + reComboHalfMarksRange + rsComboSymbolsRange, rsDingbatRange = "\\u2700-\\u27bf", rsLowerRange = "a-z\\xdf-\\xf6\\xf8-\\xff", rsMathOpRange = "\\xac\\xb1\\xd7\\xf7", rsNonCharRange = "\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf", rsPunctuationRange = "\\u2000-\\u206f", rsSpaceRange = " \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000", rsUpperRange = "A-Z\\xc0-\\xd6\\xd8-\\xde", rsVarRange = "\\ufe0e\\ufe0f", rsBreakRange = rsMathOpRange + rsNonCharRange + rsPunctuationRange + rsSpaceRange;
    var rsApos = "['’]", rsAstral = "[" + rsAstralRange + "]", rsBreak = "[" + rsBreakRange + "]", rsCombo = "[" + rsComboRange + "]", rsDigits = "\\d+", rsDingbat = "[" + rsDingbatRange + "]", rsLower = "[" + rsLowerRange + "]", rsMisc = "[^" + rsAstralRange + rsBreakRange + rsDigits + rsDingbatRange + rsLowerRange + rsUpperRange + "]", rsFitz = "\\ud83c[\\udffb-\\udfff]", rsModifier = "(?:" + rsCombo + "|" + rsFitz + ")", rsNonAstral = "[^" + rsAstralRange + "]", rsRegional = "(?:\\ud83c[\\udde6-\\uddff]){2}", rsSurrPair = "[\\ud800-\\udbff][\\udc00-\\udfff]", rsUpper = "[" + rsUpperRange + "]", rsZWJ = "\\u200d";
    var rsMiscLower = "(?:" + rsLower + "|" + rsMisc + ")", rsMiscUpper = "(?:" + rsUpper + "|" + rsMisc + ")", rsOptContrLower = "(?:" + rsApos + "(?:d|ll|m|re|s|t|ve))?", rsOptContrUpper = "(?:" + rsApos + "(?:D|LL|M|RE|S|T|VE))?", reOptMod = rsModifier + "?", rsOptVar = "[" + rsVarRange + "]?", rsOptJoin = "(?:" + rsZWJ + "(?:" + [rsNonAstral, rsRegional, rsSurrPair].join("|") + ")" + rsOptVar + reOptMod + ")*", rsOrdLower = "\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])", rsOrdUpper = "\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])", rsSeq = rsOptVar + reOptMod + rsOptJoin, rsEmoji = "(?:" + [rsDingbat, rsRegional, rsSurrPair].join("|") + ")" + rsSeq, rsSymbol = "(?:" + [rsNonAstral + rsCombo + "?", rsCombo, rsRegional, rsSurrPair, rsAstral].join("|") + ")";
    var reApos = RegExp(rsApos, "g");
    var reComboMark = RegExp(rsCombo, "g");
    var reUnicode = RegExp(rsFitz + "(?=" + rsFitz + ")|" + rsSymbol + rsSeq, "g");
    var reUnicodeWord = RegExp([
      rsUpper + "?" + rsLower + "+" + rsOptContrLower + "(?=" + [rsBreak, rsUpper, "$"].join("|") + ")",
      rsMiscUpper + "+" + rsOptContrUpper + "(?=" + [rsBreak, rsUpper + rsMiscLower, "$"].join("|") + ")",
      rsUpper + "?" + rsMiscLower + "+" + rsOptContrLower,
      rsUpper + "+" + rsOptContrUpper,
      rsOrdUpper,
      rsOrdLower,
      rsDigits,
      rsEmoji
    ].join("|"), "g");
    var reHasUnicode = RegExp("[" + rsZWJ + rsAstralRange + rsComboRange + rsVarRange + "]");
    var reHasUnicodeWord = /[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/;
    var contextProps = [
      "Array",
      "Buffer",
      "DataView",
      "Date",
      "Error",
      "Float32Array",
      "Float64Array",
      "Function",
      "Int8Array",
      "Int16Array",
      "Int32Array",
      "Map",
      "Math",
      "Object",
      "Promise",
      "RegExp",
      "Set",
      "String",
      "Symbol",
      "TypeError",
      "Uint8Array",
      "Uint8ClampedArray",
      "Uint16Array",
      "Uint32Array",
      "WeakMap",
      "_",
      "clearTimeout",
      "isFinite",
      "parseInt",
      "setTimeout"
    ];
    var templateCounter = -1;
    var typedArrayTags2 = {};
    typedArrayTags2[float32Tag2] = typedArrayTags2[float64Tag2] = typedArrayTags2[int8Tag2] = typedArrayTags2[int16Tag2] = typedArrayTags2[int32Tag2] = typedArrayTags2[uint8Tag2] = typedArrayTags2[uint8ClampedTag2] = typedArrayTags2[uint16Tag2] = typedArrayTags2[uint32Tag2] = true;
    typedArrayTags2[argsTag2] = typedArrayTags2[arrayTag2] = typedArrayTags2[arrayBufferTag2] = typedArrayTags2[boolTag2] = typedArrayTags2[dataViewTag2] = typedArrayTags2[dateTag2] = typedArrayTags2[errorTag2] = typedArrayTags2[funcTag2] = typedArrayTags2[mapTag2] = typedArrayTags2[numberTag2] = typedArrayTags2[objectTag2] = typedArrayTags2[regexpTag2] = typedArrayTags2[setTag2] = typedArrayTags2[stringTag2] = typedArrayTags2[weakMapTag2] = false;
    var cloneableTags2 = {};
    cloneableTags2[argsTag2] = cloneableTags2[arrayTag2] = cloneableTags2[arrayBufferTag2] = cloneableTags2[dataViewTag2] = cloneableTags2[boolTag2] = cloneableTags2[dateTag2] = cloneableTags2[float32Tag2] = cloneableTags2[float64Tag2] = cloneableTags2[int8Tag2] = cloneableTags2[int16Tag2] = cloneableTags2[int32Tag2] = cloneableTags2[mapTag2] = cloneableTags2[numberTag2] = cloneableTags2[objectTag2] = cloneableTags2[regexpTag2] = cloneableTags2[setTag2] = cloneableTags2[stringTag2] = cloneableTags2[symbolTag2] = cloneableTags2[uint8Tag2] = cloneableTags2[uint8ClampedTag2] = cloneableTags2[uint16Tag2] = cloneableTags2[uint32Tag2] = true;
    cloneableTags2[errorTag2] = cloneableTags2[funcTag2] = cloneableTags2[weakMapTag2] = false;
    var deburredLetters = {
      // Latin-1 Supplement block.
      "À": "A",
      "Á": "A",
      "Â": "A",
      "Ã": "A",
      "Ä": "A",
      "Å": "A",
      "à": "a",
      "á": "a",
      "â": "a",
      "ã": "a",
      "ä": "a",
      "å": "a",
      "Ç": "C",
      "ç": "c",
      "Ð": "D",
      "ð": "d",
      "È": "E",
      "É": "E",
      "Ê": "E",
      "Ë": "E",
      "è": "e",
      "é": "e",
      "ê": "e",
      "ë": "e",
      "Ì": "I",
      "Í": "I",
      "Î": "I",
      "Ï": "I",
      "ì": "i",
      "í": "i",
      "î": "i",
      "ï": "i",
      "Ñ": "N",
      "ñ": "n",
      "Ò": "O",
      "Ó": "O",
      "Ô": "O",
      "Õ": "O",
      "Ö": "O",
      "Ø": "O",
      "ò": "o",
      "ó": "o",
      "ô": "o",
      "õ": "o",
      "ö": "o",
      "ø": "o",
      "Ù": "U",
      "Ú": "U",
      "Û": "U",
      "Ü": "U",
      "ù": "u",
      "ú": "u",
      "û": "u",
      "ü": "u",
      "Ý": "Y",
      "ý": "y",
      "ÿ": "y",
      "Æ": "Ae",
      "æ": "ae",
      "Þ": "Th",
      "þ": "th",
      "ß": "ss",
      // Latin Extended-A block.
      "Ā": "A",
      "Ă": "A",
      "Ą": "A",
      "ā": "a",
      "ă": "a",
      "ą": "a",
      "Ć": "C",
      "Ĉ": "C",
      "Ċ": "C",
      "Č": "C",
      "ć": "c",
      "ĉ": "c",
      "ċ": "c",
      "č": "c",
      "Ď": "D",
      "Đ": "D",
      "ď": "d",
      "đ": "d",
      "Ē": "E",
      "Ĕ": "E",
      "Ė": "E",
      "Ę": "E",
      "Ě": "E",
      "ē": "e",
      "ĕ": "e",
      "ė": "e",
      "ę": "e",
      "ě": "e",
      "Ĝ": "G",
      "Ğ": "G",
      "Ġ": "G",
      "Ģ": "G",
      "ĝ": "g",
      "ğ": "g",
      "ġ": "g",
      "ģ": "g",
      "Ĥ": "H",
      "Ħ": "H",
      "ĥ": "h",
      "ħ": "h",
      "Ĩ": "I",
      "Ī": "I",
      "Ĭ": "I",
      "Į": "I",
      "İ": "I",
      "ĩ": "i",
      "ī": "i",
      "ĭ": "i",
      "į": "i",
      "ı": "i",
      "Ĵ": "J",
      "ĵ": "j",
      "Ķ": "K",
      "ķ": "k",
      "ĸ": "k",
      "Ĺ": "L",
      "Ļ": "L",
      "Ľ": "L",
      "Ŀ": "L",
      "Ł": "L",
      "ĺ": "l",
      "ļ": "l",
      "ľ": "l",
      "ŀ": "l",
      "ł": "l",
      "Ń": "N",
      "Ņ": "N",
      "Ň": "N",
      "Ŋ": "N",
      "ń": "n",
      "ņ": "n",
      "ň": "n",
      "ŋ": "n",
      "Ō": "O",
      "Ŏ": "O",
      "Ő": "O",
      "ō": "o",
      "ŏ": "o",
      "ő": "o",
      "Ŕ": "R",
      "Ŗ": "R",
      "Ř": "R",
      "ŕ": "r",
      "ŗ": "r",
      "ř": "r",
      "Ś": "S",
      "Ŝ": "S",
      "Ş": "S",
      "Š": "S",
      "ś": "s",
      "ŝ": "s",
      "ş": "s",
      "š": "s",
      "Ţ": "T",
      "Ť": "T",
      "Ŧ": "T",
      "ţ": "t",
      "ť": "t",
      "ŧ": "t",
      "Ũ": "U",
      "Ū": "U",
      "Ŭ": "U",
      "Ů": "U",
      "Ű": "U",
      "Ų": "U",
      "ũ": "u",
      "ū": "u",
      "ŭ": "u",
      "ů": "u",
      "ű": "u",
      "ų": "u",
      "Ŵ": "W",
      "ŵ": "w",
      "Ŷ": "Y",
      "ŷ": "y",
      "Ÿ": "Y",
      "Ź": "Z",
      "Ż": "Z",
      "Ž": "Z",
      "ź": "z",
      "ż": "z",
      "ž": "z",
      "Ĳ": "IJ",
      "ĳ": "ij",
      "Œ": "Oe",
      "œ": "oe",
      "ŉ": "'n",
      "ſ": "s"
    };
    var htmlEscapes = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;",
      "'": "&#39;"
    };
    var htmlUnescapes = {
      "&amp;": "&",
      "&lt;": "<",
      "&gt;": ">",
      "&quot;": '"',
      "&#39;": "'"
    };
    var stringEscapes = {
      "\\": "\\",
      "'": "'",
      "\n": "n",
      "\r": "r",
      "\u2028": "u2028",
      "\u2029": "u2029"
    };
    var freeParseFloat = parseFloat, freeParseInt = parseInt;
    var freeGlobal2 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
    var freeSelf2 = typeof self == "object" && self && self.Object === Object && self;
    var root34 = freeGlobal2 || freeSelf2 || Function("return this")();
    var freeExports = exports && !exports.nodeType && exports;
    var freeModule = freeExports && true && module2 && !module2.nodeType && module2;
    var moduleExports = freeModule && freeModule.exports === freeExports;
    var freeProcess = moduleExports && freeGlobal2.process;
    var nodeUtil2 = function() {
      try {
        var types = freeModule && freeModule.require && freeModule.require("util").types;
        if (types) {
          return types;
        }
        return freeProcess && freeProcess.binding && freeProcess.binding("util");
      } catch (e2) {
      }
    }();
    var nodeIsArrayBuffer = nodeUtil2 && nodeUtil2.isArrayBuffer, nodeIsDate = nodeUtil2 && nodeUtil2.isDate, nodeIsMap2 = nodeUtil2 && nodeUtil2.isMap, nodeIsRegExp = nodeUtil2 && nodeUtil2.isRegExp, nodeIsSet2 = nodeUtil2 && nodeUtil2.isSet, nodeIsTypedArray2 = nodeUtil2 && nodeUtil2.isTypedArray;
    function apply2(func, thisArg, args) {
      switch (args.length) {
        case 0:
          return func.call(thisArg);
        case 1:
          return func.call(thisArg, args[0]);
        case 2:
          return func.call(thisArg, args[0], args[1]);
        case 3:
          return func.call(thisArg, args[0], args[1], args[2]);
      }
      return func.apply(thisArg, args);
    }
    __name(apply2, "apply");
    function arrayAggregator(array, setter, iteratee, accumulator) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        var value3 = array[index2];
        setter(accumulator, value3, iteratee(value3), array);
      }
      return accumulator;
    }
    __name(arrayAggregator, "arrayAggregator");
    function arrayEach2(array, iteratee) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        if (iteratee(array[index2], index2, array) === false) {
          break;
        }
      }
      return array;
    }
    __name(arrayEach2, "arrayEach");
    function arrayEachRight(array, iteratee) {
      var length = array == null ? 0 : array.length;
      while (length--) {
        if (iteratee(array[length], length, array) === false) {
          break;
        }
      }
      return array;
    }
    __name(arrayEachRight, "arrayEachRight");
    function arrayEvery(array, predicate) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        if (!predicate(array[index2], index2, array)) {
          return false;
        }
      }
      return true;
    }
    __name(arrayEvery, "arrayEvery");
    function arrayFilter2(array, predicate) {
      var index2 = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
      while (++index2 < length) {
        var value3 = array[index2];
        if (predicate(value3, index2, array)) {
          result[resIndex++] = value3;
        }
      }
      return result;
    }
    __name(arrayFilter2, "arrayFilter");
    function arrayIncludes(array, value3) {
      var length = array == null ? 0 : array.length;
      return !!length && baseIndexOf(array, value3, 0) > -1;
    }
    __name(arrayIncludes, "arrayIncludes");
    function arrayIncludesWith(array, value3, comparator) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        if (comparator(value3, array[index2])) {
          return true;
        }
      }
      return false;
    }
    __name(arrayIncludesWith, "arrayIncludesWith");
    function arrayMap(array, iteratee) {
      var index2 = -1, length = array == null ? 0 : array.length, result = Array(length);
      while (++index2 < length) {
        result[index2] = iteratee(array[index2], index2, array);
      }
      return result;
    }
    __name(arrayMap, "arrayMap");
    function arrayPush2(array, values) {
      var index2 = -1, length = values.length, offset = array.length;
      while (++index2 < length) {
        array[offset + index2] = values[index2];
      }
      return array;
    }
    __name(arrayPush2, "arrayPush");
    function arrayReduce(array, iteratee, accumulator, initAccum) {
      var index2 = -1, length = array == null ? 0 : array.length;
      if (initAccum && length) {
        accumulator = array[++index2];
      }
      while (++index2 < length) {
        accumulator = iteratee(accumulator, array[index2], index2, array);
      }
      return accumulator;
    }
    __name(arrayReduce, "arrayReduce");
    function arrayReduceRight(array, iteratee, accumulator, initAccum) {
      var length = array == null ? 0 : array.length;
      if (initAccum && length) {
        accumulator = array[--length];
      }
      while (length--) {
        accumulator = iteratee(accumulator, array[length], length, array);
      }
      return accumulator;
    }
    __name(arrayReduceRight, "arrayReduceRight");
    function arraySome(array, predicate) {
      var index2 = -1, length = array == null ? 0 : array.length;
      while (++index2 < length) {
        if (predicate(array[index2], index2, array)) {
          return true;
        }
      }
      return false;
    }
    __name(arraySome, "arraySome");
    var asciiSize = baseProperty("length");
    function asciiToArray(string) {
      return string.split("");
    }
    __name(asciiToArray, "asciiToArray");
    function asciiWords(string) {
      return string.match(reAsciiWord) || [];
    }
    __name(asciiWords, "asciiWords");
    function baseFindKey(collection, predicate, eachFunc) {
      var result;
      eachFunc(collection, function(value3, key, collection2) {
        if (predicate(value3, key, collection2)) {
          result = key;
          return false;
        }
      });
      return result;
    }
    __name(baseFindKey, "baseFindKey");
    function baseFindIndex(array, predicate, fromIndex, fromRight) {
      var length = array.length, index2 = fromIndex + (fromRight ? 1 : -1);
      while (fromRight ? index2-- : ++index2 < length) {
        if (predicate(array[index2], index2, array)) {
          return index2;
        }
      }
      return -1;
    }
    __name(baseFindIndex, "baseFindIndex");
    function baseIndexOf(array, value3, fromIndex) {
      return value3 === value3 ? strictIndexOf(array, value3, fromIndex) : baseFindIndex(array, baseIsNaN, fromIndex);
    }
    __name(baseIndexOf, "baseIndexOf");
    function baseIndexOfWith(array, value3, fromIndex, comparator) {
      var index2 = fromIndex - 1, length = array.length;
      while (++index2 < length) {
        if (comparator(array[index2], value3)) {
          return index2;
        }
      }
      return -1;
    }
    __name(baseIndexOfWith, "baseIndexOfWith");
    function baseIsNaN(value3) {
      return value3 !== value3;
    }
    __name(baseIsNaN, "baseIsNaN");
    function baseMean(array, iteratee) {
      var length = array == null ? 0 : array.length;
      return length ? baseSum(array, iteratee) / length : NAN;
    }
    __name(baseMean, "baseMean");
    function baseProperty(key) {
      return function(object) {
        return object == null ? undefined$1 : object[key];
      };
    }
    __name(baseProperty, "baseProperty");
    function basePropertyOf(object) {
      return function(key) {
        return object == null ? undefined$1 : object[key];
      };
    }
    __name(basePropertyOf, "basePropertyOf");
    function baseReduce(collection, iteratee, accumulator, initAccum, eachFunc) {
      eachFunc(collection, function(value3, index2, collection2) {
        accumulator = initAccum ? (initAccum = false, value3) : iteratee(accumulator, value3, index2, collection2);
      });
      return accumulator;
    }
    __name(baseReduce, "baseReduce");
    function baseSortBy(array, comparer) {
      var length = array.length;
      array.sort(comparer);
      while (length--) {
        array[length] = array[length].value;
      }
      return array;
    }
    __name(baseSortBy, "baseSortBy");
    function baseSum(array, iteratee) {
      var result, index2 = -1, length = array.length;
      while (++index2 < length) {
        var current = iteratee(array[index2]);
        if (current !== undefined$1) {
          result = result === undefined$1 ? current : result + current;
        }
      }
      return result;
    }
    __name(baseSum, "baseSum");
    function baseTimes2(n2, iteratee) {
      var index2 = -1, result = Array(n2);
      while (++index2 < n2) {
        result[index2] = iteratee(index2);
      }
      return result;
    }
    __name(baseTimes2, "baseTimes");
    function baseToPairs(object, props) {
      return arrayMap(props, function(key) {
        return [key, object[key]];
      });
    }
    __name(baseToPairs, "baseToPairs");
    function baseTrim(string) {
      return string ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, "") : string;
    }
    __name(baseTrim, "baseTrim");
    function baseUnary2(func) {
      return function(value3) {
        return func(value3);
      };
    }
    __name(baseUnary2, "baseUnary");
    function baseValues(object, props) {
      return arrayMap(props, function(key) {
        return object[key];
      });
    }
    __name(baseValues, "baseValues");
    function cacheHas(cache2, key) {
      return cache2.has(key);
    }
    __name(cacheHas, "cacheHas");
    function charsStartIndex(strSymbols, chrSymbols) {
      var index2 = -1, length = strSymbols.length;
      while (++index2 < length && baseIndexOf(chrSymbols, strSymbols[index2], 0) > -1) {
      }
      return index2;
    }
    __name(charsStartIndex, "charsStartIndex");
    function charsEndIndex(strSymbols, chrSymbols) {
      var index2 = strSymbols.length;
      while (index2-- && baseIndexOf(chrSymbols, strSymbols[index2], 0) > -1) {
      }
      return index2;
    }
    __name(charsEndIndex, "charsEndIndex");
    function countHolders(array, placeholder) {
      var length = array.length, result = 0;
      while (length--) {
        if (array[length] === placeholder) {
          ++result;
        }
      }
      return result;
    }
    __name(countHolders, "countHolders");
    var deburrLetter = basePropertyOf(deburredLetters);
    var escapeHtmlChar = basePropertyOf(htmlEscapes);
    function escapeStringChar(chr) {
      return "\\" + stringEscapes[chr];
    }
    __name(escapeStringChar, "escapeStringChar");
    function getValue2(object, key) {
      return object == null ? undefined$1 : object[key];
    }
    __name(getValue2, "getValue");
    function hasUnicode(string) {
      return reHasUnicode.test(string);
    }
    __name(hasUnicode, "hasUnicode");
    function hasUnicodeWord(string) {
      return reHasUnicodeWord.test(string);
    }
    __name(hasUnicodeWord, "hasUnicodeWord");
    function iteratorToArray(iterator2) {
      var data30, result = [];
      while (!(data30 = iterator2.next()).done) {
        result.push(data30.value);
      }
      return result;
    }
    __name(iteratorToArray, "iteratorToArray");
    function mapToArray(map3) {
      var index2 = -1, result = Array(map3.size);
      map3.forEach(function(value3, key) {
        result[++index2] = [key, value3];
      });
      return result;
    }
    __name(mapToArray, "mapToArray");
    function overArg2(func, transform2) {
      return function(arg) {
        return func(transform2(arg));
      };
    }
    __name(overArg2, "overArg");
    function replaceHolders(array, placeholder) {
      var index2 = -1, length = array.length, resIndex = 0, result = [];
      while (++index2 < length) {
        var value3 = array[index2];
        if (value3 === placeholder || value3 === PLACEHOLDER) {
          array[index2] = PLACEHOLDER;
          result[resIndex++] = index2;
        }
      }
      return result;
    }
    __name(replaceHolders, "replaceHolders");
    function setToArray(set3) {
      var index2 = -1, result = Array(set3.size);
      set3.forEach(function(value3) {
        result[++index2] = value3;
      });
      return result;
    }
    __name(setToArray, "setToArray");
    function setToPairs(set3) {
      var index2 = -1, result = Array(set3.size);
      set3.forEach(function(value3) {
        result[++index2] = [value3, value3];
      });
      return result;
    }
    __name(setToPairs, "setToPairs");
    function strictIndexOf(array, value3, fromIndex) {
      var index2 = fromIndex - 1, length = array.length;
      while (++index2 < length) {
        if (array[index2] === value3) {
          return index2;
        }
      }
      return -1;
    }
    __name(strictIndexOf, "strictIndexOf");
    function strictLastIndexOf(array, value3, fromIndex) {
      var index2 = fromIndex + 1;
      while (index2--) {
        if (array[index2] === value3) {
          return index2;
        }
      }
      return index2;
    }
    __name(strictLastIndexOf, "strictLastIndexOf");
    function stringSize(string) {
      return hasUnicode(string) ? unicodeSize(string) : asciiSize(string);
    }
    __name(stringSize, "stringSize");
    function stringToArray2(string) {
      return hasUnicode(string) ? unicodeToArray(string) : asciiToArray(string);
    }
    __name(stringToArray2, "stringToArray");
    function trimmedEndIndex(string) {
      var index2 = string.length;
      while (index2-- && reWhitespace.test(string.charAt(index2))) {
      }
      return index2;
    }
    __name(trimmedEndIndex, "trimmedEndIndex");
    var unescapeHtmlChar = basePropertyOf(htmlUnescapes);
    function unicodeSize(string) {
      var result = reUnicode.lastIndex = 0;
      while (reUnicode.test(string)) {
        ++result;
      }
      return result;
    }
    __name(unicodeSize, "unicodeSize");
    function unicodeToArray(string) {
      return string.match(reUnicode) || [];
    }
    __name(unicodeToArray, "unicodeToArray");
    function unicodeWords(string) {
      return string.match(reUnicodeWord) || [];
    }
    __name(unicodeWords, "unicodeWords");
    var runInContext = /* @__PURE__ */ __name(function runInContext2(context) {
      context = context == null ? root34 : _2.defaults(root34.Object(), context, _2.pick(root34, contextProps));
      var Array2 = context.Array, Date2 = context.Date, Error2 = context.Error, Function2 = context.Function, Math2 = context.Math, Object2 = context.Object, RegExp2 = context.RegExp, String2 = context.String, TypeError2 = context.TypeError;
      var arrayProto2 = Array2.prototype, funcProto2 = Function2.prototype, objectProto2 = Object2.prototype;
      var coreJsData2 = context["__core-js_shared__"];
      var funcToString2 = funcProto2.toString;
      var hasOwnProperty2 = objectProto2.hasOwnProperty;
      var idCounter = 0;
      var maskSrcKey2 = function() {
        var uid2 = /[^.]+$/.exec(coreJsData2 && coreJsData2.keys && coreJsData2.keys.IE_PROTO || "");
        return uid2 ? "Symbol(src)_1." + uid2 : "";
      }();
      var nativeObjectToString2 = objectProto2.toString;
      var objectCtorString = funcToString2.call(Object2);
      var oldDash = root34._;
      var reIsNative2 = RegExp2(
        "^" + funcToString2.call(hasOwnProperty2).replace(reRegExpChar2, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
      );
      var Buffer2 = moduleExports ? context.Buffer : undefined$1, Symbol2 = context.Symbol, Uint8Array2 = context.Uint8Array, allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : undefined$1, getPrototype2 = overArg2(Object2.getPrototypeOf, Object2), objectCreate2 = Object2.create, propertyIsEnumerable2 = objectProto2.propertyIsEnumerable, splice2 = arrayProto2.splice, spreadableSymbol = Symbol2 ? Symbol2.isConcatSpreadable : undefined$1, symIterator = Symbol2 ? Symbol2.iterator : undefined$1, symToStringTag2 = Symbol2 ? Symbol2.toStringTag : undefined$1;
      var defineProperty2 = function() {
        try {
          var func = getNative2(Object2, "defineProperty");
          func({}, "", {});
          return func;
        } catch (e2) {
        }
      }();
      var ctxClearTimeout = context.clearTimeout !== root34.clearTimeout && context.clearTimeout, ctxNow = Date2 && Date2.now !== root34.Date.now && Date2.now, ctxSetTimeout = context.setTimeout !== root34.setTimeout && context.setTimeout;
      var nativeCeil = Math2.ceil, nativeFloor = Math2.floor, nativeGetSymbols2 = Object2.getOwnPropertySymbols, nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : undefined$1, nativeIsFinite = context.isFinite, nativeJoin = arrayProto2.join, nativeKeys2 = overArg2(Object2.keys, Object2), nativeMax = Math2.max, nativeMin = Math2.min, nativeNow = Date2.now, nativeParseInt = context.parseInt, nativeRandom = Math2.random, nativeReverse = arrayProto2.reverse;
      var DataView2 = getNative2(context, "DataView"), Map2 = getNative2(context, "Map"), Promise2 = getNative2(context, "Promise"), Set2 = getNative2(context, "Set"), WeakMap2 = getNative2(context, "WeakMap"), nativeCreate2 = getNative2(Object2, "create");
      var metaMap = WeakMap2 && new WeakMap2();
      var realNames = {};
      var dataViewCtorString2 = toSource2(DataView2), mapCtorString2 = toSource2(Map2), promiseCtorString2 = toSource2(Promise2), setCtorString2 = toSource2(Set2), weakMapCtorString2 = toSource2(WeakMap2);
      var symbolProto2 = Symbol2 ? Symbol2.prototype : undefined$1, symbolValueOf2 = symbolProto2 ? symbolProto2.valueOf : undefined$1, symbolToString = symbolProto2 ? symbolProto2.toString : undefined$1;
      function lodash2(value3) {
        if (isObjectLike2(value3) && !isArray2(value3) && !(value3 instanceof LazyWrapper)) {
          if (value3 instanceof LodashWrapper) {
            return value3;
          }
          if (hasOwnProperty2.call(value3, "__wrapped__")) {
            return wrapperClone(value3);
          }
        }
        return new LodashWrapper(value3);
      }
      __name(lodash2, "lodash");
      var baseCreate2 = /* @__PURE__ */ function() {
        function object() {
        }
        __name(object, "object");
        return function(proto) {
          if (!isObject2(proto)) {
            return {};
          }
          if (objectCreate2) {
            return objectCreate2(proto);
          }
          object.prototype = proto;
          var result2 = new object();
          object.prototype = undefined$1;
          return result2;
        };
      }();
      function baseLodash() {
      }
      __name(baseLodash, "baseLodash");
      function LodashWrapper(value3, chainAll) {
        this.__wrapped__ = value3;
        this.__actions__ = [];
        this.__chain__ = !!chainAll;
        this.__index__ = 0;
        this.__values__ = undefined$1;
      }
      __name(LodashWrapper, "LodashWrapper");
      lodash2.templateSettings = {
        /**
         * Used to detect `data` property values to be HTML-escaped.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        "escape": reEscape,
        /**
         * Used to detect code to be evaluated.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        "evaluate": reEvaluate,
        /**
         * Used to detect `data` property values to inject.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        "interpolate": reInterpolate,
        /**
         * Used to reference the data object in the template text.
         *
         * @memberOf _.templateSettings
         * @type {string}
         */
        "variable": "",
        /**
         * Used to import variables into the compiled template.
         *
         * @memberOf _.templateSettings
         * @type {Object}
         */
        "imports": {
          /**
           * A reference to the `lodash` function.
           *
           * @memberOf _.templateSettings.imports
           * @type {Function}
           */
          "_": lodash2
        }
      };
      lodash2.prototype = baseLodash.prototype;
      lodash2.prototype.constructor = lodash2;
      LodashWrapper.prototype = baseCreate2(baseLodash.prototype);
      LodashWrapper.prototype.constructor = LodashWrapper;
      function LazyWrapper(value3) {
        this.__wrapped__ = value3;
        this.__actions__ = [];
        this.__dir__ = 1;
        this.__filtered__ = false;
        this.__iteratees__ = [];
        this.__takeCount__ = MAX_ARRAY_LENGTH;
        this.__views__ = [];
      }
      __name(LazyWrapper, "LazyWrapper");
      function lazyClone() {
        var result2 = new LazyWrapper(this.__wrapped__);
        result2.__actions__ = copyArray2(this.__actions__);
        result2.__dir__ = this.__dir__;
        result2.__filtered__ = this.__filtered__;
        result2.__iteratees__ = copyArray2(this.__iteratees__);
        result2.__takeCount__ = this.__takeCount__;
        result2.__views__ = copyArray2(this.__views__);
        return result2;
      }
      __name(lazyClone, "lazyClone");
      function lazyReverse() {
        if (this.__filtered__) {
          var result2 = new LazyWrapper(this);
          result2.__dir__ = -1;
          result2.__filtered__ = true;
        } else {
          result2 = this.clone();
          result2.__dir__ *= -1;
        }
        return result2;
      }
      __name(lazyReverse, "lazyReverse");
      function lazyValue() {
        var array = this.__wrapped__.value(), dir = this.__dir__, isArr = isArray2(array), isRight = dir < 0, arrLength = isArr ? array.length : 0, view = getView(0, arrLength, this.__views__), start2 = view.start, end = view.end, length = end - start2, index2 = isRight ? end : start2 - 1, iteratees = this.__iteratees__, iterLength = iteratees.length, resIndex = 0, takeCount = nativeMin(length, this.__takeCount__);
        if (!isArr || !isRight && arrLength == length && takeCount == length) {
          return baseWrapperValue(array, this.__actions__);
        }
        var result2 = [];
        outer:
          while (length-- && resIndex < takeCount) {
            index2 += dir;
            var iterIndex = -1, value3 = array[index2];
            while (++iterIndex < iterLength) {
              var data30 = iteratees[iterIndex], iteratee2 = data30.iteratee, type = data30.type, computed2 = iteratee2(value3);
              if (type == LAZY_MAP_FLAG) {
                value3 = computed2;
              } else if (!computed2) {
                if (type == LAZY_FILTER_FLAG) {
                  continue outer;
                } else {
                  break outer;
                }
              }
            }
            result2[resIndex++] = value3;
          }
        return result2;
      }
      __name(lazyValue, "lazyValue");
      LazyWrapper.prototype = baseCreate2(baseLodash.prototype);
      LazyWrapper.prototype.constructor = LazyWrapper;
      function Hash2(entries) {
        var index2 = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index2 < length) {
          var entry = entries[index2];
          this.set(entry[0], entry[1]);
        }
      }
      __name(Hash2, "Hash");
      function hashClear2() {
        this.__data__ = nativeCreate2 ? nativeCreate2(null) : {};
        this.size = 0;
      }
      __name(hashClear2, "hashClear");
      function hashDelete2(key) {
        var result2 = this.has(key) && delete this.__data__[key];
        this.size -= result2 ? 1 : 0;
        return result2;
      }
      __name(hashDelete2, "hashDelete");
      function hashGet2(key) {
        var data30 = this.__data__;
        if (nativeCreate2) {
          var result2 = data30[key];
          return result2 === HASH_UNDEFINED2 ? undefined$1 : result2;
        }
        return hasOwnProperty2.call(data30, key) ? data30[key] : undefined$1;
      }
      __name(hashGet2, "hashGet");
      function hashHas2(key) {
        var data30 = this.__data__;
        return nativeCreate2 ? data30[key] !== undefined$1 : hasOwnProperty2.call(data30, key);
      }
      __name(hashHas2, "hashHas");
      function hashSet2(key, value3) {
        var data30 = this.__data__;
        this.size += this.has(key) ? 0 : 1;
        data30[key] = nativeCreate2 && value3 === undefined$1 ? HASH_UNDEFINED2 : value3;
        return this;
      }
      __name(hashSet2, "hashSet");
      Hash2.prototype.clear = hashClear2;
      Hash2.prototype["delete"] = hashDelete2;
      Hash2.prototype.get = hashGet2;
      Hash2.prototype.has = hashHas2;
      Hash2.prototype.set = hashSet2;
      function ListCache2(entries) {
        var index2 = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index2 < length) {
          var entry = entries[index2];
          this.set(entry[0], entry[1]);
        }
      }
      __name(ListCache2, "ListCache");
      function listCacheClear2() {
        this.__data__ = [];
        this.size = 0;
      }
      __name(listCacheClear2, "listCacheClear");
      function listCacheDelete2(key) {
        var data30 = this.__data__, index2 = assocIndexOf2(data30, key);
        if (index2 < 0) {
          return false;
        }
        var lastIndex = data30.length - 1;
        if (index2 == lastIndex) {
          data30.pop();
        } else {
          splice2.call(data30, index2, 1);
        }
        --this.size;
        return true;
      }
      __name(listCacheDelete2, "listCacheDelete");
      function listCacheGet2(key) {
        var data30 = this.__data__, index2 = assocIndexOf2(data30, key);
        return index2 < 0 ? undefined$1 : data30[index2][1];
      }
      __name(listCacheGet2, "listCacheGet");
      function listCacheHas2(key) {
        return assocIndexOf2(this.__data__, key) > -1;
      }
      __name(listCacheHas2, "listCacheHas");
      function listCacheSet2(key, value3) {
        var data30 = this.__data__, index2 = assocIndexOf2(data30, key);
        if (index2 < 0) {
          ++this.size;
          data30.push([key, value3]);
        } else {
          data30[index2][1] = value3;
        }
        return this;
      }
      __name(listCacheSet2, "listCacheSet");
      ListCache2.prototype.clear = listCacheClear2;
      ListCache2.prototype["delete"] = listCacheDelete2;
      ListCache2.prototype.get = listCacheGet2;
      ListCache2.prototype.has = listCacheHas2;
      ListCache2.prototype.set = listCacheSet2;
      function MapCache2(entries) {
        var index2 = -1, length = entries == null ? 0 : entries.length;
        this.clear();
        while (++index2 < length) {
          var entry = entries[index2];
          this.set(entry[0], entry[1]);
        }
      }
      __name(MapCache2, "MapCache");
      function mapCacheClear2() {
        this.size = 0;
        this.__data__ = {
          "hash": new Hash2(),
          "map": new (Map2 || ListCache2)(),
          "string": new Hash2()
        };
      }
      __name(mapCacheClear2, "mapCacheClear");
      function mapCacheDelete2(key) {
        var result2 = getMapData2(this, key)["delete"](key);
        this.size -= result2 ? 1 : 0;
        return result2;
      }
      __name(mapCacheDelete2, "mapCacheDelete");
      function mapCacheGet2(key) {
        return getMapData2(this, key).get(key);
      }
      __name(mapCacheGet2, "mapCacheGet");
      function mapCacheHas2(key) {
        return getMapData2(this, key).has(key);
      }
      __name(mapCacheHas2, "mapCacheHas");
      function mapCacheSet2(key, value3) {
        var data30 = getMapData2(this, key), size2 = data30.size;
        data30.set(key, value3);
        this.size += data30.size == size2 ? 0 : 1;
        return this;
      }
      __name(mapCacheSet2, "mapCacheSet");
      MapCache2.prototype.clear = mapCacheClear2;
      MapCache2.prototype["delete"] = mapCacheDelete2;
      MapCache2.prototype.get = mapCacheGet2;
      MapCache2.prototype.has = mapCacheHas2;
      MapCache2.prototype.set = mapCacheSet2;
      function SetCache(values2) {
        var index2 = -1, length = values2 == null ? 0 : values2.length;
        this.__data__ = new MapCache2();
        while (++index2 < length) {
          this.add(values2[index2]);
        }
      }
      __name(SetCache, "SetCache");
      function setCacheAdd(value3) {
        this.__data__.set(value3, HASH_UNDEFINED2);
        return this;
      }
      __name(setCacheAdd, "setCacheAdd");
      function setCacheHas(value3) {
        return this.__data__.has(value3);
      }
      __name(setCacheHas, "setCacheHas");
      SetCache.prototype.add = SetCache.prototype.push = setCacheAdd;
      SetCache.prototype.has = setCacheHas;
      function Stack2(entries) {
        var data30 = this.__data__ = new ListCache2(entries);
        this.size = data30.size;
      }
      __name(Stack2, "Stack");
      function stackClear2() {
        this.__data__ = new ListCache2();
        this.size = 0;
      }
      __name(stackClear2, "stackClear");
      function stackDelete2(key) {
        var data30 = this.__data__, result2 = data30["delete"](key);
        this.size = data30.size;
        return result2;
      }
      __name(stackDelete2, "stackDelete");
      function stackGet2(key) {
        return this.__data__.get(key);
      }
      __name(stackGet2, "stackGet");
      function stackHas2(key) {
        return this.__data__.has(key);
      }
      __name(stackHas2, "stackHas");
      function stackSet2(key, value3) {
        var data30 = this.__data__;
        if (data30 instanceof ListCache2) {
          var pairs = data30.__data__;
          if (!Map2 || pairs.length < LARGE_ARRAY_SIZE2 - 1) {
            pairs.push([key, value3]);
            this.size = ++data30.size;
            return this;
          }
          data30 = this.__data__ = new MapCache2(pairs);
        }
        data30.set(key, value3);
        this.size = data30.size;
        return this;
      }
      __name(stackSet2, "stackSet");
      Stack2.prototype.clear = stackClear2;
      Stack2.prototype["delete"] = stackDelete2;
      Stack2.prototype.get = stackGet2;
      Stack2.prototype.has = stackHas2;
      Stack2.prototype.set = stackSet2;
      function arrayLikeKeys2(value3, inherited) {
        var isArr = isArray2(value3), isArg = !isArr && isArguments2(value3), isBuff = !isArr && !isArg && isBuffer2(value3), isType = !isArr && !isArg && !isBuff && isTypedArray2(value3), skipIndexes = isArr || isArg || isBuff || isType, result2 = skipIndexes ? baseTimes2(value3.length, String2) : [], length = result2.length;
        for (var key in value3) {
          if ((inherited || hasOwnProperty2.call(value3, key)) && !(skipIndexes && // Safari 9 has enumerable `arguments.length` in strict mode.
          (key == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
          isBuff && (key == "offset" || key == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
          isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || // Skip index properties.
          isIndex2(key, length)))) {
            result2.push(key);
          }
        }
        return result2;
      }
      __name(arrayLikeKeys2, "arrayLikeKeys");
      function arraySample(array) {
        var length = array.length;
        return length ? array[baseRandom(0, length - 1)] : undefined$1;
      }
      __name(arraySample, "arraySample");
      function arraySampleSize(array, n2) {
        return shuffleSelf(copyArray2(array), baseClamp(n2, 0, array.length));
      }
      __name(arraySampleSize, "arraySampleSize");
      function arrayShuffle(array) {
        return shuffleSelf(copyArray2(array));
      }
      __name(arrayShuffle, "arrayShuffle");
      function assignMergeValue(object, key, value3) {
        if (value3 !== undefined$1 && !eq2(object[key], value3) || value3 === undefined$1 && !(key in object)) {
          baseAssignValue2(object, key, value3);
        }
      }
      __name(assignMergeValue, "assignMergeValue");
      function assignValue2(object, key, value3) {
        var objValue = object[key];
        if (!(hasOwnProperty2.call(object, key) && eq2(objValue, value3)) || value3 === undefined$1 && !(key in object)) {
          baseAssignValue2(object, key, value3);
        }
      }
      __name(assignValue2, "assignValue");
      function assocIndexOf2(array, key) {
        var length = array.length;
        while (length--) {
          if (eq2(array[length][0], key)) {
            return length;
          }
        }
        return -1;
      }
      __name(assocIndexOf2, "assocIndexOf");
      function baseAggregator(collection, setter, iteratee2, accumulator) {
        baseEach(collection, function(value3, key, collection2) {
          setter(accumulator, value3, iteratee2(value3), collection2);
        });
        return accumulator;
      }
      __name(baseAggregator, "baseAggregator");
      function baseAssign2(object, source) {
        return object && copyObject2(source, keys2(source), object);
      }
      __name(baseAssign2, "baseAssign");
      function baseAssignIn2(object, source) {
        return object && copyObject2(source, keysIn2(source), object);
      }
      __name(baseAssignIn2, "baseAssignIn");
      function baseAssignValue2(object, key, value3) {
        if (key == "__proto__" && defineProperty2) {
          defineProperty2(object, key, {
            "configurable": true,
            "enumerable": true,
            "value": value3,
            "writable": true
          });
        } else {
          object[key] = value3;
        }
      }
      __name(baseAssignValue2, "baseAssignValue");
      function baseAt(object, paths) {
        var index2 = -1, length = paths.length, result2 = Array2(length), skip = object == null;
        while (++index2 < length) {
          result2[index2] = skip ? undefined$1 : get3(object, paths[index2]);
        }
        return result2;
      }
      __name(baseAt, "baseAt");
      function baseClamp(number2, lower, upper) {
        if (number2 === number2) {
          if (upper !== undefined$1) {
            number2 = number2 <= upper ? number2 : upper;
          }
          if (lower !== undefined$1) {
            number2 = number2 >= lower ? number2 : lower;
          }
        }
        return number2;
      }
      __name(baseClamp, "baseClamp");
      function baseClone2(value3, bitmask, customizer, key, object, stack2) {
        var result2, isDeep = bitmask & CLONE_DEEP_FLAG2, isFlat = bitmask & CLONE_FLAT_FLAG2, isFull = bitmask & CLONE_SYMBOLS_FLAG2;
        if (customizer) {
          result2 = object ? customizer(value3, key, object, stack2) : customizer(value3);
        }
        if (result2 !== undefined$1) {
          return result2;
        }
        if (!isObject2(value3)) {
          return value3;
        }
        var isArr = isArray2(value3);
        if (isArr) {
          result2 = initCloneArray2(value3);
          if (!isDeep) {
            return copyArray2(value3, result2);
          }
        } else {
          var tag = getTag2(value3), isFunc = tag == funcTag2 || tag == genTag2;
          if (isBuffer2(value3)) {
            return cloneBuffer2(value3, isDeep);
          }
          if (tag == objectTag2 || tag == argsTag2 || isFunc && !object) {
            result2 = isFlat || isFunc ? {} : initCloneObject2(value3);
            if (!isDeep) {
              return isFlat ? copySymbolsIn2(value3, baseAssignIn2(result2, value3)) : copySymbols2(value3, baseAssign2(result2, value3));
            }
          } else {
            if (!cloneableTags2[tag]) {
              return object ? value3 : {};
            }
            result2 = initCloneByTag2(value3, tag, isDeep);
          }
        }
        stack2 || (stack2 = new Stack2());
        var stacked = stack2.get(value3);
        if (stacked) {
          return stacked;
        }
        stack2.set(value3, result2);
        if (isSet2(value3)) {
          value3.forEach(function(subValue) {
            result2.add(baseClone2(subValue, bitmask, customizer, subValue, value3, stack2));
          });
        } else if (isMap2(value3)) {
          value3.forEach(function(subValue, key2) {
            result2.set(key2, baseClone2(subValue, bitmask, customizer, key2, value3, stack2));
          });
        }
        var keysFunc = isFull ? isFlat ? getAllKeysIn2 : getAllKeys2 : isFlat ? keysIn2 : keys2;
        var props = isArr ? undefined$1 : keysFunc(value3);
        arrayEach2(props || value3, function(subValue, key2) {
          if (props) {
            key2 = subValue;
            subValue = value3[key2];
          }
          assignValue2(result2, key2, baseClone2(subValue, bitmask, customizer, key2, value3, stack2));
        });
        return result2;
      }
      __name(baseClone2, "baseClone");
      function baseConforms(source) {
        var props = keys2(source);
        return function(object) {
          return baseConformsTo(object, source, props);
        };
      }
      __name(baseConforms, "baseConforms");
      function baseConformsTo(object, source, props) {
        var length = props.length;
        if (object == null) {
          return !length;
        }
        object = Object2(object);
        while (length--) {
          var key = props[length], predicate = source[key], value3 = object[key];
          if (value3 === undefined$1 && !(key in object) || !predicate(value3)) {
            return false;
          }
        }
        return true;
      }
      __name(baseConformsTo, "baseConformsTo");
      function baseDelay(func, wait, args) {
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        return setTimeout2(function() {
          func.apply(undefined$1, args);
        }, wait);
      }
      __name(baseDelay, "baseDelay");
      function baseDifference(array, values2, iteratee2, comparator) {
        var index2 = -1, includes2 = arrayIncludes, isCommon = true, length = array.length, result2 = [], valuesLength = values2.length;
        if (!length) {
          return result2;
        }
        if (iteratee2) {
          values2 = arrayMap(values2, baseUnary2(iteratee2));
        }
        if (comparator) {
          includes2 = arrayIncludesWith;
          isCommon = false;
        } else if (values2.length >= LARGE_ARRAY_SIZE2) {
          includes2 = cacheHas;
          isCommon = false;
          values2 = new SetCache(values2);
        }
        outer:
          while (++index2 < length) {
            var value3 = array[index2], computed2 = iteratee2 == null ? value3 : iteratee2(value3);
            value3 = comparator || value3 !== 0 ? value3 : 0;
            if (isCommon && computed2 === computed2) {
              var valuesIndex = valuesLength;
              while (valuesIndex--) {
                if (values2[valuesIndex] === computed2) {
                  continue outer;
                }
              }
              result2.push(value3);
            } else if (!includes2(values2, computed2, comparator)) {
              result2.push(value3);
            }
          }
        return result2;
      }
      __name(baseDifference, "baseDifference");
      var baseEach = createBaseEach(baseForOwn);
      var baseEachRight = createBaseEach(baseForOwnRight, true);
      function baseEvery(collection, predicate) {
        var result2 = true;
        baseEach(collection, function(value3, index2, collection2) {
          result2 = !!predicate(value3, index2, collection2);
          return result2;
        });
        return result2;
      }
      __name(baseEvery, "baseEvery");
      function baseExtremum(array, iteratee2, comparator) {
        var index2 = -1, length = array.length;
        while (++index2 < length) {
          var value3 = array[index2], current = iteratee2(value3);
          if (current != null && (computed2 === undefined$1 ? current === current && !isSymbol2(current) : comparator(current, computed2))) {
            var computed2 = current, result2 = value3;
          }
        }
        return result2;
      }
      __name(baseExtremum, "baseExtremum");
      function baseFill(array, value3, start2, end) {
        var length = array.length;
        start2 = toInteger(start2);
        if (start2 < 0) {
          start2 = -start2 > length ? 0 : length + start2;
        }
        end = end === undefined$1 || end > length ? length : toInteger(end);
        if (end < 0) {
          end += length;
        }
        end = start2 > end ? 0 : toLength(end);
        while (start2 < end) {
          array[start2++] = value3;
        }
        return array;
      }
      __name(baseFill, "baseFill");
      function baseFilter(collection, predicate) {
        var result2 = [];
        baseEach(collection, function(value3, index2, collection2) {
          if (predicate(value3, index2, collection2)) {
            result2.push(value3);
          }
        });
        return result2;
      }
      __name(baseFilter, "baseFilter");
      function baseFlatten(array, depth, predicate, isStrict, result2) {
        var index2 = -1, length = array.length;
        predicate || (predicate = isFlattenable);
        result2 || (result2 = []);
        while (++index2 < length) {
          var value3 = array[index2];
          if (depth > 0 && predicate(value3)) {
            if (depth > 1) {
              baseFlatten(value3, depth - 1, predicate, isStrict, result2);
            } else {
              arrayPush2(result2, value3);
            }
          } else if (!isStrict) {
            result2[result2.length] = value3;
          }
        }
        return result2;
      }
      __name(baseFlatten, "baseFlatten");
      var baseFor = createBaseFor();
      var baseForRight = createBaseFor(true);
      function baseForOwn(object, iteratee2) {
        return object && baseFor(object, iteratee2, keys2);
      }
      __name(baseForOwn, "baseForOwn");
      function baseForOwnRight(object, iteratee2) {
        return object && baseForRight(object, iteratee2, keys2);
      }
      __name(baseForOwnRight, "baseForOwnRight");
      function baseFunctions(object, props) {
        return arrayFilter2(props, function(key) {
          return isFunction2(object[key]);
        });
      }
      __name(baseFunctions, "baseFunctions");
      function baseGet(object, path) {
        path = castPath(path, object);
        var index2 = 0, length = path.length;
        while (object != null && index2 < length) {
          object = object[toKey(path[index2++])];
        }
        return index2 && index2 == length ? object : undefined$1;
      }
      __name(baseGet, "baseGet");
      function baseGetAllKeys2(object, keysFunc, symbolsFunc) {
        var result2 = keysFunc(object);
        return isArray2(object) ? result2 : arrayPush2(result2, symbolsFunc(object));
      }
      __name(baseGetAllKeys2, "baseGetAllKeys");
      function baseGetTag2(value3) {
        if (value3 == null) {
          return value3 === undefined$1 ? undefinedTag2 : nullTag2;
        }
        return symToStringTag2 && symToStringTag2 in Object2(value3) ? getRawTag2(value3) : objectToString2(value3);
      }
      __name(baseGetTag2, "baseGetTag");
      function baseGt(value3, other) {
        return value3 > other;
      }
      __name(baseGt, "baseGt");
      function baseHas(object, key) {
        return object != null && hasOwnProperty2.call(object, key);
      }
      __name(baseHas, "baseHas");
      function baseHasIn(object, key) {
        return object != null && key in Object2(object);
      }
      __name(baseHasIn, "baseHasIn");
      function baseInRange(number2, start2, end) {
        return number2 >= nativeMin(start2, end) && number2 < nativeMax(start2, end);
      }
      __name(baseInRange, "baseInRange");
      function baseIntersection(arrays, iteratee2, comparator) {
        var includes2 = comparator ? arrayIncludesWith : arrayIncludes, length = arrays[0].length, othLength = arrays.length, othIndex = othLength, caches = Array2(othLength), maxLength = Infinity, result2 = [];
        while (othIndex--) {
          var array = arrays[othIndex];
          if (othIndex && iteratee2) {
            array = arrayMap(array, baseUnary2(iteratee2));
          }
          maxLength = nativeMin(array.length, maxLength);
          caches[othIndex] = !comparator && (iteratee2 || length >= 120 && array.length >= 120) ? new SetCache(othIndex && array) : undefined$1;
        }
        array = arrays[0];
        var index2 = -1, seen2 = caches[0];
        outer:
          while (++index2 < length && result2.length < maxLength) {
            var value3 = array[index2], computed2 = iteratee2 ? iteratee2(value3) : value3;
            value3 = comparator || value3 !== 0 ? value3 : 0;
            if (!(seen2 ? cacheHas(seen2, computed2) : includes2(result2, computed2, comparator))) {
              othIndex = othLength;
              while (--othIndex) {
                var cache2 = caches[othIndex];
                if (!(cache2 ? cacheHas(cache2, computed2) : includes2(arrays[othIndex], computed2, comparator))) {
                  continue outer;
                }
              }
              if (seen2) {
                seen2.push(computed2);
              }
              result2.push(value3);
            }
          }
        return result2;
      }
      __name(baseIntersection, "baseIntersection");
      function baseInverter(object, setter, iteratee2, accumulator) {
        baseForOwn(object, function(value3, key, object2) {
          setter(accumulator, iteratee2(value3), key, object2);
        });
        return accumulator;
      }
      __name(baseInverter, "baseInverter");
      function baseInvoke(object, path, args) {
        path = castPath(path, object);
        object = parent(object, path);
        var func = object == null ? object : object[toKey(last(path))];
        return func == null ? undefined$1 : apply2(func, object, args);
      }
      __name(baseInvoke, "baseInvoke");
      function baseIsArguments2(value3) {
        return isObjectLike2(value3) && baseGetTag2(value3) == argsTag2;
      }
      __name(baseIsArguments2, "baseIsArguments");
      function baseIsArrayBuffer(value3) {
        return isObjectLike2(value3) && baseGetTag2(value3) == arrayBufferTag2;
      }
      __name(baseIsArrayBuffer, "baseIsArrayBuffer");
      function baseIsDate(value3) {
        return isObjectLike2(value3) && baseGetTag2(value3) == dateTag2;
      }
      __name(baseIsDate, "baseIsDate");
      function baseIsEqual(value3, other, bitmask, customizer, stack2) {
        if (value3 === other) {
          return true;
        }
        if (value3 == null || other == null || !isObjectLike2(value3) && !isObjectLike2(other)) {
          return value3 !== value3 && other !== other;
        }
        return baseIsEqualDeep(value3, other, bitmask, customizer, baseIsEqual, stack2);
      }
      __name(baseIsEqual, "baseIsEqual");
      function baseIsEqualDeep(object, other, bitmask, customizer, equalFunc, stack2) {
        var objIsArr = isArray2(object), othIsArr = isArray2(other), objTag = objIsArr ? arrayTag2 : getTag2(object), othTag = othIsArr ? arrayTag2 : getTag2(other);
        objTag = objTag == argsTag2 ? objectTag2 : objTag;
        othTag = othTag == argsTag2 ? objectTag2 : othTag;
        var objIsObj = objTag == objectTag2, othIsObj = othTag == objectTag2, isSameTag = objTag == othTag;
        if (isSameTag && isBuffer2(object)) {
          if (!isBuffer2(other)) {
            return false;
          }
          objIsArr = true;
          objIsObj = false;
        }
        if (isSameTag && !objIsObj) {
          stack2 || (stack2 = new Stack2());
          return objIsArr || isTypedArray2(object) ? equalArrays(object, other, bitmask, customizer, equalFunc, stack2) : equalByTag(object, other, objTag, bitmask, customizer, equalFunc, stack2);
        }
        if (!(bitmask & COMPARE_PARTIAL_FLAG)) {
          var objIsWrapped = objIsObj && hasOwnProperty2.call(object, "__wrapped__"), othIsWrapped = othIsObj && hasOwnProperty2.call(other, "__wrapped__");
          if (objIsWrapped || othIsWrapped) {
            var objUnwrapped = objIsWrapped ? object.value() : object, othUnwrapped = othIsWrapped ? other.value() : other;
            stack2 || (stack2 = new Stack2());
            return equalFunc(objUnwrapped, othUnwrapped, bitmask, customizer, stack2);
          }
        }
        if (!isSameTag) {
          return false;
        }
        stack2 || (stack2 = new Stack2());
        return equalObjects(object, other, bitmask, customizer, equalFunc, stack2);
      }
      __name(baseIsEqualDeep, "baseIsEqualDeep");
      function baseIsMap2(value3) {
        return isObjectLike2(value3) && getTag2(value3) == mapTag2;
      }
      __name(baseIsMap2, "baseIsMap");
      function baseIsMatch(object, source, matchData, customizer) {
        var index2 = matchData.length, length = index2, noCustomizer = !customizer;
        if (object == null) {
          return !length;
        }
        object = Object2(object);
        while (index2--) {
          var data30 = matchData[index2];
          if (noCustomizer && data30[2] ? data30[1] !== object[data30[0]] : !(data30[0] in object)) {
            return false;
          }
        }
        while (++index2 < length) {
          data30 = matchData[index2];
          var key = data30[0], objValue = object[key], srcValue = data30[1];
          if (noCustomizer && data30[2]) {
            if (objValue === undefined$1 && !(key in object)) {
              return false;
            }
          } else {
            var stack2 = new Stack2();
            if (customizer) {
              var result2 = customizer(objValue, srcValue, key, object, source, stack2);
            }
            if (!(result2 === undefined$1 ? baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG, customizer, stack2) : result2)) {
              return false;
            }
          }
        }
        return true;
      }
      __name(baseIsMatch, "baseIsMatch");
      function baseIsNative2(value3) {
        if (!isObject2(value3) || isMasked2(value3)) {
          return false;
        }
        var pattern = isFunction2(value3) ? reIsNative2 : reIsHostCtor2;
        return pattern.test(toSource2(value3));
      }
      __name(baseIsNative2, "baseIsNative");
      function baseIsRegExp(value3) {
        return isObjectLike2(value3) && baseGetTag2(value3) == regexpTag2;
      }
      __name(baseIsRegExp, "baseIsRegExp");
      function baseIsSet2(value3) {
        return isObjectLike2(value3) && getTag2(value3) == setTag2;
      }
      __name(baseIsSet2, "baseIsSet");
      function baseIsTypedArray2(value3) {
        return isObjectLike2(value3) && isLength2(value3.length) && !!typedArrayTags2[baseGetTag2(value3)];
      }
      __name(baseIsTypedArray2, "baseIsTypedArray");
      function baseIteratee(value3) {
        if (typeof value3 == "function") {
          return value3;
        }
        if (value3 == null) {
          return identity2;
        }
        if (typeof value3 == "object") {
          return isArray2(value3) ? baseMatchesProperty(value3[0], value3[1]) : baseMatches(value3);
        }
        return property(value3);
      }
      __name(baseIteratee, "baseIteratee");
      function baseKeys2(object) {
        if (!isPrototype2(object)) {
          return nativeKeys2(object);
        }
        var result2 = [];
        for (var key in Object2(object)) {
          if (hasOwnProperty2.call(object, key) && key != "constructor") {
            result2.push(key);
          }
        }
        return result2;
      }
      __name(baseKeys2, "baseKeys");
      function baseKeysIn2(object) {
        if (!isObject2(object)) {
          return nativeKeysIn2(object);
        }
        var isProto = isPrototype2(object), result2 = [];
        for (var key in object) {
          if (!(key == "constructor" && (isProto || !hasOwnProperty2.call(object, key)))) {
            result2.push(key);
          }
        }
        return result2;
      }
      __name(baseKeysIn2, "baseKeysIn");
      function baseLt(value3, other) {
        return value3 < other;
      }
      __name(baseLt, "baseLt");
      function baseMap(collection, iteratee2) {
        var index2 = -1, result2 = isArrayLike2(collection) ? Array2(collection.length) : [];
        baseEach(collection, function(value3, key, collection2) {
          result2[++index2] = iteratee2(value3, key, collection2);
        });
        return result2;
      }
      __name(baseMap, "baseMap");
      function baseMatches(source) {
        var matchData = getMatchData(source);
        if (matchData.length == 1 && matchData[0][2]) {
          return matchesStrictComparable(matchData[0][0], matchData[0][1]);
        }
        return function(object) {
          return object === source || baseIsMatch(object, source, matchData);
        };
      }
      __name(baseMatches, "baseMatches");
      function baseMatchesProperty(path, srcValue) {
        if (isKey(path) && isStrictComparable(srcValue)) {
          return matchesStrictComparable(toKey(path), srcValue);
        }
        return function(object) {
          var objValue = get3(object, path);
          return objValue === undefined$1 && objValue === srcValue ? hasIn(object, path) : baseIsEqual(srcValue, objValue, COMPARE_PARTIAL_FLAG | COMPARE_UNORDERED_FLAG);
        };
      }
      __name(baseMatchesProperty, "baseMatchesProperty");
      function baseMerge(object, source, srcIndex, customizer, stack2) {
        if (object === source) {
          return;
        }
        baseFor(source, function(srcValue, key) {
          stack2 || (stack2 = new Stack2());
          if (isObject2(srcValue)) {
            baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack2);
          } else {
            var newValue2 = customizer ? customizer(safeGet(object, key), srcValue, key + "", object, source, stack2) : undefined$1;
            if (newValue2 === undefined$1) {
              newValue2 = srcValue;
            }
            assignMergeValue(object, key, newValue2);
          }
        }, keysIn2);
      }
      __name(baseMerge, "baseMerge");
      function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack2) {
        var objValue = safeGet(object, key), srcValue = safeGet(source, key), stacked = stack2.get(srcValue);
        if (stacked) {
          assignMergeValue(object, key, stacked);
          return;
        }
        var newValue2 = customizer ? customizer(objValue, srcValue, key + "", object, source, stack2) : undefined$1;
        var isCommon = newValue2 === undefined$1;
        if (isCommon) {
          var isArr = isArray2(srcValue), isBuff = !isArr && isBuffer2(srcValue), isTyped = !isArr && !isBuff && isTypedArray2(srcValue);
          newValue2 = srcValue;
          if (isArr || isBuff || isTyped) {
            if (isArray2(objValue)) {
              newValue2 = objValue;
            } else if (isArrayLikeObject(objValue)) {
              newValue2 = copyArray2(objValue);
            } else if (isBuff) {
              isCommon = false;
              newValue2 = cloneBuffer2(srcValue, true);
            } else if (isTyped) {
              isCommon = false;
              newValue2 = cloneTypedArray2(srcValue, true);
            } else {
              newValue2 = [];
            }
          } else if (isPlainObject2(srcValue) || isArguments2(srcValue)) {
            newValue2 = objValue;
            if (isArguments2(objValue)) {
              newValue2 = toPlainObject(objValue);
            } else if (!isObject2(objValue) || isFunction2(objValue)) {
              newValue2 = initCloneObject2(srcValue);
            }
          } else {
            isCommon = false;
          }
        }
        if (isCommon) {
          stack2.set(srcValue, newValue2);
          mergeFunc(newValue2, srcValue, srcIndex, customizer, stack2);
          stack2["delete"](srcValue);
        }
        assignMergeValue(object, key, newValue2);
      }
      __name(baseMergeDeep, "baseMergeDeep");
      function baseNth(array, n2) {
        var length = array.length;
        if (!length) {
          return;
        }
        n2 += n2 < 0 ? length : 0;
        return isIndex2(n2, length) ? array[n2] : undefined$1;
      }
      __name(baseNth, "baseNth");
      function baseOrderBy(collection, iteratees, orders) {
        if (iteratees.length) {
          iteratees = arrayMap(iteratees, function(iteratee2) {
            if (isArray2(iteratee2)) {
              return function(value3) {
                return baseGet(value3, iteratee2.length === 1 ? iteratee2[0] : iteratee2);
              };
            }
            return iteratee2;
          });
        } else {
          iteratees = [identity2];
        }
        var index2 = -1;
        iteratees = arrayMap(iteratees, baseUnary2(getIteratee()));
        var result2 = baseMap(collection, function(value3, key, collection2) {
          var criteria = arrayMap(iteratees, function(iteratee2) {
            return iteratee2(value3);
          });
          return { "criteria": criteria, "index": ++index2, "value": value3 };
        });
        return baseSortBy(result2, function(object, other) {
          return compareMultiple(object, other, orders);
        });
      }
      __name(baseOrderBy, "baseOrderBy");
      function basePick(object, paths) {
        return basePickBy(object, paths, function(value3, path) {
          return hasIn(object, path);
        });
      }
      __name(basePick, "basePick");
      function basePickBy(object, paths, predicate) {
        var index2 = -1, length = paths.length, result2 = {};
        while (++index2 < length) {
          var path = paths[index2], value3 = baseGet(object, path);
          if (predicate(value3, path)) {
            baseSet(result2, castPath(path, object), value3);
          }
        }
        return result2;
      }
      __name(basePickBy, "basePickBy");
      function basePropertyDeep(path) {
        return function(object) {
          return baseGet(object, path);
        };
      }
      __name(basePropertyDeep, "basePropertyDeep");
      function basePullAll(array, values2, iteratee2, comparator) {
        var indexOf2 = comparator ? baseIndexOfWith : baseIndexOf, index2 = -1, length = values2.length, seen2 = array;
        if (array === values2) {
          values2 = copyArray2(values2);
        }
        if (iteratee2) {
          seen2 = arrayMap(array, baseUnary2(iteratee2));
        }
        while (++index2 < length) {
          var fromIndex = 0, value3 = values2[index2], computed2 = iteratee2 ? iteratee2(value3) : value3;
          while ((fromIndex = indexOf2(seen2, computed2, fromIndex, comparator)) > -1) {
            if (seen2 !== array) {
              splice2.call(seen2, fromIndex, 1);
            }
            splice2.call(array, fromIndex, 1);
          }
        }
        return array;
      }
      __name(basePullAll, "basePullAll");
      function basePullAt(array, indexes) {
        var length = array ? indexes.length : 0, lastIndex = length - 1;
        while (length--) {
          var index2 = indexes[length];
          if (length == lastIndex || index2 !== previous) {
            var previous = index2;
            if (isIndex2(index2)) {
              splice2.call(array, index2, 1);
            } else {
              baseUnset(array, index2);
            }
          }
        }
        return array;
      }
      __name(basePullAt, "basePullAt");
      function baseRandom(lower, upper) {
        return lower + nativeFloor(nativeRandom() * (upper - lower + 1));
      }
      __name(baseRandom, "baseRandom");
      function baseRange(start2, end, step2, fromRight) {
        var index2 = -1, length = nativeMax(nativeCeil((end - start2) / (step2 || 1)), 0), result2 = Array2(length);
        while (length--) {
          result2[fromRight ? length : ++index2] = start2;
          start2 += step2;
        }
        return result2;
      }
      __name(baseRange, "baseRange");
      function baseRepeat(string, n2) {
        var result2 = "";
        if (!string || n2 < 1 || n2 > MAX_SAFE_INTEGER2) {
          return result2;
        }
        do {
          if (n2 % 2) {
            result2 += string;
          }
          n2 = nativeFloor(n2 / 2);
          if (n2) {
            string += string;
          }
        } while (n2);
        return result2;
      }
      __name(baseRepeat, "baseRepeat");
      function baseRest(func, start2) {
        return setToString(overRest(func, start2, identity2), func + "");
      }
      __name(baseRest, "baseRest");
      function baseSample(collection) {
        return arraySample(values(collection));
      }
      __name(baseSample, "baseSample");
      function baseSampleSize(collection, n2) {
        var array = values(collection);
        return shuffleSelf(array, baseClamp(n2, 0, array.length));
      }
      __name(baseSampleSize, "baseSampleSize");
      function baseSet(object, path, value3, customizer) {
        if (!isObject2(object)) {
          return object;
        }
        path = castPath(path, object);
        var index2 = -1, length = path.length, lastIndex = length - 1, nested = object;
        while (nested != null && ++index2 < length) {
          var key = toKey(path[index2]), newValue2 = value3;
          if (key === "__proto__" || key === "constructor" || key === "prototype") {
            return object;
          }
          if (index2 != lastIndex) {
            var objValue = nested[key];
            newValue2 = customizer ? customizer(objValue, key, nested) : undefined$1;
            if (newValue2 === undefined$1) {
              newValue2 = isObject2(objValue) ? objValue : isIndex2(path[index2 + 1]) ? [] : {};
            }
          }
          assignValue2(nested, key, newValue2);
          nested = nested[key];
        }
        return object;
      }
      __name(baseSet, "baseSet");
      var baseSetData = !metaMap ? identity2 : function(func, data30) {
        metaMap.set(func, data30);
        return func;
      };
      var baseSetToString = !defineProperty2 ? identity2 : function(func, string) {
        return defineProperty2(func, "toString", {
          "configurable": true,
          "enumerable": false,
          "value": constant(string),
          "writable": true
        });
      };
      function baseShuffle(collection) {
        return shuffleSelf(values(collection));
      }
      __name(baseShuffle, "baseShuffle");
      function baseSlice(array, start2, end) {
        var index2 = -1, length = array.length;
        if (start2 < 0) {
          start2 = -start2 > length ? 0 : length + start2;
        }
        end = end > length ? length : end;
        if (end < 0) {
          end += length;
        }
        length = start2 > end ? 0 : end - start2 >>> 0;
        start2 >>>= 0;
        var result2 = Array2(length);
        while (++index2 < length) {
          result2[index2] = array[index2 + start2];
        }
        return result2;
      }
      __name(baseSlice, "baseSlice");
      function baseSome(collection, predicate) {
        var result2;
        baseEach(collection, function(value3, index2, collection2) {
          result2 = predicate(value3, index2, collection2);
          return !result2;
        });
        return !!result2;
      }
      __name(baseSome, "baseSome");
      function baseSortedIndex(array, value3, retHighest) {
        var low = 0, high = array == null ? low : array.length;
        if (typeof value3 == "number" && value3 === value3 && high <= HALF_MAX_ARRAY_LENGTH) {
          while (low < high) {
            var mid = low + high >>> 1, computed2 = array[mid];
            if (computed2 !== null && !isSymbol2(computed2) && (retHighest ? computed2 <= value3 : computed2 < value3)) {
              low = mid + 1;
            } else {
              high = mid;
            }
          }
          return high;
        }
        return baseSortedIndexBy(array, value3, identity2, retHighest);
      }
      __name(baseSortedIndex, "baseSortedIndex");
      function baseSortedIndexBy(array, value3, iteratee2, retHighest) {
        var low = 0, high = array == null ? 0 : array.length;
        if (high === 0) {
          return 0;
        }
        value3 = iteratee2(value3);
        var valIsNaN = value3 !== value3, valIsNull = value3 === null, valIsSymbol = isSymbol2(value3), valIsUndefined = value3 === undefined$1;
        while (low < high) {
          var mid = nativeFloor((low + high) / 2), computed2 = iteratee2(array[mid]), othIsDefined = computed2 !== undefined$1, othIsNull = computed2 === null, othIsReflexive = computed2 === computed2, othIsSymbol = isSymbol2(computed2);
          if (valIsNaN) {
            var setLow = retHighest || othIsReflexive;
          } else if (valIsUndefined) {
            setLow = othIsReflexive && (retHighest || othIsDefined);
          } else if (valIsNull) {
            setLow = othIsReflexive && othIsDefined && (retHighest || !othIsNull);
          } else if (valIsSymbol) {
            setLow = othIsReflexive && othIsDefined && !othIsNull && (retHighest || !othIsSymbol);
          } else if (othIsNull || othIsSymbol) {
            setLow = false;
          } else {
            setLow = retHighest ? computed2 <= value3 : computed2 < value3;
          }
          if (setLow) {
            low = mid + 1;
          } else {
            high = mid;
          }
        }
        return nativeMin(high, MAX_ARRAY_INDEX);
      }
      __name(baseSortedIndexBy, "baseSortedIndexBy");
      function baseSortedUniq(array, iteratee2) {
        var index2 = -1, length = array.length, resIndex = 0, result2 = [];
        while (++index2 < length) {
          var value3 = array[index2], computed2 = iteratee2 ? iteratee2(value3) : value3;
          if (!index2 || !eq2(computed2, seen2)) {
            var seen2 = computed2;
            result2[resIndex++] = value3 === 0 ? 0 : value3;
          }
        }
        return result2;
      }
      __name(baseSortedUniq, "baseSortedUniq");
      function baseToNumber(value3) {
        if (typeof value3 == "number") {
          return value3;
        }
        if (isSymbol2(value3)) {
          return NAN;
        }
        return +value3;
      }
      __name(baseToNumber, "baseToNumber");
      function baseToString2(value3) {
        if (typeof value3 == "string") {
          return value3;
        }
        if (isArray2(value3)) {
          return arrayMap(value3, baseToString2) + "";
        }
        if (isSymbol2(value3)) {
          return symbolToString ? symbolToString.call(value3) : "";
        }
        var result2 = value3 + "";
        return result2 == "0" && 1 / value3 == -INFINITY2 ? "-0" : result2;
      }
      __name(baseToString2, "baseToString");
      function baseUniq(array, iteratee2, comparator) {
        var index2 = -1, includes2 = arrayIncludes, length = array.length, isCommon = true, result2 = [], seen2 = result2;
        if (comparator) {
          isCommon = false;
          includes2 = arrayIncludesWith;
        } else if (length >= LARGE_ARRAY_SIZE2) {
          var set4 = iteratee2 ? null : createSet(array);
          if (set4) {
            return setToArray(set4);
          }
          isCommon = false;
          includes2 = cacheHas;
          seen2 = new SetCache();
        } else {
          seen2 = iteratee2 ? [] : result2;
        }
        outer:
          while (++index2 < length) {
            var value3 = array[index2], computed2 = iteratee2 ? iteratee2(value3) : value3;
            value3 = comparator || value3 !== 0 ? value3 : 0;
            if (isCommon && computed2 === computed2) {
              var seenIndex = seen2.length;
              while (seenIndex--) {
                if (seen2[seenIndex] === computed2) {
                  continue outer;
                }
              }
              if (iteratee2) {
                seen2.push(computed2);
              }
              result2.push(value3);
            } else if (!includes2(seen2, computed2, comparator)) {
              if (seen2 !== result2) {
                seen2.push(computed2);
              }
              result2.push(value3);
            }
          }
        return result2;
      }
      __name(baseUniq, "baseUniq");
      function baseUnset(object, path) {
        path = castPath(path, object);
        object = parent(object, path);
        return object == null || delete object[toKey(last(path))];
      }
      __name(baseUnset, "baseUnset");
      function baseUpdate(object, path, updater, customizer) {
        return baseSet(object, path, updater(baseGet(object, path)), customizer);
      }
      __name(baseUpdate, "baseUpdate");
      function baseWhile(array, predicate, isDrop, fromRight) {
        var length = array.length, index2 = fromRight ? length : -1;
        while ((fromRight ? index2-- : ++index2 < length) && predicate(array[index2], index2, array)) {
        }
        return isDrop ? baseSlice(array, fromRight ? 0 : index2, fromRight ? index2 + 1 : length) : baseSlice(array, fromRight ? index2 + 1 : 0, fromRight ? length : index2);
      }
      __name(baseWhile, "baseWhile");
      function baseWrapperValue(value3, actions) {
        var result2 = value3;
        if (result2 instanceof LazyWrapper) {
          result2 = result2.value();
        }
        return arrayReduce(actions, function(result3, action) {
          return action.func.apply(action.thisArg, arrayPush2([result3], action.args));
        }, result2);
      }
      __name(baseWrapperValue, "baseWrapperValue");
      function baseXor(arrays, iteratee2, comparator) {
        var length = arrays.length;
        if (length < 2) {
          return length ? baseUniq(arrays[0]) : [];
        }
        var index2 = -1, result2 = Array2(length);
        while (++index2 < length) {
          var array = arrays[index2], othIndex = -1;
          while (++othIndex < length) {
            if (othIndex != index2) {
              result2[index2] = baseDifference(result2[index2] || array, arrays[othIndex], iteratee2, comparator);
            }
          }
        }
        return baseUniq(baseFlatten(result2, 1), iteratee2, comparator);
      }
      __name(baseXor, "baseXor");
      function baseZipObject(props, values2, assignFunc) {
        var index2 = -1, length = props.length, valsLength = values2.length, result2 = {};
        while (++index2 < length) {
          var value3 = index2 < valsLength ? values2[index2] : undefined$1;
          assignFunc(result2, props[index2], value3);
        }
        return result2;
      }
      __name(baseZipObject, "baseZipObject");
      function castArrayLikeObject(value3) {
        return isArrayLikeObject(value3) ? value3 : [];
      }
      __name(castArrayLikeObject, "castArrayLikeObject");
      function castFunction(value3) {
        return typeof value3 == "function" ? value3 : identity2;
      }
      __name(castFunction, "castFunction");
      function castPath(value3, object) {
        if (isArray2(value3)) {
          return value3;
        }
        return isKey(value3, object) ? [value3] : stringToPath(toString3(value3));
      }
      __name(castPath, "castPath");
      var castRest = baseRest;
      function castSlice(array, start2, end) {
        var length = array.length;
        end = end === undefined$1 ? length : end;
        return !start2 && end >= length ? array : baseSlice(array, start2, end);
      }
      __name(castSlice, "castSlice");
      var clearTimeout2 = ctxClearTimeout || function(id4) {
        return root34.clearTimeout(id4);
      };
      function cloneBuffer2(buffer2, isDeep) {
        if (isDeep) {
          return buffer2.slice();
        }
        var length = buffer2.length, result2 = allocUnsafe ? allocUnsafe(length) : new buffer2.constructor(length);
        buffer2.copy(result2);
        return result2;
      }
      __name(cloneBuffer2, "cloneBuffer");
      function cloneArrayBuffer2(arrayBuffer) {
        var result2 = new arrayBuffer.constructor(arrayBuffer.byteLength);
        new Uint8Array2(result2).set(new Uint8Array2(arrayBuffer));
        return result2;
      }
      __name(cloneArrayBuffer2, "cloneArrayBuffer");
      function cloneDataView2(dataView, isDeep) {
        var buffer2 = isDeep ? cloneArrayBuffer2(dataView.buffer) : dataView.buffer;
        return new dataView.constructor(buffer2, dataView.byteOffset, dataView.byteLength);
      }
      __name(cloneDataView2, "cloneDataView");
      function cloneRegExp2(regexp2) {
        var result2 = new regexp2.constructor(regexp2.source, reFlags2.exec(regexp2));
        result2.lastIndex = regexp2.lastIndex;
        return result2;
      }
      __name(cloneRegExp2, "cloneRegExp");
      function cloneSymbol2(symbol) {
        return symbolValueOf2 ? Object2(symbolValueOf2.call(symbol)) : {};
      }
      __name(cloneSymbol2, "cloneSymbol");
      function cloneTypedArray2(typedArray, isDeep) {
        var buffer2 = isDeep ? cloneArrayBuffer2(typedArray.buffer) : typedArray.buffer;
        return new typedArray.constructor(buffer2, typedArray.byteOffset, typedArray.length);
      }
      __name(cloneTypedArray2, "cloneTypedArray");
      function compareAscending(value3, other) {
        if (value3 !== other) {
          var valIsDefined = value3 !== undefined$1, valIsNull = value3 === null, valIsReflexive = value3 === value3, valIsSymbol = isSymbol2(value3);
          var othIsDefined = other !== undefined$1, othIsNull = other === null, othIsReflexive = other === other, othIsSymbol = isSymbol2(other);
          if (!othIsNull && !othIsSymbol && !valIsSymbol && value3 > other || valIsSymbol && othIsDefined && othIsReflexive && !othIsNull && !othIsSymbol || valIsNull && othIsDefined && othIsReflexive || !valIsDefined && othIsReflexive || !valIsReflexive) {
            return 1;
          }
          if (!valIsNull && !valIsSymbol && !othIsSymbol && value3 < other || othIsSymbol && valIsDefined && valIsReflexive && !valIsNull && !valIsSymbol || othIsNull && valIsDefined && valIsReflexive || !othIsDefined && valIsReflexive || !othIsReflexive) {
            return -1;
          }
        }
        return 0;
      }
      __name(compareAscending, "compareAscending");
      function compareMultiple(object, other, orders) {
        var index2 = -1, objCriteria = object.criteria, othCriteria = other.criteria, length = objCriteria.length, ordersLength = orders.length;
        while (++index2 < length) {
          var result2 = compareAscending(objCriteria[index2], othCriteria[index2]);
          if (result2) {
            if (index2 >= ordersLength) {
              return result2;
            }
            var order = orders[index2];
            return result2 * (order == "desc" ? -1 : 1);
          }
        }
        return object.index - other.index;
      }
      __name(compareMultiple, "compareMultiple");
      function composeArgs(args, partials, holders, isCurried) {
        var argsIndex = -1, argsLength = args.length, holdersLength = holders.length, leftIndex = -1, leftLength = partials.length, rangeLength = nativeMax(argsLength - holdersLength, 0), result2 = Array2(leftLength + rangeLength), isUncurried = !isCurried;
        while (++leftIndex < leftLength) {
          result2[leftIndex] = partials[leftIndex];
        }
        while (++argsIndex < holdersLength) {
          if (isUncurried || argsIndex < argsLength) {
            result2[holders[argsIndex]] = args[argsIndex];
          }
        }
        while (rangeLength--) {
          result2[leftIndex++] = args[argsIndex++];
        }
        return result2;
      }
      __name(composeArgs, "composeArgs");
      function composeArgsRight(args, partials, holders, isCurried) {
        var argsIndex = -1, argsLength = args.length, holdersIndex = -1, holdersLength = holders.length, rightIndex = -1, rightLength = partials.length, rangeLength = nativeMax(argsLength - holdersLength, 0), result2 = Array2(rangeLength + rightLength), isUncurried = !isCurried;
        while (++argsIndex < rangeLength) {
          result2[argsIndex] = args[argsIndex];
        }
        var offset = argsIndex;
        while (++rightIndex < rightLength) {
          result2[offset + rightIndex] = partials[rightIndex];
        }
        while (++holdersIndex < holdersLength) {
          if (isUncurried || argsIndex < argsLength) {
            result2[offset + holders[holdersIndex]] = args[argsIndex++];
          }
        }
        return result2;
      }
      __name(composeArgsRight, "composeArgsRight");
      function copyArray2(source, array) {
        var index2 = -1, length = source.length;
        array || (array = Array2(length));
        while (++index2 < length) {
          array[index2] = source[index2];
        }
        return array;
      }
      __name(copyArray2, "copyArray");
      function copyObject2(source, props, object, customizer) {
        var isNew = !object;
        object || (object = {});
        var index2 = -1, length = props.length;
        while (++index2 < length) {
          var key = props[index2];
          var newValue2 = customizer ? customizer(object[key], source[key], key, object, source) : undefined$1;
          if (newValue2 === undefined$1) {
            newValue2 = source[key];
          }
          if (isNew) {
            baseAssignValue2(object, key, newValue2);
          } else {
            assignValue2(object, key, newValue2);
          }
        }
        return object;
      }
      __name(copyObject2, "copyObject");
      function copySymbols2(source, object) {
        return copyObject2(source, getSymbols2(source), object);
      }
      __name(copySymbols2, "copySymbols");
      function copySymbolsIn2(source, object) {
        return copyObject2(source, getSymbolsIn2(source), object);
      }
      __name(copySymbolsIn2, "copySymbolsIn");
      function createAggregator(setter, initializer) {
        return function(collection, iteratee2) {
          var func = isArray2(collection) ? arrayAggregator : baseAggregator, accumulator = initializer ? initializer() : {};
          return func(collection, setter, getIteratee(iteratee2, 2), accumulator);
        };
      }
      __name(createAggregator, "createAggregator");
      function createAssigner(assigner) {
        return baseRest(function(object, sources) {
          var index2 = -1, length = sources.length, customizer = length > 1 ? sources[length - 1] : undefined$1, guard = length > 2 ? sources[2] : undefined$1;
          customizer = assigner.length > 3 && typeof customizer == "function" ? (length--, customizer) : undefined$1;
          if (guard && isIterateeCall(sources[0], sources[1], guard)) {
            customizer = length < 3 ? undefined$1 : customizer;
            length = 1;
          }
          object = Object2(object);
          while (++index2 < length) {
            var source = sources[index2];
            if (source) {
              assigner(object, source, index2, customizer);
            }
          }
          return object;
        });
      }
      __name(createAssigner, "createAssigner");
      function createBaseEach(eachFunc, fromRight) {
        return function(collection, iteratee2) {
          if (collection == null) {
            return collection;
          }
          if (!isArrayLike2(collection)) {
            return eachFunc(collection, iteratee2);
          }
          var length = collection.length, index2 = fromRight ? length : -1, iterable = Object2(collection);
          while (fromRight ? index2-- : ++index2 < length) {
            if (iteratee2(iterable[index2], index2, iterable) === false) {
              break;
            }
          }
          return collection;
        };
      }
      __name(createBaseEach, "createBaseEach");
      function createBaseFor(fromRight) {
        return function(object, iteratee2, keysFunc) {
          var index2 = -1, iterable = Object2(object), props = keysFunc(object), length = props.length;
          while (length--) {
            var key = props[fromRight ? length : ++index2];
            if (iteratee2(iterable[key], key, iterable) === false) {
              break;
            }
          }
          return object;
        };
      }
      __name(createBaseFor, "createBaseFor");
      function createBind(func, bitmask, thisArg) {
        var isBind = bitmask & WRAP_BIND_FLAG, Ctor = createCtor(func);
        function wrapper() {
          var fn = this && this !== root34 && this instanceof wrapper ? Ctor : func;
          return fn.apply(isBind ? thisArg : this, arguments);
        }
        __name(wrapper, "wrapper");
        return wrapper;
      }
      __name(createBind, "createBind");
      function createCaseFirst(methodName) {
        return function(string) {
          string = toString3(string);
          var strSymbols = hasUnicode(string) ? stringToArray2(string) : undefined$1;
          var chr = strSymbols ? strSymbols[0] : string.charAt(0);
          var trailing = strSymbols ? castSlice(strSymbols, 1).join("") : string.slice(1);
          return chr[methodName]() + trailing;
        };
      }
      __name(createCaseFirst, "createCaseFirst");
      function createCompounder(callback) {
        return function(string) {
          return arrayReduce(words(deburr(string).replace(reApos, "")), callback, "");
        };
      }
      __name(createCompounder, "createCompounder");
      function createCtor(Ctor) {
        return function() {
          var args = arguments;
          switch (args.length) {
            case 0:
              return new Ctor();
            case 1:
              return new Ctor(args[0]);
            case 2:
              return new Ctor(args[0], args[1]);
            case 3:
              return new Ctor(args[0], args[1], args[2]);
            case 4:
              return new Ctor(args[0], args[1], args[2], args[3]);
            case 5:
              return new Ctor(args[0], args[1], args[2], args[3], args[4]);
            case 6:
              return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5]);
            case 7:
              return new Ctor(args[0], args[1], args[2], args[3], args[4], args[5], args[6]);
          }
          var thisBinding = baseCreate2(Ctor.prototype), result2 = Ctor.apply(thisBinding, args);
          return isObject2(result2) ? result2 : thisBinding;
        };
      }
      __name(createCtor, "createCtor");
      function createCurry(func, bitmask, arity) {
        var Ctor = createCtor(func);
        function wrapper() {
          var length = arguments.length, args = Array2(length), index2 = length, placeholder = getHolder(wrapper);
          while (index2--) {
            args[index2] = arguments[index2];
          }
          var holders = length < 3 && args[0] !== placeholder && args[length - 1] !== placeholder ? [] : replaceHolders(args, placeholder);
          length -= holders.length;
          if (length < arity) {
            return createRecurry(
              func,
              bitmask,
              createHybrid,
              wrapper.placeholder,
              undefined$1,
              args,
              holders,
              undefined$1,
              undefined$1,
              arity - length
            );
          }
          var fn = this && this !== root34 && this instanceof wrapper ? Ctor : func;
          return apply2(fn, this, args);
        }
        __name(wrapper, "wrapper");
        return wrapper;
      }
      __name(createCurry, "createCurry");
      function createFind(findIndexFunc) {
        return function(collection, predicate, fromIndex) {
          var iterable = Object2(collection);
          if (!isArrayLike2(collection)) {
            var iteratee2 = getIteratee(predicate, 3);
            collection = keys2(collection);
            predicate = /* @__PURE__ */ __name(function(key) {
              return iteratee2(iterable[key], key, iterable);
            }, "predicate");
          }
          var index2 = findIndexFunc(collection, predicate, fromIndex);
          return index2 > -1 ? iterable[iteratee2 ? collection[index2] : index2] : undefined$1;
        };
      }
      __name(createFind, "createFind");
      function createFlow(fromRight) {
        return flatRest(function(funcs) {
          var length = funcs.length, index2 = length, prereq = LodashWrapper.prototype.thru;
          if (fromRight) {
            funcs.reverse();
          }
          while (index2--) {
            var func = funcs[index2];
            if (typeof func != "function") {
              throw new TypeError2(FUNC_ERROR_TEXT);
            }
            if (prereq && !wrapper && getFuncName(func) == "wrapper") {
              var wrapper = new LodashWrapper([], true);
            }
          }
          index2 = wrapper ? index2 : length;
          while (++index2 < length) {
            func = funcs[index2];
            var funcName = getFuncName(func), data30 = funcName == "wrapper" ? getData(func) : undefined$1;
            if (data30 && isLaziable(data30[0]) && data30[1] == (WRAP_ARY_FLAG | WRAP_CURRY_FLAG | WRAP_PARTIAL_FLAG | WRAP_REARG_FLAG) && !data30[4].length && data30[9] == 1) {
              wrapper = wrapper[getFuncName(data30[0])].apply(wrapper, data30[3]);
            } else {
              wrapper = func.length == 1 && isLaziable(func) ? wrapper[funcName]() : wrapper.thru(func);
            }
          }
          return function() {
            var args = arguments, value3 = args[0];
            if (wrapper && args.length == 1 && isArray2(value3)) {
              return wrapper.plant(value3).value();
            }
            var index3 = 0, result2 = length ? funcs[index3].apply(this, args) : value3;
            while (++index3 < length) {
              result2 = funcs[index3].call(this, result2);
            }
            return result2;
          };
        });
      }
      __name(createFlow, "createFlow");
      function createHybrid(func, bitmask, thisArg, partials, holders, partialsRight, holdersRight, argPos, ary2, arity) {
        var isAry = bitmask & WRAP_ARY_FLAG, isBind = bitmask & WRAP_BIND_FLAG, isBindKey = bitmask & WRAP_BIND_KEY_FLAG, isCurried = bitmask & (WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG), isFlip = bitmask & WRAP_FLIP_FLAG, Ctor = isBindKey ? undefined$1 : createCtor(func);
        function wrapper() {
          var length = arguments.length, args = Array2(length), index2 = length;
          while (index2--) {
            args[index2] = arguments[index2];
          }
          if (isCurried) {
            var placeholder = getHolder(wrapper), holdersCount = countHolders(args, placeholder);
          }
          if (partials) {
            args = composeArgs(args, partials, holders, isCurried);
          }
          if (partialsRight) {
            args = composeArgsRight(args, partialsRight, holdersRight, isCurried);
          }
          length -= holdersCount;
          if (isCurried && length < arity) {
            var newHolders = replaceHolders(args, placeholder);
            return createRecurry(
              func,
              bitmask,
              createHybrid,
              wrapper.placeholder,
              thisArg,
              args,
              newHolders,
              argPos,
              ary2,
              arity - length
            );
          }
          var thisBinding = isBind ? thisArg : this, fn = isBindKey ? thisBinding[func] : func;
          length = args.length;
          if (argPos) {
            args = reorder(args, argPos);
          } else if (isFlip && length > 1) {
            args.reverse();
          }
          if (isAry && ary2 < length) {
            args.length = ary2;
          }
          if (this && this !== root34 && this instanceof wrapper) {
            fn = Ctor || createCtor(fn);
          }
          return fn.apply(thisBinding, args);
        }
        __name(wrapper, "wrapper");
        return wrapper;
      }
      __name(createHybrid, "createHybrid");
      function createInverter(setter, toIteratee) {
        return function(object, iteratee2) {
          return baseInverter(object, setter, toIteratee(iteratee2), {});
        };
      }
      __name(createInverter, "createInverter");
      function createMathOperation(operator, defaultValue2) {
        return function(value3, other) {
          var result2;
          if (value3 === undefined$1 && other === undefined$1) {
            return defaultValue2;
          }
          if (value3 !== undefined$1) {
            result2 = value3;
          }
          if (other !== undefined$1) {
            if (result2 === undefined$1) {
              return other;
            }
            if (typeof value3 == "string" || typeof other == "string") {
              value3 = baseToString2(value3);
              other = baseToString2(other);
            } else {
              value3 = baseToNumber(value3);
              other = baseToNumber(other);
            }
            result2 = operator(value3, other);
          }
          return result2;
        };
      }
      __name(createMathOperation, "createMathOperation");
      function createOver(arrayFunc) {
        return flatRest(function(iteratees) {
          iteratees = arrayMap(iteratees, baseUnary2(getIteratee()));
          return baseRest(function(args) {
            var thisArg = this;
            return arrayFunc(iteratees, function(iteratee2) {
              return apply2(iteratee2, thisArg, args);
            });
          });
        });
      }
      __name(createOver, "createOver");
      function createPadding(length, chars2) {
        chars2 = chars2 === undefined$1 ? " " : baseToString2(chars2);
        var charsLength = chars2.length;
        if (charsLength < 2) {
          return charsLength ? baseRepeat(chars2, length) : chars2;
        }
        var result2 = baseRepeat(chars2, nativeCeil(length / stringSize(chars2)));
        return hasUnicode(chars2) ? castSlice(stringToArray2(result2), 0, length).join("") : result2.slice(0, length);
      }
      __name(createPadding, "createPadding");
      function createPartial(func, bitmask, thisArg, partials) {
        var isBind = bitmask & WRAP_BIND_FLAG, Ctor = createCtor(func);
        function wrapper() {
          var argsIndex = -1, argsLength = arguments.length, leftIndex = -1, leftLength = partials.length, args = Array2(leftLength + argsLength), fn = this && this !== root34 && this instanceof wrapper ? Ctor : func;
          while (++leftIndex < leftLength) {
            args[leftIndex] = partials[leftIndex];
          }
          while (argsLength--) {
            args[leftIndex++] = arguments[++argsIndex];
          }
          return apply2(fn, isBind ? thisArg : this, args);
        }
        __name(wrapper, "wrapper");
        return wrapper;
      }
      __name(createPartial, "createPartial");
      function createRange(fromRight) {
        return function(start2, end, step2) {
          if (step2 && typeof step2 != "number" && isIterateeCall(start2, end, step2)) {
            end = step2 = undefined$1;
          }
          start2 = toFinite(start2);
          if (end === undefined$1) {
            end = start2;
            start2 = 0;
          } else {
            end = toFinite(end);
          }
          step2 = step2 === undefined$1 ? start2 < end ? 1 : -1 : toFinite(step2);
          return baseRange(start2, end, step2, fromRight);
        };
      }
      __name(createRange, "createRange");
      function createRelationalOperation(operator) {
        return function(value3, other) {
          if (!(typeof value3 == "string" && typeof other == "string")) {
            value3 = toNumber2(value3);
            other = toNumber2(other);
          }
          return operator(value3, other);
        };
      }
      __name(createRelationalOperation, "createRelationalOperation");
      function createRecurry(func, bitmask, wrapFunc, placeholder, thisArg, partials, holders, argPos, ary2, arity) {
        var isCurry = bitmask & WRAP_CURRY_FLAG, newHolders = isCurry ? holders : undefined$1, newHoldersRight = isCurry ? undefined$1 : holders, newPartials = isCurry ? partials : undefined$1, newPartialsRight = isCurry ? undefined$1 : partials;
        bitmask |= isCurry ? WRAP_PARTIAL_FLAG : WRAP_PARTIAL_RIGHT_FLAG;
        bitmask &= ~(isCurry ? WRAP_PARTIAL_RIGHT_FLAG : WRAP_PARTIAL_FLAG);
        if (!(bitmask & WRAP_CURRY_BOUND_FLAG)) {
          bitmask &= ~(WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG);
        }
        var newData = [
          func,
          bitmask,
          thisArg,
          newPartials,
          newHolders,
          newPartialsRight,
          newHoldersRight,
          argPos,
          ary2,
          arity
        ];
        var result2 = wrapFunc.apply(undefined$1, newData);
        if (isLaziable(func)) {
          setData(result2, newData);
        }
        result2.placeholder = placeholder;
        return setWrapToString(result2, func, bitmask);
      }
      __name(createRecurry, "createRecurry");
      function createRound(methodName) {
        var func = Math2[methodName];
        return function(number2, precision) {
          number2 = toNumber2(number2);
          precision = precision == null ? 0 : nativeMin(toInteger(precision), 292);
          if (precision && nativeIsFinite(number2)) {
            var pair = (toString3(number2) + "e").split("e"), value3 = func(pair[0] + "e" + (+pair[1] + precision));
            pair = (toString3(value3) + "e").split("e");
            return +(pair[0] + "e" + (+pair[1] - precision));
          }
          return func(number2);
        };
      }
      __name(createRound, "createRound");
      var createSet = !(Set2 && 1 / setToArray(new Set2([, -0]))[1] == INFINITY2) ? noop2 : function(values2) {
        return new Set2(values2);
      };
      function createToPairs(keysFunc) {
        return function(object) {
          var tag = getTag2(object);
          if (tag == mapTag2) {
            return mapToArray(object);
          }
          if (tag == setTag2) {
            return setToPairs(object);
          }
          return baseToPairs(object, keysFunc(object));
        };
      }
      __name(createToPairs, "createToPairs");
      function createWrap(func, bitmask, thisArg, partials, holders, argPos, ary2, arity) {
        var isBindKey = bitmask & WRAP_BIND_KEY_FLAG;
        if (!isBindKey && typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        var length = partials ? partials.length : 0;
        if (!length) {
          bitmask &= ~(WRAP_PARTIAL_FLAG | WRAP_PARTIAL_RIGHT_FLAG);
          partials = holders = undefined$1;
        }
        ary2 = ary2 === undefined$1 ? ary2 : nativeMax(toInteger(ary2), 0);
        arity = arity === undefined$1 ? arity : toInteger(arity);
        length -= holders ? holders.length : 0;
        if (bitmask & WRAP_PARTIAL_RIGHT_FLAG) {
          var partialsRight = partials, holdersRight = holders;
          partials = holders = undefined$1;
        }
        var data30 = isBindKey ? undefined$1 : getData(func);
        var newData = [
          func,
          bitmask,
          thisArg,
          partials,
          holders,
          partialsRight,
          holdersRight,
          argPos,
          ary2,
          arity
        ];
        if (data30) {
          mergeData(newData, data30);
        }
        func = newData[0];
        bitmask = newData[1];
        thisArg = newData[2];
        partials = newData[3];
        holders = newData[4];
        arity = newData[9] = newData[9] === undefined$1 ? isBindKey ? 0 : func.length : nativeMax(newData[9] - length, 0);
        if (!arity && bitmask & (WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG)) {
          bitmask &= ~(WRAP_CURRY_FLAG | WRAP_CURRY_RIGHT_FLAG);
        }
        if (!bitmask || bitmask == WRAP_BIND_FLAG) {
          var result2 = createBind(func, bitmask, thisArg);
        } else if (bitmask == WRAP_CURRY_FLAG || bitmask == WRAP_CURRY_RIGHT_FLAG) {
          result2 = createCurry(func, bitmask, arity);
        } else if ((bitmask == WRAP_PARTIAL_FLAG || bitmask == (WRAP_BIND_FLAG | WRAP_PARTIAL_FLAG)) && !holders.length) {
          result2 = createPartial(func, bitmask, thisArg, partials);
        } else {
          result2 = createHybrid.apply(undefined$1, newData);
        }
        var setter = data30 ? baseSetData : setData;
        return setWrapToString(setter(result2, newData), func, bitmask);
      }
      __name(createWrap, "createWrap");
      function customDefaultsAssignIn(objValue, srcValue, key, object) {
        if (objValue === undefined$1 || eq2(objValue, objectProto2[key]) && !hasOwnProperty2.call(object, key)) {
          return srcValue;
        }
        return objValue;
      }
      __name(customDefaultsAssignIn, "customDefaultsAssignIn");
      function customDefaultsMerge(objValue, srcValue, key, object, source, stack2) {
        if (isObject2(objValue) && isObject2(srcValue)) {
          stack2.set(srcValue, objValue);
          baseMerge(objValue, srcValue, undefined$1, customDefaultsMerge, stack2);
          stack2["delete"](srcValue);
        }
        return objValue;
      }
      __name(customDefaultsMerge, "customDefaultsMerge");
      function customOmitClone(value3) {
        return isPlainObject2(value3) ? undefined$1 : value3;
      }
      __name(customOmitClone, "customOmitClone");
      function equalArrays(array, other, bitmask, customizer, equalFunc, stack2) {
        var isPartial = bitmask & COMPARE_PARTIAL_FLAG, arrLength = array.length, othLength = other.length;
        if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
          return false;
        }
        var arrStacked = stack2.get(array);
        var othStacked = stack2.get(other);
        if (arrStacked && othStacked) {
          return arrStacked == other && othStacked == array;
        }
        var index2 = -1, result2 = true, seen2 = bitmask & COMPARE_UNORDERED_FLAG ? new SetCache() : undefined$1;
        stack2.set(array, other);
        stack2.set(other, array);
        while (++index2 < arrLength) {
          var arrValue = array[index2], othValue = other[index2];
          if (customizer) {
            var compared = isPartial ? customizer(othValue, arrValue, index2, other, array, stack2) : customizer(arrValue, othValue, index2, array, other, stack2);
          }
          if (compared !== undefined$1) {
            if (compared) {
              continue;
            }
            result2 = false;
            break;
          }
          if (seen2) {
            if (!arraySome(other, function(othValue2, othIndex) {
              if (!cacheHas(seen2, othIndex) && (arrValue === othValue2 || equalFunc(arrValue, othValue2, bitmask, customizer, stack2))) {
                return seen2.push(othIndex);
              }
            })) {
              result2 = false;
              break;
            }
          } else if (!(arrValue === othValue || equalFunc(arrValue, othValue, bitmask, customizer, stack2))) {
            result2 = false;
            break;
          }
        }
        stack2["delete"](array);
        stack2["delete"](other);
        return result2;
      }
      __name(equalArrays, "equalArrays");
      function equalByTag(object, other, tag, bitmask, customizer, equalFunc, stack2) {
        switch (tag) {
          case dataViewTag2:
            if (object.byteLength != other.byteLength || object.byteOffset != other.byteOffset) {
              return false;
            }
            object = object.buffer;
            other = other.buffer;
          case arrayBufferTag2:
            if (object.byteLength != other.byteLength || !equalFunc(new Uint8Array2(object), new Uint8Array2(other))) {
              return false;
            }
            return true;
          case boolTag2:
          case dateTag2:
          case numberTag2:
            return eq2(+object, +other);
          case errorTag2:
            return object.name == other.name && object.message == other.message;
          case regexpTag2:
          case stringTag2:
            return object == other + "";
          case mapTag2:
            var convert = mapToArray;
          case setTag2:
            var isPartial = bitmask & COMPARE_PARTIAL_FLAG;
            convert || (convert = setToArray);
            if (object.size != other.size && !isPartial) {
              return false;
            }
            var stacked = stack2.get(object);
            if (stacked) {
              return stacked == other;
            }
            bitmask |= COMPARE_UNORDERED_FLAG;
            stack2.set(object, other);
            var result2 = equalArrays(convert(object), convert(other), bitmask, customizer, equalFunc, stack2);
            stack2["delete"](object);
            return result2;
          case symbolTag2:
            if (symbolValueOf2) {
              return symbolValueOf2.call(object) == symbolValueOf2.call(other);
            }
        }
        return false;
      }
      __name(equalByTag, "equalByTag");
      function equalObjects(object, other, bitmask, customizer, equalFunc, stack2) {
        var isPartial = bitmask & COMPARE_PARTIAL_FLAG, objProps = getAllKeys2(object), objLength = objProps.length, othProps = getAllKeys2(other), othLength = othProps.length;
        if (objLength != othLength && !isPartial) {
          return false;
        }
        var index2 = objLength;
        while (index2--) {
          var key = objProps[index2];
          if (!(isPartial ? key in other : hasOwnProperty2.call(other, key))) {
            return false;
          }
        }
        var objStacked = stack2.get(object);
        var othStacked = stack2.get(other);
        if (objStacked && othStacked) {
          return objStacked == other && othStacked == object;
        }
        var result2 = true;
        stack2.set(object, other);
        stack2.set(other, object);
        var skipCtor = isPartial;
        while (++index2 < objLength) {
          key = objProps[index2];
          var objValue = object[key], othValue = other[key];
          if (customizer) {
            var compared = isPartial ? customizer(othValue, objValue, key, other, object, stack2) : customizer(objValue, othValue, key, object, other, stack2);
          }
          if (!(compared === undefined$1 ? objValue === othValue || equalFunc(objValue, othValue, bitmask, customizer, stack2) : compared)) {
            result2 = false;
            break;
          }
          skipCtor || (skipCtor = key == "constructor");
        }
        if (result2 && !skipCtor) {
          var objCtor = object.constructor, othCtor = other.constructor;
          if (objCtor != othCtor && ("constructor" in object && "constructor" in other) && !(typeof objCtor == "function" && objCtor instanceof objCtor && typeof othCtor == "function" && othCtor instanceof othCtor)) {
            result2 = false;
          }
        }
        stack2["delete"](object);
        stack2["delete"](other);
        return result2;
      }
      __name(equalObjects, "equalObjects");
      function flatRest(func) {
        return setToString(overRest(func, undefined$1, flatten2), func + "");
      }
      __name(flatRest, "flatRest");
      function getAllKeys2(object) {
        return baseGetAllKeys2(object, keys2, getSymbols2);
      }
      __name(getAllKeys2, "getAllKeys");
      function getAllKeysIn2(object) {
        return baseGetAllKeys2(object, keysIn2, getSymbolsIn2);
      }
      __name(getAllKeysIn2, "getAllKeysIn");
      var getData = !metaMap ? noop2 : function(func) {
        return metaMap.get(func);
      };
      function getFuncName(func) {
        var result2 = func.name + "", array = realNames[result2], length = hasOwnProperty2.call(realNames, result2) ? array.length : 0;
        while (length--) {
          var data30 = array[length], otherFunc = data30.func;
          if (otherFunc == null || otherFunc == func) {
            return data30.name;
          }
        }
        return result2;
      }
      __name(getFuncName, "getFuncName");
      function getHolder(func) {
        var object = hasOwnProperty2.call(lodash2, "placeholder") ? lodash2 : func;
        return object.placeholder;
      }
      __name(getHolder, "getHolder");
      function getIteratee() {
        var result2 = lodash2.iteratee || iteratee;
        result2 = result2 === iteratee ? baseIteratee : result2;
        return arguments.length ? result2(arguments[0], arguments[1]) : result2;
      }
      __name(getIteratee, "getIteratee");
      function getMapData2(map4, key) {
        var data30 = map4.__data__;
        return isKeyable2(key) ? data30[typeof key == "string" ? "string" : "hash"] : data30.map;
      }
      __name(getMapData2, "getMapData");
      function getMatchData(object) {
        var result2 = keys2(object), length = result2.length;
        while (length--) {
          var key = result2[length], value3 = object[key];
          result2[length] = [key, value3, isStrictComparable(value3)];
        }
        return result2;
      }
      __name(getMatchData, "getMatchData");
      function getNative2(object, key) {
        var value3 = getValue2(object, key);
        return baseIsNative2(value3) ? value3 : undefined$1;
      }
      __name(getNative2, "getNative");
      function getRawTag2(value3) {
        var isOwn = hasOwnProperty2.call(value3, symToStringTag2), tag = value3[symToStringTag2];
        try {
          value3[symToStringTag2] = undefined$1;
          var unmasked = true;
        } catch (e2) {
        }
        var result2 = nativeObjectToString2.call(value3);
        if (unmasked) {
          if (isOwn) {
            value3[symToStringTag2] = tag;
          } else {
            delete value3[symToStringTag2];
          }
        }
        return result2;
      }
      __name(getRawTag2, "getRawTag");
      var getSymbols2 = !nativeGetSymbols2 ? stubArray2 : function(object) {
        if (object == null) {
          return [];
        }
        object = Object2(object);
        return arrayFilter2(nativeGetSymbols2(object), function(symbol) {
          return propertyIsEnumerable2.call(object, symbol);
        });
      };
      var getSymbolsIn2 = !nativeGetSymbols2 ? stubArray2 : function(object) {
        var result2 = [];
        while (object) {
          arrayPush2(result2, getSymbols2(object));
          object = getPrototype2(object);
        }
        return result2;
      };
      var getTag2 = baseGetTag2;
      if (DataView2 && getTag2(new DataView2(new ArrayBuffer(1))) != dataViewTag2 || Map2 && getTag2(new Map2()) != mapTag2 || Promise2 && getTag2(Promise2.resolve()) != promiseTag2 || Set2 && getTag2(new Set2()) != setTag2 || WeakMap2 && getTag2(new WeakMap2()) != weakMapTag2) {
        getTag2 = /* @__PURE__ */ __name(function(value3) {
          var result2 = baseGetTag2(value3), Ctor = result2 == objectTag2 ? value3.constructor : undefined$1, ctorString = Ctor ? toSource2(Ctor) : "";
          if (ctorString) {
            switch (ctorString) {
              case dataViewCtorString2:
                return dataViewTag2;
              case mapCtorString2:
                return mapTag2;
              case promiseCtorString2:
                return promiseTag2;
              case setCtorString2:
                return setTag2;
              case weakMapCtorString2:
                return weakMapTag2;
            }
          }
          return result2;
        }, "getTag");
      }
      function getView(start2, end, transforms) {
        var index2 = -1, length = transforms.length;
        while (++index2 < length) {
          var data30 = transforms[index2], size2 = data30.size;
          switch (data30.type) {
            case "drop":
              start2 += size2;
              break;
            case "dropRight":
              end -= size2;
              break;
            case "take":
              end = nativeMin(end, start2 + size2);
              break;
            case "takeRight":
              start2 = nativeMax(start2, end - size2);
              break;
          }
        }
        return { "start": start2, "end": end };
      }
      __name(getView, "getView");
      function getWrapDetails(source) {
        var match2 = source.match(reWrapDetails);
        return match2 ? match2[1].split(reSplitDetails) : [];
      }
      __name(getWrapDetails, "getWrapDetails");
      function hasPath(object, path, hasFunc) {
        path = castPath(path, object);
        var index2 = -1, length = path.length, result2 = false;
        while (++index2 < length) {
          var key = toKey(path[index2]);
          if (!(result2 = object != null && hasFunc(object, key))) {
            break;
          }
          object = object[key];
        }
        if (result2 || ++index2 != length) {
          return result2;
        }
        length = object == null ? 0 : object.length;
        return !!length && isLength2(length) && isIndex2(key, length) && (isArray2(object) || isArguments2(object));
      }
      __name(hasPath, "hasPath");
      function initCloneArray2(array) {
        var length = array.length, result2 = new array.constructor(length);
        if (length && typeof array[0] == "string" && hasOwnProperty2.call(array, "index")) {
          result2.index = array.index;
          result2.input = array.input;
        }
        return result2;
      }
      __name(initCloneArray2, "initCloneArray");
      function initCloneObject2(object) {
        return typeof object.constructor == "function" && !isPrototype2(object) ? baseCreate2(getPrototype2(object)) : {};
      }
      __name(initCloneObject2, "initCloneObject");
      function initCloneByTag2(object, tag, isDeep) {
        var Ctor = object.constructor;
        switch (tag) {
          case arrayBufferTag2:
            return cloneArrayBuffer2(object);
          case boolTag2:
          case dateTag2:
            return new Ctor(+object);
          case dataViewTag2:
            return cloneDataView2(object, isDeep);
          case float32Tag2:
          case float64Tag2:
          case int8Tag2:
          case int16Tag2:
          case int32Tag2:
          case uint8Tag2:
          case uint8ClampedTag2:
          case uint16Tag2:
          case uint32Tag2:
            return cloneTypedArray2(object, isDeep);
          case mapTag2:
            return new Ctor();
          case numberTag2:
          case stringTag2:
            return new Ctor(object);
          case regexpTag2:
            return cloneRegExp2(object);
          case setTag2:
            return new Ctor();
          case symbolTag2:
            return cloneSymbol2(object);
        }
      }
      __name(initCloneByTag2, "initCloneByTag");
      function insertWrapDetails(source, details) {
        var length = details.length;
        if (!length) {
          return source;
        }
        var lastIndex = length - 1;
        details[lastIndex] = (length > 1 ? "& " : "") + details[lastIndex];
        details = details.join(length > 2 ? ", " : " ");
        return source.replace(reWrapComment, "{\n/* [wrapped with " + details + "] */\n");
      }
      __name(insertWrapDetails, "insertWrapDetails");
      function isFlattenable(value3) {
        return isArray2(value3) || isArguments2(value3) || !!(spreadableSymbol && value3 && value3[spreadableSymbol]);
      }
      __name(isFlattenable, "isFlattenable");
      function isIndex2(value3, length) {
        var type = typeof value3;
        length = length == null ? MAX_SAFE_INTEGER2 : length;
        return !!length && (type == "number" || type != "symbol" && reIsUint2.test(value3)) && (value3 > -1 && value3 % 1 == 0 && value3 < length);
      }
      __name(isIndex2, "isIndex");
      function isIterateeCall(value3, index2, object) {
        if (!isObject2(object)) {
          return false;
        }
        var type = typeof index2;
        if (type == "number" ? isArrayLike2(object) && isIndex2(index2, object.length) : type == "string" && index2 in object) {
          return eq2(object[index2], value3);
        }
        return false;
      }
      __name(isIterateeCall, "isIterateeCall");
      function isKey(value3, object) {
        if (isArray2(value3)) {
          return false;
        }
        var type = typeof value3;
        if (type == "number" || type == "symbol" || type == "boolean" || value3 == null || isSymbol2(value3)) {
          return true;
        }
        return reIsPlainProp.test(value3) || !reIsDeepProp.test(value3) || object != null && value3 in Object2(object);
      }
      __name(isKey, "isKey");
      function isKeyable2(value3) {
        var type = typeof value3;
        return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value3 !== "__proto__" : value3 === null;
      }
      __name(isKeyable2, "isKeyable");
      function isLaziable(func) {
        var funcName = getFuncName(func), other = lodash2[funcName];
        if (typeof other != "function" || !(funcName in LazyWrapper.prototype)) {
          return false;
        }
        if (func === other) {
          return true;
        }
        var data30 = getData(other);
        return !!data30 && func === data30[0];
      }
      __name(isLaziable, "isLaziable");
      function isMasked2(func) {
        return !!maskSrcKey2 && maskSrcKey2 in func;
      }
      __name(isMasked2, "isMasked");
      var isMaskable = coreJsData2 ? isFunction2 : stubFalse2;
      function isPrototype2(value3) {
        var Ctor = value3 && value3.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto2;
        return value3 === proto;
      }
      __name(isPrototype2, "isPrototype");
      function isStrictComparable(value3) {
        return value3 === value3 && !isObject2(value3);
      }
      __name(isStrictComparable, "isStrictComparable");
      function matchesStrictComparable(key, srcValue) {
        return function(object) {
          if (object == null) {
            return false;
          }
          return object[key] === srcValue && (srcValue !== undefined$1 || key in Object2(object));
        };
      }
      __name(matchesStrictComparable, "matchesStrictComparable");
      function memoizeCapped(func) {
        var result2 = memoize(func, function(key) {
          if (cache2.size === MAX_MEMOIZE_SIZE) {
            cache2.clear();
          }
          return key;
        });
        var cache2 = result2.cache;
        return result2;
      }
      __name(memoizeCapped, "memoizeCapped");
      function mergeData(data30, source) {
        var bitmask = data30[1], srcBitmask = source[1], newBitmask = bitmask | srcBitmask, isCommon = newBitmask < (WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG | WRAP_ARY_FLAG);
        var isCombo = srcBitmask == WRAP_ARY_FLAG && bitmask == WRAP_CURRY_FLAG || srcBitmask == WRAP_ARY_FLAG && bitmask == WRAP_REARG_FLAG && data30[7].length <= source[8] || srcBitmask == (WRAP_ARY_FLAG | WRAP_REARG_FLAG) && source[7].length <= source[8] && bitmask == WRAP_CURRY_FLAG;
        if (!(isCommon || isCombo)) {
          return data30;
        }
        if (srcBitmask & WRAP_BIND_FLAG) {
          data30[2] = source[2];
          newBitmask |= bitmask & WRAP_BIND_FLAG ? 0 : WRAP_CURRY_BOUND_FLAG;
        }
        var value3 = source[3];
        if (value3) {
          var partials = data30[3];
          data30[3] = partials ? composeArgs(partials, value3, source[4]) : value3;
          data30[4] = partials ? replaceHolders(data30[3], PLACEHOLDER) : source[4];
        }
        value3 = source[5];
        if (value3) {
          partials = data30[5];
          data30[5] = partials ? composeArgsRight(partials, value3, source[6]) : value3;
          data30[6] = partials ? replaceHolders(data30[5], PLACEHOLDER) : source[6];
        }
        value3 = source[7];
        if (value3) {
          data30[7] = value3;
        }
        if (srcBitmask & WRAP_ARY_FLAG) {
          data30[8] = data30[8] == null ? source[8] : nativeMin(data30[8], source[8]);
        }
        if (data30[9] == null) {
          data30[9] = source[9];
        }
        data30[0] = source[0];
        data30[1] = newBitmask;
        return data30;
      }
      __name(mergeData, "mergeData");
      function nativeKeysIn2(object) {
        var result2 = [];
        if (object != null) {
          for (var key in Object2(object)) {
            result2.push(key);
          }
        }
        return result2;
      }
      __name(nativeKeysIn2, "nativeKeysIn");
      function objectToString2(value3) {
        return nativeObjectToString2.call(value3);
      }
      __name(objectToString2, "objectToString");
      function overRest(func, start2, transform3) {
        start2 = nativeMax(start2 === undefined$1 ? func.length - 1 : start2, 0);
        return function() {
          var args = arguments, index2 = -1, length = nativeMax(args.length - start2, 0), array = Array2(length);
          while (++index2 < length) {
            array[index2] = args[start2 + index2];
          }
          index2 = -1;
          var otherArgs = Array2(start2 + 1);
          while (++index2 < start2) {
            otherArgs[index2] = args[index2];
          }
          otherArgs[start2] = transform3(array);
          return apply2(func, this, otherArgs);
        };
      }
      __name(overRest, "overRest");
      function parent(object, path) {
        return path.length < 2 ? object : baseGet(object, baseSlice(path, 0, -1));
      }
      __name(parent, "parent");
      function reorder(array, indexes) {
        var arrLength = array.length, length = nativeMin(indexes.length, arrLength), oldArray = copyArray2(array);
        while (length--) {
          var index2 = indexes[length];
          array[length] = isIndex2(index2, arrLength) ? oldArray[index2] : undefined$1;
        }
        return array;
      }
      __name(reorder, "reorder");
      function safeGet(object, key) {
        if (key === "constructor" && typeof object[key] === "function") {
          return;
        }
        if (key == "__proto__") {
          return;
        }
        return object[key];
      }
      __name(safeGet, "safeGet");
      var setData = shortOut(baseSetData);
      var setTimeout2 = ctxSetTimeout || function(func, wait) {
        return root34.setTimeout(func, wait);
      };
      var setToString = shortOut(baseSetToString);
      function setWrapToString(wrapper, reference2, bitmask) {
        var source = reference2 + "";
        return setToString(wrapper, insertWrapDetails(source, updateWrapDetails(getWrapDetails(source), bitmask)));
      }
      __name(setWrapToString, "setWrapToString");
      function shortOut(func) {
        var count = 0, lastCalled = 0;
        return function() {
          var stamp = nativeNow(), remaining = HOT_SPAN - (stamp - lastCalled);
          lastCalled = stamp;
          if (remaining > 0) {
            if (++count >= HOT_COUNT) {
              return arguments[0];
            }
          } else {
            count = 0;
          }
          return func.apply(undefined$1, arguments);
        };
      }
      __name(shortOut, "shortOut");
      function shuffleSelf(array, size2) {
        var index2 = -1, length = array.length, lastIndex = length - 1;
        size2 = size2 === undefined$1 ? length : size2;
        while (++index2 < size2) {
          var rand2 = baseRandom(index2, lastIndex), value3 = array[rand2];
          array[rand2] = array[index2];
          array[index2] = value3;
        }
        array.length = size2;
        return array;
      }
      __name(shuffleSelf, "shuffleSelf");
      var stringToPath = memoizeCapped(function(string) {
        var result2 = [];
        if (string.charCodeAt(0) === 46) {
          result2.push("");
        }
        string.replace(rePropName, function(match2, number2, quote, subString) {
          result2.push(quote ? subString.replace(reEscapeChar, "$1") : number2 || match2);
        });
        return result2;
      });
      function toKey(value3) {
        if (typeof value3 == "string" || isSymbol2(value3)) {
          return value3;
        }
        var result2 = value3 + "";
        return result2 == "0" && 1 / value3 == -INFINITY2 ? "-0" : result2;
      }
      __name(toKey, "toKey");
      function toSource2(func) {
        if (func != null) {
          try {
            return funcToString2.call(func);
          } catch (e2) {
          }
          try {
            return func + "";
          } catch (e2) {
          }
        }
        return "";
      }
      __name(toSource2, "toSource");
      function updateWrapDetails(details, bitmask) {
        arrayEach2(wrapFlags, function(pair) {
          var value3 = "_." + pair[0];
          if (bitmask & pair[1] && !arrayIncludes(details, value3)) {
            details.push(value3);
          }
        });
        return details.sort();
      }
      __name(updateWrapDetails, "updateWrapDetails");
      function wrapperClone(wrapper) {
        if (wrapper instanceof LazyWrapper) {
          return wrapper.clone();
        }
        var result2 = new LodashWrapper(wrapper.__wrapped__, wrapper.__chain__);
        result2.__actions__ = copyArray2(wrapper.__actions__);
        result2.__index__ = wrapper.__index__;
        result2.__values__ = wrapper.__values__;
        return result2;
      }
      __name(wrapperClone, "wrapperClone");
      function chunk(array, size2, guard) {
        if (guard ? isIterateeCall(array, size2, guard) : size2 === undefined$1) {
          size2 = 1;
        } else {
          size2 = nativeMax(toInteger(size2), 0);
        }
        var length = array == null ? 0 : array.length;
        if (!length || size2 < 1) {
          return [];
        }
        var index2 = 0, resIndex = 0, result2 = Array2(nativeCeil(length / size2));
        while (index2 < length) {
          result2[resIndex++] = baseSlice(array, index2, index2 += size2);
        }
        return result2;
      }
      __name(chunk, "chunk");
      function compact(array) {
        var index2 = -1, length = array == null ? 0 : array.length, resIndex = 0, result2 = [];
        while (++index2 < length) {
          var value3 = array[index2];
          if (value3) {
            result2[resIndex++] = value3;
          }
        }
        return result2;
      }
      __name(compact, "compact");
      function concat() {
        var length = arguments.length;
        if (!length) {
          return [];
        }
        var args = Array2(length - 1), array = arguments[0], index2 = length;
        while (index2--) {
          args[index2 - 1] = arguments[index2];
        }
        return arrayPush2(isArray2(array) ? copyArray2(array) : [array], baseFlatten(args, 1));
      }
      __name(concat, "concat");
      var difference = baseRest(function(array, values2) {
        return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values2, 1, isArrayLikeObject, true)) : [];
      });
      var differenceBy = baseRest(function(array, values2) {
        var iteratee2 = last(values2);
        if (isArrayLikeObject(iteratee2)) {
          iteratee2 = undefined$1;
        }
        return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values2, 1, isArrayLikeObject, true), getIteratee(iteratee2, 2)) : [];
      });
      var differenceWith = baseRest(function(array, values2) {
        var comparator = last(values2);
        if (isArrayLikeObject(comparator)) {
          comparator = undefined$1;
        }
        return isArrayLikeObject(array) ? baseDifference(array, baseFlatten(values2, 1, isArrayLikeObject, true), undefined$1, comparator) : [];
      });
      function drop(array, n2, guard) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        n2 = guard || n2 === undefined$1 ? 1 : toInteger(n2);
        return baseSlice(array, n2 < 0 ? 0 : n2, length);
      }
      __name(drop, "drop");
      function dropRight(array, n2, guard) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        n2 = guard || n2 === undefined$1 ? 1 : toInteger(n2);
        n2 = length - n2;
        return baseSlice(array, 0, n2 < 0 ? 0 : n2);
      }
      __name(dropRight, "dropRight");
      function dropRightWhile(array, predicate) {
        return array && array.length ? baseWhile(array, getIteratee(predicate, 3), true, true) : [];
      }
      __name(dropRightWhile, "dropRightWhile");
      function dropWhile(array, predicate) {
        return array && array.length ? baseWhile(array, getIteratee(predicate, 3), true) : [];
      }
      __name(dropWhile, "dropWhile");
      function fill2(array, value3, start2, end) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        if (start2 && typeof start2 != "number" && isIterateeCall(array, value3, start2)) {
          start2 = 0;
          end = length;
        }
        return baseFill(array, value3, start2, end);
      }
      __name(fill2, "fill");
      function findIndex(array, predicate, fromIndex) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return -1;
        }
        var index2 = fromIndex == null ? 0 : toInteger(fromIndex);
        if (index2 < 0) {
          index2 = nativeMax(length + index2, 0);
        }
        return baseFindIndex(array, getIteratee(predicate, 3), index2);
      }
      __name(findIndex, "findIndex");
      function findLastIndex2(array, predicate, fromIndex) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return -1;
        }
        var index2 = length - 1;
        if (fromIndex !== undefined$1) {
          index2 = toInteger(fromIndex);
          index2 = fromIndex < 0 ? nativeMax(length + index2, 0) : nativeMin(index2, length - 1);
        }
        return baseFindIndex(array, getIteratee(predicate, 3), index2, true);
      }
      __name(findLastIndex2, "findLastIndex");
      function flatten2(array) {
        var length = array == null ? 0 : array.length;
        return length ? baseFlatten(array, 1) : [];
      }
      __name(flatten2, "flatten");
      function flattenDeep(array) {
        var length = array == null ? 0 : array.length;
        return length ? baseFlatten(array, INFINITY2) : [];
      }
      __name(flattenDeep, "flattenDeep");
      function flattenDepth(array, depth) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        depth = depth === undefined$1 ? 1 : toInteger(depth);
        return baseFlatten(array, depth);
      }
      __name(flattenDepth, "flattenDepth");
      function fromPairs(pairs) {
        var index2 = -1, length = pairs == null ? 0 : pairs.length, result2 = {};
        while (++index2 < length) {
          var pair = pairs[index2];
          result2[pair[0]] = pair[1];
        }
        return result2;
      }
      __name(fromPairs, "fromPairs");
      function head(array) {
        return array && array.length ? array[0] : undefined$1;
      }
      __name(head, "head");
      function indexOf(array, value3, fromIndex) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return -1;
        }
        var index2 = fromIndex == null ? 0 : toInteger(fromIndex);
        if (index2 < 0) {
          index2 = nativeMax(length + index2, 0);
        }
        return baseIndexOf(array, value3, index2);
      }
      __name(indexOf, "indexOf");
      function initial(array) {
        var length = array == null ? 0 : array.length;
        return length ? baseSlice(array, 0, -1) : [];
      }
      __name(initial, "initial");
      var intersection = baseRest(function(arrays) {
        var mapped = arrayMap(arrays, castArrayLikeObject);
        return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped) : [];
      });
      var intersectionBy = baseRest(function(arrays) {
        var iteratee2 = last(arrays), mapped = arrayMap(arrays, castArrayLikeObject);
        if (iteratee2 === last(mapped)) {
          iteratee2 = undefined$1;
        } else {
          mapped.pop();
        }
        return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped, getIteratee(iteratee2, 2)) : [];
      });
      var intersectionWith = baseRest(function(arrays) {
        var comparator = last(arrays), mapped = arrayMap(arrays, castArrayLikeObject);
        comparator = typeof comparator == "function" ? comparator : undefined$1;
        if (comparator) {
          mapped.pop();
        }
        return mapped.length && mapped[0] === arrays[0] ? baseIntersection(mapped, undefined$1, comparator) : [];
      });
      function join2(array, separator) {
        return array == null ? "" : nativeJoin.call(array, separator);
      }
      __name(join2, "join");
      function last(array) {
        var length = array == null ? 0 : array.length;
        return length ? array[length - 1] : undefined$1;
      }
      __name(last, "last");
      function lastIndexOf(array, value3, fromIndex) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return -1;
        }
        var index2 = length;
        if (fromIndex !== undefined$1) {
          index2 = toInteger(fromIndex);
          index2 = index2 < 0 ? nativeMax(length + index2, 0) : nativeMin(index2, length - 1);
        }
        return value3 === value3 ? strictLastIndexOf(array, value3, index2) : baseFindIndex(array, baseIsNaN, index2, true);
      }
      __name(lastIndexOf, "lastIndexOf");
      function nth(array, n2) {
        return array && array.length ? baseNth(array, toInteger(n2)) : undefined$1;
      }
      __name(nth, "nth");
      var pull = baseRest(pullAll);
      function pullAll(array, values2) {
        return array && array.length && values2 && values2.length ? basePullAll(array, values2) : array;
      }
      __name(pullAll, "pullAll");
      function pullAllBy(array, values2, iteratee2) {
        return array && array.length && values2 && values2.length ? basePullAll(array, values2, getIteratee(iteratee2, 2)) : array;
      }
      __name(pullAllBy, "pullAllBy");
      function pullAllWith(array, values2, comparator) {
        return array && array.length && values2 && values2.length ? basePullAll(array, values2, undefined$1, comparator) : array;
      }
      __name(pullAllWith, "pullAllWith");
      var pullAt = flatRest(function(array, indexes) {
        var length = array == null ? 0 : array.length, result2 = baseAt(array, indexes);
        basePullAt(array, arrayMap(indexes, function(index2) {
          return isIndex2(index2, length) ? +index2 : index2;
        }).sort(compareAscending));
        return result2;
      });
      function remove4(array, predicate) {
        var result2 = [];
        if (!(array && array.length)) {
          return result2;
        }
        var index2 = -1, indexes = [], length = array.length;
        predicate = getIteratee(predicate, 3);
        while (++index2 < length) {
          var value3 = array[index2];
          if (predicate(value3, index2, array)) {
            result2.push(value3);
            indexes.push(index2);
          }
        }
        basePullAt(array, indexes);
        return result2;
      }
      __name(remove4, "remove");
      function reverse2(array) {
        return array == null ? array : nativeReverse.call(array);
      }
      __name(reverse2, "reverse");
      function slice2(array, start2, end) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        if (end && typeof end != "number" && isIterateeCall(array, start2, end)) {
          start2 = 0;
          end = length;
        } else {
          start2 = start2 == null ? 0 : toInteger(start2);
          end = end === undefined$1 ? length : toInteger(end);
        }
        return baseSlice(array, start2, end);
      }
      __name(slice2, "slice");
      function sortedIndex(array, value3) {
        return baseSortedIndex(array, value3);
      }
      __name(sortedIndex, "sortedIndex");
      function sortedIndexBy(array, value3, iteratee2) {
        return baseSortedIndexBy(array, value3, getIteratee(iteratee2, 2));
      }
      __name(sortedIndexBy, "sortedIndexBy");
      function sortedIndexOf(array, value3) {
        var length = array == null ? 0 : array.length;
        if (length) {
          var index2 = baseSortedIndex(array, value3);
          if (index2 < length && eq2(array[index2], value3)) {
            return index2;
          }
        }
        return -1;
      }
      __name(sortedIndexOf, "sortedIndexOf");
      function sortedLastIndex(array, value3) {
        return baseSortedIndex(array, value3, true);
      }
      __name(sortedLastIndex, "sortedLastIndex");
      function sortedLastIndexBy(array, value3, iteratee2) {
        return baseSortedIndexBy(array, value3, getIteratee(iteratee2, 2), true);
      }
      __name(sortedLastIndexBy, "sortedLastIndexBy");
      function sortedLastIndexOf(array, value3) {
        var length = array == null ? 0 : array.length;
        if (length) {
          var index2 = baseSortedIndex(array, value3, true) - 1;
          if (eq2(array[index2], value3)) {
            return index2;
          }
        }
        return -1;
      }
      __name(sortedLastIndexOf, "sortedLastIndexOf");
      function sortedUniq(array) {
        return array && array.length ? baseSortedUniq(array) : [];
      }
      __name(sortedUniq, "sortedUniq");
      function sortedUniqBy(array, iteratee2) {
        return array && array.length ? baseSortedUniq(array, getIteratee(iteratee2, 2)) : [];
      }
      __name(sortedUniqBy, "sortedUniqBy");
      function tail(array) {
        var length = array == null ? 0 : array.length;
        return length ? baseSlice(array, 1, length) : [];
      }
      __name(tail, "tail");
      function take(array, n2, guard) {
        if (!(array && array.length)) {
          return [];
        }
        n2 = guard || n2 === undefined$1 ? 1 : toInteger(n2);
        return baseSlice(array, 0, n2 < 0 ? 0 : n2);
      }
      __name(take, "take");
      function takeRight(array, n2, guard) {
        var length = array == null ? 0 : array.length;
        if (!length) {
          return [];
        }
        n2 = guard || n2 === undefined$1 ? 1 : toInteger(n2);
        n2 = length - n2;
        return baseSlice(array, n2 < 0 ? 0 : n2, length);
      }
      __name(takeRight, "takeRight");
      function takeRightWhile(array, predicate) {
        return array && array.length ? baseWhile(array, getIteratee(predicate, 3), false, true) : [];
      }
      __name(takeRightWhile, "takeRightWhile");
      function takeWhile(array, predicate) {
        return array && array.length ? baseWhile(array, getIteratee(predicate, 3)) : [];
      }
      __name(takeWhile, "takeWhile");
      var union = baseRest(function(arrays) {
        return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true));
      });
      var unionBy = baseRest(function(arrays) {
        var iteratee2 = last(arrays);
        if (isArrayLikeObject(iteratee2)) {
          iteratee2 = undefined$1;
        }
        return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true), getIteratee(iteratee2, 2));
      });
      var unionWith = baseRest(function(arrays) {
        var comparator = last(arrays);
        comparator = typeof comparator == "function" ? comparator : undefined$1;
        return baseUniq(baseFlatten(arrays, 1, isArrayLikeObject, true), undefined$1, comparator);
      });
      function uniq2(array) {
        return array && array.length ? baseUniq(array) : [];
      }
      __name(uniq2, "uniq");
      function uniqBy(array, iteratee2) {
        return array && array.length ? baseUniq(array, getIteratee(iteratee2, 2)) : [];
      }
      __name(uniqBy, "uniqBy");
      function uniqWith(array, comparator) {
        comparator = typeof comparator == "function" ? comparator : undefined$1;
        return array && array.length ? baseUniq(array, undefined$1, comparator) : [];
      }
      __name(uniqWith, "uniqWith");
      function unzip(array) {
        if (!(array && array.length)) {
          return [];
        }
        var length = 0;
        array = arrayFilter2(array, function(group) {
          if (isArrayLikeObject(group)) {
            length = nativeMax(group.length, length);
            return true;
          }
        });
        return baseTimes2(length, function(index2) {
          return arrayMap(array, baseProperty(index2));
        });
      }
      __name(unzip, "unzip");
      function unzipWith(array, iteratee2) {
        if (!(array && array.length)) {
          return [];
        }
        var result2 = unzip(array);
        if (iteratee2 == null) {
          return result2;
        }
        return arrayMap(result2, function(group) {
          return apply2(iteratee2, undefined$1, group);
        });
      }
      __name(unzipWith, "unzipWith");
      var without = baseRest(function(array, values2) {
        return isArrayLikeObject(array) ? baseDifference(array, values2) : [];
      });
      var xor = baseRest(function(arrays) {
        return baseXor(arrayFilter2(arrays, isArrayLikeObject));
      });
      var xorBy = baseRest(function(arrays) {
        var iteratee2 = last(arrays);
        if (isArrayLikeObject(iteratee2)) {
          iteratee2 = undefined$1;
        }
        return baseXor(arrayFilter2(arrays, isArrayLikeObject), getIteratee(iteratee2, 2));
      });
      var xorWith = baseRest(function(arrays) {
        var comparator = last(arrays);
        comparator = typeof comparator == "function" ? comparator : undefined$1;
        return baseXor(arrayFilter2(arrays, isArrayLikeObject), undefined$1, comparator);
      });
      var zip = baseRest(unzip);
      function zipObject(props, values2) {
        return baseZipObject(props || [], values2 || [], assignValue2);
      }
      __name(zipObject, "zipObject");
      function zipObjectDeep(props, values2) {
        return baseZipObject(props || [], values2 || [], baseSet);
      }
      __name(zipObjectDeep, "zipObjectDeep");
      var zipWith = baseRest(function(arrays) {
        var length = arrays.length, iteratee2 = length > 1 ? arrays[length - 1] : undefined$1;
        iteratee2 = typeof iteratee2 == "function" ? (arrays.pop(), iteratee2) : undefined$1;
        return unzipWith(arrays, iteratee2);
      });
      function chain(value3) {
        var result2 = lodash2(value3);
        result2.__chain__ = true;
        return result2;
      }
      __name(chain, "chain");
      function tap(value3, interceptor) {
        interceptor(value3);
        return value3;
      }
      __name(tap, "tap");
      function thru(value3, interceptor) {
        return interceptor(value3);
      }
      __name(thru, "thru");
      var wrapperAt = flatRest(function(paths) {
        var length = paths.length, start2 = length ? paths[0] : 0, value3 = this.__wrapped__, interceptor = /* @__PURE__ */ __name(function(object) {
          return baseAt(object, paths);
        }, "interceptor");
        if (length > 1 || this.__actions__.length || !(value3 instanceof LazyWrapper) || !isIndex2(start2)) {
          return this.thru(interceptor);
        }
        value3 = value3.slice(start2, +start2 + (length ? 1 : 0));
        value3.__actions__.push({
          "func": thru,
          "args": [interceptor],
          "thisArg": undefined$1
        });
        return new LodashWrapper(value3, this.__chain__).thru(function(array) {
          if (length && !array.length) {
            array.push(undefined$1);
          }
          return array;
        });
      });
      function wrapperChain() {
        return chain(this);
      }
      __name(wrapperChain, "wrapperChain");
      function wrapperCommit() {
        return new LodashWrapper(this.value(), this.__chain__);
      }
      __name(wrapperCommit, "wrapperCommit");
      function wrapperNext() {
        if (this.__values__ === undefined$1) {
          this.__values__ = toArray2(this.value());
        }
        var done = this.__index__ >= this.__values__.length, value3 = done ? undefined$1 : this.__values__[this.__index__++];
        return { "done": done, "value": value3 };
      }
      __name(wrapperNext, "wrapperNext");
      function wrapperToIterator() {
        return this;
      }
      __name(wrapperToIterator, "wrapperToIterator");
      function wrapperPlant(value3) {
        var result2, parent2 = this;
        while (parent2 instanceof baseLodash) {
          var clone3 = wrapperClone(parent2);
          clone3.__index__ = 0;
          clone3.__values__ = undefined$1;
          if (result2) {
            previous.__wrapped__ = clone3;
          } else {
            result2 = clone3;
          }
          var previous = clone3;
          parent2 = parent2.__wrapped__;
        }
        previous.__wrapped__ = value3;
        return result2;
      }
      __name(wrapperPlant, "wrapperPlant");
      function wrapperReverse() {
        var value3 = this.__wrapped__;
        if (value3 instanceof LazyWrapper) {
          var wrapped = value3;
          if (this.__actions__.length) {
            wrapped = new LazyWrapper(this);
          }
          wrapped = wrapped.reverse();
          wrapped.__actions__.push({
            "func": thru,
            "args": [reverse2],
            "thisArg": undefined$1
          });
          return new LodashWrapper(wrapped, this.__chain__);
        }
        return this.thru(reverse2);
      }
      __name(wrapperReverse, "wrapperReverse");
      function wrapperValue() {
        return baseWrapperValue(this.__wrapped__, this.__actions__);
      }
      __name(wrapperValue, "wrapperValue");
      var countBy = createAggregator(function(result2, value3, key) {
        if (hasOwnProperty2.call(result2, key)) {
          ++result2[key];
        } else {
          baseAssignValue2(result2, key, 1);
        }
      });
      function every(collection, predicate, guard) {
        var func = isArray2(collection) ? arrayEvery : baseEvery;
        if (guard && isIterateeCall(collection, predicate, guard)) {
          predicate = undefined$1;
        }
        return func(collection, getIteratee(predicate, 3));
      }
      __name(every, "every");
      function filter4(collection, predicate) {
        var func = isArray2(collection) ? arrayFilter2 : baseFilter;
        return func(collection, getIteratee(predicate, 3));
      }
      __name(filter4, "filter");
      var find2 = createFind(findIndex);
      var findLast2 = createFind(findLastIndex2);
      function flatMap(collection, iteratee2) {
        return baseFlatten(map3(collection, iteratee2), 1);
      }
      __name(flatMap, "flatMap");
      function flatMapDeep(collection, iteratee2) {
        return baseFlatten(map3(collection, iteratee2), INFINITY2);
      }
      __name(flatMapDeep, "flatMapDeep");
      function flatMapDepth(collection, iteratee2, depth) {
        depth = depth === undefined$1 ? 1 : toInteger(depth);
        return baseFlatten(map3(collection, iteratee2), depth);
      }
      __name(flatMapDepth, "flatMapDepth");
      function forEach3(collection, iteratee2) {
        var func = isArray2(collection) ? arrayEach2 : baseEach;
        return func(collection, getIteratee(iteratee2, 3));
      }
      __name(forEach3, "forEach");
      function forEachRight(collection, iteratee2) {
        var func = isArray2(collection) ? arrayEachRight : baseEachRight;
        return func(collection, getIteratee(iteratee2, 3));
      }
      __name(forEachRight, "forEachRight");
      var groupBy = createAggregator(function(result2, value3, key) {
        if (hasOwnProperty2.call(result2, key)) {
          result2[key].push(value3);
        } else {
          baseAssignValue2(result2, key, [value3]);
        }
      });
      function includes(collection, value3, fromIndex, guard) {
        collection = isArrayLike2(collection) ? collection : values(collection);
        fromIndex = fromIndex && !guard ? toInteger(fromIndex) : 0;
        var length = collection.length;
        if (fromIndex < 0) {
          fromIndex = nativeMax(length + fromIndex, 0);
        }
        return isString2(collection) ? fromIndex <= length && collection.indexOf(value3, fromIndex) > -1 : !!length && baseIndexOf(collection, value3, fromIndex) > -1;
      }
      __name(includes, "includes");
      var invokeMap = baseRest(function(collection, path, args) {
        var index2 = -1, isFunc = typeof path == "function", result2 = isArrayLike2(collection) ? Array2(collection.length) : [];
        baseEach(collection, function(value3) {
          result2[++index2] = isFunc ? apply2(path, value3, args) : baseInvoke(value3, path, args);
        });
        return result2;
      });
      var keyBy = createAggregator(function(result2, value3, key) {
        baseAssignValue2(result2, key, value3);
      });
      function map3(collection, iteratee2) {
        var func = isArray2(collection) ? arrayMap : baseMap;
        return func(collection, getIteratee(iteratee2, 3));
      }
      __name(map3, "map");
      function orderBy(collection, iteratees, orders, guard) {
        if (collection == null) {
          return [];
        }
        if (!isArray2(iteratees)) {
          iteratees = iteratees == null ? [] : [iteratees];
        }
        orders = guard ? undefined$1 : orders;
        if (!isArray2(orders)) {
          orders = orders == null ? [] : [orders];
        }
        return baseOrderBy(collection, iteratees, orders);
      }
      __name(orderBy, "orderBy");
      var partition = createAggregator(function(result2, value3, key) {
        result2[key ? 0 : 1].push(value3);
      }, function() {
        return [[], []];
      });
      function reduce2(collection, iteratee2, accumulator) {
        var func = isArray2(collection) ? arrayReduce : baseReduce, initAccum = arguments.length < 3;
        return func(collection, getIteratee(iteratee2, 4), accumulator, initAccum, baseEach);
      }
      __name(reduce2, "reduce");
      function reduceRight(collection, iteratee2, accumulator) {
        var func = isArray2(collection) ? arrayReduceRight : baseReduce, initAccum = arguments.length < 3;
        return func(collection, getIteratee(iteratee2, 4), accumulator, initAccum, baseEachRight);
      }
      __name(reduceRight, "reduceRight");
      function reject3(collection, predicate) {
        var func = isArray2(collection) ? arrayFilter2 : baseFilter;
        return func(collection, negate(getIteratee(predicate, 3)));
      }
      __name(reject3, "reject");
      function sample(collection) {
        var func = isArray2(collection) ? arraySample : baseSample;
        return func(collection);
      }
      __name(sample, "sample");
      function sampleSize(collection, n2, guard) {
        if (guard ? isIterateeCall(collection, n2, guard) : n2 === undefined$1) {
          n2 = 1;
        } else {
          n2 = toInteger(n2);
        }
        var func = isArray2(collection) ? arraySampleSize : baseSampleSize;
        return func(collection, n2);
      }
      __name(sampleSize, "sampleSize");
      function shuffle2(collection) {
        var func = isArray2(collection) ? arrayShuffle : baseShuffle;
        return func(collection);
      }
      __name(shuffle2, "shuffle");
      function size(collection) {
        if (collection == null) {
          return 0;
        }
        if (isArrayLike2(collection)) {
          return isString2(collection) ? stringSize(collection) : collection.length;
        }
        var tag = getTag2(collection);
        if (tag == mapTag2 || tag == setTag2) {
          return collection.size;
        }
        return baseKeys2(collection).length;
      }
      __name(size, "size");
      function some(collection, predicate, guard) {
        var func = isArray2(collection) ? arraySome : baseSome;
        if (guard && isIterateeCall(collection, predicate, guard)) {
          predicate = undefined$1;
        }
        return func(collection, getIteratee(predicate, 3));
      }
      __name(some, "some");
      var sortBy = baseRest(function(collection, iteratees) {
        if (collection == null) {
          return [];
        }
        var length = iteratees.length;
        if (length > 1 && isIterateeCall(collection, iteratees[0], iteratees[1])) {
          iteratees = [];
        } else if (length > 2 && isIterateeCall(iteratees[0], iteratees[1], iteratees[2])) {
          iteratees = [iteratees[0]];
        }
        return baseOrderBy(collection, baseFlatten(iteratees, 1), []);
      });
      var now2 = ctxNow || function() {
        return root34.Date.now();
      };
      function after(n2, func) {
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        n2 = toInteger(n2);
        return function() {
          if (--n2 < 1) {
            return func.apply(this, arguments);
          }
        };
      }
      __name(after, "after");
      function ary(func, n2, guard) {
        n2 = guard ? undefined$1 : n2;
        n2 = func && n2 == null ? func.length : n2;
        return createWrap(func, WRAP_ARY_FLAG, undefined$1, undefined$1, undefined$1, undefined$1, n2);
      }
      __name(ary, "ary");
      function before(n2, func) {
        var result2;
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        n2 = toInteger(n2);
        return function() {
          if (--n2 > 0) {
            result2 = func.apply(this, arguments);
          }
          if (n2 <= 1) {
            func = undefined$1;
          }
          return result2;
        };
      }
      __name(before, "before");
      var bind3 = baseRest(function(func, thisArg, partials) {
        var bitmask = WRAP_BIND_FLAG;
        if (partials.length) {
          var holders = replaceHolders(partials, getHolder(bind3));
          bitmask |= WRAP_PARTIAL_FLAG;
        }
        return createWrap(func, bitmask, thisArg, partials, holders);
      });
      var bindKey = baseRest(function(object, key, partials) {
        var bitmask = WRAP_BIND_FLAG | WRAP_BIND_KEY_FLAG;
        if (partials.length) {
          var holders = replaceHolders(partials, getHolder(bindKey));
          bitmask |= WRAP_PARTIAL_FLAG;
        }
        return createWrap(key, bitmask, object, partials, holders);
      });
      function curry(func, arity, guard) {
        arity = guard ? undefined$1 : arity;
        var result2 = createWrap(func, WRAP_CURRY_FLAG, undefined$1, undefined$1, undefined$1, undefined$1, undefined$1, arity);
        result2.placeholder = curry.placeholder;
        return result2;
      }
      __name(curry, "curry");
      function curryRight(func, arity, guard) {
        arity = guard ? undefined$1 : arity;
        var result2 = createWrap(func, WRAP_CURRY_RIGHT_FLAG, undefined$1, undefined$1, undefined$1, undefined$1, undefined$1, arity);
        result2.placeholder = curryRight.placeholder;
        return result2;
      }
      __name(curryRight, "curryRight");
      function debounce2(func, wait, options5) {
        var lastArgs, lastThis, maxWait, result2, timerId, lastCallTime, lastInvokeTime = 0, leading = false, maxing = false, trailing = true;
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        wait = toNumber2(wait) || 0;
        if (isObject2(options5)) {
          leading = !!options5.leading;
          maxing = "maxWait" in options5;
          maxWait = maxing ? nativeMax(toNumber2(options5.maxWait) || 0, wait) : maxWait;
          trailing = "trailing" in options5 ? !!options5.trailing : trailing;
        }
        function invokeFunc(time) {
          var args = lastArgs, thisArg = lastThis;
          lastArgs = lastThis = undefined$1;
          lastInvokeTime = time;
          result2 = func.apply(thisArg, args);
          return result2;
        }
        __name(invokeFunc, "invokeFunc");
        function leadingEdge(time) {
          lastInvokeTime = time;
          timerId = setTimeout2(timerExpired, wait);
          return leading ? invokeFunc(time) : result2;
        }
        __name(leadingEdge, "leadingEdge");
        function remainingWait(time) {
          var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime, timeWaiting = wait - timeSinceLastCall;
          return maxing ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke) : timeWaiting;
        }
        __name(remainingWait, "remainingWait");
        function shouldInvoke(time) {
          var timeSinceLastCall = time - lastCallTime, timeSinceLastInvoke = time - lastInvokeTime;
          return lastCallTime === undefined$1 || timeSinceLastCall >= wait || timeSinceLastCall < 0 || maxing && timeSinceLastInvoke >= maxWait;
        }
        __name(shouldInvoke, "shouldInvoke");
        function timerExpired() {
          var time = now2();
          if (shouldInvoke(time)) {
            return trailingEdge(time);
          }
          timerId = setTimeout2(timerExpired, remainingWait(time));
        }
        __name(timerExpired, "timerExpired");
        function trailingEdge(time) {
          timerId = undefined$1;
          if (trailing && lastArgs) {
            return invokeFunc(time);
          }
          lastArgs = lastThis = undefined$1;
          return result2;
        }
        __name(trailingEdge, "trailingEdge");
        function cancel() {
          if (timerId !== undefined$1) {
            clearTimeout2(timerId);
          }
          lastInvokeTime = 0;
          lastArgs = lastCallTime = lastThis = timerId = undefined$1;
        }
        __name(cancel, "cancel");
        function flush2() {
          return timerId === undefined$1 ? result2 : trailingEdge(now2());
        }
        __name(flush2, "flush");
        function debounced() {
          var time = now2(), isInvoking = shouldInvoke(time);
          lastArgs = arguments;
          lastThis = this;
          lastCallTime = time;
          if (isInvoking) {
            if (timerId === undefined$1) {
              return leadingEdge(lastCallTime);
            }
            if (maxing) {
              clearTimeout2(timerId);
              timerId = setTimeout2(timerExpired, wait);
              return invokeFunc(lastCallTime);
            }
          }
          if (timerId === undefined$1) {
            timerId = setTimeout2(timerExpired, wait);
          }
          return result2;
        }
        __name(debounced, "debounced");
        debounced.cancel = cancel;
        debounced.flush = flush2;
        return debounced;
      }
      __name(debounce2, "debounce");
      var defer = baseRest(function(func, args) {
        return baseDelay(func, 1, args);
      });
      var delay = baseRest(function(func, wait, args) {
        return baseDelay(func, toNumber2(wait) || 0, args);
      });
      function flip(func) {
        return createWrap(func, WRAP_FLIP_FLAG);
      }
      __name(flip, "flip");
      function memoize(func, resolver) {
        if (typeof func != "function" || resolver != null && typeof resolver != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        var memoized = /* @__PURE__ */ __name(function() {
          var args = arguments, key = resolver ? resolver.apply(this, args) : args[0], cache2 = memoized.cache;
          if (cache2.has(key)) {
            return cache2.get(key);
          }
          var result2 = func.apply(this, args);
          memoized.cache = cache2.set(key, result2) || cache2;
          return result2;
        }, "memoized");
        memoized.cache = new (memoize.Cache || MapCache2)();
        return memoized;
      }
      __name(memoize, "memoize");
      memoize.Cache = MapCache2;
      function negate(predicate) {
        if (typeof predicate != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        return function() {
          var args = arguments;
          switch (args.length) {
            case 0:
              return !predicate.call(this);
            case 1:
              return !predicate.call(this, args[0]);
            case 2:
              return !predicate.call(this, args[0], args[1]);
            case 3:
              return !predicate.call(this, args[0], args[1], args[2]);
          }
          return !predicate.apply(this, args);
        };
      }
      __name(negate, "negate");
      function once2(func) {
        return before(2, func);
      }
      __name(once2, "once");
      var overArgs = castRest(function(func, transforms) {
        transforms = transforms.length == 1 && isArray2(transforms[0]) ? arrayMap(transforms[0], baseUnary2(getIteratee())) : arrayMap(baseFlatten(transforms, 1), baseUnary2(getIteratee()));
        var funcsLength = transforms.length;
        return baseRest(function(args) {
          var index2 = -1, length = nativeMin(args.length, funcsLength);
          while (++index2 < length) {
            args[index2] = transforms[index2].call(this, args[index2]);
          }
          return apply2(func, this, args);
        });
      });
      var partial = baseRest(function(func, partials) {
        var holders = replaceHolders(partials, getHolder(partial));
        return createWrap(func, WRAP_PARTIAL_FLAG, undefined$1, partials, holders);
      });
      var partialRight = baseRest(function(func, partials) {
        var holders = replaceHolders(partials, getHolder(partialRight));
        return createWrap(func, WRAP_PARTIAL_RIGHT_FLAG, undefined$1, partials, holders);
      });
      var rearg = flatRest(function(func, indexes) {
        return createWrap(func, WRAP_REARG_FLAG, undefined$1, undefined$1, undefined$1, indexes);
      });
      function rest(func, start2) {
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        start2 = start2 === undefined$1 ? start2 : toInteger(start2);
        return baseRest(func, start2);
      }
      __name(rest, "rest");
      function spread2(func, start2) {
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        start2 = start2 == null ? 0 : nativeMax(toInteger(start2), 0);
        return baseRest(function(args) {
          var array = args[start2], otherArgs = castSlice(args, 0, start2);
          if (array) {
            arrayPush2(otherArgs, array);
          }
          return apply2(func, this, otherArgs);
        });
      }
      __name(spread2, "spread");
      function throttle2(func, wait, options5) {
        var leading = true, trailing = true;
        if (typeof func != "function") {
          throw new TypeError2(FUNC_ERROR_TEXT);
        }
        if (isObject2(options5)) {
          leading = "leading" in options5 ? !!options5.leading : leading;
          trailing = "trailing" in options5 ? !!options5.trailing : trailing;
        }
        return debounce2(func, wait, {
          "leading": leading,
          "maxWait": wait,
          "trailing": trailing
        });
      }
      __name(throttle2, "throttle");
      function unary(func) {
        return ary(func, 1);
      }
      __name(unary, "unary");
      function wrap2(value3, wrapper) {
        return partial(castFunction(wrapper), value3);
      }
      __name(wrap2, "wrap");
      function castArray() {
        if (!arguments.length) {
          return [];
        }
        var value3 = arguments[0];
        return isArray2(value3) ? value3 : [value3];
      }
      __name(castArray, "castArray");
      function clone2(value3) {
        return baseClone2(value3, CLONE_SYMBOLS_FLAG2);
      }
      __name(clone2, "clone");
      function cloneWith(value3, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        return baseClone2(value3, CLONE_SYMBOLS_FLAG2, customizer);
      }
      __name(cloneWith, "cloneWith");
      function cloneDeep2(value3) {
        return baseClone2(value3, CLONE_DEEP_FLAG2 | CLONE_SYMBOLS_FLAG2);
      }
      __name(cloneDeep2, "cloneDeep");
      function cloneDeepWith(value3, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        return baseClone2(value3, CLONE_DEEP_FLAG2 | CLONE_SYMBOLS_FLAG2, customizer);
      }
      __name(cloneDeepWith, "cloneDeepWith");
      function conformsTo(object, source) {
        return source == null || baseConformsTo(object, source, keys2(source));
      }
      __name(conformsTo, "conformsTo");
      function eq2(value3, other) {
        return value3 === other || value3 !== value3 && other !== other;
      }
      __name(eq2, "eq");
      var gt2 = createRelationalOperation(baseGt);
      var gte2 = createRelationalOperation(function(value3, other) {
        return value3 >= other;
      });
      var isArguments2 = baseIsArguments2(/* @__PURE__ */ function() {
        return arguments;
      }()) ? baseIsArguments2 : function(value3) {
        return isObjectLike2(value3) && hasOwnProperty2.call(value3, "callee") && !propertyIsEnumerable2.call(value3, "callee");
      };
      var isArray2 = Array2.isArray;
      var isArrayBuffer2 = nodeIsArrayBuffer ? baseUnary2(nodeIsArrayBuffer) : baseIsArrayBuffer;
      function isArrayLike2(value3) {
        return value3 != null && isLength2(value3.length) && !isFunction2(value3);
      }
      __name(isArrayLike2, "isArrayLike");
      function isArrayLikeObject(value3) {
        return isObjectLike2(value3) && isArrayLike2(value3);
      }
      __name(isArrayLikeObject, "isArrayLikeObject");
      function isBoolean2(value3) {
        return value3 === true || value3 === false || isObjectLike2(value3) && baseGetTag2(value3) == boolTag2;
      }
      __name(isBoolean2, "isBoolean");
      var isBuffer2 = nativeIsBuffer || stubFalse2;
      var isDate2 = nodeIsDate ? baseUnary2(nodeIsDate) : baseIsDate;
      function isElement2(value3) {
        return isObjectLike2(value3) && value3.nodeType === 1 && !isPlainObject2(value3);
      }
      __name(isElement2, "isElement");
      function isEmpty3(value3) {
        if (value3 == null) {
          return true;
        }
        if (isArrayLike2(value3) && (isArray2(value3) || typeof value3 == "string" || typeof value3.splice == "function" || isBuffer2(value3) || isTypedArray2(value3) || isArguments2(value3))) {
          return !value3.length;
        }
        var tag = getTag2(value3);
        if (tag == mapTag2 || tag == setTag2) {
          return !value3.size;
        }
        if (isPrototype2(value3)) {
          return !baseKeys2(value3).length;
        }
        for (var key in value3) {
          if (hasOwnProperty2.call(value3, key)) {
            return false;
          }
        }
        return true;
      }
      __name(isEmpty3, "isEmpty");
      function isEqual(value3, other) {
        return baseIsEqual(value3, other);
      }
      __name(isEqual, "isEqual");
      function isEqualWith(value3, other, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        var result2 = customizer ? customizer(value3, other) : undefined$1;
        return result2 === undefined$1 ? baseIsEqual(value3, other, undefined$1, customizer) : !!result2;
      }
      __name(isEqualWith, "isEqualWith");
      function isError2(value3) {
        if (!isObjectLike2(value3)) {
          return false;
        }
        var tag = baseGetTag2(value3);
        return tag == errorTag2 || tag == domExcTag || typeof value3.message == "string" && typeof value3.name == "string" && !isPlainObject2(value3);
      }
      __name(isError2, "isError");
      function isFinite2(value3) {
        return typeof value3 == "number" && nativeIsFinite(value3);
      }
      __name(isFinite2, "isFinite");
      function isFunction2(value3) {
        if (!isObject2(value3)) {
          return false;
        }
        var tag = baseGetTag2(value3);
        return tag == funcTag2 || tag == genTag2 || tag == asyncTag2 || tag == proxyTag2;
      }
      __name(isFunction2, "isFunction");
      function isInteger(value3) {
        return typeof value3 == "number" && value3 == toInteger(value3);
      }
      __name(isInteger, "isInteger");
      function isLength2(value3) {
        return typeof value3 == "number" && value3 > -1 && value3 % 1 == 0 && value3 <= MAX_SAFE_INTEGER2;
      }
      __name(isLength2, "isLength");
      function isObject2(value3) {
        var type = typeof value3;
        return value3 != null && (type == "object" || type == "function");
      }
      __name(isObject2, "isObject");
      function isObjectLike2(value3) {
        return value3 != null && typeof value3 == "object";
      }
      __name(isObjectLike2, "isObjectLike");
      var isMap2 = nodeIsMap2 ? baseUnary2(nodeIsMap2) : baseIsMap2;
      function isMatch(object, source) {
        return object === source || baseIsMatch(object, source, getMatchData(source));
      }
      __name(isMatch, "isMatch");
      function isMatchWith(object, source, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        return baseIsMatch(object, source, getMatchData(source), customizer);
      }
      __name(isMatchWith, "isMatchWith");
      function isNaN2(value3) {
        return isNumber2(value3) && value3 != +value3;
      }
      __name(isNaN2, "isNaN");
      function isNative(value3) {
        if (isMaskable(value3)) {
          throw new Error2(CORE_ERROR_TEXT);
        }
        return baseIsNative2(value3);
      }
      __name(isNative, "isNative");
      function isNull(value3) {
        return value3 === null;
      }
      __name(isNull, "isNull");
      function isNil(value3) {
        return value3 == null;
      }
      __name(isNil, "isNil");
      function isNumber2(value3) {
        return typeof value3 == "number" || isObjectLike2(value3) && baseGetTag2(value3) == numberTag2;
      }
      __name(isNumber2, "isNumber");
      function isPlainObject2(value3) {
        if (!isObjectLike2(value3) || baseGetTag2(value3) != objectTag2) {
          return false;
        }
        var proto = getPrototype2(value3);
        if (proto === null) {
          return true;
        }
        var Ctor = hasOwnProperty2.call(proto, "constructor") && proto.constructor;
        return typeof Ctor == "function" && Ctor instanceof Ctor && funcToString2.call(Ctor) == objectCtorString;
      }
      __name(isPlainObject2, "isPlainObject");
      var isRegExp2 = nodeIsRegExp ? baseUnary2(nodeIsRegExp) : baseIsRegExp;
      function isSafeInteger(value3) {
        return isInteger(value3) && value3 >= -MAX_SAFE_INTEGER2 && value3 <= MAX_SAFE_INTEGER2;
      }
      __name(isSafeInteger, "isSafeInteger");
      var isSet2 = nodeIsSet2 ? baseUnary2(nodeIsSet2) : baseIsSet2;
      function isString2(value3) {
        return typeof value3 == "string" || !isArray2(value3) && isObjectLike2(value3) && baseGetTag2(value3) == stringTag2;
      }
      __name(isString2, "isString");
      function isSymbol2(value3) {
        return typeof value3 == "symbol" || isObjectLike2(value3) && baseGetTag2(value3) == symbolTag2;
      }
      __name(isSymbol2, "isSymbol");
      var isTypedArray2 = nodeIsTypedArray2 ? baseUnary2(nodeIsTypedArray2) : baseIsTypedArray2;
      function isUndefined2(value3) {
        return value3 === undefined$1;
      }
      __name(isUndefined2, "isUndefined");
      function isWeakMap(value3) {
        return isObjectLike2(value3) && getTag2(value3) == weakMapTag2;
      }
      __name(isWeakMap, "isWeakMap");
      function isWeakSet(value3) {
        return isObjectLike2(value3) && baseGetTag2(value3) == weakSetTag;
      }
      __name(isWeakSet, "isWeakSet");
      var lt2 = createRelationalOperation(baseLt);
      var lte2 = createRelationalOperation(function(value3, other) {
        return value3 <= other;
      });
      function toArray2(value3) {
        if (!value3) {
          return [];
        }
        if (isArrayLike2(value3)) {
          return isString2(value3) ? stringToArray2(value3) : copyArray2(value3);
        }
        if (symIterator && value3[symIterator]) {
          return iteratorToArray(value3[symIterator]());
        }
        var tag = getTag2(value3), func = tag == mapTag2 ? mapToArray : tag == setTag2 ? setToArray : values;
        return func(value3);
      }
      __name(toArray2, "toArray");
      function toFinite(value3) {
        if (!value3) {
          return value3 === 0 ? value3 : 0;
        }
        value3 = toNumber2(value3);
        if (value3 === INFINITY2 || value3 === -INFINITY2) {
          var sign = value3 < 0 ? -1 : 1;
          return sign * MAX_INTEGER;
        }
        return value3 === value3 ? value3 : 0;
      }
      __name(toFinite, "toFinite");
      function toInteger(value3) {
        var result2 = toFinite(value3), remainder = result2 % 1;
        return result2 === result2 ? remainder ? result2 - remainder : result2 : 0;
      }
      __name(toInteger, "toInteger");
      function toLength(value3) {
        return value3 ? baseClamp(toInteger(value3), 0, MAX_ARRAY_LENGTH) : 0;
      }
      __name(toLength, "toLength");
      function toNumber2(value3) {
        if (typeof value3 == "number") {
          return value3;
        }
        if (isSymbol2(value3)) {
          return NAN;
        }
        if (isObject2(value3)) {
          var other = typeof value3.valueOf == "function" ? value3.valueOf() : value3;
          value3 = isObject2(other) ? other + "" : other;
        }
        if (typeof value3 != "string") {
          return value3 === 0 ? value3 : +value3;
        }
        value3 = baseTrim(value3);
        var isBinary = reIsBinary.test(value3);
        return isBinary || reIsOctal.test(value3) ? freeParseInt(value3.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(value3) ? NAN : +value3;
      }
      __name(toNumber2, "toNumber");
      function toPlainObject(value3) {
        return copyObject2(value3, keysIn2(value3));
      }
      __name(toPlainObject, "toPlainObject");
      function toSafeInteger(value3) {
        return value3 ? baseClamp(toInteger(value3), -MAX_SAFE_INTEGER2, MAX_SAFE_INTEGER2) : value3 === 0 ? value3 : 0;
      }
      __name(toSafeInteger, "toSafeInteger");
      function toString3(value3) {
        return value3 == null ? "" : baseToString2(value3);
      }
      __name(toString3, "toString");
      var assign2 = createAssigner(function(object, source) {
        if (isPrototype2(source) || isArrayLike2(source)) {
          copyObject2(source, keys2(source), object);
          return;
        }
        for (var key in source) {
          if (hasOwnProperty2.call(source, key)) {
            assignValue2(object, key, source[key]);
          }
        }
      });
      var assignIn = createAssigner(function(object, source) {
        copyObject2(source, keysIn2(source), object);
      });
      var assignInWith = createAssigner(function(object, source, srcIndex, customizer) {
        copyObject2(source, keysIn2(source), object, customizer);
      });
      var assignWith = createAssigner(function(object, source, srcIndex, customizer) {
        copyObject2(source, keys2(source), object, customizer);
      });
      var at = flatRest(baseAt);
      function create3(prototype2, properties) {
        var result2 = baseCreate2(prototype2);
        return properties == null ? result2 : baseAssign2(result2, properties);
      }
      __name(create3, "create");
      var defaults2 = baseRest(function(object, sources) {
        object = Object2(object);
        var index2 = -1;
        var length = sources.length;
        var guard = length > 2 ? sources[2] : undefined$1;
        if (guard && isIterateeCall(sources[0], sources[1], guard)) {
          length = 1;
        }
        while (++index2 < length) {
          var source = sources[index2];
          var props = keysIn2(source);
          var propsIndex = -1;
          var propsLength = props.length;
          while (++propsIndex < propsLength) {
            var key = props[propsIndex];
            var value3 = object[key];
            if (value3 === undefined$1 || eq2(value3, objectProto2[key]) && !hasOwnProperty2.call(object, key)) {
              object[key] = source[key];
            }
          }
        }
        return object;
      });
      var defaultsDeep = baseRest(function(args) {
        args.push(undefined$1, customDefaultsMerge);
        return apply2(mergeWith, undefined$1, args);
      });
      function findKey2(object, predicate) {
        return baseFindKey(object, getIteratee(predicate, 3), baseForOwn);
      }
      __name(findKey2, "findKey");
      function findLastKey(object, predicate) {
        return baseFindKey(object, getIteratee(predicate, 3), baseForOwnRight);
      }
      __name(findLastKey, "findLastKey");
      function forIn(object, iteratee2) {
        return object == null ? object : baseFor(object, getIteratee(iteratee2, 3), keysIn2);
      }
      __name(forIn, "forIn");
      function forInRight(object, iteratee2) {
        return object == null ? object : baseForRight(object, getIteratee(iteratee2, 3), keysIn2);
      }
      __name(forInRight, "forInRight");
      function forOwn(object, iteratee2) {
        return object && baseForOwn(object, getIteratee(iteratee2, 3));
      }
      __name(forOwn, "forOwn");
      function forOwnRight(object, iteratee2) {
        return object && baseForOwnRight(object, getIteratee(iteratee2, 3));
      }
      __name(forOwnRight, "forOwnRight");
      function functions(object) {
        return object == null ? [] : baseFunctions(object, keys2(object));
      }
      __name(functions, "functions");
      function functionsIn(object) {
        return object == null ? [] : baseFunctions(object, keysIn2(object));
      }
      __name(functionsIn, "functionsIn");
      function get3(object, path, defaultValue2) {
        var result2 = object == null ? undefined$1 : baseGet(object, path);
        return result2 === undefined$1 ? defaultValue2 : result2;
      }
      __name(get3, "get");
      function has2(object, path) {
        return object != null && hasPath(object, path, baseHas);
      }
      __name(has2, "has");
      function hasIn(object, path) {
        return object != null && hasPath(object, path, baseHasIn);
      }
      __name(hasIn, "hasIn");
      var invert = createInverter(function(result2, value3, key) {
        if (value3 != null && typeof value3.toString != "function") {
          value3 = nativeObjectToString2.call(value3);
        }
        result2[value3] = key;
      }, constant(identity2));
      var invertBy = createInverter(function(result2, value3, key) {
        if (value3 != null && typeof value3.toString != "function") {
          value3 = nativeObjectToString2.call(value3);
        }
        if (hasOwnProperty2.call(result2, value3)) {
          result2[value3].push(key);
        } else {
          result2[value3] = [key];
        }
      }, getIteratee);
      var invoke2 = baseRest(baseInvoke);
      function keys2(object) {
        return isArrayLike2(object) ? arrayLikeKeys2(object) : baseKeys2(object);
      }
      __name(keys2, "keys");
      function keysIn2(object) {
        return isArrayLike2(object) ? arrayLikeKeys2(object, true) : baseKeysIn2(object);
      }
      __name(keysIn2, "keysIn");
      function mapKeys(object, iteratee2) {
        var result2 = {};
        iteratee2 = getIteratee(iteratee2, 3);
        baseForOwn(object, function(value3, key, object2) {
          baseAssignValue2(result2, iteratee2(value3, key, object2), value3);
        });
        return result2;
      }
      __name(mapKeys, "mapKeys");
      function mapValues(object, iteratee2) {
        var result2 = {};
        iteratee2 = getIteratee(iteratee2, 3);
        baseForOwn(object, function(value3, key, object2) {
          baseAssignValue2(result2, key, iteratee2(value3, key, object2));
        });
        return result2;
      }
      __name(mapValues, "mapValues");
      var merge2 = createAssigner(function(object, source, srcIndex) {
        baseMerge(object, source, srcIndex);
      });
      var mergeWith = createAssigner(function(object, source, srcIndex, customizer) {
        baseMerge(object, source, srcIndex, customizer);
      });
      var omit2 = flatRest(function(object, paths) {
        var result2 = {};
        if (object == null) {
          return result2;
        }
        var isDeep = false;
        paths = arrayMap(paths, function(path) {
          path = castPath(path, object);
          isDeep || (isDeep = path.length > 1);
          return path;
        });
        copyObject2(object, getAllKeysIn2(object), result2);
        if (isDeep) {
          result2 = baseClone2(result2, CLONE_DEEP_FLAG2 | CLONE_FLAT_FLAG2 | CLONE_SYMBOLS_FLAG2, customOmitClone);
        }
        var length = paths.length;
        while (length--) {
          baseUnset(result2, paths[length]);
        }
        return result2;
      });
      function omitBy(object, predicate) {
        return pickBy(object, negate(getIteratee(predicate)));
      }
      __name(omitBy, "omitBy");
      var pick2 = flatRest(function(object, paths) {
        return object == null ? {} : basePick(object, paths);
      });
      function pickBy(object, predicate) {
        if (object == null) {
          return {};
        }
        var props = arrayMap(getAllKeysIn2(object), function(prop2) {
          return [prop2];
        });
        predicate = getIteratee(predicate);
        return basePickBy(object, props, function(value3, path) {
          return predicate(value3, path[0]);
        });
      }
      __name(pickBy, "pickBy");
      function result(object, path, defaultValue2) {
        path = castPath(path, object);
        var index2 = -1, length = path.length;
        if (!length) {
          length = 1;
          object = undefined$1;
        }
        while (++index2 < length) {
          var value3 = object == null ? undefined$1 : object[toKey(path[index2])];
          if (value3 === undefined$1) {
            index2 = length;
            value3 = defaultValue2;
          }
          object = isFunction2(value3) ? value3.call(object) : value3;
        }
        return object;
      }
      __name(result, "result");
      function set3(object, path, value3) {
        return object == null ? object : baseSet(object, path, value3);
      }
      __name(set3, "set");
      function setWith(object, path, value3, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        return object == null ? object : baseSet(object, path, value3, customizer);
      }
      __name(setWith, "setWith");
      var toPairs = createToPairs(keys2);
      var toPairsIn = createToPairs(keysIn2);
      function transform2(object, iteratee2, accumulator) {
        var isArr = isArray2(object), isArrLike = isArr || isBuffer2(object) || isTypedArray2(object);
        iteratee2 = getIteratee(iteratee2, 4);
        if (accumulator == null) {
          var Ctor = object && object.constructor;
          if (isArrLike) {
            accumulator = isArr ? new Ctor() : [];
          } else if (isObject2(object)) {
            accumulator = isFunction2(Ctor) ? baseCreate2(getPrototype2(object)) : {};
          } else {
            accumulator = {};
          }
        }
        (isArrLike ? arrayEach2 : baseForOwn)(object, function(value3, index2, object2) {
          return iteratee2(accumulator, value3, index2, object2);
        });
        return accumulator;
      }
      __name(transform2, "transform");
      function unset(object, path) {
        return object == null ? true : baseUnset(object, path);
      }
      __name(unset, "unset");
      function update(object, path, updater) {
        return object == null ? object : baseUpdate(object, path, castFunction(updater));
      }
      __name(update, "update");
      function updateWith(object, path, updater, customizer) {
        customizer = typeof customizer == "function" ? customizer : undefined$1;
        return object == null ? object : baseUpdate(object, path, castFunction(updater), customizer);
      }
      __name(updateWith, "updateWith");
      function values(object) {
        return object == null ? [] : baseValues(object, keys2(object));
      }
      __name(values, "values");
      function valuesIn(object) {
        return object == null ? [] : baseValues(object, keysIn2(object));
      }
      __name(valuesIn, "valuesIn");
      function clamp2(number2, lower, upper) {
        if (upper === undefined$1) {
          upper = lower;
          lower = undefined$1;
        }
        if (upper !== undefined$1) {
          upper = toNumber2(upper);
          upper = upper === upper ? upper : 0;
        }
        if (lower !== undefined$1) {
          lower = toNumber2(lower);
          lower = lower === lower ? lower : 0;
        }
        return baseClamp(toNumber2(number2), lower, upper);
      }
      __name(clamp2, "clamp");
      function inRange(number2, start2, end) {
        start2 = toFinite(start2);
        if (end === undefined$1) {
          end = start2;
          start2 = 0;
        } else {
          end = toFinite(end);
        }
        number2 = toNumber2(number2);
        return baseInRange(number2, start2, end);
      }
      __name(inRange, "inRange");
      function random(lower, upper, floating) {
        if (floating && typeof floating != "boolean" && isIterateeCall(lower, upper, floating)) {
          upper = floating = undefined$1;
        }
        if (floating === undefined$1) {
          if (typeof upper == "boolean") {
            floating = upper;
            upper = undefined$1;
          } else if (typeof lower == "boolean") {
            floating = lower;
            lower = undefined$1;
          }
        }
        if (lower === undefined$1 && upper === undefined$1) {
          lower = 0;
          upper = 1;
        } else {
          lower = toFinite(lower);
          if (upper === undefined$1) {
            upper = lower;
            lower = 0;
          } else {
            upper = toFinite(upper);
          }
        }
        if (lower > upper) {
          var temp = lower;
          lower = upper;
          upper = temp;
        }
        if (floating || lower % 1 || upper % 1) {
          var rand2 = nativeRandom();
          return nativeMin(lower + rand2 * (upper - lower + freeParseFloat("1e-" + ((rand2 + "").length - 1))), upper);
        }
        return baseRandom(lower, upper);
      }
      __name(random, "random");
      var camelCase = createCompounder(function(result2, word, index2) {
        word = word.toLowerCase();
        return result2 + (index2 ? capitalize2(word) : word);
      });
      function capitalize2(string) {
        return upperFirst(toString3(string).toLowerCase());
      }
      __name(capitalize2, "capitalize");
      function deburr(string) {
        string = toString3(string);
        return string && string.replace(reLatin, deburrLetter).replace(reComboMark, "");
      }
      __name(deburr, "deburr");
      function endsWith3(string, target2, position3) {
        string = toString3(string);
        target2 = baseToString2(target2);
        var length = string.length;
        position3 = position3 === undefined$1 ? length : baseClamp(toInteger(position3), 0, length);
        var end = position3;
        position3 -= target2.length;
        return position3 >= 0 && string.slice(position3, end) == target2;
      }
      __name(endsWith3, "endsWith");
      function escape2(string) {
        string = toString3(string);
        return string && reHasUnescapedHtml.test(string) ? string.replace(reUnescapedHtml, escapeHtmlChar) : string;
      }
      __name(escape2, "escape");
      function escapeRegExp2(string) {
        string = toString3(string);
        return string && reHasRegExpChar.test(string) ? string.replace(reRegExpChar2, "\\$&") : string;
      }
      __name(escapeRegExp2, "escapeRegExp");
      var kebabCase = createCompounder(function(result2, word, index2) {
        return result2 + (index2 ? "-" : "") + word.toLowerCase();
      });
      var lowerCase = createCompounder(function(result2, word, index2) {
        return result2 + (index2 ? " " : "") + word.toLowerCase();
      });
      var lowerFirst = createCaseFirst("toLowerCase");
      function pad(string, length, chars2) {
        string = toString3(string);
        length = toInteger(length);
        var strLength = length ? stringSize(string) : 0;
        if (!length || strLength >= length) {
          return string;
        }
        var mid = (length - strLength) / 2;
        return createPadding(nativeFloor(mid), chars2) + string + createPadding(nativeCeil(mid), chars2);
      }
      __name(pad, "pad");
      function padEnd(string, length, chars2) {
        string = toString3(string);
        length = toInteger(length);
        var strLength = length ? stringSize(string) : 0;
        return length && strLength < length ? string + createPadding(length - strLength, chars2) : string;
      }
      __name(padEnd, "padEnd");
      function padStart(string, length, chars2) {
        string = toString3(string);
        length = toInteger(length);
        var strLength = length ? stringSize(string) : 0;
        return length && strLength < length ? createPadding(length - strLength, chars2) + string : string;
      }
      __name(padStart, "padStart");
      function parseInt2(string, radix, guard) {
        if (guard || radix == null) {
          radix = 0;
        } else if (radix) {
          radix = +radix;
        }
        return nativeParseInt(toString3(string).replace(reTrimStart, ""), radix || 0);
      }
      __name(parseInt2, "parseInt");
      function repeat4(string, n2, guard) {
        if (guard ? isIterateeCall(string, n2, guard) : n2 === undefined$1) {
          n2 = 1;
        } else {
          n2 = toInteger(n2);
        }
        return baseRepeat(toString3(string), n2);
      }
      __name(repeat4, "repeat");
      function replace2() {
        var args = arguments, string = toString3(args[0]);
        return args.length < 3 ? string : string.replace(args[1], args[2]);
      }
      __name(replace2, "replace");
      var snakeCase = createCompounder(function(result2, word, index2) {
        return result2 + (index2 ? "_" : "") + word.toLowerCase();
      });
      function split2(string, separator, limit) {
        if (limit && typeof limit != "number" && isIterateeCall(string, separator, limit)) {
          separator = limit = undefined$1;
        }
        limit = limit === undefined$1 ? MAX_ARRAY_LENGTH : limit >>> 0;
        if (!limit) {
          return [];
        }
        string = toString3(string);
        if (string && (typeof separator == "string" || separator != null && !isRegExp2(separator))) {
          separator = baseToString2(separator);
          if (!separator && hasUnicode(string)) {
            return castSlice(stringToArray2(string), 0, limit);
          }
        }
        return string.split(separator, limit);
      }
      __name(split2, "split");
      var startCase = createCompounder(function(result2, word, index2) {
        return result2 + (index2 ? " " : "") + upperFirst(word);
      });
      function startsWith2(string, target2, position3) {
        string = toString3(string);
        position3 = position3 == null ? 0 : baseClamp(toInteger(position3), 0, string.length);
        target2 = baseToString2(target2);
        return string.slice(position3, position3 + target2.length) == target2;
      }
      __name(startsWith2, "startsWith");
      function template(string, options5, guard) {
        var settings = lodash2.templateSettings;
        if (guard && isIterateeCall(string, options5, guard)) {
          options5 = undefined$1;
        }
        string = toString3(string);
        options5 = assignInWith({}, options5, settings, customDefaultsAssignIn);
        var imports = assignInWith({}, options5.imports, settings.imports, customDefaultsAssignIn), importsKeys = keys2(imports), importsValues = baseValues(imports, importsKeys);
        var isEscaping, isEvaluating, index2 = 0, interpolate = options5.interpolate || reNoMatch, source = "__p += '";
        var reDelimiters = RegExp2(
          (options5.escape || reNoMatch).source + "|" + interpolate.source + "|" + (interpolate === reInterpolate ? reEsTemplate : reNoMatch).source + "|" + (options5.evaluate || reNoMatch).source + "|$",
          "g"
        );
        var sourceURL = "//# sourceURL=" + (hasOwnProperty2.call(options5, "sourceURL") ? (options5.sourceURL + "").replace(/\s/g, " ") : "lodash.templateSources[" + ++templateCounter + "]") + "\n";
        string.replace(reDelimiters, function(match2, escapeValue, interpolateValue, esTemplateValue, evaluateValue, offset) {
          interpolateValue || (interpolateValue = esTemplateValue);
          source += string.slice(index2, offset).replace(reUnescapedString, escapeStringChar);
          if (escapeValue) {
            isEscaping = true;
            source += "' +\n__e(" + escapeValue + ") +\n'";
          }
          if (evaluateValue) {
            isEvaluating = true;
            source += "';\n" + evaluateValue + ";\n__p += '";
          }
          if (interpolateValue) {
            source += "' +\n((__t = (" + interpolateValue + ")) == null ? '' : __t) +\n'";
          }
          index2 = offset + match2.length;
          return match2;
        });
        source += "';\n";
        var variable = hasOwnProperty2.call(options5, "variable") && options5.variable;
        if (!variable) {
          source = "with (obj) {\n" + source + "\n}\n";
        } else if (reForbiddenIdentifierChars.test(variable)) {
          throw new Error2(INVALID_TEMPL_VAR_ERROR_TEXT);
        }
        source = (isEvaluating ? source.replace(reEmptyStringLeading, "") : source).replace(reEmptyStringMiddle, "$1").replace(reEmptyStringTrailing, "$1;");
        source = "function(" + (variable || "obj") + ") {\n" + (variable ? "" : "obj || (obj = {});\n") + "var __t, __p = ''" + (isEscaping ? ", __e = _.escape" : "") + (isEvaluating ? ", __j = Array.prototype.join;\nfunction print() { __p += __j.call(arguments, '') }\n" : ";\n") + source + "return __p\n}";
        var result2 = attempt(function() {
          return Function2(importsKeys, sourceURL + "return " + source).apply(undefined$1, importsValues);
        });
        result2.source = source;
        if (isError2(result2)) {
          throw result2;
        }
        return result2;
      }
      __name(template, "template");
      function toLower(value3) {
        return toString3(value3).toLowerCase();
      }
      __name(toLower, "toLower");
      function toUpper(value3) {
        return toString3(value3).toUpperCase();
      }
      __name(toUpper, "toUpper");
      function trim2(string, chars2, guard) {
        string = toString3(string);
        if (string && (guard || chars2 === undefined$1)) {
          return baseTrim(string);
        }
        if (!string || !(chars2 = baseToString2(chars2))) {
          return string;
        }
        var strSymbols = stringToArray2(string), chrSymbols = stringToArray2(chars2), start2 = charsStartIndex(strSymbols, chrSymbols), end = charsEndIndex(strSymbols, chrSymbols) + 1;
        return castSlice(strSymbols, start2, end).join("");
      }
      __name(trim2, "trim");
      function trimEnd2(string, chars2, guard) {
        string = toString3(string);
        if (string && (guard || chars2 === undefined$1)) {
          return string.slice(0, trimmedEndIndex(string) + 1);
        }
        if (!string || !(chars2 = baseToString2(chars2))) {
          return string;
        }
        var strSymbols = stringToArray2(string), end = charsEndIndex(strSymbols, stringToArray2(chars2)) + 1;
        return castSlice(strSymbols, 0, end).join("");
      }
      __name(trimEnd2, "trimEnd");
      function trimStart2(string, chars2, guard) {
        string = toString3(string);
        if (string && (guard || chars2 === undefined$1)) {
          return string.replace(reTrimStart, "");
        }
        if (!string || !(chars2 = baseToString2(chars2))) {
          return string;
        }
        var strSymbols = stringToArray2(string), start2 = charsStartIndex(strSymbols, stringToArray2(chars2));
        return castSlice(strSymbols, start2).join("");
      }
      __name(trimStart2, "trimStart");
      function truncate2(string, options5) {
        var length = DEFAULT_TRUNC_LENGTH, omission = DEFAULT_TRUNC_OMISSION;
        if (isObject2(options5)) {
          var separator = "separator" in options5 ? options5.separator : separator;
          length = "length" in options5 ? toInteger(options5.length) : length;
          omission = "omission" in options5 ? baseToString2(options5.omission) : omission;
        }
        string = toString3(string);
        var strLength = string.length;
        if (hasUnicode(string)) {
          var strSymbols = stringToArray2(string);
          strLength = strSymbols.length;
        }
        if (length >= strLength) {
          return string;
        }
        var end = length - stringSize(omission);
        if (end < 1) {
          return omission;
        }
        var result2 = strSymbols ? castSlice(strSymbols, 0, end).join("") : string.slice(0, end);
        if (separator === undefined$1) {
          return result2 + omission;
        }
        if (strSymbols) {
          end += result2.length - end;
        }
        if (isRegExp2(separator)) {
          if (string.slice(end).search(separator)) {
            var match2, substring = result2;
            if (!separator.global) {
              separator = RegExp2(separator.source, toString3(reFlags2.exec(separator)) + "g");
            }
            separator.lastIndex = 0;
            while (match2 = separator.exec(substring)) {
              var newEnd = match2.index;
            }
            result2 = result2.slice(0, newEnd === undefined$1 ? end : newEnd);
          }
        } else if (string.indexOf(baseToString2(separator), end) != end) {
          var index2 = result2.lastIndexOf(separator);
          if (index2 > -1) {
            result2 = result2.slice(0, index2);
          }
        }
        return result2 + omission;
      }
      __name(truncate2, "truncate");
      function unescape2(string) {
        string = toString3(string);
        return string && reHasEscapedHtml.test(string) ? string.replace(reEscapedHtml, unescapeHtmlChar) : string;
      }
      __name(unescape2, "unescape");
      var upperCase = createCompounder(function(result2, word, index2) {
        return result2 + (index2 ? " " : "") + word.toUpperCase();
      });
      var upperFirst = createCaseFirst("toUpperCase");
      function words(string, pattern, guard) {
        string = toString3(string);
        pattern = guard ? undefined$1 : pattern;
        if (pattern === undefined$1) {
          return hasUnicodeWord(string) ? unicodeWords(string) : asciiWords(string);
        }
        return string.match(pattern) || [];
      }
      __name(words, "words");
      var attempt = baseRest(function(func, args) {
        try {
          return apply2(func, undefined$1, args);
        } catch (e2) {
          return isError2(e2) ? e2 : new Error2(e2);
        }
      });
      var bindAll2 = flatRest(function(object, methodNames) {
        arrayEach2(methodNames, function(key) {
          key = toKey(key);
          baseAssignValue2(object, key, bind3(object[key], object));
        });
        return object;
      });
      function cond(pairs) {
        var length = pairs == null ? 0 : pairs.length, toIteratee = getIteratee();
        pairs = !length ? [] : arrayMap(pairs, function(pair) {
          if (typeof pair[1] != "function") {
            throw new TypeError2(FUNC_ERROR_TEXT);
          }
          return [toIteratee(pair[0]), pair[1]];
        });
        return baseRest(function(args) {
          var index2 = -1;
          while (++index2 < length) {
            var pair = pairs[index2];
            if (apply2(pair[0], this, args)) {
              return apply2(pair[1], this, args);
            }
          }
        });
      }
      __name(cond, "cond");
      function conforms(source) {
        return baseConforms(baseClone2(source, CLONE_DEEP_FLAG2));
      }
      __name(conforms, "conforms");
      function constant(value3) {
        return function() {
          return value3;
        };
      }
      __name(constant, "constant");
      function defaultTo(value3, defaultValue2) {
        return value3 == null || value3 !== value3 ? defaultValue2 : value3;
      }
      __name(defaultTo, "defaultTo");
      var flow = createFlow();
      var flowRight = createFlow(true);
      function identity2(value3) {
        return value3;
      }
      __name(identity2, "identity");
      function iteratee(func) {
        return baseIteratee(typeof func == "function" ? func : baseClone2(func, CLONE_DEEP_FLAG2));
      }
      __name(iteratee, "iteratee");
      function matches2(source) {
        return baseMatches(baseClone2(source, CLONE_DEEP_FLAG2));
      }
      __name(matches2, "matches");
      function matchesProperty(path, srcValue) {
        return baseMatchesProperty(path, baseClone2(srcValue, CLONE_DEEP_FLAG2));
      }
      __name(matchesProperty, "matchesProperty");
      var method = baseRest(function(path, args) {
        return function(object) {
          return baseInvoke(object, path, args);
        };
      });
      var methodOf = baseRest(function(object, args) {
        return function(path) {
          return baseInvoke(object, path, args);
        };
      });
      function mixin(object, source, options5) {
        var props = keys2(source), methodNames = baseFunctions(source, props);
        if (options5 == null && !(isObject2(source) && (methodNames.length || !props.length))) {
          options5 = source;
          source = object;
          object = this;
          methodNames = baseFunctions(source, keys2(source));
        }
        var chain2 = !(isObject2(options5) && "chain" in options5) || !!options5.chain, isFunc = isFunction2(object);
        arrayEach2(methodNames, function(methodName) {
          var func = source[methodName];
          object[methodName] = func;
          if (isFunc) {
            object.prototype[methodName] = function() {
              var chainAll = this.__chain__;
              if (chain2 || chainAll) {
                var result2 = object(this.__wrapped__), actions = result2.__actions__ = copyArray2(this.__actions__);
                actions.push({ "func": func, "args": arguments, "thisArg": object });
                result2.__chain__ = chainAll;
                return result2;
              }
              return func.apply(object, arrayPush2([this.value()], arguments));
            };
          }
        });
        return object;
      }
      __name(mixin, "mixin");
      function noConflict() {
        if (root34._ === this) {
          root34._ = oldDash;
        }
        return this;
      }
      __name(noConflict, "noConflict");
      function noop2() {
      }
      __name(noop2, "noop");
      function nthArg(n2) {
        n2 = toInteger(n2);
        return baseRest(function(args) {
          return baseNth(args, n2);
        });
      }
      __name(nthArg, "nthArg");
      var over = createOver(arrayMap);
      var overEvery = createOver(arrayEvery);
      var overSome = createOver(arraySome);
      function property(path) {
        return isKey(path) ? baseProperty(toKey(path)) : basePropertyDeep(path);
      }
      __name(property, "property");
      function propertyOf(object) {
        return function(path) {
          return object == null ? undefined$1 : baseGet(object, path);
        };
      }
      __name(propertyOf, "propertyOf");
      var range2 = createRange();
      var rangeRight = createRange(true);
      function stubArray2() {
        return [];
      }
      __name(stubArray2, "stubArray");
      function stubFalse2() {
        return false;
      }
      __name(stubFalse2, "stubFalse");
      function stubObject() {
        return {};
      }
      __name(stubObject, "stubObject");
      function stubString() {
        return "";
      }
      __name(stubString, "stubString");
      function stubTrue() {
        return true;
      }
      __name(stubTrue, "stubTrue");
      function times(n2, iteratee2) {
        n2 = toInteger(n2);
        if (n2 < 1 || n2 > MAX_SAFE_INTEGER2) {
          return [];
        }
        var index2 = MAX_ARRAY_LENGTH, length = nativeMin(n2, MAX_ARRAY_LENGTH);
        iteratee2 = getIteratee(iteratee2);
        n2 -= MAX_ARRAY_LENGTH;
        var result2 = baseTimes2(length, iteratee2);
        while (++index2 < n2) {
          iteratee2(index2);
        }
        return result2;
      }
      __name(times, "times");
      function toPath(value3) {
        if (isArray2(value3)) {
          return arrayMap(value3, toKey);
        }
        return isSymbol2(value3) ? [value3] : copyArray2(stringToPath(toString3(value3)));
      }
      __name(toPath, "toPath");
      function uniqueId(prefix2) {
        var id4 = ++idCounter;
        return toString3(prefix2) + id4;
      }
      __name(uniqueId, "uniqueId");
      var add3 = createMathOperation(function(augend, addend) {
        return augend + addend;
      }, 0);
      var ceil = createRound("ceil");
      var divide = createMathOperation(function(dividend, divisor) {
        return dividend / divisor;
      }, 1);
      var floor2 = createRound("floor");
      function max(array) {
        return array && array.length ? baseExtremum(array, identity2, baseGt) : undefined$1;
      }
      __name(max, "max");
      function maxBy(array, iteratee2) {
        return array && array.length ? baseExtremum(array, getIteratee(iteratee2, 2), baseGt) : undefined$1;
      }
      __name(maxBy, "maxBy");
      function mean(array) {
        return baseMean(array, identity2);
      }
      __name(mean, "mean");
      function meanBy(array, iteratee2) {
        return baseMean(array, getIteratee(iteratee2, 2));
      }
      __name(meanBy, "meanBy");
      function min(array) {
        return array && array.length ? baseExtremum(array, identity2, baseLt) : undefined$1;
      }
      __name(min, "min");
      function minBy(array, iteratee2) {
        return array && array.length ? baseExtremum(array, getIteratee(iteratee2, 2), baseLt) : undefined$1;
      }
      __name(minBy, "minBy");
      var multiply = createMathOperation(function(multiplier, multiplicand) {
        return multiplier * multiplicand;
      }, 1);
      var round = createRound("round");
      var subtract = createMathOperation(function(minuend, subtrahend) {
        return minuend - subtrahend;
      }, 0);
      function sum(array) {
        return array && array.length ? baseSum(array, identity2) : 0;
      }
      __name(sum, "sum");
      function sumBy(array, iteratee2) {
        return array && array.length ? baseSum(array, getIteratee(iteratee2, 2)) : 0;
      }
      __name(sumBy, "sumBy");
      lodash2.after = after;
      lodash2.ary = ary;
      lodash2.assign = assign2;
      lodash2.assignIn = assignIn;
      lodash2.assignInWith = assignInWith;
      lodash2.assignWith = assignWith;
      lodash2.at = at;
      lodash2.before = before;
      lodash2.bind = bind3;
      lodash2.bindAll = bindAll2;
      lodash2.bindKey = bindKey;
      lodash2.castArray = castArray;
      lodash2.chain = chain;
      lodash2.chunk = chunk;
      lodash2.compact = compact;
      lodash2.concat = concat;
      lodash2.cond = cond;
      lodash2.conforms = conforms;
      lodash2.constant = constant;
      lodash2.countBy = countBy;
      lodash2.create = create3;
      lodash2.curry = curry;
      lodash2.curryRight = curryRight;
      lodash2.debounce = debounce2;
      lodash2.defaults = defaults2;
      lodash2.defaultsDeep = defaultsDeep;
      lodash2.defer = defer;
      lodash2.delay = delay;
      lodash2.difference = difference;
      lodash2.differenceBy = differenceBy;
      lodash2.differenceWith = differenceWith;
      lodash2.drop = drop;
      lodash2.dropRight = dropRight;
      lodash2.dropRightWhile = dropRightWhile;
      lodash2.dropWhile = dropWhile;
      lodash2.fill = fill2;
      lodash2.filter = filter4;
      lodash2.flatMap = flatMap;
      lodash2.flatMapDeep = flatMapDeep;
      lodash2.flatMapDepth = flatMapDepth;
      lodash2.flatten = flatten2;
      lodash2.flattenDeep = flattenDeep;
      lodash2.flattenDepth = flattenDepth;
      lodash2.flip = flip;
      lodash2.flow = flow;
      lodash2.flowRight = flowRight;
      lodash2.fromPairs = fromPairs;
      lodash2.functions = functions;
      lodash2.functionsIn = functionsIn;
      lodash2.groupBy = groupBy;
      lodash2.initial = initial;
      lodash2.intersection = intersection;
      lodash2.intersectionBy = intersectionBy;
      lodash2.intersectionWith = intersectionWith;
      lodash2.invert = invert;
      lodash2.invertBy = invertBy;
      lodash2.invokeMap = invokeMap;
      lodash2.iteratee = iteratee;
      lodash2.keyBy = keyBy;
      lodash2.keys = keys2;
      lodash2.keysIn = keysIn2;
      lodash2.map = map3;
      lodash2.mapKeys = mapKeys;
      lodash2.mapValues = mapValues;
      lodash2.matches = matches2;
      lodash2.matchesProperty = matchesProperty;
      lodash2.memoize = memoize;
      lodash2.merge = merge2;
      lodash2.mergeWith = mergeWith;
      lodash2.method = method;
      lodash2.methodOf = methodOf;
      lodash2.mixin = mixin;
      lodash2.negate = negate;
      lodash2.nthArg = nthArg;
      lodash2.omit = omit2;
      lodash2.omitBy = omitBy;
      lodash2.once = once2;
      lodash2.orderBy = orderBy;
      lodash2.over = over;
      lodash2.overArgs = overArgs;
      lodash2.overEvery = overEvery;
      lodash2.overSome = overSome;
      lodash2.partial = partial;
      lodash2.partialRight = partialRight;
      lodash2.partition = partition;
      lodash2.pick = pick2;
      lodash2.pickBy = pickBy;
      lodash2.property = property;
      lodash2.propertyOf = propertyOf;
      lodash2.pull = pull;
      lodash2.pullAll = pullAll;
      lodash2.pullAllBy = pullAllBy;
      lodash2.pullAllWith = pullAllWith;
      lodash2.pullAt = pullAt;
      lodash2.range = range2;
      lodash2.rangeRight = rangeRight;
      lodash2.rearg = rearg;
      lodash2.reject = reject3;
      lodash2.remove = remove4;
      lodash2.rest = rest;
      lodash2.reverse = reverse2;
      lodash2.sampleSize = sampleSize;
      lodash2.set = set3;
      lodash2.setWith = setWith;
      lodash2.shuffle = shuffle2;
      lodash2.slice = slice2;
      lodash2.sortBy = sortBy;
      lodash2.sortedUniq = sortedUniq;
      lodash2.sortedUniqBy = sortedUniqBy;
      lodash2.split = split2;
      lodash2.spread = spread2;
      lodash2.tail = tail;
      lodash2.take = take;
      lodash2.takeRight = takeRight;
      lodash2.takeRightWhile = takeRightWhile;
      lodash2.takeWhile = takeWhile;
      lodash2.tap = tap;
      lodash2.throttle = throttle2;
      lodash2.thru = thru;
      lodash2.toArray = toArray2;
      lodash2.toPairs = toPairs;
      lodash2.toPairsIn = toPairsIn;
      lodash2.toPath = toPath;
      lodash2.toPlainObject = toPlainObject;
      lodash2.transform = transform2;
      lodash2.unary = unary;
      lodash2.union = union;
      lodash2.unionBy = unionBy;
      lodash2.unionWith = unionWith;
      lodash2.uniq = uniq2;
      lodash2.uniqBy = uniqBy;
      lodash2.uniqWith = uniqWith;
      lodash2.unset = unset;
      lodash2.unzip = unzip;
      lodash2.unzipWith = unzipWith;
      lodash2.update = update;
      lodash2.updateWith = updateWith;
      lodash2.values = values;
      lodash2.valuesIn = valuesIn;
      lodash2.without = without;
      lodash2.words = words;
      lodash2.wrap = wrap2;
      lodash2.xor = xor;
      lodash2.xorBy = xorBy;
      lodash2.xorWith = xorWith;
      lodash2.zip = zip;
      lodash2.zipObject = zipObject;
      lodash2.zipObjectDeep = zipObjectDeep;
      lodash2.zipWith = zipWith;
      lodash2.entries = toPairs;
      lodash2.entriesIn = toPairsIn;
      lodash2.extend = assignIn;
      lodash2.extendWith = assignInWith;
      mixin(lodash2, lodash2);
      lodash2.add = add3;
      lodash2.attempt = attempt;
      lodash2.camelCase = camelCase;
      lodash2.capitalize = capitalize2;
      lodash2.ceil = ceil;
      lodash2.clamp = clamp2;
      lodash2.clone = clone2;
      lodash2.cloneDeep = cloneDeep2;
      lodash2.cloneDeepWith = cloneDeepWith;
      lodash2.cloneWith = cloneWith;
      lodash2.conformsTo = conformsTo;
      lodash2.deburr = deburr;
      lodash2.defaultTo = defaultTo;
      lodash2.divide = divide;
      lodash2.endsWith = endsWith3;
      lodash2.eq = eq2;
      lodash2.escape = escape2;
      lodash2.escapeRegExp = escapeRegExp2;
      lodash2.every = every;
      lodash2.find = find2;
      lodash2.findIndex = findIndex;
      lodash2.findKey = findKey2;
      lodash2.findLast = findLast2;
      lodash2.findLastIndex = findLastIndex2;
      lodash2.findLastKey = findLastKey;
      lodash2.floor = floor2;
      lodash2.forEach = forEach3;
      lodash2.forEachRight = forEachRight;
      lodash2.forIn = forIn;
      lodash2.forInRight = forInRight;
      lodash2.forOwn = forOwn;
      lodash2.forOwnRight = forOwnRight;
      lodash2.get = get3;
      lodash2.gt = gt2;
      lodash2.gte = gte2;
      lodash2.has = has2;
      lodash2.hasIn = hasIn;
      lodash2.head = head;
      lodash2.identity = identity2;
      lodash2.includes = includes;
      lodash2.indexOf = indexOf;
      lodash2.inRange = inRange;
      lodash2.invoke = invoke2;
      lodash2.isArguments = isArguments2;
      lodash2.isArray = isArray2;
      lodash2.isArrayBuffer = isArrayBuffer2;
      lodash2.isArrayLike = isArrayLike2;
      lodash2.isArrayLikeObject = isArrayLikeObject;
      lodash2.isBoolean = isBoolean2;
      lodash2.isBuffer = isBuffer2;
      lodash2.isDate = isDate2;
      lodash2.isElement = isElement2;
      lodash2.isEmpty = isEmpty3;
      lodash2.isEqual = isEqual;
      lodash2.isEqualWith = isEqualWith;
      lodash2.isError = isError2;
      lodash2.isFinite = isFinite2;
      lodash2.isFunction = isFunction2;
      lodash2.isInteger = isInteger;
      lodash2.isLength = isLength2;
      lodash2.isMap = isMap2;
      lodash2.isMatch = isMatch;
      lodash2.isMatchWith = isMatchWith;
      lodash2.isNaN = isNaN2;
      lodash2.isNative = isNative;
      lodash2.isNil = isNil;
      lodash2.isNull = isNull;
      lodash2.isNumber = isNumber2;
      lodash2.isObject = isObject2;
      lodash2.isObjectLike = isObjectLike2;
      lodash2.isPlainObject = isPlainObject2;
      lodash2.isRegExp = isRegExp2;
      lodash2.isSafeInteger = isSafeInteger;
      lodash2.isSet = isSet2;
      lodash2.isString = isString2;
      lodash2.isSymbol = isSymbol2;
      lodash2.isTypedArray = isTypedArray2;
      lodash2.isUndefined = isUndefined2;
      lodash2.isWeakMap = isWeakMap;
      lodash2.isWeakSet = isWeakSet;
      lodash2.join = join2;
      lodash2.kebabCase = kebabCase;
      lodash2.last = last;
      lodash2.lastIndexOf = lastIndexOf;
      lodash2.lowerCase = lowerCase;
      lodash2.lowerFirst = lowerFirst;
      lodash2.lt = lt2;
      lodash2.lte = lte2;
      lodash2.max = max;
      lodash2.maxBy = maxBy;
      lodash2.mean = mean;
      lodash2.meanBy = meanBy;
      lodash2.min = min;
      lodash2.minBy = minBy;
      lodash2.stubArray = stubArray2;
      lodash2.stubFalse = stubFalse2;
      lodash2.stubObject = stubObject;
      lodash2.stubString = stubString;
      lodash2.stubTrue = stubTrue;
      lodash2.multiply = multiply;
      lodash2.nth = nth;
      lodash2.noConflict = noConflict;
      lodash2.noop = noop2;
      lodash2.now = now2;
      lodash2.pad = pad;
      lodash2.padEnd = padEnd;
      lodash2.padStart = padStart;
      lodash2.parseInt = parseInt2;
      lodash2.random = random;
      lodash2.reduce = reduce2;
      lodash2.reduceRight = reduceRight;
      lodash2.repeat = repeat4;
      lodash2.replace = replace2;
      lodash2.result = result;
      lodash2.round = round;
      lodash2.runInContext = runInContext2;
      lodash2.sample = sample;
      lodash2.size = size;
      lodash2.snakeCase = snakeCase;
      lodash2.some = some;
      lodash2.sortedIndex = sortedIndex;
      lodash2.sortedIndexBy = sortedIndexBy;
      lodash2.sortedIndexOf = sortedIndexOf;
      lodash2.sortedLastIndex = sortedLastIndex;
      lodash2.sortedLastIndexBy = sortedLastIndexBy;
      lodash2.sortedLastIndexOf = sortedLastIndexOf;
      lodash2.startCase = startCase;
      lodash2.startsWith = startsWith2;
      lodash2.subtract = subtract;
      lodash2.sum = sum;
      lodash2.sumBy = sumBy;
      lodash2.template = template;
      lodash2.times = times;
      lodash2.toFinite = toFinite;
      lodash2.toInteger = toInteger;
      lodash2.toLength = toLength;
      lodash2.toLower = toLower;
      lodash2.toNumber = toNumber2;
      lodash2.toSafeInteger = toSafeInteger;
      lodash2.toString = toString3;
      lodash2.toUpper = toUpper;
      lodash2.trim = trim2;
      lodash2.trimEnd = trimEnd2;
      lodash2.trimStart = trimStart2;
      lodash2.truncate = truncate2;
      lodash2.unescape = unescape2;
      lodash2.uniqueId = uniqueId;
      lodash2.upperCase = upperCase;
      lodash2.upperFirst = upperFirst;
      lodash2.each = forEach3;
      lodash2.eachRight = forEachRight;
      lodash2.first = head;
      mixin(lodash2, function() {
        var source = {};
        baseForOwn(lodash2, function(func, methodName) {
          if (!hasOwnProperty2.call(lodash2.prototype, methodName)) {
            source[methodName] = func;
          }
        });
        return source;
      }(), { "chain": false });
      lodash2.VERSION = VERSION2;
      arrayEach2(["bind", "bindKey", "curry", "curryRight", "partial", "partialRight"], function(methodName) {
        lodash2[methodName].placeholder = lodash2;
      });
      arrayEach2(["drop", "take"], function(methodName, index2) {
        LazyWrapper.prototype[methodName] = function(n2) {
          n2 = n2 === undefined$1 ? 1 : nativeMax(toInteger(n2), 0);
          var result2 = this.__filtered__ && !index2 ? new LazyWrapper(this) : this.clone();
          if (result2.__filtered__) {
            result2.__takeCount__ = nativeMin(n2, result2.__takeCount__);
          } else {
            result2.__views__.push({
              "size": nativeMin(n2, MAX_ARRAY_LENGTH),
              "type": methodName + (result2.__dir__ < 0 ? "Right" : "")
            });
          }
          return result2;
        };
        LazyWrapper.prototype[methodName + "Right"] = function(n2) {
          return this.reverse()[methodName](n2).reverse();
        };
      });
      arrayEach2(["filter", "map", "takeWhile"], function(methodName, index2) {
        var type = index2 + 1, isFilter = type == LAZY_FILTER_FLAG || type == LAZY_WHILE_FLAG;
        LazyWrapper.prototype[methodName] = function(iteratee2) {
          var result2 = this.clone();
          result2.__iteratees__.push({
            "iteratee": getIteratee(iteratee2, 3),
            "type": type
          });
          result2.__filtered__ = result2.__filtered__ || isFilter;
          return result2;
        };
      });
      arrayEach2(["head", "last"], function(methodName, index2) {
        var takeName = "take" + (index2 ? "Right" : "");
        LazyWrapper.prototype[methodName] = function() {
          return this[takeName](1).value()[0];
        };
      });
      arrayEach2(["initial", "tail"], function(methodName, index2) {
        var dropName = "drop" + (index2 ? "" : "Right");
        LazyWrapper.prototype[methodName] = function() {
          return this.__filtered__ ? new LazyWrapper(this) : this[dropName](1);
        };
      });
      LazyWrapper.prototype.compact = function() {
        return this.filter(identity2);
      };
      LazyWrapper.prototype.find = function(predicate) {
        return this.filter(predicate).head();
      };
      LazyWrapper.prototype.findLast = function(predicate) {
        return this.reverse().find(predicate);
      };
      LazyWrapper.prototype.invokeMap = baseRest(function(path, args) {
        if (typeof path == "function") {
          return new LazyWrapper(this);
        }
        return this.map(function(value3) {
          return baseInvoke(value3, path, args);
        });
      });
      LazyWrapper.prototype.reject = function(predicate) {
        return this.filter(negate(getIteratee(predicate)));
      };
      LazyWrapper.prototype.slice = function(start2, end) {
        start2 = toInteger(start2);
        var result2 = this;
        if (result2.__filtered__ && (start2 > 0 || end < 0)) {
          return new LazyWrapper(result2);
        }
        if (start2 < 0) {
          result2 = result2.takeRight(-start2);
        } else if (start2) {
          result2 = result2.drop(start2);
        }
        if (end !== undefined$1) {
          end = toInteger(end);
          result2 = end < 0 ? result2.dropRight(-end) : result2.take(end - start2);
        }
        return result2;
      };
      LazyWrapper.prototype.takeRightWhile = function(predicate) {
        return this.reverse().takeWhile(predicate).reverse();
      };
      LazyWrapper.prototype.toArray = function() {
        return this.take(MAX_ARRAY_LENGTH);
      };
      baseForOwn(LazyWrapper.prototype, function(func, methodName) {
        var checkIteratee = /^(?:filter|find|map|reject)|While$/.test(methodName), isTaker = /^(?:head|last)$/.test(methodName), lodashFunc = lodash2[isTaker ? "take" + (methodName == "last" ? "Right" : "") : methodName], retUnwrapped = isTaker || /^find/.test(methodName);
        if (!lodashFunc) {
          return;
        }
        lodash2.prototype[methodName] = function() {
          var value3 = this.__wrapped__, args = isTaker ? [1] : arguments, isLazy = value3 instanceof LazyWrapper, iteratee2 = args[0], useLazy = isLazy || isArray2(value3);
          var interceptor = /* @__PURE__ */ __name(function(value4) {
            var result3 = lodashFunc.apply(lodash2, arrayPush2([value4], args));
            return isTaker && chainAll ? result3[0] : result3;
          }, "interceptor");
          if (useLazy && checkIteratee && typeof iteratee2 == "function" && iteratee2.length != 1) {
            isLazy = useLazy = false;
          }
          var chainAll = this.__chain__, isHybrid = !!this.__actions__.length, isUnwrapped = retUnwrapped && !chainAll, onlyLazy = isLazy && !isHybrid;
          if (!retUnwrapped && useLazy) {
            value3 = onlyLazy ? value3 : new LazyWrapper(this);
            var result2 = func.apply(value3, args);
            result2.__actions__.push({ "func": thru, "args": [interceptor], "thisArg": undefined$1 });
            return new LodashWrapper(result2, chainAll);
          }
          if (isUnwrapped && onlyLazy) {
            return func.apply(this, args);
          }
          result2 = this.thru(interceptor);
          return isUnwrapped ? isTaker ? result2.value()[0] : result2.value() : result2;
        };
      });
      arrayEach2(["pop", "push", "shift", "sort", "splice", "unshift"], function(methodName) {
        var func = arrayProto2[methodName], chainName = /^(?:push|sort|unshift)$/.test(methodName) ? "tap" : "thru", retUnwrapped = /^(?:pop|shift)$/.test(methodName);
        lodash2.prototype[methodName] = function() {
          var args = arguments;
          if (retUnwrapped && !this.__chain__) {
            var value3 = this.value();
            return func.apply(isArray2(value3) ? value3 : [], args);
          }
          return this[chainName](function(value4) {
            return func.apply(isArray2(value4) ? value4 : [], args);
          });
        };
      });
      baseForOwn(LazyWrapper.prototype, function(func, methodName) {
        var lodashFunc = lodash2[methodName];
        if (lodashFunc) {
          var key = lodashFunc.name + "";
          if (!hasOwnProperty2.call(realNames, key)) {
            realNames[key] = [];
          }
          realNames[key].push({ "name": methodName, "func": lodashFunc });
        }
      });
      realNames[createHybrid(undefined$1, WRAP_BIND_KEY_FLAG).name] = [{
        "name": "wrapper",
        "func": undefined$1
      }];
      LazyWrapper.prototype.clone = lazyClone;
      LazyWrapper.prototype.reverse = lazyReverse;
      LazyWrapper.prototype.value = lazyValue;
      lodash2.prototype.at = wrapperAt;
      lodash2.prototype.chain = wrapperChain;
      lodash2.prototype.commit = wrapperCommit;
      lodash2.prototype.next = wrapperNext;
      lodash2.prototype.plant = wrapperPlant;
      lodash2.prototype.reverse = wrapperReverse;
      lodash2.prototype.toJSON = lodash2.prototype.valueOf = lodash2.prototype.value = wrapperValue;
      lodash2.prototype.first = lodash2.prototype.head;
      if (symIterator) {
        lodash2.prototype[symIterator] = wrapperToIterator;
      }
      return lodash2;
    }, "runInContext");
    var _2 = runInContext();
    if (typeof undefined$1 == "function" && typeof undefined$1.amd == "object" && undefined$1.amd) {
      root34._ = _2;
      undefined$1(function() {
        return _2;
      });
    } else if (freeModule) {
      (freeModule.exports = _2)._ = _2;
      freeExports._ = _2;
    } else {
      root34._ = _2;
    }
  }).call(commonjsGlobal);
})(lodash$1, lodash$1.exports);
var lodashExports = lodash$1.exports;
const _ = /* @__PURE__ */ getDefaultExportFromCjs(lodashExports);
const useDialogStore = /* @__PURE__ */ defineStore("dialog", () => {
  const dialogStack = ref([]);
  const genDialogKey = /* @__PURE__ */ __name(() => `dialog-${Math.random().toString(36).slice(2, 9)}`, "genDialogKey");
  function riseDialog(options5) {
    const dialogKey = options5.key;
    const index2 = dialogStack.value.findIndex((d2) => d2.key === dialogKey);
    if (index2 !== -1) {
      const dialogs = dialogStack.value.splice(index2, 1);
      dialogStack.value.push(...dialogs);
    }
  }
  __name(riseDialog, "riseDialog");
  function closeDialog(options5) {
    const targetDialog = options5 ? dialogStack.value.find((d2) => d2.key === options5.key) : dialogStack.value[0];
    if (!targetDialog) return;
    targetDialog.dialogComponentProps?.onClose?.();
    dialogStack.value.splice(dialogStack.value.indexOf(targetDialog), 1);
  }
  __name(closeDialog, "closeDialog");
  function createDialog(options5) {
    if (dialogStack.value.length >= 10) {
      dialogStack.value.shift();
    }
    const dialog = {
      key: options5.key,
      visible: true,
      title: options5.title,
      headerComponent: options5.headerComponent ? markRaw(options5.headerComponent) : void 0,
      footerComponent: options5.footerComponent ? markRaw(options5.footerComponent) : void 0,
      component: markRaw(options5.component),
      contentProps: { ...options5.props },
      dialogComponentProps: {
        maximizable: false,
        modal: true,
        closable: true,
        closeOnEscape: true,
        dismissableMask: true,
        ...options5.dialogComponentProps,
        maximized: false,
        onMaximize: /* @__PURE__ */ __name(() => {
          dialog.dialogComponentProps.maximized = true;
        }, "onMaximize"),
        onUnmaximize: /* @__PURE__ */ __name(() => {
          dialog.dialogComponentProps.maximized = false;
        }, "onUnmaximize"),
        onAfterHide: /* @__PURE__ */ __name(() => {
          closeDialog(dialog);
        }, "onAfterHide"),
        pt: lodashExports.merge(options5.dialogComponentProps?.pt || {}, {
          root: {
            onMousedown: /* @__PURE__ */ __name(() => {
              riseDialog(dialog);
            }, "onMousedown")
          }
        })
      }
    };
    dialogStack.value.push(dialog);
    return dialog;
  }
  __name(createDialog, "createDialog");
  function showDialog(options5) {
    const dialogKey = options5.key || genDialogKey();
    let dialog = dialogStack.value.find((d2) => d2.key === dialogKey);
    if (dialog) {
      dialog.visible = true;
      riseDialog(dialog);
    } else {
      dialog = createDialog({ ...options5, key: dialogKey });
    }
    return dialog;
  }
  __name(showDialog, "showDialog");
  return {
    dialogStack,
    riseDialog,
    showDialog,
    closeDialog
  };
});
const _hoisted_1$1M = ["id"];
const _sfc_main$1F = /* @__PURE__ */ defineComponent({
  __name: "GlobalDialog",
  setup(__props) {
    const dialogStore = useDialogStore();
    const primevue = usePrimeVue();
    const baseZIndex = computed(() => {
      return primevue?.config?.zIndex?.modal ?? 1100;
    });
    onMounted(() => {
      const mask3 = document.createElement("div");
      ZIndex$1.set("model", mask3, baseZIndex.value);
    });
    return (_ctx, _cache) => {
      return openBlock(true), createElementBlock(Fragment$1, null, renderList(unref(dialogStore).dialogStack, (item3, index2) => {
        return openBlock(), createBlock(unref(script$_), mergeProps$2({
          key: item3.key,
          visible: item3.visible,
          "onUpdate:visible": /* @__PURE__ */ __name(($event) => item3.visible = $event, "onUpdate:visible"),
          class: "global-dialog",
          ref_for: true
        }, item3.dialogComponentProps, {
          "auto-z-index": false,
          pt: item3.dialogComponentProps.pt,
          "pt:mask:style": { zIndex: baseZIndex.value + index2 + 1 },
          "aria-labelledby": item3.key
        }), createSlots({
          header: withCtx(() => [
            item3.headerComponent ? (openBlock(), createBlock(resolveDynamicComponent(item3.headerComponent), {
              key: 0,
              id: item3.key
            }, null, 8, ["id"])) : (openBlock(), createElementBlock("h3", {
              key: 1,
              id: item3.key
            }, toDisplayString$1(item3.title || " "), 9, _hoisted_1$1M))
          ]),
          default: withCtx(() => [
            (openBlock(), createBlock(resolveDynamicComponent(item3.component), mergeProps$2({ ref_for: true }, item3.contentProps, {
              maximized: item3.dialogComponentProps.maximized
            }), null, 16, ["maximized"]))
          ]),
          _: 2
        }, [
          item3.footerComponent ? {
            name: "footer",
            fn: withCtx(() => [
              (openBlock(), createBlock(resolveDynamicComponent(item3.footerComponent)))
            ]),
            key: "0"
          } : void 0
        ]), 1040, ["visible", "onUpdate:visible", "pt", "pt:mask:style", "aria-labelledby"]);
      }), 128);
    };
  }
});
const config$1 = {
  app_title: "ComfyUI",
  app_version: "1.14.5"
};
class ContextMenu {
  static {
    __name(this, "ContextMenu");
  }
  options;
  parentMenu;
  root;
  current_submenu;
  lock;
  /**
   * @todo Interface for values requires functionality change - currently accepts
   * an array of strings, functions, objects, nulls, or undefined.
   * @param values (allows object { title: "Nice text", callback: function ... })
   * @param options [optional] Some options:\
   * - title: title to show on top of the menu
   * - callback: function to call when an option is clicked, it receives the item information
   * - ignore_item_callbacks: ignores the callback inside the item, it just calls the options.callback
   * - event: you can pass a MouseEvent, this way the ContextMenu appears in that position
   */
  constructor(values, options22) {
    options22 ||= {};
    this.options = options22;
    const parent = options22.parentMenu;
    if (parent) {
      if (!(parent instanceof ContextMenu)) {
        console.error("parentMenu must be of class ContextMenu, ignoring it");
        options22.parentMenu = void 0;
      } else {
        this.parentMenu = parent;
        this.parentMenu.lock = true;
        this.parentMenu.current_submenu = this;
      }
      if (parent.options?.className === "dark") {
        options22.className = "dark";
      }
    }
    const eventClass = options22.event ? options22.event.constructor.name : null;
    if (eventClass !== "MouseEvent" && eventClass !== "CustomEvent" && eventClass !== "PointerEvent") {
      console.error(`Event passed to ContextMenu is not of type MouseEvent or CustomEvent. Ignoring it. (${eventClass})`);
      options22.event = void 0;
    }
    const root34 = document.createElement("div");
    let classes2 = "litegraph litecontextmenu litemenubar-panel";
    if (options22.className) classes2 += ` ${options22.className}`;
    root34.className = classes2;
    root34.style.minWidth = "100";
    root34.style.minHeight = "100";
    root34.style.pointerEvents = "none";
    setTimeout(function() {
      root34.style.pointerEvents = "auto";
    }, 100);
    root34.addEventListener(
      "pointerup",
      function(e2) {
        e2.preventDefault();
        return true;
      },
      true
    );
    root34.addEventListener(
      "contextmenu",
      function(e2) {
        if (e2.button != 2) return false;
        e2.preventDefault();
        return false;
      },
      true
    );
    root34.addEventListener(
      "pointerdown",
      (e2) => {
        if (e2.button == 2) {
          this.close();
          e2.preventDefault();
          return true;
        }
      },
      true
    );
    this.root = root34;
    if (options22.title) {
      const element = document.createElement("div");
      element.className = "litemenu-title";
      element.innerHTML = options22.title;
      root34.append(element);
    }
    for (let i2 = 0; i2 < values.length; i2++) {
      const value3 = values[i2];
      let name2 = Array.isArray(values) ? value3 : String(i2);
      if (typeof name2 !== "string") {
        name2 = name2 != null ? name2.content === void 0 ? String(name2) : name2.content : name2;
      }
      this.addItem(name2, value3, options22);
    }
    root34.addEventListener("pointerenter", function() {
      if (root34.closing_timer) {
        clearTimeout(root34.closing_timer);
      }
    });
    const ownerDocument = options22.event?.target?.ownerDocument;
    const root_document = ownerDocument || document;
    if (root_document.fullscreenElement)
      root_document.fullscreenElement.append(root34);
    else
      root_document.body.append(root34);
    let left = options22.left || 0;
    let top = options22.top || 0;
    if (options22.event) {
      left = options22.event.clientX - 10;
      top = options22.event.clientY - 10;
      if (options22.title) top -= 20;
      if (parent) {
        const rect = parent.root.getBoundingClientRect();
        left = rect.left + rect.width;
      }
      const body_rect = document.body.getBoundingClientRect();
      const root_rect = root34.getBoundingClientRect();
      if (body_rect.height == 0)
        console.error("document.body height is 0. That is dangerous, set html,body { height: 100%; }");
      if (body_rect.width && left > body_rect.width - root_rect.width - 10)
        left = body_rect.width - root_rect.width - 10;
      if (body_rect.height && top > body_rect.height - root_rect.height - 10)
        top = body_rect.height - root_rect.height - 10;
    }
    root34.style.left = `${left}px`;
    root34.style.top = `${top}px`;
    if (LiteGraph.context_menu_scaling && options22.scale) {
      root34.style.transform = `scale(${Math.round(options22.scale * 4) * 0.25})`;
    }
  }
  addItem(name2, value3, options22) {
    options22 ||= {};
    const element = document.createElement("div");
    element.className = "litemenu-entry submenu";
    let disabled3 = false;
    if (value3 === null) {
      element.classList.add("separator");
    } else {
      const innerHtml = name2 === null ? "" : String(name2);
      if (typeof value3 === "string") {
        element.innerHTML = innerHtml;
      } else {
        element.innerHTML = value3?.title ?? innerHtml;
        if (value3.disabled) {
          disabled3 = true;
          element.classList.add("disabled");
          element.setAttribute("aria-disabled", "true");
        }
        if (value3.submenu || value3.has_submenu) {
          element.classList.add("has_submenu");
          element.setAttribute("aria-haspopup", "true");
          element.setAttribute("aria-expanded", "false");
        }
        if (value3.className) element.className += ` ${value3.className}`;
      }
      element.value = value3;
      element.setAttribute("role", "menuitem");
      if (typeof value3 === "function") {
        element.dataset["value"] = String(name2);
        element.onclick_callback = value3;
      } else {
        element.dataset["value"] = String(value3);
      }
    }
    this.root.append(element);
    if (!disabled3) element.addEventListener("click", inner_onclick);
    if (!disabled3 && options22.autoopen)
      element.addEventListener("pointerenter", inner_over);
    const setAriaExpanded = /* @__PURE__ */ __name(() => {
      const entries = this.root.querySelectorAll("div.litemenu-entry.has_submenu");
      if (entries) {
        for (const entry of entries) {
          entry.setAttribute("aria-expanded", "false");
        }
      }
      element.setAttribute("aria-expanded", "true");
    }, "setAriaExpanded");
    function inner_over(e2) {
      const value22 = this.value;
      if (!value22 || !value22.has_submenu) return;
      inner_onclick.call(this, e2);
      setAriaExpanded();
    }
    __name(inner_over, "inner_over");
    const that = this;
    function inner_onclick(e2) {
      const value22 = this.value;
      let close_parent = true;
      that.current_submenu?.close(e2);
      if (value22?.has_submenu || value22?.submenu) {
        setAriaExpanded();
      }
      if (options22.callback) {
        const r2 = options22.callback.call(
          this,
          value22,
          options22,
          e2,
          that,
          options22.node
        );
        if (r2 === true) close_parent = false;
      }
      if (typeof value22 === "object") {
        if (value22.callback && !options22.ignore_item_callbacks && value22.disabled !== true) {
          const r2 = value22.callback.call(
            this,
            value22,
            options22,
            e2,
            that,
            options22.extra
          );
          if (r2 === true) close_parent = false;
        }
        if (value22.submenu) {
          if (!value22.submenu.options) throw "ContextMenu submenu needs options";
          new that.constructor(value22.submenu.options, {
            callback: value22.submenu.callback,
            event: e2,
            parentMenu: that,
            ignore_item_callbacks: value22.submenu.ignore_item_callbacks,
            title: value22.submenu.title,
            extra: value22.submenu.extra,
            autoopen: options22.autoopen
          });
          close_parent = false;
        }
      }
      if (close_parent && !that.lock) that.close();
    }
    __name(inner_onclick, "inner_onclick");
    return element;
  }
  close(e2, ignore_parent_menu) {
    this.root.remove();
    if (this.parentMenu && !ignore_parent_menu) {
      this.parentMenu.lock = false;
      this.parentMenu.current_submenu = void 0;
      if (e2 === void 0) {
        this.parentMenu.close();
      } else if (e2 && !ContextMenu.isCursorOverElement(e2, this.parentMenu.root)) {
        ContextMenu.trigger(
          this.parentMenu.root,
          `${LiteGraph.pointerevents_method}leave`,
          e2
        );
      }
    }
    this.current_submenu?.close(e2, true);
    if (this.root.closing_timer) clearTimeout(this.root.closing_timer);
  }
  // this code is used to trigger events easily (used in the context menu mouseleave
  static trigger(element, event_name, params) {
    const evt = document.createEvent("CustomEvent");
    evt.initCustomEvent(event_name, true, true, params);
    if (element.dispatchEvent) element.dispatchEvent(evt);
    else if (element.__events) element.__events.dispatchEvent(evt);
    return evt;
  }
  // returns the top most menu
  getTopMenu() {
    return this.options.parentMenu ? this.options.parentMenu.getTopMenu() : this;
  }
  getFirstEvent() {
    return this.options.parentMenu ? this.options.parentMenu.getFirstEvent() : this.options.event;
  }
  static isCursorOverElement(event, element) {
    const left = event.clientX;
    const top = event.clientY;
    const rect = element.getBoundingClientRect();
    if (!rect) return false;
    if (top > rect.top && top < rect.top + rect.height && left > rect.left && left < rect.left + rect.width) {
      return true;
    }
    return false;
  }
}
var NodeSlotType = /* @__PURE__ */ ((NodeSlotType2) => {
  NodeSlotType2[NodeSlotType2["INPUT"] = 1] = "INPUT";
  NodeSlotType2[NodeSlotType2["OUTPUT"] = 2] = "OUTPUT";
  return NodeSlotType2;
})(NodeSlotType || {});
var RenderShape = /* @__PURE__ */ ((RenderShape2) => {
  RenderShape2[RenderShape2["BOX"] = 1] = "BOX";
  RenderShape2[RenderShape2["ROUND"] = 2] = "ROUND";
  RenderShape2[RenderShape2["CIRCLE"] = 3] = "CIRCLE";
  RenderShape2[RenderShape2["CARD"] = 4] = "CARD";
  RenderShape2[RenderShape2["ARROW"] = 5] = "ARROW";
  RenderShape2[RenderShape2["GRID"] = 6] = "GRID";
  RenderShape2[RenderShape2["HollowCircle"] = 7] = "HollowCircle";
  return RenderShape2;
})(RenderShape || {});
var CanvasItem = /* @__PURE__ */ ((CanvasItem2) => {
  CanvasItem2[CanvasItem2["Nothing"] = 0] = "Nothing";
  CanvasItem2[CanvasItem2["Node"] = 1] = "Node";
  CanvasItem2[CanvasItem2["Group"] = 2] = "Group";
  CanvasItem2[CanvasItem2["Reroute"] = 4] = "Reroute";
  CanvasItem2[CanvasItem2["Link"] = 8] = "Link";
  CanvasItem2[CanvasItem2["ResizeSe"] = 16] = "ResizeSe";
  return CanvasItem2;
})(CanvasItem || {});
var LinkDirection = /* @__PURE__ */ ((LinkDirection2) => {
  LinkDirection2[LinkDirection2["NONE"] = 0] = "NONE";
  LinkDirection2[LinkDirection2["UP"] = 1] = "UP";
  LinkDirection2[LinkDirection2["DOWN"] = 2] = "DOWN";
  LinkDirection2[LinkDirection2["LEFT"] = 3] = "LEFT";
  LinkDirection2[LinkDirection2["RIGHT"] = 4] = "RIGHT";
  LinkDirection2[LinkDirection2["CENTER"] = 5] = "CENTER";
  return LinkDirection2;
})(LinkDirection || {});
var LinkRenderType = /* @__PURE__ */ ((LinkRenderType2) => {
  LinkRenderType2[LinkRenderType2["HIDDEN_LINK"] = -1] = "HIDDEN_LINK";
  LinkRenderType2[LinkRenderType2["STRAIGHT_LINK"] = 0] = "STRAIGHT_LINK";
  LinkRenderType2[LinkRenderType2["LINEAR_LINK"] = 1] = "LINEAR_LINK";
  LinkRenderType2[LinkRenderType2["SPLINE_LINK"] = 2] = "SPLINE_LINK";
  return LinkRenderType2;
})(LinkRenderType || {});
var LinkMarkerShape = /* @__PURE__ */ ((LinkMarkerShape2) => {
  LinkMarkerShape2[LinkMarkerShape2["None"] = 0] = "None";
  LinkMarkerShape2[LinkMarkerShape2["Circle"] = 1] = "Circle";
  LinkMarkerShape2[LinkMarkerShape2["Arrow"] = 2] = "Arrow";
  return LinkMarkerShape2;
})(LinkMarkerShape || {});
var TitleMode = /* @__PURE__ */ ((TitleMode2) => {
  TitleMode2[TitleMode2["NORMAL_TITLE"] = 0] = "NORMAL_TITLE";
  TitleMode2[TitleMode2["NO_TITLE"] = 1] = "NO_TITLE";
  TitleMode2[TitleMode2["TRANSPARENT_TITLE"] = 2] = "TRANSPARENT_TITLE";
  TitleMode2[TitleMode2["AUTOHIDE_TITLE"] = 3] = "AUTOHIDE_TITLE";
  return TitleMode2;
})(TitleMode || {});
var LGraphEventMode = /* @__PURE__ */ ((LGraphEventMode2) => {
  LGraphEventMode2[LGraphEventMode2["ALWAYS"] = 0] = "ALWAYS";
  LGraphEventMode2[LGraphEventMode2["ON_EVENT"] = 1] = "ON_EVENT";
  LGraphEventMode2[LGraphEventMode2["NEVER"] = 2] = "NEVER";
  LGraphEventMode2[LGraphEventMode2["ON_TRIGGER"] = 3] = "ON_TRIGGER";
  LGraphEventMode2[LGraphEventMode2["BYPASS"] = 4] = "BYPASS";
  return LGraphEventMode2;
})(LGraphEventMode || {});
var EaseFunction = /* @__PURE__ */ ((EaseFunction2) => {
  EaseFunction2["LINEAR"] = "linear";
  EaseFunction2["EASE_IN_QUAD"] = "easeInQuad";
  EaseFunction2["EASE_OUT_QUAD"] = "easeOutQuad";
  EaseFunction2["EASE_IN_OUT_QUAD"] = "easeInOutQuad";
  return EaseFunction2;
})(EaseFunction || {});
function distance(a2, b2) {
  return Math.sqrt(
    (b2[0] - a2[0]) * (b2[0] - a2[0]) + (b2[1] - a2[1]) * (b2[1] - a2[1])
  );
}
__name(distance, "distance");
function dist2(x1, y1, x2, y2) {
  return (x2 - x1) * (x2 - x1) + (y2 - y1) * (y2 - y1);
}
__name(dist2, "dist2");
function isInRectangle(x2, y2, left, top, width2, height) {
  return x2 >= left && x2 < left + width2 && y2 >= top && y2 < top + height;
}
__name(isInRectangle, "isInRectangle");
function isPointInRect(point, rect) {
  return point[0] >= rect[0] && point[0] < rect[0] + rect[2] && point[1] >= rect[1] && point[1] < rect[1] + rect[3];
}
__name(isPointInRect, "isPointInRect");
function isInRect(x2, y2, rect) {
  return x2 >= rect[0] && x2 < rect[0] + rect[2] && y2 >= rect[1] && y2 < rect[1] + rect[3];
}
__name(isInRect, "isInRect");
function isInsideRectangle(x2, y2, left, top, width2, height) {
  return left < x2 && left + width2 > x2 && top < y2 && top + height > y2;
}
__name(isInsideRectangle, "isInsideRectangle");
function isSortaInsideOctagon(x2, y2, radius) {
  const sum = Math.min(radius, Math.abs(x2)) + Math.min(radius, Math.abs(y2));
  return sum < radius * 0.75;
}
__name(isSortaInsideOctagon, "isSortaInsideOctagon");
function overlapBounding(a2, b2) {
  const aRight = a2[0] + a2[2];
  const aBottom = a2[1] + a2[3];
  const bRight = b2[0] + b2[2];
  const bBottom = b2[1] + b2[3];
  return a2[0] > bRight || a2[1] > bBottom || aRight < b2[0] || aBottom < b2[1] ? false : true;
}
__name(overlapBounding, "overlapBounding");
function containsCentre(a2, b2) {
  const centreX = b2[0] + b2[2] * 0.5;
  const centreY = b2[1] + b2[3] * 0.5;
  return isInRect(centreX, centreY, a2);
}
__name(containsCentre, "containsCentre");
function containsRect(a2, b2) {
  const aRight = a2[0] + a2[2];
  const aBottom = a2[1] + a2[3];
  const bRight = b2[0] + b2[2];
  const bBottom = b2[1] + b2[3];
  const identical = a2[0] === b2[0] && a2[1] === b2[1] && aRight === bRight && aBottom === bBottom;
  return !identical && a2[0] <= b2[0] && a2[1] <= b2[1] && aRight >= bRight && aBottom >= bBottom;
}
__name(containsRect, "containsRect");
function findPointOnCurve(out, a2, b2, controlA, controlB, t2 = 0.5) {
  const iT = 1 - t2;
  const c1 = iT * iT * iT;
  const c2 = 3 * (iT * iT) * t2;
  const c3 = 3 * iT * (t2 * t2);
  const c4 = t2 * t2 * t2;
  out[0] = c1 * a2[0] + c2 * controlA[0] + c3 * controlB[0] + c4 * b2[0];
  out[1] = c1 * a2[1] + c2 * controlA[1] + c3 * controlB[1] + c4 * b2[1];
}
__name(findPointOnCurve, "findPointOnCurve");
function createBounds(objects, padding = 10) {
  const bounds = new Float32Array([Infinity, Infinity, -Infinity, -Infinity]);
  for (const obj of objects) {
    const rect = obj.boundingRect;
    bounds[0] = Math.min(bounds[0], rect[0]);
    bounds[1] = Math.min(bounds[1], rect[1]);
    bounds[2] = Math.max(bounds[2], rect[0] + rect[2]);
    bounds[3] = Math.max(bounds[3], rect[1] + rect[3]);
  }
  if (!bounds.every((x2) => isFinite(x2))) return null;
  return [
    bounds[0] - padding,
    bounds[1] - padding,
    bounds[2] - bounds[0] + 2 * padding,
    bounds[3] - bounds[1] + 2 * padding
  ];
}
__name(createBounds, "createBounds");
function snapPoint(pos, snapTo) {
  if (!snapTo) return false;
  pos[0] = snapTo * Math.round(pos[0] / snapTo);
  pos[1] = snapTo * Math.round(pos[1] / snapTo);
  return true;
}
__name(snapPoint, "snapPoint");
class CurveEditor {
  static {
    __name(this, "CurveEditor");
  }
  points;
  selected;
  nearest;
  size;
  must_update;
  margin;
  _nearest;
  constructor(points) {
    this.points = points;
    this.selected = -1;
    this.nearest = -1;
    this.size = null;
    this.must_update = true;
    this.margin = 5;
  }
  static sampleCurve(f2, points) {
    if (!points) return;
    for (let i2 = 0; i2 < points.length - 1; ++i2) {
      const p2 = points[i2];
      const pn = points[i2 + 1];
      if (pn[0] < f2) continue;
      const r2 = pn[0] - p2[0];
      if (Math.abs(r2) < 1e-5) return p2[1];
      const local_f = (f2 - p2[0]) / r2;
      return p2[1] * (1 - local_f) + pn[1] * local_f;
    }
    return 0;
  }
  draw(ctx, size, graphcanvas, background_color, line_color, inactive = false) {
    const points = this.points;
    if (!points) return;
    this.size = size;
    const w2 = size[0] - this.margin * 2;
    const h2 = size[1] - this.margin * 2;
    line_color = line_color || "#666";
    ctx.save();
    ctx.translate(this.margin, this.margin);
    if (background_color) {
      ctx.fillStyle = "#111";
      ctx.fillRect(0, 0, w2, h2);
      ctx.fillStyle = "#222";
      ctx.fillRect(w2 * 0.5, 0, 1, h2);
      ctx.strokeStyle = "#333";
      ctx.strokeRect(0, 0, w2, h2);
    }
    ctx.strokeStyle = line_color;
    if (inactive) ctx.globalAlpha = 0.5;
    ctx.beginPath();
    for (const p2 of points) {
      ctx.lineTo(p2[0] * w2, (1 - p2[1]) * h2);
    }
    ctx.stroke();
    ctx.globalAlpha = 1;
    if (!inactive) {
      for (const [i2, p2] of points.entries()) {
        ctx.fillStyle = this.selected == i2 ? "#FFF" : this.nearest == i2 ? "#DDD" : "#AAA";
        ctx.beginPath();
        ctx.arc(p2[0] * w2, (1 - p2[1]) * h2, 2, 0, Math.PI * 2);
        ctx.fill();
      }
    }
    ctx.restore();
  }
  // localpos is mouse in curve editor space
  onMouseDown(localpos, graphcanvas) {
    const points = this.points;
    if (!points) return;
    if (localpos[1] < 0) return;
    if (this.size == null) throw new Error("CurveEditor.size was null or undefined.");
    const w2 = this.size[0] - this.margin * 2;
    const h2 = this.size[1] - this.margin * 2;
    const x2 = localpos[0] - this.margin;
    const y2 = localpos[1] - this.margin;
    const pos = [x2, y2];
    const max_dist = 30 / graphcanvas.ds.scale;
    this.selected = this.getCloserPoint(pos, max_dist);
    if (this.selected == -1) {
      const point = [x2 / w2, 1 - y2 / h2];
      points.push(point);
      points.sort(function(a2, b2) {
        return a2[0] - b2[0];
      });
      this.selected = points.indexOf(point);
      this.must_update = true;
    }
    if (this.selected != -1) return true;
  }
  onMouseMove(localpos, graphcanvas) {
    const points = this.points;
    if (!points) return;
    const s2 = this.selected;
    if (s2 < 0) return;
    if (this.size == null) throw new Error("CurveEditor.size was null or undefined.");
    const x2 = (localpos[0] - this.margin) / (this.size[0] - this.margin * 2);
    const y2 = (localpos[1] - this.margin) / (this.size[1] - this.margin * 2);
    const curvepos = [
      localpos[0] - this.margin,
      localpos[1] - this.margin
    ];
    const max_dist = 30 / graphcanvas.ds.scale;
    this._nearest = this.getCloserPoint(curvepos, max_dist);
    const point = points[s2];
    if (point) {
      const is_edge_point = s2 == 0 || s2 == points.length - 1;
      if (!is_edge_point && (localpos[0] < -10 || localpos[0] > this.size[0] + 10 || localpos[1] < -10 || localpos[1] > this.size[1] + 10)) {
        points.splice(s2, 1);
        this.selected = -1;
        return;
      }
      if (!is_edge_point) point[0] = clamp(x2, 0, 1);
      else point[0] = s2 == 0 ? 0 : 1;
      point[1] = 1 - clamp(y2, 0, 1);
      points.sort(function(a2, b2) {
        return a2[0] - b2[0];
      });
      this.selected = points.indexOf(point);
      this.must_update = true;
    }
  }
  // Former params: localpos, graphcanvas
  onMouseUp() {
    this.selected = -1;
    return false;
  }
  getCloserPoint(pos, max_dist) {
    const points = this.points;
    if (!points) return -1;
    max_dist = max_dist || 30;
    if (this.size == null) throw new Error("CurveEditor.size was null or undefined.");
    const w2 = this.size[0] - this.margin * 2;
    const h2 = this.size[1] - this.margin * 2;
    const num = points.length;
    const p2 = [0, 0];
    let min_dist = 1e6;
    let closest = -1;
    for (let i2 = 0; i2 < num; ++i2) {
      const p3 = points[i2];
      p2[0] = p3[0] * w2;
      p2[1] = (1 - p3[1]) * h2;
      const dist3 = distance(pos, p2);
      if (dist3 > min_dist || dist3 > max_dist) continue;
      closest = i2;
      min_dist = dist3;
    }
    return closest;
  }
}
class DragAndScale {
  static {
    __name(this, "DragAndScale");
  }
  /**
   * The state of this DragAndScale instance.
   *
   * Implemented as a POCO that can be proxied without side-effects.
   */
  state;
  /** Maximum scale (zoom in) */
  max_scale;
  /** Minimum scale (zoom out) */
  min_scale;
  enabled;
  last_mouse;
  element;
  visible_area;
  dragging;
  viewport;
  get offset() {
    return this.state.offset;
  }
  set offset(value3) {
    this.state.offset = value3;
  }
  get scale() {
    return this.state.scale;
  }
  set scale(value3) {
    this.state.scale = value3;
  }
  constructor(element) {
    this.state = {
      offset: new Float32Array([0, 0]),
      scale: 1
    };
    this.max_scale = 10;
    this.min_scale = 0.1;
    this.enabled = true;
    this.last_mouse = [0, 0];
    this.visible_area = new Float32Array(4);
    this.element = element;
  }
  computeVisibleArea(viewport) {
    if (!this.element) {
      this.visible_area[0] = this.visible_area[1] = this.visible_area[2] = this.visible_area[3] = 0;
      return;
    }
    let width2 = this.element.width;
    let height = this.element.height;
    let startx = -this.offset[0];
    let starty = -this.offset[1];
    if (viewport) {
      startx += viewport[0] / this.scale;
      starty += viewport[1] / this.scale;
      width2 = viewport[2];
      height = viewport[3];
    }
    const endx = startx + width2 / this.scale;
    const endy = starty + height / this.scale;
    this.visible_area[0] = startx;
    this.visible_area[1] = starty;
    this.visible_area[2] = endx - startx;
    this.visible_area[3] = endy - starty;
  }
  toCanvasContext(ctx) {
    ctx.scale(this.scale, this.scale);
    ctx.translate(this.offset[0], this.offset[1]);
  }
  convertOffsetToCanvas(pos) {
    return [
      (pos[0] + this.offset[0]) * this.scale,
      (pos[1] + this.offset[1]) * this.scale
    ];
  }
  convertCanvasToOffset(pos, out) {
    out = out || [0, 0];
    out[0] = pos[0] / this.scale - this.offset[0];
    out[1] = pos[1] / this.scale - this.offset[1];
    return out;
  }
  /** @deprecated Has not been kept up to date */
  mouseDrag(x2, y2) {
    this.offset[0] += x2 / this.scale;
    this.offset[1] += y2 / this.scale;
    this.onredraw?.(this);
  }
  changeScale(value3, zooming_center) {
    if (value3 < this.min_scale) {
      value3 = this.min_scale;
    } else if (value3 > this.max_scale) {
      value3 = this.max_scale;
    }
    if (value3 == this.scale) return;
    if (!this.element) return;
    const rect = this.element.getBoundingClientRect();
    if (!rect) return;
    zooming_center = zooming_center ?? [rect.width * 0.5, rect.height * 0.5];
    const normalizedCenter = [
      zooming_center[0] - rect.x,
      zooming_center[1] - rect.y
    ];
    const center = this.convertCanvasToOffset(normalizedCenter);
    this.scale = value3;
    if (Math.abs(this.scale - 1) < 0.01) this.scale = 1;
    const new_center = this.convertCanvasToOffset(normalizedCenter);
    const delta_offset = [
      new_center[0] - center[0],
      new_center[1] - center[1]
    ];
    this.offset[0] += delta_offset[0];
    this.offset[1] += delta_offset[1];
    this.onredraw?.(this);
  }
  changeDeltaScale(value3, zooming_center) {
    this.changeScale(this.scale * value3, zooming_center);
  }
  /**
   * Starts an animation to fit the view around the specified selection of nodes.
   * @param bounds The bounds to animate the view to, defined by a rectangle.
   */
  animateToBounds(bounds, setDirty, {
    duration = 350,
    zoom = 0.75,
    easing = EaseFunction.EASE_IN_OUT_QUAD
  } = {}) {
    if (!(duration > 0)) throw new RangeError("Duration must be greater than 0");
    const easeFunctions = {
      linear: /* @__PURE__ */ __name((t2) => t2, "linear"),
      easeInQuad: /* @__PURE__ */ __name((t2) => t2 * t2, "easeInQuad"),
      easeOutQuad: /* @__PURE__ */ __name((t2) => t2 * (2 - t2), "easeOutQuad"),
      easeInOutQuad: /* @__PURE__ */ __name((t2) => t2 < 0.5 ? 2 * t2 * t2 : -1 + (4 - 2 * t2) * t2, "easeInOutQuad")
    };
    const easeFunction = easeFunctions[easing] ?? easeFunctions.linear;
    const startTimestamp = performance.now();
    const cw = this.element.width / window.devicePixelRatio;
    const ch = this.element.height / window.devicePixelRatio;
    const startX = this.offset[0];
    const startY = this.offset[1];
    const startX2 = startX - cw / this.scale;
    const startY2 = startY - ch / this.scale;
    const startScale = this.scale;
    let targetScale = startScale;
    if (zoom > 0) {
      const targetScaleX = zoom * cw / Math.max(bounds[2], 300);
      const targetScaleY = zoom * ch / Math.max(bounds[3], 300);
      targetScale = Math.min(targetScaleX, targetScaleY, this.max_scale);
    }
    const scaledWidth = cw / targetScale;
    const scaledHeight = ch / targetScale;
    const targetX = -bounds[0] - bounds[2] * 0.5 + scaledWidth * 0.5;
    const targetY = -bounds[1] - bounds[3] * 0.5 + scaledHeight * 0.5;
    const targetX2 = targetX - scaledWidth;
    const targetY2 = targetY - scaledHeight;
    const animate = /* @__PURE__ */ __name((timestamp2) => {
      const elapsed = timestamp2 - startTimestamp;
      const progress = Math.min(elapsed / duration, 1);
      const easedProgress = easeFunction(progress);
      const currentX = startX + (targetX - startX) * easedProgress;
      const currentY = startY + (targetY - startY) * easedProgress;
      this.offset[0] = currentX;
      this.offset[1] = currentY;
      if (zoom > 0) {
        const currentX2 = startX2 + (targetX2 - startX2) * easedProgress;
        const currentY2 = startY2 + (targetY2 - startY2) * easedProgress;
        const currentWidth = Math.abs(currentX2 - currentX);
        const currentHeight = Math.abs(currentY2 - currentY);
        this.scale = Math.min(cw / currentWidth, ch / currentHeight);
      }
      setDirty();
      if (progress < 1) {
        animationId = requestAnimationFrame(animate);
      } else {
        cancelAnimationFrame(animationId);
      }
    }, "animate");
    let animationId = requestAnimationFrame(animate);
  }
  reset() {
    this.scale = 1;
    this.offset[0] = 0;
    this.offset[1] = 0;
  }
}
var SlotType = /* @__PURE__ */ ((SlotType2) => {
  SlotType2["Array"] = "array";
  SlotType2[SlotType2["Event"] = -1] = "Event";
  return SlotType2;
})(SlotType || {});
var SlotShape = ((SlotShape2) => {
  SlotShape2[SlotShape2["Box"] = RenderShape.BOX] = "Box";
  SlotShape2[SlotShape2["Arrow"] = RenderShape.ARROW] = "Arrow";
  SlotShape2[SlotShape2["Grid"] = RenderShape.GRID] = "Grid";
  SlotShape2[SlotShape2["Circle"] = RenderShape.CIRCLE] = "Circle";
  SlotShape2[SlotShape2["HollowCircle"] = RenderShape.HollowCircle] = "HollowCircle";
  return SlotShape2;
})(SlotShape || {});
var SlotDirection = ((SlotDirection2) => {
  SlotDirection2[SlotDirection2["Up"] = LinkDirection.UP] = "Up";
  SlotDirection2[SlotDirection2["Right"] = LinkDirection.RIGHT] = "Right";
  SlotDirection2[SlotDirection2["Down"] = LinkDirection.DOWN] = "Down";
  SlotDirection2[SlotDirection2["Left"] = LinkDirection.LEFT] = "Left";
  return SlotDirection2;
})(SlotDirection || {});
var LabelPosition = /* @__PURE__ */ ((LabelPosition2) => {
  LabelPosition2["Left"] = "left";
  LabelPosition2["Right"] = "right";
  return LabelPosition2;
})(LabelPosition || {});
function strokeShape(ctx, area, {
  shape = RenderShape.BOX,
  round_radius,
  title_height,
  title_mode = TitleMode.NORMAL_TITLE,
  colour,
  padding = 6,
  collapsed: collapsed2 = false,
  thickness = 1
} = {}) {
  round_radius ??= LiteGraph.ROUND_RADIUS;
  colour ??= LiteGraph.NODE_BOX_OUTLINE_COLOR;
  if (title_mode === TitleMode.TRANSPARENT_TITLE) {
    const height2 = title_height ?? LiteGraph.NODE_TITLE_HEIGHT;
    area[1] -= height2;
    area[3] += height2;
  }
  const { lineWidth, strokeStyle } = ctx;
  ctx.lineWidth = thickness;
  ctx.globalAlpha = 0.8;
  ctx.strokeStyle = colour;
  ctx.beginPath();
  const [x2, y2, width2, height] = area;
  switch (shape) {
    case RenderShape.BOX: {
      ctx.rect(
        x2 - padding,
        y2 - padding,
        width2 + 2 * padding,
        height + 2 * padding
      );
      break;
    }
    case RenderShape.ROUND:
    case RenderShape.CARD: {
      const radius = round_radius + padding;
      const isCollapsed = shape === RenderShape.CARD && collapsed2;
      const cornerRadii = isCollapsed || shape === RenderShape.ROUND ? [radius] : [radius, 2, radius, 2];
      ctx.roundRect(
        x2 - padding,
        y2 - padding,
        width2 + 2 * padding,
        height + 2 * padding,
        cornerRadii
      );
      break;
    }
    case RenderShape.CIRCLE: {
      const centerX = x2 + width2 / 2;
      const centerY = y2 + height / 2;
      const radius = Math.max(width2, height) / 2 + padding;
      ctx.arc(centerX, centerY, radius, 0, Math.PI * 2);
      break;
    }
  }
  ctx.stroke();
  ctx.lineWidth = lineWidth;
  ctx.strokeStyle = strokeStyle;
  ctx.globalAlpha = 1;
}
__name(strokeShape, "strokeShape");
const zeroUuid = "00000000-0000-0000-0000-000000000000";
const randomStorage = new Uint32Array(31);
function createUuidv4() {
  if (typeof crypto?.randomUUID === "function") return crypto.randomUUID();
  if (typeof crypto?.getRandomValues === "function") {
    const random = crypto.getRandomValues(randomStorage);
    let i2 = 0;
    return "10000000-1000-4000-8000-100000000000".replaceAll(/[018]/g, (a2) => (Number(a2) ^ random[i2++] * 3725290298461914e-24 >> Number(a2) * 0.25).toString(16));
  }
  return "10000000-1000-4000-8000-100000000000".replaceAll(/[018]/g, (a2) => (Number(a2) ^ Math.random() * 16 >> Number(a2) * 0.25).toString(16));
}
__name(createUuidv4, "createUuidv4");
class LinkConnectorEventTarget extends EventTarget {
  static {
    __name(this, "LinkConnectorEventTarget");
  }
  dispatch(type, detail) {
    const event = new CustomEvent(type, { detail });
    return super.dispatchEvent(event);
  }
  addEventListener(type, listener, options22) {
    super.addEventListener(type, listener, options22);
  }
  removeEventListener(type, listener, options22) {
    super.removeEventListener(type, listener, options22);
  }
  /** @deprecated Use {@link dispatch}. */
  dispatchEvent(event) {
    return super.dispatchEvent(event);
  }
}
class LLink {
  static {
    __name(this, "LLink");
  }
  /** Link ID */
  id;
  parentId;
  type;
  /** Output node ID */
  origin_id;
  /** Output slot index */
  origin_slot;
  /** Input node ID */
  target_id;
  /** Input slot index */
  target_slot;
  data;
  _data;
  /** Centre point of the link, calculated during render only - can be inaccurate */
  _pos;
  /** @todo Clean up - never implemented in comfy. */
  _last_time;
  /** The last canvas 2D path that was used to render this link */
  path;
  /** @inheritdoc */
  _centreAngle;
  /** @inheritdoc */
  _dragging;
  #color;
  /** Custom colour for this link only */
  get color() {
    return this.#color;
  }
  set color(value3) {
    this.#color = value3 === "" ? null : value3;
  }
  constructor(id4, type, origin_id, origin_slot, target_id, target_slot, parentId) {
    this.id = id4;
    this.type = type;
    this.origin_id = origin_id;
    this.origin_slot = origin_slot;
    this.target_id = target_id;
    this.target_slot = target_slot;
    this.parentId = parentId;
    this._data = null;
    this._pos = new Float32Array(2);
  }
  /** @deprecated Use {@link LLink.create} */
  static createFromArray(data30) {
    return new LLink(data30[0], data30[5], data30[1], data30[2], data30[3], data30[4]);
  }
  /**
   * LLink static factory: creates a new LLink from the provided data.
   * @param data Serialised LLink data to create the link from
   * @returns A new LLink
   */
  static create(data30) {
    return new LLink(
      data30.id,
      data30.type,
      data30.origin_id,
      data30.origin_slot,
      data30.target_id,
      data30.target_slot,
      data30.parentId
    );
  }
  /**
   * Gets all reroutes from the output slot to this segment.  If this segment is a reroute, it will not be included.
   * @returns An ordered array of all reroutes from the node output to
   * this reroute or the reroute before it.  Otherwise, an empty array.
   */
  static getReroutes(network, linkSegment) {
    if (!linkSegment.parentId) return [];
    return network.reroutes.get(linkSegment.parentId)?.getReroutes() ?? [];
  }
  static getFirstReroute(network, linkSegment) {
    return LLink.getReroutes(network, linkSegment).at(0);
  }
  /**
   * Finds the reroute in the chain after the provided reroute ID.
   * @param network The network this link belongs to
   * @param linkSegment The starting point of the search (input side).
   * Typically the LLink object itself, but can be any link segment.
   * @param rerouteId The matching reroute will have this set as its {@link parentId}.
   * @returns The reroute that was found, `undefined` if no reroute was found, or `null` if an infinite loop was detected.
   */
  static findNextReroute(network, linkSegment, rerouteId) {
    if (!linkSegment.parentId) return;
    return network.reroutes.get(linkSegment.parentId)?.findNextReroute(rerouteId);
  }
  configure(o2) {
    if (Array.isArray(o2)) {
      this.id = o2[0];
      this.origin_id = o2[1];
      this.origin_slot = o2[2];
      this.target_id = o2[3];
      this.target_slot = o2[4];
      this.type = o2[5];
    } else {
      this.id = o2.id;
      this.type = o2.type;
      this.origin_id = o2.origin_id;
      this.origin_slot = o2.origin_slot;
      this.target_id = o2.target_id;
      this.target_slot = o2.target_slot;
      this.parentId = o2.parentId;
    }
  }
  /**
   * Disconnects a link and removes it from the graph, cleaning up any reroutes that are no longer used
   * @param network The container (LGraph) where reroutes should be updated
   * @param keepReroutes If `undefined`, reroutes will be automatically removed if no links remain.
   * If `input` or `output`, reroutes will not be automatically removed, and retain a connection to the input or output, respectively.
   */
  disconnect(network, keepReroutes) {
    const reroutes = LLink.getReroutes(network, this);
    const lastReroute = reroutes.at(-1);
    const outputFloating = keepReroutes === "output" && lastReroute?.linkIds.size === 1 && lastReroute.floatingLinkIds.size === 0;
    if (outputFloating || keepReroutes === "input" && lastReroute) {
      const newLink = LLink.create(this);
      newLink.id = -1;
      if (keepReroutes === "input") {
        newLink.origin_id = -1;
        newLink.origin_slot = -1;
        lastReroute.floating = { slotType: "input" };
      } else {
        newLink.target_id = -1;
        newLink.target_slot = -1;
        lastReroute.floating = { slotType: "output" };
      }
      network.addFloatingLink(newLink);
    }
    for (const reroute of reroutes) {
      reroute.linkIds.delete(this.id);
      if (!keepReroutes && !reroute.linkIds.size && !reroute.floatingLinkIds.size) {
        network.reroutes.delete(reroute.id);
      }
    }
    network.links.delete(this.id);
  }
  /**
   * @deprecated Prefer {@link LLink.asSerialisable} (returns an object, not an array)
   * @returns An array representing this LLink
   */
  serialize() {
    return [
      this.id,
      this.origin_id,
      this.origin_slot,
      this.target_id,
      this.target_slot,
      this.type
    ];
  }
  asSerialisable() {
    const copy2 = {
      id: this.id,
      origin_id: this.origin_id,
      origin_slot: this.origin_slot,
      target_id: this.target_id,
      target_slot: this.target_slot,
      type: this.type
    };
    if (this.parentId) copy2.parentId = this.parentId;
    return copy2;
  }
}
function getNodeInputOnPos(node22, x2, y2) {
  const { inputs } = node22;
  if (!inputs) return;
  for (const [index2, input] of inputs.entries()) {
    const pos = node22.getInputPos(index2);
    const nameLength = input.label?.length ?? input.localized_name?.length ?? input.name?.length;
    const width2 = 20 + (nameLength || 3) * 7;
    if (isInRectangle(
      x2,
      y2,
      pos[0] - 10,
      pos[1] - 10,
      width2,
      20
    )) {
      return { index: index2, input, pos };
    }
  }
}
__name(getNodeInputOnPos, "getNodeInputOnPos");
function getNodeOutputOnPos(node22, x2, y2) {
  const { outputs } = node22;
  if (!outputs) return;
  for (const [index2, output] of outputs.entries()) {
    const pos = node22.getOutputPos(index2);
    if (isInRectangle(
      x2,
      y2,
      pos[0] - 10,
      pos[1] - 10,
      40,
      20
    )) {
      return { index: index2, output, pos };
    }
  }
}
__name(getNodeOutputOnPos, "getNodeOutputOnPos");
function isOverNodeInput(node22, canvasx, canvasy, slot_pos) {
  const result = getNodeInputOnPos(node22, canvasx, canvasy);
  if (!result) return -1;
  if (slot_pos) {
    slot_pos[0] = result.pos[0];
    slot_pos[1] = result.pos[1];
  }
  return result.index;
}
__name(isOverNodeInput, "isOverNodeInput");
function isOverNodeOutput(node22, canvasx, canvasy, slot_pos) {
  const result = getNodeOutputOnPos(node22, canvasx, canvasy);
  if (!result) return -1;
  if (slot_pos) {
    slot_pos[0] = result.pos[0];
    slot_pos[1] = result.pos[1];
  }
  return result.index;
}
__name(isOverNodeOutput, "isOverNodeOutput");
class MovingRenderLink {
  static {
    __name(this, "MovingRenderLink");
  }
  constructor(network, link2, toType, fromReroute, dragDirection = LinkDirection.CENTER) {
    this.network = network;
    this.link = link2;
    this.toType = toType;
    this.fromReroute = fromReroute;
    this.dragDirection = dragDirection;
    const {
      origin_id: outputNodeId,
      target_id: inputNodeId,
      origin_slot: outputIndex,
      target_slot: inputIndex
    } = link2;
    const outputNode = network.getNodeById(outputNodeId) ?? void 0;
    if (!outputNode) throw new Error(`Creating DraggingRenderLink for link [${link2.id}] failed: Output node [${outputNodeId}] not found.`);
    const outputSlot = outputNode.outputs.at(outputIndex);
    if (!outputSlot) throw new Error(`Creating DraggingRenderLink for link [${link2.id}] failed: Output slot [${outputIndex}] not found.`);
    this.outputNodeId = outputNodeId;
    this.outputNode = outputNode;
    this.outputSlot = outputSlot;
    this.outputIndex = outputIndex;
    this.outputPos = outputNode.getOutputPos(outputIndex);
    const inputNode = network.getNodeById(inputNodeId) ?? void 0;
    if (!inputNode) throw new Error(`Creating DraggingRenderLink for link [${link2.id}] failed: Input node [${inputNodeId}] not found.`);
    const inputSlot = inputNode.inputs.at(inputIndex);
    if (!inputSlot) throw new Error(`Creating DraggingRenderLink for link [${link2.id}] failed: Input slot [${inputIndex}] not found.`);
    this.inputNodeId = inputNodeId;
    this.inputNode = inputNode;
    this.inputSlot = inputSlot;
    this.inputIndex = inputIndex;
    this.inputPos = inputNode.getInputPos(inputIndex);
    this.node = this.toType === "input" ? outputNode : inputNode;
    this.fromSlot = this.toType === "input" ? outputSlot : inputSlot;
    this.fromPos = fromReroute?.pos ?? (this.toType === "input" ? this.outputPos : this.inputPos);
    this.fromDirection = this.toType === "input" ? LinkDirection.NONE : LinkDirection.LEFT;
    this.fromSlotIndex = this.toType === "input" ? outputIndex : inputIndex;
  }
  node;
  fromSlot;
  fromPos;
  fromDirection;
  fromSlotIndex;
  outputNodeId;
  outputNode;
  outputSlot;
  outputIndex;
  outputPos;
  inputNodeId;
  inputNode;
  inputSlot;
  inputIndex;
  inputPos;
}
class ToInputRenderLink {
  static {
    __name(this, "ToInputRenderLink");
  }
  constructor(network, node22, fromSlot, fromReroute, dragDirection = LinkDirection.CENTER) {
    this.network = network;
    this.node = node22;
    this.fromSlot = fromSlot;
    this.fromReroute = fromReroute;
    this.dragDirection = dragDirection;
    const outputIndex = node22.outputs.indexOf(fromSlot);
    if (outputIndex === -1) throw new Error(`Creating render link for node [${this.node.id}] failed: Slot index not found.`);
    this.fromSlotIndex = outputIndex;
    this.fromPos = fromReroute ? fromReroute.pos : this.node.getOutputPos(outputIndex);
  }
  toType = "input";
  fromPos;
  fromSlotIndex;
  fromDirection = LinkDirection.RIGHT;
}
class ToOutputRenderLink {
  static {
    __name(this, "ToOutputRenderLink");
  }
  constructor(network, node22, fromSlot, fromReroute, dragDirection = LinkDirection.CENTER) {
    this.network = network;
    this.node = node22;
    this.fromSlot = fromSlot;
    this.fromReroute = fromReroute;
    this.dragDirection = dragDirection;
    const inputIndex = node22.inputs.indexOf(fromSlot);
    if (inputIndex === -1) throw new Error(`Creating render link for node [${this.node.id}] failed: Slot index not found.`);
    this.fromSlotIndex = inputIndex;
    this.fromPos = fromReroute ? fromReroute.pos : this.node.getInputPos(inputIndex);
  }
  toType = "output";
  fromPos;
  fromSlotIndex;
  fromDirection = LinkDirection.LEFT;
}
class LinkConnector {
  static {
    __name(this, "LinkConnector");
  }
  /**
   * Link connection state POJO. Source of truth for state of link drag operations.
   *
   * Can be replaced or proxied to allow notifications.
   * Is always dereferenced at the start of an operation.
   */
  state = {
    connectingTo: void 0,
    multi: false,
    draggingExistingLinks: false
  };
  events = new LinkConnectorEventTarget();
  /** Contains information for rendering purposes only. */
  renderLinks = [];
  /** Existing links that are being moved **to** a new input slot. */
  inputLinks = [];
  /** Existing links that are being moved **to** a new output slot. */
  outputLinks = [];
  hiddenReroutes = /* @__PURE__ */ new Set();
  /** The widget beneath the pointer, if it is a valid connection target. */
  overWidget;
  /** The type (returned by downstream callback) for {@link overWidget} */
  overWidgetType;
  #setConnectingLinks;
  constructor(setConnectingLinks) {
    this.#setConnectingLinks = setConnectingLinks;
  }
  get isConnecting() {
    return this.state.connectingTo !== void 0;
  }
  get draggingExistingLinks() {
    return this.state.draggingExistingLinks;
  }
  /** Drag an existing link to a different input. */
  moveInputLink(network, input) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const { state, inputLinks, renderLinks } = this;
    const linkId = input.link;
    if (linkId == null) return;
    const link2 = network.links.get(linkId);
    if (!link2) return;
    try {
      const reroute = link2.parentId != null ? network.reroutes.get(link2.parentId) : void 0;
      const renderLink = new MovingRenderLink(network, link2, "input", reroute);
      const mayContinue = this.events.dispatch("before-move-input", renderLink);
      if (mayContinue === false) return;
      renderLinks.push(renderLink);
      this.listenUntilReset("input-moved", (e2) => {
        e2.detail.link.disconnect(network, "output");
      });
    } catch (error2) {
      console.warn(`Could not create render link for link id: [${link2.id}].`, link2, error2);
      return;
    }
    link2._dragging = true;
    inputLinks.push(link2);
    state.connectingTo = "input";
    state.draggingExistingLinks = true;
    this.#setLegacyLinks(false);
  }
  /** Drag all links from an output to a new output. */
  moveOutputLink(network, output) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const { state, renderLinks } = this;
    if (!output.links?.length) return;
    for (const linkId of output.links) {
      const link2 = network.links.get(linkId);
      if (!link2) continue;
      const firstReroute = LLink.getFirstReroute(network, link2);
      if (firstReroute) {
        firstReroute._dragging = true;
        this.hiddenReroutes.add(firstReroute);
      } else {
        link2._dragging = true;
      }
      this.outputLinks.push(link2);
      try {
        const renderLink = new MovingRenderLink(network, link2, "output", firstReroute, LinkDirection.RIGHT);
        const mayContinue = this.events.dispatch("before-move-output", renderLink);
        if (mayContinue === false) continue;
        renderLinks.push(renderLink);
      } catch (error2) {
        console.warn(`Could not create render link for link id: [${link2.id}].`, link2, error2);
        continue;
      }
    }
    if (renderLinks.length === 0) return this.reset();
    state.draggingExistingLinks = true;
    state.multi = true;
    state.connectingTo = "output";
    this.#setLegacyLinks(true);
  }
  /**
   * Drags a new link from an output slot to an input slot.
   * @param network The network that the link being connected belongs to
   * @param node The node the link is being dragged from
   * @param output The output slot that the link is being dragged from
   */
  dragNewFromOutput(network, node22, output, fromReroute) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const { state } = this;
    const renderLink = new ToInputRenderLink(network, node22, output, fromReroute);
    this.renderLinks.push(renderLink);
    state.connectingTo = "input";
    this.#setLegacyLinks(false);
  }
  /**
   * Drags a new link from an input slot to an output slot.
   * @param network The network that the link being connected belongs to
   * @param node The node the link is being dragged from
   * @param input The input slot that the link is being dragged from
   */
  dragNewFromInput(network, node22, input, fromReroute) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const { state } = this;
    const renderLink = new ToOutputRenderLink(network, node22, input, fromReroute);
    this.renderLinks.push(renderLink);
    state.connectingTo = "output";
    this.#setLegacyLinks(true);
  }
  /**
   * Drags a new link from a reroute to an input slot.
   * @param network The network that the link being connected belongs to
   * @param reroute The reroute that the link is being dragged from
   */
  dragFromReroute(network, reroute) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const link2 = reroute.firstLink ?? reroute.firstFloatingLink;
    if (!link2) return;
    const outputNode = network.getNodeById(link2.origin_id);
    if (!outputNode) return;
    const outputSlot = outputNode.outputs.at(link2.origin_slot);
    if (!outputSlot) return;
    const renderLink = new ToInputRenderLink(network, outputNode, outputSlot, reroute);
    renderLink.fromDirection = LinkDirection.NONE;
    this.renderLinks.push(renderLink);
    this.state.connectingTo = "input";
    this.#setLegacyLinks(false);
  }
  dragFromLinkSegment(network, linkSegment) {
    if (this.isConnecting) throw new Error("Already dragging links.");
    const { state } = this;
    if (linkSegment.origin_id == null || linkSegment.origin_slot == null) return;
    const node22 = network.getNodeById(linkSegment.origin_id);
    if (!node22) return;
    const slot = getNodeOutputOnPos(node22, linkSegment._pos[0], linkSegment._pos[1])?.output;
    if (!slot) return;
    const reroute = linkSegment.parentId ? network.reroutes.get(linkSegment.parentId) : void 0;
    if (!reroute) return;
    const renderLink = new ToInputRenderLink(network, node22, slot, reroute);
    renderLink.fromDirection = LinkDirection.NONE;
    this.renderLinks.push(renderLink);
    state.connectingTo = "input";
  }
  /**
   * Connects the links being droppe
   * @param event Contains the drop location, in canvas space
   */
  dropLinks(locator, event) {
    if (!this.isConnecting) return this.reset();
    const { renderLinks } = this;
    const mayContinue = this.events.dispatch("before-drop-links", { renderLinks, event });
    if (mayContinue === false) return this.reset();
    const { canvasX, canvasY } = event;
    const node22 = locator.getNodeOnPos(canvasX, canvasY) ?? void 0;
    if (node22) {
      this.dropOnNode(node22, event);
    } else {
      const reroute = locator.getRerouteOnPos(canvasX, canvasY);
      if (reroute) {
        this.dropOnReroute(reroute, event);
      } else {
        this.dropOnNothing(event);
      }
    }
    this.events.dispatch("after-drop-links", { renderLinks, event });
    this.reset();
  }
  dropOnNode(node22, event) {
    const { renderLinks, state } = this;
    const { connectingTo } = state;
    const { canvasX, canvasY } = event;
    if (connectingTo === "output") {
      const output = node22.getOutputOnPos([canvasX, canvasY]);
      if (output) {
        this.#dropOnOutput(node22, output);
      } else {
        this.#dropOnNodeBackground(node22, event);
      }
    } else if (connectingTo === "input") {
      const input = node22.getInputOnPos([canvasX, canvasY]);
      if (input) {
        this.#dropOnInput(node22, input);
      } else if (this.overWidget && renderLinks[0] instanceof ToInputRenderLink) {
        this.events.dispatch("dropped-on-widget", {
          link: renderLinks[0],
          node: node22,
          widget: this.overWidget
        });
        this.overWidget = void 0;
      } else {
        this.#dropOnNodeBackground(node22, event);
      }
    }
  }
  dropOnReroute(reroute, event) {
    const mayContinue = this.events.dispatch("dropped-on-reroute", { reroute, event });
    if (mayContinue === false) return;
    if (this.state.connectingTo === "input") {
      const results = reroute.findTargetInputs();
      if (!results?.length) return;
      for (const { node: inputNode, input, link: resultLink } of results) {
        for (const renderLink of this.renderLinks) {
          if (renderLink.toType !== "input") continue;
          if (renderLink instanceof MovingRenderLink) {
            const { outputNode, inputSlot, outputSlot, fromReroute } = renderLink;
            if (inputSlot === input) continue;
            const newLink = outputNode.connectSlots(outputSlot, inputNode, input, fromReroute?.id);
            if (newLink) this.events.dispatch("input-moved", renderLink);
          } else {
            const { node: outputNode, fromSlot, fromReroute } = renderLink;
            if (fromReroute?.id === reroute.id) return;
            if (fromReroute?.id != null && fromReroute.id === reroute.parentId) return;
            const reroutes = reroute.getReroutes();
            if (reroutes === null) throw new Error("Reroute loop detected.");
            if (reroutes && fromReroute?.id != null) {
              for (const r2 of reroutes) {
                if (r2.id === fromReroute.id) break;
                if (r2.id === reroute.id) {
                  throw new Error("Cannot connect to reroute that is a parent of the reroute being connected to.");
                }
              }
            }
            if (reroutes) {
              for (const reroute2 of reroutes.slice(0, -1).reverse()) {
                if (reroute2.id === fromReroute?.id) break;
                reroute2.remove();
              }
            }
            reroute.parentId = fromReroute?.id;
            const newLink = outputNode.connectSlots(fromSlot, inputNode, input, resultLink.parentId);
            this.events.dispatch("link-created", newLink);
          }
        }
      }
      return;
    }
    for (const link2 of this.renderLinks) {
      if (link2.toType !== "output") continue;
      const result = reroute.findSourceOutput();
      if (!result) return;
      const { node: node22, output } = result;
      if (link2 instanceof MovingRenderLink) {
        const { inputNode, inputSlot, outputSlot, fromReroute } = link2;
        if (outputSlot === output) continue;
        if (fromReroute) {
          fromReroute.parentId = reroute.id;
        } else {
          link2.link.parentId = reroute.id;
        }
        node22.connectSlots(output, inputNode, inputSlot, link2.link.parentId);
        this.events.dispatch("output-moved", link2);
      } else {
        const { node: inputNode, fromSlot } = link2;
        const newLink = node22.connectSlots(output, inputNode, fromSlot, reroute?.id);
        this.events.dispatch("link-created", newLink);
      }
    }
  }
  dropOnNothing(event) {
    if (this.state.connectingTo === "input") {
      for (const link2 of this.renderLinks) {
        if (link2 instanceof MovingRenderLink) {
          link2.inputNode.disconnectInput(link2.inputIndex, true);
        }
      }
    }
    this.events.dispatch("dropped-on-canvas", event);
  }
  /**
   * Connects the links being dropped onto a node.
   * @param node The node that the links are being dropped on
   * @param event Contains the drop location, in canvas space
   */
  #dropOnNodeBackground(node22, event) {
    const { state: { connectingTo } } = this;
    const mayContinue = this.events.dispatch("dropped-on-node", { node: node22, event });
    if (mayContinue === false) return;
    const firstLink = this.renderLinks[0];
    if (!firstLink || firstLink.node === node22) return;
    if (connectingTo === "output" && this.draggingExistingLinks) {
      const output = node22.findOutputByType(firstLink.fromSlot.type)?.slot;
      if (!output) {
        console.warn(`Could not find slot for link type: [${firstLink.fromSlot.type}].`);
        return;
      }
      this.#dropOnOutput(node22, output);
      return;
    }
    if (connectingTo === "input" && this.draggingExistingLinks) {
      const input = node22.findInputByType(firstLink.fromSlot.type)?.slot;
      if (!input) {
        console.warn(`Could not find slot for link type: [${firstLink.fromSlot.type}].`);
        return;
      }
      this.#dropOnInput(node22, input);
      return;
    }
    if (connectingTo === "output") {
      const output = node22.findOutputByType(firstLink.fromSlot.type)?.slot;
      if (!output) {
        console.warn(`Could not find slot for link type: [${firstLink.fromSlot.type}].`);
        return;
      }
      for (const link2 of this.renderLinks) {
        if ("link" in link2.fromSlot) {
          node22.connectSlots(output, link2.node, link2.fromSlot, link2.fromReroute?.id);
        }
      }
    } else if (connectingTo === "input") {
      const input = node22.findInputByType(firstLink.fromSlot.type)?.slot;
      if (!input) {
        console.warn(`Could not find slot for link type: [${firstLink.fromSlot.type}].`);
        return;
      }
      for (const link2 of this.renderLinks) {
        if ("links" in link2.fromSlot) {
          link2.node.connectSlots(link2.fromSlot, node22, input, link2.fromReroute?.id);
        }
      }
    }
  }
  #dropOnInput(node22, input) {
    for (const link2 of this.renderLinks) {
      if (link2.toType !== "input") continue;
      if (link2 instanceof MovingRenderLink) {
        const { outputNode, inputSlot, outputSlot, fromReroute } = link2;
        if (inputSlot === input) continue;
        const newLink = outputNode.connectSlots(outputSlot, node22, input, fromReroute?.id);
        if (newLink) this.events.dispatch("input-moved", link2);
      } else {
        const { node: outputNode, fromSlot, fromReroute } = link2;
        const newLink = outputNode.connectSlots(fromSlot, node22, input, fromReroute?.id);
        this.events.dispatch("link-created", newLink);
      }
    }
  }
  #dropOnOutput(node22, output) {
    for (const link2 of this.renderLinks) {
      if (link2.toType !== "output") continue;
      if (link2 instanceof MovingRenderLink) {
        const { inputNode, inputSlot, outputSlot } = link2;
        if (outputSlot === output) continue;
        node22.connectSlots(output, inputNode, inputSlot, link2.link.parentId);
        this.events.dispatch("output-moved", link2);
      } else {
        const { node: inputNode, fromSlot, fromReroute } = link2;
        const newLink = node22.connectSlots(output, inputNode, fromSlot, fromReroute?.id);
        this.events.dispatch("link-created", newLink);
      }
    }
  }
  /** Sets connecting_links, used by some extensions still. */
  #setLegacyLinks(fromSlotIsInput) {
    const links = this.renderLinks.map((link2) => {
      const input = fromSlotIsInput ? link2.fromSlot : null;
      const output = fromSlotIsInput ? null : link2.fromSlot;
      const afterRerouteId = link2 instanceof MovingRenderLink ? link2.link?.parentId : link2.fromReroute?.id;
      return {
        node: link2.node,
        slot: link2.fromSlotIndex,
        input,
        output,
        pos: link2.fromPos,
        afterRerouteId
      };
    });
    this.#setConnectingLinks(links);
  }
  /**
   * Exports the current state of the link connector.
   * @param network The network that the links being connected belong to.
   * @returns A POJO with the state of the link connector, links being connected, and their network.
   * @remarks Other than {@link network}, all properties are shallow cloned.
   */
  export(network) {
    return {
      renderLinks: [...this.renderLinks],
      inputLinks: [...this.inputLinks],
      outputLinks: [...this.outputLinks],
      state: { ...this.state },
      network
    };
  }
  /**
   * Adds an event listener that will be automatically removed when the reset event is fired.
   * @param eventName The event to listen for.
   * @param listener The listener to call when the event is fired.
   */
  listenUntilReset(eventName, listener, options22) {
    this.events.addEventListener(eventName, listener, options22);
    this.events.addEventListener("reset", () => this.events.removeEventListener(eventName, listener), { once: true });
  }
  /**
   * Resets everything to its initial state.
   *
   * Effectively cancels moving or connecting links.
   */
  reset(force = false) {
    this.events.dispatch("reset", force);
    const { state, outputLinks, inputLinks, hiddenReroutes, renderLinks } = this;
    if (!force && state.connectingTo === void 0) return;
    state.connectingTo = void 0;
    for (const link2 of outputLinks) delete link2._dragging;
    for (const link2 of inputLinks) delete link2._dragging;
    for (const reroute of hiddenReroutes) delete reroute._dragging;
    renderLinks.length = 0;
    inputLinks.length = 0;
    outputLinks.length = 0;
    hiddenReroutes.clear();
    state.multi = false;
    state.draggingExistingLinks = false;
  }
}
class CanvasPointer {
  static {
    __name(this, "CanvasPointer");
  }
  /** Maximum time in milliseconds to ignore click drift */
  static bufferTime = 150;
  /** Maximum gap between pointerup and pointerdown events to be considered as a double click */
  static doubleClickTime = 300;
  /** Maximum offset from click location */
  static get maxClickDrift() {
    return this.#maxClickDrift;
  }
  static set maxClickDrift(value3) {
    this.#maxClickDrift = value3;
    this.#maxClickDrift2 = value3 * value3;
  }
  static #maxClickDrift = 6;
  /** {@link maxClickDrift} squared.  Used to calculate click drift without `sqrt`. */
  static #maxClickDrift2 = this.#maxClickDrift ** 2;
  /** The element this PointerState should capture input against when dragging. */
  element;
  /** Pointer ID used by drag capture. */
  pointerId;
  /** Set to true when if the pointer moves far enough after a down event, before the corresponding up event is fired. */
  dragStarted = false;
  /** The {@link eUp} from the last successful click */
  eLastDown;
  /** Used downstream for touch event support. */
  isDouble = false;
  /** Used downstream for touch event support. */
  isDown = false;
  /**
   * If `true`, {@link eDown}, {@link eMove}, and {@link eUp} will be set to
   * `undefined` when {@link reset} is called.
   *
   * Default: `true`
   */
  clearEventsOnReset = true;
  /** The last pointerdown event for the primary button */
  eDown;
  /** The last pointermove event for the primary button */
  eMove;
  /** The last pointerup event for the primary button */
  eUp;
  /**
   * Run-once callback, called at the end of any click or drag, whether or not it was successful in any way.
   *
   * The setter of this callback will call the existing value before replacing it.
   * Therefore, simply setting this value twice will execute the first callback.
   */
  get finally() {
    return this.#finally;
  }
  set finally(value3) {
    try {
      this.#finally?.();
    } finally {
      this.#finally = value3;
    }
  }
  #finally;
  constructor(element) {
    this.element = element;
  }
  /**
   * Callback for `pointerdown` events.  To be used as the event handler (or called by it).
   * @param e The `pointerdown` event
   */
  down(e2) {
    this.reset();
    this.eDown = e2;
    this.pointerId = e2.pointerId;
    this.element.setPointerCapture(e2.pointerId);
  }
  /**
   * Callback for `pointermove` events.  To be used as the event handler (or called by it).
   * @param e The `pointermove` event
   */
  move(e2) {
    const { eDown } = this;
    if (!eDown) return;
    if (!e2.buttons) {
      this.reset();
      return;
    }
    if (!(e2.buttons & eDown.buttons)) {
      this.#completeClick(e2);
      this.reset();
      return;
    }
    this.eMove = e2;
    this.onDrag?.(e2);
    if (this.dragStarted) return;
    const longerThanBufferTime = e2.timeStamp - eDown.timeStamp > CanvasPointer.bufferTime;
    if (longerThanBufferTime || !this.#hasSamePosition(e2, eDown)) {
      this.#setDragStarted();
    }
  }
  /**
   * Callback for `pointerup` events.  To be used as the event handler (or called by it).
   * @param e The `pointerup` event
   */
  up(e2) {
    if (e2.button !== this.eDown?.button) return false;
    this.#completeClick(e2);
    const { dragStarted } = this;
    this.reset();
    return !dragStarted;
  }
  #completeClick(e2) {
    const { eDown } = this;
    if (!eDown) return;
    this.eUp = e2;
    if (this.dragStarted) {
      this.onDragEnd?.(e2);
    } else if (!this.#hasSamePosition(e2, eDown)) {
      this.#setDragStarted();
      this.onDragEnd?.(e2);
    } else if (this.onDoubleClick && this.#isDoubleClick()) {
      this.onDoubleClick(e2);
      this.eLastDown = void 0;
    } else {
      this.onClick?.(e2);
      this.eLastDown = eDown;
    }
  }
  /**
   * Checks if two events occurred near each other - not further apart than the maximum click drift.
   * @param a The first event to compare
   * @param b The second event to compare
   * @param tolerance2 The maximum distance (squared) before the positions are considered different
   * @returns `true` if the two events were no more than {@link maxClickDrift} apart, otherwise `false`
   */
  #hasSamePosition(a2, b2, tolerance2 = CanvasPointer.#maxClickDrift2) {
    const drift = dist2(a2.clientX, a2.clientY, b2.clientX, b2.clientY);
    return drift <= tolerance2;
  }
  /**
   * Checks whether the pointer is currently past the max click drift threshold.
   * @returns `true` if the latest pointer event is past the the click drift threshold
   */
  #isDoubleClick() {
    const { eDown, eLastDown } = this;
    if (!eDown || !eLastDown) return false;
    const tolerance2 = (3 * CanvasPointer.#maxClickDrift) ** 2;
    const diff2 = eDown.timeStamp - eLastDown.timeStamp;
    return diff2 > 0 && diff2 < CanvasPointer.doubleClickTime && this.#hasSamePosition(eDown, eLastDown, tolerance2);
  }
  #setDragStarted() {
    this.dragStarted = true;
    this.onDragStart?.(this);
    delete this.onDragStart;
  }
  /**
   * Resets the state of this {@link CanvasPointer} instance.
   *
   * The {@link finally} callback is first executed, then all callbacks and intra-click
   * state is cleared.
   */
  reset() {
    this.finally = void 0;
    delete this.onClick;
    delete this.onDoubleClick;
    delete this.onDragStart;
    delete this.onDrag;
    delete this.onDragEnd;
    this.isDown = false;
    this.isDouble = false;
    this.dragStarted = false;
    if (this.clearEventsOnReset) {
      this.eDown = void 0;
      this.eMove = void 0;
      this.eUp = void 0;
    }
    const { element, pointerId } = this;
    this.pointerId = void 0;
    if (typeof pointerId === "number" && element.hasPointerCapture(pointerId)) {
      element.releasePointerCapture(pointerId);
    }
  }
}
class NullGraphError extends Error {
  static {
    __name(this, "NullGraphError");
  }
  constructor(message3 = "Attempted to access LGraph reference that was null or undefined.", cause) {
    super(message3, { cause });
    this.name = "NullGraphError";
  }
}
var BadgePosition = /* @__PURE__ */ ((BadgePosition2) => {
  BadgePosition2["TopLeft"] = "top-left";
  BadgePosition2["TopRight"] = "top-right";
  return BadgePosition2;
})(BadgePosition || {});
class LGraphBadge {
  static {
    __name(this, "LGraphBadge");
  }
  text;
  fgColor;
  bgColor;
  fontSize;
  padding;
  height;
  cornerRadius;
  constructor({
    text: text2,
    fgColor = "white",
    bgColor = "#0F1F0F",
    fontSize = 12,
    padding = 6,
    height = 20,
    cornerRadius = 5
  }) {
    this.text = text2;
    this.fgColor = fgColor;
    this.bgColor = bgColor;
    this.fontSize = fontSize;
    this.padding = padding;
    this.height = height;
    this.cornerRadius = cornerRadius;
  }
  get visible() {
    return this.text.length > 0;
  }
  getWidth(ctx) {
    if (!this.visible) return 0;
    const { font } = ctx;
    ctx.font = `${this.fontSize}px sans-serif`;
    const textWidth = ctx.measureText(this.text).width;
    ctx.font = font;
    return textWidth + this.padding * 2;
  }
  draw(ctx, x2, y2) {
    if (!this.visible) return;
    const { fillStyle } = ctx;
    ctx.font = `${this.fontSize}px sans-serif`;
    const badgeWidth = this.getWidth(ctx);
    const badgeX = 0;
    ctx.fillStyle = this.bgColor;
    ctx.beginPath();
    if (ctx.roundRect) {
      ctx.roundRect(x2 + badgeX, y2, badgeWidth, this.height, this.cornerRadius);
    } else {
      ctx.rect(x2 + badgeX, y2, badgeWidth, this.height);
    }
    ctx.fill();
    ctx.fillStyle = this.fgColor;
    ctx.fillText(
      this.text,
      x2 + badgeX + this.padding,
      y2 + this.height - this.padding
    );
    ctx.fillStyle = fillStyle;
  }
}
function pick(obj, keys2) {
  const picked = {};
  for (const key of keys2) {
    if (key in obj) {
      picked[key] = obj[key];
    }
  }
  return picked;
}
__name(pick, "pick");
function shallowCloneCommonProps(slot) {
  return pick(slot, [
    "color_off",
    "color_on",
    "dir",
    "label",
    "localized_name",
    "locked",
    "name",
    "nameLocked",
    "removable",
    "shape",
    "type"
  ]);
}
__name(shallowCloneCommonProps, "shallowCloneCommonProps");
function inputAsSerialisable(slot) {
  const { link: link2 } = slot;
  const widgetOrPos = slot.widget ? { widget: { name: slot.widget.name } } : { pos: slot.pos };
  return {
    ...shallowCloneCommonProps(slot),
    ...widgetOrPos,
    link: link2
  };
}
__name(inputAsSerialisable, "inputAsSerialisable");
function outputAsSerialisable(slot) {
  const { pos, slot_index, links, widget } = slot;
  const outputWidget = widget ? { widget: { name: widget.name } } : null;
  return {
    ...shallowCloneCommonProps(slot),
    ...outputWidget,
    pos,
    slot_index,
    links
  };
}
__name(outputAsSerialisable, "outputAsSerialisable");
function toNodeSlotClass(slot) {
  if (isINodeInputSlot(slot)) {
    return new NodeInputSlot(slot);
  } else if (isINodeOutputSlot(slot)) {
    return new NodeOutputSlot(slot);
  }
  throw new Error("Invalid slot type");
}
__name(toNodeSlotClass, "toNodeSlotClass");
function isWidgetInputSlot(slot) {
  return isINodeInputSlot(slot) && !!slot.widget;
}
__name(isWidgetInputSlot, "isWidgetInputSlot");
class NodeSlot {
  static {
    __name(this, "NodeSlot");
  }
  name;
  localized_name;
  label;
  type;
  dir;
  removable;
  shape;
  color_off;
  color_on;
  locked;
  nameLocked;
  pos;
  widget;
  constructor(slot) {
    Object.assign(this, slot);
    this.name = slot.name;
    this.type = slot.type;
  }
  /**
   * The label to display in the UI.
   */
  get renderingLabel() {
    return this.label || this.localized_name || this.name || "";
  }
  connectedColor(context) {
    return this.color_on || context.default_connection_color_byType[this.type] || context.default_connection_color.output_on;
  }
  disconnectedColor(context) {
    return this.color_off || context.default_connection_color_byTypeOff[this.type] || context.default_connection_color_byType[this.type] || context.default_connection_color.output_off;
  }
  renderingColor(context) {
    return this.isConnected() ? this.connectedColor(context) : this.disconnectedColor(context);
  }
  draw(ctx, options22) {
    const {
      pos,
      colorContext,
      labelColor = "#AAA",
      labelPosition = LabelPosition.Right,
      lowQuality = false,
      renderText = true,
      highlight = false
    } = options22;
    let { doStroke = false } = options22;
    const originalFillStyle = ctx.fillStyle;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalLineWidth = ctx.lineWidth;
    const slot_type = this.type;
    const slot_shape = slot_type === SlotType.Array ? SlotShape.Grid : this.shape;
    ctx.beginPath();
    let doFill = true;
    ctx.fillStyle = this.renderingColor(colorContext);
    ctx.lineWidth = 1;
    if (slot_type === SlotType.Event || slot_shape === SlotShape.Box) {
      ctx.rect(pos[0] - 6 + 0.5, pos[1] - 5 + 0.5, 14, 10);
    } else if (slot_shape === SlotShape.Arrow) {
      ctx.moveTo(pos[0] + 8, pos[1] + 0.5);
      ctx.lineTo(pos[0] - 4, pos[1] + 6 + 0.5);
      ctx.lineTo(pos[0] - 4, pos[1] - 6 + 0.5);
      ctx.closePath();
    } else if (slot_shape === SlotShape.Grid) {
      const gridSize = 3;
      const cellSize = 2;
      const spacing = 3;
      for (let x2 = 0; x2 < gridSize; x2++) {
        for (let y2 = 0; y2 < gridSize; y2++) {
          ctx.rect(
            pos[0] - 4 + x2 * spacing,
            pos[1] - 4 + y2 * spacing,
            cellSize,
            cellSize
          );
        }
      }
      doStroke = false;
    } else {
      if (lowQuality) {
        ctx.rect(pos[0] - 4, pos[1] - 4, 8, 8);
      } else {
        let radius;
        if (slot_shape === SlotShape.HollowCircle) {
          doFill = false;
          doStroke = true;
          ctx.lineWidth = 3;
          ctx.strokeStyle = ctx.fillStyle;
          radius = highlight ? 4 : 3;
        } else {
          radius = highlight ? 5 : 4;
        }
        ctx.arc(pos[0], pos[1], radius, 0, Math.PI * 2);
      }
    }
    if (doFill) ctx.fill();
    if (!lowQuality && doStroke) ctx.stroke();
    if (renderText) {
      const text2 = this.renderingLabel;
      if (text2) {
        ctx.fillStyle = labelColor;
        if (labelPosition === LabelPosition.Right) {
          if (this.dir == LinkDirection.UP) {
            ctx.fillText(text2, pos[0], pos[1] - 10);
          } else {
            ctx.fillText(text2, pos[0] + 10, pos[1] + 5);
          }
        } else {
          if (this.dir == LinkDirection.DOWN) {
            ctx.fillText(text2, pos[0], pos[1] - 8);
          } else {
            ctx.fillText(text2, pos[0] - 10, pos[1] + 5);
          }
        }
      }
    }
    ctx.fillStyle = originalFillStyle;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.lineWidth = originalLineWidth;
  }
  drawCollapsed(ctx, options22) {
    const [x2, y2] = options22.pos;
    const originalFillStyle = ctx.fillStyle;
    ctx.fillStyle = "#686";
    ctx.beginPath();
    if (this.type === SlotType.Event || this.shape === RenderShape.BOX) {
      ctx.rect(x2 - 7 + 0.5, y2 - 4, 14, 8);
    } else if (this.shape === RenderShape.ARROW) {
      const isInput = this instanceof NodeInputSlot;
      if (isInput) {
        ctx.moveTo(x2 + 8, y2);
        ctx.lineTo(x2 - 4, y2 - 4);
        ctx.lineTo(x2 - 4, y2 + 4);
      } else {
        ctx.moveTo(x2 + 6, y2);
        ctx.lineTo(x2 - 6, y2 - 4);
        ctx.lineTo(x2 - 6, y2 + 4);
      }
      ctx.closePath();
    } else {
      ctx.arc(x2, y2, 4, 0, Math.PI * 2);
    }
    ctx.fill();
    ctx.fillStyle = originalFillStyle;
  }
}
function isINodeInputSlot(slot) {
  return "link" in slot;
}
__name(isINodeInputSlot, "isINodeInputSlot");
class NodeInputSlot extends NodeSlot {
  static {
    __name(this, "NodeInputSlot");
  }
  link;
  constructor(slot) {
    super(slot);
    this.link = slot.link;
  }
  isConnected() {
    return this.link != null;
  }
  isValidTarget(fromSlot) {
    return "links" in fromSlot && LiteGraph.isValidConnection(this.type, fromSlot.type);
  }
  draw(ctx, options22) {
    const originalTextAlign = ctx.textAlign;
    ctx.textAlign = "left";
    super.draw(ctx, {
      ...options22,
      labelPosition: LabelPosition.Right,
      doStroke: false
    });
    ctx.textAlign = originalTextAlign;
  }
}
function isINodeOutputSlot(slot) {
  return "links" in slot;
}
__name(isINodeOutputSlot, "isINodeOutputSlot");
class NodeOutputSlot extends NodeSlot {
  static {
    __name(this, "NodeOutputSlot");
  }
  links;
  _data;
  slot_index;
  constructor(slot) {
    super(slot);
    this.links = slot.links;
    this._data = slot._data;
    this.slot_index = slot.slot_index;
  }
  isValidTarget(fromSlot) {
    return "link" in fromSlot && LiteGraph.isValidConnection(this.type, fromSlot.type);
  }
  isConnected() {
    return this.links != null && this.links.length > 0;
  }
  draw(ctx, options22) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    ctx.textAlign = "right";
    ctx.strokeStyle = "black";
    super.draw(ctx, {
      ...options22,
      labelPosition: LabelPosition.Left,
      doStroke: true
    });
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
  }
}
function stringOrEmpty(value3) {
  return value3 == null ? "" : String(value3);
}
__name(stringOrEmpty, "stringOrEmpty");
function parseSlotTypes(type) {
  return type == "" || type == "0" ? ["*"] : String(type).toLowerCase().split(",");
}
__name(parseSlotTypes, "parseSlotTypes");
function getAllNestedItems(items2) {
  const allItems = /* @__PURE__ */ new Set();
  if (items2) {
    for (const item3 of items2) addRecursively(item3, allItems);
  }
  return allItems;
  function addRecursively(item3, flatSet) {
    if (flatSet.has(item3) || item3.pinned) return;
    flatSet.add(item3);
    if (item3.children) {
      for (const child of item3.children) addRecursively(child, flatSet);
    }
  }
  __name(addRecursively, "addRecursively");
}
__name(getAllNestedItems, "getAllNestedItems");
function findFirstNode(items2) {
  for (const item3 of items2) {
    if (item3 instanceof LGraphNode) return item3;
  }
}
__name(findFirstNode, "findFirstNode");
function findFreeSlotOfType(slots, type) {
  if (!slots?.length) return;
  let occupiedSlot;
  let wildSlot;
  let occupiedWildSlot;
  const validTypes = parseSlotTypes(type);
  for (const [index2, slot] of slots.entries()) {
    const slotTypes = parseSlotTypes(slot.type);
    for (const validType of validTypes) {
      for (const slotType of slotTypes) {
        if (slotType === validType) {
          if (slot.link == null && !slot.links?.length) {
            return { index: index2, slot };
          }
          occupiedSlot ??= { index: index2, slot };
        } else if (!wildSlot && (validType === "*" || slotType === "*")) {
          if (slot.link == null && !slot.links?.length) {
            wildSlot = { index: index2, slot };
          } else {
            occupiedWildSlot ??= { index: index2, slot };
          }
        }
      }
    }
  }
  return wildSlot ?? occupiedSlot ?? occupiedWildSlot;
}
__name(findFreeSlotOfType, "findFreeSlotOfType");
class LayoutElement {
  static {
    __name(this, "LayoutElement");
  }
  value;
  boundingRect;
  constructor(o2) {
    this.value = o2.value;
    this.boundingRect = o2.boundingRect;
  }
  get center() {
    return [
      this.boundingRect[0] + this.boundingRect[2] / 2,
      this.boundingRect[1] + this.boundingRect[3] / 2
    ];
  }
}
function distributeSpace(totalSpace, requests) {
  if (requests.length === 0) return [];
  const totalMinSize = requests.reduce((sum, req) => sum + req.minSize, 0);
  if (totalSpace < totalMinSize) {
    return requests.map((req) => req.minSize);
  }
  let allocations = requests.map((req) => ({
    computedSize: req.minSize,
    maxSize: req.maxSize ?? Infinity,
    remaining: (req.maxSize ?? Infinity) - req.minSize
  }));
  let remainingSpace = totalSpace - totalMinSize;
  while (remainingSpace > 0 && allocations.some((alloc) => alloc.remaining > 0)) {
    const growableItems = allocations.filter(
      (alloc) => alloc.remaining > 0
    ).length;
    if (growableItems === 0) break;
    const sharePerItem = remainingSpace / growableItems;
    let spaceUsedThisRound = 0;
    allocations = allocations.map((alloc) => {
      if (alloc.remaining <= 0) return alloc;
      const growth = Math.min(sharePerItem, alloc.remaining);
      spaceUsedThisRound += growth;
      return {
        ...alloc,
        computedSize: alloc.computedSize + growth,
        remaining: alloc.remaining - growth
      };
    });
    remainingSpace -= spaceUsedThisRound;
    if (spaceUsedThisRound === 0) break;
  }
  return allocations.map(({ computedSize }) => computedSize);
}
__name(distributeSpace, "distributeSpace");
function toClass(cls, obj) {
  return obj instanceof cls ? obj : new cls(obj);
}
__name(toClass, "toClass");
function isColorable(obj) {
  return typeof obj === "object" && obj !== null && "setColorOption" in obj && "getColorOption" in obj;
}
__name(isColorable, "isColorable");
class BaseWidget {
  static {
    __name(this, "BaseWidget");
  }
  linkedWidgets;
  name;
  options;
  label;
  type;
  value;
  y = 0;
  last_y;
  width;
  disabled;
  hidden;
  advanced;
  tooltip;
  element;
  constructor(widget) {
    Object.assign(this, widget);
    this.name = widget.name;
    this.options = widget.options;
    this.type = widget.type;
  }
  get outline_color() {
    return this.advanced ? LiteGraph.WIDGET_ADVANCED_OUTLINE_COLOR : LiteGraph.WIDGET_OUTLINE_COLOR;
  }
  get background_color() {
    return LiteGraph.WIDGET_BGCOLOR;
  }
  get height() {
    return LiteGraph.NODE_WIDGET_HEIGHT;
  }
  get text_color() {
    return LiteGraph.WIDGET_TEXT_COLOR;
  }
  get secondary_text_color() {
    return LiteGraph.WIDGET_SECONDARY_TEXT_COLOR;
  }
  /**
   * Sets the value of the widget
   * @param value The value to set
   * @param options The options for setting the value
   */
  setValue(value3, options22) {
    const { node: node22, canvas: canvas2, e: e2 } = options22;
    const oldValue = this.value;
    const v2 = this.type === "number" ? Number(value3) : value3;
    this.value = v2;
    if (this.options?.property && node22.properties[this.options.property] !== void 0) {
      node22.setProperty(this.options.property, v2);
    }
    const pos = canvas2.graph_mouse;
    this.callback?.(this.value, canvas2, node22, pos, e2);
    node22.onWidgetChanged?.(this.name ?? "", v2, oldValue, this);
    if (node22.graph) node22.graph._version++;
  }
}
class BooleanWidget extends BaseWidget {
  static {
    __name(this, "BooleanWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = "toggle";
    this.value = widget.value;
  }
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const { height } = this;
    ctx.textAlign = "left";
    ctx.strokeStyle = this.outline_color;
    ctx.fillStyle = this.background_color;
    ctx.beginPath();
    if (show_text)
      ctx.roundRect(margin, y2, width2 - margin * 2, height, [height * 0.5]);
    else ctx.rect(margin, y2, width2 - margin * 2, height);
    ctx.fill();
    if (show_text && !this.disabled) ctx.stroke();
    ctx.fillStyle = this.value ? "#89A" : "#333";
    ctx.beginPath();
    ctx.arc(
      width2 - margin * 2,
      y2 + height * 0.5,
      height * 0.36,
      0,
      Math.PI * 2
    );
    ctx.fill();
    if (show_text) {
      ctx.fillStyle = this.secondary_text_color;
      const label8 = this.label || this.name;
      if (label8 != null) {
        ctx.fillText(label8, margin * 2, y2 + height * 0.7);
      }
      ctx.fillStyle = this.value ? this.text_color : this.secondary_text_color;
      ctx.textAlign = "right";
      ctx.fillText(
        this.value ? this.options.on || "true" : this.options.off || "false",
        width2 - 40,
        y2 + height * 0.7
      );
    }
  }
  onClick(options22) {
    this.setValue(!this.value, options22);
  }
}
class ButtonWidget extends BaseWidget {
  static {
    __name(this, "ButtonWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = "button";
    this.clicked = widget.clicked ?? false;
  }
  /**
   * Draws the widget
   * @param ctx The canvas context
   * @param options The options for drawing the widget
   */
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { height } = this;
    ctx.fillStyle = this.background_color;
    if (this.clicked) {
      ctx.fillStyle = "#AAA";
      this.clicked = false;
    }
    ctx.fillRect(margin, y2, width2 - margin * 2, height);
    if (show_text && !this.disabled) {
      ctx.strokeStyle = this.outline_color;
      ctx.strokeRect(margin, y2, width2 - margin * 2, height);
    }
    if (show_text) {
      ctx.textAlign = "center";
      ctx.fillStyle = this.text_color;
      ctx.fillText(
        this.label || this.name || "",
        width2 * 0.5,
        y2 + height * 0.7
      );
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  onClick(options22) {
    const { e: e2, node: node22, canvas: canvas2 } = options22;
    const pos = canvas2.graph_mouse;
    this.clicked = true;
    canvas2.setDirty(true);
    this.callback?.(this, canvas2, node22, pos, e2);
  }
}
class ComboWidget extends BaseWidget {
  static {
    __name(this, "ComboWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = "combo";
    this.value = widget.value;
  }
  /**
   * Draws the widget
   * @param ctx The canvas context
   * @param options The options for drawing the widget
   */
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { height } = this;
    ctx.textAlign = "left";
    ctx.strokeStyle = this.outline_color;
    ctx.fillStyle = this.background_color;
    ctx.beginPath();
    if (show_text)
      ctx.roundRect(margin, y2, width2 - margin * 2, height, [height * 0.5]);
    else
      ctx.rect(margin, y2, width2 - margin * 2, height);
    ctx.fill();
    if (show_text) {
      if (!this.disabled) {
        ctx.stroke();
        ctx.fillStyle = this.text_color;
        ctx.beginPath();
        ctx.moveTo(margin + 16, y2 + 5);
        ctx.lineTo(margin + 6, y2 + height * 0.5);
        ctx.lineTo(margin + 16, y2 + height - 5);
        ctx.fill();
        ctx.beginPath();
        ctx.moveTo(width2 - margin - 16, y2 + 5);
        ctx.lineTo(width2 - margin - 6, y2 + height * 0.5);
        ctx.lineTo(width2 - margin - 16, y2 + height - 5);
        ctx.fill();
      }
      ctx.fillStyle = this.secondary_text_color;
      const label8 = this.label || this.name;
      if (label8 != null) {
        ctx.fillText(label8, margin * 2 + 5, y2 + height * 0.7);
      }
      ctx.fillStyle = this.text_color;
      ctx.textAlign = "right";
      let displayValue = typeof this.value === "number" ? String(this.value) : this.value;
      if (this.options.values) {
        let values = this.options.values;
        if (typeof values === "function") {
          values = values();
        }
        if (values && !Array.isArray(values)) {
          displayValue = values[this.value];
        }
      }
      const labelWidth = ctx.measureText(label8 || "").width + margin * 2;
      const inputWidth = width2 - margin * 4;
      const availableWidth = inputWidth - labelWidth;
      const textWidth = ctx.measureText(displayValue).width;
      if (textWidth > availableWidth) {
        const ELLIPSIS = "…";
        const ellipsisWidth = ctx.measureText(ELLIPSIS).width;
        const charWidthAvg = ctx.measureText("a").width;
        if (availableWidth <= ellipsisWidth) {
          displayValue = "․";
        } else {
          displayValue = `${displayValue}`;
          const overflowWidth = textWidth + ellipsisWidth - availableWidth;
          if (overflowWidth + charWidthAvg * 3 > availableWidth) {
            const preciseRange = availableWidth + charWidthAvg * 3;
            const preTruncateCt = Math.floor((preciseRange - ellipsisWidth) / charWidthAvg);
            displayValue = displayValue.substr(0, preTruncateCt);
          }
          while (ctx.measureText(displayValue).width + ellipsisWidth > availableWidth) {
            displayValue = displayValue.substr(0, displayValue.length - 1);
          }
          displayValue += ELLIPSIS;
        }
      }
      ctx.fillText(
        displayValue,
        width2 - margin * 2 - 20,
        y2 + height * 0.7
      );
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  onClick(options22) {
    const { e: e2, node: node22, canvas: canvas2 } = options22;
    const x2 = e2.canvasX - node22.pos[0];
    const width2 = this.width || node22.size[0];
    const delta2 = x2 < 40 ? -1 : x2 > width2 - 40 ? 1 : 0;
    let values = this.options.values;
    if (typeof values === "function") {
      values = values(this, node22);
    }
    const values_list = Array.isArray(values) ? values : Object.keys(values);
    if (delta2) {
      let index2 = -1;
      canvas2.last_mouseclick = 0;
      index2 = typeof values === "object" ? values_list.indexOf(String(this.value)) + delta2 : values_list.indexOf(this.value) + delta2;
      if (index2 >= values_list.length) index2 = values_list.length - 1;
      if (index2 < 0) index2 = 0;
      this.setValue(
        Array.isArray(values) ? values[index2] : index2,
        {
          e: e2,
          node: node22,
          canvas: canvas2
        }
      );
      return;
    }
    const text_values = values != values_list ? Object.values(values) : values;
    new LiteGraph.ContextMenu(text_values, {
      scale: Math.max(1, canvas2.ds.scale),
      event: e2,
      className: "dark",
      callback: /* @__PURE__ */ __name((value3) => {
        this.setValue(
          values != values_list ? text_values.indexOf(value3) : value3,
          {
            e: e2,
            node: node22,
            canvas: canvas2
          }
        );
      }, "callback")
    });
  }
}
function getWidgetStep(options22) {
  return options22.step2 || (options22.step || 10) * 0.1;
}
__name(getWidgetStep, "getWidgetStep");
class KnobWidget extends BaseWidget {
  static {
    __name(this, "KnobWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = "knob";
    this.value = widget.value;
    this.options = widget.options;
  }
  computedHeight;
  /**
   * Compute the layout size of the widget.
   * @returns The layout size of the widget.
   */
  computeLayoutSize() {
    return {
      minHeight: 60,
      minWidth: 20,
      maxHeight: 1e6,
      maxWidth: 1e6
    };
  }
  get height() {
    return this.computedHeight || super.height;
  }
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { gradient_stops = "rgb(14, 182, 201); rgb(0, 216, 72)" } = this.options;
    const effective_height = this.computedHeight || this.height;
    const size_modifier = Math.min(this.computedHeight || this.height, this.width || 20) / 20;
    const arc_center = { x: width2 / 2, y: effective_height / 2 + y2 };
    ctx.lineWidth = (Math.min(width2, effective_height) - margin * size_modifier) / 6;
    const arc_size = (Math.min(width2, effective_height) - margin * size_modifier - ctx.lineWidth) / 2;
    {
      const gradient2 = ctx.createRadialGradient(
        arc_center.x,
        arc_center.y,
        arc_size + ctx.lineWidth,
        0,
        0,
        arc_size + ctx.lineWidth
      );
      gradient2.addColorStop(0, "rgb(29, 29, 29)");
      gradient2.addColorStop(1, "rgb(116, 116, 116)");
      ctx.fillStyle = gradient2;
    }
    ctx.beginPath();
    {
      ctx.arc(
        arc_center.x,
        arc_center.y,
        arc_size + ctx.lineWidth / 2,
        0,
        Math.PI * 2,
        false
      );
      ctx.fill();
      ctx.closePath();
    }
    const arc2 = {
      start_angle: Math.PI * 0.6,
      end_angle: Math.PI * 2.4
    };
    ctx.beginPath();
    {
      const gradient2 = ctx.createRadialGradient(
        arc_center.x,
        arc_center.y,
        arc_size + ctx.lineWidth,
        0,
        0,
        arc_size + ctx.lineWidth
      );
      gradient2.addColorStop(0, "rgb(99, 99, 99)");
      gradient2.addColorStop(1, "rgb(36, 36, 36)");
      ctx.strokeStyle = gradient2;
    }
    ctx.arc(
      arc_center.x,
      arc_center.y,
      arc_size,
      arc2.start_angle,
      arc2.end_angle,
      false
    );
    ctx.stroke();
    ctx.closePath();
    const range2 = this.options.max - this.options.min;
    let nvalue = (this.value - this.options.min) / range2;
    nvalue = clamp(nvalue, 0, 1);
    ctx.beginPath();
    const gradient = ctx.createConicGradient(
      arc2.start_angle,
      arc_center.x,
      arc_center.y
    );
    const gs = gradient_stops.split(";");
    for (const [index2, stop2] of gs.entries()) {
      gradient.addColorStop(index2, stop2.trim());
    }
    ctx.strokeStyle = gradient;
    const value_end_angle = (arc2.end_angle - arc2.start_angle) * nvalue + arc2.start_angle;
    ctx.arc(
      arc_center.x,
      arc_center.y,
      arc_size,
      arc2.start_angle,
      value_end_angle,
      false
    );
    ctx.stroke();
    ctx.closePath();
    if (show_text && !this.disabled) {
      ctx.strokeStyle = this.outline_color;
      ctx.beginPath();
      ctx.strokeStyle = this.outline_color;
      ctx.arc(
        arc_center.x,
        arc_center.y,
        arc_size + ctx.lineWidth / 2,
        0,
        Math.PI * 2,
        false
      );
      ctx.lineWidth = 1;
      ctx.stroke();
      ctx.closePath();
    }
    if (show_text) {
      ctx.textAlign = "center";
      ctx.fillStyle = this.text_color;
      const fixedValue = Number(this.value).toFixed(this.options.precision ?? 3);
      ctx.fillText(
        `${this.label || this.name}
${fixedValue}`,
        width2 * 0.5,
        y2 + effective_height * 0.5
      );
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  onClick() {
    this.current_drag_offset = 0;
  }
  current_drag_offset = 0;
  onDrag(options22) {
    if (this.options.read_only) return;
    const { e: e2 } = options22;
    const step2 = getWidgetStep(this.options);
    const range2 = this.options.max - this.options.min;
    const range_10_percent = range2 / 10;
    const range_1_percent = range2 / 100;
    const step_for = {
      shift: range_10_percent > step2 ? range_10_percent - range_10_percent % step2 : step2,
      delta_y: range_1_percent > step2 ? range_1_percent - range_1_percent % step2 : step2
      // 1% increments
    };
    const use_y = Math.abs(e2.movementY) > Math.abs(e2.movementX);
    const delta2 = use_y ? -e2.movementY : e2.movementX;
    const drag_threshold = 15;
    this.current_drag_offset += delta2;
    let adjustment = 0;
    if (this.current_drag_offset > drag_threshold) {
      adjustment += 1;
      this.current_drag_offset -= drag_threshold;
    } else if (this.current_drag_offset < -15) {
      adjustment -= 1;
      this.current_drag_offset += drag_threshold;
    }
    const step_with_shift_modifier = e2.shiftKey ? step_for.shift : use_y ? step_for.delta_y : step2;
    const deltaValue = adjustment * step_with_shift_modifier;
    const newValue2 = clamp(
      this.value + deltaValue,
      this.options.min,
      this.options.max
    );
    if (newValue2 !== this.value) {
      this.setValue(newValue2, options22);
    }
  }
}
class NumberWidget extends BaseWidget {
  static {
    __name(this, "NumberWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = "number";
    this.value = widget.value;
  }
  /**
   * Draws the widget
   * @param ctx The canvas context
   * @param options The options for drawing the widget
   */
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { height } = this;
    ctx.textAlign = "left";
    ctx.strokeStyle = this.outline_color;
    ctx.fillStyle = this.background_color;
    ctx.beginPath();
    if (show_text)
      ctx.roundRect(margin, y2, width2 - margin * 2, height, [height * 0.5]);
    else
      ctx.rect(margin, y2, width2 - margin * 2, height);
    ctx.fill();
    if (show_text) {
      if (!this.disabled) {
        ctx.stroke();
        ctx.fillStyle = this.text_color;
        ctx.beginPath();
        ctx.moveTo(margin + 16, y2 + 5);
        ctx.lineTo(margin + 6, y2 + height * 0.5);
        ctx.lineTo(margin + 16, y2 + height - 5);
        ctx.fill();
        ctx.beginPath();
        ctx.moveTo(width2 - margin - 16, y2 + 5);
        ctx.lineTo(width2 - margin - 6, y2 + height * 0.5);
        ctx.lineTo(width2 - margin - 16, y2 + height - 5);
        ctx.fill();
      }
      ctx.fillStyle = this.secondary_text_color;
      const label8 = this.label || this.name;
      if (label8 != null) {
        ctx.fillText(label8, margin * 2 + 5, y2 + height * 0.7);
      }
      ctx.fillStyle = this.text_color;
      ctx.textAlign = "right";
      ctx.fillText(
        Number(this.value).toFixed(
          this.options.precision !== void 0 ? this.options.precision : 3
        ),
        width2 - margin * 2 - 20,
        y2 + height * 0.7
      );
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  onClick(options) {
    const { e, node, canvas } = options;
    const x = e.canvasX - node.pos[0];
    const width = this.width || node.size[0];
    const delta = x < 40 ? -1 : x > width - 40 ? 1 : 0;
    if (delta) {
      let newValue2 = this.value + delta * getWidgetStep(this.options);
      if (this.options.min != null && newValue2 < this.options.min) {
        newValue2 = this.options.min;
      }
      if (this.options.max != null && newValue2 > this.options.max) {
        newValue2 = this.options.max;
      }
      if (newValue2 !== this.value) {
        this.setValue(newValue2, { e, node, canvas });
      }
      return;
    }
    canvas.prompt("Value", this.value, (v) => {
      if (/^[\d\s()*+/-]+|\d+\.\d+$/.test(v)) {
        try {
          v = eval(v);
        } catch {
        }
      }
      const newValue = Number(v);
      if (!isNaN(newValue)) {
        this.setValue(newValue, { e, node, canvas });
      }
    }, e);
  }
  /**
   * Handles drag events for the number widget
   * @param options The options for handling the drag event
   */
  onDrag(options22) {
    const { e: e2, node: node22, canvas: canvas2 } = options22;
    const width2 = this.width || node22.width;
    const x2 = e2.canvasX - node22.pos[0];
    const delta2 = x2 < 40 ? -1 : x2 > width2 - 40 ? 1 : 0;
    if (delta2 && (x2 > -3 && x2 < width2 + 3)) return;
    let newValue2 = this.value;
    if (e2.deltaX) newValue2 += e2.deltaX * getWidgetStep(this.options);
    if (this.options.min != null && newValue2 < this.options.min) {
      newValue2 = this.options.min;
    }
    if (this.options.max != null && newValue2 > this.options.max) {
      newValue2 = this.options.max;
    }
    if (newValue2 !== this.value) {
      this.setValue(newValue2, { e: e2, node: node22, canvas: canvas2 });
    }
  }
}
class SliderWidget extends BaseWidget {
  static {
    __name(this, "SliderWidget");
  }
  marker;
  constructor(widget) {
    super(widget);
    this.type = "slider";
    this.value = widget.value;
    this.options = widget.options;
    this.marker = widget.marker;
  }
  /**
   * Draws the widget
   * @param ctx The canvas context
   * @param options The options for drawing the widget
   */
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { height } = this;
    ctx.fillStyle = this.background_color;
    ctx.fillRect(margin, y2, width2 - margin * 2, height);
    const range2 = this.options.max - this.options.min;
    let nvalue = (this.value - this.options.min) / range2;
    nvalue = clamp(nvalue, 0, 1);
    ctx.fillStyle = this.options.slider_color ?? "#678";
    ctx.fillRect(margin, y2, nvalue * (width2 - margin * 2), height);
    if (show_text && !this.disabled) {
      ctx.strokeStyle = this.outline_color;
      ctx.strokeRect(margin, y2, width2 - margin * 2, height);
    }
    if (this.marker != null) {
      let marker_nvalue = (this.marker - this.options.min) / range2;
      marker_nvalue = clamp(marker_nvalue, 0, 1);
      ctx.fillStyle = this.options.marker_color ?? "#AA9";
      ctx.fillRect(
        margin + marker_nvalue * (width2 - margin * 2),
        y2,
        2,
        height
      );
    }
    if (show_text) {
      ctx.textAlign = "center";
      ctx.fillStyle = this.text_color;
      const fixedValue = Number(this.value).toFixed(this.options.precision ?? 3);
      ctx.fillText(
        `${this.label || this.name}  ${fixedValue}`,
        width2 * 0.5,
        y2 + height * 0.7
      );
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  /**
   * Handles click events for the slider widget
   */
  onClick(options22) {
    if (this.options.read_only) return;
    const { e: e2, node: node22 } = options22;
    const width2 = this.width || node22.size[0];
    const x2 = e2.canvasX - node22.pos[0];
    const slideFactor = clamp((x2 - 15) / (width2 - 30), 0, 1);
    const newValue2 = this.options.min + (this.options.max - this.options.min) * slideFactor;
    if (newValue2 !== this.value) {
      this.setValue(newValue2, options22);
    }
  }
  /**
   * Handles drag events for the slider widget
   */
  onDrag(options22) {
    if (this.options.read_only) return false;
    const { e: e2, node: node22 } = options22;
    const width2 = this.width || node22.size[0];
    const x2 = e2.canvasX - node22.pos[0];
    const slideFactor = clamp((x2 - 15) / (width2 - 30), 0, 1);
    const newValue2 = this.options.min + (this.options.max - this.options.min) * slideFactor;
    if (newValue2 !== this.value) {
      this.setValue(newValue2, options22);
    }
  }
}
class TextWidget extends BaseWidget {
  static {
    __name(this, "TextWidget");
  }
  constructor(widget) {
    super(widget);
    this.type = widget.type ?? "string";
    this.value = widget.value?.toString() ?? "";
  }
  /**
   * Draws the widget
   * @param ctx The canvas context
   * @param options The options for drawing the widget
   */
  drawWidget(ctx, {
    y: y2,
    width: width2,
    show_text = true,
    margin = 15
  }) {
    const originalTextAlign = ctx.textAlign;
    const originalStrokeStyle = ctx.strokeStyle;
    const originalFillStyle = ctx.fillStyle;
    const { height } = this;
    ctx.textAlign = "left";
    ctx.strokeStyle = this.outline_color;
    ctx.fillStyle = this.background_color;
    ctx.beginPath();
    if (show_text)
      ctx.roundRect(margin, y2, width2 - margin * 2, height, [height * 0.5]);
    else
      ctx.rect(margin, y2, width2 - margin * 2, height);
    ctx.fill();
    if (show_text) {
      if (!this.disabled) ctx.stroke();
      ctx.save();
      ctx.beginPath();
      ctx.rect(margin, y2, width2 - margin * 2, height);
      ctx.clip();
      ctx.fillStyle = this.secondary_text_color;
      const label8 = this.label || this.name;
      if (label8 != null) {
        ctx.fillText(label8, margin * 2, y2 + height * 0.7);
      }
      ctx.fillStyle = this.text_color;
      ctx.textAlign = "right";
      ctx.fillText(
        // 30 chars max
        String(this.value).substr(0, 30),
        width2 - margin * 2,
        y2 + height * 0.7
      );
      ctx.restore();
    }
    ctx.textAlign = originalTextAlign;
    ctx.strokeStyle = originalStrokeStyle;
    ctx.fillStyle = originalFillStyle;
  }
  onClick(options22) {
    const { e: e2, node: node22, canvas: canvas2 } = options22;
    canvas2.prompt(
      "Value",
      this.value,
      (v2) => {
        if (v2 !== null) {
          this.setValue(v2, { e: e2, node: node22, canvas: canvas2 });
        }
      },
      e2,
      this.options?.multiline ?? false
    );
  }
}
const WIDGET_TYPE_MAP = {
  // @ts-expect-error https://github.com/Comfy-Org/litegraph.js/issues/616
  button: ButtonWidget,
  // @ts-expect-error #616
  toggle: BooleanWidget,
  // @ts-expect-error #616
  slider: SliderWidget,
  // @ts-expect-error #616
  knob: KnobWidget,
  // @ts-expect-error #616
  combo: ComboWidget,
  // @ts-expect-error #616
  number: NumberWidget,
  // @ts-expect-error #616
  string: TextWidget,
  // @ts-expect-error #616
  text: TextWidget
};
class LGraphNode {
  static {
    __name(this, "LGraphNode");
  }
  // Static properties used by dynamic child classes
  static title;
  static MAX_CONSOLE;
  static type;
  static category;
  static filter;
  static skip_list;
  /** Default setting for {@link LGraphNode.connectInputToOutput}. @see {@link INodeFlags.keepAllLinksOnBypass} */
  static keepAllLinksOnBypass = false;
  /** The title text of the node. */
  title;
  /**
   * The font style used to render the node's title text.
   */
  get titleFontStyle() {
    return `${LiteGraph.NODE_TEXT_SIZE}px Arial`;
  }
  get innerFontStyle() {
    return `normal ${LiteGraph.NODE_SUBTEXT_SIZE}px Arial`;
  }
  graph = null;
  id;
  type = null;
  inputs = [];
  outputs = [];
  // Not used
  connections = [];
  properties = {};
  properties_info = [];
  flags = {};
  widgets;
  /**
   * The amount of space available for widgets to grow into.
   * @see {@link layoutWidgets}
   */
  freeWidgetSpace;
  locked;
  // Execution order, automatically computed during run
  order;
  mode;
  last_serialization;
  serialize_widgets;
  /**
   * The overridden fg color used to render the node.
   * @see {@link renderingColor}
   */
  color;
  /**
   * The overridden bg color used to render the node.
   * @see {@link renderingBgColor}
   */
  bgcolor;
  /**
   * The overridden box color used to render the node.
   * @see {@link renderingBoxColor}
   */
  boxcolor;
  /** The fg color used to render the node. */
  get renderingColor() {
    return this.color || this.constructor.color || LiteGraph.NODE_DEFAULT_COLOR;
  }
  /** The bg color used to render the node. */
  get renderingBgColor() {
    return this.bgcolor || this.constructor.bgcolor || LiteGraph.NODE_DEFAULT_BGCOLOR;
  }
  /** The box color used to render the node. */
  get renderingBoxColor() {
    const mode2 = this.mode ?? LGraphEventMode.ALWAYS;
    let colState = LiteGraph.node_box_coloured_by_mode && LiteGraph.NODE_MODES_COLORS[mode2] ? LiteGraph.NODE_MODES_COLORS[mode2] : void 0;
    if (LiteGraph.node_box_coloured_when_on) {
      colState = this.action_triggered ? "#FFF" : this.execute_triggered ? "#AAA" : colState;
    }
    return this.boxcolor || colState || LiteGraph.NODE_DEFAULT_BOXCOLOR;
  }
  /** @inheritdoc {@link IColorable.setColorOption} */
  setColorOption(colorOption) {
    if (colorOption == null) {
      delete this.color;
      delete this.bgcolor;
    } else {
      this.color = colorOption.color;
      this.bgcolor = colorOption.bgcolor;
    }
  }
  /** @inheritdoc {@link IColorable.getColorOption} */
  getColorOption() {
    return Object.values(LGraphCanvas.node_colors).find(
      (colorOption) => colorOption.color === this.color && colorOption.bgcolor === this.bgcolor
    ) ?? null;
  }
  exec_version;
  action_call;
  execute_triggered;
  action_triggered;
  widgets_up;
  widgets_start_y;
  lostFocusAt;
  gotFocusAt;
  badges = [];
  badgePosition = BadgePosition.TopLeft;
  /**
   * The width of the node when collapsed.
   * Updated by {@link LGraphCanvas.drawNode}
   */
  _collapsed_width;
  console;
  _level;
  _shape;
  mouseOver;
  redraw_on_mouse;
  resizable;
  clonable;
  _relative_id;
  clip_area;
  ignore_remove;
  has_errors;
  removable;
  block_delete;
  selected;
  showAdvanced;
  /** @inheritdoc {@link renderArea} */
  #renderArea = new Float32Array(4);
  /**
   * Rect describing the node area, including shadows and any protrusions.
   * Determines if the node is visible.  Calculated once at the start of every frame.
   */
  get renderArea() {
    return this.#renderArea;
  }
  /** @inheritdoc {@link boundingRect} */
  #boundingRect = new Float32Array(4);
  /**
   * Cached node position & area as `x, y, width, height`.  Includes changes made by {@link onBounding}, if present.
   *
   * Determines the node hitbox and other rendering effects.  Calculated once at the start of every frame.
   */
  get boundingRect() {
    return this.#boundingRect;
  }
  /** {@link pos} and {@link size} values are backed by this {@link Rect}. */
  _posSize = new Float32Array(4);
  _pos = this._posSize.subarray(0, 2);
  _size = this._posSize.subarray(2, 4);
  get pos() {
    return this._pos;
  }
  set pos(value3) {
    if (!value3 || value3.length < 2) return;
    this._pos[0] = value3[0];
    this._pos[1] = value3[1];
  }
  get size() {
    return this._size;
  }
  set size(value3) {
    if (!value3 || value3.length < 2) return;
    this._size[0] = value3[0];
    this._size[1] = value3[1];
  }
  /**
   * The size of the node used for rendering.
   */
  get renderingSize() {
    return this.flags.collapsed ? [this._collapsed_width ?? 0, 0] : this._size;
  }
  get shape() {
    return this._shape;
  }
  set shape(v2) {
    switch (v2) {
      case "default":
        delete this._shape;
        break;
      case "box":
        this._shape = RenderShape.BOX;
        break;
      case "round":
        this._shape = RenderShape.ROUND;
        break;
      case "circle":
        this._shape = RenderShape.CIRCLE;
        break;
      case "card":
        this._shape = RenderShape.CARD;
        break;
      default:
        this._shape = v2;
    }
  }
  /**
   * The shape of the node used for rendering. @see {@link RenderShape}
   */
  get renderingShape() {
    return this._shape || this.constructor.shape || LiteGraph.NODE_DEFAULT_SHAPE;
  }
  get is_selected() {
    return this.selected;
  }
  set is_selected(value3) {
    this.selected = value3;
  }
  get title_mode() {
    return this.constructor.title_mode ?? TitleMode.NORMAL_TITLE;
  }
  constructor(title) {
    this.id = LiteGraph.use_uuids ? LiteGraph.uuidv4() : -1;
    this.title = title || "Unnamed";
    this.size = [LiteGraph.NODE_WIDTH, 60];
    this.pos = [10, 10];
  }
  /**
   * configure a node from an object containing the serialized info
   */
  configure(info) {
    if (this.graph) {
      this.graph._version++;
    }
    for (const j2 in info) {
      if (j2 == "properties") {
        for (const k2 in info.properties) {
          this.properties[k2] = info.properties[k2];
          this.onPropertyChanged?.(k2, info.properties[k2]);
        }
        continue;
      }
      if (info[j2] == null) {
        continue;
      } else if (typeof info[j2] == "object") {
        if (this[j2]?.configure) {
          this[j2]?.configure(info[j2]);
        } else {
          this[j2] = LiteGraph.cloneObject(info[j2], this[j2]);
        }
      } else {
        this[j2] = info[j2];
      }
    }
    if (!info.title) {
      this.title = this.constructor.title;
    }
    this.inputs ??= [];
    this.inputs = this.inputs.map((input) => toClass(NodeInputSlot, input));
    for (const [i2, input] of this.inputs.entries()) {
      const link2 = this.graph && input.link != null ? this.graph._links.get(input.link) : null;
      this.onConnectionsChange?.(NodeSlotType.INPUT, i2, true, link2, input);
      this.onInputAdded?.(input);
    }
    this.outputs ??= [];
    this.outputs = this.outputs.map((output) => toClass(NodeOutputSlot, output));
    for (const [i2, output] of this.outputs.entries()) {
      if (!output.links) continue;
      for (const linkId of output.links) {
        const link2 = this.graph ? this.graph._links.get(linkId) : null;
        this.onConnectionsChange?.(NodeSlotType.OUTPUT, i2, true, link2, output);
      }
      this.onOutputAdded?.(output);
    }
    if (this.widgets) {
      for (const w2 of this.widgets) {
        if (!w2) continue;
        if (w2.options?.property && this.properties[w2.options.property] != void 0)
          w2.value = JSON.parse(JSON.stringify(this.properties[w2.options.property]));
      }
      if (info.widgets_values) {
        for (let i2 = 0; i2 < info.widgets_values.length; ++i2) {
          const widget = this.widgets[i2];
          if (widget) {
            widget.value = info.widgets_values[i2];
          }
        }
      }
    }
    if (this.pinned) this.resizable = false;
    this.onConfigure?.(info);
  }
  /**
   * serialize the content
   */
  serialize() {
    const o2 = {
      id: this.id,
      type: this.type ?? void 0,
      pos: [this.pos[0], this.pos[1]],
      size: [this.size[0], this.size[1]],
      flags: LiteGraph.cloneObject(this.flags),
      order: this.order,
      mode: this.mode,
      showAdvanced: this.showAdvanced
    };
    if (this.constructor === LGraphNode && this.last_serialization)
      return this.last_serialization;
    if (this.inputs) o2.inputs = this.inputs.map((input) => inputAsSerialisable(input));
    if (this.outputs) o2.outputs = this.outputs.map((output) => outputAsSerialisable(output));
    if (this.title && this.title != this.constructor.title) o2.title = this.title;
    if (this.properties) o2.properties = LiteGraph.cloneObject(this.properties);
    const { widgets } = this;
    if (widgets && this.serialize_widgets) {
      o2.widgets_values = [];
      for (const [i2, widget] of widgets.entries()) {
        o2.widgets_values[i2] = widget ? widget.value : null;
      }
    }
    if (!o2.type) o2.type = this.constructor.type;
    if (this.color) o2.color = this.color;
    if (this.bgcolor) o2.bgcolor = this.bgcolor;
    if (this.boxcolor) o2.boxcolor = this.boxcolor;
    if (this.shape) o2.shape = this.shape;
    if (this.onSerialize?.(o2)) console.warn("node onSerialize shouldnt return anything, data should be stored in the object pass in the first parameter");
    return o2;
  }
  /* Creates a clone of this node */
  clone() {
    if (this.type == null) return null;
    const node22 = LiteGraph.createNode(this.type);
    if (!node22) return null;
    const data30 = LiteGraph.cloneObject(this.serialize());
    const { inputs, outputs } = data30;
    if (inputs) {
      for (const input of inputs) {
        input.link = null;
      }
    }
    if (outputs) {
      for (const { links } of outputs) {
        if (links) links.length = 0;
      }
    }
    delete data30.id;
    if (LiteGraph.use_uuids) data30.id = LiteGraph.uuidv4();
    node22.configure(data30);
    return node22;
  }
  /**
   * serialize and stringify
   */
  toString() {
    return JSON.stringify(this.serialize());
  }
  /**
   * get the title string
   */
  getTitle() {
    return this.title || this.constructor.title;
  }
  /**
   * sets the value of a property
   * @param name
   * @param value
   */
  setProperty(name2, value3) {
    this.properties ||= {};
    if (value3 === this.properties[name2]) return;
    const prev_value = this.properties[name2];
    this.properties[name2] = value3;
    if (this.onPropertyChanged?.(name2, value3, prev_value) === false)
      this.properties[name2] = prev_value;
    if (this.widgets) {
      for (const w2 of this.widgets) {
        if (!w2) continue;
        if (w2.options.property == name2) {
          w2.value = value3;
          break;
        }
      }
    }
  }
  /**
   * sets the output data
   * @param slot
   * @param data
   */
  setOutputData(slot, data30) {
    const { outputs } = this;
    if (!outputs) return;
    if (slot == -1 || slot >= outputs.length) return;
    const output_info = outputs[slot];
    if (!output_info) return;
    output_info._data = data30;
    if (!this.graph) throw new NullGraphError();
    const { links } = outputs[slot];
    if (links) {
      for (const id4 of links) {
        const link2 = this.graph._links.get(id4);
        if (link2) link2.data = data30;
      }
    }
  }
  /**
   * sets the output data type, useful when you want to be able to overwrite the data type
   */
  setOutputDataType(slot, type) {
    const { outputs } = this;
    if (!outputs || (slot == -1 || slot >= outputs.length)) return;
    const output_info = outputs[slot];
    if (!output_info) return;
    output_info.type = type;
    if (!this.graph) throw new NullGraphError();
    const { links } = outputs[slot];
    if (links) {
      for (const id4 of links) {
        const link2 = this.graph._links.get(id4);
        if (!link2) continue;
        link2.type = type;
      }
    }
  }
  /**
   * Retrieves the input data (data traveling through the connection) from one slot
   * @param slot
   * @param force_update if set to true it will force the connected node of this slot to output data into this link
   * @returns data or if it is not connected returns undefined
   */
  getInputData(slot, force_update) {
    if (!this.inputs) return;
    if (slot >= this.inputs.length || this.inputs[slot].link == null) return;
    if (!this.graph) throw new NullGraphError();
    const link_id = this.inputs[slot].link;
    const link2 = this.graph._links.get(link_id);
    if (!link2) return null;
    if (!force_update) return link2.data;
    const node22 = this.graph.getNodeById(link2.origin_id);
    if (!node22) return link2.data;
    if (node22.updateOutputData) {
      node22.updateOutputData(link2.origin_slot);
    } else {
      node22.onExecute?.();
    }
    return link2.data;
  }
  /**
   * Retrieves the input data type (in case this supports multiple input types)
   * @param slot
   * @returns datatype in string format
   */
  getInputDataType(slot) {
    if (!this.inputs) return null;
    if (slot >= this.inputs.length || this.inputs[slot].link == null) return null;
    if (!this.graph) throw new NullGraphError();
    const link_id = this.inputs[slot].link;
    const link2 = this.graph._links.get(link_id);
    if (!link2) return null;
    const node22 = this.graph.getNodeById(link2.origin_id);
    if (!node22) return link2.type;
    const output_info = node22.outputs[link2.origin_slot];
    return output_info ? output_info.type : null;
  }
  /**
   * Retrieves the input data from one slot using its name instead of slot number
   * @param slot_name
   * @param force_update if set to true it will force the connected node of this slot to output data into this link
   * @returns data or if it is not connected returns null
   */
  getInputDataByName(slot_name, force_update) {
    const slot = this.findInputSlot(slot_name);
    return slot == -1 ? null : this.getInputData(slot, force_update);
  }
  /**
   * tells you if there is a connection in one input slot
   * @param slot The 0-based index of the input to check
   * @returns `true` if the input slot has a link ID (does not perform validation)
   */
  isInputConnected(slot) {
    if (!this.inputs) return false;
    return slot < this.inputs.length && this.inputs[slot].link != null;
  }
  /**
   * tells you info about an input connection (which node, type, etc)
   * @returns object or null { link: id, name: string, type: string or 0 }
   */
  getInputInfo(slot) {
    return !this.inputs || !(slot < this.inputs.length) ? null : this.inputs[slot];
  }
  /**
   * Returns the link info in the connection of an input slot
   * @returns object or null
   */
  getInputLink(slot) {
    if (!this.inputs) return null;
    if (slot < this.inputs.length) {
      if (!this.graph) throw new NullGraphError();
      const input = this.inputs[slot];
      if (input.link != null) {
        return this.graph._links.get(input.link) ?? null;
      }
    }
    return null;
  }
  /**
   * returns the node connected in the input slot
   * @returns node or null
   */
  getInputNode(slot) {
    if (!this.inputs) return null;
    if (slot >= this.inputs.length) return null;
    const input = this.inputs[slot];
    if (!input || input.link === null) return null;
    if (!this.graph) throw new NullGraphError();
    const link_info = this.graph._links.get(input.link);
    if (!link_info) return null;
    return this.graph.getNodeById(link_info.origin_id);
  }
  /**
   * returns the value of an input with this name, otherwise checks if there is a property with that name
   * @returns value
   */
  getInputOrProperty(name2) {
    const { inputs } = this;
    if (!inputs?.length) {
      return this.properties ? this.properties[name2] : null;
    }
    if (!this.graph) throw new NullGraphError();
    for (const input of inputs) {
      if (name2 == input.name && input.link != null) {
        const link2 = this.graph._links.get(input.link);
        if (link2) return link2.data;
      }
    }
    return this.properties[name2];
  }
  /**
   * tells you the last output data that went in that slot
   * @returns object or null
   */
  getOutputData(slot) {
    if (!this.outputs) return null;
    if (slot >= this.outputs.length) return null;
    const info = this.outputs[slot];
    return info._data;
  }
  /**
   * tells you info about an output connection (which node, type, etc)
   * @returns object or null { name: string, type: string, links: [ ids of links in number ] }
   */
  getOutputInfo(slot) {
    return !this.outputs || !(slot < this.outputs.length) ? null : this.outputs[slot];
  }
  /**
   * tells you if there is a connection in one output slot
   */
  isOutputConnected(slot) {
    if (!this.outputs) return false;
    return slot < this.outputs.length && Number(this.outputs[slot].links?.length) > 0;
  }
  /**
   * tells you if there is any connection in the output slots
   */
  isAnyOutputConnected() {
    const { outputs } = this;
    if (!outputs) return false;
    for (const output of outputs) {
      if (output.links?.length) return true;
    }
    return false;
  }
  /**
   * retrieves all the nodes connected to this output slot
   */
  getOutputNodes(slot) {
    const { outputs } = this;
    if (!outputs || outputs.length == 0) return null;
    if (slot >= outputs.length) return null;
    const { links } = outputs[slot];
    if (!links || links.length == 0) return null;
    if (!this.graph) throw new NullGraphError();
    const r2 = [];
    for (const id4 of links) {
      const link2 = this.graph._links.get(id4);
      if (link2) {
        const target_node = this.graph.getNodeById(link2.target_id);
        if (target_node) {
          r2.push(target_node);
        }
      }
    }
    return r2;
  }
  addOnTriggerInput() {
    const trigS = this.findInputSlot("onTrigger");
    if (trigS == -1) {
      this.addInput("onTrigger", LiteGraph.EVENT, {
        nameLocked: true
      });
      return this.findInputSlot("onTrigger");
    }
    return trigS;
  }
  addOnExecutedOutput() {
    const trigS = this.findOutputSlot("onExecuted");
    if (trigS == -1) {
      this.addOutput("onExecuted", LiteGraph.ACTION, {
        nameLocked: true
      });
      return this.findOutputSlot("onExecuted");
    }
    return trigS;
  }
  onAfterExecuteNode(param, options22) {
    const trigS = this.findOutputSlot("onExecuted");
    if (trigS != -1) {
      this.triggerSlot(trigS, param, null, options22);
    }
  }
  changeMode(modeTo) {
    switch (modeTo) {
      case LGraphEventMode.ON_EVENT:
        break;
      case LGraphEventMode.ON_TRIGGER:
        this.addOnTriggerInput();
        this.addOnExecutedOutput();
        break;
      case LGraphEventMode.NEVER:
        break;
      case LGraphEventMode.ALWAYS:
        break;
      case LiteGraph.ON_REQUEST:
        break;
      default:
        return false;
    }
    this.mode = modeTo;
    return true;
  }
  /**
   * Triggers the node code execution, place a boolean/counter to mark the node as being executed
   */
  doExecute(param, options22) {
    options22 = options22 || {};
    if (this.onExecute) {
      options22.action_call ||= `${this.id}_exec_${Math.floor(Math.random() * 9999)}`;
      if (!this.graph) throw new NullGraphError();
      this.graph.nodes_executing[this.id] = true;
      this.onExecute(param, options22);
      this.graph.nodes_executing[this.id] = false;
      this.exec_version = this.graph.iteration;
      if (options22?.action_call) {
        this.action_call = options22.action_call;
        this.graph.nodes_executedAction[this.id] = options22.action_call;
      }
    }
    this.execute_triggered = 2;
    this.onAfterExecuteNode?.(param, options22);
  }
  /**
   * Triggers an action, wrapped by logics to control execution flow
   * @param action name
   */
  actionDo(action, param, options22) {
    options22 = options22 || {};
    if (this.onAction) {
      options22.action_call ||= `${this.id}_${action || "action"}_${Math.floor(Math.random() * 9999)}`;
      if (!this.graph) throw new NullGraphError();
      this.graph.nodes_actioning[this.id] = action || "actioning";
      this.onAction(action, param, options22);
      this.graph.nodes_actioning[this.id] = false;
      if (options22?.action_call) {
        this.action_call = options22.action_call;
        this.graph.nodes_executedAction[this.id] = options22.action_call;
      }
    }
    this.action_triggered = 2;
    this.onAfterExecuteNode?.(param, options22);
  }
  /**
   * Triggers an event in this node, this will trigger any output with the same name
   * @param action name ( "on_play", ... ) if action is equivalent to false then the event is send to all
   */
  trigger(action, param, options22) {
    const { outputs } = this;
    if (!outputs || !outputs.length) {
      return;
    }
    if (this.graph) this.graph._last_trigger_time = LiteGraph.getTime();
    for (const [i2, output] of outputs.entries()) {
      if (!output || output.type !== LiteGraph.EVENT || action && output.name != action) {
        continue;
      }
      this.triggerSlot(i2, param, null, options22);
    }
  }
  /**
   * Triggers a slot event in this node: cycle output slots and launch execute/action on connected nodes
   * @param slot the index of the output slot
   * @param link_id [optional] in case you want to trigger and specific output link in a slot
   */
  triggerSlot(slot, param, link_id, options22) {
    options22 = options22 || {};
    if (!this.outputs) return;
    if (slot == null) {
      console.error("slot must be a number");
      return;
    }
    if (typeof slot !== "number")
      console.warn("slot must be a number, use node.trigger('name') if you want to use a string");
    const output = this.outputs[slot];
    if (!output) return;
    const links = output.links;
    if (!links || !links.length) return;
    if (!this.graph) throw new NullGraphError();
    this.graph._last_trigger_time = LiteGraph.getTime();
    for (const id4 of links) {
      if (link_id != null && link_id != id4) continue;
      const link_info = this.graph._links.get(id4);
      if (!link_info) continue;
      link_info._last_time = LiteGraph.getTime();
      const node22 = this.graph.getNodeById(link_info.target_id);
      if (!node22) continue;
      if (node22.mode === LGraphEventMode.ON_TRIGGER) {
        if (!options22.action_call)
          options22.action_call = `${this.id}_trigg_${Math.floor(Math.random() * 9999)}`;
        node22.doExecute?.(param, options22);
      } else if (node22.onAction) {
        if (!options22.action_call)
          options22.action_call = `${this.id}_act_${Math.floor(Math.random() * 9999)}`;
        const target_connection = node22.inputs[link_info.target_slot];
        node22.actionDo(target_connection.name, param, options22);
      }
    }
  }
  /**
   * clears the trigger slot animation
   * @param slot the index of the output slot
   * @param link_id [optional] in case you want to trigger and specific output link in a slot
   */
  clearTriggeredSlot(slot, link_id) {
    if (!this.outputs) return;
    const output = this.outputs[slot];
    if (!output) return;
    const links = output.links;
    if (!links || !links.length) return;
    if (!this.graph) throw new NullGraphError();
    for (const id4 of links) {
      if (link_id != null && link_id != id4) continue;
      const link_info = this.graph._links.get(id4);
      if (!link_info) continue;
      link_info._last_time = 0;
    }
  }
  /**
   * changes node size and triggers callback
   */
  setSize(size) {
    this.size = size;
    this.onResize?.(this.size);
  }
  /**
   * Expands the node size to fit its content.
   */
  expandToFitContent() {
    const newSize = this.computeSize();
    this.setSize([
      Math.max(this.size[0], newSize[0]),
      Math.max(this.size[1], newSize[1])
    ]);
  }
  /**
   * add a new property to this node
   * @param type string defining the output type ("vec3","number",...)
   * @param extra_info this can be used to have special properties of the property (like values, etc)
   */
  addProperty(name2, default_value, type, extra_info) {
    const o2 = { name: name2, type, default_value };
    if (extra_info) Object.assign(o2, extra_info);
    this.properties_info ||= [];
    this.properties_info.push(o2);
    this.properties ||= {};
    this.properties[name2] = default_value;
    return o2;
  }
  /**
   * add a new output slot to use in this node
   * @param type string defining the output type ("vec3","number",...)
   * @param extra_info this can be used to have special properties of an output (label, special color, position, etc)
   */
  addOutput(name2, type, extra_info) {
    const output = new NodeOutputSlot({ name: name2, type, links: null });
    if (extra_info) Object.assign(output, extra_info);
    this.outputs ||= [];
    this.outputs.push(output);
    this.onOutputAdded?.(output);
    if (LiteGraph.auto_load_slot_types)
      LiteGraph.registerNodeAndSlotType(this, type, true);
    this.expandToFitContent();
    this.setDirtyCanvas(true, true);
    return output;
  }
  /**
   * add a new output slot to use in this node
   * @param array of triplets like [[name,type,extra_info],[...]]
   */
  addOutputs(array) {
    for (const info of array) {
      const o2 = new NodeOutputSlot({ name: info[0], type: info[1], links: null });
      if (array[2]) Object.assign(o2, info[2]);
      this.outputs ||= [];
      this.outputs.push(o2);
      this.onOutputAdded?.(o2);
      if (LiteGraph.auto_load_slot_types)
        LiteGraph.registerNodeAndSlotType(this, info[1], true);
    }
    this.expandToFitContent();
    this.setDirtyCanvas(true, true);
  }
  /**
   * remove an existing output slot
   */
  removeOutput(slot) {
    this.disconnectOutput(slot);
    const { outputs } = this;
    outputs.splice(slot, 1);
    for (let i2 = slot; i2 < outputs.length; ++i2) {
      const output = outputs[i2];
      if (!output || !output.links) continue;
      for (const linkId of output.links) {
        if (!this.graph) throw new NullGraphError();
        const link2 = this.graph._links.get(linkId);
        if (!link2) continue;
        link2.origin_slot--;
      }
    }
    this.onOutputRemoved?.(slot);
    this.setDirtyCanvas(true, true);
  }
  /**
   * add a new input slot to use in this node
   * @param type string defining the input type ("vec3","number",...), it its a generic one use 0
   * @param extra_info this can be used to have special properties of an input (label, color, position, etc)
   */
  addInput(name2, type, extra_info) {
    type = type || 0;
    const input = new NodeInputSlot({ name: name2, type, link: null });
    if (extra_info) Object.assign(input, extra_info);
    this.inputs ||= [];
    this.inputs.push(input);
    this.expandToFitContent();
    this.onInputAdded?.(input);
    LiteGraph.registerNodeAndSlotType(this, type);
    this.setDirtyCanvas(true, true);
    return input;
  }
  /**
   * add several new input slots in this node
   * @param array of triplets like [[name,type,extra_info],[...]]
   */
  addInputs(array) {
    for (const info of array) {
      const o2 = new NodeInputSlot({ name: info[0], type: info[1], link: null });
      if (array[2]) Object.assign(o2, info[2]);
      this.inputs ||= [];
      this.inputs.push(o2);
      this.onInputAdded?.(o2);
      LiteGraph.registerNodeAndSlotType(this, info[1]);
    }
    this.expandToFitContent();
    this.setDirtyCanvas(true, true);
  }
  /**
   * remove an existing input slot
   */
  removeInput(slot) {
    this.disconnectInput(slot, true);
    const { inputs } = this;
    const slot_info = inputs.splice(slot, 1);
    for (let i2 = slot; i2 < inputs.length; ++i2) {
      const input = inputs[i2];
      if (!input?.link) continue;
      if (!this.graph) throw new NullGraphError();
      const link2 = this.graph._links.get(input.link);
      if (!link2) continue;
      link2.target_slot--;
    }
    this.onInputRemoved?.(slot, slot_info[0]);
    this.setDirtyCanvas(true, true);
  }
  /**
   * add an special connection to this node (used for special kinds of graphs)
   * @param type string defining the input type ("vec3","number",...)
   * @param pos position of the connection inside the node
   * @param direction if is input or output
   */
  addConnection(name2, type, pos, direction) {
    const o2 = {
      name: name2,
      type,
      pos,
      direction,
      links: null
    };
    this.connections.push(o2);
    return o2;
  }
  /**
   * computes the minimum size of a node according to its inputs and output slots
   * @returns the total size
   */
  computeSize(out) {
    const ctorSize = this.constructor.size;
    if (ctorSize) return [ctorSize[0], ctorSize[1]];
    const { inputs, outputs } = this;
    let rows = Math.max(
      inputs ? inputs.filter((input) => !isWidgetInputSlot(input)).length : 1,
      outputs ? outputs.length : 1
    );
    const size = out || new Float32Array([0, 0]);
    rows = Math.max(rows, 1);
    const font_size = LiteGraph.NODE_TEXT_SIZE;
    const title_width = compute_text_size(this.title);
    let input_width = 0;
    let output_width = 0;
    if (inputs) {
      for (const input of inputs) {
        const text2 = input.label || input.localized_name || input.name || "";
        const text_width = compute_text_size(text2);
        if (input_width < text_width)
          input_width = text_width;
      }
    }
    if (outputs) {
      for (const output of outputs) {
        const text2 = output.label || output.localized_name || output.name || "";
        const text_width = compute_text_size(text2);
        if (output_width < text_width)
          output_width = text_width;
      }
    }
    size[0] = Math.max(input_width + output_width + 10, title_width);
    size[0] = Math.max(size[0], LiteGraph.NODE_WIDTH);
    if (this.widgets?.length)
      size[0] = Math.max(size[0], LiteGraph.NODE_WIDTH * 1.5);
    size[1] = (this.constructor.slot_start_y || 0) + rows * LiteGraph.NODE_SLOT_HEIGHT;
    let widgets_height = 0;
    if (this.widgets?.length) {
      for (const widget of this.widgets) {
        if (widget.hidden || widget.advanced && !this.showAdvanced) continue;
        let widget_height = 0;
        if (widget.computeSize) {
          widget_height += widget.computeSize(size[0])[1];
        } else if (widget.computeLayoutSize) {
          widget_height += widget.computeLayoutSize(this).minHeight;
        } else {
          widget_height += LiteGraph.NODE_WIDGET_HEIGHT;
        }
        widgets_height += widget_height + 4;
      }
      widgets_height += 8;
    }
    if (this.widgets_up)
      size[1] = Math.max(size[1], widgets_height);
    else if (this.widgets_start_y != null)
      size[1] = Math.max(size[1], widgets_height + this.widgets_start_y);
    else
      size[1] += widgets_height;
    function compute_text_size(text2) {
      return text2 ? font_size * text2.length * 0.6 : 0;
    }
    __name(compute_text_size, "compute_text_size");
    if (this.constructor.min_height && size[1] < this.constructor.min_height) {
      size[1] = this.constructor.min_height;
    }
    size[1] += 6;
    return size;
  }
  inResizeCorner(canvasX, canvasY) {
    const rows = this.outputs ? this.outputs.length : 1;
    const outputs_offset = (this.constructor.slot_start_y || 0) + rows * LiteGraph.NODE_SLOT_HEIGHT;
    return isInRectangle(
      canvasX,
      canvasY,
      this.pos[0] + this.size[0] - 15,
      this.pos[1] + Math.max(this.size[1] - 15, outputs_offset),
      20,
      20
    );
  }
  /**
   * returns all the info available about a property of this node.
   * @param property name of the property
   * @returns the object with all the available info
   */
  getPropertyInfo(property) {
    let info = null;
    const { properties_info } = this;
    if (properties_info) {
      for (const propInfo of properties_info) {
        if (propInfo.name == property) {
          info = propInfo;
          break;
        }
      }
    }
    if (this.constructor[`@${property}`]) info = this.constructor[`@${property}`];
    if (this.constructor.widgets_info?.[property])
      info = this.constructor.widgets_info[property];
    if (!info && this.onGetPropertyInfo) {
      info = this.onGetPropertyInfo(property);
    }
    info ||= {};
    info.type ||= typeof this.properties[property];
    if (info.widget == "combo") info.type = "enum";
    return info;
  }
  /**
   * Defines a widget inside the node, it will be rendered on top of the node, you can control lots of properties
   * @param type the widget type
   * @param name the text to show on the widget
   * @param value the default value
   * @param callback function to call when it changes (optionally, it can be the name of the property to modify)
   * @param options the object that contains special properties of this widget
   * @returns the created widget object
   */
  addWidget(type, name2, value3, callback, options22) {
    this.widgets ||= [];
    if (!options22 && callback && typeof callback === "object") {
      options22 = callback;
      callback = null;
    }
    options22 ||= {};
    if (typeof options22 === "string")
      options22 = { property: options22 };
    if (callback && typeof callback === "string") {
      options22.property = callback;
      callback = null;
    }
    const w2 = {
      // @ts-expect-error Type check or just assert?
      type: type.toLowerCase(),
      name: name2,
      value: value3,
      callback: typeof callback !== "function" ? void 0 : callback,
      options: options22,
      y: 0
    };
    if (w2.options.y !== void 0) {
      w2.y = w2.options.y;
    }
    if (!callback && !w2.options.callback && !w2.options.property) {
      console.warn("LiteGraph addWidget(...) without a callback or property assigned");
    }
    if (type == "combo" && !w2.options.values) {
      throw "LiteGraph addWidget('combo',...) requires to pass values in options: { values:['red','blue'] }";
    }
    const widget = this.addCustomWidget(w2);
    this.expandToFitContent();
    return widget;
  }
  addCustomWidget(custom_widget) {
    this.widgets ||= [];
    const WidgetClass = WIDGET_TYPE_MAP[custom_widget.type];
    const widget = WidgetClass ? new WidgetClass(custom_widget) : custom_widget;
    this.widgets.push(widget);
    return widget;
  }
  move(deltaX, deltaY) {
    if (this.pinned) return;
    this.pos[0] += deltaX;
    this.pos[1] += deltaY;
  }
  /**
   * Internal method to measure the node for rendering.  Prefer {@link boundingRect} where possible.
   *
   * Populates {@link out} with the results in graph space.
   * Populates {@link _collapsed_width} with the collapsed width if the node is collapsed.
   * Adjusts for title and collapsed status, but does not call {@link onBounding}.
   * @param out `x, y, width, height` are written to this array.
   * @param ctx The canvas context to use for measuring text.
   */
  measure(out, ctx) {
    const titleMode = this.title_mode;
    const renderTitle = titleMode != TitleMode.TRANSPARENT_TITLE && titleMode != TitleMode.NO_TITLE;
    const titleHeight = renderTitle ? LiteGraph.NODE_TITLE_HEIGHT : 0;
    out[0] = this.pos[0];
    out[1] = this.pos[1] + -titleHeight;
    if (!this.flags?.collapsed) {
      out[2] = this.size[0];
      out[3] = this.size[1] + titleHeight;
    } else {
      ctx.font = this.innerFontStyle;
      this._collapsed_width = Math.min(
        this.size[0],
        ctx.measureText(this.getTitle() ?? "").width + LiteGraph.NODE_TITLE_HEIGHT * 2
      );
      out[2] = this._collapsed_width || LiteGraph.NODE_COLLAPSED_WIDTH;
      out[3] = LiteGraph.NODE_TITLE_HEIGHT;
    }
  }
  /**
   * returns the bounding of the object, used for rendering purposes
   * @param out {Float32Array[4]?} [optional] a place to store the output, to free garbage
   * @param includeExternal {boolean?} [optional] set to true to
   * include the shadow and connection points in the bounding calculation
   * @returns the bounding box in format of [topleft_cornerx, topleft_cornery, width, height]
   */
  getBounding(out, includeExternal) {
    out ||= new Float32Array(4);
    const rect = includeExternal ? this.renderArea : this.boundingRect;
    out[0] = rect[0];
    out[1] = rect[1];
    out[2] = rect[2];
    out[3] = rect[3];
    return out;
  }
  /**
   * Calculates the render area of this node, populating both {@link boundingRect} and {@link renderArea}.
   * Called automatically at the start of every frame.
   */
  updateArea(ctx) {
    const bounds = this.#boundingRect;
    this.measure(bounds, ctx);
    this.onBounding?.(bounds);
    const renderArea = this.#renderArea;
    renderArea.set(bounds);
    renderArea[0] -= 4;
    renderArea[1] -= 4;
    renderArea[2] += 6 + 4;
    renderArea[3] += 5 + 4;
  }
  /**
   * checks if a point is inside the shape of a node
   */
  isPointInside(x2, y2) {
    return isInRect(x2, y2, this.boundingRect);
  }
  /**
   * Checks if the provided point is inside this node's collapse button area.
   * @param x X co-ordinate to check
   * @param y Y co-ordinate to check
   * @returns true if the x,y point is in the collapse button area, otherwise false
   */
  isPointInCollapse(x2, y2) {
    const squareLength = LiteGraph.NODE_TITLE_HEIGHT;
    return isInRectangle(
      x2,
      y2,
      this.pos[0],
      this.pos[1] - squareLength,
      squareLength,
      squareLength
    );
  }
  /**
   * Returns the input slot at the given position. Uses full 20 height, and approximates the label length.
   * @param pos The graph co-ordinates to check
   * @returns The input slot at the given position if found, otherwise `undefined`.
   */
  getInputOnPos(pos) {
    return getNodeInputOnPos(this, pos[0], pos[1])?.input;
  }
  /**
   * Returns the output slot at the given position. Uses full 20x20 box for the slot.
   * @param pos The graph co-ordinates to check
   * @returns The output slot at the given position if found, otherwise `undefined`.
   */
  getOutputOnPos(pos) {
    return getNodeOutputOnPos(this, pos[0], pos[1])?.output;
  }
  /**
   * Returns the input or output slot at the given position.
   *
   * Tries {@link getNodeInputOnPos} first, then {@link getNodeOutputOnPos}.
   * @param pos The graph co-ordinates to check
   * @returns The input or output slot at the given position if found, otherwise `undefined`.
   */
  getSlotOnPos(pos) {
    if (!isPointInRect(pos, this.boundingRect)) return;
    return this.getInputOnPos(pos) ?? this.getOutputOnPos(pos);
  }
  /**
   * @deprecated Use {@link getSlotOnPos} instead.
   * checks if a point is inside a node slot, and returns info about which slot
   * @param x
   * @param y
   * @returns if found the object contains { input|output: slot object, slot: number, link_pos: [x,y] }
   */
  getSlotInPosition(x2, y2) {
    const { inputs, outputs } = this;
    if (inputs) {
      for (const [i2, input] of inputs.entries()) {
        const pos = this.getInputPos(i2);
        if (isInRectangle(x2, y2, pos[0] - 10, pos[1] - 10, 20, 20)) {
          return { input, slot: i2, link_pos: pos };
        }
      }
    }
    if (outputs) {
      for (const [i2, output] of outputs.entries()) {
        const pos = this.getOutputPos(i2);
        if (isInRectangle(x2, y2, pos[0] - 10, pos[1] - 10, 20, 20)) {
          return { output, slot: i2, link_pos: pos };
        }
      }
    }
    return null;
  }
  /**
   * Gets the widget on this node at the given co-ordinates.
   * @param canvasX X co-ordinate in graph space
   * @param canvasY Y co-ordinate in graph space
   * @returns The widget found, otherwise `null`
   */
  getWidgetOnPos(canvasX, canvasY, includeDisabled = false) {
    const { widgets, pos, size } = this;
    if (!widgets?.length) return null;
    const x2 = canvasX - pos[0];
    const y2 = canvasY - pos[1];
    const nodeWidth = size[0];
    for (const widget of widgets) {
      if (widget.disabled && !includeDisabled || widget.hidden || widget.advanced && !this.showAdvanced) {
        continue;
      }
      const h2 = widget.computedHeight ?? widget.computeSize?.(nodeWidth)[1] ?? LiteGraph.NODE_WIDGET_HEIGHT;
      const w2 = widget.width || nodeWidth;
      if (widget.last_y !== void 0 && isInRectangle(x2, y2, 6, widget.last_y, w2 - 12, h2)) {
        return widget;
      }
    }
    return null;
  }
  findInputSlot(name2, returnObj = false) {
    const { inputs } = this;
    if (!inputs) return -1;
    for (const [i2, input] of inputs.entries()) {
      if (name2 == input.name) {
        return !returnObj ? i2 : input;
      }
    }
    return -1;
  }
  findOutputSlot(name2, returnObj = false) {
    const { outputs } = this;
    if (!outputs) return -1;
    for (const [i2, output] of outputs.entries()) {
      if (name2 == output.name) {
        return !returnObj ? i2 : output;
      }
    }
    return -1;
  }
  findInputSlotFree(optsIn) {
    return this.#findFreeSlot(this.inputs, optsIn);
  }
  findOutputSlotFree(optsIn) {
    return this.#findFreeSlot(this.outputs, optsIn);
  }
  /**
   * Finds the next free slot
   * @param slots The slots to search, i.e. this.inputs or this.outputs
   */
  #findFreeSlot(slots, options22) {
    const defaults2 = {
      returnObj: false,
      typesNotAccepted: []
    };
    const opts = Object.assign(defaults2, options22 || {});
    const length = slots?.length;
    if (!(length > 0)) return -1;
    for (let i2 = 0; i2 < length; ++i2) {
      const slot = slots[i2];
      if (!slot || slot.link || slot.links?.length) continue;
      if (opts.typesNotAccepted?.includes?.(slot.type)) continue;
      return !opts.returnObj ? i2 : slot;
    }
    return -1;
  }
  findInputSlotByType(type, returnObj, preferFreeSlot, doNotUseOccupied) {
    return this.#findSlotByType(
      this.inputs,
      type,
      returnObj,
      preferFreeSlot,
      doNotUseOccupied
    );
  }
  findOutputSlotByType(type, returnObj, preferFreeSlot, doNotUseOccupied) {
    return this.#findSlotByType(
      this.outputs,
      type,
      returnObj,
      preferFreeSlot,
      doNotUseOccupied
    );
  }
  findSlotByType(input, type, returnObj, preferFreeSlot, doNotUseOccupied) {
    return input ? this.#findSlotByType(
      this.inputs,
      type,
      returnObj,
      preferFreeSlot,
      doNotUseOccupied
    ) : this.#findSlotByType(
      this.outputs,
      type,
      returnObj,
      preferFreeSlot,
      doNotUseOccupied
    );
  }
  /**
   * Finds a matching slot from those provided, returning the slot itself or its index in {@link slots}.
   * @param slots Slots to search (this.inputs or this.outputs)
   * @param type Type of slot to look for
   * @param returnObj If true, returns the slot itself.  Otherwise, the index.
   * @param preferFreeSlot Prefer a free slot, but if none are found, fall back to an occupied slot.
   * @param doNotUseOccupied Do not fall back to occupied slots.
   * @see {findSlotByType}
   * @see {findOutputSlotByType}
   * @see {findInputSlotByType}
   * @returns If a match is found, the slot if returnObj is true, otherwise the index.  If no matches are found, -1
   */
  #findSlotByType(slots, type, returnObj, preferFreeSlot, doNotUseOccupied) {
    const length = slots?.length;
    if (!length) return -1;
    if (type == "" || type == "*") type = 0;
    const sourceTypes = String(type).toLowerCase().split(",");
    let occupiedSlot = null;
    for (let i2 = 0; i2 < length; ++i2) {
      const slot = slots[i2];
      const destTypes = slot.type == "0" || slot.type == "*" ? ["0"] : String(slot.type).toLowerCase().split(",");
      for (const sourceType of sourceTypes) {
        const source = sourceType == "_event_" ? LiteGraph.EVENT : sourceType;
        for (const destType of destTypes) {
          const dest = destType == "_event_" ? LiteGraph.EVENT : destType;
          if (source == dest || source === "*" || dest === "*") {
            if (preferFreeSlot && (slot.links?.length || slot.link != null)) {
              occupiedSlot ??= returnObj ? slot : i2;
              continue;
            }
            return returnObj ? slot : i2;
          }
        }
      }
    }
    return doNotUseOccupied ? -1 : occupiedSlot ?? -1;
  }
  /**
   * Determines the slot index to connect to when attempting to connect by type.
   * @param findInputs If true, searches for an input.  Otherwise, an output.
   * @param node The node at the other end of the connection.
   * @param slotType The type of slot at the other end of the connection.
   * @param options Search restrictions to adhere to.
   * @see {connectByType}
   * @see {connectByTypeOutput}
   */
  findConnectByTypeSlot(findInputs, node22, slotType, options22) {
    if (options22 && typeof options22 === "object") {
      if ("firstFreeIfInputGeneralInCase" in options22) options22.wildcardToTyped = !!options22.firstFreeIfInputGeneralInCase;
      if ("firstFreeIfOutputGeneralInCase" in options22) options22.wildcardToTyped = !!options22.firstFreeIfOutputGeneralInCase;
      if ("generalTypeInCase" in options22) options22.typedToWildcard = !!options22.generalTypeInCase;
    }
    const optsDef = {
      createEventInCase: true,
      wildcardToTyped: true,
      typedToWildcard: true
    };
    const opts = Object.assign(optsDef, options22);
    if (!this.graph) throw new NullGraphError();
    if (node22 && typeof node22 === "number") {
      const nodeById = this.graph.getNodeById(node22);
      if (!nodeById) return;
      node22 = nodeById;
    }
    const slot = node22.findSlotByType(findInputs, slotType, false, true);
    if (slot >= 0 && slot !== null) return slot;
    if (opts.createEventInCase && slotType == LiteGraph.EVENT) {
      if (findInputs) return -1;
      if (LiteGraph.do_add_triggers_slots) return node22.addOnExecutedOutput();
    }
    if (opts.typedToWildcard) {
      const generalSlot = node22.findSlotByType(findInputs, 0, false, true, true);
      if (generalSlot >= 0) return generalSlot;
    }
    if (opts.wildcardToTyped && (slotType == 0 || slotType == "*" || slotType == "")) {
      const opt = { typesNotAccepted: [LiteGraph.EVENT] };
      const nonEventSlot = findInputs ? node22.findInputSlotFree(opt) : node22.findOutputSlotFree(opt);
      if (nonEventSlot >= 0) return nonEventSlot;
    }
  }
  /**
   * Finds the first free output slot with any of the comma-delimited types in {@link type}.
   *
   * If no slots are free, falls back in order to:
   * - The first free wildcard slot
   * - The first occupied slot
   * - The first occupied wildcard slot
   * @param type The {@link ISlotType type} of slot to find
   * @returns The index and slot if found, otherwise `undefined`.
   */
  findOutputByType(type) {
    return findFreeSlotOfType(this.outputs, type);
  }
  /**
   * Finds the first free input slot with any of the comma-delimited types in {@link type}.
   *
   * If no slots are free, falls back in order to:
   * - The first free wildcard slot
   * - The first occupied slot
   * - The first occupied wildcard slot
   * @param type The {@link ISlotType type} of slot to find
   * @returns The index and slot if found, otherwise `undefined`.
   */
  findInputByType(type) {
    return findFreeSlotOfType(this.inputs, type);
  }
  /**
   * connect this node output to the input of another node BY TYPE
   * @param slot (could be the number of the slot or the string with the name of the slot)
   * @param target_node the target node
   * @param target_slotType the input slot type of the target node
   * @returns the link_info is created, otherwise null
   */
  connectByType(slot, target_node, target_slotType, optsIn) {
    const slotIndex = this.findConnectByTypeSlot(
      true,
      target_node,
      target_slotType,
      optsIn
    );
    if (slotIndex !== void 0)
      return this.connect(slot, target_node, slotIndex, optsIn?.afterRerouteId);
    console.debug("[connectByType]: no way to connect type:", target_slotType, "to node:", target_node);
    return null;
  }
  /**
   * connect this node input to the output of another node BY TYPE
   * @param slot (could be the number of the slot or the string with the name of the slot)
   * @param source_node the target node
   * @param source_slotType the output slot type of the target node
   * @returns the link_info is created, otherwise null
   */
  connectByTypeOutput(slot, source_node, source_slotType, optsIn) {
    if (typeof optsIn === "object") {
      if ("firstFreeIfInputGeneralInCase" in optsIn) optsIn.wildcardToTyped = !!optsIn.firstFreeIfInputGeneralInCase;
      if ("generalTypeInCase" in optsIn) optsIn.typedToWildcard = !!optsIn.generalTypeInCase;
    }
    const slotIndex = this.findConnectByTypeSlot(
      false,
      source_node,
      source_slotType,
      optsIn
    );
    if (slotIndex !== void 0)
      return source_node.connect(slotIndex, this, slot, optsIn?.afterRerouteId);
    console.debug("[connectByType]: no way to connect type:", source_slotType, "to node:", source_node);
    return null;
  }
  /**
   * Connect an output of this node to an input of another node
   * @param slot (could be the number of the slot or the string with the name of the slot)
   * @param target_node the target node
   * @param target_slot the input slot of the target node (could be the number of the slot or the string with the name of the slot, or -1 to connect a trigger)
   * @returns the link_info is created, otherwise null
   */
  connect(slot, target_node, target_slot, afterRerouteId) {
    let targetIndex;
    const { graph, outputs } = this;
    if (!graph) {
      console.log("Connect: Error, node doesn't belong to any graph. Nodes must be added first to a graph before connecting them.");
      return null;
    }
    if (typeof slot === "string") {
      slot = this.findOutputSlot(slot);
      if (slot == -1) {
        if (LiteGraph.debug) console.log(`Connect: Error, no slot of name ${slot}`);
        return null;
      }
    } else if (!outputs || slot >= outputs.length) {
      if (LiteGraph.debug) console.log("Connect: Error, slot number not found");
      return null;
    }
    if (target_node && typeof target_node === "number") {
      const nodeById = graph.getNodeById(target_node);
      if (!nodeById) throw "target node is null";
      target_node = nodeById;
    }
    if (!target_node) throw "target node is null";
    if (target_node == this) return null;
    if (typeof target_slot === "string") {
      targetIndex = target_node.findInputSlot(target_slot);
      if (targetIndex == -1) {
        if (LiteGraph.debug) console.log(`Connect: Error, no slot of name ${targetIndex}`);
        return null;
      }
    } else if (target_slot === LiteGraph.EVENT) {
      if (LiteGraph.do_add_triggers_slots) {
        target_node.changeMode(LGraphEventMode.ON_TRIGGER);
        targetIndex = target_node.findInputSlot("onTrigger");
      } else {
        return null;
      }
    } else if (typeof target_slot === "number") {
      targetIndex = target_slot;
    } else {
      targetIndex = 0;
    }
    if (target_node.onBeforeConnectInput) {
      const requestedIndex = target_node.onBeforeConnectInput(targetIndex, target_slot);
      targetIndex = typeof requestedIndex === "number" ? requestedIndex : null;
    }
    if (targetIndex === null || !target_node.inputs || targetIndex >= target_node.inputs.length) {
      if (LiteGraph.debug) console.log("Connect: Error, slot number not found");
      return null;
    }
    const input = target_node.inputs[targetIndex];
    const output = outputs[slot];
    if (!output) return null;
    if (output.links?.length) {
      if (output.type === LiteGraph.EVENT && !LiteGraph.allow_multi_output_for_events) {
        graph.beforeChange();
        this.disconnectOutput(slot, false, { doProcessChange: false });
      }
    }
    const link2 = this.connectSlots(output, target_node, input, afterRerouteId);
    return link2 ?? null;
  }
  /**
   * Connect two slots between two nodes
   * @param output The output slot to connect
   * @param inputNode The node that the input slot is on
   * @param input The input slot to connect
   * @param afterRerouteId The reroute ID to use for the link
   * @returns The link that was created, or null if the connection was blocked
   */
  connectSlots(output, inputNode, input, afterRerouteId) {
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    const outputIndex = this.outputs.indexOf(output);
    if (outputIndex === -1) {
      console.warn("connectSlots: output not found");
      return;
    }
    const inputIndex = inputNode.inputs.indexOf(input);
    if (inputIndex === -1) {
      console.warn("connectSlots: input not found");
      return;
    }
    if (!LiteGraph.isValidConnection(output.type, input.type)) {
      this.setDirtyCanvas(false, true);
      return null;
    }
    if (inputNode.onConnectInput?.(inputIndex, output.type, output, this, outputIndex) === false)
      return null;
    if (this.onConnectOutput?.(outputIndex, input.type, input, inputNode, inputIndex) === false)
      return null;
    if (inputNode.inputs[inputIndex]?.link != null) {
      graph.beforeChange();
      inputNode.disconnectInput(inputIndex, true);
    }
    const link2 = new LLink(
      ++graph.state.lastLinkId,
      input.type || output.type,
      this.id,
      outputIndex,
      inputNode.id,
      inputIndex,
      afterRerouteId
    );
    graph._links.set(link2.id, link2);
    output.links ??= [];
    output.links.push(link2.id);
    inputNode.inputs[inputIndex].link = link2.id;
    const reroutes = LLink.getReroutes(graph, link2);
    for (const reroute of reroutes) {
      reroute.linkIds.add(link2.id);
      if (reroute.floating) delete reroute.floating;
      reroute._dragging = void 0;
    }
    const lastReroute = reroutes.at(-1);
    if (lastReroute) {
      for (const linkId of lastReroute.floatingLinkIds) {
        const link22 = graph.floatingLinks.get(linkId);
        if (link22?.parentId === lastReroute.id) {
          graph.removeFloatingLink(link22);
        }
      }
    }
    graph._version++;
    this.onConnectionsChange?.(
      NodeSlotType.OUTPUT,
      outputIndex,
      true,
      link2,
      output
    );
    inputNode.onConnectionsChange?.(
      NodeSlotType.INPUT,
      inputIndex,
      true,
      link2,
      input
    );
    this.setDirtyCanvas(false, true);
    graph.afterChange();
    graph.connectionChange(this);
    return link2;
  }
  /**
   * disconnect one output to an specific node
   * @param slot (could be the number of the slot or the string with the name of the slot)
   * @param target_node the target node to which this slot is connected [Optional,
   * if not target_node is specified all nodes will be disconnected]
   * @returns if it was disconnected successfully
   */
  disconnectOutput(slot, target_node) {
    if (typeof slot === "string") {
      slot = this.findOutputSlot(slot);
      if (slot == -1) {
        if (LiteGraph.debug) console.log(`Connect: Error, no slot of name ${slot}`);
        return false;
      }
    } else if (!this.outputs || slot >= this.outputs.length) {
      if (LiteGraph.debug) console.log("Connect: Error, slot number not found");
      return false;
    }
    for (const link2 of this.graph?.floatingLinks.values() ?? []) {
      if (link2.origin_id === this.id && link2.origin_slot === slot) {
        this.graph?.removeFloatingLink(link2);
      }
    }
    const output = this.outputs[slot];
    if (!output || !output.links || output.links.length == 0) return false;
    const { links } = output;
    const graph = this.graph;
    if (!graph) throw new NullGraphError();
    if (target_node) {
      const target2 = typeof target_node === "number" ? graph.getNodeById(target_node) : target_node;
      if (!target2) throw "Target Node not found";
      for (const [i2, link_id] of links.entries()) {
        const link_info = graph._links.get(link_id);
        if (link_info?.target_id == target2.id) {
          links.splice(i2, 1);
          const input = target2.inputs[link_info.target_slot];
          input.link = null;
          link_info.disconnect(graph, "input");
          graph._version++;
          target2.onConnectionsChange?.(
            NodeSlotType.INPUT,
            link_info.target_slot,
            false,
            link_info,
            input
          );
          this.onConnectionsChange?.(
            NodeSlotType.OUTPUT,
            slot,
            false,
            link_info,
            output
          );
          break;
        }
      }
    } else {
      for (const link_id of links) {
        const link_info = graph._links.get(link_id);
        if (!link_info) continue;
        const target2 = graph.getNodeById(link_info.target_id);
        graph._version++;
        if (target2) {
          const input = target2.inputs[link_info.target_slot];
          input.link = null;
          target2.onConnectionsChange?.(
            NodeSlotType.INPUT,
            link_info.target_slot,
            false,
            link_info,
            input
          );
        }
        link_info.disconnect(graph, "input");
        this.onConnectionsChange?.(
          NodeSlotType.OUTPUT,
          slot,
          false,
          link_info,
          output
        );
      }
      output.links = null;
    }
    this.setDirtyCanvas(false, true);
    graph.connectionChange(this);
    return true;
  }
  /**
   * Disconnect one input
   * @param slot Input slot index, or the name of the slot
   * @param keepReroutes If `true`, reroutes will not be garbage collected.
   * @returns true if disconnected successfully or already disconnected, otherwise false
   */
  disconnectInput(slot, keepReroutes) {
    if (typeof slot === "string") {
      slot = this.findInputSlot(slot);
      if (slot == -1) {
        if (LiteGraph.debug) console.log(`Connect: Error, no slot of name ${slot}`);
        return false;
      }
    } else if (!this.inputs || slot >= this.inputs.length) {
      if (LiteGraph.debug) {
        console.log("Connect: Error, slot number not found");
      }
      return false;
    }
    const input = this.inputs[slot];
    if (!input) return false;
    const link_id = this.inputs[slot].link;
    if (link_id != null) {
      this.inputs[slot].link = null;
      if (!this.graph) throw new NullGraphError();
      const link_info = this.graph._links.get(link_id);
      if (link_info) {
        const target_node = this.graph.getNodeById(link_info.origin_id);
        if (!target_node) return false;
        const output = target_node.outputs[link_info.origin_slot];
        if (!output?.links?.length) return false;
        let i2 = 0;
        for (const l2 = output.links.length; i2 < l2; i2++) {
          if (output.links[i2] == link_id) {
            output.links.splice(i2, 1);
            break;
          }
        }
        link_info.disconnect(this.graph, keepReroutes ? "output" : void 0);
        if (this.graph) this.graph._version++;
        this.onConnectionsChange?.(
          NodeSlotType.INPUT,
          slot,
          false,
          link_info,
          input
        );
        target_node.onConnectionsChange?.(
          NodeSlotType.OUTPUT,
          i2,
          false,
          link_info,
          output
        );
      }
    }
    this.setDirtyCanvas(false, true);
    this.graph?.connectionChange(this);
    return true;
  }
  /**
   * @deprecated Use {@link getInputPos} or {@link getOutputPos} instead.
   * returns the center of a connection point in canvas coords
   * @param is_input true if if a input slot, false if it is an output
   * @param slot_number (could be the number of the slot or the string with the name of the slot)
   * @param out [optional] a place to store the output, to free garbage
   * @returns the position
   */
  getConnectionPos(is_input, slot_number, out) {
    out ||= new Float32Array(2);
    const { pos: [nodeX, nodeY], inputs, outputs } = this;
    if (this.flags.collapsed) {
      const w2 = this._collapsed_width || LiteGraph.NODE_COLLAPSED_WIDTH;
      out[0] = is_input ? nodeX : nodeX + w2;
      out[1] = nodeY - LiteGraph.NODE_TITLE_HEIGHT * 0.5;
      return out;
    }
    if (is_input && slot_number == -1) {
      out[0] = nodeX + LiteGraph.NODE_TITLE_HEIGHT * 0.5;
      out[1] = nodeY + LiteGraph.NODE_TITLE_HEIGHT * 0.5;
      return out;
    }
    const inputPos = inputs?.[slot_number]?.pos;
    const outputPos = outputs?.[slot_number]?.pos;
    if (is_input && inputPos) {
      out[0] = nodeX + inputPos[0];
      out[1] = nodeY + inputPos[1];
      return out;
    } else if (!is_input && outputPos) {
      out[0] = nodeX + outputPos[0];
      out[1] = nodeY + outputPos[1];
      return out;
    }
    const offset = LiteGraph.NODE_SLOT_HEIGHT * 0.5;
    out[0] = is_input ? nodeX + offset : nodeX + this.size[0] + 1 - offset;
    out[1] = nodeY + (slot_number + 0.7) * LiteGraph.NODE_SLOT_HEIGHT + (this.constructor.slot_start_y || 0);
    return out;
  }
  /**
   * Gets the position of an input slot, in graph co-ordinates.
   *
   * This method is preferred over the legacy {@link getConnectionPos} method.
   * @param slot Input slot index
   * @returns Position of the input slot
   */
  getInputPos(slot) {
    const { pos: [nodeX, nodeY], inputs } = this;
    if (this.flags.collapsed) {
      const halfTitle = LiteGraph.NODE_TITLE_HEIGHT * 0.5;
      return [nodeX, nodeY - halfTitle];
    }
    const inputPos = inputs?.[slot]?.pos;
    if (inputPos) return [nodeX + inputPos[0], nodeY + inputPos[1]];
    const offsetX = LiteGraph.NODE_SLOT_HEIGHT * 0.5;
    const nodeOffsetY = this.constructor.slot_start_y || 0;
    const slotY = (slot + 0.7) * LiteGraph.NODE_SLOT_HEIGHT;
    return [nodeX + offsetX, nodeY + slotY + nodeOffsetY];
  }
  /**
   * Gets the position of an output slot, in graph co-ordinates.
   *
   * This method is preferred over the legacy {@link getConnectionPos} method.
   * @param slot Output slot index
   * @returns Position of the output slot
   */
  getOutputPos(slot) {
    const { pos: [nodeX, nodeY], outputs, size: [width2] } = this;
    if (this.flags.collapsed) {
      const width22 = this._collapsed_width || LiteGraph.NODE_COLLAPSED_WIDTH;
      const halfTitle = LiteGraph.NODE_TITLE_HEIGHT * 0.5;
      return [nodeX + width22, nodeY - halfTitle];
    }
    const outputPos = outputs?.[slot]?.pos;
    if (outputPos) return outputPos;
    const offsetX = LiteGraph.NODE_SLOT_HEIGHT * 0.5;
    const nodeOffsetY = this.constructor.slot_start_y || 0;
    const slotY = (slot + 0.7) * LiteGraph.NODE_SLOT_HEIGHT;
    return [nodeX + width2 + 1 - offsetX, nodeY + slotY + nodeOffsetY];
  }
  /** @inheritdoc */
  snapToGrid(snapTo) {
    return this.pinned ? false : snapPoint(this.pos, snapTo);
  }
  /** @see {@link snapToGrid} */
  alignToGrid() {
    this.snapToGrid(LiteGraph.CANVAS_GRID_SIZE);
  }
  /* Console output */
  trace(msg) {
    this.console ||= [];
    this.console.push(msg);
    if (this.console.length > LGraphNode.MAX_CONSOLE)
      this.console.shift();
  }
  /* Forces to redraw or the main canvas (LGraphNode) or the bg canvas (links) */
  setDirtyCanvas(dirty_foreground, dirty_background) {
    this.graph?.canvasAction((c2) => c2.setDirty(dirty_foreground, dirty_background));
  }
  loadImage(url) {
    const img = new Image();
    img.src = LiteGraph.node_images_path + url;
    img.ready = false;
    const dirty = /* @__PURE__ */ __name(() => this.setDirtyCanvas(true), "dirty");
    img.addEventListener("load", function() {
      this.ready = true;
      dirty();
    });
    return img;
  }
  /* Allows to get onMouseMove and onMouseUp events even if the mouse is out of focus */
  captureInput(v2) {
    if (!this.graph || !this.graph.list_of_graphcanvas) return;
    const list2 = this.graph.list_of_graphcanvas;
    for (const c2 of list2) {
      if (!v2 && c2.node_capturing_input != this) continue;
      c2.node_capturing_input = v2 ? this : null;
    }
  }
  get collapsed() {
    return !!this.flags.collapsed;
  }
  get collapsible() {
    return !this.pinned && this.constructor.collapsable !== false;
  }
  /**
   * Toggle node collapse (makes it smaller on the canvas)
   */
  collapse(force) {
    if (!this.collapsible && !force) return;
    if (!this.graph) throw new NullGraphError();
    this.graph._version++;
    this.flags.collapsed = !this.flags.collapsed;
    this.setDirtyCanvas(true, true);
  }
  /**
   * Toggles advanced mode of the node, showing advanced widgets
   */
  toggleAdvanced() {
    if (!this.widgets?.some((w2) => w2.advanced)) return;
    if (!this.graph) throw new NullGraphError();
    this.graph._version++;
    this.showAdvanced = !this.showAdvanced;
    this.expandToFitContent();
    this.setDirtyCanvas(true, true);
  }
  get pinned() {
    return !!this.flags.pinned;
  }
  /**
   * Prevents the node being accidentally moved or resized by mouse interaction.
   * Toggles pinned state if no value is provided.
   */
  pin(v2) {
    if (!this.graph) throw new NullGraphError();
    this.graph._version++;
    this.flags.pinned = v2 ?? !this.flags.pinned;
    this.resizable = !this.pinned;
    if (!this.pinned) delete this.flags.pinned;
  }
  unpin() {
    this.pin(false);
  }
  localToScreen(x2, y2, dragAndScale) {
    return [
      (x2 + this.pos[0]) * dragAndScale.scale + dragAndScale.offset[0],
      (y2 + this.pos[1]) * dragAndScale.scale + dragAndScale.offset[1]
    ];
  }
  get width() {
    return this.collapsed ? this._collapsed_width || LiteGraph.NODE_COLLAPSED_WIDTH : this.size[0];
  }
  /**
   * Returns the height of the node, including the title bar.
   */
  get height() {
    return LiteGraph.NODE_TITLE_HEIGHT + this.bodyHeight;
  }
  /**
   * Returns the height of the node, excluding the title bar.
   */
  get bodyHeight() {
    return this.collapsed ? 0 : this.size[1];
  }
  drawBadges(ctx, { gap = 2 } = {}) {
    const badgeInstances = this.badges.map((badge) => badge instanceof LGraphBadge ? badge : badge());
    const isLeftAligned = this.badgePosition === BadgePosition.TopLeft;
    let currentX = isLeftAligned ? 0 : this.width - badgeInstances.reduce((acc, badge) => acc + badge.getWidth(ctx) + gap, 0);
    const y2 = -(LiteGraph.NODE_TITLE_HEIGHT + gap);
    for (const badge of badgeInstances) {
      badge.draw(ctx, currentX, y2 - badge.height);
      currentX += badge.getWidth(ctx) + gap;
    }
  }
  /**
   * Renders the node's title bar background
   */
  drawTitleBarBackground(ctx, options22) {
    const {
      scale,
      title_height = LiteGraph.NODE_TITLE_HEIGHT,
      low_quality = false
    } = options22;
    const fgcolor = this.renderingColor;
    const shape = this.renderingShape;
    const size = this.renderingSize;
    if (this.onDrawTitleBar) {
      this.onDrawTitleBar(ctx, title_height, size, scale, fgcolor);
      return;
    }
    if (this.title_mode === TitleMode.TRANSPARENT_TITLE) {
      return;
    }
    if (this.collapsed) {
      ctx.shadowColor = LiteGraph.DEFAULT_SHADOW_COLOR;
    }
    ctx.fillStyle = this.constructor.title_color || fgcolor;
    ctx.beginPath();
    if (shape == RenderShape.BOX || low_quality) {
      ctx.rect(0, -title_height, size[0], title_height);
    } else if (shape == RenderShape.ROUND || shape == RenderShape.CARD) {
      ctx.roundRect(
        0,
        -title_height,
        size[0],
        title_height,
        this.collapsed ? [LiteGraph.ROUND_RADIUS] : [LiteGraph.ROUND_RADIUS, LiteGraph.ROUND_RADIUS, 0, 0]
      );
    }
    ctx.fill();
    ctx.shadowColor = "transparent";
  }
  /**
   * Renders the node's title box, i.e. the dot in front of the title text that
   * when clicked toggles the node's collapsed state. The term `title box` comes
   * from the original LiteGraph implementation.
   */
  drawTitleBox(ctx, options22) {
    const {
      scale,
      low_quality = false,
      title_height = LiteGraph.NODE_TITLE_HEIGHT,
      box_size = 10
    } = options22;
    const size = this.renderingSize;
    const shape = this.renderingShape;
    if (this.onDrawTitleBox) {
      this.onDrawTitleBox(ctx, title_height, size, scale);
      return;
    }
    if ([RenderShape.ROUND, RenderShape.CIRCLE, RenderShape.CARD].includes(shape)) {
      if (low_quality) {
        ctx.fillStyle = "black";
        ctx.beginPath();
        ctx.arc(
          title_height * 0.5,
          title_height * -0.5,
          box_size * 0.5 + 1,
          0,
          Math.PI * 2
        );
        ctx.fill();
      }
      ctx.fillStyle = this.renderingBoxColor;
      if (low_quality) {
        ctx.fillRect(
          title_height * 0.5 - box_size * 0.5,
          title_height * -0.5 - box_size * 0.5,
          box_size,
          box_size
        );
      } else {
        ctx.beginPath();
        ctx.arc(
          title_height * 0.5,
          title_height * -0.5,
          box_size * 0.5,
          0,
          Math.PI * 2
        );
        ctx.fill();
      }
    } else {
      if (low_quality) {
        ctx.fillStyle = "black";
        ctx.fillRect(
          (title_height - box_size) * 0.5 - 1,
          (title_height + box_size) * -0.5 - 1,
          box_size + 2,
          box_size + 2
        );
      }
      ctx.fillStyle = this.renderingBoxColor;
      ctx.fillRect(
        (title_height - box_size) * 0.5,
        (title_height + box_size) * -0.5,
        box_size,
        box_size
      );
    }
  }
  /**
   * Renders the node's title text.
   */
  drawTitleText(ctx, options22) {
    const {
      scale,
      default_title_color,
      low_quality = false,
      title_height = LiteGraph.NODE_TITLE_HEIGHT
    } = options22;
    const size = this.renderingSize;
    const selected2 = this.selected;
    if (this.onDrawTitleText) {
      this.onDrawTitleText(
        ctx,
        title_height,
        size,
        scale,
        this.titleFontStyle,
        selected2
      );
      return;
    }
    if (low_quality) {
      return;
    }
    ctx.font = this.titleFontStyle;
    const rawTitle = this.getTitle() ?? `❌ ${this.type}`;
    const title = String(rawTitle) + (this.pinned ? "📌" : "");
    if (title) {
      if (selected2) {
        ctx.fillStyle = LiteGraph.NODE_SELECTED_TITLE_COLOR;
      } else {
        ctx.fillStyle = this.constructor.title_text_color || default_title_color;
      }
      if (this.collapsed) {
        ctx.textAlign = "left";
        ctx.fillText(
          // avoid urls too long
          title.substr(0, 20),
          title_height,
          LiteGraph.NODE_TITLE_TEXT_Y - title_height
        );
        ctx.textAlign = "left";
      } else {
        ctx.textAlign = "left";
        ctx.fillText(
          title,
          title_height,
          LiteGraph.NODE_TITLE_TEXT_Y - title_height
        );
      }
    }
  }
  /**
   * Attempts to gracefully bypass this node in all of its connections by reconnecting all links.
   *
   * Each input is checked against each output.  This is done on a matching index basis, i.e. input 3 -> output 3.
   * If there are any input links remaining,
   * and {@link flags}.{@link INodeFlags.keepAllLinksOnBypass keepAllLinksOnBypass} is `true`,
   * each input will check for outputs that match, and take the first one that matches
   * `true`: Try the index matching first, then every input to every output.
   * `false`: Only matches indexes, e.g. input 3 to output 3.
   *
   * If {@link flags}.{@link INodeFlags.keepAllLinksOnBypass keepAllLinksOnBypass} is `undefined`, it will fall back to
   * the static {@link keepAllLinksOnBypass}.
   * @returns `true` if any new links were established, otherwise `false`.
   * @todo Decision: Change API to return array of new links instead?
   */
  connectInputToOutput() {
    const { inputs, outputs, graph } = this;
    if (!inputs || !outputs) return;
    if (!graph) throw new NullGraphError();
    const { _links } = graph;
    let madeAnyConnections = false;
    for (const [index2, input] of inputs.entries()) {
      if (input.link == null) continue;
      const output = outputs[index2];
      if (!output || !LiteGraph.isValidConnection(input.type, output.type)) continue;
      const inLink = _links.get(input.link);
      if (!inLink) continue;
      const inNode = graph.getNodeById(inLink?.origin_id);
      if (!inNode) continue;
      bypassAllLinks(output, inNode, inLink, graph);
    }
    if (!(this.flags.keepAllLinksOnBypass ?? LGraphNode.keepAllLinksOnBypass))
      return madeAnyConnections;
    for (const input of inputs) {
      if (input.link == null) continue;
      const inLink = _links.get(input.link);
      if (!inLink) continue;
      const inNode = graph.getNodeById(inLink?.origin_id);
      if (!inNode) continue;
      for (const output of outputs) {
        if (!LiteGraph.isValidConnection(input.type, output.type)) continue;
        bypassAllLinks(output, inNode, inLink, graph);
        break;
      }
    }
    return madeAnyConnections;
    function bypassAllLinks(output, inNode, inLink, graph2) {
      const outLinks = output.links?.map((x2) => _links.get(x2)).filter((x2) => !!x2);
      if (!outLinks?.length) return;
      for (const outLink of outLinks) {
        const outNode = graph2.getNodeById(outLink.target_id);
        if (!outNode) return;
        const result = inNode.connect(
          inLink.origin_slot,
          outNode,
          outLink.target_slot,
          inLink.parentId
        );
        madeAnyConnections ||= !!result;
      }
    }
    __name(bypassAllLinks, "bypassAllLinks");
  }
  drawWidgets(ctx, options22) {
    if (!this.widgets) return;
    const { colorContext, linkOverWidget, linkOverWidgetType, lowQuality = false, editorAlpha = 1 } = options22;
    const width2 = this.size[0];
    const widgets = this.widgets;
    const H = LiteGraph.NODE_WIDGET_HEIGHT;
    const show_text = !lowQuality;
    ctx.save();
    ctx.globalAlpha = editorAlpha;
    const margin = 15;
    for (const w2 of widgets) {
      if (w2.hidden || w2.advanced && !this.showAdvanced) continue;
      const y2 = w2.y;
      const outline_color = w2.advanced ? LiteGraph.WIDGET_ADVANCED_OUTLINE_COLOR : LiteGraph.WIDGET_OUTLINE_COLOR;
      if (w2 === linkOverWidget) {
        new NodeInputSlot({
          name: "",
          // @ts-expect-error https://github.com/Comfy-Org/litegraph.js/issues/616
          type: linkOverWidgetType,
          link: 0
        }).draw(ctx, { pos: [10, y2 + 10], colorContext });
      }
      w2.last_y = y2;
      ctx.strokeStyle = outline_color;
      ctx.fillStyle = "#222";
      ctx.textAlign = "left";
      if (w2.disabled) ctx.globalAlpha *= 0.5;
      const widget_width = w2.width || width2;
      const WidgetClass = WIDGET_TYPE_MAP[w2.type];
      if (WidgetClass) {
        toClass(WidgetClass, w2).drawWidget(ctx, { y: y2, width: widget_width, show_text, margin });
      } else {
        w2.draw?.(ctx, this, widget_width, y2, H);
      }
      ctx.globalAlpha = editorAlpha;
    }
    ctx.restore();
  }
  /**
   * When {@link LGraphNode.collapsed} is `true`, this method draws the node's collapsed slots.
   */
  drawCollapsedSlots(ctx) {
    let input_slot = null;
    let output_slot = null;
    for (const slot of this.inputs ?? []) {
      if (slot.link == null) {
        continue;
      }
      input_slot = slot;
      break;
    }
    for (const slot of this.outputs ?? []) {
      if (!slot.links || !slot.links.length) {
        continue;
      }
      output_slot = slot;
      break;
    }
    if (input_slot) {
      const x2 = 0;
      const y2 = LiteGraph.NODE_TITLE_HEIGHT * -0.5;
      toClass(NodeInputSlot, input_slot).drawCollapsed(ctx, {
        pos: [x2, y2]
      });
    }
    if (output_slot) {
      const x2 = this._collapsed_width ?? LiteGraph.NODE_COLLAPSED_WIDTH;
      const y2 = LiteGraph.NODE_TITLE_HEIGHT * -0.5;
      toClass(NodeOutputSlot, output_slot).drawCollapsed(ctx, {
        pos: [x2, y2]
      });
    }
  }
  get highlightColor() {
    return LiteGraph.NODE_TEXT_HIGHLIGHT_COLOR ?? LiteGraph.NODE_SELECTED_TITLE_COLOR ?? LiteGraph.NODE_TEXT_COLOR;
  }
  get slots() {
    return [...this.inputs, ...this.outputs];
  }
  layoutSlot(slot, options22) {
    const { slotIndex } = options22;
    const isInput = isINodeInputSlot(slot);
    const pos = isInput ? this.getInputPos(slotIndex) : this.getOutputPos(slotIndex);
    slot._layoutElement = new LayoutElement({
      value: slot,
      boundingRect: [
        pos[0] - this.pos[0] - LiteGraph.NODE_SLOT_HEIGHT * 0.5,
        pos[1] - this.pos[1] - LiteGraph.NODE_SLOT_HEIGHT * 0.5,
        LiteGraph.NODE_SLOT_HEIGHT,
        LiteGraph.NODE_SLOT_HEIGHT
      ]
    });
  }
  layoutSlots() {
    const slots = [];
    for (const [i2, slot] of this.inputs.entries()) {
      if (this.widgets?.length && isWidgetInputSlot(slot)) continue;
      this.layoutSlot(slot, {
        slotIndex: i2
      });
      if (slot._layoutElement) {
        slots.push(slot._layoutElement);
      }
    }
    for (const [i2, slot] of this.outputs.entries()) {
      this.layoutSlot(slot, {
        slotIndex: i2
      });
      if (slot._layoutElement) {
        slots.push(slot._layoutElement);
      }
    }
    return slots.length ? createBounds(
      slots,
      /** padding= */
      0
    ) : null;
  }
  #getMouseOverSlot(slot) {
    const isInput = isINodeInputSlot(slot);
    const mouseOverId = this.mouseOver?.[isInput ? "inputId" : "outputId"] ?? -1;
    if (mouseOverId === -1) {
      return null;
    }
    return isInput ? this.inputs[mouseOverId] : this.outputs[mouseOverId];
  }
  #isMouseOverSlot(slot) {
    return this.#getMouseOverSlot(slot) === slot;
  }
  /**
   * Draws the node's input and output slots.
   */
  drawSlots(ctx, options22) {
    const { fromSlot, colorContext, editorAlpha, lowQuality } = options22;
    for (const slot of this.slots) {
      const layoutElement = slot._layoutElement;
      const slotInstance = toNodeSlotClass(slot);
      const isValid2 = !fromSlot || slotInstance.isValidTarget(fromSlot);
      const highlight = isValid2 && this.#isMouseOverSlot(slot);
      const labelColor = highlight ? this.highlightColor : LiteGraph.NODE_TEXT_COLOR;
      ctx.globalAlpha = isValid2 ? editorAlpha : 0.4 * editorAlpha;
      slotInstance.draw(ctx, {
        pos: layoutElement?.center ?? [0, 0],
        colorContext,
        labelColor,
        lowQuality,
        renderText: !lowQuality,
        highlight
      });
    }
  }
  /**
   * Lays out the node's widgets vertically.
   * Sets following properties on each widget:
   * -  {@link IBaseWidget.computedHeight}
   * -  {@link IBaseWidget.y}
   */
  layoutWidgets(options22) {
    if (!this.widgets || !this.widgets.length) return;
    const bodyHeight = this.bodyHeight;
    const widgetStartY = this.widgets_start_y ?? (this.widgets_up ? 0 : options22.widgetStartY) + 2;
    let freeSpace = bodyHeight - widgetStartY;
    let fixedWidgetHeight = 0;
    const growableWidgets = [];
    for (const w2 of this.widgets) {
      if (w2.computeSize) {
        const height = w2.computeSize()[1] + 4;
        w2.computedHeight = height;
        fixedWidgetHeight += height;
      } else if (w2.computeLayoutSize) {
        const { minHeight, maxHeight } = w2.computeLayoutSize(this);
        growableWidgets.push({
          minHeight,
          prefHeight: maxHeight,
          w: w2
        });
      } else {
        const height = LiteGraph.NODE_WIDGET_HEIGHT + 4;
        w2.computedHeight = height;
        fixedWidgetHeight += height;
      }
    }
    freeSpace -= fixedWidgetHeight;
    this.freeWidgetSpace = freeSpace;
    const spaceRequests = growableWidgets.map((d2) => ({
      minSize: d2.minHeight,
      maxSize: d2.prefHeight
    }));
    const allocations = distributeSpace(Math.max(0, freeSpace), spaceRequests);
    for (const [i2, d2] of growableWidgets.entries()) {
      d2.w.computedHeight = allocations[i2];
    }
    let y2 = widgetStartY;
    for (const w2 of this.widgets) {
      w2.y = y2;
      y2 += w2.computedHeight ?? 0;
    }
    if (!this.graph) throw new NullGraphError();
    if (y2 > bodyHeight) {
      this.setSize([this.size[0], y2]);
      this.graph.setDirtyCanvas(false, true);
    }
  }
  /**
   * Lays out the node's widget input slots.
   */
  layoutWidgetInputSlots() {
    if (!this.widgets) return;
    const slotByWidgetName = /* @__PURE__ */ new Map();
    for (const [i2, slot] of this.inputs.entries()) {
      if (!isWidgetInputSlot(slot)) continue;
      slotByWidgetName.set(slot.widget?.name, { ...slot, index: i2 });
    }
    if (!slotByWidgetName.size) return;
    for (const widget of this.widgets) {
      const slot = slotByWidgetName.get(widget.name);
      if (!slot) continue;
      const actualSlot = this.inputs[slot.index];
      const offset = LiteGraph.NODE_SLOT_HEIGHT * 0.5;
      actualSlot.pos = [offset, widget.y + offset];
      this.layoutSlot(actualSlot, { slotIndex: slot.index });
    }
  }
}
class LGraphGroup {
  static {
    __name(this, "LGraphGroup");
  }
  static minWidth = 140;
  static minHeight = 80;
  static resizeLength = 10;
  static padding = 4;
  static defaultColour = "#335";
  id;
  color;
  title;
  font;
  font_size = LiteGraph.DEFAULT_GROUP_FONT || 24;
  _bounding = new Float32Array([
    10,
    10,
    LGraphGroup.minWidth,
    LGraphGroup.minHeight
  ]);
  _pos = this._bounding.subarray(0, 2);
  _size = this._bounding.subarray(2, 4);
  /** @deprecated See {@link _children} */
  _nodes = [];
  _children = /* @__PURE__ */ new Set();
  graph;
  flags = {};
  selected;
  constructor(title, id4) {
    this.id = id4 ?? -1;
    this.title = title || "Group";
    this.color = LGraphCanvas.node_colors.pale_blue ? LGraphCanvas.node_colors.pale_blue.groupcolor : "#AAA";
  }
  /** @inheritdoc {@link IColorable.setColorOption} */
  setColorOption(colorOption) {
    if (colorOption == null) {
      delete this.color;
    } else {
      this.color = colorOption.groupcolor;
    }
  }
  /** @inheritdoc {@link IColorable.getColorOption} */
  getColorOption() {
    return Object.values(LGraphCanvas.node_colors).find(
      (colorOption) => colorOption.groupcolor === this.color
    ) ?? null;
  }
  /** Position of the group, as x,y co-ordinates in graph space */
  get pos() {
    return this._pos;
  }
  set pos(v2) {
    if (!v2 || v2.length < 2) return;
    this._pos[0] = v2[0];
    this._pos[1] = v2[1];
  }
  /** Size of the group, as width,height in graph units */
  get size() {
    return this._size;
  }
  set size(v2) {
    if (!v2 || v2.length < 2) return;
    this._size[0] = Math.max(LGraphGroup.minWidth, v2[0]);
    this._size[1] = Math.max(LGraphGroup.minHeight, v2[1]);
  }
  get boundingRect() {
    return this._bounding;
  }
  get nodes() {
    return this._nodes;
  }
  get titleHeight() {
    return this.font_size * 1.4;
  }
  get children() {
    return this._children;
  }
  get pinned() {
    return !!this.flags.pinned;
  }
  /**
   * Prevents the group being accidentally moved or resized by mouse interaction.
   * Toggles pinned state if no value is provided.
   */
  pin(value3) {
    const newState = value3 === void 0 ? !this.pinned : value3;
    if (newState) this.flags.pinned = true;
    else delete this.flags.pinned;
  }
  unpin() {
    this.pin(false);
  }
  configure(o2) {
    this.id = o2.id;
    this.title = o2.title;
    this._bounding.set(o2.bounding);
    this.color = o2.color;
    this.flags = o2.flags || this.flags;
    if (o2.font_size) this.font_size = o2.font_size;
  }
  serialize() {
    const b2 = this._bounding;
    return {
      id: this.id,
      title: this.title,
      bounding: [...b2],
      color: this.color,
      font_size: this.font_size,
      flags: this.flags
    };
  }
  /**
   * Draws the group on the canvas
   * @param graphCanvas
   * @param ctx
   */
  draw(graphCanvas, ctx) {
    const { padding, resizeLength, defaultColour } = LGraphGroup;
    const font_size = this.font_size || LiteGraph.DEFAULT_GROUP_FONT_SIZE;
    const [x2, y2] = this._pos;
    const [width2, height] = this._size;
    const color2 = this.color || defaultColour;
    ctx.globalAlpha = 0.25 * graphCanvas.editor_alpha;
    ctx.fillStyle = color2;
    ctx.strokeStyle = color2;
    ctx.beginPath();
    ctx.rect(x2 + 0.5, y2 + 0.5, width2, font_size * 1.4);
    ctx.fill();
    ctx.fillStyle = color2;
    ctx.strokeStyle = color2;
    ctx.beginPath();
    ctx.rect(x2 + 0.5, y2 + 0.5, width2, height);
    ctx.fill();
    ctx.globalAlpha = graphCanvas.editor_alpha;
    ctx.stroke();
    ctx.beginPath();
    ctx.moveTo(x2 + width2, y2 + height);
    ctx.lineTo(x2 + width2 - resizeLength, y2 + height);
    ctx.lineTo(x2 + width2, y2 + height - resizeLength);
    ctx.fill();
    ctx.font = `${font_size}px Arial`;
    ctx.textAlign = "left";
    ctx.fillText(this.title + (this.pinned ? "📌" : ""), x2 + padding, y2 + font_size);
    if (LiteGraph.highlight_selected_group && this.selected) {
      strokeShape(ctx, this._bounding, {
        title_height: this.titleHeight,
        padding
      });
    }
  }
  resize(width2, height) {
    if (this.pinned) return false;
    this._size[0] = Math.max(LGraphGroup.minWidth, width2);
    this._size[1] = Math.max(LGraphGroup.minHeight, height);
    return true;
  }
  move(deltaX, deltaY, skipChildren = false) {
    if (this.pinned) return;
    this._pos[0] += deltaX;
    this._pos[1] += deltaY;
    if (skipChildren === true) return;
    for (const item3 of this._children) {
      item3.move(deltaX, deltaY);
    }
  }
  /** @inheritdoc */
  snapToGrid(snapTo) {
    return this.pinned ? false : snapPoint(this.pos, snapTo);
  }
  recomputeInsideNodes() {
    if (!this.graph) throw new NullGraphError();
    const { nodes, reroutes, groups } = this.graph;
    const children = this._children;
    this._nodes.length = 0;
    children.clear();
    for (const node22 of nodes) {
      if (containsCentre(this._bounding, node22.boundingRect)) {
        this._nodes.push(node22);
        children.add(node22);
      }
    }
    for (const reroute of reroutes.values()) {
      if (isPointInRect(reroute.pos, this._bounding))
        children.add(reroute);
    }
    for (const group of groups) {
      if (containsRect(this._bounding, group._bounding))
        children.add(group);
    }
    groups.sort((a2, b2) => {
      if (a2 === this) {
        return children.has(b2) ? -1 : 0;
      } else if (b2 === this) {
        return children.has(a2) ? 1 : 0;
      } else {
        return 0;
      }
    });
  }
  /**
   * Resizes and moves the group to neatly fit all given {@link objects}.
   * @param objects All objects that should be inside the group
   * @param padding Value in graph units to add to all sides of the group.  Default: 10
   */
  resizeTo(objects, padding = 10) {
    const boundingBox = createBounds(objects, padding);
    if (boundingBox === null) return;
    this.pos[0] = boundingBox[0];
    this.pos[1] = boundingBox[1] - this.titleHeight;
    this.size[0] = boundingBox[2];
    this.size[1] = boundingBox[3] + this.titleHeight;
  }
  /**
   * Add nodes to the group and adjust the group's position and size accordingly
   * @param nodes The nodes to add to the group
   * @param padding The padding around the group
   */
  addNodes(nodes, padding = 10) {
    if (!this._nodes && nodes.length === 0) return;
    this.resizeTo([...this.children, ...this._nodes, ...nodes], padding);
  }
  getMenuOptions() {
    return [
      {
        content: this.pinned ? "Unpin" : "Pin",
        callback: /* @__PURE__ */ __name(() => {
          if (this.pinned) this.unpin();
          else this.pin();
          this.setDirtyCanvas(false, true);
        }, "callback")
      },
      null,
      { content: "Title", callback: LGraphCanvas.onShowPropertyEditor },
      {
        content: "Color",
        has_submenu: true,
        callback: LGraphCanvas.onMenuNodeColors
      },
      {
        content: "Font size",
        property: "font_size",
        type: "Number",
        callback: LGraphCanvas.onShowPropertyEditor
      },
      null,
      { content: "Remove", callback: LGraphCanvas.onMenuNodeRemove }
    ];
  }
  isPointInTitlebar(x2, y2) {
    const b2 = this.boundingRect;
    return isInRectangle(x2, y2, b2[0], b2[1], b2[2], this.titleHeight);
  }
  isInResize(x2, y2) {
    const b2 = this.boundingRect;
    const right = b2[0] + b2[2];
    const bottom = b2[1] + b2[3];
    return x2 < right && y2 < bottom && x2 - right + (y2 - bottom) > -LGraphGroup.resizeLength;
  }
  isPointInside = LGraphNode.prototype.isPointInside;
  setDirtyCanvas = LGraphNode.prototype.setDirtyCanvas;
}
class Reroute {
  static {
    __name(this, "Reroute");
  }
  /**
   * Initialises a new link reroute object.
   * @param id Unique identifier for this reroute
   * @param network The network of links this reroute belongs to.  Internally converted to a WeakRef.
   * @param pos Position in graph coordinates
   * @param linkIds Link IDs ({@link LLink.id}) of all links that use this reroute
   */
  constructor(id4, network, pos, parentId, linkIds, floatingLinkIds) {
    this.id = id4;
    this.#network = new WeakRef(network);
    this.parentId = parentId;
    if (pos) this.pos = pos;
    this.linkIds = new Set(linkIds);
    this.floatingLinkIds = new Set(floatingLinkIds);
  }
  static radius = 10;
  #malloc = new Float32Array(8);
  /** The network this reroute belongs to.  Contains all valid links and reroutes. */
  #network;
  #parentId;
  get parentId() {
    return this.#parentId;
  }
  /** Ignores attempts to create an infinite loop. @inheritdoc */
  set parentId(value3) {
    if (value3 === this.id) return;
    if (this.getReroutes() === null) return;
    this.#parentId = value3;
  }
  /** This property is only defined on the last reroute of a floating reroute chain (closest to input end). */
  floating;
  #pos = this.#malloc.subarray(0, 2);
  /** @inheritdoc */
  get pos() {
    return this.#pos;
  }
  set pos(value3) {
    if (!(value3?.length >= 2))
      throw new TypeError("Reroute.pos is an x,y point, and expects an indexable with at least two values.");
    this.#pos[0] = value3[0];
    this.#pos[1] = value3[1];
  }
  /** @inheritdoc */
  get boundingRect() {
    const { radius } = Reroute;
    const [x2, y2] = this.#pos;
    return [x2 - radius, y2 - radius, 2 * radius, 2 * radius];
  }
  /** @inheritdoc */
  selected;
  /** The ID ({@link LLink.id}) of every link using this reroute */
  linkIds;
  /** The ID ({@link LLink.id}) of every floating link using this reroute */
  floatingLinkIds;
  /** Cached cos */
  cos = 0;
  sin = 0;
  /** Bezier curve control point for the "target" (input) side of the link */
  controlPoint = this.#malloc.subarray(4, 6);
  /** @inheritdoc */
  path;
  /** @inheritdoc */
  _centreAngle;
  /** @inheritdoc */
  _pos = this.#malloc.subarray(6, 8);
  /** @inheritdoc */
  _dragging;
  /** Colour of the first link that rendered this reroute */
  _colour;
  /**
   * Used to ensure reroute angles are only executed once per frame.
   * @todo Calculate on change instead.
   */
  #lastRenderTime = -Infinity;
  get firstLink() {
    const linkId = this.linkIds.values().next().value;
    return linkId === void 0 ? void 0 : this.#network.deref()?.links.get(linkId);
  }
  get firstFloatingLink() {
    const linkId = this.floatingLinkIds.values().next().value;
    return linkId === void 0 ? void 0 : this.#network.deref()?.floatingLinks.get(linkId);
  }
  /** @inheritdoc */
  get origin_id() {
    return this.firstLink?.origin_id;
  }
  /** @inheritdoc */
  get origin_slot() {
    return this.firstLink?.origin_slot;
  }
  /**
   * Applies a new parentId to the reroute, and optinoally a new position and linkId.
   * Primarily used for deserialisation.
   * @param parentId The ID of the reroute prior to this reroute, or
   * `undefined` if it is the first reroute connected to a nodes output
   * @param pos The position of this reroute
   * @param linkIds All link IDs that pass through this reroute
   */
  update(parentId, pos, linkIds, floating) {
    this.parentId = parentId;
    if (pos) this.pos = pos;
    if (linkIds) this.linkIds = new Set(linkIds);
    this.floating = floating;
  }
  /**
   * Validates the linkIds this reroute has.  Removes broken links.
   * @param links Collection of valid links
   * @returns true if any links remain after validation
   */
  validateLinks(links, floatingLinks) {
    const { linkIds, floatingLinkIds } = this;
    for (const linkId of linkIds) {
      if (!links.get(linkId)) linkIds.delete(linkId);
    }
    for (const linkId of floatingLinkIds) {
      if (!floatingLinks.get(linkId)) floatingLinkIds.delete(linkId);
    }
    return linkIds.size > 0 || floatingLinkIds.size > 0;
  }
  /**
   * Retrieves an ordered array of all reroutes from the node output.
   * @param visited Internal.  A set of reroutes that this function
   * has already visited whilst recursing up the chain.
   * @returns An ordered array of all reroutes from the node output to this reroute, inclusive.
   * `null` if an infinite loop is detected.
   * `undefined` if the reroute chain or {@link LinkNetwork} are invalid.
   */
  getReroutes(visited = /* @__PURE__ */ new Set()) {
    if (this.#parentId === void 0) return [this];
    if (visited.has(this)) return null;
    visited.add(this);
    const parent = this.#network.deref()?.reroutes.get(this.#parentId);
    if (!parent) {
      this.#parentId = void 0;
      return [this];
    }
    const reroutes = parent.getReroutes(visited);
    reroutes?.push(this);
    return reroutes;
  }
  /**
   * Internal.  Called by {@link LLink.findNextReroute}.  Not intended for use by itself.
   * @param withParentId The rerouteId to look for
   * @param visited A set of reroutes that have already been visited
   * @returns The reroute that was found, `undefined` if no reroute was found, or `null` if an infinite loop was detected.
   */
  findNextReroute(withParentId, visited = /* @__PURE__ */ new Set()) {
    if (this.#parentId === withParentId) return this;
    if (visited.has(this)) return null;
    visited.add(this);
    if (this.#parentId === void 0) return;
    return this.#network.deref()?.reroutes.get(this.#parentId)?.findNextReroute(withParentId, visited);
  }
  findSourceOutput() {
    const network = this.#network.deref();
    if (!network) return;
    const link2 = this.firstLink ?? this.firstFloatingLink;
    if (!link2) return;
    const node22 = network.getNodeById(link2.origin_id);
    if (!node22) return;
    return {
      node: node22,
      output: node22.outputs[link2.origin_slot],
      outputIndex: link2.origin_slot,
      link: link2
    };
  }
  /**
   * Finds the first input slot for links or floating links passing through this reroute.
   */
  findTargetInputs() {
    const network = this.#network.deref();
    if (!network) return;
    const results = [];
    addAllResults(network, this.linkIds, network.links);
    addAllResults(network, this.floatingLinkIds, network.floatingLinks);
    return results;
    function addAllResults(network2, linkIds, links) {
      for (const linkId of linkIds) {
        const link2 = links.get(linkId);
        if (!link2) continue;
        const node22 = network2.getNodeById(link2.target_id);
        const input = node22?.inputs[link2.target_slot];
        if (!input) continue;
        results.push({ node: node22, input, inputIndex: link2.target_slot, link: link2 });
      }
    }
    __name(addAllResults, "addAllResults");
  }
  /** @inheritdoc */
  move(deltaX, deltaY) {
    this.#pos[0] += deltaX;
    this.#pos[1] += deltaY;
  }
  /** @inheritdoc */
  snapToGrid(snapTo) {
    if (!snapTo) return false;
    const { pos } = this;
    pos[0] = snapTo * Math.round(pos[0] / snapTo);
    pos[1] = snapTo * Math.round(pos[1] / snapTo);
    return true;
  }
  remove() {
    const network = this.#network.deref();
    if (!network) return;
    network.removeReroute(this.id);
  }
  calculateAngle(lastRenderTime, network, linkStart) {
    if (!(lastRenderTime > this.#lastRenderTime)) return;
    this.#lastRenderTime = lastRenderTime;
    const { links, floatingLinks } = network;
    const { id: id4, linkIds, floatingLinkIds, pos: thisPos } = this;
    const angles = [];
    let sum = 0;
    calculateLinks(linkIds, links);
    calculateLinks(floatingLinkIds, floatingLinks);
    if (!angles.length) {
      this.cos = 0;
      this.sin = 0;
      this.controlPoint[0] = 0;
      this.controlPoint[1] = 0;
      return;
    }
    sum /= angles.length;
    const originToReroute = Math.atan2(
      this.#pos[1] - linkStart[1],
      this.#pos[0] - linkStart[0]
    );
    let diff2 = (originToReroute - sum) * 0.5;
    if (Math.abs(diff2) > Math.PI * 0.5) diff2 += Math.PI;
    const dist3 = Math.min(80, distance(linkStart, this.#pos) * 0.25);
    const originDiff = originToReroute - diff2;
    const cos = Math.cos(originDiff);
    const sin = Math.sin(originDiff);
    this.cos = cos;
    this.sin = sin;
    this.controlPoint[0] = dist3 * -cos;
    this.controlPoint[1] = dist3 * -sin;
    function calculateLinks(linkIds2, links2) {
      for (const linkId of linkIds2) {
        const link2 = links2.get(linkId);
        const pos = getNextPos(network, link2, id4);
        if (!pos) continue;
        const angle = getDirection(thisPos, pos);
        angles.push(angle);
        sum += angle;
      }
    }
    __name(calculateLinks, "calculateLinks");
  }
  /**
   * Renders the reroute on the canvas.
   * @param ctx Canvas context to draw on
   * @remarks Leaves {@link ctx}.fillStyle, strokeStyle, and lineWidth dirty (perf.).
   */
  draw(ctx) {
    const { pos } = this;
    ctx.fillStyle = this._colour ?? "#18184d";
    ctx.beginPath();
    ctx.arc(pos[0], pos[1], Reroute.radius, 0, 2 * Math.PI);
    ctx.fill();
    ctx.lineWidth = Reroute.radius * 0.1;
    ctx.strokeStyle = "rgb(0,0,0,0.5)";
    ctx.stroke();
    ctx.fillStyle = "#ffffff55";
    ctx.strokeStyle = "rgb(0,0,0,0.3)";
    ctx.beginPath();
    ctx.arc(pos[0], pos[1], Reroute.radius * 0.8, 0, 2 * Math.PI);
    ctx.fill();
    ctx.stroke();
    if (this.selected) {
      ctx.strokeStyle = "#fff";
      ctx.beginPath();
      ctx.arc(pos[0], pos[1], Reroute.radius * 1.2, 0, 2 * Math.PI);
      ctx.stroke();
    }
  }
  /** @inheritdoc */
  asSerialisable() {
    const { id: id4, parentId, pos, linkIds } = this;
    return {
      id: id4,
      parentId,
      pos: [pos[0], pos[1]],
      linkIds: [...linkIds],
      floating: this.floating ? { slotType: this.floating.slotType } : void 0
    };
  }
}
function getNextPos(network, link2, id4) {
  if (!link2) return;
  const linkPos = LLink.findNextReroute(network, link2, id4)?.pos;
  if (linkPos) return linkPos;
  if (link2.target_id === -1 || link2.target_slot === -1) return;
  return network.getNodeById(link2.target_id)?.getInputPos(link2.target_slot);
}
__name(getNextPos, "getNextPos");
function getDirection(fromPos, toPos) {
  return Math.atan2(toPos[1] - fromPos[1], toPos[0] - fromPos[0]);
}
__name(getDirection, "getDirection");
function getBoundaryNodes(nodes) {
  const valid = nodes?.find((x2) => x2);
  if (!valid) return null;
  let top = valid;
  let right = valid;
  let bottom = valid;
  let left = valid;
  for (const node22 of nodes) {
    if (!node22) continue;
    const [x2, y2] = node22.pos;
    const [width2, height] = node22.size;
    if (y2 < top.pos[1]) top = node22;
    if (x2 + width2 > right.pos[0] + right.size[0]) right = node22;
    if (y2 + height > bottom.pos[1] + bottom.size[1]) bottom = node22;
    if (x2 < left.pos[0]) left = node22;
  }
  return {
    top,
    right,
    bottom,
    left
  };
}
__name(getBoundaryNodes, "getBoundaryNodes");
function distributeNodes(nodes, horizontal2) {
  const nodeCount = nodes?.length;
  if (!(nodeCount > 1)) return;
  const index2 = horizontal2 ? 0 : 1;
  let total = 0;
  let highest = -Infinity;
  for (const node22 of nodes) {
    total += node22.size[index2];
    const high = node22.pos[index2] + node22.size[index2];
    if (high > highest) highest = high;
  }
  const sorted = [...nodes].sort((a2, b2) => a2.pos[index2] - b2.pos[index2]);
  const lowest = sorted[0].pos[index2];
  const gap = (highest - lowest - total) / (nodeCount - 1);
  let startAt = lowest;
  for (let i2 = 0; i2 < nodeCount; i2++) {
    const node22 = sorted[i2];
    node22.pos[index2] = startAt + gap * i2;
    startAt += node22.size[index2];
  }
}
__name(distributeNodes, "distributeNodes");
function alignNodes(nodes, direction, align_to) {
  if (!nodes) return;
  const boundary = align_to === void 0 ? getBoundaryNodes(nodes) : { top: align_to, right: align_to, bottom: align_to, left: align_to };
  if (boundary === null) return;
  for (const node22 of nodes) {
    switch (direction) {
      case "right":
        node22.pos[0] = boundary.right.pos[0] + boundary.right.size[0] - node22.size[0];
        break;
      case "left":
        node22.pos[0] = boundary.left.pos[0];
        break;
      case "top":
        node22.pos[1] = boundary.top.pos[1];
        break;
      case "bottom":
        node22.pos[1] = boundary.bottom.pos[1] + boundary.bottom.size[1] - node22.size[1];
        break;
    }
  }
}
__name(alignNodes, "alignNodes");
class LGraphCanvas {
  static {
    __name(this, "LGraphCanvas");
  }
  // Optimised buffers used during rendering
  static #temp = new Float32Array(4);
  static #temp_vec2 = new Float32Array(2);
  static #tmp_area = new Float32Array(4);
  static #margin_area = new Float32Array(4);
  static #link_bounding = new Float32Array(4);
  static #lTempA = new Float32Array(2);
  static #lTempB = new Float32Array(2);
  static #lTempC = new Float32Array(2);
  static DEFAULT_BACKGROUND_IMAGE = "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGQAAABkCAIAAAD/gAIDAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAQBJREFUeNrs1rEKwjAUhlETUkj3vP9rdmr1Ysammk2w5wdxuLgcMHyptfawuZX4pJSWZTnfnu/lnIe/jNNxHHGNn//HNbbv+4dr6V+11uF527arU7+u63qfa/bnmh8sWLBgwYJlqRf8MEptXPBXJXa37BSl3ixYsGDBMliwFLyCV/DeLIMFCxYsWLBMwSt4Be/NggXLYMGCBUvBK3iNruC9WbBgwYJlsGApeAWv4L1ZBgsWLFiwYJmCV/AK3psFC5bBggULloJX8BpdwXuzYMGCBctgwVLwCl7Be7MMFixYsGDBsu8FH1FaSmExVfAxBa/gvVmwYMGCZbBg/W4vAQYA5tRF9QYlv/QAAAAASUVORK5CYII=";
  static DEFAULT_EVENT_LINK_COLOR = "#A86";
  /** Link type to colour dictionary. */
  static link_type_colors = {
    "-1": LGraphCanvas.DEFAULT_EVENT_LINK_COLOR,
    "number": "#AAA",
    "node": "#DCA"
  };
  static gradients = {};
  static search_limit = -1;
  static node_colors = {
    red: { color: "#322", bgcolor: "#533", groupcolor: "#A88" },
    brown: { color: "#332922", bgcolor: "#593930", groupcolor: "#b06634" },
    green: { color: "#232", bgcolor: "#353", groupcolor: "#8A8" },
    blue: { color: "#223", bgcolor: "#335", groupcolor: "#88A" },
    pale_blue: {
      color: "#2a363b",
      bgcolor: "#3f5159",
      groupcolor: "#3f789e"
    },
    cyan: { color: "#233", bgcolor: "#355", groupcolor: "#8AA" },
    purple: { color: "#323", bgcolor: "#535", groupcolor: "#a1309b" },
    yellow: { color: "#432", bgcolor: "#653", groupcolor: "#b58b2a" },
    black: { color: "#222", bgcolor: "#000", groupcolor: "#444" }
  };
  /**
   * The state of this canvas, e.g. whether it is being dragged, or read-only.
   *
   * Implemented as a POCO that can be proxied without side-effects.
   */
  state = {
    draggingItems: false,
    draggingCanvas: false,
    readOnly: false,
    hoveringOver: CanvasItem.Nothing,
    shouldSetCursor: true
  };
  #updateCursorStyle() {
    if (!this.state.shouldSetCursor) return;
    let cursor = "default";
    if (this.state.draggingCanvas) {
      cursor = "grabbing";
    } else if (this.state.readOnly) {
      cursor = "grab";
    } else if (this.state.hoveringOver & CanvasItem.ResizeSe) {
      cursor = "se-resize";
    } else if (this.state.hoveringOver & CanvasItem.Node) {
      cursor = "crosshair";
    }
    this.canvas.style.cursor = cursor;
  }
  // Whether the canvas was previously being dragged prior to pressing space key.
  // null if space key is not pressed.
  _previously_dragging_canvas = null;
  // #region Legacy accessors
  /** @deprecated @inheritdoc {@link LGraphCanvasState.readOnly} */
  get read_only() {
    return this.state.readOnly;
  }
  set read_only(value3) {
    this.state.readOnly = value3;
    this.#updateCursorStyle();
  }
  get isDragging() {
    return this.state.draggingItems;
  }
  set isDragging(value3) {
    this.state.draggingItems = value3;
  }
  get hoveringOver() {
    return this.state.hoveringOver;
  }
  set hoveringOver(value3) {
    this.state.hoveringOver = value3;
    this.#updateCursorStyle();
  }
  /** @deprecated Replace all references with {@link pointer}.{@link CanvasPointer.isDown isDown}. */
  get pointer_is_down() {
    return this.pointer.isDown;
  }
  /** @deprecated Replace all references with {@link pointer}.{@link CanvasPointer.isDouble isDouble}. */
  get pointer_is_double() {
    return this.pointer.isDouble;
  }
  /** @deprecated @inheritdoc {@link LGraphCanvasState.draggingCanvas} */
  get dragging_canvas() {
    return this.state.draggingCanvas;
  }
  set dragging_canvas(value3) {
    this.state.draggingCanvas = value3;
    this.#updateCursorStyle();
  }
  // #endregion Legacy accessors
  /**
   * @deprecated Use {@link LGraphNode.titleFontStyle} instead.
   */
  get title_text_font() {
    return `${LiteGraph.NODE_TEXT_SIZE}px Arial`;
  }
  get inner_text_font() {
    return `normal ${LiteGraph.NODE_SUBTEXT_SIZE}px Arial`;
  }
  #maximumFrameGap = 0;
  /** Maximum frames per second to render. 0: unlimited. Default: 0 */
  get maximumFps() {
    return this.#maximumFrameGap > Number.EPSILON ? this.#maximumFrameGap / 1e3 : 0;
  }
  set maximumFps(value3) {
    this.#maximumFrameGap = value3 > Number.EPSILON ? 1e3 / value3 : 0;
  }
  /**
   * @deprecated Use {@link LiteGraphGlobal.ROUND_RADIUS} instead.
   */
  get round_radius() {
    return LiteGraph.ROUND_RADIUS;
  }
  /**
   * @deprecated Use {@link LiteGraphGlobal.ROUND_RADIUS} instead.
   */
  set round_radius(value3) {
    LiteGraph.ROUND_RADIUS = value3;
  }
  /**
   * Render low quality when zoomed out.
   */
  get low_quality() {
    return this.ds.scale < this.low_quality_zoom_threshold;
  }
  options;
  background_image;
  ds;
  pointer;
  zoom_modify_alpha;
  zoom_speed;
  node_title_color;
  default_link_color;
  default_connection_color;
  default_connection_color_byType;
  default_connection_color_byTypeOff;
  highquality_render;
  use_gradients;
  editor_alpha;
  pause_rendering;
  clear_background;
  clear_background_color;
  render_only_selected;
  show_info;
  allow_dragcanvas;
  allow_dragnodes;
  allow_interaction;
  multi_select;
  allow_searchbox;
  allow_reconnect_links;
  align_to_grid;
  drag_mode;
  dragging_rectangle;
  filter;
  set_canvas_dirty_on_mouse_event;
  always_render_background;
  render_shadows;
  render_canvas_border;
  render_connections_shadows;
  render_connections_border;
  render_curved_connections;
  render_connection_arrows;
  render_collapsed_slots;
  render_execution_order;
  render_link_tooltip;
  /** Shape of the markers shown at the midpoint of links.  Default: Circle */
  linkMarkerShape = LinkMarkerShape.Circle;
  links_render_mode;
  /** Zoom threshold for low quality rendering. Zoom below this threshold will render low quality. */
  low_quality_zoom_threshold = 0.6;
  /** mouse in canvas coordinates, where 0,0 is the top-left corner of the blue rectangle */
  mouse;
  /** mouse in graph coordinates, where 0,0 is the top-left corner of the blue rectangle */
  graph_mouse;
  /** @deprecated LEGACY: REMOVE THIS, USE {@link graph_mouse} INSTEAD */
  canvas_mouse;
  /** to personalize the search box */
  onSearchBox;
  onSearchBoxSelection;
  onMouse;
  /** to render background objects (behind nodes and connections) in the canvas affected by transform */
  onDrawBackground;
  /** to render foreground objects (above nodes and connections) in the canvas affected by transform */
  onDrawForeground;
  connections_width;
  /** The current node being drawn by {@link drawNode}.  This should NOT be used to determine the currently selected node.  See {@link selectedItems} */
  current_node;
  /** used for widgets */
  node_widget;
  /** The link to draw a tooltip for. */
  over_link_center;
  last_mouse_position;
  /** The visible area of this canvas.  Tightly coupled with {@link ds}. */
  visible_area;
  /** Contains all links and reroutes that were rendered.  Repopulated every render cycle. */
  renderedPaths = /* @__PURE__ */ new Set();
  /** @deprecated Replaced by {@link renderedPaths}, but length is set to 0 by some extensions. */
  visible_links = [];
  /** @deprecated This array is populated and cleared to support legacy extensions. The contents are ignored by Litegraph. */
  connecting_links;
  linkConnector = new LinkConnector((links) => this.connecting_links = links);
  /** The viewport of this canvas.  Tightly coupled with {@link ds}. */
  viewport;
  autoresize;
  static active_canvas;
  frame = 0;
  last_draw_time = 0;
  render_time = 0;
  fps = 0;
  /** @deprecated See {@link LGraphCanvas.selectedItems} */
  selected_nodes = {};
  /** All selected nodes, groups, and reroutes */
  selectedItems = /* @__PURE__ */ new Set();
  /** The group currently being resized. */
  resizingGroup = null;
  /** @deprecated See {@link LGraphCanvas.selectedItems} */
  selected_group = null;
  /** The nodes that are currently visible on the canvas. */
  visible_nodes = [];
  /**
   * The IDs of the nodes that are currently visible on the canvas. More
   * performant than {@link visible_nodes} for visibility checks.
   */
  #visible_node_ids = /* @__PURE__ */ new Set();
  node_over;
  node_capturing_input;
  highlighted_links = {};
  dirty_canvas = true;
  dirty_bgcanvas = true;
  /** A map of nodes that require selective-redraw */
  dirty_nodes = /* @__PURE__ */ new Map();
  dirty_area;
  /** @deprecated Unused */
  node_in_panel;
  last_mouse = [0, 0];
  last_mouseclick = 0;
  graph;
  canvas;
  bgcanvas;
  ctx;
  _events_binded;
  bgctx;
  is_rendering;
  /** @deprecated Panels */
  block_click;
  /** @deprecated Panels */
  last_click_position;
  resizing_node;
  /** @deprecated See {@link LGraphCanvas.resizingGroup} */
  selected_group_resizing;
  /** @deprecated See {@link pointer}.{@link CanvasPointer.dragStarted dragStarted} */
  last_mouse_dragging;
  onMouseDown;
  _highlight_pos;
  _highlight_input;
  // TODO: Check if panels are used
  /** @deprecated Panels */
  node_panel;
  /** @deprecated Panels */
  options_panel;
  _bg_img;
  _pattern;
  _pattern_img;
  // TODO: This looks like another panel thing
  prompt_box;
  search_box;
  /** @deprecated Panels */
  SELECTED_NODE;
  /** @deprecated Panels */
  NODEPANEL_IS_OPEN;
  /** Once per frame check of snap to grid value.  @todo Update on change. */
  #snapToGrid;
  /** Set on keydown, keyup. @todo */
  #shiftDown = false;
  /** If true, enable drag zoom. Ctrl+Shift+Drag Up/Down: zoom canvas. */
  dragZoomEnabled = false;
  /** The start position of the drag zoom. */
  #dragZoomStart = null;
  static active_node;
  onClear;
  /** called after moving a node @deprecated Does not handle multi-node move, and can return the wrong node. */
  onNodeMoved;
  /** called if the selection changes */
  onSelectionChange;
  /** called when rendering a tooltip */
  onDrawLinkTooltip;
  /** to render foreground objects not affected by transform (for GUIs) */
  onDrawOverlay;
  onRenderBackground;
  onNodeDblClicked;
  onShowNodePanel;
  onNodeSelected;
  onNodeDeselected;
  onRender;
  /** Implement this function to allow conversion of widget types to input types, e.g. number -> INT or FLOAT for widget link validation checks */
  getWidgetLinkType;
  /**
   * Creates a new instance of LGraphCanvas.
   * @param canvas The canvas HTML element (or its id) to use, or null / undefined to leave blank.
   * @param graph The graph that owns this canvas.
   * @param options
   */
  constructor(canvas2, graph, options22) {
    options22 ||= {};
    this.options = options22;
    this.background_image = LGraphCanvas.DEFAULT_BACKGROUND_IMAGE;
    this.ds = new DragAndScale(canvas2);
    this.pointer = new CanvasPointer(canvas2);
    this.linkConnector.events.addEventListener("reset", () => {
      this.connecting_links = null;
    });
    this.linkConnector.events.addEventListener("dropped-on-canvas", (customEvent) => {
      if (!this.connecting_links) return;
      const e2 = customEvent.detail;
      this.emitEvent({
        subType: "empty-release",
        originalEvent: e2,
        linkReleaseContext: { links: this.connecting_links }
      });
      const firstLink = this.linkConnector.renderLinks[0];
      if (LiteGraph.release_link_on_empty_shows_menu) {
        const linkReleaseContext = this.linkConnector.state.connectingTo === "input" ? {
          node_from: firstLink.node,
          slot_from: firstLink.fromSlot,
          type_filter_in: firstLink.fromSlot.type
        } : {
          node_to: firstLink.node,
          slot_from: firstLink.fromSlot,
          type_filter_out: firstLink.fromSlot.type
        };
        if ("shiftKey" in e2 && e2.shiftKey) {
          if (this.allow_searchbox) {
            this.showSearchBox(e2, linkReleaseContext);
          }
        } else if (this.linkConnector.state.connectingTo === "input") {
          this.showConnectionMenu({ nodeFrom: firstLink.node, slotFrom: firstLink.fromSlot, e: e2 });
        } else {
          this.showConnectionMenu({ nodeTo: firstLink.node, slotTo: firstLink.fromSlot, e: e2 });
        }
      }
    });
    this.zoom_modify_alpha = true;
    this.zoom_speed = 1.1;
    this.node_title_color = LiteGraph.NODE_TITLE_COLOR;
    this.default_link_color = LiteGraph.LINK_COLOR;
    this.default_connection_color = {
      input_off: "#778",
      input_on: "#7F7",
      output_off: "#778",
      output_on: "#7F7"
    };
    this.default_connection_color_byType = {
      /* number: "#7F7",
            string: "#77F",
            boolean: "#F77", */
    };
    this.default_connection_color_byTypeOff = {
      /* number: "#474",
            string: "#447",
            boolean: "#744", */
    };
    this.highquality_render = true;
    this.use_gradients = false;
    this.editor_alpha = 1;
    this.pause_rendering = false;
    this.clear_background = true;
    this.clear_background_color = "#222";
    this.render_only_selected = true;
    this.show_info = true;
    this.allow_dragcanvas = true;
    this.allow_dragnodes = true;
    this.allow_interaction = true;
    this.multi_select = false;
    this.allow_searchbox = true;
    this.allow_reconnect_links = true;
    this.align_to_grid = false;
    this.drag_mode = false;
    this.dragging_rectangle = null;
    this.filter = null;
    this.set_canvas_dirty_on_mouse_event = true;
    this.always_render_background = false;
    this.render_shadows = true;
    this.render_canvas_border = true;
    this.render_connections_shadows = false;
    this.render_connections_border = true;
    this.render_curved_connections = false;
    this.render_connection_arrows = false;
    this.render_collapsed_slots = true;
    this.render_execution_order = false;
    this.render_link_tooltip = true;
    this.links_render_mode = LinkRenderType.SPLINE_LINK;
    this.mouse = [0, 0];
    this.graph_mouse = [0, 0];
    this.canvas_mouse = this.graph_mouse;
    this.connections_width = 3;
    this.current_node = null;
    this.node_widget = null;
    this.last_mouse_position = [0, 0];
    this.visible_area = this.ds.visible_area;
    this.connecting_links = null;
    this.viewport = options22.viewport || null;
    this.graph = graph;
    graph?.attachCanvas(this);
    this.canvas = void 0;
    this.bgcanvas = void 0;
    this.ctx = void 0;
    this.setCanvas(canvas2, options22.skip_events);
    this.clear();
    if (!options22.skip_render) {
      this.startRendering();
    }
    this.autoresize = options22.autoresize;
  }
  static onGroupAdd(info, entry, mouse_event) {
    const canvas2 = LGraphCanvas.active_canvas;
    const group = new LiteGraph.LGraphGroup();
    group.pos = canvas2.convertEventToCanvasOffset(mouse_event);
    if (!canvas2.graph) throw new NullGraphError();
    canvas2.graph.add(group);
  }
  /**
   * @deprecated Functionality moved to {@link getBoundaryNodes}.  The new function returns null on failure, instead of an object with all null properties.
   * Determines the furthest nodes in each direction
   * @param nodes the nodes to from which boundary nodes will be extracted
   * @returns
   */
  static getBoundaryNodes(nodes) {
    const _nodes = Array.isArray(nodes) ? nodes : Object.values(nodes);
    return getBoundaryNodes(_nodes) ?? {
      top: null,
      right: null,
      bottom: null,
      left: null
    };
  }
  /**
   * @deprecated Functionality moved to {@link alignNodes}.  The new function does not set dirty canvas.
   * @param nodes a list of nodes
   * @param direction Direction to align the nodes
   * @param align_to Node to align to (if null, align to the furthest node in the given direction)
   */
  static alignNodes(nodes, direction, align_to) {
    alignNodes(Object.values(nodes), direction, align_to);
    LGraphCanvas.active_canvas.setDirty(true, true);
  }
  static onNodeAlign(value3, options22, event, prev_menu, node22) {
    new LiteGraph.ContextMenu(["Top", "Bottom", "Left", "Right"], {
      event,
      callback: inner_clicked,
      parentMenu: prev_menu
    });
    function inner_clicked(value22) {
      alignNodes(
        Object.values(LGraphCanvas.active_canvas.selected_nodes),
        value22.toLowerCase(),
        node22
      );
      LGraphCanvas.active_canvas.setDirty(true, true);
    }
    __name(inner_clicked, "inner_clicked");
  }
  static onGroupAlign(value3, options22, event, prev_menu) {
    new LiteGraph.ContextMenu(["Top", "Bottom", "Left", "Right"], {
      event,
      callback: inner_clicked,
      parentMenu: prev_menu
    });
    function inner_clicked(value22) {
      alignNodes(
        Object.values(LGraphCanvas.active_canvas.selected_nodes),
        value22.toLowerCase()
      );
      LGraphCanvas.active_canvas.setDirty(true, true);
    }
    __name(inner_clicked, "inner_clicked");
  }
  static createDistributeMenu(value3, options22, event, prev_menu) {
    new LiteGraph.ContextMenu(["Vertically", "Horizontally"], {
      event,
      callback: inner_clicked,
      parentMenu: prev_menu
    });
    function inner_clicked(value22) {
      const canvas2 = LGraphCanvas.active_canvas;
      distributeNodes(Object.values(canvas2.selected_nodes), value22 === "Horizontally");
      canvas2.setDirty(true, true);
    }
    __name(inner_clicked, "inner_clicked");
  }
  static onMenuAdd(value3, options22, e2, prev_menu, callback) {
    const canvas2 = LGraphCanvas.active_canvas;
    const ref_window = canvas2.getCanvasWindow();
    const { graph } = canvas2;
    if (!graph) return;
    inner_onMenuAdded("", prev_menu);
    return false;
    function inner_onMenuAdded(base_category, prev_menu2) {
      if (!graph) return;
      const categories = LiteGraph.getNodeTypesCategories(canvas2.filter || graph.filter).filter((category) => category.startsWith(base_category));
      const entries = [];
      for (const category of categories) {
        if (!category) continue;
        const base_category_regex = new RegExp(`^(${base_category})`);
        const category_name = category.replace(base_category_regex, "").split("/", 1)[0];
        const category_path = base_category === "" ? `${category_name}/` : `${base_category}${category_name}/`;
        let name2 = category_name;
        if (name2.includes("::")) name2 = name2.split("::", 2)[1];
        const index2 = entries.findIndex((entry) => entry.value === category_path);
        if (index2 === -1) {
          entries.push({
            value: category_path,
            content: name2,
            has_submenu: true,
            callback: /* @__PURE__ */ __name(function(value22, event, mouseEvent, contextMenu2) {
              inner_onMenuAdded(value22.value, contextMenu2);
            }, "callback")
          });
        }
      }
      const nodes = LiteGraph.getNodeTypesInCategory(
        base_category.slice(0, -1),
        canvas2.filter || graph.filter
      );
      for (const node22 of nodes) {
        if (node22.skip_list) continue;
        const entry = {
          value: node22.type,
          content: node22.title,
          has_submenu: false,
          callback: /* @__PURE__ */ __name(function(value22, event, mouseEvent, contextMenu2) {
            if (!canvas2.graph) throw new NullGraphError();
            const first_event = contextMenu2.getFirstEvent();
            canvas2.graph.beforeChange();
            const node222 = LiteGraph.createNode(value22.value);
            if (node222) {
              if (!first_event) throw new TypeError("Context menu event was null. This should not occure in normal usage.");
              node222.pos = canvas2.convertEventToCanvasOffset(first_event);
              canvas2.graph.add(node222);
            }
            callback?.(node222);
            canvas2.graph.afterChange();
          }, "callback")
        };
        entries.push(entry);
      }
      new LiteGraph.ContextMenu(entries, { event: e2, parentMenu: prev_menu2 }, ref_window);
    }
    __name(inner_onMenuAdded, "inner_onMenuAdded");
  }
  static onMenuCollapseAll() {
  }
  static onMenuNodeEdit() {
  }
  /** @param _options Parameter is never used */
  static showMenuNodeOptionalOutputs(v2, _options, e2, prev_menu, node22) {
    if (!node22) return;
    const canvas2 = LGraphCanvas.active_canvas;
    let entries = [];
    if (LiteGraph.do_add_triggers_slots && node22.findOutputSlot("onExecuted") == -1) {
      entries.push({ content: "On Executed", value: ["onExecuted", LiteGraph.EVENT, { nameLocked: true }], className: "event" });
    }
    const retEntries = node22.onMenuNodeOutputs?.(entries);
    if (retEntries) entries = retEntries;
    if (!entries.length) return;
    new LiteGraph.ContextMenu(
      entries,
      {
        event: e2,
        callback: inner_clicked,
        parentMenu: prev_menu,
        node: node22
      }
    );
    function inner_clicked(v22, e22, prev2) {
      if (!node22) return;
      if (v22.callback) v22.callback.call(this, node22, v22, e22, prev2);
      if (!v22.value) return;
      const value3 = v22.value[1];
      if (value3 && (typeof value3 === "object" || Array.isArray(value3))) {
        const entries2 = [];
        for (const i2 in value3) {
          entries2.push({ content: i2, value: value3[i2] });
        }
        new LiteGraph.ContextMenu(entries2, {
          event: e22,
          callback: inner_clicked,
          parentMenu: prev_menu,
          node: node22
        });
        return false;
      }
      const { graph } = node22;
      if (!graph) throw new NullGraphError();
      graph.beforeChange();
      node22.addOutput(v22.value[0], v22.value[1], v22.value[2]);
      node22.onNodeOutputAdd?.(v22.value);
      canvas2.setDirty(true, true);
      graph.afterChange();
    }
    __name(inner_clicked, "inner_clicked");
    return false;
  }
  /** @param value Parameter is never used */
  static onShowMenuNodeProperties(value3, options22, e2, prev_menu, node22) {
    if (!node22 || !node22.properties) return;
    const canvas2 = LGraphCanvas.active_canvas;
    const ref_window = canvas2.getCanvasWindow();
    const entries = [];
    for (const i2 in node22.properties) {
      value3 = node22.properties[i2] !== void 0 ? node22.properties[i2] : " ";
      if (typeof value3 == "object")
        value3 = JSON.stringify(value3);
      const info = node22.getPropertyInfo(i2);
      if (info.type == "enum" || info.type == "combo")
        value3 = LGraphCanvas.getPropertyPrintableValue(value3, info.values);
      value3 = LGraphCanvas.decodeHTML(stringOrEmpty(value3));
      entries.push({
        content: `<span class='property_name'>${info.label || i2}</span><span class='property_value'>${value3}</span>`,
        value: i2
      });
    }
    if (!entries.length) {
      return;
    }
    new LiteGraph.ContextMenu(
      entries,
      {
        event: e2,
        callback: inner_clicked,
        parentMenu: prev_menu,
        allow_html: true,
        node: node22
      },
      // @ts-expect-error Unused
      ref_window
    );
    function inner_clicked(v2) {
      if (!node22) return;
      const rect = this.getBoundingClientRect();
      canvas2.showEditPropertyValue(node22, v2.value, {
        position: [rect.left, rect.top]
      });
    }
    __name(inner_clicked, "inner_clicked");
    return false;
  }
  /** @deprecated */
  static decodeHTML(str) {
    const e2 = document.createElement("div");
    e2.textContent = str;
    return e2.innerHTML;
  }
  static onMenuResizeNode(value3, options22, e2, menu2, node22) {
    if (!node22) return;
    const fApplyMultiNode = /* @__PURE__ */ __name(function(node222) {
      node222.setSize(node222.computeSize());
    }, "fApplyMultiNode");
    const canvas2 = LGraphCanvas.active_canvas;
    if (!canvas2.selected_nodes || Object.keys(canvas2.selected_nodes).length <= 1) {
      fApplyMultiNode(node22);
    } else {
      for (const i2 in canvas2.selected_nodes) {
        fApplyMultiNode(canvas2.selected_nodes[i2]);
      }
    }
    canvas2.setDirty(true, true);
  }
  // TODO refactor :: this is used fot title but not for properties!
  static onShowPropertyEditor(item3, options22, e2, menu2, node22) {
    const property = item3.property || "title";
    const value3 = node22[property];
    const title = document.createElement("span");
    title.className = "name";
    title.textContent = property;
    const input = document.createElement("input");
    Object.assign(input, { type: "text", className: "value", autofocus: true });
    const button = document.createElement("button");
    button.textContent = "OK";
    const dialog = Object.assign(document.createElement("div"), {
      is_modified: false,
      className: "graphdialog",
      close: /* @__PURE__ */ __name(() => dialog.remove(), "close")
    });
    dialog.append(title, input, button);
    input.value = String(value3);
    input.addEventListener("blur", function() {
      this.focus();
    });
    input.addEventListener("keydown", (e22) => {
      dialog.is_modified = true;
      if (e22.key == "Escape") {
        dialog.close();
      } else if (e22.key == "Enter") {
        inner();
      } else if (!e22.target || !("localName" in e22.target) || e22.target.localName != "textarea") {
        return;
      }
      e22.preventDefault();
      e22.stopPropagation();
    });
    const canvas2 = LGraphCanvas.active_canvas;
    const canvasEl = canvas2.canvas;
    const rect = canvasEl.getBoundingClientRect();
    const offsetx = rect ? -20 - rect.left : -20;
    const offsety = rect ? -20 - rect.top : -20;
    if (e2) {
      dialog.style.left = `${e2.clientX + offsetx}px`;
      dialog.style.top = `${e2.clientY + offsety}px`;
    } else {
      dialog.style.left = `${canvasEl.width * 0.5 + offsetx}px`;
      dialog.style.top = `${canvasEl.height * 0.5 + offsety}px`;
    }
    button.addEventListener("click", inner);
    if (canvasEl.parentNode == null) throw new TypeError("canvasEl.parentNode was null");
    canvasEl.parentNode.append(dialog);
    input.focus();
    let dialogCloseTimer;
    dialog.addEventListener("mouseleave", function() {
      if (LiteGraph.dialog_close_on_mouse_leave) {
        if (!dialog.is_modified && LiteGraph.dialog_close_on_mouse_leave) {
          dialogCloseTimer = setTimeout(
            dialog.close,
            LiteGraph.dialog_close_on_mouse_leave_delay
          );
        }
      }
    });
    dialog.addEventListener("mouseenter", function() {
      if (LiteGraph.dialog_close_on_mouse_leave) {
        if (dialogCloseTimer) clearTimeout(dialogCloseTimer);
      }
    });
    function inner() {
      if (input) setValue2(input.value);
    }
    __name(inner, "inner");
    function setValue2(value22) {
      if (item3.type == "Number") {
        value22 = Number(value22);
      } else if (item3.type == "Boolean") {
        value22 = Boolean(value22);
      }
      node22[property] = value22;
      dialog.remove();
      canvas2.setDirty(true, true);
    }
    __name(setValue2, "setValue");
  }
  static getPropertyPrintableValue(value3, values) {
    if (!values) return String(value3);
    if (Array.isArray(values)) {
      return String(value3);
    }
    if (typeof values === "object") {
      let desc_value = "";
      for (const k2 in values) {
        if (values[k2] != value3) continue;
        desc_value = k2;
        break;
      }
      return `${String(value3)} (${desc_value})`;
    }
  }
  static onMenuNodeCollapse(value3, options22, e2, menu2, node22) {
    if (!node22.graph) throw new NullGraphError();
    node22.graph.beforeChange();
    const fApplyMultiNode = /* @__PURE__ */ __name(function(node222) {
      node222.collapse();
    }, "fApplyMultiNode");
    const graphcanvas = LGraphCanvas.active_canvas;
    if (!graphcanvas.selected_nodes || Object.keys(graphcanvas.selected_nodes).length <= 1) {
      fApplyMultiNode(node22);
    } else {
      for (const i2 in graphcanvas.selected_nodes) {
        fApplyMultiNode(graphcanvas.selected_nodes[i2]);
      }
    }
    node22.graph.afterChange();
  }
  static onMenuToggleAdvanced(value3, options22, e2, menu2, node22) {
    if (!node22.graph) throw new NullGraphError();
    node22.graph.beforeChange();
    const fApplyMultiNode = /* @__PURE__ */ __name(function(node222) {
      node222.toggleAdvanced();
    }, "fApplyMultiNode");
    const graphcanvas = LGraphCanvas.active_canvas;
    if (!graphcanvas.selected_nodes || Object.keys(graphcanvas.selected_nodes).length <= 1) {
      fApplyMultiNode(node22);
    } else {
      for (const i2 in graphcanvas.selected_nodes) {
        fApplyMultiNode(graphcanvas.selected_nodes[i2]);
      }
    }
    node22.graph.afterChange();
  }
  static onMenuNodeMode(value3, options22, e2, menu2, node22) {
    new LiteGraph.ContextMenu(
      LiteGraph.NODE_MODES,
      { event: e2, callback: inner_clicked, parentMenu: menu2, node: node22 }
    );
    function inner_clicked(v2) {
      if (!node22) return;
      const kV = Object.values(LiteGraph.NODE_MODES).indexOf(v2);
      const fApplyMultiNode = /* @__PURE__ */ __name(function(node222) {
        if (kV !== -1 && LiteGraph.NODE_MODES[kV]) {
          node222.changeMode(kV);
        } else {
          console.warn(`unexpected mode: ${v2}`);
          node222.changeMode(LGraphEventMode.ALWAYS);
        }
      }, "fApplyMultiNode");
      const graphcanvas = LGraphCanvas.active_canvas;
      if (!graphcanvas.selected_nodes || Object.keys(graphcanvas.selected_nodes).length <= 1) {
        fApplyMultiNode(node22);
      } else {
        for (const i2 in graphcanvas.selected_nodes) {
          fApplyMultiNode(graphcanvas.selected_nodes[i2]);
        }
      }
    }
    __name(inner_clicked, "inner_clicked");
    return false;
  }
  /** @param value Parameter is never used */
  static onMenuNodeColors(value3, options22, e2, menu2, node22) {
    if (!node22) throw "no node for color";
    const values = [];
    values.push({
      value: null,
      content: "<span style='display: block; padding-left: 4px;'>No color</span>"
    });
    for (const i2 in LGraphCanvas.node_colors) {
      const color2 = LGraphCanvas.node_colors[i2];
      value3 = {
        value: i2,
        content: `<span style='display: block; color: #999; padding-left: 4px; border-left: 8px solid ${color2.color}; background-color:${color2.bgcolor}'>${i2}</span>`
      };
      values.push(value3);
    }
    new LiteGraph.ContextMenu(values, {
      event: e2,
      callback: inner_clicked,
      parentMenu: menu2,
      node: node22
    });
    function inner_clicked(v2) {
      if (!node22) return;
      const fApplyColor = /* @__PURE__ */ __name(function(item3) {
        const colorOption = v2.value ? LGraphCanvas.node_colors[v2.value] : null;
        item3.setColorOption(colorOption);
      }, "fApplyColor");
      const canvas2 = LGraphCanvas.active_canvas;
      if (!canvas2.selected_nodes || Object.keys(canvas2.selected_nodes).length <= 1) {
        fApplyColor(node22);
      } else {
        for (const i2 in canvas2.selected_nodes) {
          fApplyColor(canvas2.selected_nodes[i2]);
        }
      }
      canvas2.setDirty(true, true);
    }
    __name(inner_clicked, "inner_clicked");
    return false;
  }
  static onMenuNodeShapes(value3, options22, e2, menu2, node22) {
    if (!node22) throw "no node passed";
    new LiteGraph.ContextMenu(LiteGraph.VALID_SHAPES, {
      event: e2,
      callback: inner_clicked,
      parentMenu: menu2,
      node: node22
    });
    function inner_clicked(v2) {
      if (!node22) return;
      if (!node22.graph) throw new NullGraphError();
      node22.graph.beforeChange();
      const fApplyMultiNode = /* @__PURE__ */ __name(function(node222) {
        node222.shape = v2;
      }, "fApplyMultiNode");
      const canvas2 = LGraphCanvas.active_canvas;
      if (!canvas2.selected_nodes || Object.keys(canvas2.selected_nodes).length <= 1) {
        fApplyMultiNode(node22);
      } else {
        for (const i2 in canvas2.selected_nodes) {
          fApplyMultiNode(canvas2.selected_nodes[i2]);
        }
      }
      node22.graph.afterChange();
      canvas2.setDirty(true);
    }
    __name(inner_clicked, "inner_clicked");
    return false;
  }
  static onMenuNodeRemove() {
    LGraphCanvas.active_canvas.deleteSelected();
  }
  static onMenuNodeClone(value3, options22, e2, menu2, node22) {
    const { graph } = node22;
    if (!graph) throw new NullGraphError();
    graph.beforeChange();
    const newSelected = /* @__PURE__ */ new Set();
    const fApplyMultiNode = /* @__PURE__ */ __name(function(node222, newNodes) {
      if (node222.clonable === false) return;
      const newnode = node222.clone();
      if (!newnode) return;
      newnode.pos = [node222.pos[0] + 5, node222.pos[1] + 5];
      if (!node222.graph) throw new NullGraphError();
      node222.graph.add(newnode);
      newNodes.add(newnode);
    }, "fApplyMultiNode");
    const canvas2 = LGraphCanvas.active_canvas;
    if (!canvas2.selected_nodes || Object.keys(canvas2.selected_nodes).length <= 1) {
      fApplyMultiNode(node22, newSelected);
    } else {
      for (const i2 in canvas2.selected_nodes) {
        fApplyMultiNode(canvas2.selected_nodes[i2], newSelected);
      }
    }
    if (newSelected.size) {
      canvas2.selectNodes([...newSelected]);
    }
    graph.afterChange();
    canvas2.setDirty(true, true);
  }
  /**
   * clears all the data inside
   *
   */
  clear() {
    this.frame = 0;
    this.last_draw_time = 0;
    this.render_time = 0;
    this.fps = 0;
    this.dragging_rectangle = null;
    this.selected_nodes = {};
    this.selected_group = null;
    this.selectedItems.clear();
    this.onSelectionChange?.(this.selected_nodes);
    this.visible_nodes = [];
    this.node_over = void 0;
    this.node_capturing_input = null;
    this.connecting_links = null;
    this.highlighted_links = {};
    this.dragging_canvas = false;
    this.#dirty();
    this.dirty_area = null;
    this.node_in_panel = null;
    this.node_widget = null;
    this.last_mouse = [0, 0];
    this.last_mouseclick = 0;
    this.pointer.reset();
    this.visible_area.set([0, 0, 0, 0]);
    this.onClear?.();
  }
  /**
   * assigns a graph, you can reassign graphs to the same canvas
   * @param graph
   */
  setGraph(graph, skip_clear) {
    if (this.graph == graph) return;
    if (!skip_clear) this.clear();
    if (!graph && this.graph) {
      this.graph.detachCanvas(this);
      return;
    }
    graph.attachCanvas(this);
    this.setDirty(true, true);
  }
  /**
   * @returns the visually active graph (in case there are more in the stack)
   */
  getCurrentGraph() {
    return this.graph;
  }
  /**
   * Finds the canvas if required, throwing on failure.
   * @param canvas Canvas element, or its element ID
   * @returns The canvas element
   * @throws If {@link canvas} is an element ID that does not belong to a valid HTML canvas element
   */
  #validateCanvas(canvas2) {
    if (typeof canvas2 === "string") {
      const el = document.getElementById(canvas2);
      if (!(el instanceof HTMLCanvasElement)) throw "Error validating LiteGraph canvas: Canvas element not found";
      return el;
    }
    return canvas2;
  }
  /**
   * Sets the current HTML canvas element.
   * Calls bindEvents to add input event listeners, and (re)creates the background canvas.
   * @param canvas The canvas element to assign, or its HTML element ID.  If null or undefined, the current reference is cleared.
   * @param skip_events If true, events on the previous canvas will not be removed.  Has no effect on the first invocation.
   */
  setCanvas(canvas2, skip_events) {
    const element = this.#validateCanvas(canvas2);
    if (element === this.canvas) return;
    if (!element && this.canvas && !skip_events) this.unbindEvents();
    this.canvas = element;
    this.ds.element = element;
    this.pointer.element = element;
    if (!element) return;
    element.className += " lgraphcanvas";
    element.data = this;
    this.bgcanvas = document.createElement("canvas");
    this.bgcanvas.width = this.canvas.width;
    this.bgcanvas.height = this.canvas.height;
    const ctx = element.getContext?.("2d");
    if (ctx == null) {
      if (element.localName != "canvas") {
        throw `Element supplied for LGraphCanvas must be a <canvas> element, you passed a ${element.localName}`;
      }
      throw "This browser doesn't support Canvas";
    }
    this.ctx = ctx;
    if (!skip_events) this.bindEvents();
  }
  /** Captures an event and prevents default - returns false. */
  _doNothing(e2) {
    e2.preventDefault();
    return false;
  }
  /** Captures an event and prevents default - returns true. */
  _doReturnTrue(e2) {
    e2.preventDefault();
    return true;
  }
  /**
   * binds mouse, keyboard, touch and drag events to the canvas
   */
  bindEvents() {
    if (this._events_binded) {
      console.warn("LGraphCanvas: events already binded");
      return;
    }
    const { canvas: canvas2 } = this;
    const { document: document2 } = this.getCanvasWindow();
    this._mousedown_callback = this.processMouseDown.bind(this);
    this._mousewheel_callback = this.processMouseWheel.bind(this);
    this._mousemove_callback = this.processMouseMove.bind(this);
    this._mouseup_callback = this.processMouseUp.bind(this);
    this._mouseout_callback = this.processMouseOut.bind(this);
    this._mousecancel_callback = this.processMouseCancel.bind(this);
    canvas2.addEventListener("pointerdown", this._mousedown_callback, true);
    canvas2.addEventListener("wheel", this._mousewheel_callback, false);
    canvas2.addEventListener("pointerup", this._mouseup_callback, true);
    canvas2.addEventListener("pointermove", this._mousemove_callback);
    canvas2.addEventListener("pointerout", this._mouseout_callback);
    canvas2.addEventListener("pointercancel", this._mousecancel_callback, true);
    canvas2.addEventListener("contextmenu", this._doNothing);
    this._key_callback = this.processKey.bind(this);
    canvas2.addEventListener("keydown", this._key_callback, true);
    document2.addEventListener("keyup", this._key_callback, true);
    canvas2.addEventListener("dragover", this._doNothing, false);
    canvas2.addEventListener("dragend", this._doNothing, false);
    canvas2.addEventListener("dragenter", this._doReturnTrue, false);
    this._events_binded = true;
  }
  /**
   * unbinds mouse events from the canvas
   */
  unbindEvents() {
    if (!this._events_binded) {
      console.warn("LGraphCanvas: no events binded");
      return;
    }
    const { document: document2 } = this.getCanvasWindow();
    const { canvas: canvas2 } = this;
    canvas2.removeEventListener("pointercancel", this._mousecancel_callback);
    canvas2.removeEventListener("pointerout", this._mouseout_callback);
    canvas2.removeEventListener("pointermove", this._mousemove_callback);
    canvas2.removeEventListener("pointerup", this._mouseup_callback);
    canvas2.removeEventListener("pointerdown", this._mousedown_callback);
    canvas2.removeEventListener("wheel", this._mousewheel_callback);
    canvas2.removeEventListener("keydown", this._key_callback);
    document2.removeEventListener("keyup", this._key_callback);
    canvas2.removeEventListener("contextmenu", this._doNothing);
    canvas2.removeEventListener("dragenter", this._doReturnTrue);
    this._mousedown_callback = void 0;
    this._mousewheel_callback = void 0;
    this._key_callback = void 0;
    this._events_binded = false;
  }
  /**
   * Ensures the canvas will be redrawn on the next frame by setting the dirty flag(s).
   * Without parameters, this function does nothing.
   * @todo Impl. `setDirty()` or similar as shorthand to redraw everything.
   * @param fgcanvas If true, marks the foreground canvas as dirty (nodes and anything drawn on top of them).  Default: false
   * @param bgcanvas If true, mark the background canvas as dirty (background, groups, links).  Default: false
   */
  setDirty(fgcanvas, bgcanvas) {
    if (fgcanvas) this.dirty_canvas = true;
    if (bgcanvas) this.dirty_bgcanvas = true;
  }
  /** Marks the entire canvas as dirty. */
  #dirty() {
    this.dirty_canvas = true;
    this.dirty_bgcanvas = true;
  }
  /**
   * Used to attach the canvas in a popup
   * @returns returns the window where the canvas is attached (the DOM root node)
   */
  getCanvasWindow() {
    if (!this.canvas) return window;
    const doc2 = this.canvas.ownerDocument;
    return doc2.defaultView || doc2.parentWindow;
  }
  /**
   * starts rendering the content of the canvas when needed
   *
   */
  startRendering() {
    if (this.is_rendering) return;
    this.is_rendering = true;
    renderFrame.call(this);
    function renderFrame() {
      if (!this.pause_rendering) {
        this.draw();
      }
      const window2 = this.getCanvasWindow();
      if (this.is_rendering) {
        if (this.#maximumFrameGap > 0) {
          const gap = this.#maximumFrameGap - (LiteGraph.getTime() - this.last_draw_time);
          setTimeout(renderFrame.bind(this), Math.max(1, gap));
        } else {
          window2.requestAnimationFrame(renderFrame.bind(this));
        }
      }
    }
    __name(renderFrame, "renderFrame");
  }
  /**
   * stops rendering the content of the canvas (to save resources)
   *
   */
  stopRendering() {
    this.is_rendering = false;
  }
  /* LiteGraphCanvas input */
  // used to block future mouse events (because of im gui)
  blockClick() {
    this.block_click = true;
    this.last_mouseclick = 0;
  }
  /**
   * Gets the widget at the current cursor position
   * @param node Optional node to check for widgets under cursor
   * @returns The widget located at the current cursor position or null
   */
  getWidgetAtCursor(node22) {
    node22 ??= this.node_over;
    return node22?.getWidgetOnPos(this.graph_mouse[0], this.graph_mouse[1], true) ?? null;
  }
  /**
   * Clears highlight and mouse-over information from nodes that should not have it.
   *
   * Intended to be called when the pointer moves away from a node.
   * @param node The node that the mouse is now over
   * @param e MouseEvent that is triggering this
   */
  updateMouseOverNodes(node22, e2) {
    if (!this.graph) throw new NullGraphError();
    const nodes = this.graph._nodes;
    for (const otherNode of nodes) {
      if (otherNode.mouseOver && node22 != otherNode) {
        otherNode.mouseOver = null;
        this._highlight_input = void 0;
        this._highlight_pos = void 0;
        this.linkConnector.overWidget = void 0;
        otherNode.lostFocusAt = LiteGraph.getTime();
        this.node_over?.onMouseLeave?.(e2);
        this.node_over = void 0;
        this.dirty_canvas = true;
      }
    }
  }
  processMouseDown(e2) {
    if (this.dragZoomEnabled && e2.ctrlKey && e2.shiftKey && !e2.altKey && e2.buttons) {
      this.#dragZoomStart = { pos: [e2.x, e2.y], scale: this.ds.scale };
      return;
    }
    const { graph, pointer } = this;
    this.adjustMouseEvent(e2);
    if (e2.isPrimary) pointer.down(e2);
    if (this.set_canvas_dirty_on_mouse_event) this.dirty_canvas = true;
    if (!graph) return;
    const ref_window = this.getCanvasWindow();
    LGraphCanvas.active_canvas = this;
    const x2 = e2.clientX;
    const y2 = e2.clientY;
    this.ds.viewport = this.viewport;
    const is_inside = !this.viewport || isInRect(x2, y2, this.viewport);
    if (!is_inside) return;
    const node22 = graph.getNodeOnPos(e2.canvasX, e2.canvasY, this.visible_nodes) ?? void 0;
    this.mouse[0] = x2;
    this.mouse[1] = y2;
    this.graph_mouse[0] = e2.canvasX;
    this.graph_mouse[1] = e2.canvasY;
    this.last_click_position = [this.mouse[0], this.mouse[1]];
    pointer.isDouble = pointer.isDown && e2.isPrimary;
    pointer.isDown = true;
    this.canvas.focus();
    LiteGraph.closeAllContextMenus(ref_window);
    if (this.onMouse?.(e2) == true) return;
    if (e2.button === 0 && !pointer.isDouble) {
      this.#processPrimaryButton(e2, node22);
    } else if (e2.button === 1) {
      this.#processMiddleButton(e2, node22);
    } else if ((e2.button === 2 || pointer.isDouble) && this.allow_interaction && !this.read_only) {
      if (node22) this.processSelect(node22, e2, true);
      this.processContextMenu(node22, e2);
    }
    this.last_mouse = [x2, y2];
    this.last_mouseclick = LiteGraph.getTime();
    this.last_mouse_dragging = true;
    graph.change();
    if (!ref_window.document.activeElement || ref_window.document.activeElement.nodeName.toLowerCase() != "input" && ref_window.document.activeElement.nodeName.toLowerCase() != "textarea") {
      e2.preventDefault();
    }
    e2.stopPropagation();
    this.onMouseDown?.(e2);
  }
  #processPrimaryButton(e2, node22) {
    const { pointer, graph, linkConnector } = this;
    if (!graph) throw new NullGraphError();
    const x2 = e2.canvasX;
    const y2 = e2.canvasY;
    const ctrlOrMeta = e2.ctrlKey || e2.metaKey;
    if (ctrlOrMeta && !e2.altKey) {
      const dragRect = new Float32Array(4);
      dragRect[0] = x2;
      dragRect[1] = y2;
      dragRect[2] = 1;
      dragRect[3] = 1;
      pointer.onClick = (eUp) => {
        const clickedItem = node22 ?? graph.getRerouteOnPos(eUp.canvasX, eUp.canvasY) ?? graph.getGroupTitlebarOnPos(eUp.canvasX, eUp.canvasY);
        this.processSelect(clickedItem, eUp);
      };
      pointer.onDragStart = () => this.dragging_rectangle = dragRect;
      pointer.onDragEnd = (upEvent) => this.#handleMultiSelect(upEvent, dragRect);
      pointer.finally = () => this.dragging_rectangle = null;
      return;
    }
    if (this.read_only) {
      pointer.finally = () => this.dragging_canvas = false;
      this.dragging_canvas = true;
      return;
    }
    if (LiteGraph.alt_drag_do_clone_nodes && e2.altKey && !e2.ctrlKey && node22 && this.allow_interaction) {
      const node_data = node22.clone()?.serialize();
      if (node_data?.type != null) {
        const cloned = LiteGraph.createNode(node_data.type);
        if (cloned) {
          cloned.configure(node_data);
          cloned.pos[0] += 5;
          cloned.pos[1] += 5;
          if (this.allow_dragnodes) {
            pointer.onDragStart = (pointer2) => {
              graph.add(cloned, false);
              this.#startDraggingItems(cloned, pointer2);
            };
            pointer.onDragEnd = (e22) => this.#processDraggedItems(e22);
          } else {
            graph.beforeChange();
            graph.add(cloned, false);
            graph.afterChange();
          }
          return;
        }
      }
    }
    if (node22 && (this.allow_interaction || node22.flags.allow_interaction)) {
      this.#processNodeClick(e2, ctrlOrMeta, node22);
    } else {
      if (this.links_render_mode !== LinkRenderType.HIDDEN_LINK) {
        const reroute = graph.getRerouteOnPos(x2, y2);
        if (reroute) {
          if (e2.shiftKey) {
            linkConnector.dragFromReroute(graph, reroute);
            pointer.onDragEnd = (upEvent) => linkConnector.dropLinks(graph, upEvent);
            pointer.finally = () => linkConnector.reset(true);
            this.dirty_bgcanvas = true;
          }
          pointer.onClick = () => this.processSelect(reroute, e2);
          if (!pointer.onDragEnd) {
            pointer.onDragStart = (pointer2) => this.#startDraggingItems(reroute, pointer2, true);
            pointer.onDragEnd = (e22) => this.#processDraggedItems(e22);
          }
          return;
        }
      }
      const { lineWidth } = this.ctx;
      this.ctx.lineWidth = this.connections_width + 7;
      const dpi = window?.devicePixelRatio || 1;
      for (const linkSegment of this.renderedPaths) {
        const centre = linkSegment._pos;
        if (!centre) continue;
        if ((e2.shiftKey || e2.altKey) && linkSegment.path && this.ctx.isPointInStroke(linkSegment.path, x2 * dpi, y2 * dpi)) {
          this.ctx.lineWidth = lineWidth;
          if (e2.shiftKey && !e2.altKey) {
            linkConnector.dragFromLinkSegment(graph, linkSegment);
            pointer.onDragEnd = (upEvent) => linkConnector.dropLinks(graph, upEvent);
            pointer.finally = () => linkConnector.reset(true);
            return;
          } else if (e2.altKey && !e2.shiftKey) {
            const newReroute = graph.createReroute([x2, y2], linkSegment);
            pointer.onDragStart = (pointer2) => this.#startDraggingItems(newReroute, pointer2);
            pointer.onDragEnd = (e22) => this.#processDraggedItems(e22);
            return;
          }
        } else if (isInRectangle(x2, y2, centre[0] - 4, centre[1] - 4, 8, 8)) {
          this.ctx.lineWidth = lineWidth;
          pointer.onClick = () => this.showLinkMenu(linkSegment, e2);
          pointer.onDragStart = () => this.dragging_canvas = true;
          pointer.finally = () => this.dragging_canvas = false;
          this.over_link_center = void 0;
          return;
        }
      }
      this.ctx.lineWidth = lineWidth;
      const group = graph.getGroupOnPos(x2, y2);
      this.selected_group = group ?? null;
      if (group) {
        if (group.isInResize(x2, y2)) {
          const b2 = group.boundingRect;
          const offsetX = x2 - (b2[0] + b2[2]);
          const offsetY = y2 - (b2[1] + b2[3]);
          pointer.onDragStart = () => this.resizingGroup = group;
          pointer.onDrag = (eMove) => {
            if (this.read_only) return;
            const pos = [
              eMove.canvasX - group.pos[0] - offsetX,
              eMove.canvasY - group.pos[1] - offsetY
            ];
            if (this.#snapToGrid) snapPoint(pos, this.#snapToGrid);
            const resized = group.resize(pos[0], pos[1]);
            if (resized) this.dirty_bgcanvas = true;
          };
          pointer.finally = () => this.resizingGroup = null;
        } else {
          const f2 = group.font_size || LiteGraph.DEFAULT_GROUP_FONT_SIZE;
          const headerHeight = f2 * 1.4;
          if (isInRectangle(
            x2,
            y2,
            group.pos[0],
            group.pos[1],
            group.size[0],
            headerHeight
          )) {
            pointer.onClick = () => this.processSelect(group, e2);
            pointer.onDragStart = (pointer2) => {
              group.recomputeInsideNodes();
              this.#startDraggingItems(group, pointer2, true);
            };
            pointer.onDragEnd = (e22) => this.#processDraggedItems(e22);
          }
        }
        pointer.onDoubleClick = () => {
          this.emitEvent({
            subType: "group-double-click",
            originalEvent: e2,
            group
          });
        };
      } else {
        pointer.onDoubleClick = () => {
          if (this.allow_searchbox) {
            this.showSearchBox(e2);
            e2.preventDefault();
          }
          this.emitEvent({
            subType: "empty-double-click",
            originalEvent: e2
          });
        };
      }
    }
    if (!pointer.onDragStart && !pointer.onClick && !pointer.onDrag && this.allow_dragcanvas) {
      pointer.onClick = () => this.processSelect(null, e2);
      pointer.finally = () => this.dragging_canvas = false;
      this.dragging_canvas = true;
    }
  }
  /**
   * Processes a pointerdown event inside the bounds of a node.  Part of {@link processMouseDown}.
   * @param e The pointerdown event
   * @param ctrlOrMeta Ctrl or meta key is pressed
   * @param node The node to process a click event for
   */
  #processNodeClick(e2, ctrlOrMeta, node22) {
    const { pointer, graph, linkConnector } = this;
    if (!graph) throw new NullGraphError();
    const x2 = e2.canvasX;
    const y2 = e2.canvasY;
    pointer.onClick = () => this.processSelect(node22, e2);
    if (!node22.flags.pinned) {
      this.bringToFront(node22);
    }
    const inCollapse = node22.isPointInCollapse(x2, y2);
    if (inCollapse) {
      pointer.onClick = () => {
        node22.collapse();
        this.setDirty(true, true);
      };
    } else if (!node22.flags.collapsed) {
      if (node22.resizable !== false && node22.inResizeCorner(x2, y2)) {
        const b2 = node22.boundingRect;
        const offsetX = x2 - (b2[0] + b2[2]);
        const offsetY = y2 - (b2[1] + b2[3]);
        pointer.onDragStart = () => {
          graph.beforeChange();
          this.resizing_node = node22;
        };
        pointer.onDrag = (eMove) => {
          if (this.read_only) return;
          const pos2 = [
            eMove.canvasX - node22.pos[0] - offsetX,
            eMove.canvasY - node22.pos[1] - offsetY
          ];
          if (this.#snapToGrid) snapPoint(pos2, this.#snapToGrid);
          const min = node22.computeSize();
          pos2[0] = Math.max(min[0], pos2[0]);
          pos2[1] = Math.max(min[1], pos2[1]);
          node22.setSize(pos2);
          this.#dirty();
        };
        pointer.onDragEnd = () => {
          this.#dirty();
          graph.afterChange(this.resizing_node);
        };
        pointer.finally = () => this.resizing_node = null;
        this.canvas.style.cursor = "se-resize";
        return;
      }
      const { inputs, outputs } = node22;
      if (outputs) {
        for (const [i2, output] of outputs.entries()) {
          const link_pos = node22.getOutputPos(i2);
          if (isInRectangle(x2, y2, link_pos[0] - 15, link_pos[1] - 10, 30, 20)) {
            if (e2.shiftKey && output.links?.length) {
              linkConnector.moveOutputLink(graph, output);
              pointer.onDragEnd = (upEvent) => linkConnector.dropLinks(graph, upEvent);
              pointer.finally = () => linkConnector.reset(true);
              return;
            }
            linkConnector.dragNewFromOutput(graph, node22, output);
            pointer.onDragEnd = (upEvent) => linkConnector.dropLinks(graph, upEvent);
            pointer.finally = () => linkConnector.reset(true);
            if (LiteGraph.shift_click_do_break_link_from) {
              if (e2.shiftKey) {
                node22.disconnectOutput(i2);
              }
            } else if (LiteGraph.ctrl_alt_click_do_break_link) {
              if (ctrlOrMeta && e2.altKey && !e2.shiftKey) {
                node22.disconnectOutput(i2);
              }
            }
            pointer.onDoubleClick = () => node22.onOutputDblClick?.(i2, e2);
            pointer.onClick = () => node22.onOutputClick?.(i2, e2);
            return;
          }
        }
      }
      if (inputs) {
        for (const [i2, input] of inputs.entries()) {
          const link_pos = node22.getInputPos(i2);
          if (isInRectangle(x2, y2, link_pos[0] - 15, link_pos[1] - 10, 30, 20)) {
            pointer.onDoubleClick = () => node22.onInputDblClick?.(i2, e2);
            pointer.onClick = () => node22.onInputClick?.(i2, e2);
            if (input.link !== null) {
              if (LiteGraph.click_do_break_link_to || LiteGraph.ctrl_alt_click_do_break_link && ctrlOrMeta && e2.altKey && !e2.shiftKey) {
                node22.disconnectInput(i2, true);
              } else if (e2.shiftKey || this.allow_reconnect_links) {
                linkConnector.moveInputLink(graph, input);
              }
            } else {
              for (const link2 of graph.floatingLinks.values()) {
                if (link2.target_id === node22.id && link2.target_slot === i2) {
                  graph.removeFloatingLink(link2);
                }
              }
            }
            if (!linkConnector.isConnecting) {
              linkConnector.dragNewFromInput(graph, node22, input);
            }
            pointer.onDragEnd = (upEvent) => linkConnector.dropLinks(graph, upEvent);
            pointer.finally = () => linkConnector.reset(true);
            this.dirty_bgcanvas = true;
            return;
          }
        }
      }
    }
    const pos = [x2 - node22.pos[0], y2 - node22.pos[1]];
    const widget = node22.getWidgetOnPos(x2, y2);
    if (widget) {
      this.#processWidgetClick(e2, node22, widget);
      this.node_widget = [node22, widget];
    } else {
      pointer.onDoubleClick = () => {
        if (pos[1] < 0 && !inCollapse) {
          node22.onNodeTitleDblClick?.(e2, pos, this);
        }
        node22.onDblClick?.(e2, pos, this);
        this.emitEvent({
          subType: "node-double-click",
          originalEvent: e2,
          node: node22
        });
        this.processNodeDblClicked(node22);
      };
      if (node22.onMouseDown?.(e2, pos, this) || !this.allow_dragnodes)
        return;
      pointer.onDragStart = (pointer2) => this.#startDraggingItems(node22, pointer2, true);
      pointer.onDragEnd = (e22) => this.#processDraggedItems(e22);
    }
    this.dirty_canvas = true;
  }
  #processWidgetClick(e2, node22, widget) {
    const { pointer } = this;
    if (typeof widget.onPointerDown === "function") {
      const handled = widget.onPointerDown(pointer, node22, this);
      if (handled) return;
    }
    const oldValue = widget.value;
    const pos = this.graph_mouse;
    const x2 = pos[0] - node22.pos[0];
    const y2 = pos[1] - node22.pos[1];
    const WidgetClass = WIDGET_TYPE_MAP[widget.type];
    if (WidgetClass) {
      const widgetInstance = toClass(WidgetClass, widget);
      pointer.onClick = () => widgetInstance.onClick({
        e: e2,
        node: node22,
        canvas: this
      });
      pointer.onDrag = (eMove) => widgetInstance.onDrag?.({
        e: eMove,
        node: node22,
        canvas: this
      });
    } else if (widget.mouse) {
      const result = widget.mouse(e2, [x2, y2], node22);
      if (result != null) this.dirty_canvas = result;
    }
    if (oldValue != widget.value) {
      node22.onWidgetChanged?.(widget.name, widget.value, oldValue, widget);
      if (!node22.graph) throw new NullGraphError();
      node22.graph._version++;
    }
    pointer.finally = () => {
      if (widget.mouse) {
        const { eUp } = pointer;
        if (!eUp) return;
        const { canvasX, canvasY } = eUp;
        widget.mouse(eUp, [canvasX - node22.pos[0], canvasY - node22.pos[1]], node22);
      }
      this.node_widget = null;
    };
  }
  /**
   * Pointer middle button click processing.  Part of {@link processMouseDown}.
   * @param e The pointerdown event
   * @param node The node to process a click event for
   */
  #processMiddleButton(e2, node22) {
    const { pointer } = this;
    if (LiteGraph.middle_click_slot_add_default_node && node22 && this.allow_interaction && !this.read_only && !this.connecting_links && !node22.flags.collapsed) {
      let mClikSlot = false;
      let mClikSlot_index = false;
      let mClikSlot_isOut = false;
      const { inputs, outputs } = node22;
      if (outputs) {
        for (const [i2, output] of outputs.entries()) {
          const link_pos = node22.getOutputPos(i2);
          if (isInRectangle(e2.canvasX, e2.canvasY, link_pos[0] - 15, link_pos[1] - 10, 30, 20)) {
            mClikSlot = output;
            mClikSlot_index = i2;
            mClikSlot_isOut = true;
            break;
          }
        }
      }
      if (inputs) {
        for (const [i2, input] of inputs.entries()) {
          const link_pos = node22.getInputPos(i2);
          if (isInRectangle(e2.canvasX, e2.canvasY, link_pos[0] - 15, link_pos[1] - 10, 30, 20)) {
            mClikSlot = input;
            mClikSlot_index = i2;
            mClikSlot_isOut = false;
            break;
          }
        }
      }
      if (mClikSlot && mClikSlot_index !== false) {
        const alphaPosY = 0.5 - (mClikSlot_index + 1) / (mClikSlot_isOut ? outputs.length : inputs.length);
        const node_bounding = node22.getBounding();
        const posRef = [
          !mClikSlot_isOut ? node_bounding[0] : node_bounding[0] + node_bounding[2],
          e2.canvasY - 80
        ];
        pointer.onClick = () => this.createDefaultNodeForSlot({
          nodeFrom: !mClikSlot_isOut ? null : node22,
          slotFrom: !mClikSlot_isOut ? null : mClikSlot_index,
          nodeTo: !mClikSlot_isOut ? node22 : null,
          slotTo: !mClikSlot_isOut ? mClikSlot_index : null,
          position: posRef,
          nodeType: "AUTO",
          posAdd: [!mClikSlot_isOut ? -30 : 30, -alphaPosY * 130],
          posSizeFix: [!mClikSlot_isOut ? -1 : 0, 0]
        });
      }
    }
    if (this.allow_dragcanvas) {
      pointer.onDragStart = () => this.dragging_canvas = true;
      pointer.finally = () => this.dragging_canvas = false;
    }
  }
  #processDragZoom(e2) {
    if (!e2.buttons) {
      this.#dragZoomStart = null;
      return;
    }
    const start2 = this.#dragZoomStart;
    if (!start2) throw new TypeError("Drag-zoom state object was null");
    if (!this.graph) throw new NullGraphError();
    const deltaY = e2.y - start2.pos[1];
    const startScale = start2.scale;
    const scale = startScale - deltaY / 100;
    this.ds.changeScale(scale, start2.pos);
    this.graph.change();
  }
  /**
   * Called when a mouse move event has to be processed
   */
  processMouseMove(e2) {
    if (this.dragZoomEnabled && e2.ctrlKey && e2.shiftKey && this.#dragZoomStart) {
      this.#processDragZoom(e2);
      return;
    }
    if (this.autoresize) this.resize();
    if (this.set_canvas_dirty_on_mouse_event) this.dirty_canvas = true;
    const { graph, resizingGroup, linkConnector } = this;
    if (!graph) return;
    LGraphCanvas.active_canvas = this;
    this.adjustMouseEvent(e2);
    const mouse = [e2.clientX, e2.clientY];
    this.mouse[0] = mouse[0];
    this.mouse[1] = mouse[1];
    const delta2 = [
      mouse[0] - this.last_mouse[0],
      mouse[1] - this.last_mouse[1]
    ];
    this.last_mouse = mouse;
    this.graph_mouse[0] = e2.canvasX;
    this.graph_mouse[1] = e2.canvasY;
    if (e2.isPrimary) this.pointer.move(e2);
    if (this.block_click) {
      e2.preventDefault();
      return;
    }
    e2.dragging = this.last_mouse_dragging;
    if (this.node_widget) {
      const [node222, widget] = this.node_widget;
      if (widget?.mouse) {
        const x2 = e2.canvasX - node222.pos[0];
        const y2 = e2.canvasY - node222.pos[1];
        const result = widget.mouse(e2, [x2, y2], node222);
        if (result != null) this.dirty_canvas = result;
      }
    }
    let underPointer = CanvasItem.Nothing;
    const node22 = graph.getNodeOnPos(
      e2.canvasX,
      e2.canvasY,
      this.visible_nodes
    );
    const dragRect = this.dragging_rectangle;
    if (dragRect) {
      dragRect[2] = e2.canvasX - dragRect[0];
      dragRect[3] = e2.canvasY - dragRect[1];
      this.dirty_canvas = true;
    } else if (resizingGroup) {
      underPointer |= CanvasItem.ResizeSe | CanvasItem.Group;
    } else if (this.dragging_canvas) {
      this.ds.offset[0] += delta2[0] / this.ds.scale;
      this.ds.offset[1] += delta2[1] / this.ds.scale;
      this.#dirty();
    } else if ((this.allow_interaction || node22?.flags.allow_interaction) && !this.read_only) {
      if (linkConnector.isConnecting) this.dirty_canvas = true;
      this.updateMouseOverNodes(node22, e2);
      if (node22) {
        underPointer |= CanvasItem.Node;
        if (node22.redraw_on_mouse) this.dirty_canvas = true;
        const pos = [0, 0];
        const inputId = isOverNodeInput(node22, e2.canvasX, e2.canvasY, pos);
        const outputId = isOverNodeOutput(node22, e2.canvasX, e2.canvasY, pos);
        const overWidget = node22.getWidgetOnPos(e2.canvasX, e2.canvasY, true);
        if (!node22.mouseOver) {
          node22.mouseOver = {
            inputId: null,
            outputId: null,
            overWidget: null
          };
          this.node_over = node22;
          this.dirty_canvas = true;
          node22.onMouseEnter?.(e2);
        }
        node22.onMouseMove?.(e2, [e2.canvasX - node22.pos[0], e2.canvasY - node22.pos[1]], this);
        if (node22.mouseOver.inputId !== inputId || node22.mouseOver.outputId !== outputId || node22.mouseOver.overWidget !== overWidget) {
          node22.mouseOver.inputId = inputId;
          node22.mouseOver.outputId = outputId;
          node22.mouseOver.overWidget = overWidget;
          linkConnector.overWidget = void 0;
          if (linkConnector.isConnecting) {
            const firstLink = linkConnector.renderLinks.at(0);
            let highlightPos;
            let highlightInput;
            if (!firstLink || firstLink.node === node22) ;
            else if (linkConnector.state.connectingTo === "input") {
              if (inputId === -1 && outputId === -1) {
                if (this.getWidgetLinkType && overWidget) {
                  const widgetLinkType = this.getWidgetLinkType(overWidget, node22);
                  if (widgetLinkType && LiteGraph.isValidConnection(linkConnector.renderLinks[0]?.fromSlot.type, widgetLinkType) && firstLink.node.isValidWidgetLink?.(firstLink.fromSlotIndex, node22, overWidget) !== false) {
                    const { pos: [nodeX, nodeY] } = node22;
                    highlightPos = [nodeX + 10, nodeY + 10 + overWidget.y];
                    linkConnector.overWidget = overWidget;
                    linkConnector.overWidgetType = widgetLinkType;
                  }
                }
                if (!linkConnector.overWidget) {
                  const result = node22.findInputByType(firstLink.fromSlot.type);
                  if (result) {
                    highlightInput = result.slot;
                    highlightPos = node22.getInputPos(result.index);
                  }
                }
              } else if (inputId != -1 && node22.inputs[inputId] && LiteGraph.isValidConnection(firstLink.fromSlot.type, node22.inputs[inputId].type)) {
                highlightPos = pos;
                highlightInput = node22.inputs[inputId];
              }
            } else if (linkConnector.state.connectingTo === "output") {
              if (inputId === -1 && outputId === -1) {
                const result = node22.findOutputByType(firstLink.fromSlot.type);
                if (result) {
                  highlightPos = node22.getOutputPos(result.index);
                }
              } else {
                if (outputId != -1 && node22.outputs[outputId] && LiteGraph.isValidConnection(firstLink.fromSlot.type, node22.outputs[outputId].type)) {
                  highlightPos = pos;
                }
              }
            }
            this._highlight_pos = highlightPos;
            this._highlight_input = highlightInput;
          }
          this.dirty_canvas = true;
        }
        if (node22.inResizeCorner(e2.canvasX, e2.canvasY)) {
          underPointer |= CanvasItem.ResizeSe;
        }
      } else {
        const reroute = graph.getRerouteOnPos(e2.canvasX, e2.canvasY);
        if (reroute) {
          underPointer |= CanvasItem.Reroute;
          if (linkConnector.isConnecting) {
            const firstSlot = linkConnector.renderLinks[0]?.fromSlot;
            const rerouteType = reroute.firstLink?.type ?? reroute.firstFloatingLink?.type;
            if (firstSlot && rerouteType != null && LiteGraph.isValidConnection(rerouteType, firstSlot.type)) {
              this._highlight_pos = reroute.pos;
            }
          }
        } else {
          this._highlight_pos &&= void 0;
        }
        const segment = this.#getLinkCentreOnPos(e2);
        if (this.over_link_center !== segment) {
          underPointer |= CanvasItem.Link;
          this.over_link_center = segment;
          this.dirty_bgcanvas = true;
        }
        if (this.canvas) {
          const group = graph.getGroupOnPos(e2.canvasX, e2.canvasY);
          if (group && !e2.ctrlKey && !this.read_only && group.isInResize(e2.canvasX, e2.canvasY)) {
            underPointer |= CanvasItem.ResizeSe;
          }
        }
      }
      if (this.node_capturing_input && this.node_capturing_input != node22) {
        this.node_capturing_input.onMouseMove?.(
          e2,
          [
            e2.canvasX - this.node_capturing_input.pos[0],
            e2.canvasY - this.node_capturing_input.pos[1]
          ],
          this
        );
      }
      if (this.isDragging) {
        const selected2 = this.selectedItems;
        const allItems = e2.ctrlKey ? selected2 : getAllNestedItems(selected2);
        const deltaX = delta2[0] / this.ds.scale;
        const deltaY = delta2[1] / this.ds.scale;
        for (const item3 of allItems) {
          item3.move(deltaX, deltaY, true);
        }
        this.#dirty();
      }
      if (this.resizing_node) underPointer |= CanvasItem.ResizeSe;
    }
    this.hoveringOver = underPointer;
    e2.preventDefault();
    return;
  }
  /**
   * Start dragging an item, optionally including all other selected items.
   *
   * ** This function sets the {@link CanvasPointer.finally}() callback. **
   * @param item The item that the drag event started on
   * @param pointer The pointer event that initiated the drag, e.g. pointerdown
   * @param sticky If `true`, the item is added to the selection - see {@link processSelect}
   */
  #startDraggingItems(item3, pointer, sticky = false) {
    this.emitBeforeChange();
    this.graph?.beforeChange();
    pointer.finally = () => {
      this.isDragging = false;
      this.graph?.afterChange();
      this.emitAfterChange();
    };
    this.processSelect(item3, pointer.eDown, sticky);
    this.isDragging = true;
  }
  /**
   * Handles shared clean up and placement after items have been dragged.
   * @param e The event that completed the drag, e.g. pointerup, pointermove
   */
  #processDraggedItems(e2) {
    const { graph } = this;
    if (e2.shiftKey || LiteGraph.alwaysSnapToGrid)
      graph?.snapToGrid(this.selectedItems);
    this.dirty_canvas = true;
    this.dirty_bgcanvas = true;
    this.onNodeMoved?.(findFirstNode(this.selectedItems));
  }
  /**
   * Called when a mouse up event has to be processed
   */
  processMouseUp(e2) {
    if (e2.isPrimary === false) return;
    const { graph, pointer } = this;
    if (!graph) return;
    LGraphCanvas.active_canvas = this;
    this.adjustMouseEvent(e2);
    const now2 = LiteGraph.getTime();
    e2.click_time = now2 - this.last_mouseclick;
    const isClick = pointer.up(e2);
    if (isClick === true) {
      pointer.isDown = false;
      pointer.isDouble = false;
      this.connecting_links = null;
      this.dragging_canvas = false;
      graph.change();
      e2.stopPropagation();
      e2.preventDefault();
      return;
    }
    this.last_mouse_dragging = false;
    this.last_click_position = null;
    this.block_click &&= false;
    if (e2.button === 0) {
      this.selected_group = null;
      this.isDragging = false;
      const x2 = e2.canvasX;
      const y2 = e2.canvasY;
      if (!this.linkConnector.isConnecting) {
        this.dirty_canvas = true;
        this.node_over?.onMouseUp?.(e2, [x2 - this.node_over.pos[0], y2 - this.node_over.pos[1]], this);
        this.node_capturing_input?.onMouseUp?.(e2, [
          x2 - this.node_capturing_input.pos[0],
          y2 - this.node_capturing_input.pos[1]
        ]);
      }
    } else if (e2.button === 1) {
      this.dirty_canvas = true;
      this.dragging_canvas = false;
    } else if (e2.button === 2) {
      this.dirty_canvas = true;
    }
    pointer.isDown = false;
    pointer.isDouble = false;
    graph.change();
    e2.stopPropagation();
    e2.preventDefault();
    return;
  }
  /**
   * Called when the mouse moves off the canvas.  Clears all node hover states.
   * @param e
   */
  processMouseOut(e2) {
    this.adjustMouseEvent(e2);
    this.updateMouseOverNodes(null, e2);
  }
  processMouseCancel() {
    console.warn("Pointer cancel!");
    this.pointer.reset();
  }
  /**
   * Called when a mouse wheel event has to be processed
   */
  processMouseWheel(e2) {
    if (!this.graph || !this.allow_dragcanvas) return;
    const delta2 = e2.wheelDeltaY ?? e2.detail * -60;
    this.adjustMouseEvent(e2);
    const pos = [e2.clientX, e2.clientY];
    if (this.viewport && !isPointInRect(pos, this.viewport)) return;
    let { scale } = this.ds;
    if (delta2 > 0) scale *= this.zoom_speed;
    else if (delta2 < 0) scale *= 1 / this.zoom_speed;
    this.ds.changeScale(scale, [e2.clientX, e2.clientY]);
    this.graph.change();
    e2.preventDefault();
    return;
  }
  /**
   * process a key event
   */
  processKey(e2) {
    this.#shiftDown = e2.shiftKey;
    if (!this.graph) return;
    let block_default = false;
    if (e2.target.localName == "input") return;
    if (e2.type == "keydown") {
      if (e2.key === " ") {
        this.read_only = true;
        if (this._previously_dragging_canvas === null) {
          this._previously_dragging_canvas = this.dragging_canvas;
        }
        this.dragging_canvas = this.pointer.isDown;
        block_default = true;
      } else if (e2.key === "Escape") {
        this.node_panel?.close();
        this.options_panel?.close();
        block_default = true;
      } else if (e2.keyCode === 65 && e2.ctrlKey) {
        this.selectItems();
        block_default = true;
      } else if (e2.keyCode === 67 && (e2.metaKey || e2.ctrlKey) && !e2.shiftKey) {
        if (this.selected_nodes) {
          this.copyToClipboard();
          block_default = true;
        }
      } else if (e2.keyCode === 86 && (e2.metaKey || e2.ctrlKey)) {
        this.pasteFromClipboard({ connectInputs: e2.shiftKey });
      } else if (e2.key === "Delete" || e2.key === "Backspace") {
        if (e2.target.localName != "input" && e2.target.localName != "textarea") {
          this.deleteSelected();
          block_default = true;
        }
      }
      if (this.selected_nodes) {
        for (const i2 in this.selected_nodes) {
          this.selected_nodes[i2].onKeyDown?.(e2);
        }
      }
    } else if (e2.type == "keyup") {
      if (e2.key === " ") {
        this.read_only = false;
        this.dragging_canvas = (this._previously_dragging_canvas ?? false) && this.pointer.isDown;
        this._previously_dragging_canvas = null;
      }
      if (this.selected_nodes) {
        for (const i2 in this.selected_nodes) {
          this.selected_nodes[i2].onKeyUp?.(e2);
        }
      }
    }
    this.graph.change();
    if (block_default) {
      e2.preventDefault();
      e2.stopImmediatePropagation();
      return false;
    }
  }
  /**
   * Copies canvas items to an internal, app-specific clipboard backed by local storage.
   * When called without parameters, it copies {@link selectedItems}.
   * @param items The items to copy.  If nullish, all selected items are copied.
   */
  copyToClipboard(items2) {
    const serialisable = {
      nodes: [],
      groups: [],
      reroutes: [],
      links: []
    };
    for (const item3 of items2 ?? this.selectedItems) {
      if (item3 instanceof LGraphNode) {
        if (item3.clonable === false) continue;
        const cloned = item3.clone()?.serialize();
        if (!cloned) continue;
        cloned.id = item3.id;
        serialisable.nodes.push(cloned);
        if (item3.inputs) {
          for (const { link: linkId } of item3.inputs) {
            if (linkId == null) continue;
            const link2 = this.graph?._links.get(linkId)?.asSerialisable();
            if (link2) serialisable.links.push(link2);
          }
        }
      } else if (item3 instanceof LGraphGroup) {
        serialisable.groups.push(item3.serialize());
      } else if (item3 instanceof Reroute) {
        serialisable.reroutes.push(item3.asSerialisable());
      }
    }
    localStorage.setItem(
      "litegrapheditor_clipboard",
      JSON.stringify(serialisable)
    );
  }
  emitEvent(detail) {
    this.canvas.dispatchEvent(
      new CustomEvent("litegraph:canvas", {
        bubbles: true,
        detail
      })
    );
  }
  /** @todo Refactor to where it belongs - e.g. Deleting / creating nodes is not actually canvas event. */
  emitBeforeChange() {
    this.emitEvent({
      subType: "before-change"
    });
  }
  /** @todo See {@link emitBeforeChange} */
  emitAfterChange() {
    this.emitEvent({
      subType: "after-change"
    });
  }
  /**
   * Pastes the items from the canvas "clipbaord" - a local storage variable.
   */
  _pasteFromClipboard(options22 = {}) {
    const {
      connectInputs = false,
      position: position3 = this.graph_mouse
    } = options22;
    if (!LiteGraph.ctrl_shift_v_paste_connect_unselected_outputs && connectInputs) return;
    const data30 = localStorage.getItem("litegrapheditor_clipboard");
    if (!data30) return;
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    graph.beforeChange();
    const parsed = JSON.parse(data30);
    parsed.nodes ??= [];
    parsed.groups ??= [];
    parsed.reroutes ??= [];
    parsed.links ??= [];
    let offsetX = Infinity;
    let offsetY = Infinity;
    for (const item3 of [...parsed.nodes, ...parsed.reroutes]) {
      if (item3.pos == null) throw new TypeError("Invalid node encounterd on paste.  `pos` was null.");
      if (item3.pos[0] < offsetX) offsetX = item3.pos[0];
      if (item3.pos[1] < offsetY) offsetY = item3.pos[1];
    }
    if (parsed.groups) {
      for (const group of parsed.groups) {
        if (group.bounding[0] < offsetX) offsetX = group.bounding[0];
        if (group.bounding[1] < offsetY) offsetY = group.bounding[1];
      }
    }
    const results = {
      created: [],
      nodes: /* @__PURE__ */ new Map(),
      links: /* @__PURE__ */ new Map(),
      reroutes: /* @__PURE__ */ new Map()
    };
    const { created: created4, nodes, links, reroutes } = results;
    for (const info of parsed.groups) {
      info.id = -1;
      const group = new LGraphGroup();
      group.configure(info);
      graph.add(group);
      created4.push(group);
    }
    for (const info of parsed.nodes) {
      const node22 = info.type == null ? null : LiteGraph.createNode(info.type);
      if (!node22) {
        continue;
      }
      nodes.set(info.id, node22);
      info.id = -1;
      node22.configure(info);
      graph.add(node22);
      created4.push(node22);
    }
    for (const info of parsed.reroutes) {
      const { id: id4, ...rerouteInfo } = info;
      const reroute = graph.setReroute(rerouteInfo);
      created4.push(reroute);
      reroutes.set(id4, reroute);
    }
    for (const reroute of reroutes.values()) {
      if (reroute.parentId == null) continue;
      const mapped = reroutes.get(reroute.parentId);
      if (mapped) reroute.parentId = mapped.id;
    }
    for (const info of parsed.links) {
      let outNode = nodes.get(info.origin_id);
      let afterRerouteId;
      if (info.parentId != null) afterRerouteId = reroutes.get(info.parentId)?.id;
      if (connectInputs && LiteGraph.ctrl_shift_v_paste_connect_unselected_outputs) {
        outNode ??= graph.getNodeById(info.origin_id);
        afterRerouteId ??= info.parentId;
      }
      const inNode = nodes.get(info.target_id);
      if (inNode) {
        const link2 = outNode?.connect(
          info.origin_slot,
          inNode,
          info.target_slot,
          afterRerouteId
        );
        if (link2) links.set(info.id, link2);
      }
    }
    for (const reroute of reroutes.values()) {
      const ids = [...reroute.linkIds].map((x2) => links.get(x2)?.id ?? x2);
      reroute.update(reroute.parentId, void 0, ids, reroute.floating);
      if (!reroute.validateLinks(graph.links, graph.floatingLinks)) {
        graph.removeReroute(reroute.id);
      }
    }
    for (const item3 of created4) {
      item3.pos[0] += position3[0] - offsetX;
      item3.pos[1] += position3[1] - offsetY;
    }
    this.selectItems(created4);
    graph.afterChange();
    return results;
  }
  pasteFromClipboard(options22 = {}) {
    this.emitBeforeChange();
    try {
      this._pasteFromClipboard(options22);
    } finally {
      this.emitAfterChange();
    }
  }
  processNodeDblClicked(n2) {
    this.onShowNodePanel?.(n2);
    this.onNodeDblClicked?.(n2);
    this.setDirty(true);
  }
  #handleMultiSelect(e2, dragRect) {
    const { graph, selectedItems } = this;
    if (!graph) throw new NullGraphError();
    const w2 = Math.abs(dragRect[2]);
    const h2 = Math.abs(dragRect[3]);
    if (dragRect[2] < 0) dragRect[0] -= w2;
    if (dragRect[3] < 0) dragRect[1] -= h2;
    dragRect[2] = w2;
    dragRect[3] = h2;
    const isSelected7 = [];
    const notSelected = [];
    for (const nodeX of graph._nodes) {
      if (!overlapBounding(dragRect, nodeX.boundingRect)) continue;
      if (!nodeX.selected || !selectedItems.has(nodeX))
        notSelected.push(nodeX);
      else isSelected7.push(nodeX);
    }
    for (const group of graph.groups) {
      if (!containsRect(dragRect, group._bounding)) continue;
      group.recomputeInsideNodes();
      if (!group.selected || !selectedItems.has(group))
        notSelected.push(group);
      else isSelected7.push(group);
    }
    for (const reroute of graph.reroutes.values()) {
      if (!isPointInRect(reroute.pos, dragRect)) continue;
      selectedItems.add(reroute);
      reroute.selected = true;
      if (!reroute.selected || !selectedItems.has(reroute))
        notSelected.push(reroute);
      else isSelected7.push(reroute);
    }
    if (e2.shiftKey) {
      for (const item3 of notSelected) this.select(item3);
    } else if (e2.altKey) {
      for (const item3 of isSelected7) this.deselect(item3);
    } else {
      for (const item3 of selectedItems.values()) {
        if (!isSelected7.includes(item3)) this.deselect(item3);
      }
      for (const item3 of notSelected) this.select(item3);
    }
    this.onSelectionChange?.(this.selected_nodes);
  }
  /**
   * Determines whether to select or deselect an item that has received a pointer event.  Will deselect other nodes if
   * @param item Canvas item to select/deselect
   * @param e The MouseEvent to handle
   * @param sticky Prevents deselecting individual nodes (as used by aux/right-click)
   * @remarks
   * Accessibility: anyone using {@link mutli_select} always deselects when clicking empty space.
   */
  processSelect(item3, e2, sticky = false) {
    const addModifier = e2?.shiftKey;
    const subtractModifier = e2 != null && (e2.metaKey || e2.ctrlKey);
    const eitherModifier = addModifier || subtractModifier;
    const modifySelection = eitherModifier || this.multi_select;
    if (!item3) {
      if (!eitherModifier || this.multi_select) this.deselectAll();
    } else if (!item3.selected || !this.selectedItems.has(item3)) {
      if (!modifySelection) this.deselectAll(item3);
      this.select(item3);
    } else if (modifySelection && !sticky) {
      this.deselect(item3);
    } else if (!sticky) {
      this.deselectAll(item3);
    } else {
      return;
    }
    this.onSelectionChange?.(this.selected_nodes);
    this.setDirty(true);
  }
  /**
   * Selects a {@link Positionable} item.
   * @param item The canvas item to add to the selection.
   */
  select(item3) {
    if (item3.selected && this.selectedItems.has(item3)) return;
    item3.selected = true;
    this.selectedItems.add(item3);
    if (!(item3 instanceof LGraphNode)) return;
    item3.onSelected?.();
    this.selected_nodes[item3.id] = item3;
    this.onNodeSelected?.(item3);
    if (item3.inputs) {
      for (const input of item3.inputs) {
        if (input.link == null) continue;
        this.highlighted_links[input.link] = true;
      }
    }
    if (item3.outputs) {
      for (const id4 of item3.outputs.flatMap((x2) => x2.links)) {
        if (id4 == null) continue;
        this.highlighted_links[id4] = true;
      }
    }
  }
  /**
   * Deselects a {@link Positionable} item.
   * @param item The canvas item to remove from the selection.
   */
  deselect(item3) {
    if (!item3.selected && !this.selectedItems.has(item3)) return;
    item3.selected = false;
    this.selectedItems.delete(item3);
    if (!(item3 instanceof LGraphNode)) return;
    item3.onDeselected?.();
    delete this.selected_nodes[item3.id];
    this.onNodeDeselected?.(item3);
    if (item3.inputs) {
      for (const input of item3.inputs) {
        if (input.link == null) continue;
        delete this.highlighted_links[input.link];
      }
    }
    if (item3.outputs) {
      for (const id4 of item3.outputs.flatMap((x2) => x2.links)) {
        if (id4 == null) continue;
        delete this.highlighted_links[id4];
      }
    }
  }
  /** @deprecated See {@link LGraphCanvas.processSelect} */
  processNodeSelected(item3, e2) {
    this.processSelect(
      item3,
      e2,
      e2 && (e2.shiftKey || e2.metaKey || e2.ctrlKey || this.multi_select)
    );
  }
  /** @deprecated See {@link LGraphCanvas.select} */
  selectNode(node22, add_to_current_selection) {
    if (node22 == null) {
      this.deselectAll();
    } else {
      this.selectNodes([node22], add_to_current_selection);
    }
  }
  get empty() {
    if (!this.graph) throw new NullGraphError();
    return this.graph.empty;
  }
  get positionableItems() {
    if (!this.graph) throw new NullGraphError();
    return this.graph.positionableItems();
  }
  /**
   * Selects several items.
   * @param items Items to select - if falsy, all items on the canvas will be selected
   * @param add_to_current_selection If set, the items will be added to the current selection instead of replacing it
   */
  selectItems(items2, add_to_current_selection) {
    const itemsToSelect = items2 ?? this.positionableItems;
    if (!add_to_current_selection) this.deselectAll();
    for (const item3 of itemsToSelect) this.select(item3);
    this.onSelectionChange?.(this.selected_nodes);
    this.setDirty(true);
  }
  /**
   * selects several nodes (or adds them to the current selection)
   * @deprecated See {@link LGraphCanvas.selectItems}
   */
  selectNodes(nodes, add_to_current_selection) {
    this.selectItems(nodes, add_to_current_selection);
  }
  /** @deprecated See {@link LGraphCanvas.deselect} */
  deselectNode(node22) {
    this.deselect(node22);
  }
  /**
   * Deselects all items on the canvas.
   * @param keepSelected If set, this item will not be removed from the selection.
   */
  deselectAll(keepSelected) {
    if (!this.graph) return;
    const selected2 = this.selectedItems;
    let wasSelected;
    for (const sel of selected2) {
      if (sel === keepSelected) {
        wasSelected = sel;
        continue;
      }
      sel.onDeselected?.();
      sel.selected = false;
    }
    selected2.clear();
    if (wasSelected) selected2.add(wasSelected);
    this.setDirty(true);
    const oldNode = keepSelected?.id == null ? null : this.selected_nodes[keepSelected.id];
    this.selected_nodes = {};
    this.current_node = null;
    this.highlighted_links = {};
    if (keepSelected instanceof LGraphNode) {
      if (oldNode) this.selected_nodes[oldNode.id] = oldNode;
      if (keepSelected.inputs) {
        for (const input of keepSelected.inputs) {
          if (input.link == null) continue;
          this.highlighted_links[input.link] = true;
        }
      }
      if (keepSelected.outputs) {
        for (const id4 of keepSelected.outputs.flatMap((x2) => x2.links)) {
          if (id4 == null) continue;
          this.highlighted_links[id4] = true;
        }
      }
    }
    this.onSelectionChange?.(this.selected_nodes);
  }
  /** @deprecated See {@link LGraphCanvas.deselectAll} */
  deselectAllNodes() {
    this.deselectAll();
  }
  /**
   * Deletes all selected items from the graph.
   * @todo Refactor deletion task to LGraph.  Selection is a canvas property, delete is a graph action.
   */
  deleteSelected() {
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    this.emitBeforeChange();
    graph.beforeChange();
    for (const item3 of this.selectedItems) {
      if (item3 instanceof LGraphNode) {
        const node22 = item3;
        if (node22.block_delete) continue;
        node22.connectInputToOutput();
        graph.remove(node22);
        this.onNodeDeselected?.(node22);
      } else if (item3 instanceof LGraphGroup) {
        graph.remove(item3);
      } else if (item3 instanceof Reroute) {
        graph.removeReroute(item3.id);
      }
    }
    this.selected_nodes = {};
    this.selectedItems.clear();
    this.current_node = null;
    this.highlighted_links = {};
    this.onSelectionChange?.(this.selected_nodes);
    this.setDirty(true);
    graph.afterChange();
    this.emitAfterChange();
  }
  /**
   * deletes all nodes in the current selection from the graph
   * @deprecated See {@link LGraphCanvas.deleteSelected}
   */
  deleteSelectedNodes() {
    this.deleteSelected();
  }
  /**
   * centers the camera on a given node
   */
  centerOnNode(node22) {
    const dpi = window?.devicePixelRatio || 1;
    this.ds.offset[0] = -node22.pos[0] - node22.size[0] * 0.5 + this.canvas.width * 0.5 / (this.ds.scale * dpi);
    this.ds.offset[1] = -node22.pos[1] - node22.size[1] * 0.5 + this.canvas.height * 0.5 / (this.ds.scale * dpi);
    this.setDirty(true, true);
  }
  /**
   * adds some useful properties to a mouse event, like the position in graph coordinates
   */
  adjustMouseEvent(e2) {
    let clientX_rel = e2.clientX;
    let clientY_rel = e2.clientY;
    if (this.canvas) {
      const b2 = this.canvas.getBoundingClientRect();
      clientX_rel -= b2.left;
      clientY_rel -= b2.top;
    }
    e2.safeOffsetX = clientX_rel;
    e2.safeOffsetY = clientY_rel;
    if (e2.deltaX === void 0)
      e2.deltaX = clientX_rel - this.last_mouse_position[0];
    if (e2.deltaY === void 0)
      e2.deltaY = clientY_rel - this.last_mouse_position[1];
    this.last_mouse_position[0] = clientX_rel;
    this.last_mouse_position[1] = clientY_rel;
    e2.canvasX = clientX_rel / this.ds.scale - this.ds.offset[0];
    e2.canvasY = clientY_rel / this.ds.scale - this.ds.offset[1];
  }
  /**
   * changes the zoom level of the graph (default is 1), you can pass also a place used to pivot the zoom
   */
  setZoom(value3, zooming_center) {
    this.ds.changeScale(value3, zooming_center);
    this.#dirty();
  }
  /**
   * converts a coordinate from graph coordinates to canvas2D coordinates
   */
  convertOffsetToCanvas(pos, out) {
    return this.ds.convertOffsetToCanvas(pos, out);
  }
  /**
   * converts a coordinate from Canvas2D coordinates to graph space
   */
  convertCanvasToOffset(pos, out) {
    return this.ds.convertCanvasToOffset(pos, out);
  }
  // converts event coordinates from canvas2D to graph coordinates
  convertEventToCanvasOffset(e2) {
    const rect = this.canvas.getBoundingClientRect();
    return this.convertCanvasToOffset([
      e2.clientX - rect.left,
      e2.clientY - rect.top
    ]);
  }
  /**
   * brings a node to front (above all other nodes)
   */
  bringToFront(node22) {
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    const i2 = graph._nodes.indexOf(node22);
    if (i2 == -1) return;
    graph._nodes.splice(i2, 1);
    graph._nodes.push(node22);
  }
  /**
   * sends a node to the back (below all other nodes)
   */
  sendToBack(node22) {
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    const i2 = graph._nodes.indexOf(node22);
    if (i2 == -1) return;
    graph._nodes.splice(i2, 1);
    graph._nodes.unshift(node22);
  }
  /**
   * Determines which nodes are visible and populates {@link out} with the results.
   * @param nodes The list of nodes to check - if falsy, all nodes in the graph will be checked
   * @param out Array to write visible nodes into - if falsy, a new array is created instead
   * @returns Array passed ({@link out}), or a new array containing all visible nodes
   */
  computeVisibleNodes(nodes, out) {
    const visible_nodes = out || [];
    visible_nodes.length = 0;
    if (!this.graph) throw new NullGraphError();
    const _nodes = nodes || this.graph._nodes;
    for (const node22 of _nodes) {
      node22.updateArea(this.ctx);
      if (!overlapBounding(this.visible_area, node22.renderArea)) continue;
      visible_nodes.push(node22);
    }
    return visible_nodes;
  }
  /**
   * Checks if a node is visible on the canvas.
   * @param node The node to check
   * @returns `true` if the node is visible, otherwise `false`
   */
  isNodeVisible(node22) {
    return this.#visible_node_ids.has(node22.id);
  }
  /**
   * renders the whole canvas content, by rendering in two separated canvas, one containing the background grid and the connections, and one containing the nodes)
   */
  draw(force_canvas, force_bgcanvas) {
    if (!this.canvas || this.canvas.width == 0 || this.canvas.height == 0) return;
    const now2 = LiteGraph.getTime();
    this.render_time = (now2 - this.last_draw_time) * 1e-3;
    this.last_draw_time = now2;
    if (this.graph) this.ds.computeVisibleArea(this.viewport);
    if (this.dirty_canvas || force_canvas) {
      this.computeVisibleNodes(void 0, this.visible_nodes);
      this.#visible_node_ids = new Set(this.visible_nodes.map((node22) => node22.id));
    }
    if (this.dirty_bgcanvas || force_bgcanvas || this.always_render_background || this.graph?._last_trigger_time && now2 - this.graph._last_trigger_time < 1e3) {
      this.drawBackCanvas();
    }
    if (this.dirty_canvas || force_canvas) this.drawFrontCanvas();
    this.fps = this.render_time ? 1 / this.render_time : 0;
    this.frame++;
  }
  /**
   * draws the front canvas (the one containing all the nodes)
   */
  drawFrontCanvas() {
    this.dirty_canvas = false;
    const { ctx, canvas: canvas2, linkConnector } = this;
    if (ctx.start2D && !this.viewport) {
      ctx.start2D();
      ctx.restore();
      ctx.setTransform(1, 0, 0, 1, 0, 0);
    }
    const area = this.viewport || this.dirty_area;
    if (area) {
      ctx.save();
      ctx.beginPath();
      ctx.rect(area[0], area[1], area[2], area[3]);
      ctx.clip();
    }
    this.#snapToGrid = this.#shiftDown || LiteGraph.alwaysSnapToGrid ? this.graph?.getSnapToGridSize() : void 0;
    if (this.clear_background) {
      if (area) ctx.clearRect(area[0], area[1], area[2], area[3]);
      else ctx.clearRect(0, 0, canvas2.width, canvas2.height);
    }
    if (this.bgcanvas == this.canvas) {
      this.drawBackCanvas();
    } else {
      const scale = window.devicePixelRatio;
      ctx.drawImage(
        this.bgcanvas,
        0,
        0,
        this.bgcanvas.width / scale,
        this.bgcanvas.height / scale
      );
    }
    this.onRender?.(canvas2, ctx);
    if (this.show_info) {
      this.renderInfo(ctx, area ? area[0] : 0, area ? area[1] : 0);
    }
    if (this.graph) {
      ctx.save();
      this.ds.toCanvasContext(ctx);
      const { visible_nodes } = this;
      const drawSnapGuides = this.#snapToGrid && this.isDragging;
      for (const node22 of visible_nodes) {
        ctx.save();
        if (drawSnapGuides && this.selectedItems.has(node22))
          this.drawSnapGuide(ctx, node22);
        ctx.translate(node22.pos[0], node22.pos[1]);
        this.drawNode(node22, ctx);
        ctx.restore();
      }
      if (this.render_execution_order) {
        this.drawExecutionOrder(ctx);
      }
      if (this.graph.config.links_ontop) {
        this.drawConnections(ctx);
      }
      if (linkConnector.isConnecting) {
        const { renderLinks } = linkConnector;
        const highlightPos = this.#getHighlightPosition();
        ctx.lineWidth = this.connections_width;
        for (const renderLink of renderLinks) {
          const { fromSlot, fromPos: pos, fromDirection, dragDirection } = renderLink;
          const connShape = fromSlot.shape;
          const connType = fromSlot.type;
          const colour = connType === LiteGraph.EVENT ? LiteGraph.EVENT_LINK_COLOR : LiteGraph.CONNECTING_LINK_COLOR;
          this.renderLink(
            ctx,
            pos,
            highlightPos,
            null,
            false,
            null,
            colour,
            fromDirection,
            dragDirection
          );
          ctx.beginPath();
          if (connType === LiteGraph.EVENT || connShape === RenderShape.BOX) {
            ctx.rect(pos[0] - 6 + 0.5, pos[1] - 5 + 0.5, 14, 10);
            ctx.fill();
            ctx.beginPath();
            ctx.rect(
              this.graph_mouse[0] - 6 + 0.5,
              this.graph_mouse[1] - 5 + 0.5,
              14,
              10
            );
          } else if (connShape === RenderShape.ARROW) {
            ctx.moveTo(pos[0] + 8, pos[1] + 0.5);
            ctx.lineTo(pos[0] - 4, pos[1] + 6 + 0.5);
            ctx.lineTo(pos[0] - 4, pos[1] - 6 + 0.5);
            ctx.closePath();
          } else {
            ctx.arc(pos[0], pos[1], 4, 0, Math.PI * 2);
            ctx.fill();
            ctx.beginPath();
            ctx.arc(this.graph_mouse[0], this.graph_mouse[1], 4, 0, Math.PI * 2);
          }
          ctx.fill();
        }
        this.#renderSnapHighlight(ctx, highlightPos);
      }
      if (this.dragging_rectangle) {
        const { eDown, eMove } = this.pointer;
        ctx.strokeStyle = "#FFF";
        if (eDown && eMove) {
          const transform2 = ctx.getTransform();
          const ratio = Math.max(1, window.devicePixelRatio);
          ctx.setTransform(ratio, 0, 0, ratio, 0, 0);
          const x2 = eDown.safeOffsetX;
          const y2 = eDown.safeOffsetY;
          ctx.strokeRect(x2, y2, eMove.safeOffsetX - x2, eMove.safeOffsetY - y2);
          ctx.setTransform(transform2);
        } else {
          const [x2, y2, w2, h2] = this.dragging_rectangle;
          ctx.strokeRect(x2, y2, w2, h2);
        }
      }
      if (this.over_link_center && this.render_link_tooltip)
        this.drawLinkTooltip(ctx, this.over_link_center);
      else
        this.onDrawLinkTooltip?.(ctx, null);
      this.onDrawForeground?.(ctx, this.visible_area);
      ctx.restore();
    }
    this.onDrawOverlay?.(ctx);
    if (area) ctx.restore();
  }
  /** @returns If the pointer is over a link centre marker, the link segment it belongs to.  Otherwise, `undefined`.  */
  #getLinkCentreOnPos(e2) {
    for (const linkSegment of this.renderedPaths) {
      const centre = linkSegment._pos;
      if (!centre) continue;
      if (isInRectangle(e2.canvasX, e2.canvasY, centre[0] - 4, centre[1] - 4, 8, 8)) {
        return linkSegment;
      }
    }
  }
  /** Get the target snap / highlight point in graph space */
  #getHighlightPosition() {
    return LiteGraph.snaps_for_comfy ? this._highlight_pos ?? this.graph_mouse : this.graph_mouse;
  }
  /**
   * Renders indicators showing where a link will connect if released.
   * Partial border over target node and a highlight over the slot itself.
   * @param ctx Canvas 2D context
   */
  #renderSnapHighlight(ctx, highlightPos) {
    if (!this._highlight_pos) return;
    ctx.fillStyle = "#ffcc00";
    ctx.beginPath();
    const shape = this._highlight_input?.shape;
    if (shape === RenderShape.ARROW) {
      ctx.moveTo(highlightPos[0] + 8, highlightPos[1] + 0.5);
      ctx.lineTo(highlightPos[0] - 4, highlightPos[1] + 6 + 0.5);
      ctx.lineTo(highlightPos[0] - 4, highlightPos[1] - 6 + 0.5);
      ctx.closePath();
    } else {
      ctx.arc(highlightPos[0], highlightPos[1], 6, 0, Math.PI * 2);
    }
    ctx.fill();
    if (!LiteGraph.snap_highlights_node) return;
    const { linkConnector } = this;
    const { overWidget } = linkConnector;
    const node22 = this.node_over;
    if (!(node22 && linkConnector.isConnecting)) return;
    const { strokeStyle, lineWidth } = ctx;
    const area = node22.boundingRect;
    const gap = 3;
    const radius = LiteGraph.ROUND_RADIUS + gap;
    const x2 = area[0] - gap;
    const y2 = area[1] - gap;
    const width2 = area[2] + gap * 2;
    const height = area[3] + gap * 2;
    ctx.beginPath();
    ctx.roundRect(x2, y2, width2, height, radius);
    const start2 = linkConnector.state.connectingTo === "output" ? 0 : 1;
    const inverter = start2 ? -1 : 1;
    const hx = highlightPos[0];
    const hy = highlightPos[1];
    const gRadius = width2 < height ? width2 : width2 * Math.max(height / width2, 0.5);
    const gradient = ctx.createRadialGradient(hx, hy, 0, hx, hy, gRadius);
    gradient.addColorStop(1, "#00000000");
    gradient.addColorStop(0, "#ffcc00aa");
    const linearGradient = ctx.createLinearGradient(x2, y2, x2 + width2, y2);
    linearGradient.addColorStop(0.5, "#00000000");
    linearGradient.addColorStop(start2 + 0.67 * inverter, "#ddeeff33");
    linearGradient.addColorStop(start2 + inverter, "#ffcc0055");
    ctx.setLineDash([radius, radius * 1e-3]);
    ctx.lineWidth = 1;
    ctx.strokeStyle = linearGradient;
    ctx.stroke();
    if (overWidget) {
      const { computedHeight } = overWidget;
      ctx.beginPath();
      const { pos: [nodeX, nodeY] } = node22;
      const height2 = LiteGraph.NODE_WIDGET_HEIGHT;
      if (overWidget.type.startsWith("custom") && computedHeight != null && computedHeight > height2 * 2) {
        ctx.rect(
          nodeX + 9,
          nodeY + overWidget.y + 9,
          (overWidget.width ?? area[2]) - 18,
          computedHeight - 18
        );
      } else {
        ctx.roundRect(
          nodeX + 15,
          nodeY + overWidget.y,
          overWidget.width ?? area[2],
          height2,
          height2 * 0.5
        );
      }
      ctx.stroke();
    }
    ctx.strokeStyle = gradient;
    ctx.stroke();
    ctx.setLineDash([]);
    ctx.lineWidth = lineWidth;
    ctx.strokeStyle = strokeStyle;
  }
  /**
   * draws some useful stats in the corner of the canvas
   */
  renderInfo(ctx, x2, y2) {
    x2 = x2 || 10;
    y2 = y2 || this.canvas.offsetHeight - 80;
    ctx.save();
    ctx.translate(x2, y2);
    ctx.font = "10px Arial";
    ctx.fillStyle = "#888";
    ctx.textAlign = "left";
    if (this.graph) {
      ctx.fillText(`T: ${this.graph.globaltime.toFixed(2)}s`, 5, 13 * 1);
      ctx.fillText(`I: ${this.graph.iteration}`, 5, 13 * 2);
      ctx.fillText(`N: ${this.graph._nodes.length} [${this.visible_nodes.length}]`, 5, 13 * 3);
      ctx.fillText(`V: ${this.graph._version}`, 5, 13 * 4);
      ctx.fillText(`FPS:${this.fps.toFixed(2)}`, 5, 13 * 5);
    } else {
      ctx.fillText("No graph selected", 5, 13 * 1);
    }
    ctx.restore();
  }
  /**
   * draws the back canvas (the one containing the background and the connections)
   */
  drawBackCanvas() {
    const canvas2 = this.bgcanvas;
    if (canvas2.width != this.canvas.width || canvas2.height != this.canvas.height) {
      canvas2.width = this.canvas.width;
      canvas2.height = this.canvas.height;
    }
    if (!this.bgctx) {
      this.bgctx = this.bgcanvas.getContext("2d");
    }
    const ctx = this.bgctx;
    if (!ctx) throw new TypeError("Background canvas context was null.");
    const viewport = this.viewport || [0, 0, ctx.canvas.width, ctx.canvas.height];
    if (this.clear_background) {
      ctx.clearRect(viewport[0], viewport[1], viewport[2], viewport[3]);
    }
    const bg_already_painted = this.onRenderBackground ? this.onRenderBackground(canvas2, ctx) : false;
    if (!this.viewport) {
      const scale = window.devicePixelRatio;
      ctx.restore();
      ctx.setTransform(scale, 0, 0, scale, 0, 0);
    }
    if (this.graph) {
      ctx.save();
      this.ds.toCanvasContext(ctx);
      if (this.ds.scale < 1.5 && !bg_already_painted && this.clear_background_color) {
        ctx.fillStyle = this.clear_background_color;
        ctx.fillRect(
          this.visible_area[0],
          this.visible_area[1],
          this.visible_area[2],
          this.visible_area[3]
        );
      }
      if (this.background_image && this.ds.scale > 0.5 && !bg_already_painted) {
        if (this.zoom_modify_alpha) {
          ctx.globalAlpha = (1 - 0.5 / this.ds.scale) * this.editor_alpha;
        } else {
          ctx.globalAlpha = this.editor_alpha;
        }
        ctx.imageSmoothingEnabled = false;
        if (!this._bg_img || this._bg_img.name != this.background_image) {
          this._bg_img = new Image();
          this._bg_img.name = this.background_image;
          this._bg_img.src = this.background_image;
          const that = this;
          this._bg_img.addEventListener("load", function() {
            that.draw(true, true);
          });
        }
        let pattern = this._pattern;
        if (pattern == null && this._bg_img.width > 0) {
          pattern = ctx.createPattern(this._bg_img, "repeat");
          this._pattern_img = this._bg_img;
          this._pattern = pattern;
        }
        if (pattern) {
          ctx.fillStyle = pattern;
          ctx.fillRect(
            this.visible_area[0],
            this.visible_area[1],
            this.visible_area[2],
            this.visible_area[3]
          );
          ctx.fillStyle = "transparent";
        }
        ctx.globalAlpha = 1;
        ctx.imageSmoothingEnabled = true;
      }
      if (this.graph._groups.length) {
        this.drawGroups(canvas2, ctx);
      }
      this.onDrawBackground?.(ctx, this.visible_area);
      if (this.render_canvas_border) {
        ctx.strokeStyle = "#235";
        ctx.strokeRect(0, 0, canvas2.width, canvas2.height);
      }
      if (this.render_connections_shadows) {
        ctx.shadowColor = "#000";
        ctx.shadowOffsetX = 0;
        ctx.shadowOffsetY = 0;
        ctx.shadowBlur = 6;
      } else {
        ctx.shadowColor = "rgba(0,0,0,0)";
      }
      this.drawConnections(ctx);
      ctx.shadowColor = "rgba(0,0,0,0)";
      ctx.restore();
    }
    this.dirty_bgcanvas = false;
    this.dirty_canvas = true;
  }
  /**
   * draws the given node inside the canvas
   */
  drawNode(node22, ctx) {
    this.current_node = node22;
    const color2 = node22.renderingColor;
    const bgcolor = node22.renderingBgColor;
    const { low_quality, editor_alpha } = this;
    ctx.globalAlpha = editor_alpha;
    if (this.render_shadows && !low_quality) {
      ctx.shadowColor = LiteGraph.DEFAULT_SHADOW_COLOR;
      ctx.shadowOffsetX = 2 * this.ds.scale;
      ctx.shadowOffsetY = 2 * this.ds.scale;
      ctx.shadowBlur = 3 * this.ds.scale;
    } else {
      ctx.shadowColor = "transparent";
    }
    if (node22.flags.collapsed && node22.onDrawCollapsed?.(ctx, this) == true)
      return;
    const shape = node22._shape || RenderShape.BOX;
    const size = LGraphCanvas.#temp_vec2;
    size.set(node22.renderingSize);
    if (node22.collapsed) {
      ctx.font = this.inner_text_font;
    }
    if (node22.clip_area) {
      ctx.save();
      ctx.beginPath();
      if (shape == RenderShape.BOX) {
        ctx.rect(0, 0, size[0], size[1]);
      } else if (shape == RenderShape.ROUND) {
        ctx.roundRect(0, 0, size[0], size[1], [10]);
      } else if (shape == RenderShape.CIRCLE) {
        ctx.arc(size[0] * 0.5, size[1] * 0.5, size[0] * 0.5, 0, Math.PI * 2);
      }
      ctx.clip();
    }
    this.drawNodeShape(
      node22,
      ctx,
      size,
      color2,
      bgcolor,
      !!node22.selected
    );
    if (!low_quality) {
      node22.drawBadges(ctx);
    }
    ctx.shadowColor = "transparent";
    ctx.strokeStyle = LiteGraph.NODE_BOX_OUTLINE_COLOR;
    node22.onDrawForeground?.(ctx, this, this.canvas);
    ctx.font = this.inner_text_font;
    if (!node22.collapsed) {
      const slotsBounds = node22.layoutSlots();
      const widgetStartY = slotsBounds ? slotsBounds[1] + slotsBounds[3] : 0;
      node22.layoutWidgets({ widgetStartY });
      node22.layoutWidgetInputSlots();
      node22.drawSlots(ctx, {
        fromSlot: this.linkConnector.renderLinks[0]?.fromSlot,
        colorContext: this,
        editorAlpha: this.editor_alpha,
        lowQuality: this.low_quality
      });
      ctx.textAlign = "left";
      ctx.globalAlpha = 1;
      this.drawNodeWidgets(node22, widgetStartY, ctx);
    } else if (this.render_collapsed_slots) {
      node22.drawCollapsedSlots(ctx);
    }
    if (node22.clip_area) {
      ctx.restore();
    }
    ctx.globalAlpha = 1;
  }
  /**
   * Draws the link mouseover effect and tooltip.
   * @param ctx Canvas 2D context to draw on
   * @param link The link to render the mouseover effect for
   * @remarks
   * Called against {@link LGraphCanvas.over_link_center}.
   * @todo Split tooltip from hover, so it can be drawn / eased separately
   */
  drawLinkTooltip(ctx, link2) {
    const pos = link2._pos;
    ctx.fillStyle = "black";
    ctx.beginPath();
    if (this.linkMarkerShape === LinkMarkerShape.Arrow) {
      const transform2 = ctx.getTransform();
      ctx.translate(pos[0], pos[1]);
      if (Number.isFinite(link2._centreAngle)) ctx.rotate(link2._centreAngle);
      ctx.moveTo(-2, -3);
      ctx.lineTo(4, 0);
      ctx.lineTo(-2, 3);
      ctx.setTransform(transform2);
    } else if (this.linkMarkerShape == null || this.linkMarkerShape === LinkMarkerShape.Circle) {
      ctx.arc(pos[0], pos[1], 3, 0, Math.PI * 2);
    }
    ctx.fill();
    const { data: data30 } = link2;
    if (data30 == null) return;
    if (this.onDrawLinkTooltip?.(ctx, link2, this) == true) return;
    let text2 = null;
    if (typeof data30 === "number")
      text2 = data30.toFixed(2);
    else if (typeof data30 === "string")
      text2 = `"${data30}"`;
    else if (typeof data30 === "boolean")
      text2 = String(data30);
    else if (data30.toToolTip)
      text2 = data30.toToolTip();
    else
      text2 = `[${data30.constructor.name}]`;
    if (text2 == null) return;
    text2 = text2.substring(0, 30);
    ctx.font = "14px Courier New";
    const info = ctx.measureText(text2);
    const w2 = info.width + 20;
    const h2 = 24;
    ctx.shadowColor = "black";
    ctx.shadowOffsetX = 2;
    ctx.shadowOffsetY = 2;
    ctx.shadowBlur = 3;
    ctx.fillStyle = "#454";
    ctx.beginPath();
    ctx.roundRect(pos[0] - w2 * 0.5, pos[1] - 15 - h2, w2, h2, [3]);
    ctx.moveTo(pos[0] - 10, pos[1] - 15);
    ctx.lineTo(pos[0] + 10, pos[1] - 15);
    ctx.lineTo(pos[0], pos[1] - 5);
    ctx.fill();
    ctx.shadowColor = "transparent";
    ctx.textAlign = "center";
    ctx.fillStyle = "#CEC";
    ctx.fillText(text2, pos[0], pos[1] - 15 - h2 * 0.3);
  }
  /**
   * Draws the shape of the given node on the canvas
   * @param node The node to draw
   * @param ctx 2D canvas rendering context used to draw
   * @param size Size of the background to draw, in graph units.  Differs from node size if collapsed, etc.
   * @param fgcolor Foreground colour - used for text
   * @param bgcolor Background colour of the node
   * @param selected Whether to render the node as selected.  Likely to be removed in future, as current usage is simply the selected property of the node.
   */
  drawNodeShape(node22, ctx, size, fgcolor, bgcolor, selected2) {
    ctx.strokeStyle = fgcolor;
    ctx.fillStyle = LiteGraph.use_legacy_node_error_indicator ? "#F00" : bgcolor;
    const title_height = LiteGraph.NODE_TITLE_HEIGHT;
    const { low_quality } = this;
    const { collapsed: collapsed2 } = node22.flags;
    const shape = node22.renderingShape;
    const { title_mode } = node22;
    const render_title = title_mode == TitleMode.TRANSPARENT_TITLE || title_mode == TitleMode.NO_TITLE ? false : true;
    const area = LGraphCanvas.#tmp_area;
    area.set(node22.boundingRect);
    area[0] -= node22.pos[0];
    area[1] -= node22.pos[1];
    const old_alpha = ctx.globalAlpha;
    ctx.beginPath();
    if (shape == RenderShape.BOX || low_quality) {
      ctx.fillRect(area[0], area[1], area[2], area[3]);
    } else if (shape == RenderShape.ROUND || shape == RenderShape.CARD) {
      ctx.roundRect(
        area[0],
        area[1],
        area[2],
        area[3],
        shape == RenderShape.CARD ? [LiteGraph.ROUND_RADIUS, LiteGraph.ROUND_RADIUS, 0, 0] : [LiteGraph.ROUND_RADIUS]
      );
    } else if (shape == RenderShape.CIRCLE) {
      ctx.arc(size[0] * 0.5, size[1] * 0.5, size[0] * 0.5, 0, Math.PI * 2);
    }
    ctx.fill();
    if (node22.has_errors && !LiteGraph.use_legacy_node_error_indicator) {
      strokeShape(ctx, area, {
        shape,
        title_mode,
        title_height,
        padding: 12,
        colour: LiteGraph.NODE_ERROR_COLOUR,
        collapsed: collapsed2,
        thickness: 10
      });
    }
    if (!collapsed2 && render_title) {
      ctx.shadowColor = "transparent";
      ctx.fillStyle = "rgba(0,0,0,0.2)";
      ctx.fillRect(0, -1, area[2], 2);
    }
    ctx.shadowColor = "transparent";
    node22.onDrawBackground?.(ctx);
    if (render_title || title_mode == TitleMode.TRANSPARENT_TITLE) {
      node22.drawTitleBarBackground(ctx, {
        scale: this.ds.scale,
        low_quality
      });
      node22.drawTitleBox(ctx, {
        scale: this.ds.scale,
        low_quality,
        box_size: 10
      });
      ctx.globalAlpha = old_alpha;
      node22.drawTitleText(ctx, {
        scale: this.ds.scale,
        default_title_color: this.node_title_color,
        low_quality
      });
      node22.onDrawTitle?.(ctx);
    }
    if (selected2) {
      node22.onBounding?.(area);
      const padding = node22.has_errors && !LiteGraph.use_legacy_node_error_indicator ? 20 : void 0;
      strokeShape(ctx, area, {
        shape,
        title_height,
        title_mode,
        padding,
        collapsed: node22.flags?.collapsed
      });
    }
    if (node22.execute_triggered != null && node22.execute_triggered > 0) node22.execute_triggered--;
    if (node22.action_triggered != null && node22.action_triggered > 0) node22.action_triggered--;
  }
  /**
   * Draws a snap guide for a {@link Positionable} item.
   *
   * Initial design was a simple white rectangle representing the location the
   * item would land if dropped.
   * @param ctx The 2D canvas context to draw on
   * @param item The item to draw a snap guide for
   * @param shape The shape of the snap guide to draw
   * @todo Update to align snapping with boundingRect
   * @todo Shapes
   */
  drawSnapGuide(ctx, item3, shape = RenderShape.ROUND) {
    const snapGuide = LGraphCanvas.#temp;
    snapGuide.set(item3.boundingRect);
    const { pos } = item3;
    const offsetX = pos[0] - snapGuide[0];
    const offsetY = pos[1] - snapGuide[1];
    snapGuide[0] += offsetX;
    snapGuide[1] += offsetY;
    if (this.#snapToGrid) snapPoint(snapGuide, this.#snapToGrid);
    snapGuide[0] -= offsetX;
    snapGuide[1] -= offsetY;
    const { globalAlpha } = ctx;
    ctx.globalAlpha = 1;
    ctx.beginPath();
    const [x2, y2, w2, h2] = snapGuide;
    if (shape === RenderShape.CIRCLE) {
      const midX = x2 + w2 * 0.5;
      const midY = y2 + h2 * 0.5;
      const radius = Math.min(w2 * 0.5, h2 * 0.5);
      ctx.arc(midX, midY, radius, 0, Math.PI * 2);
    } else {
      ctx.rect(x2, y2, w2, h2);
    }
    ctx.lineWidth = 0.5;
    ctx.strokeStyle = "#FFFFFF66";
    ctx.fillStyle = "#FFFFFF22";
    ctx.fill();
    ctx.stroke();
    ctx.globalAlpha = globalAlpha;
  }
  drawConnections(ctx) {
    this.renderedPaths.clear();
    if (this.links_render_mode === LinkRenderType.HIDDEN_LINK) return;
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    const visibleReroutes = [];
    const now2 = LiteGraph.getTime();
    const { visible_area } = this;
    LGraphCanvas.#margin_area[0] = visible_area[0] - 20;
    LGraphCanvas.#margin_area[1] = visible_area[1] - 20;
    LGraphCanvas.#margin_area[2] = visible_area[2] + 40;
    LGraphCanvas.#margin_area[3] = visible_area[3] + 40;
    ctx.lineWidth = this.connections_width;
    ctx.fillStyle = "#AAA";
    ctx.strokeStyle = "#AAA";
    ctx.globalAlpha = this.editor_alpha;
    const nodes = graph._nodes;
    for (const node22 of nodes) {
      const { inputs } = node22;
      if (!inputs?.length) continue;
      for (const [i2, input] of inputs.entries()) {
        if (!input || input.link == null) continue;
        const link_id = input.link;
        const link2 = graph._links.get(link_id);
        if (!link2) continue;
        const endPos = node22.getInputPos(i2);
        const start_node = graph.getNodeById(link2.origin_id);
        if (start_node == null) continue;
        const outputId = link2.origin_slot;
        const startPos = outputId === -1 ? [start_node.pos[0] + 10, start_node.pos[1] + 10] : start_node.getOutputPos(outputId);
        const output = start_node.outputs[outputId];
        if (!output) continue;
        this.#renderAllLinkSegments(ctx, link2, startPos, endPos, visibleReroutes, now2, output.dir, input.dir);
      }
    }
    if (graph.floatingLinks.size > 0) {
      this.#renderFloatingLinks(ctx, graph, visibleReroutes, now2);
    }
    for (const reroute of visibleReroutes) {
      if (this.#snapToGrid && this.isDragging && this.selectedItems.has(reroute)) {
        this.drawSnapGuide(ctx, reroute, RenderShape.CIRCLE);
      }
      reroute.draw(ctx);
    }
    ctx.globalAlpha = 1;
  }
  #renderFloatingLinks(ctx, graph, visibleReroutes, now2) {
    for (const link2 of graph.floatingLinks.values()) {
      const reroutes = LLink.getReroutes(graph, link2);
      const firstReroute = reroutes[0];
      const reroute = reroutes.at(-1);
      if (!firstReroute || !reroute?.floating) continue;
      if (reroute.floating.slotType === "input") {
        const node22 = graph.getNodeById(link2.target_id);
        if (!node22) continue;
        const startPos = firstReroute.pos;
        const endPos = node22.getInputPos(link2.target_slot);
        const endDirection = node22.inputs[link2.target_slot]?.dir;
        firstReroute._dragging = true;
        this.#renderAllLinkSegments(ctx, link2, startPos, endPos, visibleReroutes, now2, LinkDirection.CENTER, endDirection);
      } else {
        const node22 = graph.getNodeById(link2.origin_id);
        if (!node22) continue;
        const startPos = node22.getOutputPos(link2.origin_slot);
        const endPos = reroute.pos;
        const startDirection = node22.outputs[link2.origin_slot]?.dir;
        link2._dragging = true;
        this.#renderAllLinkSegments(ctx, link2, startPos, endPos, visibleReroutes, now2, startDirection, LinkDirection.CENTER);
      }
    }
  }
  #renderAllLinkSegments(ctx, link2, startPos, endPos, visibleReroutes, now2, startDirection, endDirection) {
    const { graph, renderedPaths } = this;
    if (!graph) return;
    const reroutes = LLink.getReroutes(graph, link2);
    const points = [
      startPos,
      ...reroutes.map((x2) => x2.pos),
      endPos
    ];
    const pointsX = points.map((x2) => x2[0]);
    const pointsY = points.map((x2) => x2[1]);
    LGraphCanvas.#link_bounding[0] = Math.min(...pointsX);
    LGraphCanvas.#link_bounding[1] = Math.min(...pointsY);
    LGraphCanvas.#link_bounding[2] = Math.max(...pointsX) - LGraphCanvas.#link_bounding[0];
    LGraphCanvas.#link_bounding[3] = Math.max(...pointsY) - LGraphCanvas.#link_bounding[1];
    if (!overlapBounding(LGraphCanvas.#link_bounding, LGraphCanvas.#margin_area))
      return;
    const start_dir = startDirection || LinkDirection.RIGHT;
    const end_dir = endDirection || LinkDirection.LEFT;
    if (reroutes.length) {
      let startControl;
      const l2 = reroutes.length;
      for (let j2 = 0; j2 < l2; j2++) {
        const reroute = reroutes[j2];
        if (!renderedPaths.has(reroute)) {
          renderedPaths.add(reroute);
          visibleReroutes.push(reroute);
          reroute._colour = link2.color || LGraphCanvas.link_type_colors[link2.type] || this.default_link_color;
          const prevReroute = reroute.parentId == null ? void 0 : graph.reroutes.get(reroute.parentId);
          const rerouteStartPos = prevReroute?.pos ?? startPos;
          reroute.calculateAngle(this.last_draw_time, graph, rerouteStartPos);
          if (!reroute._dragging) {
            this.renderLink(
              ctx,
              rerouteStartPos,
              reroute.pos,
              link2,
              false,
              0,
              null,
              start_dir,
              end_dir,
              {
                startControl,
                endControl: reroute.controlPoint,
                reroute
              }
            );
          }
        }
        if (!startControl && reroutes.at(-1)?.floating?.slotType === "input") {
          startControl = [0, 0];
        } else {
          const nextPos = reroutes[j2 + 1]?.pos ?? endPos;
          const dist3 = Math.min(80, distance(reroute.pos, nextPos) * 0.25);
          startControl = [dist3 * reroute.cos, dist3 * reroute.sin];
        }
      }
      if (link2._dragging) return;
      const segmentStartPos = points.at(-2) ?? startPos;
      this.renderLink(
        ctx,
        segmentStartPos,
        endPos,
        link2,
        false,
        0,
        null,
        start_dir,
        end_dir,
        { startControl }
      );
    } else if (!link2._dragging) {
      this.renderLink(
        ctx,
        startPos,
        endPos,
        link2,
        false,
        0,
        null,
        start_dir,
        end_dir
      );
    }
    renderedPaths.add(link2);
    if (link2?._last_time && now2 - link2._last_time < 1e3) {
      const f2 = 2 - (now2 - link2._last_time) * 2e-3;
      const tmp = ctx.globalAlpha;
      ctx.globalAlpha = tmp * f2;
      this.renderLink(
        ctx,
        startPos,
        endPos,
        link2,
        true,
        f2,
        "white",
        start_dir,
        end_dir
      );
      ctx.globalAlpha = tmp;
    }
  }
  /**
   * draws a link between two points
   * @param ctx Canvas 2D rendering context
   * @param a start pos
   * @param b end pos
   * @param link the link object with all the link info
   * @param skip_border ignore the shadow of the link
   * @param flow show flow animation (for events)
   * @param color the color for the link
   * @param start_dir the direction enum
   * @param end_dir the direction enum
   */
  renderLink(ctx, a2, b2, link2, skip_border, flow, color2, start_dir, end_dir, {
    startControl,
    endControl,
    reroute,
    num_sublines = 1
  } = {}) {
    const linkColour = link2 != null && this.highlighted_links[link2.id] ? "#FFF" : color2 || link2?.color || link2?.type != null && LGraphCanvas.link_type_colors[link2.type] || this.default_link_color;
    const startDir = start_dir || LinkDirection.RIGHT;
    const endDir = end_dir || LinkDirection.LEFT;
    const dist3 = this.links_render_mode == LinkRenderType.SPLINE_LINK && (!endControl || !startControl) ? distance(a2, b2) : 0;
    if (this.render_connections_border && !this.low_quality) {
      ctx.lineWidth = this.connections_width + 4;
    }
    ctx.lineJoin = "round";
    num_sublines ||= 1;
    if (num_sublines > 1) ctx.lineWidth = 0.5;
    const path = new Path2D();
    const linkSegment = reroute ?? link2;
    if (linkSegment) linkSegment.path = path;
    const innerA = LGraphCanvas.#lTempA;
    const innerB = LGraphCanvas.#lTempB;
    const pos = linkSegment?._pos ?? [0, 0];
    for (let i2 = 0; i2 < num_sublines; i2++) {
      const offsety = (i2 - (num_sublines - 1) * 0.5) * 5;
      innerA[0] = a2[0];
      innerA[1] = a2[1];
      innerB[0] = b2[0];
      innerB[1] = b2[1];
      if (this.links_render_mode == LinkRenderType.SPLINE_LINK) {
        if (endControl) {
          innerB[0] = b2[0] + endControl[0];
          innerB[1] = b2[1] + endControl[1];
        } else {
          this.#addSplineOffset(innerB, endDir, dist3);
        }
        if (startControl) {
          innerA[0] = a2[0] + startControl[0];
          innerA[1] = a2[1] + startControl[1];
        } else {
          this.#addSplineOffset(innerA, startDir, dist3);
        }
        path.moveTo(a2[0], a2[1] + offsety);
        path.bezierCurveTo(
          innerA[0],
          innerA[1] + offsety,
          innerB[0],
          innerB[1] + offsety,
          b2[0],
          b2[1] + offsety
        );
        findPointOnCurve(pos, a2, b2, innerA, innerB, 0.5);
        if (linkSegment && this.linkMarkerShape === LinkMarkerShape.Arrow) {
          const justPastCentre = LGraphCanvas.#lTempC;
          findPointOnCurve(justPastCentre, a2, b2, innerA, innerB, 0.51);
          linkSegment._centreAngle = Math.atan2(
            justPastCentre[1] - pos[1],
            justPastCentre[0] - pos[0]
          );
        }
      } else if (this.links_render_mode == LinkRenderType.LINEAR_LINK) {
        const l2 = 15;
        switch (startDir) {
          case LinkDirection.LEFT:
            innerA[0] += -15;
            break;
          case LinkDirection.RIGHT:
            innerA[0] += l2;
            break;
          case LinkDirection.UP:
            innerA[1] += -15;
            break;
          case LinkDirection.DOWN:
            innerA[1] += l2;
            break;
        }
        switch (endDir) {
          case LinkDirection.LEFT:
            innerB[0] += -15;
            break;
          case LinkDirection.RIGHT:
            innerB[0] += l2;
            break;
          case LinkDirection.UP:
            innerB[1] += -15;
            break;
          case LinkDirection.DOWN:
            innerB[1] += l2;
            break;
        }
        path.moveTo(a2[0], a2[1] + offsety);
        path.lineTo(innerA[0], innerA[1] + offsety);
        path.lineTo(innerB[0], innerB[1] + offsety);
        path.lineTo(b2[0], b2[1] + offsety);
        pos[0] = (innerA[0] + innerB[0]) * 0.5;
        pos[1] = (innerA[1] + innerB[1]) * 0.5;
        if (linkSegment && this.linkMarkerShape === LinkMarkerShape.Arrow) {
          linkSegment._centreAngle = Math.atan2(
            innerB[1] - innerA[1],
            innerB[0] - innerA[0]
          );
        }
      } else if (this.links_render_mode == LinkRenderType.STRAIGHT_LINK) {
        if (startDir == LinkDirection.RIGHT) {
          innerA[0] += 10;
        } else {
          innerA[1] += 10;
        }
        if (endDir == LinkDirection.LEFT) {
          innerB[0] -= 10;
        } else {
          innerB[1] -= 10;
        }
        const midX = (innerA[0] + innerB[0]) * 0.5;
        path.moveTo(a2[0], a2[1]);
        path.lineTo(innerA[0], innerA[1]);
        path.lineTo(midX, innerA[1]);
        path.lineTo(midX, innerB[1]);
        path.lineTo(innerB[0], innerB[1]);
        path.lineTo(b2[0], b2[1]);
        pos[0] = midX;
        pos[1] = (innerA[1] + innerB[1]) * 0.5;
        if (linkSegment && this.linkMarkerShape === LinkMarkerShape.Arrow) {
          const diff2 = innerB[1] - innerA[1];
          if (Math.abs(diff2) < 4) linkSegment._centreAngle = 0;
          else if (diff2 > 0) linkSegment._centreAngle = Math.PI * 0.5;
          else linkSegment._centreAngle = -(Math.PI * 0.5);
        }
      } else {
        return;
      }
    }
    if (this.render_connections_border && !this.low_quality && !skip_border) {
      ctx.strokeStyle = "rgba(0,0,0,0.5)";
      ctx.stroke(path);
    }
    ctx.lineWidth = this.connections_width;
    ctx.fillStyle = ctx.strokeStyle = linkColour;
    ctx.stroke(path);
    if (this.ds.scale >= 0.6 && this.highquality_render && linkSegment && // TODO: Re-assess this usage - likely a workaround that linkSegment truthy check resolves
    endDir != LinkDirection.CENTER) {
      if (this.render_connection_arrows) {
        const posA = this.computeConnectionPoint(a2, b2, 0.25, startDir, endDir);
        const posB = this.computeConnectionPoint(a2, b2, 0.26, startDir, endDir);
        const posC = this.computeConnectionPoint(a2, b2, 0.75, startDir, endDir);
        const posD = this.computeConnectionPoint(a2, b2, 0.76, startDir, endDir);
        let angleA = 0;
        let angleB = 0;
        if (this.render_curved_connections) {
          angleA = -Math.atan2(posB[0] - posA[0], posB[1] - posA[1]);
          angleB = -Math.atan2(posD[0] - posC[0], posD[1] - posC[1]);
        } else {
          angleB = angleA = b2[1] > a2[1] ? 0 : Math.PI;
        }
        const transform2 = ctx.getTransform();
        ctx.translate(posA[0], posA[1]);
        ctx.rotate(angleA);
        ctx.beginPath();
        ctx.moveTo(-5, -3);
        ctx.lineTo(0, 7);
        ctx.lineTo(5, -3);
        ctx.fill();
        ctx.setTransform(transform2);
        ctx.translate(posC[0], posC[1]);
        ctx.rotate(angleB);
        ctx.beginPath();
        ctx.moveTo(-5, -3);
        ctx.lineTo(0, 7);
        ctx.lineTo(5, -3);
        ctx.fill();
        ctx.setTransform(transform2);
      }
      ctx.beginPath();
      if (this.linkMarkerShape === LinkMarkerShape.Arrow) {
        const transform2 = ctx.getTransform();
        ctx.translate(pos[0], pos[1]);
        if (linkSegment._centreAngle) ctx.rotate(linkSegment._centreAngle);
        ctx.moveTo(-3.2, -5);
        ctx.lineTo(7, 0);
        ctx.lineTo(-3.2, 5);
        ctx.fill();
        ctx.setTransform(transform2);
      } else if (this.linkMarkerShape == null || this.linkMarkerShape === LinkMarkerShape.Circle) {
        ctx.arc(pos[0], pos[1], 5, 0, Math.PI * 2);
      }
      ctx.fill();
    }
    if (flow) {
      ctx.fillStyle = linkColour;
      for (let i2 = 0; i2 < 5; ++i2) {
        const f2 = (LiteGraph.getTime() * 1e-3 + i2 * 0.2) % 1;
        const flowPos = this.computeConnectionPoint(a2, b2, f2, startDir, endDir);
        ctx.beginPath();
        ctx.arc(flowPos[0], flowPos[1], 5, 0, 2 * Math.PI);
        ctx.fill();
      }
    }
  }
  /**
   * Finds a point along a spline represented by a to b, with spline endpoint directions dictacted by start_dir and end_dir.
   * @param a Start point
   * @param b End point
   * @param t Time: distance between points (e.g 0.25 is 25% along the line)
   * @param start_dir Spline start direction
   * @param end_dir Spline end direction
   * @returns The point at {@link t} distance along the spline a-b.
   */
  computeConnectionPoint(a2, b2, t2, start_dir, end_dir) {
    start_dir ||= LinkDirection.RIGHT;
    end_dir ||= LinkDirection.LEFT;
    const dist3 = distance(a2, b2);
    const pa = [a2[0], a2[1]];
    const pb = [b2[0], b2[1]];
    this.#addSplineOffset(pa, start_dir, dist3);
    this.#addSplineOffset(pb, end_dir, dist3);
    const c1 = (1 - t2) * (1 - t2) * (1 - t2);
    const c2 = 3 * ((1 - t2) * (1 - t2)) * t2;
    const c3 = 3 * (1 - t2) * (t2 * t2);
    const c4 = t2 * t2 * t2;
    const x2 = c1 * a2[0] + c2 * pa[0] + c3 * pb[0] + c4 * b2[0];
    const y2 = c1 * a2[1] + c2 * pa[1] + c3 * pb[1] + c4 * b2[1];
    return [x2, y2];
  }
  /**
   * Modifies an existing point, adding a single-axis offset.
   * @param point The point to add the offset to
   * @param direction The direction to add the offset in
   * @param dist Distance to offset
   * @param factor Distance is mulitplied by this value.  Default: 0.25
   */
  #addSplineOffset(point, direction, dist3, factor = 0.25) {
    switch (direction) {
      case LinkDirection.LEFT:
        point[0] += dist3 * -factor;
        break;
      case LinkDirection.RIGHT:
        point[0] += dist3 * factor;
        break;
      case LinkDirection.UP:
        point[1] += dist3 * -factor;
        break;
      case LinkDirection.DOWN:
        point[1] += dist3 * factor;
        break;
    }
  }
  drawExecutionOrder(ctx) {
    ctx.shadowColor = "transparent";
    ctx.globalAlpha = 0.25;
    ctx.textAlign = "center";
    ctx.strokeStyle = "white";
    ctx.globalAlpha = 0.75;
    const { visible_nodes } = this;
    for (const node22 of visible_nodes) {
      ctx.fillStyle = "black";
      ctx.fillRect(
        node22.pos[0] - LiteGraph.NODE_TITLE_HEIGHT,
        node22.pos[1] - LiteGraph.NODE_TITLE_HEIGHT,
        LiteGraph.NODE_TITLE_HEIGHT,
        LiteGraph.NODE_TITLE_HEIGHT
      );
      if (node22.order == 0) {
        ctx.strokeRect(
          node22.pos[0] - LiteGraph.NODE_TITLE_HEIGHT + 0.5,
          node22.pos[1] - LiteGraph.NODE_TITLE_HEIGHT + 0.5,
          LiteGraph.NODE_TITLE_HEIGHT,
          LiteGraph.NODE_TITLE_HEIGHT
        );
      }
      ctx.fillStyle = "#FFF";
      ctx.fillText(
        stringOrEmpty(node22.order),
        node22.pos[0] + LiteGraph.NODE_TITLE_HEIGHT * -0.5,
        node22.pos[1] - 6
      );
    }
    ctx.globalAlpha = 1;
  }
  /**
   * draws the widgets stored inside a node
   * @deprecated Use {@link LGraphNode.drawWidgets} instead.
   * @remarks Currently there are extensions hijacking this function, so we cannot remove it.
   */
  drawNodeWidgets(node22, posY, ctx) {
    const { linkConnector } = this;
    node22.drawWidgets(ctx, {
      colorContext: this,
      linkOverWidget: linkConnector.overWidget,
      linkOverWidgetType: linkConnector.overWidgetType,
      lowQuality: this.low_quality,
      editorAlpha: this.editor_alpha
    });
  }
  /**
   * draws every group area in the background
   */
  drawGroups(canvas2, ctx) {
    if (!this.graph) return;
    const groups = this.graph._groups;
    ctx.save();
    ctx.globalAlpha = 0.5 * this.editor_alpha;
    const drawSnapGuides = this.#snapToGrid && this.isDragging;
    for (const group of groups) {
      if (!overlapBounding(this.visible_area, group._bounding)) {
        continue;
      }
      if (drawSnapGuides && this.selectedItems.has(group))
        this.drawSnapGuide(ctx, group);
      group.draw(this, ctx);
    }
    ctx.restore();
  }
  /**
   * resizes the canvas to a given size, if no size is passed, then it tries to fill the parentNode
   * @todo Remove or rewrite
   */
  resize(width2, height) {
    if (!width2 && !height) {
      const parent = this.canvas.parentElement;
      if (!parent) throw new TypeError("Attempted to resize canvas, but parent element was null.");
      width2 = parent.offsetWidth;
      height = parent.offsetHeight;
    }
    if (this.canvas.width == width2 && this.canvas.height == height) return;
    this.canvas.width = width2 ?? 0;
    this.canvas.height = height ?? 0;
    this.bgcanvas.width = this.canvas.width;
    this.bgcanvas.height = this.canvas.height;
    this.setDirty(true, true);
  }
  onNodeSelectionChange() {
  }
  /**
   * Determines the furthest nodes in each direction for the currently selected nodes
   */
  boundaryNodesForSelection() {
    return LGraphCanvas.getBoundaryNodes(this.selected_nodes);
  }
  showLinkMenu(segment, e2) {
    const { graph } = this;
    if (!graph) throw new NullGraphError();
    const title = "data" in segment && segment.data != null ? segment.data.constructor.name : void 0;
    const { origin_id, origin_slot } = segment;
    if (origin_id == null || origin_slot == null) {
      new LiteGraph.ContextMenu(["Link has no origin"], {
        event: e2,
        title
      });
      return false;
    }
    const node_left = graph.getNodeById(origin_id);
    const fromType = node_left?.outputs?.[origin_slot]?.type;
    const options22 = ["Add Node", null, "Delete", null];
    options22.splice(1, 0, "Add Reroute");
    const menu2 = new LiteGraph.ContextMenu(options22, {
      event: e2,
      title,
      callback: inner_clicked.bind(this)
    });
    return false;
    function inner_clicked(v2, options222, e22) {
      if (!graph) throw new NullGraphError();
      switch (v2) {
        case "Add Node":
          LGraphCanvas.onMenuAdd(null, null, e22, menu2, (node22) => {
            if (!node22?.inputs?.length || !node22?.outputs?.length || origin_slot == null) return;
            const options32 = { afterRerouteId: segment.parentId };
            if (node_left?.connectByType(origin_slot, node22, fromType ?? "*", options32)) {
              node22.pos[0] -= node22.size[0] * 0.5;
            }
          });
          break;
        case "Add Reroute": {
          try {
            this.emitBeforeChange();
            this.adjustMouseEvent(e22);
            graph.createReroute(segment._pos, segment);
            this.setDirty(false, true);
          } catch (error2) {
            console.error(error2);
          } finally {
            this.emitAfterChange();
          }
          break;
        }
        case "Delete":
          graph.removeLink(segment.id);
          break;
      }
    }
    __name(inner_clicked, "inner_clicked");
  }
  createDefaultNodeForSlot(optPass) {
    const opts = Object.assign({
      nodeFrom: null,
      slotFrom: null,
      nodeTo: null,
      slotTo: null,
      position: [0, 0],
      nodeType: void 0,
      posAdd: [0, 0],
      posSizeFix: [0, 0]
    }, optPass);
    const { afterRerouteId } = opts;
    const isFrom = opts.nodeFrom && opts.slotFrom !== null;
    const isTo = !isFrom && opts.nodeTo && opts.slotTo !== null;
    if (!isFrom && !isTo) {
      console.warn(`No data passed to createDefaultNodeForSlot`, opts.nodeFrom, opts.slotFrom, opts.nodeTo, opts.slotTo);
      return false;
    }
    if (!opts.nodeType) {
      console.warn("No type to createDefaultNodeForSlot");
      return false;
    }
    const nodeX = isFrom ? opts.nodeFrom : opts.nodeTo;
    if (!nodeX) throw new TypeError("nodeX was null when creating default node for slot.");
    let slotX = isFrom ? opts.slotFrom : opts.slotTo;
    let iSlotConn = false;
    switch (typeof slotX) {
      case "string":
        iSlotConn = isFrom ? nodeX.findOutputSlot(slotX, false) : nodeX.findInputSlot(slotX, false);
        slotX = isFrom ? nodeX.outputs[slotX] : nodeX.inputs[slotX];
        break;
      case "object":
        if (slotX === null) {
          console.warn("Cant get slot information", slotX);
          return false;
        }
        iSlotConn = isFrom ? nodeX.findOutputSlot(slotX.name) : nodeX.findInputSlot(slotX.name);
        break;
      case "number":
        iSlotConn = slotX;
        slotX = isFrom ? nodeX.outputs[slotX] : nodeX.inputs[slotX];
        break;
      case "undefined":
      default:
        console.warn("Cant get slot information", slotX);
        return false;
    }
    const fromSlotType = slotX.type == LiteGraph.EVENT ? "_event_" : slotX.type;
    const slotTypesDefault = isFrom ? LiteGraph.slot_types_default_out : LiteGraph.slot_types_default_in;
    if (slotTypesDefault?.[fromSlotType]) {
      let nodeNewType = false;
      if (typeof slotTypesDefault[fromSlotType] == "object") {
        for (const typeX in slotTypesDefault[fromSlotType]) {
          if (opts.nodeType == slotTypesDefault[fromSlotType][typeX] || opts.nodeType == "AUTO") {
            nodeNewType = slotTypesDefault[fromSlotType][typeX];
            break;
          }
        }
      } else if (opts.nodeType == slotTypesDefault[fromSlotType] || opts.nodeType == "AUTO") {
        nodeNewType = slotTypesDefault[fromSlotType];
      }
      if (nodeNewType) {
        let nodeNewOpts = false;
        if (typeof nodeNewType == "object" && nodeNewType.node) {
          nodeNewOpts = nodeNewType;
          nodeNewType = nodeNewType.node;
        }
        const newNode = LiteGraph.createNode(nodeNewType);
        if (newNode) {
          if (nodeNewOpts) {
            if (nodeNewOpts.properties) {
              for (const i2 in nodeNewOpts.properties) {
                newNode.addProperty(i2, nodeNewOpts.properties[i2]);
              }
            }
            if (nodeNewOpts.inputs) {
              newNode.inputs = [];
              for (const i2 in nodeNewOpts.inputs) {
                newNode.addOutput(
                  nodeNewOpts.inputs[i2][0],
                  nodeNewOpts.inputs[i2][1]
                );
              }
            }
            if (nodeNewOpts.outputs) {
              newNode.outputs = [];
              for (const i2 in nodeNewOpts.outputs) {
                newNode.addOutput(
                  nodeNewOpts.outputs[i2][0],
                  nodeNewOpts.outputs[i2][1]
                );
              }
            }
            if (nodeNewOpts.title) {
              newNode.title = nodeNewOpts.title;
            }
            if (nodeNewOpts.json) {
              newNode.configure(nodeNewOpts.json);
            }
          }
          if (!this.graph) throw new NullGraphError();
          this.graph.add(newNode);
          newNode.pos = [
            opts.position[0] + opts.posAdd[0] + (opts.posSizeFix[0] ? opts.posSizeFix[0] * newNode.size[0] : 0),
            opts.position[1] + opts.posAdd[1] + (opts.posSizeFix[1] ? opts.posSizeFix[1] * newNode.size[1] : 0)
          ];
          if (isFrom) {
            if (!opts.nodeFrom) throw new TypeError("createDefaultNodeForSlot - nodeFrom was null");
            opts.nodeFrom.connectByType(iSlotConn, newNode, fromSlotType, { afterRerouteId });
          } else {
            if (!opts.nodeTo) throw new TypeError("createDefaultNodeForSlot - nodeTo was null");
            opts.nodeTo.connectByTypeOutput(iSlotConn, newNode, fromSlotType, { afterRerouteId });
          }
          return true;
        }
        console.log(`failed creating ${nodeNewType}`);
      }
    }
    return false;
  }
  showConnectionMenu(optPass) {
    const opts = Object.assign({
      nodeFrom: null,
      slotFrom: null,
      nodeTo: null,
      slotTo: null,
      e: void 0,
      allow_searchbox: this.allow_searchbox,
      showSearchBox: this.showSearchBox
    }, optPass || {});
    const that = this;
    const { afterRerouteId } = opts;
    const isFrom = opts.nodeFrom && opts.slotFrom;
    const isTo = !isFrom && opts.nodeTo && opts.slotTo;
    if (!isFrom && !isTo) {
      console.warn("No data passed to showConnectionMenu");
      return;
    }
    const nodeX = isFrom ? opts.nodeFrom : opts.nodeTo;
    if (!nodeX) throw new TypeError("nodeX was null when creating default node for slot.");
    let slotX = isFrom ? opts.slotFrom : opts.slotTo;
    let iSlotConn;
    switch (typeof slotX) {
      case "string":
        iSlotConn = isFrom ? nodeX.findOutputSlot(slotX, false) : nodeX.findInputSlot(slotX, false);
        slotX = isFrom ? nodeX.outputs[slotX] : nodeX.inputs[slotX];
        break;
      case "object":
        if (slotX === null) {
          console.warn("Cant get slot information", slotX);
          return;
        }
        iSlotConn = isFrom ? nodeX.findOutputSlot(slotX.name) : nodeX.findInputSlot(slotX.name);
        break;
      case "number":
        iSlotConn = slotX;
        slotX = isFrom ? nodeX.outputs[slotX] : nodeX.inputs[slotX];
        break;
      default:
        console.warn("Cant get slot information", slotX);
        return;
    }
    const options22 = ["Add Node", null];
    if (opts.allow_searchbox) {
      options22.push("Search", null);
    }
    const fromSlotType = slotX.type == LiteGraph.EVENT ? "_event_" : slotX.type;
    const slotTypesDefault = isFrom ? LiteGraph.slot_types_default_out : LiteGraph.slot_types_default_in;
    if (slotTypesDefault?.[fromSlotType]) {
      if (typeof slotTypesDefault[fromSlotType] == "object") {
        for (const typeX in slotTypesDefault[fromSlotType]) {
          options22.push(slotTypesDefault[fromSlotType][typeX]);
        }
      } else {
        options22.push(slotTypesDefault[fromSlotType]);
      }
    }
    const menu2 = new LiteGraph.ContextMenu(options22, {
      event: opts.e,
      title: (slotX && slotX.name != "" ? slotX.name + (fromSlotType ? " | " : "") : "") + (slotX && fromSlotType ? fromSlotType : ""),
      callback: inner_clicked
    });
    function inner_clicked(v2, options222, e2) {
      switch (v2) {
        case "Add Node":
          LGraphCanvas.onMenuAdd(null, null, e2, menu2, function(node22) {
            if (!node22) return;
            if (isFrom) {
              opts.nodeFrom?.connectByType(iSlotConn, node22, fromSlotType, { afterRerouteId });
            } else {
              opts.nodeTo?.connectByTypeOutput(iSlotConn, node22, fromSlotType, { afterRerouteId });
            }
          });
          break;
        case "Search":
          if (isFrom) {
            opts.showSearchBox(e2, { node_from: opts.nodeFrom, slot_from: slotX, type_filter_in: fromSlotType });
          } else {
            opts.showSearchBox(e2, { node_to: opts.nodeTo, slot_from: slotX, type_filter_out: fromSlotType });
          }
          break;
        default: {
          const customProps = {
            position: [opts.e?.canvasX ?? 0, opts.e?.canvasY ?? 0],
            nodeType: v2,
            afterRerouteId
          };
          const options32 = Object.assign(opts, customProps);
          that.createDefaultNodeForSlot(options32);
          break;
        }
      }
    }
    __name(inner_clicked, "inner_clicked");
  }
  // refactor: there are different dialogs, some uses createDialog some dont
  prompt(title, value3, callback, event, multiline) {
    const that = this;
    title = title || "";
    const customProperties = {
      is_modified: false,
      className: "graphdialog rounded",
      innerHTML: multiline ? "<span class='name'></span> <textarea autofocus class='value'></textarea><button class='rounded'>OK</button>" : "<span class='name'></span> <input autofocus type='text' class='value'/><button class='rounded'>OK</button>",
      close() {
        that.prompt_box = null;
        if (dialog.parentNode) {
          dialog.remove();
        }
      }
    };
    const div = document.createElement("div");
    const dialog = Object.assign(div, customProperties);
    const graphcanvas = LGraphCanvas.active_canvas;
    const { canvas: canvas2 } = graphcanvas;
    if (!canvas2.parentNode) throw new TypeError("canvas element parentNode was null when opening a prompt.");
    canvas2.parentNode.append(dialog);
    if (this.ds.scale > 1) dialog.style.transform = `scale(${this.ds.scale})`;
    let dialogCloseTimer;
    let prevent_timeout = 0;
    LiteGraph.pointerListenerAdd(dialog, "leave", function() {
      if (prevent_timeout) return;
      if (LiteGraph.dialog_close_on_mouse_leave) {
        if (!dialog.is_modified && LiteGraph.dialog_close_on_mouse_leave) {
          dialogCloseTimer = setTimeout(
            dialog.close,
            LiteGraph.dialog_close_on_mouse_leave_delay
          );
        }
      }
    });
    LiteGraph.pointerListenerAdd(dialog, "enter", function() {
      if (LiteGraph.dialog_close_on_mouse_leave && dialogCloseTimer)
        clearTimeout(dialogCloseTimer);
    });
    const selInDia = dialog.querySelectorAll("select");
    if (selInDia) {
      for (const selIn of selInDia) {
        selIn.addEventListener("click", function() {
          prevent_timeout++;
        });
        selIn.addEventListener("blur", function() {
          prevent_timeout = 0;
        });
        selIn.addEventListener("change", function() {
          prevent_timeout = -1;
        });
      }
    }
    this.prompt_box?.close();
    this.prompt_box = dialog;
    const name_element = dialog.querySelector(".name");
    if (!name_element) throw new TypeError("name_element was null");
    name_element.textContent = title;
    const value_element = dialog.querySelector(".value");
    if (!value_element) throw new TypeError("value_element was null");
    value_element.value = value3;
    value_element.select();
    const input = value_element;
    input.addEventListener("keydown", function(e2) {
      dialog.is_modified = true;
      if (e2.key == "Escape") {
        dialog.close();
      } else if (e2.key == "Enter" && e2.target.localName != "textarea") {
        if (callback) {
          callback(this.value);
        }
        dialog.close();
      } else {
        return;
      }
      e2.preventDefault();
      e2.stopPropagation();
    });
    const button = dialog.querySelector("button");
    if (!button) throw new TypeError("button was null when opening prompt");
    button.addEventListener("click", function() {
      callback?.(input.value);
      that.setDirty(true);
      dialog.close();
    });
    const rect = canvas2.getBoundingClientRect();
    let offsetx = -20;
    let offsety = -20;
    if (rect) {
      offsetx -= rect.left;
      offsety -= rect.top;
    }
    if (event) {
      dialog.style.left = `${event.clientX + offsetx}px`;
      dialog.style.top = `${event.clientY + offsety}px`;
    } else {
      dialog.style.left = `${canvas2.width * 0.5 + offsetx}px`;
      dialog.style.top = `${canvas2.height * 0.5 + offsety}px`;
    }
    setTimeout(function() {
      input.focus();
      const clickTime = Date.now();
      function handleOutsideClick(e2) {
        if (e2.target === canvas2 && Date.now() - clickTime > 256) {
          dialog.close();
          canvas2.parentElement?.removeEventListener("click", handleOutsideClick);
          canvas2.parentElement?.removeEventListener("touchend", handleOutsideClick);
        }
      }
      __name(handleOutsideClick, "handleOutsideClick");
      canvas2.parentElement?.addEventListener("click", handleOutsideClick);
      canvas2.parentElement?.addEventListener("touchend", handleOutsideClick);
    }, 10);
    return dialog;
  }
  showSearchBox(event, searchOptions4) {
    const options22 = {
      slot_from: null,
      node_from: null,
      node_to: null,
      // TODO check for registered_slot_[in/out]_types not empty
      // this will be checked for functionality enabled : filter on slot type, in and out
      do_type_filter: LiteGraph.search_filter_enabled,
      // these are default: pass to set initially set values
      // @ts-expect-error
      type_filter_in: false,
      type_filter_out: false,
      show_general_if_none_on_typefilter: true,
      show_general_after_typefiltered: true,
      hide_on_mouse_leave: LiteGraph.search_hide_on_mouse_leave,
      show_all_if_empty: true,
      show_all_on_open: LiteGraph.search_show_all_on_open
    };
    Object.assign(options22, searchOptions4);
    const that = this;
    const graphcanvas = LGraphCanvas.active_canvas;
    const { canvas: canvas2 } = graphcanvas;
    const root_document = canvas2.ownerDocument || document;
    const div = document.createElement("div");
    const dialog = Object.assign(div, {
      close() {
        that.search_box = void 0;
        this.blur();
        canvas2.focus();
        root_document.body.style.overflow = "";
        setTimeout(() => canvas2.focus(), 20);
        dialog.remove();
      }
    });
    dialog.className = "litegraph litesearchbox graphdialog rounded";
    dialog.innerHTML = "<span class='name'>Search</span> <input autofocus type='text' class='value rounded'/>";
    if (options22.do_type_filter) {
      dialog.innerHTML += "<select class='slot_in_type_filter'><option value=''></option></select>";
      dialog.innerHTML += "<select class='slot_out_type_filter'><option value=''></option></select>";
    }
    const helper = document.createElement("div");
    helper.className = "helper";
    dialog.append(helper);
    if (root_document.fullscreenElement) {
      root_document.fullscreenElement.append(dialog);
    } else {
      root_document.body.append(dialog);
      root_document.body.style.overflow = "hidden";
    }
    let selIn;
    let selOut;
    if (options22.do_type_filter) {
      selIn = dialog.querySelector(".slot_in_type_filter");
      selOut = dialog.querySelector(".slot_out_type_filter");
    }
    if (this.ds.scale > 1) {
      dialog.style.transform = `scale(${this.ds.scale})`;
    }
    if (options22.hide_on_mouse_leave) {
      let prevent_timeout = false;
      let timeout_close = null;
      LiteGraph.pointerListenerAdd(dialog, "enter", function() {
        if (timeout_close) {
          clearTimeout(timeout_close);
          timeout_close = null;
        }
      });
      dialog.addEventListener("pointerleave", function() {
        if (prevent_timeout) return;
        const hideDelay = options22.hide_on_mouse_leave;
        const delay = typeof hideDelay === "number" ? hideDelay : 500;
        timeout_close = setTimeout(dialog.close, delay);
      });
      if (options22.do_type_filter) {
        if (!selIn) throw new TypeError("selIn was null when showing search box");
        if (!selOut) throw new TypeError("selOut was null when showing search box");
        selIn.addEventListener("click", function() {
          prevent_timeout++;
        });
        selIn.addEventListener("blur", function() {
          prevent_timeout = 0;
        });
        selIn.addEventListener("change", function() {
          prevent_timeout = -1;
        });
        selOut.addEventListener("click", function() {
          prevent_timeout++;
        });
        selOut.addEventListener("blur", function() {
          prevent_timeout = 0;
        });
        selOut.addEventListener("change", function() {
          prevent_timeout = -1;
        });
      }
    }
    that.search_box?.close();
    that.search_box = dialog;
    let first2 = null;
    let timeout = null;
    let selected2 = null;
    const maybeInput = dialog.querySelector("input");
    if (!maybeInput) throw new TypeError("Could not create search input box.");
    const input = maybeInput;
    if (input) {
      input.addEventListener("blur", function() {
        this.focus();
      });
      input.addEventListener("keydown", function(e2) {
        if (e2.key == "ArrowUp") {
          changeSelection(false);
        } else if (e2.key == "ArrowDown") {
          changeSelection(true);
        } else if (e2.key == "Escape") {
          dialog.close();
        } else if (e2.key == "Enter") {
          if (selected2 instanceof HTMLElement) {
            select(unescape(String(selected2.dataset.type)));
          } else if (first2) {
            select(first2);
          } else {
            dialog.close();
          }
        } else {
          if (timeout) {
            clearInterval(timeout);
          }
          timeout = setTimeout(refreshHelper, 10);
          return;
        }
        e2.preventDefault();
        e2.stopPropagation();
        e2.stopImmediatePropagation();
        return true;
      });
    }
    if (options22.do_type_filter) {
      if (selIn) {
        const aSlots = LiteGraph.slot_types_in;
        const nSlots = aSlots.length;
        if (options22.type_filter_in == LiteGraph.EVENT || options22.type_filter_in == LiteGraph.ACTION) {
          options22.type_filter_in = "_event_";
        }
        for (let iK = 0; iK < nSlots; iK++) {
          const opt = document.createElement("option");
          opt.value = aSlots[iK];
          opt.innerHTML = aSlots[iK];
          selIn.append(opt);
          if (
            // @ts-expect-error
            options22.type_filter_in !== false && String(options22.type_filter_in).toLowerCase() == String(aSlots[iK]).toLowerCase()
          ) {
            opt.selected = true;
          }
        }
        selIn.addEventListener("change", function() {
          refreshHelper();
        });
      }
      if (selOut) {
        const aSlots = LiteGraph.slot_types_out;
        if (options22.type_filter_out == LiteGraph.EVENT || options22.type_filter_out == LiteGraph.ACTION) {
          options22.type_filter_out = "_event_";
        }
        for (const aSlot of aSlots) {
          const opt = document.createElement("option");
          opt.value = aSlot;
          opt.innerHTML = aSlot;
          selOut.append(opt);
          if (options22.type_filter_out !== false && String(options22.type_filter_out).toLowerCase() == String(aSlot).toLowerCase()) {
            opt.selected = true;
          }
        }
        selOut.addEventListener("change", function() {
          refreshHelper();
        });
      }
    }
    const rect = canvas2.getBoundingClientRect();
    const left = (event ? event.clientX : rect.left + rect.width * 0.5) - 80;
    const top = (event ? event.clientY : rect.top + rect.height * 0.5) - 20;
    dialog.style.left = `${left}px`;
    dialog.style.top = `${top}px`;
    if (event.layerY > rect.height - 200) {
      helper.style.maxHeight = `${rect.height - event.layerY - 20}px`;
    }
    requestAnimationFrame(function() {
      input.focus();
    });
    if (options22.show_all_on_open) refreshHelper();
    function select(name2) {
      if (name2) {
        if (that.onSearchBoxSelection) {
          that.onSearchBoxSelection(name2, event, graphcanvas);
        } else {
          if (!graphcanvas.graph) throw new NullGraphError();
          graphcanvas.graph.beforeChange();
          const node22 = LiteGraph.createNode(name2);
          if (node22) {
            node22.pos = graphcanvas.convertEventToCanvasOffset(event);
            graphcanvas.graph.add(node22, false);
          }
          if (options22.node_from) {
            let iS = false;
            switch (typeof options22.slot_from) {
              case "string":
                iS = options22.node_from.findOutputSlot(options22.slot_from);
                break;
              case "object":
                if (options22.slot_from == null) throw new TypeError("options.slot_from was null when showing search box");
                iS = options22.slot_from.name ? options22.node_from.findOutputSlot(options22.slot_from.name) : -1;
                if (iS == -1 && options22.slot_from.slot_index !== void 0) iS = options22.slot_from.slot_index;
                break;
              case "number":
                iS = options22.slot_from;
                break;
              default:
                iS = 0;
            }
            if (options22.node_from.outputs[iS] !== void 0) {
              if (iS !== false && iS > -1) {
                if (node22 == null) throw new TypeError("options.slot_from was null when showing search box");
                options22.node_from.connectByType(iS, node22, options22.node_from.outputs[iS].type);
              }
            }
          }
          if (options22.node_to) {
            let iS = false;
            switch (typeof options22.slot_from) {
              case "string":
                iS = options22.node_to.findInputSlot(options22.slot_from);
                break;
              case "object":
                if (options22.slot_from == null) throw new TypeError("options.slot_from was null when showing search box");
                iS = options22.slot_from.name ? options22.node_to.findInputSlot(options22.slot_from.name) : -1;
                if (iS == -1 && options22.slot_from.slot_index !== void 0) iS = options22.slot_from.slot_index;
                break;
              case "number":
                iS = options22.slot_from;
                break;
              default:
                iS = 0;
            }
            if (options22.node_to.inputs[iS] !== void 0) {
              if (iS !== false && iS > -1) {
                if (node22 == null) throw new TypeError("options.slot_from was null when showing search box");
                options22.node_to.connectByTypeOutput(iS, node22, options22.node_to.inputs[iS].type);
              }
            }
          }
          graphcanvas.graph.afterChange();
        }
      }
      dialog.close();
    }
    __name(select, "select");
    function changeSelection(forward) {
      const prev2 = selected2;
      if (!selected2) {
        selected2 = forward ? helper.childNodes[0] : helper.childNodes[helper.childNodes.length];
      } else if (selected2 instanceof Element) {
        selected2.classList.remove("selected");
        selected2 = forward ? selected2.nextSibling : selected2.previousSibling;
        selected2 ||= prev2;
      }
      if (selected2 instanceof Element) {
        selected2.classList.add("selected");
        selected2.scrollIntoView({ block: "end", behavior: "smooth" });
      }
    }
    __name(changeSelection, "changeSelection");
    function refreshHelper() {
      timeout = null;
      let str = input.value;
      first2 = null;
      helper.innerHTML = "";
      if (!str && !options22.show_all_if_empty) return;
      if (that.onSearchBox) {
        const list2 = that.onSearchBox(helper, str, graphcanvas);
        if (list2) {
          for (const item3 of list2) {
            addResult(item3);
          }
        }
      } else {
        let inner_test_filter = /* @__PURE__ */ __name(function(type, optsIn) {
          optsIn = optsIn || {};
          const optsDef = {
            skipFilter: false,
            inTypeOverride: false,
            outTypeOverride: false
          };
          const opts = Object.assign(optsDef, optsIn);
          const ctor = LiteGraph.registered_node_types[type];
          if (filter4 && ctor.filter != filter4) return false;
          if ((!options22.show_all_if_empty || str) && !type.toLowerCase().includes(str) && (!ctor.title || !ctor.title.toLowerCase().includes(str))) {
            return false;
          }
          if (options22.do_type_filter && !opts.skipFilter) {
            const sType = type;
            let sV = opts.inTypeOverride !== false ? opts.inTypeOverride : sIn.value;
            if (sIn && sV && LiteGraph.registered_slot_in_types[sV]?.nodes) {
              const doesInc = LiteGraph.registered_slot_in_types[sV].nodes.includes(sType);
              if (doesInc === false) return false;
            }
            sV = sOut.value;
            if (opts.outTypeOverride !== false) sV = opts.outTypeOverride;
            if (sOut && sV && LiteGraph.registered_slot_out_types[sV]?.nodes) {
              const doesInc = LiteGraph.registered_slot_out_types[sV].nodes.includes(sType);
              if (doesInc === false) return false;
            }
          }
          return true;
        }, "inner_test_filter");
        let c2 = 0;
        str = str.toLowerCase();
        if (!graphcanvas.graph) throw new NullGraphError();
        const filter4 = graphcanvas.filter || graphcanvas.graph.filter;
        let sIn = false;
        let sOut = false;
        if (options22.do_type_filter && that.search_box) {
          sIn = that.search_box.querySelector(".slot_in_type_filter");
          sOut = that.search_box.querySelector(".slot_out_type_filter");
        }
        const keys2 = Object.keys(LiteGraph.registered_node_types);
        const filtered = keys2.filter((x2) => inner_test_filter(x2));
        for (const item3 of filtered) {
          addResult(item3);
          if (LGraphCanvas.search_limit !== -1 && c2++ > LGraphCanvas.search_limit)
            break;
        }
        if (options22.show_general_after_typefiltered && (sIn.value || sOut.value)) {
          filtered_extra = [];
          for (const i2 in LiteGraph.registered_node_types) {
            if (inner_test_filter(i2, {
              inTypeOverride: sIn && sIn.value ? "*" : false,
              outTypeOverride: sOut && sOut.value ? "*" : false
            })) {
              filtered_extra.push(i2);
            }
          }
          for (const extraItem of filtered_extra) {
            addResult(extraItem, "generic_type");
            if (LGraphCanvas.search_limit !== -1 && c2++ > LGraphCanvas.search_limit)
              break;
          }
        }
        if ((sIn.value || sOut.value) && helper.childNodes.length == 0 && options22.show_general_if_none_on_typefilter) {
          filtered_extra = [];
          for (const i2 in LiteGraph.registered_node_types) {
            if (inner_test_filter(i2, { skipFilter: true }))
              filtered_extra.push(i2);
          }
          for (const extraItem of filtered_extra) {
            addResult(extraItem, "not_in_filter");
            if (LGraphCanvas.search_limit !== -1 && c2++ > LGraphCanvas.search_limit)
              break;
          }
        }
      }
      function addResult(type, className) {
        const help = document.createElement("div");
        first2 ||= type;
        const nodeType = LiteGraph.registered_node_types[type];
        if (nodeType?.title) {
          help.textContent = nodeType?.title;
          const typeEl = document.createElement("span");
          typeEl.className = "litegraph lite-search-item-type";
          typeEl.textContent = type;
          help.append(typeEl);
        } else {
          help.textContent = type;
        }
        help.dataset["type"] = escape(type);
        help.className = "litegraph lite-search-item";
        if (className) {
          help.className += ` ${className}`;
        }
        help.addEventListener("click", function() {
          select(unescape(String(this.dataset.type)));
        });
        helper.append(help);
      }
      __name(addResult, "addResult");
    }
    __name(refreshHelper, "refreshHelper");
    return dialog;
  }
  showEditPropertyValue(node22, property, options22) {
    if (!node22 || node22.properties[property] === void 0) return;
    options22 = options22 || {};
    const info = node22.getPropertyInfo(property);
    const { type } = info;
    let input_html = "";
    if (type == "string" || type == "number" || type == "array" || type == "object") {
      input_html = "<input autofocus type='text' class='value'/>";
    } else if ((type == "enum" || type == "combo") && info.values) {
      input_html = "<select autofocus type='text' class='value'>";
      for (const i2 in info.values) {
        const v2 = Array.isArray(info.values) ? info.values[i2] : i2;
        const selected2 = v2 == node22.properties[property] ? "selected" : "";
        input_html += `<option value='${v2}' ${selected2}>${info.values[i2]}</option>`;
      }
      input_html += "</select>";
    } else if (type == "boolean" || type == "toggle") {
      const checked4 = node22.properties[property] ? "checked" : "";
      input_html = `<input autofocus type='checkbox' class='value' ${checked4}/>`;
    } else {
      console.warn(`unknown type: ${type}`);
      return;
    }
    const dialog = this.createDialog(
      `<span class='name'>${info.label || property}</span>${input_html}<button>OK</button>`,
      options22
    );
    let input;
    if ((type == "enum" || type == "combo") && info.values) {
      input = dialog.querySelector("select");
      input?.addEventListener("change", function(e2) {
        dialog.modified();
        setValue2(e2.target?.value);
      });
    } else if (type == "boolean" || type == "toggle") {
      input = dialog.querySelector("input");
      input?.addEventListener("click", function() {
        dialog.modified();
        setValue2(!!input.checked);
      });
    } else {
      input = dialog.querySelector("input");
      if (input) {
        input.addEventListener("blur", function() {
          this.focus();
        });
        let v2 = node22.properties[property] !== void 0 ? node22.properties[property] : "";
        if (type !== "string") {
          v2 = JSON.stringify(v2);
        }
        input.value = v2;
        input.addEventListener("keydown", function(e2) {
          if (e2.key == "Escape") {
            dialog.close();
          } else if (e2.key == "Enter") {
            inner();
          } else {
            dialog.modified();
            return;
          }
          e2.preventDefault();
          e2.stopPropagation();
        });
      }
    }
    input?.focus();
    const button = dialog.querySelector("button");
    if (!button) throw new TypeError("Show edit property value button was null.");
    button.addEventListener("click", inner);
    function inner() {
      setValue2(input?.value);
    }
    __name(inner, "inner");
    const dirty = /* @__PURE__ */ __name(() => this.#dirty(), "dirty");
    function setValue2(value3) {
      if (info?.values && typeof info.values === "object" && info.values[value3] != void 0) {
        value3 = info.values[value3];
      }
      if (typeof node22.properties[property] == "number") {
        value3 = Number(value3);
      }
      if (type == "array" || type == "object") {
        value3 = JSON.parse(value3);
      }
      node22.properties[property] = value3;
      if (node22.graph) {
        node22.graph._version++;
      }
      node22.onPropertyChanged?.(property, value3);
      options22.onclose?.();
      dialog.close();
      dirty();
    }
    __name(setValue2, "setValue");
    return dialog;
  }
  // TODO refactor, theer are different dialog, some uses createDialog, some dont
  createDialog(html, options22) {
    const def_options = {
      checkForInput: false,
      closeOnLeave: true,
      closeOnLeave_checkModified: true
    };
    options22 = Object.assign(def_options, options22 || {});
    const customProperties = {
      className: "graphdialog",
      innerHTML: html,
      is_modified: false,
      modified() {
        this.is_modified = true;
      },
      close() {
        this.remove();
      }
    };
    const div = document.createElement("div");
    const dialog = Object.assign(div, customProperties);
    const rect = this.canvas.getBoundingClientRect();
    let offsetx = -20;
    let offsety = -20;
    if (rect) {
      offsetx -= rect.left;
      offsety -= rect.top;
    }
    if (options22.position) {
      offsetx += options22.position[0];
      offsety += options22.position[1];
    } else if (options22.event) {
      offsetx += options22.event.clientX;
      offsety += options22.event.clientY;
    } else {
      offsetx += this.canvas.width * 0.5;
      offsety += this.canvas.height * 0.5;
    }
    dialog.style.left = `${offsetx}px`;
    dialog.style.top = `${offsety}px`;
    if (!this.canvas.parentNode) throw new TypeError("Canvas parent element was null.");
    this.canvas.parentNode.append(dialog);
    if (options22.checkForInput) {
      const aI = dialog.querySelectorAll("input");
      if (aI) {
        for (const iX of aI) {
          iX.addEventListener("keydown", function(e2) {
            dialog.modified();
            if (e2.key == "Escape") {
              dialog.close();
            } else if (e2.key != "Enter") {
              return;
            }
            e2.preventDefault();
            e2.stopPropagation();
          });
          iX.focus();
        }
      }
    }
    let dialogCloseTimer;
    let prevent_timeout = 0;
    dialog.addEventListener("mouseleave", function() {
      if (prevent_timeout) return;
      if (!dialog.is_modified && LiteGraph.dialog_close_on_mouse_leave) {
        dialogCloseTimer = setTimeout(
          dialog.close,
          LiteGraph.dialog_close_on_mouse_leave_delay
        );
      }
    });
    dialog.addEventListener("mouseenter", function() {
      if (options22.closeOnLeave || LiteGraph.dialog_close_on_mouse_leave) {
        if (dialogCloseTimer) clearTimeout(dialogCloseTimer);
      }
    });
    const selInDia = dialog.querySelectorAll("select");
    if (selInDia) {
      for (const selIn of selInDia) {
        selIn.addEventListener("click", function() {
          prevent_timeout++;
        });
        selIn.addEventListener("blur", function() {
          prevent_timeout = 0;
        });
        selIn.addEventListener("change", function() {
          prevent_timeout = -1;
        });
      }
    }
    return dialog;
  }
  createPanel(title, options22) {
    options22 = options22 || {};
    const ref_window = options22.window || window;
    const root34 = document.createElement("div");
    root34.className = "litegraph dialog";
    root34.innerHTML = "<div class='dialog-header'><span class='dialog-title'></span></div><div class='dialog-content'></div><div style='display:none;' class='dialog-alt-content'></div><div class='dialog-footer'></div>";
    root34.header = root34.querySelector(".dialog-header");
    if (options22.width)
      root34.style.width = options22.width + (typeof options22.width === "number" ? "px" : "");
    if (options22.height)
      root34.style.height = options22.height + (typeof options22.height === "number" ? "px" : "");
    if (options22.closable) {
      const close5 = document.createElement("span");
      close5.innerHTML = "&#10005;";
      close5.classList.add("close");
      close5.addEventListener("click", function() {
        root34.close();
      });
      root34.header.append(close5);
    }
    root34.title_element = root34.querySelector(".dialog-title");
    root34.title_element.textContent = title;
    root34.content = root34.querySelector(".dialog-content");
    root34.alt_content = root34.querySelector(".dialog-alt-content");
    root34.footer = root34.querySelector(".dialog-footer");
    root34.close = function() {
      if (typeof root34.onClose == "function") root34.onClose();
      root34.remove();
      this.remove();
    };
    root34.toggleAltContent = function(force) {
      let vTo;
      let vAlt;
      if (force !== void 0) {
        vTo = force ? "block" : "none";
        vAlt = force ? "none" : "block";
      } else {
        vTo = root34.alt_content.style.display != "block" ? "block" : "none";
        vAlt = root34.alt_content.style.display != "block" ? "none" : "block";
      }
      root34.alt_content.style.display = vTo;
      root34.content.style.display = vAlt;
    };
    root34.toggleFooterVisibility = function(force) {
      let vTo;
      if (force !== void 0) {
        vTo = force ? "block" : "none";
      } else {
        vTo = root34.footer.style.display != "block" ? "block" : "none";
      }
      root34.footer.style.display = vTo;
    };
    root34.clear = function() {
      this.content.innerHTML = "";
    };
    root34.addHTML = function(code2, classname, on_footer) {
      const elem = document.createElement("div");
      if (classname) elem.className = classname;
      elem.innerHTML = code2;
      if (on_footer) root34.footer.append(elem);
      else root34.content.append(elem);
      return elem;
    };
    root34.addButton = function(name2, callback, options222) {
      const elem = document.createElement("button");
      elem.textContent = name2;
      elem.options = options222;
      elem.classList.add("btn");
      elem.addEventListener("click", callback);
      root34.footer.append(elem);
      return elem;
    };
    root34.addSeparator = function() {
      const elem = document.createElement("div");
      elem.className = "separator";
      root34.content.append(elem);
    };
    root34.addWidget = function(type, name2, value3, options222, callback) {
      options222 = options222 || {};
      let str_value = String(value3);
      type = type.toLowerCase();
      if (type == "number" && typeof value3 === "number") str_value = value3.toFixed(3);
      const elem = document.createElement("div");
      elem.className = "property";
      elem.innerHTML = "<span class='property_name'></span><span class='property_value'></span>";
      const nameSpan = elem.querySelector(".property_name");
      if (!nameSpan) throw new TypeError("Property name element was null.");
      nameSpan.textContent = options222.label || name2;
      const value_element = elem.querySelector(".property_value");
      if (!value_element) throw new TypeError("Property name element was null.");
      value_element.textContent = str_value;
      elem.dataset["property"] = name2;
      elem.dataset["type"] = options222.type || type;
      elem.options = options222;
      elem.value = value3;
      if (type == "code") {
        elem.addEventListener("click", function() {
          root34.inner_showCodePad(this.dataset["property"]);
        });
      } else if (type == "boolean") {
        elem.classList.add("boolean");
        if (value3) elem.classList.add("bool-on");
        elem.addEventListener("click", () => {
          const propname = elem.dataset["property"];
          elem.value = !elem.value;
          elem.classList.toggle("bool-on");
          if (!value_element) throw new TypeError("Property name element was null.");
          value_element.textContent = elem.value ? "true" : "false";
          innerChange(propname, elem.value);
        });
      } else if (type == "string" || type == "number") {
        if (!value_element) throw new TypeError("Property name element was null.");
        value_element.setAttribute("contenteditable", "true");
        value_element.addEventListener("keydown", function(e2) {
          if (e2.code == "Enter" && (type != "string" || !e2.shiftKey)) {
            e2.preventDefault();
            this.blur();
          }
        });
        value_element.addEventListener("blur", function() {
          let v2 = this.textContent;
          const propname = this.parentElement?.dataset["property"];
          const proptype = this.parentElement?.dataset["type"];
          if (proptype == "number") v2 = Number(v2);
          innerChange(propname, v2);
        });
      } else if (type == "enum" || type == "combo") {
        const str_value2 = LGraphCanvas.getPropertyPrintableValue(value3, options222.values);
        if (!value_element) throw new TypeError("Property name element was null.");
        value_element.textContent = str_value2 ?? "";
        value_element.addEventListener("click", function(event) {
          const values = options222.values || [];
          const propname = this.parentElement?.dataset["property"];
          const inner_clicked = /* @__PURE__ */ __name((v2) => {
            this.textContent = v2;
            innerChange(propname, v2);
            return false;
          }, "inner_clicked");
          new LiteGraph.ContextMenu(
            values,
            {
              event,
              className: "dark",
              callback: inner_clicked
            },
            // @ts-expect-error
            ref_window
          );
        });
      }
      root34.content.append(elem);
      function innerChange(name22, value22) {
        options222.callback?.(name22, value22, options222);
        callback?.(name22, value22, options222);
      }
      __name(innerChange, "innerChange");
      return elem;
    };
    if (typeof root34.onOpen == "function") root34.onOpen();
    return root34;
  }
  closePanels() {
    document.querySelector("#node-panel")?.close?.();
    document.querySelector("#option-panel")?.close?.();
  }
  showShowNodePanel(node22) {
    this.SELECTED_NODE = node22;
    this.closePanels();
    const ref_window = this.getCanvasWindow();
    const panel2 = this.createPanel(node22.title || "", {
      closable: true,
      window: ref_window,
      onOpen: /* @__PURE__ */ __name(() => {
        this.NODEPANEL_IS_OPEN = true;
      }, "onOpen"),
      onClose: /* @__PURE__ */ __name(() => {
        this.NODEPANEL_IS_OPEN = false;
        this.node_panel = null;
      }, "onClose")
    });
    this.node_panel = panel2;
    panel2.id = "node-panel";
    panel2.node = node22;
    panel2.classList.add("settings");
    const inner_refresh = /* @__PURE__ */ __name(() => {
      panel2.content.innerHTML = "";
      panel2.addHTML(`<span class='node_type'>${node22.type}</span><span class='node_desc'>${node22.constructor.desc || ""}</span><span class='separator'></span>`);
      panel2.addHTML("<h3>Properties</h3>");
      const fUpdate = /* @__PURE__ */ __name((name2, value3) => {
        if (!this.graph) throw new NullGraphError();
        this.graph.beforeChange(node22);
        switch (name2) {
          case "Title":
            if (typeof value3 !== "string") throw new TypeError("Attempting to set title to non-string value.");
            node22.title = value3;
            break;
          case "Mode": {
            if (typeof value3 !== "string") throw new TypeError("Attempting to set mode to non-string value.");
            const kV = Object.values(LiteGraph.NODE_MODES).indexOf(value3);
            if (kV !== -1 && LiteGraph.NODE_MODES[kV]) {
              node22.changeMode(kV);
            } else {
              console.warn(`unexpected mode: ${value3}`);
            }
            break;
          }
          case "Color":
            if (typeof value3 !== "string") throw new TypeError("Attempting to set colour to non-string value.");
            if (LGraphCanvas.node_colors[value3]) {
              node22.color = LGraphCanvas.node_colors[value3].color;
              node22.bgcolor = LGraphCanvas.node_colors[value3].bgcolor;
            } else {
              console.warn(`unexpected color: ${value3}`);
            }
            break;
          default:
            node22.setProperty(name2, value3);
            break;
        }
        this.graph.afterChange();
        this.dirty_canvas = true;
      }, "fUpdate");
      panel2.addWidget("string", "Title", node22.title, {}, fUpdate);
      const mode2 = node22.mode == null ? void 0 : LiteGraph.NODE_MODES[node22.mode];
      panel2.addWidget("combo", "Mode", mode2, { values: LiteGraph.NODE_MODES }, fUpdate);
      const nodeCol = node22.color !== void 0 ? Object.keys(LGraphCanvas.node_colors).filter(function(nK) {
        return LGraphCanvas.node_colors[nK].color == node22.color;
      }) : "";
      panel2.addWidget("combo", "Color", nodeCol, { values: Object.keys(LGraphCanvas.node_colors) }, fUpdate);
      for (const pName in node22.properties) {
        const value3 = node22.properties[pName];
        const info = node22.getPropertyInfo(pName);
        if (node22.onAddPropertyToPanel?.(pName, panel2)) continue;
        panel2.addWidget(info.widget || info.type, pName, value3, info, fUpdate);
      }
      panel2.addSeparator();
      node22.onShowCustomPanelInfo?.(panel2);
      panel2.footer.innerHTML = "";
      panel2.addButton("Delete", function() {
        if (node22.block_delete) return;
        if (!node22.graph) throw new NullGraphError();
        node22.graph.remove(node22);
        panel2.close();
      }).classList.add("delete");
    }, "inner_refresh");
    panel2.inner_showCodePad = function(propname) {
      panel2.classList.remove("settings");
      panel2.classList.add("centered");
      panel2.alt_content.innerHTML = "<textarea class='code'></textarea>";
      const textarea = panel2.alt_content.querySelector("textarea");
      const fDoneWith = /* @__PURE__ */ __name(function() {
        panel2.toggleAltContent(false);
        panel2.toggleFooterVisibility(true);
        textarea.remove();
        panel2.classList.add("settings");
        panel2.classList.remove("centered");
        inner_refresh();
      }, "fDoneWith");
      textarea.value = String(node22.properties[propname]);
      textarea.addEventListener("keydown", function(e2) {
        if (e2.code == "Enter" && e2.ctrlKey) {
          node22.setProperty(propname, textarea.value);
          fDoneWith();
        }
      });
      panel2.toggleAltContent(true);
      panel2.toggleFooterVisibility(false);
      textarea.style.height = "calc(100% - 40px)";
      const assign2 = panel2.addButton("Assign", function() {
        node22.setProperty(propname, textarea.value);
        fDoneWith();
      });
      panel2.alt_content.append(assign2);
      const button = panel2.addButton("Close", fDoneWith);
      button.style.float = "right";
      panel2.alt_content.append(button);
    };
    inner_refresh();
    if (!this.canvas.parentNode) throw new TypeError("showNodePanel - this.canvas.parentNode was null");
    this.canvas.parentNode.append(panel2);
  }
  checkPanels() {
    if (!this.canvas) return;
    if (!this.canvas.parentNode) throw new TypeError("checkPanels - this.canvas.parentNode was null");
    const panels = this.canvas.parentNode.querySelectorAll(".litegraph.dialog");
    for (const panel2 of panels) {
      if (!panel2.node) continue;
      if (!panel2.node.graph || panel2.graph != this.graph) panel2.close();
    }
  }
  getCanvasMenuOptions() {
    let options22;
    if (this.getMenuOptions) {
      options22 = this.getMenuOptions();
    } else {
      options22 = [
        {
          content: "Add Node",
          has_submenu: true,
          callback: LGraphCanvas.onMenuAdd
        },
        { content: "Add Group", callback: LGraphCanvas.onGroupAdd }
        // { content: "Arrange", callback: that.graph.arrange },
        // {content:"Collapse All", callback: LGraphCanvas.onMenuCollapseAll }
      ];
      if (Object.keys(this.selected_nodes).length > 1) {
        options22.push({
          content: "Align",
          has_submenu: true,
          callback: LGraphCanvas.onGroupAlign
        });
      }
    }
    const extra = this.getExtraMenuOptions?.(this, options22);
    return Array.isArray(extra) ? options22.concat(extra) : options22;
  }
  // called by processContextMenu to extract the menu list
  getNodeMenuOptions(node22) {
    let options22;
    if (node22.getMenuOptions) {
      options22 = node22.getMenuOptions(this);
    } else {
      options22 = [
        {
          content: "Inputs",
          has_submenu: true,
          disabled: true
        },
        {
          content: "Outputs",
          has_submenu: true,
          disabled: true,
          callback: LGraphCanvas.showMenuNodeOptionalOutputs
        },
        null,
        {
          content: "Properties",
          has_submenu: true,
          callback: LGraphCanvas.onShowMenuNodeProperties
        },
        {
          content: "Properties Panel",
          callback: /* @__PURE__ */ __name(function(item3, options222, e2, menu2, node222) {
            LGraphCanvas.active_canvas.showShowNodePanel(node222);
          }, "callback")
        },
        null,
        {
          content: "Title",
          callback: LGraphCanvas.onShowPropertyEditor
        },
        {
          content: "Mode",
          has_submenu: true,
          callback: LGraphCanvas.onMenuNodeMode
        }
      ];
      if (node22.resizable !== false) {
        options22.push({
          content: "Resize",
          callback: LGraphCanvas.onMenuResizeNode
        });
      }
      if (node22.collapsible) {
        options22.push({
          content: node22.collapsed ? "Expand" : "Collapse",
          callback: LGraphCanvas.onMenuNodeCollapse
        });
      }
      if (node22.widgets?.some((w2) => w2.advanced)) {
        options22.push({
          content: node22.showAdvanced ? "Hide Advanced" : "Show Advanced",
          callback: LGraphCanvas.onMenuToggleAdvanced
        });
      }
      options22.push(
        {
          content: node22.pinned ? "Unpin" : "Pin",
          callback: /* @__PURE__ */ __name(() => {
            for (const i2 in this.selected_nodes) {
              const node222 = this.selected_nodes[i2];
              node222.pin();
            }
            this.setDirty(true, true);
          }, "callback")
        },
        {
          content: "Colors",
          has_submenu: true,
          callback: LGraphCanvas.onMenuNodeColors
        },
        {
          content: "Shapes",
          has_submenu: true,
          callback: LGraphCanvas.onMenuNodeShapes
        },
        null
      );
    }
    const extra = node22.getExtraMenuOptions?.(this, options22);
    if (Array.isArray(extra) && extra.length > 0) {
      extra.push(null);
      options22 = extra.concat(options22);
    }
    if (node22.clonable !== false) {
      options22.push({
        content: "Clone",
        callback: LGraphCanvas.onMenuNodeClone
      });
    }
    if (Object.keys(this.selected_nodes).length > 1) {
      options22.push({
        content: "Align Selected To",
        has_submenu: true,
        callback: LGraphCanvas.onNodeAlign
      }, {
        content: "Distribute Nodes",
        has_submenu: true,
        callback: LGraphCanvas.createDistributeMenu
      });
    }
    options22.push(null, {
      content: "Remove",
      disabled: !(node22.removable !== false && !node22.block_delete),
      callback: LGraphCanvas.onMenuNodeRemove
    });
    node22.graph?.onGetNodeMenuOptions?.(options22, node22);
    return options22;
  }
  /** @deprecated */
  getGroupMenuOptions(group) {
    console.warn("LGraphCanvas.getGroupMenuOptions is deprecated, use LGraphGroup.getMenuOptions instead");
    return group.getMenuOptions();
  }
  processContextMenu(node22, event) {
    const canvas2 = LGraphCanvas.active_canvas;
    const ref_window = canvas2.getCanvasWindow();
    let menu_info;
    const options22 = {
      event,
      callback: inner_option_clicked,
      extra: node22
    };
    if (node22) {
      options22.title = node22.type ?? void 0;
      LGraphCanvas.active_node = node22;
      const slot = node22.getSlotInPosition(event.canvasX, event.canvasY);
      if (slot) {
        menu_info = [];
        if (node22.getSlotMenuOptions) {
          menu_info = node22.getSlotMenuOptions(slot);
        } else {
          if (slot?.output?.links?.length)
            menu_info.push({ content: "Disconnect Links", slot });
          const _slot = slot.input || slot.output;
          if (!_slot) throw new TypeError("Both in put and output slots were null when processing context menu.");
          if (_slot.removable) {
            menu_info.push(
              _slot.locked ? "Cannot remove" : { content: "Remove Slot", slot }
            );
          }
          if (!_slot.nameLocked)
            menu_info.push({ content: "Rename Slot", slot });
          if (node22.getExtraSlotMenuOptions) {
            menu_info.push(...node22.getExtraSlotMenuOptions(slot));
          }
        }
        options22.title = (slot.input ? slot.input.type : slot.output.type) || "*";
        if (slot.input && slot.input.type == LiteGraph.ACTION)
          options22.title = "Action";
        if (slot.output && slot.output.type == LiteGraph.EVENT)
          options22.title = "Event";
      } else {
        menu_info = this.getNodeMenuOptions(node22);
      }
    } else {
      menu_info = this.getCanvasMenuOptions();
      if (!this.graph) throw new NullGraphError();
      if (this.links_render_mode !== LinkRenderType.HIDDEN_LINK) {
        const reroute = this.graph.getRerouteOnPos(event.canvasX, event.canvasY);
        if (reroute) {
          menu_info.unshift({
            content: "Delete Reroute",
            callback: /* @__PURE__ */ __name(() => {
              if (!this.graph) throw new NullGraphError();
              this.graph.removeReroute(reroute.id);
            }, "callback")
          }, null);
        }
      }
      const group = this.graph.getGroupOnPos(
        event.canvasX,
        event.canvasY
      );
      if (group) {
        menu_info.push(null, {
          content: "Edit Group",
          has_submenu: true,
          submenu: {
            title: "Group",
            extra: group,
            options: group.getMenuOptions()
          }
        });
      }
    }
    if (!menu_info) return;
    new LiteGraph.ContextMenu(menu_info, options22, ref_window);
    const createDialog = /* @__PURE__ */ __name((options222) => this.createDialog(
      "<span class='name'>Name</span><input autofocus type='text'/><button>OK</button>",
      options222
    ), "createDialog");
    const setDirty = /* @__PURE__ */ __name(() => this.setDirty(true), "setDirty");
    function inner_option_clicked(v2, options222) {
      if (!v2) return;
      if (v2.content == "Remove Slot") {
        if (!node22?.graph) throw new NullGraphError();
        const info = v2.slot;
        if (!info) throw new TypeError("Found-slot info was null when processing context menu.");
        node22.graph.beforeChange();
        if (info.input) {
          node22.removeInput(info.slot);
        } else if (info.output) {
          node22.removeOutput(info.slot);
        }
        node22.graph.afterChange();
        return;
      } else if (v2.content == "Disconnect Links") {
        if (!node22?.graph) throw new NullGraphError();
        const info = v2.slot;
        if (!info) throw new TypeError("Found-slot info was null when processing context menu.");
        node22.graph.beforeChange();
        if (info.output) {
          node22.disconnectOutput(info.slot);
        } else if (info.input) {
          node22.disconnectInput(info.slot, true);
        }
        node22.graph.afterChange();
        return;
      } else if (v2.content == "Rename Slot") {
        if (!node22) throw new TypeError("`node` was null when processing the context menu.");
        const info = v2.slot;
        if (!info) throw new TypeError("Found-slot info was null when processing context menu.");
        const slot_info = info.input ? node22.getInputInfo(info.slot) : node22.getOutputInfo(info.slot);
        const dialog = createDialog(options222);
        const input = dialog.querySelector("input");
        if (input && slot_info) {
          input.value = slot_info.label || "";
        }
        const inner = /* @__PURE__ */ __name(function() {
          if (!node22.graph) throw new NullGraphError();
          node22.graph.beforeChange();
          if (input?.value) {
            if (slot_info) {
              slot_info.label = input.value;
            }
            setDirty();
          }
          dialog.close();
          node22.graph.afterChange();
        }, "inner");
        dialog.querySelector("button")?.addEventListener("click", inner);
        if (!input) throw new TypeError("Input element was null when processing context menu.");
        input.addEventListener("keydown", function(e2) {
          dialog.is_modified = true;
          if (e2.key == "Escape") {
            dialog.close();
          } else if (e2.key == "Enter") {
            inner();
          } else if (e2.target.localName != "textarea") {
            return;
          }
          e2.preventDefault();
          e2.stopPropagation();
        });
        input.focus();
      }
    }
    __name(inner_option_clicked, "inner_option_clicked");
  }
  /**
   * Starts an animation to fit the view around the specified selection of nodes.
   * @param bounds The bounds to animate the view to, defined by a rectangle.
   */
  animateToBounds(bounds, options22 = {}) {
    const setDirty = /* @__PURE__ */ __name(() => this.setDirty(true, true), "setDirty");
    this.ds.animateToBounds(bounds, setDirty, options22);
  }
  /**
   * Fits the view to the selected nodes with animation.
   * If nothing is selected, the view is fitted around all items in the graph.
   */
  fitViewToSelectionAnimated(options22 = {}) {
    const items2 = this.selectedItems.size ? Array.from(this.selectedItems) : this.positionableItems;
    const bounds = createBounds(items2);
    if (!bounds) throw new TypeError("Attempted to fit to view but could not calculate bounds.");
    const setDirty = /* @__PURE__ */ __name(() => this.setDirty(true, true), "setDirty");
    this.ds.animateToBounds(bounds, setDirty, options22);
  }
}
class MapProxyHandler {
  static {
    __name(this, "MapProxyHandler");
  }
  getOwnPropertyDescriptor(target2, p2) {
    const value3 = this.get(target2, p2);
    if (value3) {
      return {
        configurable: true,
        enumerable: true,
        value: value3
      };
    }
  }
  has(target2, p2) {
    if (typeof p2 === "symbol") return false;
    const int = parseInt(p2, 10);
    return target2.has(!isNaN(int) ? int : p2);
  }
  ownKeys(target2) {
    return [...target2.keys()].map(String);
  }
  get(target2, p2) {
    if (p2 in target2) return Reflect.get(target2, p2, target2);
    if (typeof p2 === "symbol") return;
    const int = parseInt(p2, 10);
    return target2.get(!isNaN(int) ? int : p2);
  }
  set(target2, p2, newValue2) {
    if (typeof p2 === "symbol") return false;
    const int = parseInt(p2, 10);
    target2.set(!isNaN(int) ? int : p2, newValue2);
    return true;
  }
  deleteProperty(target2, p2) {
    return target2.delete(p2);
  }
  static bindAllMethods(map3) {
    map3.clear = map3.clear.bind(map3);
    map3.delete = map3.delete.bind(map3);
    map3.forEach = map3.forEach.bind(map3);
    map3.get = map3.get.bind(map3);
    map3.has = map3.has.bind(map3);
    map3.set = map3.set.bind(map3);
    map3.entries = map3.entries.bind(map3);
    map3.keys = map3.keys.bind(map3);
    map3.values = map3.values.bind(map3);
  }
}
let LGraph$1 = class LGraph2 {
  static {
    __name(this, "LGraph");
  }
  static serialisedSchemaVersion = 1;
  // default supported types
  static supported_types = ["number", "string", "boolean"];
  static STATUS_STOPPED = 1;
  static STATUS_RUNNING = 2;
  id = zeroUuid;
  revision = 0;
  _version = -1;
  /** The backing store for links.  Keys are wrapped in String() */
  _links = /* @__PURE__ */ new Map();
  /**
   * Indexed property access is deprecated.
   * Backwards compatibility with a Proxy has been added, but will eventually be removed.
   *
   * Use {@link Map} methods:
   * ```
   * const linkId = 123
   * const link = graph.links.get(linkId)
   * // Deprecated: const link = graph.links[linkId]
   * ```
   */
  links;
  list_of_graphcanvas;
  status = LGraph2.STATUS_STOPPED;
  state = {
    lastGroupId: 0,
    lastNodeId: 0,
    lastLinkId: 0,
    lastRerouteId: 0
  };
  _nodes = [];
  _nodes_by_id = {};
  _nodes_in_order = [];
  _nodes_executable = null;
  _groups = [];
  iteration = 0;
  globaltime = 0;
  /** @deprecated Unused */
  runningtime = 0;
  fixedtime = 0;
  fixedtime_lapse = 0.01;
  elapsed_time = 0.01;
  last_update_time = 0;
  starttime = 0;
  catch_errors = true;
  execution_timer_id;
  errors_in_execution;
  /** @deprecated Unused */
  execution_time;
  _last_trigger_time;
  filter;
  /** Must contain serialisable values, e.g. primitive types */
  config = {};
  vars = {};
  nodes_executing = [];
  nodes_actioning = [];
  nodes_executedAction = [];
  extra = {};
  inputs = {};
  outputs = {};
  /** @deprecated Deserialising a workflow sets this unused property. */
  version;
  /** @returns Whether the graph has no items */
  get empty() {
    return this._nodes.length + this._groups.length + this.reroutes.size === 0;
  }
  /** @returns All items on the canvas that can be selected */
  *positionableItems() {
    for (const node22 of this._nodes) yield node22;
    for (const group of this._groups) yield group;
    for (const reroute of this.reroutes.values()) yield reroute;
    return;
  }
  /** Internal only.  Not required for serialisation; calculated on deserialise. */
  #lastFloatingLinkId = 0;
  #floatingLinks = /* @__PURE__ */ new Map();
  get floatingLinks() {
    return this.#floatingLinks;
  }
  #reroutes = /* @__PURE__ */ new Map();
  /** All reroutes in this graph. */
  get reroutes() {
    return this.#reroutes;
  }
  /** @deprecated See {@link state}.{@link LGraphState.lastNodeId lastNodeId} */
  get last_node_id() {
    return this.state.lastNodeId;
  }
  set last_node_id(value3) {
    this.state.lastNodeId = value3;
  }
  /** @deprecated See {@link state}.{@link LGraphState.lastLinkId lastLinkId} */
  get last_link_id() {
    return this.state.lastLinkId;
  }
  set last_link_id(value3) {
    this.state.lastLinkId = value3;
  }
  _input_nodes;
  /**
   * See {@link LGraph}
   * @param o data from previous serialization [optional]
   */
  constructor(o2) {
    if (LiteGraph.debug) console.log("Graph created");
    const links = this._links;
    MapProxyHandler.bindAllMethods(links);
    const handler14 = new MapProxyHandler();
    this.links = new Proxy(links, handler14);
    this.list_of_graphcanvas = null;
    this.clear();
    if (o2) this.configure(o2);
  }
  // TODO: Remove
  // used to know which types of connections support this graph (some graphs do not allow certain types)
  getSupportedTypes() {
    return this.supported_types || LGraph2.supported_types;
  }
  /**
   * Removes all nodes from this graph
   */
  clear() {
    this.stop();
    this.status = LGraph2.STATUS_STOPPED;
    this.id = zeroUuid;
    this.revision = 0;
    this.state = {
      lastGroupId: 0,
      lastNodeId: 0,
      lastLinkId: 0,
      lastRerouteId: 0
    };
    this._version = -1;
    if (this._nodes) {
      for (const _node of this._nodes) {
        _node.onRemoved?.();
      }
    }
    this._nodes = [];
    this._nodes_by_id = {};
    this._nodes_in_order = [];
    this._nodes_executable = null;
    this._links.clear();
    this.reroutes.clear();
    this.#floatingLinks.clear();
    this._groups = [];
    this.iteration = 0;
    this.config = {};
    this.vars = {};
    this.extra = {};
    this.globaltime = 0;
    this.runningtime = 0;
    this.fixedtime = 0;
    this.fixedtime_lapse = 0.01;
    this.elapsed_time = 0.01;
    this.last_update_time = 0;
    this.starttime = 0;
    this.catch_errors = true;
    this.nodes_executing = [];
    this.nodes_actioning = [];
    this.nodes_executedAction = [];
    this.inputs = {};
    this.outputs = {};
    this.change();
    this.canvasAction((c2) => c2.clear());
  }
  get nodes() {
    return this._nodes;
  }
  get groups() {
    return this._groups;
  }
  /**
   * Attach Canvas to this graph
   */
  attachCanvas(graphcanvas) {
    if (graphcanvas.constructor != LGraphCanvas)
      throw "attachCanvas expects a LGraphCanvas instance";
    if (graphcanvas.graph != this)
      graphcanvas.graph?.detachCanvas(graphcanvas);
    graphcanvas.graph = this;
    this.list_of_graphcanvas ||= [];
    this.list_of_graphcanvas.push(graphcanvas);
  }
  /**
   * Detach Canvas from this graph
   */
  detachCanvas(graphcanvas) {
    if (!this.list_of_graphcanvas) return;
    const pos = this.list_of_graphcanvas.indexOf(graphcanvas);
    if (pos == -1) return;
    graphcanvas.graph = null;
    this.list_of_graphcanvas.splice(pos, 1);
  }
  /**
   * @deprecated Will be removed in 0.9
   * Starts running this graph every interval milliseconds.
   * @param interval amount of milliseconds between executions, if 0 then it renders to the monitor refresh rate
   */
  start(interval) {
    if (this.status == LGraph2.STATUS_RUNNING) return;
    this.status = LGraph2.STATUS_RUNNING;
    this.onPlayEvent?.();
    this.sendEventToAllNodes("onStart");
    this.starttime = LiteGraph.getTime();
    this.last_update_time = this.starttime;
    interval ||= 0;
    if (interval == 0 && typeof window != "undefined" && window.requestAnimationFrame) {
      const on_frame = /* @__PURE__ */ __name(() => {
        if (this.execution_timer_id != -1) return;
        window.requestAnimationFrame(on_frame);
        this.onBeforeStep?.();
        this.runStep(1, !this.catch_errors);
        this.onAfterStep?.();
      }, "on_frame");
      this.execution_timer_id = -1;
      on_frame();
    } else {
      this.execution_timer_id = setInterval(() => {
        this.onBeforeStep?.();
        this.runStep(1, !this.catch_errors);
        this.onAfterStep?.();
      }, interval);
    }
  }
  /**
   * @deprecated Will be removed in 0.9
   * Stops the execution loop of the graph
   */
  stop() {
    if (this.status == LGraph2.STATUS_STOPPED) return;
    this.status = LGraph2.STATUS_STOPPED;
    this.onStopEvent?.();
    if (this.execution_timer_id != null) {
      if (this.execution_timer_id != -1) {
        clearInterval(this.execution_timer_id);
      }
      this.execution_timer_id = null;
    }
    this.sendEventToAllNodes("onStop");
  }
  /**
   * Run N steps (cycles) of the graph
   * @param num number of steps to run, default is 1
   * @param do_not_catch_errors [optional] if you want to try/catch errors
   * @param limit max number of nodes to execute (used to execute from start to a node)
   */
  runStep(num, do_not_catch_errors, limit) {
    num = num || 1;
    const start2 = LiteGraph.getTime();
    this.globaltime = 1e-3 * (start2 - this.starttime);
    const nodes = this._nodes_executable || this._nodes;
    if (!nodes) return;
    limit = limit || nodes.length;
    if (do_not_catch_errors) {
      for (let i2 = 0; i2 < num; i2++) {
        for (let j2 = 0; j2 < limit; ++j2) {
          const node22 = nodes[j2];
          if (node22.mode == LGraphEventMode.ALWAYS && node22.onExecute) {
            node22.doExecute?.();
          }
        }
        this.fixedtime += this.fixedtime_lapse;
        this.onExecuteStep?.();
      }
      this.onAfterExecute?.();
    } else {
      try {
        for (let i2 = 0; i2 < num; i2++) {
          for (let j2 = 0; j2 < limit; ++j2) {
            const node22 = nodes[j2];
            if (node22.mode == LGraphEventMode.ALWAYS) {
              node22.onExecute?.();
            }
          }
          this.fixedtime += this.fixedtime_lapse;
          this.onExecuteStep?.();
        }
        this.onAfterExecute?.();
        this.errors_in_execution = false;
      } catch (error2) {
        this.errors_in_execution = true;
        if (LiteGraph.throw_errors) throw error2;
        if (LiteGraph.debug) console.log("Error during execution:", error2);
        this.stop();
      }
    }
    const now2 = LiteGraph.getTime();
    let elapsed = now2 - start2;
    if (elapsed == 0) elapsed = 1;
    this.execution_time = 1e-3 * elapsed;
    this.globaltime += 1e-3 * elapsed;
    this.iteration += 1;
    this.elapsed_time = (now2 - this.last_update_time) * 1e-3;
    this.last_update_time = now2;
    this.nodes_executing = [];
    this.nodes_actioning = [];
    this.nodes_executedAction = [];
  }
  /**
   * Updates the graph execution order according to relevance of the nodes (nodes with only outputs have more relevance than
   * nodes with only inputs.
   */
  updateExecutionOrder() {
    this._nodes_in_order = this.computeExecutionOrder(false);
    this._nodes_executable = [];
    for (const node22 of this._nodes_in_order) {
      if (node22.onExecute) {
        this._nodes_executable.push(node22);
      }
    }
  }
  // This is more internal, it computes the executable nodes in order and returns it
  computeExecutionOrder(only_onExecute, set_level) {
    const L2 = [];
    const S2 = [];
    const M2 = {};
    const visited_links = {};
    const remaining_links = {};
    for (const node22 of this._nodes) {
      if (only_onExecute && !node22.onExecute) {
        continue;
      }
      M2[node22.id] = node22;
      let num = 0;
      if (node22.inputs) {
        for (const input of node22.inputs) {
          if (input?.link != null) {
            num += 1;
          }
        }
      }
      if (num == 0) {
        S2.push(node22);
        if (set_level) node22._level = 1;
      } else {
        if (set_level) node22._level = 0;
        remaining_links[node22.id] = num;
      }
    }
    while (true) {
      const node22 = S2.shift();
      if (node22 === void 0) break;
      L2.push(node22);
      delete M2[node22.id];
      if (!node22.outputs) continue;
      for (const output of node22.outputs) {
        if (output?.links == null || output.links.length == 0)
          continue;
        for (const link_id of output.links) {
          const link2 = this._links.get(link_id);
          if (!link2) continue;
          if (visited_links[link2.id]) continue;
          const target_node = this.getNodeById(link2.target_id);
          if (target_node == null) {
            visited_links[link2.id] = true;
            continue;
          }
          if (set_level) {
            node22._level ??= 0;
            if (!target_node._level || target_node._level <= node22._level) {
              target_node._level = node22._level + 1;
            }
          }
          visited_links[link2.id] = true;
          remaining_links[target_node.id] -= 1;
          if (remaining_links[target_node.id] == 0) S2.push(target_node);
        }
      }
    }
    for (const i2 in M2) {
      L2.push(M2[i2]);
    }
    if (L2.length != this._nodes.length && LiteGraph.debug)
      console.warn("something went wrong, nodes missing");
    function setOrder(nodes) {
      const l2 = nodes.length;
      for (let i2 = 0; i2 < l2; ++i2) {
        nodes[i2].order = i2;
      }
    }
    __name(setOrder, "setOrder");
    setOrder(L2);
    L2.sort(function(A2, B2) {
      const Ap = A2.constructor.priority || A2.priority || 0;
      const Bp = B2.constructor.priority || B2.priority || 0;
      return Ap == Bp ? A2.order - B2.order : Ap - Bp;
    });
    setOrder(L2);
    return L2;
  }
  /**
   * @deprecated Will be removed in 0.9
   * Returns all the nodes that could affect this one (ancestors) by crawling all the inputs recursively.
   * It doesn't include the node itself
   * @returns an array with all the LGraphNodes that affect this node, in order of execution
   */
  getAncestors(node22) {
    const ancestors = [];
    const pending = [node22];
    const visited = {};
    while (pending.length) {
      const current = pending.shift();
      if (!current?.inputs) continue;
      if (!visited[current.id] && current != node22) {
        visited[current.id] = true;
        ancestors.push(current);
      }
      for (let i2 = 0; i2 < current.inputs.length; ++i2) {
        const input = current.getInputNode(i2);
        if (input && !ancestors.includes(input)) {
          pending.push(input);
        }
      }
    }
    ancestors.sort(function(a2, b2) {
      return a2.order - b2.order;
    });
    return ancestors;
  }
  /**
   * Positions every node in a more readable manner
   */
  arrange(margin, layout) {
    margin = margin || 100;
    const nodes = this.computeExecutionOrder(false, true);
    const columns = [];
    for (const node22 of nodes) {
      const col = node22._level || 1;
      columns[col] ||= [];
      columns[col].push(node22);
    }
    let x2 = margin;
    for (const column of columns) {
      if (!column) continue;
      let max_size = 100;
      let y2 = margin + LiteGraph.NODE_TITLE_HEIGHT;
      for (const node22 of column) {
        node22.pos[0] = layout == LiteGraph.VERTICAL_LAYOUT ? y2 : x2;
        node22.pos[1] = layout == LiteGraph.VERTICAL_LAYOUT ? x2 : y2;
        const max_size_index = layout == LiteGraph.VERTICAL_LAYOUT ? 1 : 0;
        if (node22.size[max_size_index] > max_size) {
          max_size = node22.size[max_size_index];
        }
        const node_size_index = layout == LiteGraph.VERTICAL_LAYOUT ? 0 : 1;
        y2 += node22.size[node_size_index] + margin + LiteGraph.NODE_TITLE_HEIGHT;
      }
      x2 += max_size + margin;
    }
    this.setDirtyCanvas(true, true);
  }
  /**
   * Returns the amount of time the graph has been running in milliseconds
   * @returns number of milliseconds the graph has been running
   */
  getTime() {
    return this.globaltime;
  }
  /**
   * Returns the amount of time accumulated using the fixedtime_lapse var.
   * This is used in context where the time increments should be constant
   * @returns number of milliseconds the graph has been running
   */
  getFixedTime() {
    return this.fixedtime;
  }
  /**
   * Returns the amount of time it took to compute the latest iteration.
   * Take into account that this number could be not correct
   * if the nodes are using graphical actions
   * @returns number of milliseconds it took the last cycle
   */
  getElapsedTime() {
    return this.elapsed_time;
  }
  /**
   * @deprecated Will be removed in 0.9
   * Sends an event to all the nodes, useful to trigger stuff
   * @param eventname the name of the event (function to be called)
   * @param params parameters in array format
   */
  sendEventToAllNodes(eventname, params, mode2) {
    mode2 = mode2 || LGraphEventMode.ALWAYS;
    const nodes = this._nodes_in_order || this._nodes;
    if (!nodes) return;
    for (const node22 of nodes) {
      if (!node22[eventname] || node22.mode != mode2) continue;
      if (params === void 0) {
        node22[eventname]();
      } else if (params && params.constructor === Array) {
        node22[eventname].apply(node22, params);
      } else {
        node22[eventname](params);
      }
    }
  }
  /**
   * Runs an action on every canvas registered to this graph.
   * @param action Action to run for every canvas
   */
  canvasAction(action) {
    const canvases = this.list_of_graphcanvas;
    if (!canvases) return;
    for (const canvas2 of canvases) action(canvas2);
  }
  /** @deprecated See {@link LGraph.canvasAction} */
  sendActionToCanvas(action, params) {
    const { list_of_graphcanvas } = this;
    if (!list_of_graphcanvas) return;
    for (const c2 of list_of_graphcanvas) {
      c2[action]?.apply(c2, params);
    }
  }
  /**
   * Adds a new node instance to this graph
   * @param node the instance of the node
   */
  add(node22, skip_compute_order) {
    if (!node22) return;
    const { state } = this;
    if (LiteGraph.alwaysSnapToGrid) {
      const snapTo = this.getSnapToGridSize();
      if (snapTo) node22.snapToGrid(snapTo);
    }
    if (node22 instanceof LGraphGroup) {
      if (node22.id == null || node22.id === -1) node22.id = ++state.lastGroupId;
      if (node22.id > state.lastGroupId) state.lastGroupId = node22.id;
      this._groups.push(node22);
      this.setDirtyCanvas(true);
      this.change();
      node22.graph = this;
      this._version++;
      return;
    }
    if (node22.id != -1 && this._nodes_by_id[node22.id] != null) {
      console.warn(
        "LiteGraph: there is already a node with this ID, changing it"
      );
      node22.id = LiteGraph.use_uuids ? LiteGraph.uuidv4() : ++state.lastNodeId;
    }
    if (this._nodes.length >= LiteGraph.MAX_NUMBER_OF_NODES) {
      throw "LiteGraph: max number of nodes in a graph reached";
    }
    if (LiteGraph.use_uuids) {
      if (node22.id == null || node22.id == -1)
        node22.id = LiteGraph.uuidv4();
    } else {
      if (node22.id == null || node22.id == -1) {
        node22.id = ++state.lastNodeId;
      } else if (typeof node22.id === "number" && state.lastNodeId < node22.id) {
        state.lastNodeId = node22.id;
      }
    }
    node22.graph = this;
    this._version++;
    this._nodes.push(node22);
    this._nodes_by_id[node22.id] = node22;
    node22.onAdded?.(this);
    if (this.config.align_to_grid) node22.alignToGrid();
    if (!skip_compute_order) this.updateExecutionOrder();
    this.onNodeAdded?.(node22);
    this.setDirtyCanvas(true);
    this.change();
    return node22;
  }
  /**
   * Removes a node from the graph
   * @param node the instance of the node
   */
  remove(node22) {
    if (node22 instanceof LGraphGroup) {
      const index2 = this._groups.indexOf(node22);
      if (index2 != -1) {
        this._groups.splice(index2, 1);
      }
      node22.graph = void 0;
      this._version++;
      this.setDirtyCanvas(true, true);
      this.change();
      return;
    }
    if (this._nodes_by_id[node22.id] == null) return;
    if (node22.ignore_remove) return;
    this.beforeChange();
    const { inputs, outputs } = node22;
    if (inputs) {
      for (const [i2, slot] of inputs.entries()) {
        if (slot.link != null) node22.disconnectInput(i2, true);
      }
    }
    if (outputs) {
      for (const [i2, slot] of outputs.entries()) {
        if (slot.links?.length) node22.disconnectOutput(i2);
      }
    }
    for (const link2 of this.floatingLinks.values()) {
      if (link2.origin_id === node22.id || link2.target_id === node22.id) {
        this.removeFloatingLink(link2);
      }
    }
    node22.onRemoved?.();
    node22.graph = null;
    this._version++;
    const { list_of_graphcanvas } = this;
    if (list_of_graphcanvas) {
      for (const canvas2 of list_of_graphcanvas) {
        if (canvas2.selected_nodes[node22.id])
          delete canvas2.selected_nodes[node22.id];
      }
    }
    const pos = this._nodes.indexOf(node22);
    if (pos != -1) this._nodes.splice(pos, 1);
    delete this._nodes_by_id[node22.id];
    this.onNodeRemoved?.(node22);
    this.canvasAction((c2) => c2.checkPanels());
    this.setDirtyCanvas(true, true);
    this.afterChange();
    this.change();
    this.updateExecutionOrder();
  }
  /**
   * Returns a node by its id.
   */
  getNodeById(id4) {
    return id4 != null ? this._nodes_by_id[id4] : null;
  }
  /**
   * Returns a list of nodes that matches a class
   * @param classObject the class itself (not an string)
   * @returns a list with all the nodes of this type
   */
  // eslint-disable-next-line @typescript-eslint/no-unsafe-function-type
  findNodesByClass(classObject, result) {
    result = result || [];
    result.length = 0;
    const { _nodes } = this;
    for (const node22 of _nodes) {
      if (node22.constructor === classObject)
        result.push(node22);
    }
    return result;
  }
  /**
   * Returns a list of nodes that matches a type
   * @param type the name of the node type
   * @returns a list with all the nodes of this type
   */
  findNodesByType(type, result) {
    const matchType = type.toLowerCase();
    result = result || [];
    result.length = 0;
    const { _nodes } = this;
    for (const node22 of _nodes) {
      if (node22.type?.toLowerCase() == matchType)
        result.push(node22);
    }
    return result;
  }
  /**
   * Returns the first node that matches a name in its title
   * @param title the name of the node to search
   * @returns the node or null
   */
  findNodeByTitle(title) {
    const { _nodes } = this;
    for (const node22 of _nodes) {
      if (node22.title == title)
        return node22;
    }
    return null;
  }
  /**
   * Returns a list of nodes that matches a name
   * @param title the name of the node to search
   * @returns a list with all the nodes with this name
   */
  findNodesByTitle(title) {
    const result = [];
    const { _nodes } = this;
    for (const node22 of _nodes) {
      if (node22.title == title)
        result.push(node22);
    }
    return result;
  }
  /**
   * Returns the top-most node in this position of the canvas
   * @param x the x coordinate in canvas space
   * @param y the y coordinate in canvas space
   * @param nodeList a list with all the nodes to search from, by default is all the nodes in the graph
   * @returns the node at this position or null
   */
  getNodeOnPos(x2, y2, nodeList) {
    const nodes = nodeList || this._nodes;
    let i2 = nodes.length;
    while (--i2 >= 0) {
      const node22 = nodes[i2];
      if (node22.isPointInside(x2, y2)) return node22;
    }
    return null;
  }
  /**
   * Returns the top-most group in that position
   * @param x The x coordinate in canvas space
   * @param y The y coordinate in canvas space
   * @returns The group or null
   */
  getGroupOnPos(x2, y2) {
    return this._groups.toReversed().find((g2) => g2.isPointInside(x2, y2));
  }
  /**
   * Returns the top-most group with a titlebar in the provided position.
   * @param x The x coordinate in canvas space
   * @param y The y coordinate in canvas space
   * @returns The group or null
   */
  getGroupTitlebarOnPos(x2, y2) {
    return this._groups.toReversed().find((g2) => g2.isPointInTitlebar(x2, y2));
  }
  /**
   * Finds a reroute a the given graph point
   * @param x X co-ordinate in graph space
   * @param y Y co-ordinate in graph space
   * @returns The first reroute under the given co-ordinates, or undefined
   */
  getRerouteOnPos(x2, y2) {
    for (const reroute of this.reroutes.values()) {
      const { pos } = reroute;
      if (isSortaInsideOctagon(x2 - pos[0], y2 - pos[1], 2 * Reroute.radius))
        return reroute;
    }
  }
  /**
   * Snaps the provided items to a grid.
   *
   * Item positions are reounded to the nearest multiple of {@link LiteGraph.CANVAS_GRID_SIZE}.
   *
   * When {@link LiteGraph.alwaysSnapToGrid} is enabled
   * and the grid size is falsy, a default of 1 is used.
   * @param items The items to be snapped to the grid
   * @todo Currently only snaps nodes.
   */
  snapToGrid(items2) {
    const snapTo = this.getSnapToGridSize();
    if (!snapTo) return;
    for (const item3 of getAllNestedItems(items2)) {
      if (!item3.pinned) item3.snapToGrid(snapTo);
    }
  }
  /**
   * Finds the size of the grid that items should be snapped to when moved.
   * @returns The size of the grid that items should be snapped to
   */
  getSnapToGridSize() {
    return LiteGraph.alwaysSnapToGrid ? LiteGraph.CANVAS_GRID_SIZE || 1 : LiteGraph.CANVAS_GRID_SIZE;
  }
  /**
   * @deprecated Will be removed in 0.9
   * Checks that the node type matches the node type registered,
   * used when replacing a nodetype by a newer version during execution
   * this replaces the ones using the old version with the new version
   */
  checkNodeTypes() {
    const { _nodes } = this;
    for (const [i2, node22] of _nodes.entries()) {
      const ctor = LiteGraph.registered_node_types[node22.type];
      if (node22.constructor == ctor) continue;
      console.log("node being replaced by newer version:", node22.type);
      const newnode = LiteGraph.createNode(node22.type);
      if (!newnode) continue;
      _nodes[i2] = newnode;
      newnode.configure(node22.serialize());
      newnode.graph = this;
      this._nodes_by_id[newnode.id] = newnode;
      if (node22.inputs) newnode.inputs = [...node22.inputs];
      if (node22.outputs) newnode.outputs = [...node22.outputs];
    }
    this.updateExecutionOrder();
  }
  // ********** GLOBALS *****************
  onAction(action, param, options22) {
    this._input_nodes = this.findNodesByClass(
      // @ts-expect-error Never impl.
      LiteGraph.GraphInput,
      this._input_nodes
    );
    for (const node22 of this._input_nodes) {
      if (node22.properties.name != action) continue;
      node22.actionDo(action, param, options22);
      break;
    }
  }
  trigger(action, param) {
    this.onTrigger?.(action, param);
  }
  /**
   * Tell this graph it has a global graph input of this type
   */
  addInput(name2, type, value3) {
    const input = this.inputs[name2];
    if (input) return;
    this.beforeChange();
    this.inputs[name2] = { name: name2, type, value: value3 };
    this._version++;
    this.afterChange();
    this.onInputAdded?.(name2, type);
    this.onInputsOutputsChange?.();
  }
  /**
   * Assign a data to the global graph input
   */
  setInputData(name2, data30) {
    const input = this.inputs[name2];
    if (!input) return;
    input.value = data30;
  }
  /**
   * Returns the current value of a global graph input
   */
  getInputData(name2) {
    const input = this.inputs[name2];
    return input ? input.value : null;
  }
  /**
   * Changes the name of a global graph input
   */
  renameInput(old_name, name2) {
    if (name2 == old_name) return;
    if (!this.inputs[old_name]) return false;
    if (this.inputs[name2]) {
      console.error("there is already one input with that name");
      return false;
    }
    this.inputs[name2] = this.inputs[old_name];
    delete this.inputs[old_name];
    this._version++;
    this.onInputRenamed?.(old_name, name2);
    this.onInputsOutputsChange?.();
  }
  /**
   * Changes the type of a global graph input
   */
  changeInputType(name2, type) {
    if (!this.inputs[name2]) return false;
    if (this.inputs[name2].type && String(this.inputs[name2].type).toLowerCase() == String(type).toLowerCase()) {
      return;
    }
    this.inputs[name2].type = type;
    this._version++;
    this.onInputTypeChanged?.(name2, type);
  }
  /**
   * Removes a global graph input
   */
  removeInput(name2) {
    if (!this.inputs[name2]) return false;
    delete this.inputs[name2];
    this._version++;
    this.onInputRemoved?.(name2);
    this.onInputsOutputsChange?.();
    return true;
  }
  /**
   * Creates a global graph output
   */
  addOutput(name2, type, value3) {
    this.outputs[name2] = { name: name2, type, value: value3 };
    this._version++;
    this.onOutputAdded?.(name2, type);
    this.onInputsOutputsChange?.();
  }
  /**
   * Assign a data to the global output
   */
  setOutputData(name2, value3) {
    const output = this.outputs[name2];
    if (!output) return;
    output.value = value3;
  }
  /**
   * Returns the current value of a global graph output
   */
  getOutputData(name2) {
    const output = this.outputs[name2];
    if (!output) return null;
    return output.value;
  }
  /**
   * Renames a global graph output
   */
  renameOutput(old_name, name2) {
    if (!this.outputs[old_name]) return false;
    if (this.outputs[name2]) {
      console.error("there is already one output with that name");
      return false;
    }
    this.outputs[name2] = this.outputs[old_name];
    delete this.outputs[old_name];
    this._version++;
    this.onOutputRenamed?.(old_name, name2);
    this.onInputsOutputsChange?.();
  }
  /**
   * Changes the type of a global graph output
   */
  changeOutputType(name2, type) {
    if (!this.outputs[name2]) return false;
    if (this.outputs[name2].type && String(this.outputs[name2].type).toLowerCase() == String(type).toLowerCase()) {
      return;
    }
    this.outputs[name2].type = type;
    this._version++;
    this.onOutputTypeChanged?.(name2, type);
  }
  /**
   * Removes a global graph output
   */
  removeOutput(name2) {
    if (!this.outputs[name2]) return false;
    delete this.outputs[name2];
    this._version++;
    this.onOutputRemoved?.(name2);
    this.onInputsOutputsChange?.();
    return true;
  }
  /** @todo Clean up - never implemented. */
  triggerInput(name2, value3) {
    const nodes = this.findNodesByTitle(name2);
    for (const node22 of nodes) {
      node22.onTrigger(value3);
    }
  }
  /** @todo Clean up - never implemented. */
  setCallback(name2, func) {
    const nodes = this.findNodesByTitle(name2);
    for (const node22 of nodes) {
      node22.setTrigger(func);
    }
  }
  // used for undo, called before any change is made to the graph
  beforeChange(info) {
    this.onBeforeChange?.(this, info);
    this.canvasAction((c2) => c2.onBeforeChange?.(this));
  }
  // used to resend actions, called after any change is made to the graph
  afterChange(info) {
    this.onAfterChange?.(this, info);
    this.canvasAction((c2) => c2.onAfterChange?.(this));
  }
  connectionChange(node22) {
    this.updateExecutionOrder();
    this.onConnectionChange?.(node22);
    this._version++;
    this.canvasAction((c2) => c2.onConnectionChange?.());
  }
  /**
   * clears the triggered slot animation in all links (stop visual animation)
   */
  clearTriggeredSlots() {
    for (const link_info of this._links.values()) {
      if (!link_info) continue;
      if (link_info._last_time) link_info._last_time = 0;
    }
  }
  /* Called when something visually changed (not the graph!) */
  change() {
    if (LiteGraph.debug) {
      console.log("Graph changed");
    }
    this.canvasAction((c2) => c2.setDirty(true, true));
    this.on_change?.(this);
  }
  setDirtyCanvas(fg, bg) {
    this.canvasAction((c2) => c2.setDirty(fg, bg));
  }
  addFloatingLink(link2) {
    if (link2.id === -1) {
      link2.id = ++this.#lastFloatingLinkId;
    }
    this.#floatingLinks.set(link2.id, link2);
    const reroutes = LLink.getReroutes(this, link2);
    for (const reroute of reroutes) {
      reroute.floatingLinkIds.add(link2.id);
    }
    return link2;
  }
  removeFloatingLink(link2) {
    this.#floatingLinks.delete(link2.id);
    const reroutes = LLink.getReroutes(this, link2);
    for (const reroute of reroutes) {
      reroute.floatingLinkIds.delete(link2.id);
      if (reroute.floatingLinkIds.size === 0) {
        delete reroute.floating;
      }
      if (reroute.floatingLinkIds.size === 0 && reroute.linkIds.size === 0) {
        this.removeReroute(reroute.id);
      }
    }
  }
  /**
   * Configures a reroute on the graph where ID is already known (probably deserialisation).
   * Creates the object if it does not exist.
   * @param serialisedReroute See {@link SerialisableReroute}
   */
  setReroute({ id: id4, parentId, pos, linkIds, floating }) {
    id4 ??= ++this.state.lastRerouteId;
    if (id4 > this.state.lastRerouteId) this.state.lastRerouteId = id4;
    const reroute = this.reroutes.get(id4) ?? new Reroute(id4, this);
    reroute.update(parentId, pos, linkIds, floating);
    this.reroutes.set(id4, reroute);
    return reroute;
  }
  /**
   * Creates a new reroute and adds it to the graph.
   * @param pos Position in graph space
   * @param before The existing link segment (reroute, link) that will be after this reroute,
   * going from the node output to input.
   * @returns The newly created reroute - typically ignored.
   */
  createReroute(pos, before) {
    const rerouteId = ++this.state.lastRerouteId;
    const linkIds = before instanceof Reroute ? before.linkIds : [before.id];
    const reroute = new Reroute(rerouteId, this, pos, before.parentId, linkIds);
    this.reroutes.set(rerouteId, reroute);
    for (const linkId of linkIds) {
      const link2 = this._links.get(linkId);
      if (!link2) continue;
      if (link2.parentId === before.parentId) link2.parentId = rerouteId;
      const reroutes = LLink.getReroutes(this, link2);
      for (const x2 of reroutes.filter((x22) => x22.parentId === before.parentId)) {
        x2.parentId = rerouteId;
      }
    }
    return reroute;
  }
  /**
   * Removes a reroute from the graph
   * @param id ID of reroute to remove
   */
  removeReroute(id4) {
    const { reroutes } = this;
    const reroute = reroutes.get(id4);
    if (!reroute) return;
    const { parentId, linkIds, floatingLinkIds } = reroute;
    for (const reroute2 of reroutes.values()) {
      if (reroute2.parentId === id4) reroute2.parentId = parentId;
    }
    for (const linkId of linkIds) {
      const link2 = this._links.get(linkId);
      if (link2 && link2.parentId === id4) link2.parentId = parentId;
    }
    for (const linkId of floatingLinkIds) {
      const link2 = this.floatingLinks.get(linkId);
      if (!link2) {
        console.warn(`Removed reroute had floating link ID that did not exist [${linkId}]`);
        continue;
      }
      const floatingReroutes = LLink.getReroutes(this, link2);
      if (!(floatingReroutes.length > 0)) {
        this.#floatingLinks.delete(linkId);
      } else if (link2.parentId === id4) {
        link2.parentId = parentId;
      }
    }
    reroutes.delete(id4);
    this.setDirtyCanvas(false, true);
  }
  /**
   * Destroys a link
   */
  removeLink(link_id) {
    const link2 = this._links.get(link_id);
    if (!link2) return;
    const node22 = this.getNodeById(link2.target_id);
    node22?.disconnectInput(link2.target_slot, false);
    link2.disconnect(this);
  }
  /**
   * Creates a Object containing all the info about this graph, it can be serialized
   * @deprecated Use {@link asSerialisable}, which returns the newer schema version.
   * @returns value of the node
   */
  serialize(option5) {
    const { config: config2, state, groups, nodes, reroutes, extra, floatingLinks } = this.asSerialisable(option5);
    const linkArray = [...this._links.values()];
    const links = linkArray.map((x2) => x2.serialize());
    if (reroutes?.length) {
      extra.linkExtensions = linkArray.filter((x2) => x2.parentId !== void 0).map((x2) => ({ id: x2.id, parentId: x2.parentId }));
    }
    extra.reroutes = reroutes?.length ? reroutes : void 0;
    return {
      id: this.id,
      revision: this.revision,
      last_node_id: state.lastNodeId,
      last_link_id: state.lastLinkId,
      nodes,
      links,
      floatingLinks,
      groups,
      config: config2,
      extra,
      version: LiteGraph.VERSION
    };
  }
  /**
   * Prepares a shallow copy of this object for immediate serialisation or structuredCloning.
   * The return value should be discarded immediately.
   * @param options Serialise options = currently `sortNodes: boolean`, whether to sort nodes by ID.
   * @returns A shallow copy of parts of this graph, with shallow copies of its serialisable objects.
   * Mutating the properties of the return object may result in changes to your graph.
   * It is intended for use with {@link structuredClone} or {@link JSON.stringify}.
   */
  asSerialisable(options22) {
    const { id: id4, revision, config: config2, state, extra } = this;
    const nodeList = !LiteGraph.use_uuids && options22?.sortNodes ? [...this._nodes].sort((a2, b2) => a2.id - b2.id) : this._nodes;
    const nodes = nodeList.map((node22) => node22.serialize());
    const groups = this._groups.map((x2) => x2.serialize());
    const links = this._links.size ? [...this._links.values()].map((x2) => x2.asSerialisable()) : void 0;
    const floatingLinks = this.floatingLinks.size ? [...this.floatingLinks.values()].map((x2) => x2.asSerialisable()) : void 0;
    const reroutes = this.reroutes.size ? [...this.reroutes.values()].map((x2) => x2.asSerialisable()) : void 0;
    const data30 = {
      id: id4,
      revision,
      version: LGraph2.serialisedSchemaVersion,
      config: config2,
      state,
      groups,
      nodes,
      links,
      floatingLinks,
      reroutes,
      extra
    };
    this.onSerialize?.(data30);
    return data30;
  }
  /**
   * Configure a graph from a JSON string
   * @param data The deserialised object to configure this graph from
   * @param keep_old If `true`, the graph will not be cleared prior to
   * adding the configuration.
   */
  configure(data30, keep_old) {
    if (!data30) return;
    if (!keep_old) this.clear();
    if (data30.id) this.id = data30.id;
    else if (this.id === zeroUuid) this.id = createUuidv4();
    let reroutes;
    if (data30.version === 0.4) {
      const { extra } = data30;
      if (Array.isArray(data30.links)) {
        for (const linkData of data30.links) {
          const link2 = LLink.createFromArray(linkData);
          this._links.set(link2.id, link2);
        }
      }
      if (Array.isArray(extra?.linkExtensions)) {
        for (const linkEx of extra.linkExtensions) {
          const link2 = this._links.get(linkEx.id);
          if (link2) link2.parentId = linkEx.parentId;
        }
      }
      reroutes = extra?.reroutes;
    } else {
      if (data30.state) {
        const { state: { lastGroupId, lastLinkId, lastNodeId, lastRerouteId } } = data30;
        if (lastGroupId != null) this.state.lastGroupId = lastGroupId;
        if (lastLinkId != null) this.state.lastLinkId = lastLinkId;
        if (lastNodeId != null) this.state.lastNodeId = lastNodeId;
        if (lastRerouteId != null) this.state.lastRerouteId = lastRerouteId;
      }
      if (Array.isArray(data30.links)) {
        for (const linkData of data30.links) {
          const link2 = LLink.create(linkData);
          this._links.set(link2.id, link2);
        }
      }
      reroutes = data30.reroutes;
    }
    if (Array.isArray(data30.floatingLinks)) {
      for (const linkData of data30.floatingLinks) {
        const floatingLink = LLink.create(linkData);
        this.#floatingLinks.set(floatingLink.id, floatingLink);
        if (floatingLink.id > this.#lastFloatingLinkId) this.#lastFloatingLinkId = floatingLink.id;
      }
    }
    if (Array.isArray(reroutes)) {
      for (const rerouteData of reroutes) {
        this.setReroute(rerouteData);
      }
    }
    for (const floatingLink of this.floatingLinks.values()) {
      const reroutes2 = LLink.getReroutes(this, floatingLink);
      for (const reroute of reroutes2) {
        reroute.floatingLinkIds.add(floatingLink.id);
      }
    }
    for (const reroute of this.reroutes.values()) {
      if (!reroute.validateLinks(this._links, this.floatingLinks)) {
        this.reroutes.delete(reroute.id);
      }
    }
    const nodesData = data30.nodes;
    for (const i2 in data30) {
      if (["nodes", "groups", "links", "state", "reroutes", "floatingLinks", "id"].includes(i2)) {
        continue;
      }
      this[i2] = data30[i2];
    }
    let error2 = false;
    this._nodes = [];
    if (nodesData) {
      for (const n_info of nodesData) {
        let node22 = LiteGraph.createNode(String(n_info.type), n_info.title);
        if (!node22) {
          if (LiteGraph.debug) console.log("Node not found or has errors:", n_info.type);
          node22 = new LGraphNode("");
          node22.last_serialization = n_info;
          node22.has_errors = true;
          error2 = true;
        }
        node22.id = n_info.id;
        this.add(node22, true);
      }
      for (const n_info of nodesData) {
        const node22 = this.getNodeById(n_info.id);
        node22?.configure(n_info);
      }
    }
    this._groups.length = 0;
    const groupData = data30.groups;
    if (groupData) {
      for (const data210 of groupData) {
        const group = new LiteGraph.LGraphGroup();
        group.configure(data210);
        this.add(group);
      }
    }
    this.updateExecutionOrder();
    this.extra = data30.extra || {};
    this.onConfigure?.(data30);
    this._version++;
    this.setDirtyCanvas(true, true);
    return error2;
  }
  load(url, callback) {
    const that = this;
    if (url instanceof Blob || url instanceof File) {
      const reader = new FileReader();
      reader.addEventListener("load", function(event) {
        const result = stringOrEmpty(event.target?.result);
        const data30 = JSON.parse(result);
        that.configure(data30);
        callback?.();
      });
      reader.readAsText(url);
      return;
    }
    const req = new XMLHttpRequest();
    req.open("GET", url, true);
    req.send(null);
    req.addEventListener("load", function() {
      if (req.status !== 200) {
        console.error("Error loading graph:", req.status, req.response);
        return;
      }
      const data30 = JSON.parse(req.response);
      that.configure(data30);
      callback?.();
    });
    req.addEventListener("error", (err) => {
      console.error("Error loading graph:", err);
    });
  }
};
class LiteGraphGlobal {
  static {
    __name(this, "LiteGraphGlobal");
  }
  // Enums
  SlotShape = SlotShape;
  SlotDirection = SlotDirection;
  SlotType = SlotType;
  LabelPosition = LabelPosition;
  /** Used in serialised graphs at one point. */
  VERSION = 0.4;
  CANVAS_GRID_SIZE = 10;
  NODE_TITLE_HEIGHT = 30;
  NODE_TITLE_TEXT_Y = 20;
  NODE_SLOT_HEIGHT = 20;
  NODE_WIDGET_HEIGHT = 20;
  NODE_WIDTH = 140;
  NODE_MIN_WIDTH = 50;
  NODE_COLLAPSED_RADIUS = 10;
  NODE_COLLAPSED_WIDTH = 80;
  NODE_TITLE_COLOR = "#999";
  NODE_SELECTED_TITLE_COLOR = "#FFF";
  NODE_TEXT_SIZE = 14;
  NODE_TEXT_COLOR = "#AAA";
  NODE_TEXT_HIGHLIGHT_COLOR = "#EEE";
  NODE_SUBTEXT_SIZE = 12;
  NODE_DEFAULT_COLOR = "#333";
  NODE_DEFAULT_BGCOLOR = "#353535";
  NODE_DEFAULT_BOXCOLOR = "#666";
  NODE_DEFAULT_SHAPE = RenderShape.ROUND;
  NODE_BOX_OUTLINE_COLOR = "#FFF";
  NODE_ERROR_COLOUR = "#E00";
  DEFAULT_SHADOW_COLOR = "rgba(0,0,0,0.5)";
  DEFAULT_GROUP_FONT = 24;
  DEFAULT_GROUP_FONT_SIZE;
  WIDGET_BGCOLOR = "#222";
  WIDGET_OUTLINE_COLOR = "#666";
  WIDGET_ADVANCED_OUTLINE_COLOR = "rgba(56, 139, 253, 0.8)";
  WIDGET_TEXT_COLOR = "#DDD";
  WIDGET_SECONDARY_TEXT_COLOR = "#999";
  LINK_COLOR = "#9A9";
  EVENT_LINK_COLOR = "#A86";
  CONNECTING_LINK_COLOR = "#AFA";
  /** avoid infinite loops */
  MAX_NUMBER_OF_NODES = 1e4;
  /** default node position */
  DEFAULT_POSITION = [100, 100];
  /** ,"circle" */
  VALID_SHAPES = ["default", "box", "round", "card"];
  ROUND_RADIUS = 8;
  // shapes are used for nodes but also for slots
  BOX_SHAPE = RenderShape.BOX;
  ROUND_SHAPE = RenderShape.ROUND;
  CIRCLE_SHAPE = RenderShape.CIRCLE;
  CARD_SHAPE = RenderShape.CARD;
  ARROW_SHAPE = RenderShape.ARROW;
  /** intended for slot arrays */
  GRID_SHAPE = RenderShape.GRID;
  // enums
  INPUT = NodeSlotType.INPUT;
  OUTPUT = NodeSlotType.OUTPUT;
  // TODO: -1 can lead to ambiguity in JS; these should be updated to a more explicit constant or Symbol.
  /** for outputs */
  EVENT = -1;
  /** for inputs */
  ACTION = -1;
  /** helper, will add "On Request" and more in the future */
  NODE_MODES = ["Always", "On Event", "Never", "On Trigger"];
  /** use with node_box_coloured_by_mode */
  NODE_MODES_COLORS = ["#666", "#422", "#333", "#224", "#626"];
  ALWAYS = LGraphEventMode.ALWAYS;
  ON_EVENT = LGraphEventMode.ON_EVENT;
  NEVER = LGraphEventMode.NEVER;
  ON_TRIGGER = LGraphEventMode.ON_TRIGGER;
  UP = LinkDirection.UP;
  DOWN = LinkDirection.DOWN;
  LEFT = LinkDirection.LEFT;
  RIGHT = LinkDirection.RIGHT;
  CENTER = LinkDirection.CENTER;
  /** helper */
  LINK_RENDER_MODES = ["Straight", "Linear", "Spline"];
  HIDDEN_LINK = LinkRenderType.HIDDEN_LINK;
  STRAIGHT_LINK = LinkRenderType.STRAIGHT_LINK;
  LINEAR_LINK = LinkRenderType.LINEAR_LINK;
  SPLINE_LINK = LinkRenderType.SPLINE_LINK;
  NORMAL_TITLE = TitleMode.NORMAL_TITLE;
  NO_TITLE = TitleMode.NO_TITLE;
  TRANSPARENT_TITLE = TitleMode.TRANSPARENT_TITLE;
  AUTOHIDE_TITLE = TitleMode.AUTOHIDE_TITLE;
  /** arrange nodes vertically */
  VERTICAL_LAYOUT = "vertical";
  /** used to redirect calls */
  proxy = null;
  node_images_path = "";
  debug = false;
  catch_exceptions = true;
  throw_errors = true;
  /** if set to true some nodes like Formula would be allowed to evaluate code that comes from unsafe sources (like node configuration), which could lead to exploits */
  allow_scripts = false;
  /** nodetypes by string */
  registered_node_types = {};
  /** @deprecated used for dropping files in the canvas.  It appears the code that enables this was removed, but the object remains and is references by built-in drag drop. */
  node_types_by_file_extension = {};
  /** node types by classname */
  Nodes = {};
  /** used to store vars between graphs */
  Globals = {};
  /** @deprecated Unused and will be deleted. */
  searchbox_extras = {};
  /** [true!] this make the nodes box (top left circle) coloured when triggered (execute/action), visual feedback */
  node_box_coloured_when_on = false;
  /** [true!] nodebox based on node mode, visual feedback */
  node_box_coloured_by_mode = false;
  /** [false on mobile] better true if not touch device, TODO add an helper/listener to close if false */
  dialog_close_on_mouse_leave = false;
  dialog_close_on_mouse_leave_delay = 500;
  /** [false!] prefer false if results too easy to break links - implement with ALT or TODO custom keys */
  shift_click_do_break_link_from = false;
  /** [false!]prefer false, way too easy to break links */
  click_do_break_link_to = false;
  /** [true!] who accidentally ctrl-alt-clicks on an in/output? nobody! that's who! */
  ctrl_alt_click_do_break_link = true;
  /** [true!] snaps links when dragging connections over valid targets */
  snaps_for_comfy = true;
  /** [true!] renders a partial border to highlight when a dragged link is snapped to a node */
  snap_highlights_node = true;
  /**
   * If `true`, items always snap to the grid - modifier keys are ignored.
   * When {@link snapToGrid} is falsy, a value of `1` is used.
   * Default: `false`
   */
  alwaysSnapToGrid;
  /**
   * When set to a positive number, when nodes are moved their positions will
   * be rounded to the nearest multiple of this value.  Half up.
   * Default: `undefined`
   * @todo Not implemented - see {@link LiteGraph.CANVAS_GRID_SIZE}
   */
  snapToGrid;
  /** [false on mobile] better true if not touch device, TODO add an helper/listener to close if false */
  search_hide_on_mouse_leave = true;
  /**
   * [true!] enable filtering slots type in the search widget
   * !requires auto_load_slot_types or manual set registered_slot_[in/out]_types and slot_types_[in/out]
   */
  search_filter_enabled = false;
  /** [true!] opens the results list when opening the search widget */
  search_show_all_on_open = true;
  /**
   * [if want false, use true, run, get vars values to be statically set, than disable]
   * nodes types and nodeclass association with node types need to be calculated,
   * if dont want this, calculate once and set registered_slot_[in/out]_types and slot_types_[in/out]
   */
  auto_load_slot_types = false;
  // set these values if not using auto_load_slot_types
  /** slot types for nodeclass */
  registered_slot_in_types = {};
  /** slot types for nodeclass */
  registered_slot_out_types = {};
  /** slot types IN */
  slot_types_in = [];
  /** slot types OUT */
  slot_types_out = [];
  /**
   * specify for each IN slot type a(/many) default node(s), use single string, array, or object
   * (with node, title, parameters, ..) like for search
   */
  slot_types_default_in = {};
  /**
   * specify for each OUT slot type a(/many) default node(s), use single string, array, or object
   * (with node, title, parameters, ..) like for search
   */
  slot_types_default_out = {};
  /** [true!] very handy, ALT click to clone and drag the new node */
  alt_drag_do_clone_nodes = false;
  /**
   * [true!] will create and connect event slots when using action/events connections,
   * !WILL CHANGE node mode when using onTrigger (enable mode colors), onExecuted does not need this
   */
  do_add_triggers_slots = false;
  /** [false!] being events, it is strongly reccomended to use them sequentially, one by one */
  allow_multi_output_for_events = true;
  /** [true!] allows to create and connect a ndoe clicking with the third button (wheel) */
  middle_click_slot_add_default_node = false;
  /** [true!] dragging a link to empty space will open a menu, add from list, search or defaults */
  release_link_on_empty_shows_menu = false;
  /** "mouse"|"pointer" use mouse for retrocompatibility issues? (none found @ now) */
  pointerevents_method = "pointer";
  /**
   * [true!] allows ctrl + shift + v to paste nodes with the outputs of the unselected nodes connected
   * with the inputs of the newly pasted nodes
   */
  ctrl_shift_v_paste_connect_unselected_outputs = true;
  // if true, all newly created nodes/links will use string UUIDs for their id fields instead of integers.
  // use this if you must have node IDs that are unique across all graphs and subgraphs.
  use_uuids = false;
  // Whether to highlight the bounding box of selected groups
  highlight_selected_group = true;
  /** If `true`, the old "eye-melting-red" error indicator will be used for nodes */
  use_legacy_node_error_indicator = false;
  /** Whether to scale context with the graph when zooming in.  Zooming out never makes context menus smaller. */
  context_menu_scaling = false;
  // TODO: Remove legacy accessors
  LGraph = LGraph$1;
  LLink = LLink;
  LGraphNode = LGraphNode;
  LGraphGroup = LGraphGroup;
  DragAndScale = DragAndScale;
  LGraphCanvas = LGraphCanvas;
  ContextMenu = ContextMenu;
  CurveEditor = CurveEditor;
  Reroute = Reroute;
  /**
   * Register a node class so it can be listed when the user wants to create a new one
   * @param type name of the node and path
   * @param base_class class containing the structure of a node
   */
  registerNodeType(type, base_class) {
    if (!base_class.prototype)
      throw "Cannot register a simple object, it must be a class with a prototype";
    base_class.type = type;
    if (this.debug) console.log("Node registered:", type);
    const classname = base_class.name;
    const pos = type.lastIndexOf("/");
    base_class.category = type.substring(0, pos);
    base_class.title ||= classname;
    for (const i2 in LGraphNode.prototype) {
      base_class.prototype[i2] ||= LGraphNode.prototype[i2];
    }
    const prev2 = this.registered_node_types[type];
    if (prev2) {
      console.log("replacing node type:", type);
    }
    this.registered_node_types[type] = base_class;
    if (base_class.constructor.name) this.Nodes[classname] = base_class;
    this.onNodeTypeRegistered?.(type, base_class);
    if (prev2) this.onNodeTypeReplaced?.(type, base_class, prev2);
    if (base_class.prototype.onPropertyChange)
      console.warn(`LiteGraph node class ${type} has onPropertyChange method, it must be called onPropertyChanged with d at the end`);
    if (this.auto_load_slot_types) new base_class(base_class.title || "tmpnode");
  }
  /**
   * removes a node type from the system
   * @param type name of the node or the node constructor itself
   */
  unregisterNodeType(type) {
    const base_class = typeof type === "string" ? this.registered_node_types[type] : type;
    if (!base_class) throw `node type not found: ${String(type)}`;
    delete this.registered_node_types[String(base_class.type)];
    const name2 = base_class.constructor.name;
    if (name2) delete this.Nodes[name2];
  }
  /**
   * Save a slot type and his node
   * @param type name of the node or the node constructor itself
   * @param slot_type name of the slot type (variable type), eg. string, number, array, boolean, ..
   */
  registerNodeAndSlotType(type, slot_type, out) {
    out ||= false;
    const base_class = typeof type === "string" && this.registered_node_types[type] !== "anonymous" ? this.registered_node_types[type] : type;
    const class_type = base_class.constructor.type;
    let allTypes = [];
    if (typeof slot_type === "string") {
      allTypes = slot_type.split(",");
    } else if (slot_type == this.EVENT || slot_type == this.ACTION) {
      allTypes = ["_event_"];
    } else {
      allTypes = ["*"];
    }
    for (let slotType of allTypes) {
      if (slotType === "") slotType = "*";
      const registerTo = out ? "registered_slot_out_types" : "registered_slot_in_types";
      if (this[registerTo][slotType] === void 0)
        this[registerTo][slotType] = { nodes: [] };
      if (!this[registerTo][slotType].nodes.includes(class_type))
        this[registerTo][slotType].nodes.push(class_type);
      const types = out ? this.slot_types_out : this.slot_types_in;
      if (!types.includes(slotType.toLowerCase())) {
        types.push(slotType.toLowerCase());
        types.sort();
      }
    }
  }
  /**
   * Removes all previously registered node's types
   */
  clearRegisteredTypes() {
    this.registered_node_types = {};
    this.node_types_by_file_extension = {};
    this.Nodes = {};
    this.searchbox_extras = {};
  }
  /**
   * Create a node of a given type with a name. The node is not attached to any graph yet.
   * @param type full name of the node class. p.e. "math/sin"
   * @param title a name to distinguish from other nodes
   * @param options to set options
   */
  createNode(type, title, options22) {
    const base_class = this.registered_node_types[type];
    if (!base_class) {
      if (this.debug) console.log(`GraphNode type "${type}" not registered.`);
      return null;
    }
    title = title || base_class.title || type;
    let node22 = null;
    if (this.catch_exceptions) {
      try {
        node22 = new base_class(title);
      } catch (error2) {
        console.error(error2);
        return null;
      }
    } else {
      node22 = new base_class(title);
    }
    node22.type = type;
    if (!node22.title && title) node22.title = title;
    node22.properties ||= {};
    node22.properties_info ||= [];
    node22.flags ||= {};
    node22.size ||= node22.computeSize();
    node22.pos ||= [this.DEFAULT_POSITION[0], this.DEFAULT_POSITION[1]];
    node22.mode ||= LGraphEventMode.ALWAYS;
    if (options22) {
      for (const i2 in options22) {
        node22[i2] = options22[i2];
      }
    }
    node22.onNodeCreated?.();
    return node22;
  }
  /**
   * Returns a registered node type with a given name
   * @param type full name of the node class. p.e. "math/sin"
   * @returns the node class
   */
  getNodeType(type) {
    return this.registered_node_types[type];
  }
  /**
   * Returns a list of node types matching one category
   * @param category category name
   * @returns array with all the node classes
   */
  getNodeTypesInCategory(category, filter4) {
    const r2 = [];
    for (const i2 in this.registered_node_types) {
      const type = this.registered_node_types[i2];
      if (type.filter != filter4) continue;
      if (category == "") {
        if (type.category == null) r2.push(type);
      } else if (type.category == category) {
        r2.push(type);
      }
    }
    return r2;
  }
  /**
   * Returns a list with all the node type categories
   * @param filter only nodes with ctor.filter equal can be shown
   * @returns array with all the names of the categories
   */
  getNodeTypesCategories(filter4) {
    const categories = { "": 1 };
    for (const i2 in this.registered_node_types) {
      const type = this.registered_node_types[i2];
      if (type.category && !type.skip_list) {
        if (type.filter != filter4) continue;
        categories[type.category] = 1;
      }
    }
    const result = [];
    for (const i2 in categories) {
      result.push(i2);
    }
    return result;
  }
  // debug purposes: reloads all the js scripts that matches a wildcard
  reloadNodes(folder_wildcard) {
    const tmp = document.getElementsByTagName("script");
    const script_files = [];
    for (const element of tmp) {
      script_files.push(element);
    }
    const docHeadObj = document.getElementsByTagName("head")[0];
    folder_wildcard = document.location.href + folder_wildcard;
    for (const script_file of script_files) {
      const src = script_file.src;
      if (!src || src.substr(0, folder_wildcard.length) != folder_wildcard)
        continue;
      try {
        if (this.debug) console.log("Reloading:", src);
        const dynamicScript = document.createElement("script");
        dynamicScript.type = "text/javascript";
        dynamicScript.src = src;
        docHeadObj.append(dynamicScript);
        script_file.remove();
      } catch (error2) {
        if (this.throw_errors) throw error2;
        if (this.debug) console.log("Error while reloading", src);
      }
    }
    if (this.debug) console.log("Nodes reloaded");
  }
  // separated just to improve if it doesn't work
  /** @deprecated Prefer {@link structuredClone} */
  cloneObject(obj, target2) {
    if (obj == null) return null;
    const r2 = JSON.parse(JSON.stringify(obj));
    if (!target2) return r2;
    for (const i2 in r2) {
      target2[i2] = r2[i2];
    }
    return target2;
  }
  /** @see {@link createUuidv4} @inheritdoc */
  uuidv4 = createUuidv4;
  /**
   * Returns if the types of two slots are compatible (taking into account wildcards, etc)
   * @param type_a output
   * @param type_b input
   * @returns true if they can be connected
   */
  isValidConnection(type_a, type_b) {
    if (type_a == "" || type_a === "*") type_a = 0;
    if (type_b == "" || type_b === "*") type_b = 0;
    if (!type_a || !type_b || type_a == type_b || type_a == this.EVENT && type_b == this.ACTION) {
      return true;
    }
    type_a = String(type_a);
    type_b = String(type_b);
    type_a = type_a.toLowerCase();
    type_b = type_b.toLowerCase();
    if (!type_a.includes(",") && !type_b.includes(","))
      return type_a == type_b;
    const supported_types_a = type_a.split(",");
    const supported_types_b = type_b.split(",");
    for (const a2 of supported_types_a) {
      for (const b2 of supported_types_b) {
        if (this.isValidConnection(a2, b2))
          return true;
      }
    }
    return false;
  }
  // used to create nodes from wrapping functions
  getParameterNames(func) {
    return String(func).replaceAll(/\/\/.*$/gm, "").replaceAll(/\s+/g, "").replaceAll(/\/\*[^*/]*\*\//g, "").split("){", 1)[0].replace(/^[^(]*\(/, "").replaceAll(/=[^,]+/g, "").split(",").filter(Boolean);
  }
  /* helper for interaction: pointer, touch, mouse Listeners
    used by LGraphCanvas DragAndScale ContextMenu */
  pointerListenerAdd(oDOM, sEvIn, fCall, capture = false) {
    if (!oDOM || !oDOM.addEventListener || !sEvIn || typeof fCall !== "function") return;
    let sMethod = this.pointerevents_method;
    let sEvent = sEvIn;
    if (sMethod == "pointer" && !window.PointerEvent) {
      console.warn("sMethod=='pointer' && !window.PointerEvent");
      console.log(`Converting pointer[${sEvent}] : down move up cancel enter TO touchstart touchmove touchend, etc ..`);
      switch (sEvent) {
        case "down": {
          sMethod = "touch";
          sEvent = "start";
          break;
        }
        case "move": {
          sMethod = "touch";
          break;
        }
        case "up": {
          sMethod = "touch";
          sEvent = "end";
          break;
        }
        case "cancel": {
          sMethod = "touch";
          break;
        }
        case "enter": {
          console.log("debug: Should I send a move event?");
          break;
        }
        default: {
          console.warn(`PointerEvent not available in this browser ? The event ${sEvent} would not be called`);
        }
      }
    }
    switch (sEvent) {
      case "down":
      case "up":
      case "move":
      case "over":
      case "out":
      case "enter": {
        oDOM.addEventListener(sMethod + sEvent, fCall, capture);
      }
      case "leave":
      case "cancel":
      case "gotpointercapture":
      case "lostpointercapture": {
        if (sMethod != "mouse") {
          return oDOM.addEventListener(sMethod + sEvent, fCall, capture);
        }
      }
      default:
        return oDOM.addEventListener(sEvent, fCall, capture);
    }
  }
  pointerListenerRemove(oDOM, sEvent, fCall, capture = false) {
    if (!oDOM || !oDOM.removeEventListener || !sEvent || typeof fCall !== "function") return;
    switch (sEvent) {
      case "down":
      case "up":
      case "move":
      case "over":
      case "out":
      case "enter": {
        if (this.pointerevents_method == "pointer" || this.pointerevents_method == "mouse") {
          oDOM.removeEventListener(this.pointerevents_method + sEvent, fCall, capture);
        }
      }
      case "leave":
      case "cancel":
      case "gotpointercapture":
      case "lostpointercapture": {
        if (this.pointerevents_method == "pointer") {
          return oDOM.removeEventListener(this.pointerevents_method + sEvent, fCall, capture);
        }
      }
      default:
        return oDOM.removeEventListener(sEvent, fCall, capture);
    }
  }
  getTime() {
    return performance.now();
  }
  distance = distance;
  colorToString(c2) {
    return `rgba(${Math.round(c2[0] * 255).toFixed()},${Math.round(c2[1] * 255).toFixed()},${Math.round(c2[2] * 255).toFixed()},${c2.length == 4 ? c2[3].toFixed(2) : "1.0"})`;
  }
  isInsideRectangle = isInsideRectangle;
  // [minx,miny,maxx,maxy]
  growBounding(bounding, x2, y2) {
    if (x2 < bounding[0]) {
      bounding[0] = x2;
    } else if (x2 > bounding[2]) {
      bounding[2] = x2;
    }
    if (y2 < bounding[1]) {
      bounding[1] = y2;
    } else if (y2 > bounding[3]) {
      bounding[3] = y2;
    }
  }
  overlapBounding = overlapBounding;
  // point inside bounding box
  isInsideBounding(p2, bb) {
    if (p2[0] < bb[0][0] || p2[1] < bb[0][1] || p2[0] > bb[1][0] || p2[1] > bb[1][1]) {
      return false;
    }
    return true;
  }
  // Convert a hex value to its decimal value - the inputted hex must be in the
  // format of a hex triplet - the kind we use for HTML colours. The function
  // will return an array with three values.
  hex2num(hex) {
    if (hex.charAt(0) == "#") {
      hex = hex.slice(1);
    }
    hex = hex.toUpperCase();
    const hex_alphabets = "0123456789ABCDEF";
    const value3 = new Array(3);
    let k2 = 0;
    let int1, int2;
    for (let i2 = 0; i2 < 6; i2 += 2) {
      int1 = hex_alphabets.indexOf(hex.charAt(i2));
      int2 = hex_alphabets.indexOf(hex.charAt(i2 + 1));
      value3[k2] = int1 * 16 + int2;
      k2++;
    }
    return value3;
  }
  // Give a array with three values as the argument and the function will return
  // the corresponding hex triplet.
  num2hex(triplet) {
    const hex_alphabets = "0123456789ABCDEF";
    let hex = "#";
    let int1, int2;
    for (let i2 = 0; i2 < 3; i2++) {
      int1 = triplet[i2] / 16;
      int2 = triplet[i2] % 16;
      hex += hex_alphabets.charAt(int1) + hex_alphabets.charAt(int2);
    }
    return hex;
  }
  closeAllContextMenus(ref_window) {
    ref_window = ref_window || window;
    const elements = ref_window.document.querySelectorAll(".litecontextmenu");
    if (!elements.length) return;
    const results = [];
    for (const element of elements) {
      results.push(element);
    }
    for (const result of results) {
      if ("close" in result && typeof result.close === "function") {
        result.close();
      } else if (result.parentNode) {
        result.remove();
      }
    }
  }
  extendClass(target2, origin2) {
    for (const i2 in origin2) {
      if (target2.hasOwnProperty(i2)) continue;
      target2[i2] = origin2[i2];
    }
    if (origin2.prototype) {
      for (const i2 in origin2.prototype) {
        if (!origin2.prototype.hasOwnProperty(i2)) continue;
        if (target2.prototype.hasOwnProperty(i2)) continue;
        if (origin2.prototype.__lookupGetter__(i2)) {
          target2.prototype.__defineGetter__(
            i2,
            origin2.prototype.__lookupGetter__(i2)
          );
        } else {
          target2.prototype[i2] = origin2.prototype[i2];
        }
        if (origin2.prototype.__lookupSetter__(i2)) {
          target2.prototype.__defineSetter__(
            i2,
            origin2.prototype.__lookupSetter__(i2)
          );
        }
      }
    }
  }
}
function loadPolyfills() {
  if (typeof window != "undefined" && window.CanvasRenderingContext2D && !window.CanvasRenderingContext2D.prototype.roundRect) {
    window.CanvasRenderingContext2D.prototype.roundRect = function(x2, y2, w2, h2, radius, radius_low) {
      let top_left_radius = 0;
      let top_right_radius = 0;
      let bottom_left_radius = 0;
      let bottom_right_radius = 0;
      if (radius === 0) {
        this.rect(x2, y2, w2, h2);
        return;
      }
      if (radius_low === void 0) radius_low = radius;
      if (Array.isArray(radius)) {
        if (radius.length == 1) {
          top_left_radius = top_right_radius = bottom_left_radius = bottom_right_radius = radius[0];
        } else if (radius.length == 2) {
          top_left_radius = bottom_right_radius = radius[0];
          top_right_radius = bottom_left_radius = radius[1];
        } else if (radius.length == 4) {
          top_left_radius = radius[0];
          top_right_radius = radius[1];
          bottom_left_radius = radius[2];
          bottom_right_radius = radius[3];
        } else {
          return;
        }
      } else {
        top_left_radius = radius || 0;
        top_right_radius = radius || 0;
        const low = !Array.isArray(radius_low) && radius_low ? radius_low : 0;
        bottom_left_radius = low;
        bottom_right_radius = low;
      }
      this.moveTo(x2 + top_left_radius, y2);
      this.lineTo(x2 + w2 - top_right_radius, y2);
      this.quadraticCurveTo(x2 + w2, y2, x2 + w2, y2 + top_right_radius);
      this.lineTo(x2 + w2, y2 + h2 - bottom_right_radius);
      this.quadraticCurveTo(
        x2 + w2,
        y2 + h2,
        x2 + w2 - bottom_right_radius,
        y2 + h2
      );
      this.lineTo(x2 + bottom_right_radius, y2 + h2);
      this.quadraticCurveTo(x2, y2 + h2, x2, y2 + h2 - bottom_left_radius);
      this.lineTo(x2, y2 + bottom_left_radius);
      this.quadraticCurveTo(x2, y2, x2 + top_left_radius, y2);
    };
  }
  if (typeof window != "undefined" && !window["requestAnimationFrame"]) {
    window.requestAnimationFrame = // @ts-expect-error Legacy code
    window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame || function(callback) {
      window.setTimeout(callback, 1e3 / 60);
    };
  }
}
__name(loadPolyfills, "loadPolyfills");
const LiteGraph = new LiteGraphGlobal();
function clamp(v2, a2, b2) {
  return a2 > v2 ? a2 : b2 < v2 ? b2 : v2;
}
__name(clamp, "clamp");
loadPolyfills();
/*!
  * shared v9.14.3
  * (c) 2025 kazuya kawaguchi
  * Released under the MIT License.
  */
const inBrowser = typeof window !== "undefined";
let mark;
let measure;
if (false) {
  const perf2 = inBrowser && window.performance;
  if (perf2 && perf2.mark && perf2.measure && perf2.clearMarks && // @ts-ignore browser compat
  perf2.clearMeasures) {
    mark = /* @__PURE__ */ __name((tag) => {
      perf2.mark(tag);
    }, "mark");
    measure = /* @__PURE__ */ __name((name2, startTag, endTag) => {
      perf2.measure(name2, startTag, endTag);
      perf2.clearMarks(startTag);
      perf2.clearMarks(endTag);
    }, "measure");
  }
}
const RE_ARGS$1 = /\{([0-9a-zA-Z]+)\}/g;
function format$5(message3, ...args) {
  if (args.length === 1 && isObject$c(args[0])) {
    args = args[0];
  }
  if (!args || !args.hasOwnProperty) {
    args = {};
  }
  return message3.replace(RE_ARGS$1, (match2, identifier) => {
    return args.hasOwnProperty(identifier) ? args[identifier] : "";
  });
}
__name(format$5, "format$5");
const makeSymbol = /* @__PURE__ */ __name((name2, shareable = false) => !shareable ? Symbol(name2) : Symbol.for(name2), "makeSymbol");
const generateFormatCacheKey = /* @__PURE__ */ __name((locale2, key, source) => friendlyJSONstringify({ l: locale2, k: key, s: source }), "generateFormatCacheKey");
const friendlyJSONstringify = /* @__PURE__ */ __name((json) => JSON.stringify(json).replace(/\u2028/g, "\\u2028").replace(/\u2029/g, "\\u2029").replace(/\u0027/g, "\\u0027"), "friendlyJSONstringify");
const isNumber$5 = /* @__PURE__ */ __name((val) => typeof val === "number" && isFinite(val), "isNumber$5");
const isDate$2 = /* @__PURE__ */ __name((val) => toTypeString(val) === "[object Date]", "isDate$2");
const isRegExp$2 = /* @__PURE__ */ __name((val) => toTypeString(val) === "[object RegExp]", "isRegExp$2");
const isEmptyObject$1 = /* @__PURE__ */ __name((val) => isPlainObject$1(val) && Object.keys(val).length === 0, "isEmptyObject$1");
const assign$4 = Object.assign;
const _create = Object.create;
const create$1 = /* @__PURE__ */ __name((obj = null) => _create(obj), "create$1");
let _globalThis;
const getGlobalThis = /* @__PURE__ */ __name(() => {
  return _globalThis || (_globalThis = typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : create$1());
}, "getGlobalThis");
function escapeHtml$1(rawText) {
  return rawText.replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&apos;");
}
__name(escapeHtml$1, "escapeHtml$1");
const hasOwnProperty$a = Object.prototype.hasOwnProperty;
function hasOwn$1(obj, key) {
  return hasOwnProperty$a.call(obj, key);
}
__name(hasOwn$1, "hasOwn$1");
const isArray$8 = Array.isArray;
const isFunction$9 = /* @__PURE__ */ __name((val) => typeof val === "function", "isFunction$9");
const isString$7 = /* @__PURE__ */ __name((val) => typeof val === "string", "isString$7");
const isBoolean$1 = /* @__PURE__ */ __name((val) => typeof val === "boolean", "isBoolean$1");
const isSymbol = /* @__PURE__ */ __name((val) => typeof val === "symbol", "isSymbol");
const isObject$c = /* @__PURE__ */ __name((val) => val !== null && typeof val === "object", "isObject$c");
const isPromise = /* @__PURE__ */ __name((val) => {
  return isObject$c(val) && isFunction$9(val.then) && isFunction$9(val.catch);
}, "isPromise");
const objectToString$2 = Object.prototype.toString;
const toTypeString = /* @__PURE__ */ __name((value3) => objectToString$2.call(value3), "toTypeString");
const isPlainObject$1 = /* @__PURE__ */ __name((val) => {
  if (!isObject$c(val))
    return false;
  const proto = Object.getPrototypeOf(val);
  return proto === null || proto.constructor === Object;
}, "isPlainObject$1");
const toDisplayString = /* @__PURE__ */ __name((val) => {
  return val == null ? "" : isArray$8(val) || isPlainObject$1(val) && val.toString === objectToString$2 ? JSON.stringify(val, null, 2) : String(val);
}, "toDisplayString");
function join$2(items2, separator = "") {
  return items2.reduce((str, item3, index2) => index2 === 0 ? str + item3 : str + separator + item3, "");
}
__name(join$2, "join$2");
const RANGE = 2;
function generateCodeFrame(source, start2 = 0, end = source.length) {
  const lines = source.split(/\r?\n/);
  let count = 0;
  const res = [];
  for (let i2 = 0; i2 < lines.length; i2++) {
    count += lines[i2].length + 1;
    if (count >= start2) {
      for (let j2 = i2 - RANGE; j2 <= i2 + RANGE || end > count; j2++) {
        if (j2 < 0 || j2 >= lines.length)
          continue;
        const line = j2 + 1;
        res.push(`${line}${" ".repeat(3 - String(line).length)}|  ${lines[j2]}`);
        const lineLength = lines[j2].length;
        if (j2 === i2) {
          const pad = start2 - (count - lineLength) + 1;
          const length = Math.max(1, end > count ? lineLength - pad : end - start2);
          res.push(`   |  ` + " ".repeat(pad) + "^".repeat(length));
        } else if (j2 > i2) {
          if (end > count) {
            const length = Math.max(Math.min(end - count, lineLength), 1);
            res.push(`   |  ` + "^".repeat(length));
          }
          count += lineLength + 1;
        }
      }
      break;
    }
  }
  return res.join("\n");
}
__name(generateCodeFrame, "generateCodeFrame");
function incrementer(code2) {
  let current = code2;
  return () => ++current;
}
__name(incrementer, "incrementer");
function warn$1(msg, err) {
  if (typeof console !== "undefined") {
    console.warn(`[intlify] ` + msg);
    if (err) {
      console.warn(err.stack);
    }
  }
}
__name(warn$1, "warn$1");
const hasWarned = {};
function warnOnce(msg) {
  if (!hasWarned[msg]) {
    hasWarned[msg] = true;
    warn$1(msg);
  }
}
__name(warnOnce, "warnOnce");
function createEmitter() {
  const events2 = /* @__PURE__ */ new Map();
  const emitter = {
    events: events2,
    on(event, handler14) {
      const handlers2 = events2.get(event);
      const added = handlers2 && handlers2.push(handler14);
      if (!added) {
        events2.set(event, [handler14]);
      }
    },
    off(event, handler14) {
      const handlers2 = events2.get(event);
      if (handlers2) {
        handlers2.splice(handlers2.indexOf(handler14) >>> 0, 1);
      }
    },
    emit(event, payload) {
      (events2.get(event) || []).slice().map((handler14) => handler14(payload));
      (events2.get("*") || []).slice().map((handler14) => handler14(event, payload));
    }
  };
  return emitter;
}
__name(createEmitter, "createEmitter");
const isNotObjectOrIsArray = /* @__PURE__ */ __name((val) => !isObject$c(val) || isArray$8(val), "isNotObjectOrIsArray");
function deepCopy(src, des) {
  if (isNotObjectOrIsArray(src) || isNotObjectOrIsArray(des)) {
    throw new Error("Invalid value");
  }
  const stack2 = [{ src, des }];
  while (stack2.length) {
    const { src: src2, des: des2 } = stack2.pop();
    Object.keys(src2).forEach((key) => {
      if (key === "__proto__") {
        return;
      }
      if (isObject$c(src2[key]) && !isObject$c(des2[key])) {
        des2[key] = Array.isArray(src2[key]) ? [] : create$1();
      }
      if (isNotObjectOrIsArray(des2[key]) || isNotObjectOrIsArray(src2[key])) {
        des2[key] = src2[key];
      } else {
        stack2.push({ src: src2[key], des: des2[key] });
      }
    });
  }
}
__name(deepCopy, "deepCopy");
/*!
  * message-compiler v9.14.3
  * (c) 2025 kazuya kawaguchi
  * Released under the MIT License.
  */
const LOCATION_STUB = {
  start: { line: 1, column: 1, offset: 0 },
  end: { line: 1, column: 1, offset: 0 }
};
function createPosition(line, column, offset) {
  return { line, column, offset };
}
__name(createPosition, "createPosition");
function createLocation(start2, end, source) {
  const loc = { start: start2, end };
  if (source != null) {
    loc.source = source;
  }
  return loc;
}
__name(createLocation, "createLocation");
const RE_ARGS = /\{([0-9a-zA-Z]+)\}/g;
function format$4(message3, ...args) {
  if (args.length === 1 && isObject$b(args[0])) {
    args = args[0];
  }
  if (!args || !args.hasOwnProperty) {
    args = {};
  }
  return message3.replace(RE_ARGS, (match2, identifier) => {
    return args.hasOwnProperty(identifier) ? args[identifier] : "";
  });
}
__name(format$4, "format$4");
const assign$3 = Object.assign;
const isString$6 = /* @__PURE__ */ __name((val) => typeof val === "string", "isString$6");
const isObject$b = /* @__PURE__ */ __name((val) => val !== null && typeof val === "object", "isObject$b");
function join$1(items2, separator = "") {
  return items2.reduce((str, item3, index2) => index2 === 0 ? str + item3 : str + separator + item3, "");
}
__name(join$1, "join$1");
const CompileWarnCodes = {
  USE_MODULO_SYNTAX: 1,
  __EXTEND_POINT__: 2
};
const warnMessages$2 = {
  [CompileWarnCodes.USE_MODULO_SYNTAX]: `Use modulo before '{{0}}'.`
};
function createCompileWarn(code2, loc, ...args) {
  const msg = format$4(warnMessages$2[code2] || "", ...args || []);
  const message3 = { message: String(msg), code: code2 };
  if (loc) {
    message3.location = loc;
  }
  return message3;
}
__name(createCompileWarn, "createCompileWarn");
const CompileErrorCodes = {
  // tokenizer error codes
  EXPECTED_TOKEN: 1,
  INVALID_TOKEN_IN_PLACEHOLDER: 2,
  UNTERMINATED_SINGLE_QUOTE_IN_PLACEHOLDER: 3,
  UNKNOWN_ESCAPE_SEQUENCE: 4,
  INVALID_UNICODE_ESCAPE_SEQUENCE: 5,
  UNBALANCED_CLOSING_BRACE: 6,
  UNTERMINATED_CLOSING_BRACE: 7,
  EMPTY_PLACEHOLDER: 8,
  NOT_ALLOW_NEST_PLACEHOLDER: 9,
  INVALID_LINKED_FORMAT: 10,
  // parser error codes
  MUST_HAVE_MESSAGES_IN_PLURAL: 11,
  UNEXPECTED_EMPTY_LINKED_MODIFIER: 12,
  UNEXPECTED_EMPTY_LINKED_KEY: 13,
  UNEXPECTED_LEXICAL_ANALYSIS: 14,
  // generator error codes
  UNHANDLED_CODEGEN_NODE_TYPE: 15,
  // minifier error codes
  UNHANDLED_MINIFIER_NODE_TYPE: 16,
  // Special value for higher-order compilers to pick up the last code
  // to avoid collision of error codes. This should always be kept as the last
  // item.
  __EXTEND_POINT__: 17
};
const errorMessages$2 = {
  // tokenizer error messages
  [CompileErrorCodes.EXPECTED_TOKEN]: `Expected token: '{0}'`,
  [CompileErrorCodes.INVALID_TOKEN_IN_PLACEHOLDER]: `Invalid token in placeholder: '{0}'`,
  [CompileErrorCodes.UNTERMINATED_SINGLE_QUOTE_IN_PLACEHOLDER]: `Unterminated single quote in placeholder`,
  [CompileErrorCodes.UNKNOWN_ESCAPE_SEQUENCE]: `Unknown escape sequence: \\{0}`,
  [CompileErrorCodes.INVALID_UNICODE_ESCAPE_SEQUENCE]: `Invalid unicode escape sequence: {0}`,
  [CompileErrorCodes.UNBALANCED_CLOSING_BRACE]: `Unbalanced closing brace`,
  [CompileErrorCodes.UNTERMINATED_CLOSING_BRACE]: `Unterminated closing brace`,
  [CompileErrorCodes.EMPTY_PLACEHOLDER]: `Empty placeholder`,
  [CompileErrorCodes.NOT_ALLOW_NEST_PLACEHOLDER]: `Not allowed nest placeholder`,
  [CompileErrorCodes.INVALID_LINKED_FORMAT]: `Invalid linked format`,
  // parser error messages
  [CompileErrorCodes.MUST_HAVE_MESSAGES_IN_PLURAL]: `Plural must have messages`,
  [CompileErrorCodes.UNEXPECTED_EMPTY_LINKED_MODIFIER]: `Unexpected empty linked modifier`,
  [CompileErrorCodes.UNEXPECTED_EMPTY_LINKED_KEY]: `Unexpected empty linked key`,
  [CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS]: `Unexpected lexical analysis in token: '{0}'`,
  // generator error messages
  [CompileErrorCodes.UNHANDLED_CODEGEN_NODE_TYPE]: `unhandled codegen node type: '{0}'`,
  // minimizer error messages
  [CompileErrorCodes.UNHANDLED_MINIFIER_NODE_TYPE]: `unhandled mimifier node type: '{0}'`
};
function createCompileError(code2, loc, options5 = {}) {
  const { domain: domain2, messages: messages2, args } = options5;
  const msg = format$4((messages2 || errorMessages$2)[code2] || "", ...args || []);
  const error2 = new SyntaxError(String(msg));
  error2.code = code2;
  if (loc) {
    error2.location = loc;
  }
  error2.domain = domain2;
  return error2;
}
__name(createCompileError, "createCompileError");
function defaultOnError(error2) {
  throw error2;
}
__name(defaultOnError, "defaultOnError");
const RE_HTML_TAG = /<\/?[\w\s="/.':;#-\/]+>/;
const detectHtmlTag = /* @__PURE__ */ __name((source) => RE_HTML_TAG.test(source), "detectHtmlTag");
const CHAR_SP = " ";
const CHAR_CR = "\r";
const CHAR_LF = "\n";
const CHAR_LS = String.fromCharCode(8232);
const CHAR_PS = String.fromCharCode(8233);
function createScanner(str) {
  const _buf = str;
  let _index = 0;
  let _line = 1;
  let _column = 1;
  let _peekOffset = 0;
  const isCRLF = /* @__PURE__ */ __name((index3) => _buf[index3] === CHAR_CR && _buf[index3 + 1] === CHAR_LF, "isCRLF");
  const isLF = /* @__PURE__ */ __name((index3) => _buf[index3] === CHAR_LF, "isLF");
  const isPS = /* @__PURE__ */ __name((index3) => _buf[index3] === CHAR_PS, "isPS");
  const isLS = /* @__PURE__ */ __name((index3) => _buf[index3] === CHAR_LS, "isLS");
  const isLineEnd = /* @__PURE__ */ __name((index3) => isCRLF(index3) || isLF(index3) || isPS(index3) || isLS(index3), "isLineEnd");
  const index2 = /* @__PURE__ */ __name(() => _index, "index");
  const line = /* @__PURE__ */ __name(() => _line, "line");
  const column = /* @__PURE__ */ __name(() => _column, "column");
  const peekOffset = /* @__PURE__ */ __name(() => _peekOffset, "peekOffset");
  const charAt = /* @__PURE__ */ __name((offset) => isCRLF(offset) || isPS(offset) || isLS(offset) ? CHAR_LF : _buf[offset], "charAt");
  const currentChar = /* @__PURE__ */ __name(() => charAt(_index), "currentChar");
  const currentPeek = /* @__PURE__ */ __name(() => charAt(_index + _peekOffset), "currentPeek");
  function next2() {
    _peekOffset = 0;
    if (isLineEnd(_index)) {
      _line++;
      _column = 0;
    }
    if (isCRLF(_index)) {
      _index++;
    }
    _index++;
    _column++;
    return _buf[_index];
  }
  __name(next2, "next");
  function peek() {
    if (isCRLF(_index + _peekOffset)) {
      _peekOffset++;
    }
    _peekOffset++;
    return _buf[_index + _peekOffset];
  }
  __name(peek, "peek");
  function reset2() {
    _index = 0;
    _line = 1;
    _column = 1;
    _peekOffset = 0;
  }
  __name(reset2, "reset");
  function resetPeek(offset = 0) {
    _peekOffset = offset;
  }
  __name(resetPeek, "resetPeek");
  function skipToPeek() {
    const target2 = _index + _peekOffset;
    while (target2 !== _index) {
      next2();
    }
    _peekOffset = 0;
  }
  __name(skipToPeek, "skipToPeek");
  return {
    index: index2,
    line,
    column,
    peekOffset,
    charAt,
    currentChar,
    currentPeek,
    next: next2,
    peek,
    reset: reset2,
    resetPeek,
    skipToPeek
  };
}
__name(createScanner, "createScanner");
const EOF = void 0;
const DOT$1 = ".";
const LITERAL_DELIMITER = "'";
const ERROR_DOMAIN$3 = "tokenizer";
function createTokenizer(source, options5 = {}) {
  const location2 = options5.location !== false;
  const _scnr = createScanner(source);
  const currentOffset = /* @__PURE__ */ __name(() => _scnr.index(), "currentOffset");
  const currentPosition = /* @__PURE__ */ __name(() => createPosition(_scnr.line(), _scnr.column(), _scnr.index()), "currentPosition");
  const _initLoc = currentPosition();
  const _initOffset = currentOffset();
  const _context = {
    currentType: 14,
    offset: _initOffset,
    startLoc: _initLoc,
    endLoc: _initLoc,
    lastType: 14,
    lastOffset: _initOffset,
    lastStartLoc: _initLoc,
    lastEndLoc: _initLoc,
    braceNest: 0,
    inLinked: false,
    text: ""
  };
  const context = /* @__PURE__ */ __name(() => _context, "context");
  const { onError } = options5;
  function emitError(code2, pos, offset, ...args) {
    const ctx = context();
    pos.column += offset;
    pos.offset += offset;
    if (onError) {
      const loc = location2 ? createLocation(ctx.startLoc, pos) : null;
      const err = createCompileError(code2, loc, {
        domain: ERROR_DOMAIN$3,
        args
      });
      onError(err);
    }
  }
  __name(emitError, "emitError");
  function getToken(context2, type, value3) {
    context2.endLoc = currentPosition();
    context2.currentType = type;
    const token = { type };
    if (location2) {
      token.loc = createLocation(context2.startLoc, context2.endLoc);
    }
    if (value3 != null) {
      token.value = value3;
    }
    return token;
  }
  __name(getToken, "getToken");
  const getEndToken = /* @__PURE__ */ __name((context2) => getToken(
    context2,
    14
    /* TokenTypes.EOF */
  ), "getEndToken");
  function eat(scnr, ch) {
    if (scnr.currentChar() === ch) {
      scnr.next();
      return ch;
    } else {
      emitError(CompileErrorCodes.EXPECTED_TOKEN, currentPosition(), 0, ch);
      return "";
    }
  }
  __name(eat, "eat");
  function peekSpaces(scnr) {
    let buf = "";
    while (scnr.currentPeek() === CHAR_SP || scnr.currentPeek() === CHAR_LF) {
      buf += scnr.currentPeek();
      scnr.peek();
    }
    return buf;
  }
  __name(peekSpaces, "peekSpaces");
  function skipSpaces2(scnr) {
    const buf = peekSpaces(scnr);
    scnr.skipToPeek();
    return buf;
  }
  __name(skipSpaces2, "skipSpaces");
  function isIdentifierStart(ch) {
    if (ch === EOF) {
      return false;
    }
    const cc = ch.charCodeAt(0);
    return cc >= 97 && cc <= 122 || // a-z
    cc >= 65 && cc <= 90 || // A-Z
    cc === 95;
  }
  __name(isIdentifierStart, "isIdentifierStart");
  function isNumberStart(ch) {
    if (ch === EOF) {
      return false;
    }
    const cc = ch.charCodeAt(0);
    return cc >= 48 && cc <= 57;
  }
  __name(isNumberStart, "isNumberStart");
  function isNamedIdentifierStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 2) {
      return false;
    }
    peekSpaces(scnr);
    const ret = isIdentifierStart(scnr.currentPeek());
    scnr.resetPeek();
    return ret;
  }
  __name(isNamedIdentifierStart, "isNamedIdentifierStart");
  function isListIdentifierStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 2) {
      return false;
    }
    peekSpaces(scnr);
    const ch = scnr.currentPeek() === "-" ? scnr.peek() : scnr.currentPeek();
    const ret = isNumberStart(ch);
    scnr.resetPeek();
    return ret;
  }
  __name(isListIdentifierStart, "isListIdentifierStart");
  function isLiteralStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 2) {
      return false;
    }
    peekSpaces(scnr);
    const ret = scnr.currentPeek() === LITERAL_DELIMITER;
    scnr.resetPeek();
    return ret;
  }
  __name(isLiteralStart, "isLiteralStart");
  function isLinkedDotStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 8) {
      return false;
    }
    peekSpaces(scnr);
    const ret = scnr.currentPeek() === ".";
    scnr.resetPeek();
    return ret;
  }
  __name(isLinkedDotStart, "isLinkedDotStart");
  function isLinkedModifierStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 9) {
      return false;
    }
    peekSpaces(scnr);
    const ret = isIdentifierStart(scnr.currentPeek());
    scnr.resetPeek();
    return ret;
  }
  __name(isLinkedModifierStart, "isLinkedModifierStart");
  function isLinkedDelimiterStart(scnr, context2) {
    const { currentType } = context2;
    if (!(currentType === 8 || currentType === 12)) {
      return false;
    }
    peekSpaces(scnr);
    const ret = scnr.currentPeek() === ":";
    scnr.resetPeek();
    return ret;
  }
  __name(isLinkedDelimiterStart, "isLinkedDelimiterStart");
  function isLinkedReferStart(scnr, context2) {
    const { currentType } = context2;
    if (currentType !== 10) {
      return false;
    }
    const fn = /* @__PURE__ */ __name(() => {
      const ch = scnr.currentPeek();
      if (ch === "{") {
        return isIdentifierStart(scnr.peek());
      } else if (ch === "@" || ch === "%" || ch === "|" || ch === ":" || ch === "." || ch === CHAR_SP || !ch) {
        return false;
      } else if (ch === CHAR_LF) {
        scnr.peek();
        return fn();
      } else {
        return isTextStart(scnr, false);
      }
    }, "fn");
    const ret = fn();
    scnr.resetPeek();
    return ret;
  }
  __name(isLinkedReferStart, "isLinkedReferStart");
  function isPluralStart(scnr) {
    peekSpaces(scnr);
    const ret = scnr.currentPeek() === "|";
    scnr.resetPeek();
    return ret;
  }
  __name(isPluralStart, "isPluralStart");
  function detectModuloStart(scnr) {
    const spaces = peekSpaces(scnr);
    const ret = scnr.currentPeek() === "%" && scnr.peek() === "{";
    scnr.resetPeek();
    return {
      isModulo: ret,
      hasSpace: spaces.length > 0
    };
  }
  __name(detectModuloStart, "detectModuloStart");
  function isTextStart(scnr, reset2 = true) {
    const fn = /* @__PURE__ */ __name((hasSpace = false, prev2 = "", detectModulo = false) => {
      const ch = scnr.currentPeek();
      if (ch === "{") {
        return prev2 === "%" ? false : hasSpace;
      } else if (ch === "@" || !ch) {
        return prev2 === "%" ? true : hasSpace;
      } else if (ch === "%") {
        scnr.peek();
        return fn(hasSpace, "%", true);
      } else if (ch === "|") {
        return prev2 === "%" || detectModulo ? true : !(prev2 === CHAR_SP || prev2 === CHAR_LF);
      } else if (ch === CHAR_SP) {
        scnr.peek();
        return fn(true, CHAR_SP, detectModulo);
      } else if (ch === CHAR_LF) {
        scnr.peek();
        return fn(true, CHAR_LF, detectModulo);
      } else {
        return true;
      }
    }, "fn");
    const ret = fn();
    reset2 && scnr.resetPeek();
    return ret;
  }
  __name(isTextStart, "isTextStart");
  function takeChar(scnr, fn) {
    const ch = scnr.currentChar();
    if (ch === EOF) {
      return EOF;
    }
    if (fn(ch)) {
      scnr.next();
      return ch;
    }
    return null;
  }
  __name(takeChar, "takeChar");
  function isIdentifier(ch) {
    const cc = ch.charCodeAt(0);
    return cc >= 97 && cc <= 122 || // a-z
    cc >= 65 && cc <= 90 || // A-Z
    cc >= 48 && cc <= 57 || // 0-9
    cc === 95 || // _
    cc === 36;
  }
  __name(isIdentifier, "isIdentifier");
  function takeIdentifierChar(scnr) {
    return takeChar(scnr, isIdentifier);
  }
  __name(takeIdentifierChar, "takeIdentifierChar");
  function isNamedIdentifier(ch) {
    const cc = ch.charCodeAt(0);
    return cc >= 97 && cc <= 122 || // a-z
    cc >= 65 && cc <= 90 || // A-Z
    cc >= 48 && cc <= 57 || // 0-9
    cc === 95 || // _
    cc === 36 || // $
    cc === 45;
  }
  __name(isNamedIdentifier, "isNamedIdentifier");
  function takeNamedIdentifierChar(scnr) {
    return takeChar(scnr, isNamedIdentifier);
  }
  __name(takeNamedIdentifierChar, "takeNamedIdentifierChar");
  function isDigit(ch) {
    const cc = ch.charCodeAt(0);
    return cc >= 48 && cc <= 57;
  }
  __name(isDigit, "isDigit");
  function takeDigit(scnr) {
    return takeChar(scnr, isDigit);
  }
  __name(takeDigit, "takeDigit");
  function isHexDigit(ch) {
    const cc = ch.charCodeAt(0);
    return cc >= 48 && cc <= 57 || // 0-9
    cc >= 65 && cc <= 70 || // A-F
    cc >= 97 && cc <= 102;
  }
  __name(isHexDigit, "isHexDigit");
  function takeHexDigit(scnr) {
    return takeChar(scnr, isHexDigit);
  }
  __name(takeHexDigit, "takeHexDigit");
  function getDigits(scnr) {
    let ch = "";
    let num = "";
    while (ch = takeDigit(scnr)) {
      num += ch;
    }
    return num;
  }
  __name(getDigits, "getDigits");
  function readModulo(scnr) {
    skipSpaces2(scnr);
    const ch = scnr.currentChar();
    if (ch !== "%") {
      emitError(CompileErrorCodes.EXPECTED_TOKEN, currentPosition(), 0, ch);
    }
    scnr.next();
    return "%";
  }
  __name(readModulo, "readModulo");
  function readText(scnr) {
    let buf = "";
    while (true) {
      const ch = scnr.currentChar();
      if (ch === "{" || ch === "}" || ch === "@" || ch === "|" || !ch) {
        break;
      } else if (ch === "%") {
        if (isTextStart(scnr)) {
          buf += ch;
          scnr.next();
        } else {
          break;
        }
      } else if (ch === CHAR_SP || ch === CHAR_LF) {
        if (isTextStart(scnr)) {
          buf += ch;
          scnr.next();
        } else if (isPluralStart(scnr)) {
          break;
        } else {
          buf += ch;
          scnr.next();
        }
      } else {
        buf += ch;
        scnr.next();
      }
    }
    return buf;
  }
  __name(readText, "readText");
  function readNamedIdentifier(scnr) {
    skipSpaces2(scnr);
    let ch = "";
    let name2 = "";
    while (ch = takeNamedIdentifierChar(scnr)) {
      name2 += ch;
    }
    if (scnr.currentChar() === EOF) {
      emitError(CompileErrorCodes.UNTERMINATED_CLOSING_BRACE, currentPosition(), 0);
    }
    return name2;
  }
  __name(readNamedIdentifier, "readNamedIdentifier");
  function readListIdentifier(scnr) {
    skipSpaces2(scnr);
    let value3 = "";
    if (scnr.currentChar() === "-") {
      scnr.next();
      value3 += `-${getDigits(scnr)}`;
    } else {
      value3 += getDigits(scnr);
    }
    if (scnr.currentChar() === EOF) {
      emitError(CompileErrorCodes.UNTERMINATED_CLOSING_BRACE, currentPosition(), 0);
    }
    return value3;
  }
  __name(readListIdentifier, "readListIdentifier");
  function isLiteral2(ch) {
    return ch !== LITERAL_DELIMITER && ch !== CHAR_LF;
  }
  __name(isLiteral2, "isLiteral");
  function readLiteral(scnr) {
    skipSpaces2(scnr);
    eat(scnr, `'`);
    let ch = "";
    let literal = "";
    while (ch = takeChar(scnr, isLiteral2)) {
      if (ch === "\\") {
        literal += readEscapeSequence(scnr);
      } else {
        literal += ch;
      }
    }
    const current = scnr.currentChar();
    if (current === CHAR_LF || current === EOF) {
      emitError(CompileErrorCodes.UNTERMINATED_SINGLE_QUOTE_IN_PLACEHOLDER, currentPosition(), 0);
      if (current === CHAR_LF) {
        scnr.next();
        eat(scnr, `'`);
      }
      return literal;
    }
    eat(scnr, `'`);
    return literal;
  }
  __name(readLiteral, "readLiteral");
  function readEscapeSequence(scnr) {
    const ch = scnr.currentChar();
    switch (ch) {
      case "\\":
      case `'`:
        scnr.next();
        return `\\${ch}`;
      case "u":
        return readUnicodeEscapeSequence(scnr, ch, 4);
      case "U":
        return readUnicodeEscapeSequence(scnr, ch, 6);
      default:
        emitError(CompileErrorCodes.UNKNOWN_ESCAPE_SEQUENCE, currentPosition(), 0, ch);
        return "";
    }
  }
  __name(readEscapeSequence, "readEscapeSequence");
  function readUnicodeEscapeSequence(scnr, unicode, digits) {
    eat(scnr, unicode);
    let sequence = "";
    for (let i2 = 0; i2 < digits; i2++) {
      const ch = takeHexDigit(scnr);
      if (!ch) {
        emitError(CompileErrorCodes.INVALID_UNICODE_ESCAPE_SEQUENCE, currentPosition(), 0, `\\${unicode}${sequence}${scnr.currentChar()}`);
        break;
      }
      sequence += ch;
    }
    return `\\${unicode}${sequence}`;
  }
  __name(readUnicodeEscapeSequence, "readUnicodeEscapeSequence");
  function isInvalidIdentifier(ch) {
    return ch !== "{" && ch !== "}" && ch !== CHAR_SP && ch !== CHAR_LF;
  }
  __name(isInvalidIdentifier, "isInvalidIdentifier");
  function readInvalidIdentifier(scnr) {
    skipSpaces2(scnr);
    let ch = "";
    let identifiers = "";
    while (ch = takeChar(scnr, isInvalidIdentifier)) {
      identifiers += ch;
    }
    return identifiers;
  }
  __name(readInvalidIdentifier, "readInvalidIdentifier");
  function readLinkedModifier(scnr) {
    let ch = "";
    let name2 = "";
    while (ch = takeIdentifierChar(scnr)) {
      name2 += ch;
    }
    return name2;
  }
  __name(readLinkedModifier, "readLinkedModifier");
  function readLinkedRefer(scnr) {
    const fn = /* @__PURE__ */ __name((buf) => {
      const ch = scnr.currentChar();
      if (ch === "{" || ch === "%" || ch === "@" || ch === "|" || ch === "(" || ch === ")" || !ch) {
        return buf;
      } else if (ch === CHAR_SP) {
        return buf;
      } else if (ch === CHAR_LF || ch === DOT$1) {
        buf += ch;
        scnr.next();
        return fn(buf);
      } else {
        buf += ch;
        scnr.next();
        return fn(buf);
      }
    }, "fn");
    return fn("");
  }
  __name(readLinkedRefer, "readLinkedRefer");
  function readPlural(scnr) {
    skipSpaces2(scnr);
    const plural = eat(
      scnr,
      "|"
      /* TokenChars.Pipe */
    );
    skipSpaces2(scnr);
    return plural;
  }
  __name(readPlural, "readPlural");
  function readTokenInPlaceholder(scnr, context2) {
    let token = null;
    const ch = scnr.currentChar();
    switch (ch) {
      case "{":
        if (context2.braceNest >= 1) {
          emitError(CompileErrorCodes.NOT_ALLOW_NEST_PLACEHOLDER, currentPosition(), 0);
        }
        scnr.next();
        token = getToken(
          context2,
          2,
          "{"
          /* TokenChars.BraceLeft */
        );
        skipSpaces2(scnr);
        context2.braceNest++;
        return token;
      case "}":
        if (context2.braceNest > 0 && context2.currentType === 2) {
          emitError(CompileErrorCodes.EMPTY_PLACEHOLDER, currentPosition(), 0);
        }
        scnr.next();
        token = getToken(
          context2,
          3,
          "}"
          /* TokenChars.BraceRight */
        );
        context2.braceNest--;
        context2.braceNest > 0 && skipSpaces2(scnr);
        if (context2.inLinked && context2.braceNest === 0) {
          context2.inLinked = false;
        }
        return token;
      case "@":
        if (context2.braceNest > 0) {
          emitError(CompileErrorCodes.UNTERMINATED_CLOSING_BRACE, currentPosition(), 0);
        }
        token = readTokenInLinked(scnr, context2) || getEndToken(context2);
        context2.braceNest = 0;
        return token;
      default: {
        let validNamedIdentifier = true;
        let validListIdentifier = true;
        let validLiteral = true;
        if (isPluralStart(scnr)) {
          if (context2.braceNest > 0) {
            emitError(CompileErrorCodes.UNTERMINATED_CLOSING_BRACE, currentPosition(), 0);
          }
          token = getToken(context2, 1, readPlural(scnr));
          context2.braceNest = 0;
          context2.inLinked = false;
          return token;
        }
        if (context2.braceNest > 0 && (context2.currentType === 5 || context2.currentType === 6 || context2.currentType === 7)) {
          emitError(CompileErrorCodes.UNTERMINATED_CLOSING_BRACE, currentPosition(), 0);
          context2.braceNest = 0;
          return readToken(scnr, context2);
        }
        if (validNamedIdentifier = isNamedIdentifierStart(scnr, context2)) {
          token = getToken(context2, 5, readNamedIdentifier(scnr));
          skipSpaces2(scnr);
          return token;
        }
        if (validListIdentifier = isListIdentifierStart(scnr, context2)) {
          token = getToken(context2, 6, readListIdentifier(scnr));
          skipSpaces2(scnr);
          return token;
        }
        if (validLiteral = isLiteralStart(scnr, context2)) {
          token = getToken(context2, 7, readLiteral(scnr));
          skipSpaces2(scnr);
          return token;
        }
        if (!validNamedIdentifier && !validListIdentifier && !validLiteral) {
          token = getToken(context2, 13, readInvalidIdentifier(scnr));
          emitError(CompileErrorCodes.INVALID_TOKEN_IN_PLACEHOLDER, currentPosition(), 0, token.value);
          skipSpaces2(scnr);
          return token;
        }
        break;
      }
    }
    return token;
  }
  __name(readTokenInPlaceholder, "readTokenInPlaceholder");
  function readTokenInLinked(scnr, context2) {
    const { currentType } = context2;
    let token = null;
    const ch = scnr.currentChar();
    if ((currentType === 8 || currentType === 9 || currentType === 12 || currentType === 10) && (ch === CHAR_LF || ch === CHAR_SP)) {
      emitError(CompileErrorCodes.INVALID_LINKED_FORMAT, currentPosition(), 0);
    }
    switch (ch) {
      case "@":
        scnr.next();
        token = getToken(
          context2,
          8,
          "@"
          /* TokenChars.LinkedAlias */
        );
        context2.inLinked = true;
        return token;
      case ".":
        skipSpaces2(scnr);
        scnr.next();
        return getToken(
          context2,
          9,
          "."
          /* TokenChars.LinkedDot */
        );
      case ":":
        skipSpaces2(scnr);
        scnr.next();
        return getToken(
          context2,
          10,
          ":"
          /* TokenChars.LinkedDelimiter */
        );
      default:
        if (isPluralStart(scnr)) {
          token = getToken(context2, 1, readPlural(scnr));
          context2.braceNest = 0;
          context2.inLinked = false;
          return token;
        }
        if (isLinkedDotStart(scnr, context2) || isLinkedDelimiterStart(scnr, context2)) {
          skipSpaces2(scnr);
          return readTokenInLinked(scnr, context2);
        }
        if (isLinkedModifierStart(scnr, context2)) {
          skipSpaces2(scnr);
          return getToken(context2, 12, readLinkedModifier(scnr));
        }
        if (isLinkedReferStart(scnr, context2)) {
          skipSpaces2(scnr);
          if (ch === "{") {
            return readTokenInPlaceholder(scnr, context2) || token;
          } else {
            return getToken(context2, 11, readLinkedRefer(scnr));
          }
        }
        if (currentType === 8) {
          emitError(CompileErrorCodes.INVALID_LINKED_FORMAT, currentPosition(), 0);
        }
        context2.braceNest = 0;
        context2.inLinked = false;
        return readToken(scnr, context2);
    }
  }
  __name(readTokenInLinked, "readTokenInLinked");
  function readToken(scnr, context2) {
    let token = {
      type: 14
      /* TokenTypes.EOF */
    };
    if (context2.braceNest > 0) {
      return readTokenInPlaceholder(scnr, context2) || getEndToken(context2);
    }
    if (context2.inLinked) {
      return readTokenInLinked(scnr, context2) || getEndToken(context2);
    }
    const ch = scnr.currentChar();
    switch (ch) {
      case "{":
        return readTokenInPlaceholder(scnr, context2) || getEndToken(context2);
      case "}":
        emitError(CompileErrorCodes.UNBALANCED_CLOSING_BRACE, currentPosition(), 0);
        scnr.next();
        return getToken(
          context2,
          3,
          "}"
          /* TokenChars.BraceRight */
        );
      case "@":
        return readTokenInLinked(scnr, context2) || getEndToken(context2);
      default: {
        if (isPluralStart(scnr)) {
          token = getToken(context2, 1, readPlural(scnr));
          context2.braceNest = 0;
          context2.inLinked = false;
          return token;
        }
        const { isModulo, hasSpace } = detectModuloStart(scnr);
        if (isModulo) {
          return hasSpace ? getToken(context2, 0, readText(scnr)) : getToken(context2, 4, readModulo(scnr));
        }
        if (isTextStart(scnr)) {
          return getToken(context2, 0, readText(scnr));
        }
        break;
      }
    }
    return token;
  }
  __name(readToken, "readToken");
  function nextToken() {
    const { currentType, offset, startLoc, endLoc } = _context;
    _context.lastType = currentType;
    _context.lastOffset = offset;
    _context.lastStartLoc = startLoc;
    _context.lastEndLoc = endLoc;
    _context.offset = currentOffset();
    _context.startLoc = currentPosition();
    if (_scnr.currentChar() === EOF) {
      return getToken(
        _context,
        14
        /* TokenTypes.EOF */
      );
    }
    return readToken(_scnr, _context);
  }
  __name(nextToken, "nextToken");
  return {
    nextToken,
    currentOffset,
    currentPosition,
    context
  };
}
__name(createTokenizer, "createTokenizer");
const ERROR_DOMAIN$2 = "parser";
const KNOWN_ESCAPES = /(?:\\\\|\\'|\\u([0-9a-fA-F]{4})|\\U([0-9a-fA-F]{6}))/g;
function fromEscapeSequence(match2, codePoint4, codePoint6) {
  switch (match2) {
    case `\\\\`:
      return `\\`;
    case `\\'`:
      return `'`;
    default: {
      const codePoint = parseInt(codePoint4 || codePoint6, 16);
      if (codePoint <= 55295 || codePoint >= 57344) {
        return String.fromCodePoint(codePoint);
      }
      return "�";
    }
  }
}
__name(fromEscapeSequence, "fromEscapeSequence");
function createParser(options5 = {}) {
  const location2 = options5.location !== false;
  const { onError, onWarn } = options5;
  function emitError(tokenzer, code2, start2, offset, ...args) {
    const end = tokenzer.currentPosition();
    end.offset += offset;
    end.column += offset;
    if (onError) {
      const loc = location2 ? createLocation(start2, end) : null;
      const err = createCompileError(code2, loc, {
        domain: ERROR_DOMAIN$2,
        args
      });
      onError(err);
    }
  }
  __name(emitError, "emitError");
  function emitWarn(tokenzer, code2, start2, offset, ...args) {
    const end = tokenzer.currentPosition();
    end.offset += offset;
    end.column += offset;
    if (onWarn) {
      const loc = location2 ? createLocation(start2, end) : null;
      onWarn(createCompileWarn(code2, loc, args));
    }
  }
  __name(emitWarn, "emitWarn");
  function startNode(type, offset, loc) {
    const node3 = { type };
    if (location2) {
      node3.start = offset;
      node3.end = offset;
      node3.loc = { start: loc, end: loc };
    }
    return node3;
  }
  __name(startNode, "startNode");
  function endNode(node3, offset, pos, type) {
    if (type) {
      node3.type = type;
    }
    if (location2) {
      node3.end = offset;
      if (node3.loc) {
        node3.loc.end = pos;
      }
    }
  }
  __name(endNode, "endNode");
  function parseText(tokenizer, value3) {
    const context = tokenizer.context();
    const node3 = startNode(3, context.offset, context.startLoc);
    node3.value = value3;
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parseText, "parseText");
  function parseList(tokenizer, index2) {
    const context = tokenizer.context();
    const { lastOffset: offset, lastStartLoc: loc } = context;
    const node3 = startNode(5, offset, loc);
    node3.index = parseInt(index2, 10);
    tokenizer.nextToken();
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parseList, "parseList");
  function parseNamed(tokenizer, key, modulo) {
    const context = tokenizer.context();
    const { lastOffset: offset, lastStartLoc: loc } = context;
    const node3 = startNode(4, offset, loc);
    node3.key = key;
    if (modulo === true) {
      node3.modulo = true;
    }
    tokenizer.nextToken();
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parseNamed, "parseNamed");
  function parseLiteral(tokenizer, value3) {
    const context = tokenizer.context();
    const { lastOffset: offset, lastStartLoc: loc } = context;
    const node3 = startNode(9, offset, loc);
    node3.value = value3.replace(KNOWN_ESCAPES, fromEscapeSequence);
    tokenizer.nextToken();
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parseLiteral, "parseLiteral");
  function parseLinkedModifier(tokenizer) {
    const token = tokenizer.nextToken();
    const context = tokenizer.context();
    const { lastOffset: offset, lastStartLoc: loc } = context;
    const node3 = startNode(8, offset, loc);
    if (token.type !== 12) {
      emitError(tokenizer, CompileErrorCodes.UNEXPECTED_EMPTY_LINKED_MODIFIER, context.lastStartLoc, 0);
      node3.value = "";
      endNode(node3, offset, loc);
      return {
        nextConsumeToken: token,
        node: node3
      };
    }
    if (token.value == null) {
      emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
    }
    node3.value = token.value || "";
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return {
      node: node3
    };
  }
  __name(parseLinkedModifier, "parseLinkedModifier");
  function parseLinkedKey(tokenizer, value3) {
    const context = tokenizer.context();
    const node3 = startNode(7, context.offset, context.startLoc);
    node3.value = value3;
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parseLinkedKey, "parseLinkedKey");
  function parseLinked(tokenizer) {
    const context = tokenizer.context();
    const linkedNode = startNode(6, context.offset, context.startLoc);
    let token = tokenizer.nextToken();
    if (token.type === 9) {
      const parsed = parseLinkedModifier(tokenizer);
      linkedNode.modifier = parsed.node;
      token = parsed.nextConsumeToken || tokenizer.nextToken();
    }
    if (token.type !== 10) {
      emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
    }
    token = tokenizer.nextToken();
    if (token.type === 2) {
      token = tokenizer.nextToken();
    }
    switch (token.type) {
      case 11:
        if (token.value == null) {
          emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
        }
        linkedNode.key = parseLinkedKey(tokenizer, token.value || "");
        break;
      case 5:
        if (token.value == null) {
          emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
        }
        linkedNode.key = parseNamed(tokenizer, token.value || "");
        break;
      case 6:
        if (token.value == null) {
          emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
        }
        linkedNode.key = parseList(tokenizer, token.value || "");
        break;
      case 7:
        if (token.value == null) {
          emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
        }
        linkedNode.key = parseLiteral(tokenizer, token.value || "");
        break;
      default: {
        emitError(tokenizer, CompileErrorCodes.UNEXPECTED_EMPTY_LINKED_KEY, context.lastStartLoc, 0);
        const nextContext = tokenizer.context();
        const emptyLinkedKeyNode = startNode(7, nextContext.offset, nextContext.startLoc);
        emptyLinkedKeyNode.value = "";
        endNode(emptyLinkedKeyNode, nextContext.offset, nextContext.startLoc);
        linkedNode.key = emptyLinkedKeyNode;
        endNode(linkedNode, nextContext.offset, nextContext.startLoc);
        return {
          nextConsumeToken: token,
          node: linkedNode
        };
      }
    }
    endNode(linkedNode, tokenizer.currentOffset(), tokenizer.currentPosition());
    return {
      node: linkedNode
    };
  }
  __name(parseLinked, "parseLinked");
  function parseMessage(tokenizer) {
    const context = tokenizer.context();
    const startOffset = context.currentType === 1 ? tokenizer.currentOffset() : context.offset;
    const startLoc = context.currentType === 1 ? context.endLoc : context.startLoc;
    const node3 = startNode(2, startOffset, startLoc);
    node3.items = [];
    let nextToken = null;
    let modulo = null;
    do {
      const token = nextToken || tokenizer.nextToken();
      nextToken = null;
      switch (token.type) {
        case 0:
          if (token.value == null) {
            emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
          }
          node3.items.push(parseText(tokenizer, token.value || ""));
          break;
        case 6:
          if (token.value == null) {
            emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
          }
          node3.items.push(parseList(tokenizer, token.value || ""));
          break;
        case 4:
          modulo = true;
          break;
        case 5:
          if (token.value == null) {
            emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
          }
          node3.items.push(parseNamed(tokenizer, token.value || "", !!modulo));
          if (modulo) {
            emitWarn(tokenizer, CompileWarnCodes.USE_MODULO_SYNTAX, context.lastStartLoc, 0, getTokenCaption(token));
            modulo = null;
          }
          break;
        case 7:
          if (token.value == null) {
            emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, getTokenCaption(token));
          }
          node3.items.push(parseLiteral(tokenizer, token.value || ""));
          break;
        case 8: {
          const parsed = parseLinked(tokenizer);
          node3.items.push(parsed.node);
          nextToken = parsed.nextConsumeToken || null;
          break;
        }
      }
    } while (context.currentType !== 14 && context.currentType !== 1);
    const endOffset = context.currentType === 1 ? context.lastOffset : tokenizer.currentOffset();
    const endLoc = context.currentType === 1 ? context.lastEndLoc : tokenizer.currentPosition();
    endNode(node3, endOffset, endLoc);
    return node3;
  }
  __name(parseMessage, "parseMessage");
  function parsePlural(tokenizer, offset, loc, msgNode) {
    const context = tokenizer.context();
    let hasEmptyMessage = msgNode.items.length === 0;
    const node3 = startNode(1, offset, loc);
    node3.cases = [];
    node3.cases.push(msgNode);
    do {
      const msg = parseMessage(tokenizer);
      if (!hasEmptyMessage) {
        hasEmptyMessage = msg.items.length === 0;
      }
      node3.cases.push(msg);
    } while (context.currentType !== 14);
    if (hasEmptyMessage) {
      emitError(tokenizer, CompileErrorCodes.MUST_HAVE_MESSAGES_IN_PLURAL, loc, 0);
    }
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parsePlural, "parsePlural");
  function parseResource(tokenizer) {
    const context = tokenizer.context();
    const { offset, startLoc } = context;
    const msgNode = parseMessage(tokenizer);
    if (context.currentType === 14) {
      return msgNode;
    } else {
      return parsePlural(tokenizer, offset, startLoc, msgNode);
    }
  }
  __name(parseResource, "parseResource");
  function parse2(source) {
    const tokenizer = createTokenizer(source, assign$3({}, options5));
    const context = tokenizer.context();
    const node3 = startNode(0, context.offset, context.startLoc);
    if (location2 && node3.loc) {
      node3.loc.source = source;
    }
    node3.body = parseResource(tokenizer);
    if (options5.onCacheKey) {
      node3.cacheKey = options5.onCacheKey(source);
    }
    if (context.currentType !== 14) {
      emitError(tokenizer, CompileErrorCodes.UNEXPECTED_LEXICAL_ANALYSIS, context.lastStartLoc, 0, source[context.offset] || "");
    }
    endNode(node3, tokenizer.currentOffset(), tokenizer.currentPosition());
    return node3;
  }
  __name(parse2, "parse");
  return { parse: parse2 };
}
__name(createParser, "createParser");
function getTokenCaption(token) {
  if (token.type === 14) {
    return "EOF";
  }
  const name2 = (token.value || "").replace(/\r?\n/gu, "\\n");
  return name2.length > 10 ? name2.slice(0, 9) + "…" : name2;
}
__name(getTokenCaption, "getTokenCaption");
function createTransformer(ast, options5 = {}) {
  const _context = {
    ast,
    helpers: /* @__PURE__ */ new Set()
  };
  const context = /* @__PURE__ */ __name(() => _context, "context");
  const helper = /* @__PURE__ */ __name((name2) => {
    _context.helpers.add(name2);
    return name2;
  }, "helper");
  return { context, helper };
}
__name(createTransformer, "createTransformer");
function traverseNodes(nodes, transformer) {
  for (let i2 = 0; i2 < nodes.length; i2++) {
    traverseNode(nodes[i2], transformer);
  }
}
__name(traverseNodes, "traverseNodes");
function traverseNode(node3, transformer) {
  switch (node3.type) {
    case 1:
      traverseNodes(node3.cases, transformer);
      transformer.helper(
        "plural"
        /* HelperNameMap.PLURAL */
      );
      break;
    case 2:
      traverseNodes(node3.items, transformer);
      break;
    case 6: {
      const linked = node3;
      traverseNode(linked.key, transformer);
      transformer.helper(
        "linked"
        /* HelperNameMap.LINKED */
      );
      transformer.helper(
        "type"
        /* HelperNameMap.TYPE */
      );
      break;
    }
    case 5:
      transformer.helper(
        "interpolate"
        /* HelperNameMap.INTERPOLATE */
      );
      transformer.helper(
        "list"
        /* HelperNameMap.LIST */
      );
      break;
    case 4:
      transformer.helper(
        "interpolate"
        /* HelperNameMap.INTERPOLATE */
      );
      transformer.helper(
        "named"
        /* HelperNameMap.NAMED */
      );
      break;
  }
}
__name(traverseNode, "traverseNode");
function transform(ast, options5 = {}) {
  const transformer = createTransformer(ast);
  transformer.helper(
    "normalize"
    /* HelperNameMap.NORMALIZE */
  );
  ast.body && traverseNode(ast.body, transformer);
  const context = transformer.context();
  ast.helpers = Array.from(context.helpers);
}
__name(transform, "transform");
function optimize(ast) {
  const body = ast.body;
  if (body.type === 2) {
    optimizeMessageNode(body);
  } else {
    body.cases.forEach((c2) => optimizeMessageNode(c2));
  }
  return ast;
}
__name(optimize, "optimize");
function optimizeMessageNode(message3) {
  if (message3.items.length === 1) {
    const item3 = message3.items[0];
    if (item3.type === 3 || item3.type === 9) {
      message3.static = item3.value;
      delete item3.value;
    }
  } else {
    const values = [];
    for (let i2 = 0; i2 < message3.items.length; i2++) {
      const item3 = message3.items[i2];
      if (!(item3.type === 3 || item3.type === 9)) {
        break;
      }
      if (item3.value == null) {
        break;
      }
      values.push(item3.value);
    }
    if (values.length === message3.items.length) {
      message3.static = join$1(values);
      for (let i2 = 0; i2 < message3.items.length; i2++) {
        const item3 = message3.items[i2];
        if (item3.type === 3 || item3.type === 9) {
          delete item3.value;
        }
      }
    }
  }
}
__name(optimizeMessageNode, "optimizeMessageNode");
const ERROR_DOMAIN$1 = "minifier";
function minify(node3) {
  node3.t = node3.type;
  switch (node3.type) {
    case 0: {
      const resource = node3;
      minify(resource.body);
      resource.b = resource.body;
      delete resource.body;
      break;
    }
    case 1: {
      const plural = node3;
      const cases = plural.cases;
      for (let i2 = 0; i2 < cases.length; i2++) {
        minify(cases[i2]);
      }
      plural.c = cases;
      delete plural.cases;
      break;
    }
    case 2: {
      const message3 = node3;
      const items2 = message3.items;
      for (let i2 = 0; i2 < items2.length; i2++) {
        minify(items2[i2]);
      }
      message3.i = items2;
      delete message3.items;
      if (message3.static) {
        message3.s = message3.static;
        delete message3.static;
      }
      break;
    }
    case 3:
    case 9:
    case 8:
    case 7: {
      const valueNode = node3;
      if (valueNode.value) {
        valueNode.v = valueNode.value;
        delete valueNode.value;
      }
      break;
    }
    case 6: {
      const linked = node3;
      minify(linked.key);
      linked.k = linked.key;
      delete linked.key;
      if (linked.modifier) {
        minify(linked.modifier);
        linked.m = linked.modifier;
        delete linked.modifier;
      }
      break;
    }
    case 5: {
      const list2 = node3;
      list2.i = list2.index;
      delete list2.index;
      break;
    }
    case 4: {
      const named = node3;
      named.k = named.key;
      delete named.key;
      break;
    }
    default: {
      throw createCompileError(CompileErrorCodes.UNHANDLED_MINIFIER_NODE_TYPE, null, {
        domain: ERROR_DOMAIN$1,
        args: [node3.type]
      });
    }
  }
  delete node3.type;
}
__name(minify, "minify");
const ERROR_DOMAIN = "parser";
function createCodeGenerator(ast, options5) {
  const { sourceMap, filename, breakLineCode, needIndent: _needIndent } = options5;
  const location2 = options5.location !== false;
  const _context = {
    filename,
    code: "",
    column: 1,
    line: 1,
    offset: 0,
    map: void 0,
    breakLineCode,
    needIndent: _needIndent,
    indentLevel: 0
  };
  if (location2 && ast.loc) {
    _context.source = ast.loc.source;
  }
  const context = /* @__PURE__ */ __name(() => _context, "context");
  function push2(code2, node3) {
    _context.code += code2;
  }
  __name(push2, "push");
  function _newline(n2, withBreakLine = true) {
    const _breakLineCode = withBreakLine ? breakLineCode : "";
    push2(_needIndent ? _breakLineCode + `  `.repeat(n2) : _breakLineCode);
  }
  __name(_newline, "_newline");
  function indent(withNewLine = true) {
    const level = ++_context.indentLevel;
    withNewLine && _newline(level);
  }
  __name(indent, "indent");
  function deindent(withNewLine = true) {
    const level = --_context.indentLevel;
    withNewLine && _newline(level);
  }
  __name(deindent, "deindent");
  function newline2() {
    _newline(_context.indentLevel);
  }
  __name(newline2, "newline");
  const helper = /* @__PURE__ */ __name((key) => `_${key}`, "helper");
  const needIndent = /* @__PURE__ */ __name(() => _context.needIndent, "needIndent");
  return {
    context,
    push: push2,
    indent,
    deindent,
    newline: newline2,
    helper,
    needIndent
  };
}
__name(createCodeGenerator, "createCodeGenerator");
function generateLinkedNode(generator, node3) {
  const { helper } = generator;
  generator.push(`${helper(
    "linked"
    /* HelperNameMap.LINKED */
  )}(`);
  generateNode(generator, node3.key);
  if (node3.modifier) {
    generator.push(`, `);
    generateNode(generator, node3.modifier);
    generator.push(`, _type`);
  } else {
    generator.push(`, undefined, _type`);
  }
  generator.push(`)`);
}
__name(generateLinkedNode, "generateLinkedNode");
function generateMessageNode(generator, node3) {
  const { helper, needIndent } = generator;
  generator.push(`${helper(
    "normalize"
    /* HelperNameMap.NORMALIZE */
  )}([`);
  generator.indent(needIndent());
  const length = node3.items.length;
  for (let i2 = 0; i2 < length; i2++) {
    generateNode(generator, node3.items[i2]);
    if (i2 === length - 1) {
      break;
    }
    generator.push(", ");
  }
  generator.deindent(needIndent());
  generator.push("])");
}
__name(generateMessageNode, "generateMessageNode");
function generatePluralNode(generator, node3) {
  const { helper, needIndent } = generator;
  if (node3.cases.length > 1) {
    generator.push(`${helper(
      "plural"
      /* HelperNameMap.PLURAL */
    )}([`);
    generator.indent(needIndent());
    const length = node3.cases.length;
    for (let i2 = 0; i2 < length; i2++) {
      generateNode(generator, node3.cases[i2]);
      if (i2 === length - 1) {
        break;
      }
      generator.push(", ");
    }
    generator.deindent(needIndent());
    generator.push(`])`);
  }
}
__name(generatePluralNode, "generatePluralNode");
function generateResource(generator, node3) {
  if (node3.body) {
    generateNode(generator, node3.body);
  } else {
    generator.push("null");
  }
}
__name(generateResource, "generateResource");
function generateNode(generator, node3) {
  const { helper } = generator;
  switch (node3.type) {
    case 0:
      generateResource(generator, node3);
      break;
    case 1:
      generatePluralNode(generator, node3);
      break;
    case 2:
      generateMessageNode(generator, node3);
      break;
    case 6:
      generateLinkedNode(generator, node3);
      break;
    case 8:
      generator.push(JSON.stringify(node3.value), node3);
      break;
    case 7:
      generator.push(JSON.stringify(node3.value), node3);
      break;
    case 5:
      generator.push(`${helper(
        "interpolate"
        /* HelperNameMap.INTERPOLATE */
      )}(${helper(
        "list"
        /* HelperNameMap.LIST */
      )}(${node3.index}))`, node3);
      break;
    case 4:
      generator.push(`${helper(
        "interpolate"
        /* HelperNameMap.INTERPOLATE */
      )}(${helper(
        "named"
        /* HelperNameMap.NAMED */
      )}(${JSON.stringify(node3.key)}))`, node3);
      break;
    case 9:
      generator.push(JSON.stringify(node3.value), node3);
      break;
    case 3:
      generator.push(JSON.stringify(node3.value), node3);
      break;
    default: {
      throw createCompileError(CompileErrorCodes.UNHANDLED_CODEGEN_NODE_TYPE, null, {
        domain: ERROR_DOMAIN,
        args: [node3.type]
      });
    }
  }
}
__name(generateNode, "generateNode");
const generate = /* @__PURE__ */ __name((ast, options5 = {}) => {
  const mode2 = isString$6(options5.mode) ? options5.mode : "normal";
  const filename = isString$6(options5.filename) ? options5.filename : "message.intl";
  const sourceMap = !!options5.sourceMap;
  const breakLineCode = options5.breakLineCode != null ? options5.breakLineCode : mode2 === "arrow" ? ";" : "\n";
  const needIndent = options5.needIndent ? options5.needIndent : mode2 !== "arrow";
  const helpers2 = ast.helpers || [];
  const generator = createCodeGenerator(ast, {
    mode: mode2,
    filename,
    sourceMap,
    breakLineCode,
    needIndent
  });
  generator.push(mode2 === "normal" ? `function __msg__ (ctx) {` : `(ctx) => {`);
  generator.indent(needIndent);
  if (helpers2.length > 0) {
    generator.push(`const { ${join$1(helpers2.map((s2) => `${s2}: _${s2}`), ", ")} } = ctx`);
    generator.newline();
  }
  generator.push(`return `);
  generateNode(generator, ast);
  generator.deindent(needIndent);
  generator.push(`}`);
  delete ast.helpers;
  const { code: code2, map: map3 } = generator.context();
  return {
    ast,
    code: code2,
    map: map3 ? map3.toJSON() : void 0
    // eslint-disable-line @typescript-eslint/no-explicit-any
  };
}, "generate");
function baseCompile$1(source, options5 = {}) {
  const assignedOptions = assign$3({}, options5);
  const jit = !!assignedOptions.jit;
  const enalbeMinify = !!assignedOptions.minify;
  const enambeOptimize = assignedOptions.optimize == null ? true : assignedOptions.optimize;
  const parser = createParser(assignedOptions);
  const ast = parser.parse(source);
  if (!jit) {
    transform(ast, assignedOptions);
    return generate(ast, assignedOptions);
  } else {
    enambeOptimize && optimize(ast);
    enalbeMinify && minify(ast);
    return { ast, code: "" };
  }
}
__name(baseCompile$1, "baseCompile$1");
/*!
  * core-base v9.14.3
  * (c) 2025 kazuya kawaguchi
  * Released under the MIT License.
  */
function initFeatureFlags$1() {
  if (typeof __INTLIFY_PROD_DEVTOOLS__ !== "boolean") {
    getGlobalThis().__INTLIFY_PROD_DEVTOOLS__ = false;
  }
  if (typeof __INTLIFY_JIT_COMPILATION__ !== "boolean") {
    getGlobalThis().__INTLIFY_JIT_COMPILATION__ = false;
  }
  if (typeof __INTLIFY_DROP_MESSAGE_COMPILER__ !== "boolean") {
    getGlobalThis().__INTLIFY_DROP_MESSAGE_COMPILER__ = false;
  }
}
__name(initFeatureFlags$1, "initFeatureFlags$1");
const pathStateMachine = [];
pathStateMachine[
  0
  /* States.BEFORE_PATH */
] = {
  [
    "w"
    /* PathCharTypes.WORKSPACE */
  ]: [
    0
    /* States.BEFORE_PATH */
  ],
  [
    "i"
    /* PathCharTypes.IDENT */
  ]: [
    3,
    0
    /* Actions.APPEND */
  ],
  [
    "["
    /* PathCharTypes.LEFT_BRACKET */
  ]: [
    4
    /* States.IN_SUB_PATH */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: [
    7
    /* States.AFTER_PATH */
  ]
};
pathStateMachine[
  1
  /* States.IN_PATH */
] = {
  [
    "w"
    /* PathCharTypes.WORKSPACE */
  ]: [
    1
    /* States.IN_PATH */
  ],
  [
    "."
    /* PathCharTypes.DOT */
  ]: [
    2
    /* States.BEFORE_IDENT */
  ],
  [
    "["
    /* PathCharTypes.LEFT_BRACKET */
  ]: [
    4
    /* States.IN_SUB_PATH */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: [
    7
    /* States.AFTER_PATH */
  ]
};
pathStateMachine[
  2
  /* States.BEFORE_IDENT */
] = {
  [
    "w"
    /* PathCharTypes.WORKSPACE */
  ]: [
    2
    /* States.BEFORE_IDENT */
  ],
  [
    "i"
    /* PathCharTypes.IDENT */
  ]: [
    3,
    0
    /* Actions.APPEND */
  ],
  [
    "0"
    /* PathCharTypes.ZERO */
  ]: [
    3,
    0
    /* Actions.APPEND */
  ]
};
pathStateMachine[
  3
  /* States.IN_IDENT */
] = {
  [
    "i"
    /* PathCharTypes.IDENT */
  ]: [
    3,
    0
    /* Actions.APPEND */
  ],
  [
    "0"
    /* PathCharTypes.ZERO */
  ]: [
    3,
    0
    /* Actions.APPEND */
  ],
  [
    "w"
    /* PathCharTypes.WORKSPACE */
  ]: [
    1,
    1
    /* Actions.PUSH */
  ],
  [
    "."
    /* PathCharTypes.DOT */
  ]: [
    2,
    1
    /* Actions.PUSH */
  ],
  [
    "["
    /* PathCharTypes.LEFT_BRACKET */
  ]: [
    4,
    1
    /* Actions.PUSH */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: [
    7,
    1
    /* Actions.PUSH */
  ]
};
pathStateMachine[
  4
  /* States.IN_SUB_PATH */
] = {
  [
    "'"
    /* PathCharTypes.SINGLE_QUOTE */
  ]: [
    5,
    0
    /* Actions.APPEND */
  ],
  [
    '"'
    /* PathCharTypes.DOUBLE_QUOTE */
  ]: [
    6,
    0
    /* Actions.APPEND */
  ],
  [
    "["
    /* PathCharTypes.LEFT_BRACKET */
  ]: [
    4,
    2
    /* Actions.INC_SUB_PATH_DEPTH */
  ],
  [
    "]"
    /* PathCharTypes.RIGHT_BRACKET */
  ]: [
    1,
    3
    /* Actions.PUSH_SUB_PATH */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: 8,
  [
    "l"
    /* PathCharTypes.ELSE */
  ]: [
    4,
    0
    /* Actions.APPEND */
  ]
};
pathStateMachine[
  5
  /* States.IN_SINGLE_QUOTE */
] = {
  [
    "'"
    /* PathCharTypes.SINGLE_QUOTE */
  ]: [
    4,
    0
    /* Actions.APPEND */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: 8,
  [
    "l"
    /* PathCharTypes.ELSE */
  ]: [
    5,
    0
    /* Actions.APPEND */
  ]
};
pathStateMachine[
  6
  /* States.IN_DOUBLE_QUOTE */
] = {
  [
    '"'
    /* PathCharTypes.DOUBLE_QUOTE */
  ]: [
    4,
    0
    /* Actions.APPEND */
  ],
  [
    "o"
    /* PathCharTypes.END_OF_FAIL */
  ]: 8,
  [
    "l"
    /* PathCharTypes.ELSE */
  ]: [
    6,
    0
    /* Actions.APPEND */
  ]
};
const literalValueRE = /^\s?(?:true|false|-?[\d.]+|'[^']*'|"[^"]*")\s?$/;
function isLiteral(exp) {
  return literalValueRE.test(exp);
}
__name(isLiteral, "isLiteral");
function stripQuotes(str) {
  const a2 = str.charCodeAt(0);
  const b2 = str.charCodeAt(str.length - 1);
  return a2 === b2 && (a2 === 34 || a2 === 39) ? str.slice(1, -1) : str;
}
__name(stripQuotes, "stripQuotes");
function getPathCharType(ch) {
  if (ch === void 0 || ch === null) {
    return "o";
  }
  const code2 = ch.charCodeAt(0);
  switch (code2) {
    case 91:
    case 93:
    case 46:
    case 34:
    case 39:
      return ch;
    case 95:
    case 36:
    case 45:
      return "i";
    case 9:
    case 10:
    case 13:
    case 160:
    case 65279:
    case 8232:
    case 8233:
      return "w";
  }
  return "i";
}
__name(getPathCharType, "getPathCharType");
function formatSubPath(path) {
  const trimmed = path.trim();
  if (path.charAt(0) === "0" && isNaN(parseInt(path))) {
    return false;
  }
  return isLiteral(trimmed) ? stripQuotes(trimmed) : "*" + trimmed;
}
__name(formatSubPath, "formatSubPath");
function parse$1(path) {
  const keys2 = [];
  let index2 = -1;
  let mode2 = 0;
  let subPathDepth = 0;
  let c2;
  let key;
  let newChar;
  let type;
  let transition;
  let action;
  let typeMap;
  const actions = [];
  actions[
    0
    /* Actions.APPEND */
  ] = () => {
    if (key === void 0) {
      key = newChar;
    } else {
      key += newChar;
    }
  };
  actions[
    1
    /* Actions.PUSH */
  ] = () => {
    if (key !== void 0) {
      keys2.push(key);
      key = void 0;
    }
  };
  actions[
    2
    /* Actions.INC_SUB_PATH_DEPTH */
  ] = () => {
    actions[
      0
      /* Actions.APPEND */
    ]();
    subPathDepth++;
  };
  actions[
    3
    /* Actions.PUSH_SUB_PATH */
  ] = () => {
    if (subPathDepth > 0) {
      subPathDepth--;
      mode2 = 4;
      actions[
        0
        /* Actions.APPEND */
      ]();
    } else {
      subPathDepth = 0;
      if (key === void 0) {
        return false;
      }
      key = formatSubPath(key);
      if (key === false) {
        return false;
      } else {
        actions[
          1
          /* Actions.PUSH */
        ]();
      }
    }
  };
  function maybeUnescapeQuote() {
    const nextChar = path[index2 + 1];
    if (mode2 === 5 && nextChar === "'" || mode2 === 6 && nextChar === '"') {
      index2++;
      newChar = "\\" + nextChar;
      actions[
        0
        /* Actions.APPEND */
      ]();
      return true;
    }
  }
  __name(maybeUnescapeQuote, "maybeUnescapeQuote");
  while (mode2 !== null) {
    index2++;
    c2 = path[index2];
    if (c2 === "\\" && maybeUnescapeQuote()) {
      continue;
    }
    type = getPathCharType(c2);
    typeMap = pathStateMachine[mode2];
    transition = typeMap[type] || typeMap[
      "l"
      /* PathCharTypes.ELSE */
    ] || 8;
    if (transition === 8) {
      return;
    }
    mode2 = transition[0];
    if (transition[1] !== void 0) {
      action = actions[transition[1]];
      if (action) {
        newChar = c2;
        if (action() === false) {
          return;
        }
      }
    }
    if (mode2 === 7) {
      return keys2;
    }
  }
}
__name(parse$1, "parse$1");
const cache = /* @__PURE__ */ new Map();
function resolveWithKeyValue(obj, path) {
  return isObject$c(obj) ? obj[path] : null;
}
__name(resolveWithKeyValue, "resolveWithKeyValue");
function resolveValue$1(obj, path) {
  if (!isObject$c(obj)) {
    return null;
  }
  let hit = cache.get(path);
  if (!hit) {
    hit = parse$1(path);
    if (hit) {
      cache.set(path, hit);
    }
  }
  if (!hit) {
    return null;
  }
  const len = hit.length;
  let last = obj;
  let i2 = 0;
  while (i2 < len) {
    const val = last[hit[i2]];
    if (val === void 0) {
      return null;
    }
    if (isFunction$9(last)) {
      return null;
    }
    last = val;
    i2++;
  }
  return last;
}
__name(resolveValue$1, "resolveValue$1");
const DEFAULT_MODIFIER = /* @__PURE__ */ __name((str) => str, "DEFAULT_MODIFIER");
const DEFAULT_MESSAGE = /* @__PURE__ */ __name((ctx) => "", "DEFAULT_MESSAGE");
const DEFAULT_MESSAGE_DATA_TYPE = "text";
const DEFAULT_NORMALIZE = /* @__PURE__ */ __name((values) => values.length === 0 ? "" : join$2(values), "DEFAULT_NORMALIZE");
const DEFAULT_INTERPOLATE = toDisplayString;
function pluralDefault(choice, choicesLength) {
  choice = Math.abs(choice);
  if (choicesLength === 2) {
    return choice ? choice > 1 ? 1 : 0 : 1;
  }
  return choice ? Math.min(choice, 2) : 0;
}
__name(pluralDefault, "pluralDefault");
function getPluralIndex(options5) {
  const index2 = isNumber$5(options5.pluralIndex) ? options5.pluralIndex : -1;
  return options5.named && (isNumber$5(options5.named.count) || isNumber$5(options5.named.n)) ? isNumber$5(options5.named.count) ? options5.named.count : isNumber$5(options5.named.n) ? options5.named.n : index2 : index2;
}
__name(getPluralIndex, "getPluralIndex");
function normalizeNamed(pluralIndex, props) {
  if (!props.count) {
    props.count = pluralIndex;
  }
  if (!props.n) {
    props.n = pluralIndex;
  }
}
__name(normalizeNamed, "normalizeNamed");
function createMessageContext(options5 = {}) {
  const locale2 = options5.locale;
  const pluralIndex = getPluralIndex(options5);
  const pluralRule = isObject$c(options5.pluralRules) && isString$7(locale2) && isFunction$9(options5.pluralRules[locale2]) ? options5.pluralRules[locale2] : pluralDefault;
  const orgPluralRule = isObject$c(options5.pluralRules) && isString$7(locale2) && isFunction$9(options5.pluralRules[locale2]) ? pluralDefault : void 0;
  const plural = /* @__PURE__ */ __name((messages2) => {
    return messages2[pluralRule(pluralIndex, messages2.length, orgPluralRule)];
  }, "plural");
  const _list = options5.list || [];
  const list2 = /* @__PURE__ */ __name((index2) => _list[index2], "list");
  const _named = options5.named || create$1();
  isNumber$5(options5.pluralIndex) && normalizeNamed(pluralIndex, _named);
  const named = /* @__PURE__ */ __name((key) => _named[key], "named");
  function message3(key) {
    const msg = isFunction$9(options5.messages) ? options5.messages(key) : isObject$c(options5.messages) ? options5.messages[key] : false;
    return !msg ? options5.parent ? options5.parent.message(key) : DEFAULT_MESSAGE : msg;
  }
  __name(message3, "message");
  const _modifier = /* @__PURE__ */ __name((name2) => options5.modifiers ? options5.modifiers[name2] : DEFAULT_MODIFIER, "_modifier");
  const normalize3 = isPlainObject$1(options5.processor) && isFunction$9(options5.processor.normalize) ? options5.processor.normalize : DEFAULT_NORMALIZE;
  const interpolate = isPlainObject$1(options5.processor) && isFunction$9(options5.processor.interpolate) ? options5.processor.interpolate : DEFAULT_INTERPOLATE;
  const type = isPlainObject$1(options5.processor) && isString$7(options5.processor.type) ? options5.processor.type : DEFAULT_MESSAGE_DATA_TYPE;
  const linked = /* @__PURE__ */ __name((key, ...args) => {
    const [arg1, arg2] = args;
    let type2 = "text";
    let modifier = "";
    if (args.length === 1) {
      if (isObject$c(arg1)) {
        modifier = arg1.modifier || modifier;
        type2 = arg1.type || type2;
      } else if (isString$7(arg1)) {
        modifier = arg1 || modifier;
      }
    } else if (args.length === 2) {
      if (isString$7(arg1)) {
        modifier = arg1 || modifier;
      }
      if (isString$7(arg2)) {
        type2 = arg2 || type2;
      }
    }
    const ret = message3(key)(ctx);
    const msg = (
      // The message in vnode resolved with linked are returned as an array by processor.nomalize
      type2 === "vnode" && isArray$8(ret) && modifier ? ret[0] : ret
    );
    return modifier ? _modifier(modifier)(msg, type2) : msg;
  }, "linked");
  const ctx = {
    [
      "list"
      /* HelperNameMap.LIST */
    ]: list2,
    [
      "named"
      /* HelperNameMap.NAMED */
    ]: named,
    [
      "plural"
      /* HelperNameMap.PLURAL */
    ]: plural,
    [
      "linked"
      /* HelperNameMap.LINKED */
    ]: linked,
    [
      "message"
      /* HelperNameMap.MESSAGE */
    ]: message3,
    [
      "type"
      /* HelperNameMap.TYPE */
    ]: type,
    [
      "interpolate"
      /* HelperNameMap.INTERPOLATE */
    ]: interpolate,
    [
      "normalize"
      /* HelperNameMap.NORMALIZE */
    ]: normalize3,
    [
      "values"
      /* HelperNameMap.VALUES */
    ]: assign$4(create$1(), _list, _named)
  };
  return ctx;
}
__name(createMessageContext, "createMessageContext");
let devtools = null;
function setDevToolsHook(hook) {
  devtools = hook;
}
__name(setDevToolsHook, "setDevToolsHook");
function getDevToolsHook() {
  return devtools;
}
__name(getDevToolsHook, "getDevToolsHook");
function initI18nDevTools(i18n2, version2, meta) {
  devtools && devtools.emit("i18n:init", {
    timestamp: Date.now(),
    i18n: i18n2,
    version: version2,
    meta
  });
}
__name(initI18nDevTools, "initI18nDevTools");
const translateDevTools = /* @__PURE__ */ createDevToolsHook(
  "function:translate"
  /* IntlifyDevToolsHooks.FunctionTranslate */
);
function createDevToolsHook(hook) {
  return (payloads) => devtools && devtools.emit(hook, payloads);
}
__name(createDevToolsHook, "createDevToolsHook");
const code$1$2 = CompileWarnCodes.__EXTEND_POINT__;
const inc$1$1 = incrementer(code$1$2);
const CoreWarnCodes = {
  NOT_FOUND_KEY: code$1$2,
  // 2
  FALLBACK_TO_TRANSLATE: inc$1$1(),
  // 3
  CANNOT_FORMAT_NUMBER: inc$1$1(),
  // 4
  FALLBACK_TO_NUMBER_FORMAT: inc$1$1(),
  // 5
  CANNOT_FORMAT_DATE: inc$1$1(),
  // 6
  FALLBACK_TO_DATE_FORMAT: inc$1$1(),
  // 7
  EXPERIMENTAL_CUSTOM_MESSAGE_COMPILER: inc$1$1(),
  // 8
  __EXTEND_POINT__: inc$1$1()
  // 9
};
const warnMessages$1 = {
  [CoreWarnCodes.NOT_FOUND_KEY]: `Not found '{key}' key in '{locale}' locale messages.`,
  [CoreWarnCodes.FALLBACK_TO_TRANSLATE]: `Fall back to translate '{key}' key with '{target}' locale.`,
  [CoreWarnCodes.CANNOT_FORMAT_NUMBER]: `Cannot format a number value due to not supported Intl.NumberFormat.`,
  [CoreWarnCodes.FALLBACK_TO_NUMBER_FORMAT]: `Fall back to number format '{key}' key with '{target}' locale.`,
  [CoreWarnCodes.CANNOT_FORMAT_DATE]: `Cannot format a date value due to not supported Intl.DateTimeFormat.`,
  [CoreWarnCodes.FALLBACK_TO_DATE_FORMAT]: `Fall back to datetime format '{key}' key with '{target}' locale.`,
  [CoreWarnCodes.EXPERIMENTAL_CUSTOM_MESSAGE_COMPILER]: `This project is using Custom Message Compiler, which is an experimental feature. It may receive breaking changes or be removed in the future.`
};
function getWarnMessage$1(code2, ...args) {
  return format$5(warnMessages$1[code2], ...args);
}
__name(getWarnMessage$1, "getWarnMessage$1");
const code$3 = CompileErrorCodes.__EXTEND_POINT__;
const inc$2 = incrementer(code$3);
const CoreErrorCodes = {
  INVALID_ARGUMENT: code$3,
  // 17
  INVALID_DATE_ARGUMENT: inc$2(),
  // 18
  INVALID_ISO_DATE_ARGUMENT: inc$2(),
  // 19
  NOT_SUPPORT_NON_STRING_MESSAGE: inc$2(),
  // 20
  NOT_SUPPORT_LOCALE_PROMISE_VALUE: inc$2(),
  // 21
  NOT_SUPPORT_LOCALE_ASYNC_FUNCTION: inc$2(),
  // 22
  NOT_SUPPORT_LOCALE_TYPE: inc$2(),
  // 23
  __EXTEND_POINT__: inc$2()
  // 24
};
function createCoreError(code2) {
  return createCompileError(code2, null, false ? { messages: errorMessages$1 } : void 0);
}
__name(createCoreError, "createCoreError");
const errorMessages$1 = {
  [CoreErrorCodes.INVALID_ARGUMENT]: "Invalid arguments",
  [CoreErrorCodes.INVALID_DATE_ARGUMENT]: "The date provided is an invalid Date object.Make sure your Date represents a valid date.",
  [CoreErrorCodes.INVALID_ISO_DATE_ARGUMENT]: "The argument provided is not a valid ISO date string",
  [CoreErrorCodes.NOT_SUPPORT_NON_STRING_MESSAGE]: "Not support non-string message",
  [CoreErrorCodes.NOT_SUPPORT_LOCALE_PROMISE_VALUE]: "cannot support promise value",
  [CoreErrorCodes.NOT_SUPPORT_LOCALE_ASYNC_FUNCTION]: "cannot support async function",
  [CoreErrorCodes.NOT_SUPPORT_LOCALE_TYPE]: "cannot support locale type"
};
function getLocale(context, options5) {
  return options5.locale != null ? resolveLocale(options5.locale) : resolveLocale(context.locale);
}
__name(getLocale, "getLocale");
let _resolveLocale;
function resolveLocale(locale2) {
  if (isString$7(locale2)) {
    return locale2;
  } else {
    if (isFunction$9(locale2)) {
      if (locale2.resolvedOnce && _resolveLocale != null) {
        return _resolveLocale;
      } else if (locale2.constructor.name === "Function") {
        const resolve2 = locale2();
        if (isPromise(resolve2)) {
          throw createCoreError(CoreErrorCodes.NOT_SUPPORT_LOCALE_PROMISE_VALUE);
        }
        return _resolveLocale = resolve2;
      } else {
        throw createCoreError(CoreErrorCodes.NOT_SUPPORT_LOCALE_ASYNC_FUNCTION);
      }
    } else {
      throw createCoreError(CoreErrorCodes.NOT_SUPPORT_LOCALE_TYPE);
    }
  }
}
__name(resolveLocale, "resolveLocale");
function fallbackWithSimple(ctx, fallback, start2) {
  return [.../* @__PURE__ */ new Set([
    start2,
    ...isArray$8(fallback) ? fallback : isObject$c(fallback) ? Object.keys(fallback) : isString$7(fallback) ? [fallback] : [start2]
  ])];
}
__name(fallbackWithSimple, "fallbackWithSimple");
function fallbackWithLocaleChain(ctx, fallback, start2) {
  const startLocale = isString$7(start2) ? start2 : DEFAULT_LOCALE;
  const context = ctx;
  if (!context.__localeChainCache) {
    context.__localeChainCache = /* @__PURE__ */ new Map();
  }
  let chain = context.__localeChainCache.get(startLocale);
  if (!chain) {
    chain = [];
    let block3 = [start2];
    while (isArray$8(block3)) {
      block3 = appendBlockToChain(chain, block3, fallback);
    }
    const defaults2 = isArray$8(fallback) || !isPlainObject$1(fallback) ? fallback : fallback["default"] ? fallback["default"] : null;
    block3 = isString$7(defaults2) ? [defaults2] : defaults2;
    if (isArray$8(block3)) {
      appendBlockToChain(chain, block3, false);
    }
    context.__localeChainCache.set(startLocale, chain);
  }
  return chain;
}
__name(fallbackWithLocaleChain, "fallbackWithLocaleChain");
function appendBlockToChain(chain, block3, blocks) {
  let follow = true;
  for (let i2 = 0; i2 < block3.length && isBoolean$1(follow); i2++) {
    const locale2 = block3[i2];
    if (isString$7(locale2)) {
      follow = appendLocaleToChain(chain, block3[i2], blocks);
    }
  }
  return follow;
}
__name(appendBlockToChain, "appendBlockToChain");
function appendLocaleToChain(chain, locale2, blocks) {
  let follow;
  const tokens = locale2.split("-");
  do {
    const target2 = tokens.join("-");
    follow = appendItemToChain(chain, target2, blocks);
    tokens.splice(-1, 1);
  } while (tokens.length && follow === true);
  return follow;
}
__name(appendLocaleToChain, "appendLocaleToChain");
function appendItemToChain(chain, target2, blocks) {
  let follow = false;
  if (!chain.includes(target2)) {
    follow = true;
    if (target2) {
      follow = target2[target2.length - 1] !== "!";
      const locale2 = target2.replace(/!/g, "");
      chain.push(locale2);
      if ((isArray$8(blocks) || isPlainObject$1(blocks)) && blocks[locale2]) {
        follow = blocks[locale2];
      }
    }
  }
  return follow;
}
__name(appendItemToChain, "appendItemToChain");
const VERSION$1 = "9.14.3";
const NOT_REOSLVED = -1;
const DEFAULT_LOCALE = "en-US";
const MISSING_RESOLVE_VALUE = "";
const capitalize = /* @__PURE__ */ __name((str) => `${str.charAt(0).toLocaleUpperCase()}${str.substr(1)}`, "capitalize");
function getDefaultLinkedModifiers() {
  return {
    upper: /* @__PURE__ */ __name((val, type) => {
      return type === "text" && isString$7(val) ? val.toUpperCase() : type === "vnode" && isObject$c(val) && "__v_isVNode" in val ? val.children.toUpperCase() : val;
    }, "upper"),
    lower: /* @__PURE__ */ __name((val, type) => {
      return type === "text" && isString$7(val) ? val.toLowerCase() : type === "vnode" && isObject$c(val) && "__v_isVNode" in val ? val.children.toLowerCase() : val;
    }, "lower"),
    capitalize: /* @__PURE__ */ __name((val, type) => {
      return type === "text" && isString$7(val) ? capitalize(val) : type === "vnode" && isObject$c(val) && "__v_isVNode" in val ? capitalize(val.children) : val;
    }, "capitalize")
  };
}
__name(getDefaultLinkedModifiers, "getDefaultLinkedModifiers");
let _compiler;
function registerMessageCompiler(compiler) {
  _compiler = compiler;
}
__name(registerMessageCompiler, "registerMessageCompiler");
let _resolver;
function registerMessageResolver(resolver) {
  _resolver = resolver;
}
__name(registerMessageResolver, "registerMessageResolver");
let _fallbacker;
function registerLocaleFallbacker(fallbacker) {
  _fallbacker = fallbacker;
}
__name(registerLocaleFallbacker, "registerLocaleFallbacker");
let _additionalMeta = null;
const setAdditionalMeta = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ (meta) => {
  _additionalMeta = meta;
}, "setAdditionalMeta");
const getAdditionalMeta = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ () => _additionalMeta, "getAdditionalMeta");
let _fallbackContext = null;
const setFallbackContext = /* @__PURE__ */ __name((context) => {
  _fallbackContext = context;
}, "setFallbackContext");
const getFallbackContext = /* @__PURE__ */ __name(() => _fallbackContext, "getFallbackContext");
let _cid = 0;
function createCoreContext(options5 = {}) {
  const onWarn = isFunction$9(options5.onWarn) ? options5.onWarn : warn$1;
  const version2 = isString$7(options5.version) ? options5.version : VERSION$1;
  const locale2 = isString$7(options5.locale) || isFunction$9(options5.locale) ? options5.locale : DEFAULT_LOCALE;
  const _locale = isFunction$9(locale2) ? DEFAULT_LOCALE : locale2;
  const fallbackLocale = isArray$8(options5.fallbackLocale) || isPlainObject$1(options5.fallbackLocale) || isString$7(options5.fallbackLocale) || options5.fallbackLocale === false ? options5.fallbackLocale : _locale;
  const messages2 = isPlainObject$1(options5.messages) ? options5.messages : createResources(_locale);
  const datetimeFormats = isPlainObject$1(options5.datetimeFormats) ? options5.datetimeFormats : createResources(_locale);
  const numberFormats = isPlainObject$1(options5.numberFormats) ? options5.numberFormats : createResources(_locale);
  const modifiers2 = assign$4(create$1(), options5.modifiers, getDefaultLinkedModifiers());
  const pluralRules = options5.pluralRules || create$1();
  const missing = isFunction$9(options5.missing) ? options5.missing : null;
  const missingWarn = isBoolean$1(options5.missingWarn) || isRegExp$2(options5.missingWarn) ? options5.missingWarn : true;
  const fallbackWarn = isBoolean$1(options5.fallbackWarn) || isRegExp$2(options5.fallbackWarn) ? options5.fallbackWarn : true;
  const fallbackFormat = !!options5.fallbackFormat;
  const unresolving = !!options5.unresolving;
  const postTranslation = isFunction$9(options5.postTranslation) ? options5.postTranslation : null;
  const processor = isPlainObject$1(options5.processor) ? options5.processor : null;
  const warnHtmlMessage = isBoolean$1(options5.warnHtmlMessage) ? options5.warnHtmlMessage : true;
  const escapeParameter = !!options5.escapeParameter;
  const messageCompiler = isFunction$9(options5.messageCompiler) ? options5.messageCompiler : _compiler;
  if (false) {
    warnOnce(getWarnMessage$1(CoreWarnCodes.EXPERIMENTAL_CUSTOM_MESSAGE_COMPILER));
  }
  const messageResolver = isFunction$9(options5.messageResolver) ? options5.messageResolver : _resolver || resolveWithKeyValue;
  const localeFallbacker = isFunction$9(options5.localeFallbacker) ? options5.localeFallbacker : _fallbacker || fallbackWithSimple;
  const fallbackContext = isObject$c(options5.fallbackContext) ? options5.fallbackContext : void 0;
  const internalOptions = options5;
  const __datetimeFormatters = isObject$c(internalOptions.__datetimeFormatters) ? internalOptions.__datetimeFormatters : /* @__PURE__ */ new Map();
  const __numberFormatters = isObject$c(internalOptions.__numberFormatters) ? internalOptions.__numberFormatters : /* @__PURE__ */ new Map();
  const __meta = isObject$c(internalOptions.__meta) ? internalOptions.__meta : {};
  _cid++;
  const context = {
    version: version2,
    cid: _cid,
    locale: locale2,
    fallbackLocale,
    messages: messages2,
    modifiers: modifiers2,
    pluralRules,
    missing,
    missingWarn,
    fallbackWarn,
    fallbackFormat,
    unresolving,
    postTranslation,
    processor,
    warnHtmlMessage,
    escapeParameter,
    messageCompiler,
    messageResolver,
    localeFallbacker,
    fallbackContext,
    onWarn,
    __meta
  };
  {
    context.datetimeFormats = datetimeFormats;
    context.numberFormats = numberFormats;
    context.__datetimeFormatters = __datetimeFormatters;
    context.__numberFormatters = __numberFormatters;
  }
  if (false) {
    context.__v_emitter = internalOptions.__v_emitter != null ? internalOptions.__v_emitter : void 0;
  }
  if (__INTLIFY_PROD_DEVTOOLS__) {
    initI18nDevTools(context, version2, __meta);
  }
  return context;
}
__name(createCoreContext, "createCoreContext");
const createResources = /* @__PURE__ */ __name((locale2) => ({ [locale2]: create$1() }), "createResources");
function isTranslateFallbackWarn(fallback, key) {
  return fallback instanceof RegExp ? fallback.test(key) : fallback;
}
__name(isTranslateFallbackWarn, "isTranslateFallbackWarn");
function isTranslateMissingWarn(missing, key) {
  return missing instanceof RegExp ? missing.test(key) : missing;
}
__name(isTranslateMissingWarn, "isTranslateMissingWarn");
function handleMissing(context, key, locale2, missingWarn, type) {
  const { missing, onWarn } = context;
  if (false) {
    const emitter = context.__v_emitter;
    if (emitter) {
      emitter.emit("missing", {
        locale: locale2,
        key,
        type,
        groupId: `${type}:${key}`
      });
    }
  }
  if (missing !== null) {
    const ret = missing(context, locale2, key, type);
    return isString$7(ret) ? ret : key;
  } else {
    if (false) {
      onWarn(getWarnMessage$1(CoreWarnCodes.NOT_FOUND_KEY, { key, locale: locale2 }));
    }
    return key;
  }
}
__name(handleMissing, "handleMissing");
function updateFallbackLocale(ctx, locale2, fallback) {
  const context = ctx;
  context.__localeChainCache = /* @__PURE__ */ new Map();
  ctx.localeFallbacker(ctx, fallback, locale2);
}
__name(updateFallbackLocale, "updateFallbackLocale");
function isAlmostSameLocale(locale2, compareLocale) {
  if (locale2 === compareLocale)
    return false;
  return locale2.split("-")[0] === compareLocale.split("-")[0];
}
__name(isAlmostSameLocale, "isAlmostSameLocale");
function isImplicitFallback(targetLocale, locales) {
  const index2 = locales.indexOf(targetLocale);
  if (index2 === -1) {
    return false;
  }
  for (let i2 = index2 + 1; i2 < locales.length; i2++) {
    if (isAlmostSameLocale(targetLocale, locales[i2])) {
      return true;
    }
  }
  return false;
}
__name(isImplicitFallback, "isImplicitFallback");
function format$3(ast) {
  const msg = /* @__PURE__ */ __name((ctx) => formatParts(ctx, ast), "msg");
  return msg;
}
__name(format$3, "format$3");
function formatParts(ctx, ast) {
  const body = resolveBody(ast);
  if (body == null) {
    throw createUnhandleNodeError(
      0
      /* NodeTypes.Resource */
    );
  }
  const type = resolveType(body);
  if (type === 1) {
    const plural = body;
    const cases = resolveCases(plural);
    return ctx.plural(cases.reduce((messages2, c2) => [
      ...messages2,
      formatMessageParts(ctx, c2)
    ], []));
  } else {
    return formatMessageParts(ctx, body);
  }
}
__name(formatParts, "formatParts");
const PROPS_BODY = ["b", "body"];
function resolveBody(node3) {
  return resolveProps(node3, PROPS_BODY);
}
__name(resolveBody, "resolveBody");
const PROPS_CASES = ["c", "cases"];
function resolveCases(node3) {
  return resolveProps(node3, PROPS_CASES, []);
}
__name(resolveCases, "resolveCases");
function formatMessageParts(ctx, node3) {
  const static_ = resolveStatic(node3);
  if (static_ != null) {
    return ctx.type === "text" ? static_ : ctx.normalize([static_]);
  } else {
    const messages2 = resolveItems(node3).reduce((acm, c2) => [...acm, formatMessagePart(ctx, c2)], []);
    return ctx.normalize(messages2);
  }
}
__name(formatMessageParts, "formatMessageParts");
const PROPS_STATIC = ["s", "static"];
function resolveStatic(node3) {
  return resolveProps(node3, PROPS_STATIC);
}
__name(resolveStatic, "resolveStatic");
const PROPS_ITEMS = ["i", "items"];
function resolveItems(node3) {
  return resolveProps(node3, PROPS_ITEMS, []);
}
__name(resolveItems, "resolveItems");
function formatMessagePart(ctx, node3) {
  const type = resolveType(node3);
  switch (type) {
    case 3: {
      return resolveValue(node3, type);
    }
    case 9: {
      return resolveValue(node3, type);
    }
    case 4: {
      const named = node3;
      if (hasOwn$1(named, "k") && named.k) {
        return ctx.interpolate(ctx.named(named.k));
      }
      if (hasOwn$1(named, "key") && named.key) {
        return ctx.interpolate(ctx.named(named.key));
      }
      throw createUnhandleNodeError(type);
    }
    case 5: {
      const list2 = node3;
      if (hasOwn$1(list2, "i") && isNumber$5(list2.i)) {
        return ctx.interpolate(ctx.list(list2.i));
      }
      if (hasOwn$1(list2, "index") && isNumber$5(list2.index)) {
        return ctx.interpolate(ctx.list(list2.index));
      }
      throw createUnhandleNodeError(type);
    }
    case 6: {
      const linked = node3;
      const modifier = resolveLinkedModifier(linked);
      const key = resolveLinkedKey(linked);
      return ctx.linked(formatMessagePart(ctx, key), modifier ? formatMessagePart(ctx, modifier) : void 0, ctx.type);
    }
    case 7: {
      return resolveValue(node3, type);
    }
    case 8: {
      return resolveValue(node3, type);
    }
    default:
      throw new Error(`unhandled node on format message part: ${type}`);
  }
}
__name(formatMessagePart, "formatMessagePart");
const PROPS_TYPE = ["t", "type"];
function resolveType(node3) {
  return resolveProps(node3, PROPS_TYPE);
}
__name(resolveType, "resolveType");
const PROPS_VALUE = ["v", "value"];
function resolveValue(node3, type) {
  const resolved = resolveProps(node3, PROPS_VALUE);
  if (resolved) {
    return resolved;
  } else {
    throw createUnhandleNodeError(type);
  }
}
__name(resolveValue, "resolveValue");
const PROPS_MODIFIER = ["m", "modifier"];
function resolveLinkedModifier(node3) {
  return resolveProps(node3, PROPS_MODIFIER);
}
__name(resolveLinkedModifier, "resolveLinkedModifier");
const PROPS_KEY = ["k", "key"];
function resolveLinkedKey(node3) {
  const resolved = resolveProps(node3, PROPS_KEY);
  if (resolved) {
    return resolved;
  } else {
    throw createUnhandleNodeError(
      6
      /* NodeTypes.Linked */
    );
  }
}
__name(resolveLinkedKey, "resolveLinkedKey");
function resolveProps(node3, props, defaultValue2) {
  for (let i2 = 0; i2 < props.length; i2++) {
    const prop2 = props[i2];
    if (hasOwn$1(node3, prop2) && node3[prop2] != null) {
      return node3[prop2];
    }
  }
  return defaultValue2;
}
__name(resolveProps, "resolveProps");
function createUnhandleNodeError(type) {
  return new Error(`unhandled node type: ${type}`);
}
__name(createUnhandleNodeError, "createUnhandleNodeError");
const WARN_MESSAGE = `Detected HTML in '{source}' message. Recommend not using HTML messages to avoid XSS.`;
function checkHtmlMessage(source, warnHtmlMessage) {
  if (warnHtmlMessage && detectHtmlTag(source)) {
    warn$1(format$5(WARN_MESSAGE, { source }));
  }
}
__name(checkHtmlMessage, "checkHtmlMessage");
const defaultOnCacheKey = /* @__PURE__ */ __name((message3) => message3, "defaultOnCacheKey");
let compileCache = create$1();
function onCompileWarn(_warn) {
  if (_warn.code === CompileWarnCodes.USE_MODULO_SYNTAX) {
    warn$1(`The use of named interpolation with modulo syntax is deprecated. It will be removed in v10.
reference: https://vue-i18n.intlify.dev/guide/essentials/syntax#rails-i18n-format 
(message compiler warning message: ${_warn.message})`);
  }
}
__name(onCompileWarn, "onCompileWarn");
function clearCompileCache() {
  compileCache = create$1();
}
__name(clearCompileCache, "clearCompileCache");
function isMessageAST(val) {
  return isObject$c(val) && resolveType(val) === 0 && (hasOwn$1(val, "b") || hasOwn$1(val, "body"));
}
__name(isMessageAST, "isMessageAST");
function baseCompile(message3, options5 = {}) {
  let detectError = false;
  const onError = options5.onError || defaultOnError;
  options5.onError = (err) => {
    detectError = true;
    onError(err);
  };
  return { ...baseCompile$1(message3, options5), detectError };
}
__name(baseCompile, "baseCompile");
const compileToFunction = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ (message3, context) => {
  if (!isString$7(message3)) {
    throw createCoreError(CoreErrorCodes.NOT_SUPPORT_NON_STRING_MESSAGE);
  }
  if (false) {
    context.onWarn = onCompileWarn;
  }
  {
    const warnHtmlMessage = isBoolean$1(context.warnHtmlMessage) ? context.warnHtmlMessage : true;
    const onCacheKey = context.onCacheKey || defaultOnCacheKey;
    const cacheKey = onCacheKey(message3);
    const cached = compileCache[cacheKey];
    if (cached) {
      return cached;
    }
    const { code: code2, detectError } = baseCompile(message3, context);
    const msg = new Function(`return ${code2}`)();
    return !detectError ? compileCache[cacheKey] = msg : msg;
  }
}, "compileToFunction");
function compile$1(message3, context) {
  if (false) {
    context.onWarn = onCompileWarn;
  }
  if (__INTLIFY_JIT_COMPILATION__ && !__INTLIFY_DROP_MESSAGE_COMPILER__ && isString$7(message3)) {
    const warnHtmlMessage = isBoolean$1(context.warnHtmlMessage) ? context.warnHtmlMessage : true;
    const onCacheKey = context.onCacheKey || defaultOnCacheKey;
    const cacheKey = onCacheKey(message3);
    const cached = compileCache[cacheKey];
    if (cached) {
      return cached;
    }
    const { ast, detectError } = baseCompile(message3, {
      ...context,
      location: false,
      jit: true
    });
    const msg = format$3(ast);
    return !detectError ? compileCache[cacheKey] = msg : msg;
  } else {
    if (false) {
      warn$1(`the message that is resolve with key '${context.key}' is not supported for jit compilation`);
      return () => message3;
    }
    const cacheKey = message3.cacheKey;
    if (cacheKey) {
      const cached = compileCache[cacheKey];
      if (cached) {
        return cached;
      }
      return compileCache[cacheKey] = format$3(message3);
    } else {
      return format$3(message3);
    }
  }
}
__name(compile$1, "compile$1");
const NOOP_MESSAGE_FUNCTION = /* @__PURE__ */ __name(() => "", "NOOP_MESSAGE_FUNCTION");
const isMessageFunction = /* @__PURE__ */ __name((val) => isFunction$9(val), "isMessageFunction");
function translate(context, ...args) {
  const { fallbackFormat, postTranslation, unresolving, messageCompiler, fallbackLocale, messages: messages2 } = context;
  const [key, options5] = parseTranslateArgs(...args);
  const missingWarn = isBoolean$1(options5.missingWarn) ? options5.missingWarn : context.missingWarn;
  const fallbackWarn = isBoolean$1(options5.fallbackWarn) ? options5.fallbackWarn : context.fallbackWarn;
  const escapeParameter = isBoolean$1(options5.escapeParameter) ? options5.escapeParameter : context.escapeParameter;
  const resolvedMessage = !!options5.resolvedMessage;
  const defaultMsgOrKey = isString$7(options5.default) || isBoolean$1(options5.default) ? !isBoolean$1(options5.default) ? options5.default : !messageCompiler ? () => key : key : fallbackFormat ? !messageCompiler ? () => key : key : "";
  const enableDefaultMsg = fallbackFormat || defaultMsgOrKey !== "";
  const locale2 = getLocale(context, options5);
  escapeParameter && escapeParams(options5);
  let [formatScope, targetLocale, message3] = !resolvedMessage ? resolveMessageFormat(context, key, locale2, fallbackLocale, fallbackWarn, missingWarn) : [
    key,
    locale2,
    messages2[locale2] || create$1()
  ];
  let format2 = formatScope;
  let cacheBaseKey = key;
  if (!resolvedMessage && !(isString$7(format2) || isMessageAST(format2) || isMessageFunction(format2))) {
    if (enableDefaultMsg) {
      format2 = defaultMsgOrKey;
      cacheBaseKey = format2;
    }
  }
  if (!resolvedMessage && (!(isString$7(format2) || isMessageAST(format2) || isMessageFunction(format2)) || !isString$7(targetLocale))) {
    return unresolving ? NOT_REOSLVED : key;
  }
  if (false) {
    warn$1(`The message format compilation is not supported in this build. Because message compiler isn't included. You need to pre-compilation all message format. So translate function return '${key}'.`);
    return key;
  }
  let occurred = false;
  const onError = /* @__PURE__ */ __name(() => {
    occurred = true;
  }, "onError");
  const msg = !isMessageFunction(format2) ? compileMessageFormat(context, key, targetLocale, format2, cacheBaseKey, onError) : format2;
  if (occurred) {
    return format2;
  }
  const ctxOptions = getMessageContextOptions(context, targetLocale, message3, options5);
  const msgContext = createMessageContext(ctxOptions);
  const messaged = evaluateMessage(context, msg, msgContext);
  const ret = postTranslation ? postTranslation(messaged, key) : messaged;
  if (__INTLIFY_PROD_DEVTOOLS__) {
    const payloads = {
      timestamp: Date.now(),
      key: isString$7(key) ? key : isMessageFunction(format2) ? format2.key : "",
      locale: targetLocale || (isMessageFunction(format2) ? format2.locale : ""),
      format: isString$7(format2) ? format2 : isMessageFunction(format2) ? format2.source : "",
      message: ret
    };
    payloads.meta = assign$4({}, context.__meta, /* @__PURE__ */ getAdditionalMeta() || {});
    translateDevTools(payloads);
  }
  return ret;
}
__name(translate, "translate");
function escapeParams(options5) {
  if (isArray$8(options5.list)) {
    options5.list = options5.list.map((item3) => isString$7(item3) ? escapeHtml$1(item3) : item3);
  } else if (isObject$c(options5.named)) {
    Object.keys(options5.named).forEach((key) => {
      if (isString$7(options5.named[key])) {
        options5.named[key] = escapeHtml$1(options5.named[key]);
      }
    });
  }
}
__name(escapeParams, "escapeParams");
function resolveMessageFormat(context, key, locale2, fallbackLocale, fallbackWarn, missingWarn) {
  const { messages: messages2, onWarn, messageResolver: resolveValue2, localeFallbacker } = context;
  const locales = localeFallbacker(context, fallbackLocale, locale2);
  let message3 = create$1();
  let targetLocale;
  let format2 = null;
  let from2 = locale2;
  let to = null;
  const type = "translate";
  for (let i2 = 0; i2 < locales.length; i2++) {
    targetLocale = to = locales[i2];
    if (false) {
      onWarn(getWarnMessage$1(CoreWarnCodes.FALLBACK_TO_TRANSLATE, {
        key,
        target: targetLocale
      }));
    }
    if (false) {
      const emitter = context.__v_emitter;
      if (emitter) {
        emitter.emit("fallback", {
          type,
          key,
          from: from2,
          to,
          groupId: `${type}:${key}`
        });
      }
    }
    message3 = messages2[targetLocale] || create$1();
    let start2 = null;
    let startTag;
    let endTag;
    if (false) {
      start2 = window.performance.now();
      startTag = "intlify-message-resolve-start";
      endTag = "intlify-message-resolve-end";
      mark && mark(startTag);
    }
    if ((format2 = resolveValue2(message3, key)) === null) {
      format2 = message3[key];
    }
    if (false) {
      const end = window.performance.now();
      const emitter = context.__v_emitter;
      if (emitter && start2 && format2) {
        emitter.emit("message-resolve", {
          type: "message-resolve",
          key,
          message: format2,
          time: end - start2,
          groupId: `${type}:${key}`
        });
      }
      if (startTag && endTag && mark && measure) {
        mark(endTag);
        measure("intlify message resolve", startTag, endTag);
      }
    }
    if (isString$7(format2) || isMessageAST(format2) || isMessageFunction(format2)) {
      break;
    }
    if (!isImplicitFallback(targetLocale, locales)) {
      const missingRet = handleMissing(
        context,
        // eslint-disable-line @typescript-eslint/no-explicit-any
        key,
        targetLocale,
        missingWarn,
        type
      );
      if (missingRet !== key) {
        format2 = missingRet;
      }
    }
    from2 = to;
  }
  return [format2, targetLocale, message3];
}
__name(resolveMessageFormat, "resolveMessageFormat");
function compileMessageFormat(context, key, targetLocale, format2, cacheBaseKey, onError) {
  const { messageCompiler, warnHtmlMessage } = context;
  if (isMessageFunction(format2)) {
    const msg2 = format2;
    msg2.locale = msg2.locale || targetLocale;
    msg2.key = msg2.key || key;
    return msg2;
  }
  if (messageCompiler == null) {
    const msg2 = /* @__PURE__ */ __name(() => format2, "msg2");
    msg2.locale = targetLocale;
    msg2.key = key;
    return msg2;
  }
  let start2 = null;
  let startTag;
  let endTag;
  if (false) {
    start2 = window.performance.now();
    startTag = "intlify-message-compilation-start";
    endTag = "intlify-message-compilation-end";
    mark && mark(startTag);
  }
  const msg = messageCompiler(format2, getCompileContext(context, targetLocale, cacheBaseKey, format2, warnHtmlMessage, onError));
  if (false) {
    const end = window.performance.now();
    const emitter = context.__v_emitter;
    if (emitter && start2) {
      emitter.emit("message-compilation", {
        type: "message-compilation",
        message: format2,
        time: end - start2,
        groupId: `${"translate"}:${key}`
      });
    }
    if (startTag && endTag && mark && measure) {
      mark(endTag);
      measure("intlify message compilation", startTag, endTag);
    }
  }
  msg.locale = targetLocale;
  msg.key = key;
  msg.source = format2;
  return msg;
}
__name(compileMessageFormat, "compileMessageFormat");
function evaluateMessage(context, msg, msgCtx) {
  let start2 = null;
  let startTag;
  let endTag;
  if (false) {
    start2 = window.performance.now();
    startTag = "intlify-message-evaluation-start";
    endTag = "intlify-message-evaluation-end";
    mark && mark(startTag);
  }
  const messaged = msg(msgCtx);
  if (false) {
    const end = window.performance.now();
    const emitter = context.__v_emitter;
    if (emitter && start2) {
      emitter.emit("message-evaluation", {
        type: "message-evaluation",
        value: messaged,
        time: end - start2,
        groupId: `${"translate"}:${msg.key}`
      });
    }
    if (startTag && endTag && mark && measure) {
      mark(endTag);
      measure("intlify message evaluation", startTag, endTag);
    }
  }
  return messaged;
}
__name(evaluateMessage, "evaluateMessage");
function parseTranslateArgs(...args) {
  const [arg1, arg2, arg3] = args;
  const options5 = create$1();
  if (!isString$7(arg1) && !isNumber$5(arg1) && !isMessageFunction(arg1) && !isMessageAST(arg1)) {
    throw createCoreError(CoreErrorCodes.INVALID_ARGUMENT);
  }
  const key = isNumber$5(arg1) ? String(arg1) : isMessageFunction(arg1) ? arg1 : arg1;
  if (isNumber$5(arg2)) {
    options5.plural = arg2;
  } else if (isString$7(arg2)) {
    options5.default = arg2;
  } else if (isPlainObject$1(arg2) && !isEmptyObject$1(arg2)) {
    options5.named = arg2;
  } else if (isArray$8(arg2)) {
    options5.list = arg2;
  }
  if (isNumber$5(arg3)) {
    options5.plural = arg3;
  } else if (isString$7(arg3)) {
    options5.default = arg3;
  } else if (isPlainObject$1(arg3)) {
    assign$4(options5, arg3);
  }
  return [key, options5];
}
__name(parseTranslateArgs, "parseTranslateArgs");
function getCompileContext(context, locale2, key, source, warnHtmlMessage, onError) {
  return {
    locale: locale2,
    key,
    warnHtmlMessage,
    onError: /* @__PURE__ */ __name((err) => {
      onError && onError(err);
      if (false) {
        const _source = getSourceForCodeFrame(source);
        const message3 = `Message compilation error: ${err.message}`;
        const codeFrame = err.location && _source && generateCodeFrame(_source, err.location.start.offset, err.location.end.offset);
        const emitter = context.__v_emitter;
        if (emitter && _source) {
          emitter.emit("compile-error", {
            message: _source,
            error: err.message,
            start: err.location && err.location.start.offset,
            end: err.location && err.location.end.offset,
            groupId: `${"translate"}:${key}`
          });
        }
        console.error(codeFrame ? `${message3}
${codeFrame}` : message3);
      } else {
        throw err;
      }
    }, "onError"),
    onCacheKey: /* @__PURE__ */ __name((source2) => generateFormatCacheKey(locale2, key, source2), "onCacheKey")
  };
}
__name(getCompileContext, "getCompileContext");
function getSourceForCodeFrame(source) {
  if (isString$7(source)) {
    return source;
  } else {
    if (source.loc && source.loc.source) {
      return source.loc.source;
    }
  }
}
__name(getSourceForCodeFrame, "getSourceForCodeFrame");
function getMessageContextOptions(context, locale2, message3, options5) {
  const { modifiers: modifiers2, pluralRules, messageResolver: resolveValue2, fallbackLocale, fallbackWarn, missingWarn, fallbackContext } = context;
  const resolveMessage = /* @__PURE__ */ __name((key) => {
    let val = resolveValue2(message3, key);
    if (val == null && fallbackContext) {
      const [, , message22] = resolveMessageFormat(fallbackContext, key, locale2, fallbackLocale, fallbackWarn, missingWarn);
      val = resolveValue2(message22, key);
    }
    if (isString$7(val) || isMessageAST(val)) {
      let occurred = false;
      const onError = /* @__PURE__ */ __name(() => {
        occurred = true;
      }, "onError");
      const msg = compileMessageFormat(context, key, locale2, val, key, onError);
      return !occurred ? msg : NOOP_MESSAGE_FUNCTION;
    } else if (isMessageFunction(val)) {
      return val;
    } else {
      return NOOP_MESSAGE_FUNCTION;
    }
  }, "resolveMessage");
  const ctxOptions = {
    locale: locale2,
    modifiers: modifiers2,
    pluralRules,
    messages: resolveMessage
  };
  if (context.processor) {
    ctxOptions.processor = context.processor;
  }
  if (options5.list) {
    ctxOptions.list = options5.list;
  }
  if (options5.named) {
    ctxOptions.named = options5.named;
  }
  if (isNumber$5(options5.plural)) {
    ctxOptions.pluralIndex = options5.plural;
  }
  return ctxOptions;
}
__name(getMessageContextOptions, "getMessageContextOptions");
const intlDefined = typeof Intl !== "undefined";
const Availabilities = {
  dateTimeFormat: intlDefined && typeof Intl.DateTimeFormat !== "undefined",
  numberFormat: intlDefined && typeof Intl.NumberFormat !== "undefined"
};
function datetime(context, ...args) {
  const { datetimeFormats, unresolving, fallbackLocale, onWarn, localeFallbacker } = context;
  const { __datetimeFormatters } = context;
  if (false) {
    onWarn(getWarnMessage$1(CoreWarnCodes.CANNOT_FORMAT_DATE));
    return MISSING_RESOLVE_VALUE;
  }
  const [key, value3, options5, overrides] = parseDateTimeArgs(...args);
  const missingWarn = isBoolean$1(options5.missingWarn) ? options5.missingWarn : context.missingWarn;
  const fallbackWarn = isBoolean$1(options5.fallbackWarn) ? options5.fallbackWarn : context.fallbackWarn;
  const part = !!options5.part;
  const locale2 = getLocale(context, options5);
  const locales = localeFallbacker(
    context,
    // eslint-disable-line @typescript-eslint/no-explicit-any
    fallbackLocale,
    locale2
  );
  if (!isString$7(key) || key === "") {
    return new Intl.DateTimeFormat(locale2, overrides).format(value3);
  }
  let datetimeFormat = {};
  let targetLocale;
  let format2 = null;
  let from2 = locale2;
  let to = null;
  const type = "datetime format";
  for (let i2 = 0; i2 < locales.length; i2++) {
    targetLocale = to = locales[i2];
    if (false) {
      onWarn(getWarnMessage$1(CoreWarnCodes.FALLBACK_TO_DATE_FORMAT, {
        key,
        target: targetLocale
      }));
    }
    if (false) {
      const emitter = context.__v_emitter;
      if (emitter) {
        emitter.emit("fallback", {
          type,
          key,
          from: from2,
          to,
          groupId: `${type}:${key}`
        });
      }
    }
    datetimeFormat = datetimeFormats[targetLocale] || {};
    format2 = datetimeFormat[key];
    if (isPlainObject$1(format2))
      break;
    handleMissing(context, key, targetLocale, missingWarn, type);
    from2 = to;
  }
  if (!isPlainObject$1(format2) || !isString$7(targetLocale)) {
    return unresolving ? NOT_REOSLVED : key;
  }
  let id4 = `${targetLocale}__${key}`;
  if (!isEmptyObject$1(overrides)) {
    id4 = `${id4}__${JSON.stringify(overrides)}`;
  }
  let formatter = __datetimeFormatters.get(id4);
  if (!formatter) {
    formatter = new Intl.DateTimeFormat(targetLocale, assign$4({}, format2, overrides));
    __datetimeFormatters.set(id4, formatter);
  }
  return !part ? formatter.format(value3) : formatter.formatToParts(value3);
}
__name(datetime, "datetime");
const DATETIME_FORMAT_OPTIONS_KEYS = [
  "localeMatcher",
  "weekday",
  "era",
  "year",
  "month",
  "day",
  "hour",
  "minute",
  "second",
  "timeZoneName",
  "formatMatcher",
  "hour12",
  "timeZone",
  "dateStyle",
  "timeStyle",
  "calendar",
  "dayPeriod",
  "numberingSystem",
  "hourCycle",
  "fractionalSecondDigits"
];
function parseDateTimeArgs(...args) {
  const [arg1, arg2, arg3, arg4] = args;
  const options5 = create$1();
  let overrides = create$1();
  let value3;
  if (isString$7(arg1)) {
    const matches2 = arg1.match(/(\d{4}-\d{2}-\d{2})(T|\s)?(.*)/);
    if (!matches2) {
      throw createCoreError(CoreErrorCodes.INVALID_ISO_DATE_ARGUMENT);
    }
    const dateTime = matches2[3] ? matches2[3].trim().startsWith("T") ? `${matches2[1].trim()}${matches2[3].trim()}` : `${matches2[1].trim()}T${matches2[3].trim()}` : matches2[1].trim();
    value3 = new Date(dateTime);
    try {
      value3.toISOString();
    } catch (e2) {
      throw createCoreError(CoreErrorCodes.INVALID_ISO_DATE_ARGUMENT);
    }
  } else if (isDate$2(arg1)) {
    if (isNaN(arg1.getTime())) {
      throw createCoreError(CoreErrorCodes.INVALID_DATE_ARGUMENT);
    }
    value3 = arg1;
  } else if (isNumber$5(arg1)) {
    value3 = arg1;
  } else {
    throw createCoreError(CoreErrorCodes.INVALID_ARGUMENT);
  }
  if (isString$7(arg2)) {
    options5.key = arg2;
  } else if (isPlainObject$1(arg2)) {
    Object.keys(arg2).forEach((key) => {
      if (DATETIME_FORMAT_OPTIONS_KEYS.includes(key)) {
        overrides[key] = arg2[key];
      } else {
        options5[key] = arg2[key];
      }
    });
  }
  if (isString$7(arg3)) {
    options5.locale = arg3;
  } else if (isPlainObject$1(arg3)) {
    overrides = arg3;
  }
  if (isPlainObject$1(arg4)) {
    overrides = arg4;
  }
  return [options5.key || "", value3, options5, overrides];
}
__name(parseDateTimeArgs, "parseDateTimeArgs");
function clearDateTimeFormat(ctx, locale2, format2) {
  const context = ctx;
  for (const key in format2) {
    const id4 = `${locale2}__${key}`;
    if (!context.__datetimeFormatters.has(id4)) {
      continue;
    }
    context.__datetimeFormatters.delete(id4);
  }
}
__name(clearDateTimeFormat, "clearDateTimeFormat");
function number(context, ...args) {
  const { numberFormats, unresolving, fallbackLocale, onWarn, localeFallbacker } = context;
  const { __numberFormatters } = context;
  if (false) {
    onWarn(getWarnMessage$1(CoreWarnCodes.CANNOT_FORMAT_NUMBER));
    return MISSING_RESOLVE_VALUE;
  }
  const [key, value3, options5, overrides] = parseNumberArgs(...args);
  const missingWarn = isBoolean$1(options5.missingWarn) ? options5.missingWarn : context.missingWarn;
  const fallbackWarn = isBoolean$1(options5.fallbackWarn) ? options5.fallbackWarn : context.fallbackWarn;
  const part = !!options5.part;
  const locale2 = getLocale(context, options5);
  const locales = localeFallbacker(
    context,
    // eslint-disable-line @typescript-eslint/no-explicit-any
    fallbackLocale,
    locale2
  );
  if (!isString$7(key) || key === "") {
    return new Intl.NumberFormat(locale2, overrides).format(value3);
  }
  let numberFormat = {};
  let targetLocale;
  let format2 = null;
  let from2 = locale2;
  let to = null;
  const type = "number format";
  for (let i2 = 0; i2 < locales.length; i2++) {
    targetLocale = to = locales[i2];
    if (false) {
      onWarn(getWarnMessage$1(CoreWarnCodes.FALLBACK_TO_NUMBER_FORMAT, {
        key,
        target: targetLocale
      }));
    }
    if (false) {
      const emitter = context.__v_emitter;
      if (emitter) {
        emitter.emit("fallback", {
          type,
          key,
          from: from2,
          to,
          groupId: `${type}:${key}`
        });
      }
    }
    numberFormat = numberFormats[targetLocale] || {};
    format2 = numberFormat[key];
    if (isPlainObject$1(format2))
      break;
    handleMissing(context, key, targetLocale, missingWarn, type);
    from2 = to;
  }
  if (!isPlainObject$1(format2) || !isString$7(targetLocale)) {
    return unresolving ? NOT_REOSLVED : key;
  }
  let id4 = `${targetLocale}__${key}`;
  if (!isEmptyObject$1(overrides)) {
    id4 = `${id4}__${JSON.stringify(overrides)}`;
  }
  let formatter = __numberFormatters.get(id4);
  if (!formatter) {
    formatter = new Intl.NumberFormat(targetLocale, assign$4({}, format2, overrides));
    __numberFormatters.set(id4, formatter);
  }
  return !part ? formatter.format(value3) : formatter.formatToParts(value3);
}
__name(number, "number");
const NUMBER_FORMAT_OPTIONS_KEYS = [
  "localeMatcher",
  "style",
  "currency",
  "currencyDisplay",
  "currencySign",
  "useGrouping",
  "minimumIntegerDigits",
  "minimumFractionDigits",
  "maximumFractionDigits",
  "minimumSignificantDigits",
  "maximumSignificantDigits",
  "compactDisplay",
  "notation",
  "signDisplay",
  "unit",
  "unitDisplay",
  "roundingMode",
  "roundingPriority",
  "roundingIncrement",
  "trailingZeroDisplay"
];
function parseNumberArgs(...args) {
  const [arg1, arg2, arg3, arg4] = args;
  const options5 = create$1();
  let overrides = create$1();
  if (!isNumber$5(arg1)) {
    throw createCoreError(CoreErrorCodes.INVALID_ARGUMENT);
  }
  const value3 = arg1;
  if (isString$7(arg2)) {
    options5.key = arg2;
  } else if (isPlainObject$1(arg2)) {
    Object.keys(arg2).forEach((key) => {
      if (NUMBER_FORMAT_OPTIONS_KEYS.includes(key)) {
        overrides[key] = arg2[key];
      } else {
        options5[key] = arg2[key];
      }
    });
  }
  if (isString$7(arg3)) {
    options5.locale = arg3;
  } else if (isPlainObject$1(arg3)) {
    overrides = arg3;
  }
  if (isPlainObject$1(arg4)) {
    overrides = arg4;
  }
  return [options5.key || "", value3, options5, overrides];
}
__name(parseNumberArgs, "parseNumberArgs");
function clearNumberFormat(ctx, locale2, format2) {
  const context = ctx;
  for (const key in format2) {
    const id4 = `${locale2}__${key}`;
    if (!context.__numberFormatters.has(id4)) {
      continue;
    }
    context.__numberFormatters.delete(id4);
  }
}
__name(clearNumberFormat, "clearNumberFormat");
{
  initFeatureFlags$1();
}
/*!
  * vue-i18n v9.14.3
  * (c) 2025 kazuya kawaguchi
  * Released under the MIT License.
  */
const VERSION = "9.14.3";
function initFeatureFlags() {
  if (typeof __VUE_I18N_FULL_INSTALL__ !== "boolean") {
    getGlobalThis().__VUE_I18N_FULL_INSTALL__ = true;
  }
  if (typeof __VUE_I18N_LEGACY_API__ !== "boolean") {
    getGlobalThis().__VUE_I18N_LEGACY_API__ = true;
  }
  if (typeof __INTLIFY_JIT_COMPILATION__ !== "boolean") {
    getGlobalThis().__INTLIFY_JIT_COMPILATION__ = false;
  }
  if (typeof __INTLIFY_DROP_MESSAGE_COMPILER__ !== "boolean") {
    getGlobalThis().__INTLIFY_DROP_MESSAGE_COMPILER__ = false;
  }
  if (typeof __INTLIFY_PROD_DEVTOOLS__ !== "boolean") {
    getGlobalThis().__INTLIFY_PROD_DEVTOOLS__ = false;
  }
}
__name(initFeatureFlags, "initFeatureFlags");
const code$1$1 = CoreWarnCodes.__EXTEND_POINT__;
const inc$1 = incrementer(code$1$1);
const I18nWarnCodes = {
  FALLBACK_TO_ROOT: code$1$1,
  // 9
  NOT_SUPPORTED_PRESERVE: inc$1(),
  // 10
  NOT_SUPPORTED_FORMATTER: inc$1(),
  // 11
  NOT_SUPPORTED_PRESERVE_DIRECTIVE: inc$1(),
  // 12
  NOT_SUPPORTED_GET_CHOICE_INDEX: inc$1(),
  // 13
  COMPONENT_NAME_LEGACY_COMPATIBLE: inc$1(),
  // 14
  NOT_FOUND_PARENT_SCOPE: inc$1(),
  // 15
  IGNORE_OBJ_FLATTEN: inc$1(),
  // 16
  NOTICE_DROP_ALLOW_COMPOSITION: inc$1(),
  // 17
  NOTICE_DROP_TRANSLATE_EXIST_COMPATIBLE_FLAG: inc$1()
  // 18
};
const warnMessages = {
  [I18nWarnCodes.FALLBACK_TO_ROOT]: `Fall back to {type} '{key}' with root locale.`,
  [I18nWarnCodes.NOT_SUPPORTED_PRESERVE]: `Not supported 'preserve'.`,
  [I18nWarnCodes.NOT_SUPPORTED_FORMATTER]: `Not supported 'formatter'.`,
  [I18nWarnCodes.NOT_SUPPORTED_PRESERVE_DIRECTIVE]: `Not supported 'preserveDirectiveContent'.`,
  [I18nWarnCodes.NOT_SUPPORTED_GET_CHOICE_INDEX]: `Not supported 'getChoiceIndex'.`,
  [I18nWarnCodes.COMPONENT_NAME_LEGACY_COMPATIBLE]: `Component name legacy compatible: '{name}' -> 'i18n'`,
  [I18nWarnCodes.NOT_FOUND_PARENT_SCOPE]: `Not found parent scope. use the global scope.`,
  [I18nWarnCodes.IGNORE_OBJ_FLATTEN]: `Ignore object flatten: '{key}' key has an string value`,
  [I18nWarnCodes.NOTICE_DROP_ALLOW_COMPOSITION]: `'allowComposition' option will be dropped in the next major version. For more information, please see 👉 https://tinyurl.com/2p97mcze`,
  [I18nWarnCodes.NOTICE_DROP_TRANSLATE_EXIST_COMPATIBLE_FLAG]: `'translateExistCompatible' option will be dropped in the next major version.`
};
function getWarnMessage(code2, ...args) {
  return format$5(warnMessages[code2], ...args);
}
__name(getWarnMessage, "getWarnMessage");
const code$2 = CoreErrorCodes.__EXTEND_POINT__;
const inc = incrementer(code$2);
const I18nErrorCodes = {
  // composer module errors
  UNEXPECTED_RETURN_TYPE: code$2,
  // 24
  // legacy module errors
  INVALID_ARGUMENT: inc(),
  // 25
  // i18n module errors
  MUST_BE_CALL_SETUP_TOP: inc(),
  // 26
  NOT_INSTALLED: inc(),
  // 27
  NOT_AVAILABLE_IN_LEGACY_MODE: inc(),
  // 28
  // directive module errors
  REQUIRED_VALUE: inc(),
  // 29
  INVALID_VALUE: inc(),
  // 30
  // vue-devtools errors
  CANNOT_SETUP_VUE_DEVTOOLS_PLUGIN: inc(),
  // 31
  NOT_INSTALLED_WITH_PROVIDE: inc(),
  // 32
  // unexpected error
  UNEXPECTED_ERROR: inc(),
  // 33
  // not compatible legacy vue-i18n constructor
  NOT_COMPATIBLE_LEGACY_VUE_I18N: inc(),
  // 34
  // bridge support vue 2.x only
  BRIDGE_SUPPORT_VUE_2_ONLY: inc(),
  // 35
  // need to define `i18n` option in `allowComposition: true` and `useScope: 'local' at `useI18n``
  MUST_DEFINE_I18N_OPTION_IN_ALLOW_COMPOSITION: inc(),
  // 36
  // Not available Compostion API in Legacy API mode. Please make sure that the legacy API mode is working properly
  NOT_AVAILABLE_COMPOSITION_IN_LEGACY: inc(),
  // 37
  // for enhancement
  __EXTEND_POINT__: inc()
  // 38
};
function createI18nError(code2, ...args) {
  return createCompileError(code2, null, false ? { messages: errorMessages, args } : void 0);
}
__name(createI18nError, "createI18nError");
const errorMessages = {
  [I18nErrorCodes.UNEXPECTED_RETURN_TYPE]: "Unexpected return type in composer",
  [I18nErrorCodes.INVALID_ARGUMENT]: "Invalid argument",
  [I18nErrorCodes.MUST_BE_CALL_SETUP_TOP]: "Must be called at the top of a `setup` function",
  [I18nErrorCodes.NOT_INSTALLED]: "Need to install with `app.use` function",
  [I18nErrorCodes.UNEXPECTED_ERROR]: "Unexpected error",
  [I18nErrorCodes.NOT_AVAILABLE_IN_LEGACY_MODE]: "Not available in legacy mode",
  [I18nErrorCodes.REQUIRED_VALUE]: `Required in value: {0}`,
  [I18nErrorCodes.INVALID_VALUE]: `Invalid value`,
  [I18nErrorCodes.CANNOT_SETUP_VUE_DEVTOOLS_PLUGIN]: `Cannot setup vue-devtools plugin`,
  [I18nErrorCodes.NOT_INSTALLED_WITH_PROVIDE]: "Need to install with `provide` function",
  [I18nErrorCodes.NOT_COMPATIBLE_LEGACY_VUE_I18N]: "Not compatible legacy VueI18n.",
  [I18nErrorCodes.BRIDGE_SUPPORT_VUE_2_ONLY]: "vue-i18n-bridge support Vue 2.x only",
  [I18nErrorCodes.MUST_DEFINE_I18N_OPTION_IN_ALLOW_COMPOSITION]: "Must define ‘i18n’ option or custom block in Composition API with using local scope in Legacy API mode",
  [I18nErrorCodes.NOT_AVAILABLE_COMPOSITION_IN_LEGACY]: "Not available Compostion API in Legacy API mode. Please make sure that the legacy API mode is working properly"
};
const TranslateVNodeSymbol = /* @__PURE__ */ makeSymbol("__translateVNode");
const DatetimePartsSymbol = /* @__PURE__ */ makeSymbol("__datetimeParts");
const NumberPartsSymbol = /* @__PURE__ */ makeSymbol("__numberParts");
const EnableEmitter = /* @__PURE__ */ makeSymbol("__enableEmitter");
const DisableEmitter = /* @__PURE__ */ makeSymbol("__disableEmitter");
const SetPluralRulesSymbol = makeSymbol("__setPluralRules");
makeSymbol("__intlifyMeta");
const InejctWithOptionSymbol = /* @__PURE__ */ makeSymbol("__injectWithOption");
const DisposeSymbol = /* @__PURE__ */ makeSymbol("__dispose");
const __VUE_I18N_BRIDGE__ = "__VUE_I18N_BRIDGE__";
function handleFlatJson(obj) {
  if (!isObject$c(obj)) {
    return obj;
  }
  for (const key in obj) {
    if (!hasOwn$1(obj, key)) {
      continue;
    }
    if (!key.includes(".")) {
      if (isObject$c(obj[key])) {
        handleFlatJson(obj[key]);
      }
    } else {
      const subKeys = key.split(".");
      const lastIndex = subKeys.length - 1;
      let currentObj = obj;
      let hasStringValue = false;
      for (let i2 = 0; i2 < lastIndex; i2++) {
        if (subKeys[i2] === "__proto__") {
          throw new Error(`unsafe key: ${subKeys[i2]}`);
        }
        if (!(subKeys[i2] in currentObj)) {
          currentObj[subKeys[i2]] = create$1();
        }
        if (!isObject$c(currentObj[subKeys[i2]])) {
          hasStringValue = true;
          break;
        }
        currentObj = currentObj[subKeys[i2]];
      }
      if (!hasStringValue) {
        currentObj[subKeys[lastIndex]] = obj[key];
        delete obj[key];
      }
      if (isObject$c(currentObj[subKeys[lastIndex]])) {
        handleFlatJson(currentObj[subKeys[lastIndex]]);
      }
    }
  }
  return obj;
}
__name(handleFlatJson, "handleFlatJson");
function getLocaleMessages(locale2, options5) {
  const { messages: messages2, __i18n, messageResolver, flatJson } = options5;
  const ret = isPlainObject$1(messages2) ? messages2 : isArray$8(__i18n) ? create$1() : { [locale2]: create$1() };
  if (isArray$8(__i18n)) {
    __i18n.forEach((custom2) => {
      if ("locale" in custom2 && "resource" in custom2) {
        const { locale: locale22, resource } = custom2;
        if (locale22) {
          ret[locale22] = ret[locale22] || create$1();
          deepCopy(resource, ret[locale22]);
        } else {
          deepCopy(resource, ret);
        }
      } else {
        isString$7(custom2) && deepCopy(JSON.parse(custom2), ret);
      }
    });
  }
  if (messageResolver == null && flatJson) {
    for (const key in ret) {
      if (hasOwn$1(ret, key)) {
        handleFlatJson(ret[key]);
      }
    }
  }
  return ret;
}
__name(getLocaleMessages, "getLocaleMessages");
function getComponentOptions(instance) {
  return instance.type;
}
__name(getComponentOptions, "getComponentOptions");
function adjustI18nResources(gl, options5, componentOptions) {
  let messages2 = isObject$c(options5.messages) ? options5.messages : create$1();
  if ("__i18nGlobal" in componentOptions) {
    messages2 = getLocaleMessages(gl.locale.value, {
      messages: messages2,
      __i18n: componentOptions.__i18nGlobal
    });
  }
  const locales = Object.keys(messages2);
  if (locales.length) {
    locales.forEach((locale2) => {
      gl.mergeLocaleMessage(locale2, messages2[locale2]);
    });
  }
  {
    if (isObject$c(options5.datetimeFormats)) {
      const locales2 = Object.keys(options5.datetimeFormats);
      if (locales2.length) {
        locales2.forEach((locale2) => {
          gl.mergeDateTimeFormat(locale2, options5.datetimeFormats[locale2]);
        });
      }
    }
    if (isObject$c(options5.numberFormats)) {
      const locales2 = Object.keys(options5.numberFormats);
      if (locales2.length) {
        locales2.forEach((locale2) => {
          gl.mergeNumberFormat(locale2, options5.numberFormats[locale2]);
        });
      }
    }
  }
}
__name(adjustI18nResources, "adjustI18nResources");
function createTextNode(key) {
  return createVNode(Text$4, null, key, 0);
}
__name(createTextNode, "createTextNode");
const DEVTOOLS_META = "__INTLIFY_META__";
const NOOP_RETURN_ARRAY = /* @__PURE__ */ __name(() => [], "NOOP_RETURN_ARRAY");
const NOOP_RETURN_FALSE = /* @__PURE__ */ __name(() => false, "NOOP_RETURN_FALSE");
let composerID = 0;
function defineCoreMissingHandler(missing) {
  return (ctx, locale2, key, type) => {
    return missing(locale2, key, getCurrentInstance() || void 0, type);
  };
}
__name(defineCoreMissingHandler, "defineCoreMissingHandler");
const getMetaInfo = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ () => {
  const instance = getCurrentInstance();
  let meta = null;
  return instance && (meta = getComponentOptions(instance)[DEVTOOLS_META]) ? { [DEVTOOLS_META]: meta } : null;
}, "getMetaInfo");
function createComposer(options5 = {}, VueI18nLegacy) {
  const { __root, __injectWithOption } = options5;
  const _isGlobal = __root === void 0;
  const flatJson = options5.flatJson;
  const _ref = inBrowser ? ref : shallowRef;
  const translateExistCompatible = !!options5.translateExistCompatible;
  if (false) {
    if (translateExistCompatible && true) {
      warnOnce(getWarnMessage(I18nWarnCodes.NOTICE_DROP_TRANSLATE_EXIST_COMPATIBLE_FLAG));
    }
  }
  let _inheritLocale = isBoolean$1(options5.inheritLocale) ? options5.inheritLocale : true;
  const _locale = _ref(
    // prettier-ignore
    __root && _inheritLocale ? __root.locale.value : isString$7(options5.locale) ? options5.locale : DEFAULT_LOCALE
  );
  const _fallbackLocale = _ref(
    // prettier-ignore
    __root && _inheritLocale ? __root.fallbackLocale.value : isString$7(options5.fallbackLocale) || isArray$8(options5.fallbackLocale) || isPlainObject$1(options5.fallbackLocale) || options5.fallbackLocale === false ? options5.fallbackLocale : _locale.value
  );
  const _messages = _ref(getLocaleMessages(_locale.value, options5));
  const _datetimeFormats = _ref(isPlainObject$1(options5.datetimeFormats) ? options5.datetimeFormats : { [_locale.value]: {} });
  const _numberFormats = _ref(isPlainObject$1(options5.numberFormats) ? options5.numberFormats : { [_locale.value]: {} });
  let _missingWarn = __root ? __root.missingWarn : isBoolean$1(options5.missingWarn) || isRegExp$2(options5.missingWarn) ? options5.missingWarn : true;
  let _fallbackWarn = __root ? __root.fallbackWarn : isBoolean$1(options5.fallbackWarn) || isRegExp$2(options5.fallbackWarn) ? options5.fallbackWarn : true;
  let _fallbackRoot = __root ? __root.fallbackRoot : isBoolean$1(options5.fallbackRoot) ? options5.fallbackRoot : true;
  let _fallbackFormat = !!options5.fallbackFormat;
  let _missing = isFunction$9(options5.missing) ? options5.missing : null;
  let _runtimeMissing = isFunction$9(options5.missing) ? defineCoreMissingHandler(options5.missing) : null;
  let _postTranslation = isFunction$9(options5.postTranslation) ? options5.postTranslation : null;
  let _warnHtmlMessage = __root ? __root.warnHtmlMessage : isBoolean$1(options5.warnHtmlMessage) ? options5.warnHtmlMessage : true;
  let _escapeParameter = !!options5.escapeParameter;
  const _modifiers = __root ? __root.modifiers : isPlainObject$1(options5.modifiers) ? options5.modifiers : {};
  let _pluralRules = options5.pluralRules || __root && __root.pluralRules;
  let _context;
  const getCoreContext = /* @__PURE__ */ __name(() => {
    _isGlobal && setFallbackContext(null);
    const ctxOptions = {
      version: VERSION,
      locale: _locale.value,
      fallbackLocale: _fallbackLocale.value,
      messages: _messages.value,
      modifiers: _modifiers,
      pluralRules: _pluralRules,
      missing: _runtimeMissing === null ? void 0 : _runtimeMissing,
      missingWarn: _missingWarn,
      fallbackWarn: _fallbackWarn,
      fallbackFormat: _fallbackFormat,
      unresolving: true,
      postTranslation: _postTranslation === null ? void 0 : _postTranslation,
      warnHtmlMessage: _warnHtmlMessage,
      escapeParameter: _escapeParameter,
      messageResolver: options5.messageResolver,
      messageCompiler: options5.messageCompiler,
      __meta: { framework: "vue" }
    };
    {
      ctxOptions.datetimeFormats = _datetimeFormats.value;
      ctxOptions.numberFormats = _numberFormats.value;
      ctxOptions.__datetimeFormatters = isPlainObject$1(_context) ? _context.__datetimeFormatters : void 0;
      ctxOptions.__numberFormatters = isPlainObject$1(_context) ? _context.__numberFormatters : void 0;
    }
    if (false) {
      ctxOptions.__v_emitter = isPlainObject$1(_context) ? _context.__v_emitter : void 0;
    }
    const ctx = createCoreContext(ctxOptions);
    _isGlobal && setFallbackContext(ctx);
    return ctx;
  }, "getCoreContext");
  _context = getCoreContext();
  updateFallbackLocale(_context, _locale.value, _fallbackLocale.value);
  function trackReactivityValues() {
    return [
      _locale.value,
      _fallbackLocale.value,
      _messages.value,
      _datetimeFormats.value,
      _numberFormats.value
    ];
  }
  __name(trackReactivityValues, "trackReactivityValues");
  const locale2 = computed({
    get: /* @__PURE__ */ __name(() => _locale.value, "get"),
    set: /* @__PURE__ */ __name((val) => {
      _locale.value = val;
      _context.locale = _locale.value;
    }, "set")
  });
  const fallbackLocale = computed({
    get: /* @__PURE__ */ __name(() => _fallbackLocale.value, "get"),
    set: /* @__PURE__ */ __name((val) => {
      _fallbackLocale.value = val;
      _context.fallbackLocale = _fallbackLocale.value;
      updateFallbackLocale(_context, _locale.value, val);
    }, "set")
  });
  const messages2 = computed(() => _messages.value);
  const datetimeFormats = /* @__PURE__ */ computed(() => _datetimeFormats.value);
  const numberFormats = /* @__PURE__ */ computed(() => _numberFormats.value);
  function getPostTranslationHandler() {
    return isFunction$9(_postTranslation) ? _postTranslation : null;
  }
  __name(getPostTranslationHandler, "getPostTranslationHandler");
  function setPostTranslationHandler(handler14) {
    _postTranslation = handler14;
    _context.postTranslation = handler14;
  }
  __name(setPostTranslationHandler, "setPostTranslationHandler");
  function getMissingHandler() {
    return _missing;
  }
  __name(getMissingHandler, "getMissingHandler");
  function setMissingHandler(handler14) {
    if (handler14 !== null) {
      _runtimeMissing = defineCoreMissingHandler(handler14);
    }
    _missing = handler14;
    _context.missing = _runtimeMissing;
  }
  __name(setMissingHandler, "setMissingHandler");
  function isResolvedTranslateMessage(type, arg) {
    return type !== "translate" || !arg.resolvedMessage;
  }
  __name(isResolvedTranslateMessage, "isResolvedTranslateMessage");
  const wrapWithDeps = /* @__PURE__ */ __name((fn, argumentParser, warnType, fallbackSuccess, fallbackFail, successCondition) => {
    trackReactivityValues();
    let ret;
    try {
      if (__INTLIFY_PROD_DEVTOOLS__) {
        /* @__PURE__ */ setAdditionalMeta(/* @__PURE__ */ getMetaInfo());
      }
      if (!_isGlobal) {
        _context.fallbackContext = __root ? getFallbackContext() : void 0;
      }
      ret = fn(_context);
    } finally {
      if (__INTLIFY_PROD_DEVTOOLS__) {
        /* @__PURE__ */ setAdditionalMeta(null);
      }
      if (!_isGlobal) {
        _context.fallbackContext = void 0;
      }
    }
    if (warnType !== "translate exists" && // for not `te` (e.g `t`)
    isNumber$5(ret) && ret === NOT_REOSLVED || warnType === "translate exists" && !ret) {
      const [key, arg2] = argumentParser();
      if (false) {
        if (_fallbackRoot && (isTranslateFallbackWarn(_fallbackWarn, key) || isTranslateMissingWarn(_missingWarn, key))) {
          warn$1(getWarnMessage(I18nWarnCodes.FALLBACK_TO_ROOT, {
            key,
            type: warnType
          }));
        }
        if (false) {
          const { __v_emitter: emitter } = _context;
          if (emitter && _fallbackRoot) {
            emitter.emit("fallback", {
              type: warnType,
              key,
              to: "global",
              groupId: `${warnType}:${key}`
            });
          }
        }
      }
      return __root && _fallbackRoot ? fallbackSuccess(__root) : fallbackFail(key);
    } else if (successCondition(ret)) {
      return ret;
    } else {
      throw createI18nError(I18nErrorCodes.UNEXPECTED_RETURN_TYPE);
    }
  }, "wrapWithDeps");
  function t2(...args) {
    return wrapWithDeps((context) => Reflect.apply(translate, null, [context, ...args]), () => parseTranslateArgs(...args), "translate", (root34) => Reflect.apply(root34.t, root34, [...args]), (key) => key, (val) => isString$7(val));
  }
  __name(t2, "t");
  function rt(...args) {
    const [arg1, arg2, arg3] = args;
    if (arg3 && !isObject$c(arg3)) {
      throw createI18nError(I18nErrorCodes.INVALID_ARGUMENT);
    }
    return t2(...[arg1, arg2, assign$4({ resolvedMessage: true }, arg3 || {})]);
  }
  __name(rt, "rt");
  function d2(...args) {
    return wrapWithDeps((context) => Reflect.apply(datetime, null, [context, ...args]), () => parseDateTimeArgs(...args), "datetime format", (root34) => Reflect.apply(root34.d, root34, [...args]), () => MISSING_RESOLVE_VALUE, (val) => isString$7(val));
  }
  __name(d2, "d");
  function n2(...args) {
    return wrapWithDeps((context) => Reflect.apply(number, null, [context, ...args]), () => parseNumberArgs(...args), "number format", (root34) => Reflect.apply(root34.n, root34, [...args]), () => MISSING_RESOLVE_VALUE, (val) => isString$7(val));
  }
  __name(n2, "n");
  function normalize3(values) {
    return values.map((val) => isString$7(val) || isNumber$5(val) || isBoolean$1(val) ? createTextNode(String(val)) : val);
  }
  __name(normalize3, "normalize");
  const interpolate = /* @__PURE__ */ __name((val) => val, "interpolate");
  const processor = {
    normalize: normalize3,
    interpolate,
    type: "vnode"
  };
  function translateVNode(...args) {
    return wrapWithDeps(
      (context) => {
        let ret;
        const _context2 = context;
        try {
          _context2.processor = processor;
          ret = Reflect.apply(translate, null, [_context2, ...args]);
        } finally {
          _context2.processor = null;
        }
        return ret;
      },
      () => parseTranslateArgs(...args),
      "translate",
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      (root34) => root34[TranslateVNodeSymbol](...args),
      (key) => [createTextNode(key)],
      (val) => isArray$8(val)
    );
  }
  __name(translateVNode, "translateVNode");
  function numberParts(...args) {
    return wrapWithDeps(
      (context) => Reflect.apply(number, null, [context, ...args]),
      () => parseNumberArgs(...args),
      "number format",
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      (root34) => root34[NumberPartsSymbol](...args),
      NOOP_RETURN_ARRAY,
      (val) => isString$7(val) || isArray$8(val)
    );
  }
  __name(numberParts, "numberParts");
  function datetimeParts(...args) {
    return wrapWithDeps(
      (context) => Reflect.apply(datetime, null, [context, ...args]),
      () => parseDateTimeArgs(...args),
      "datetime format",
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      (root34) => root34[DatetimePartsSymbol](...args),
      NOOP_RETURN_ARRAY,
      (val) => isString$7(val) || isArray$8(val)
    );
  }
  __name(datetimeParts, "datetimeParts");
  function setPluralRules(rules) {
    _pluralRules = rules;
    _context.pluralRules = _pluralRules;
  }
  __name(setPluralRules, "setPluralRules");
  function te2(key, locale22) {
    return wrapWithDeps(() => {
      if (!key) {
        return false;
      }
      const targetLocale = isString$7(locale22) ? locale22 : _locale.value;
      const message3 = getLocaleMessage(targetLocale);
      const resolved = _context.messageResolver(message3, key);
      return !translateExistCompatible ? isMessageAST(resolved) || isMessageFunction(resolved) || isString$7(resolved) : resolved != null;
    }, () => [key], "translate exists", (root34) => {
      return Reflect.apply(root34.te, root34, [key, locale22]);
    }, NOOP_RETURN_FALSE, (val) => isBoolean$1(val));
  }
  __name(te2, "te");
  function resolveMessages(key) {
    let messages22 = null;
    const locales = fallbackWithLocaleChain(_context, _fallbackLocale.value, _locale.value);
    for (let i2 = 0; i2 < locales.length; i2++) {
      const targetLocaleMessages = _messages.value[locales[i2]] || {};
      const messageValue = _context.messageResolver(targetLocaleMessages, key);
      if (messageValue != null) {
        messages22 = messageValue;
        break;
      }
    }
    return messages22;
  }
  __name(resolveMessages, "resolveMessages");
  function tm(key) {
    const messages22 = resolveMessages(key);
    return messages22 != null ? messages22 : __root ? __root.tm(key) || {} : {};
  }
  __name(tm, "tm");
  function getLocaleMessage(locale22) {
    return _messages.value[locale22] || {};
  }
  __name(getLocaleMessage, "getLocaleMessage");
  function setLocaleMessage(locale22, message3) {
    if (flatJson) {
      const _message = { [locale22]: message3 };
      for (const key in _message) {
        if (hasOwn$1(_message, key)) {
          handleFlatJson(_message[key]);
        }
      }
      message3 = _message[locale22];
    }
    _messages.value[locale22] = message3;
    _context.messages = _messages.value;
  }
  __name(setLocaleMessage, "setLocaleMessage");
  function mergeLocaleMessage(locale22, message3) {
    _messages.value[locale22] = _messages.value[locale22] || {};
    const _message = { [locale22]: message3 };
    if (flatJson) {
      for (const key in _message) {
        if (hasOwn$1(_message, key)) {
          handleFlatJson(_message[key]);
        }
      }
    }
    message3 = _message[locale22];
    deepCopy(message3, _messages.value[locale22]);
    _context.messages = _messages.value;
  }
  __name(mergeLocaleMessage, "mergeLocaleMessage");
  function getDateTimeFormat(locale22) {
    return _datetimeFormats.value[locale22] || {};
  }
  __name(getDateTimeFormat, "getDateTimeFormat");
  function setDateTimeFormat(locale22, format2) {
    _datetimeFormats.value[locale22] = format2;
    _context.datetimeFormats = _datetimeFormats.value;
    clearDateTimeFormat(_context, locale22, format2);
  }
  __name(setDateTimeFormat, "setDateTimeFormat");
  function mergeDateTimeFormat(locale22, format2) {
    _datetimeFormats.value[locale22] = assign$4(_datetimeFormats.value[locale22] || {}, format2);
    _context.datetimeFormats = _datetimeFormats.value;
    clearDateTimeFormat(_context, locale22, format2);
  }
  __name(mergeDateTimeFormat, "mergeDateTimeFormat");
  function getNumberFormat(locale22) {
    return _numberFormats.value[locale22] || {};
  }
  __name(getNumberFormat, "getNumberFormat");
  function setNumberFormat(locale22, format2) {
    _numberFormats.value[locale22] = format2;
    _context.numberFormats = _numberFormats.value;
    clearNumberFormat(_context, locale22, format2);
  }
  __name(setNumberFormat, "setNumberFormat");
  function mergeNumberFormat(locale22, format2) {
    _numberFormats.value[locale22] = assign$4(_numberFormats.value[locale22] || {}, format2);
    _context.numberFormats = _numberFormats.value;
    clearNumberFormat(_context, locale22, format2);
  }
  __name(mergeNumberFormat, "mergeNumberFormat");
  composerID++;
  if (__root && inBrowser) {
    watch(__root.locale, (val) => {
      if (_inheritLocale) {
        _locale.value = val;
        _context.locale = val;
        updateFallbackLocale(_context, _locale.value, _fallbackLocale.value);
      }
    });
    watch(__root.fallbackLocale, (val) => {
      if (_inheritLocale) {
        _fallbackLocale.value = val;
        _context.fallbackLocale = val;
        updateFallbackLocale(_context, _locale.value, _fallbackLocale.value);
      }
    });
  }
  const composer = {
    id: composerID,
    locale: locale2,
    fallbackLocale,
    get inheritLocale() {
      return _inheritLocale;
    },
    set inheritLocale(val) {
      _inheritLocale = val;
      if (val && __root) {
        _locale.value = __root.locale.value;
        _fallbackLocale.value = __root.fallbackLocale.value;
        updateFallbackLocale(_context, _locale.value, _fallbackLocale.value);
      }
    },
    get availableLocales() {
      return Object.keys(_messages.value).sort();
    },
    messages: messages2,
    get modifiers() {
      return _modifiers;
    },
    get pluralRules() {
      return _pluralRules || {};
    },
    get isGlobal() {
      return _isGlobal;
    },
    get missingWarn() {
      return _missingWarn;
    },
    set missingWarn(val) {
      _missingWarn = val;
      _context.missingWarn = _missingWarn;
    },
    get fallbackWarn() {
      return _fallbackWarn;
    },
    set fallbackWarn(val) {
      _fallbackWarn = val;
      _context.fallbackWarn = _fallbackWarn;
    },
    get fallbackRoot() {
      return _fallbackRoot;
    },
    set fallbackRoot(val) {
      _fallbackRoot = val;
    },
    get fallbackFormat() {
      return _fallbackFormat;
    },
    set fallbackFormat(val) {
      _fallbackFormat = val;
      _context.fallbackFormat = _fallbackFormat;
    },
    get warnHtmlMessage() {
      return _warnHtmlMessage;
    },
    set warnHtmlMessage(val) {
      _warnHtmlMessage = val;
      _context.warnHtmlMessage = val;
    },
    get escapeParameter() {
      return _escapeParameter;
    },
    set escapeParameter(val) {
      _escapeParameter = val;
      _context.escapeParameter = val;
    },
    t: t2,
    getLocaleMessage,
    setLocaleMessage,
    mergeLocaleMessage,
    getPostTranslationHandler,
    setPostTranslationHandler,
    getMissingHandler,
    setMissingHandler,
    [SetPluralRulesSymbol]: setPluralRules
  };
  {
    composer.datetimeFormats = datetimeFormats;
    composer.numberFormats = numberFormats;
    composer.rt = rt;
    composer.te = te2;
    composer.tm = tm;
    composer.d = d2;
    composer.n = n2;
    composer.getDateTimeFormat = getDateTimeFormat;
    composer.setDateTimeFormat = setDateTimeFormat;
    composer.mergeDateTimeFormat = mergeDateTimeFormat;
    composer.getNumberFormat = getNumberFormat;
    composer.setNumberFormat = setNumberFormat;
    composer.mergeNumberFormat = mergeNumberFormat;
    composer[InejctWithOptionSymbol] = __injectWithOption;
    composer[TranslateVNodeSymbol] = translateVNode;
    composer[DatetimePartsSymbol] = datetimeParts;
    composer[NumberPartsSymbol] = numberParts;
  }
  if (false) {
    composer[EnableEmitter] = (emitter) => {
      _context.__v_emitter = emitter;
    };
    composer[DisableEmitter] = () => {
      _context.__v_emitter = void 0;
    };
  }
  return composer;
}
__name(createComposer, "createComposer");
function convertComposerOptions(options5) {
  const locale2 = isString$7(options5.locale) ? options5.locale : DEFAULT_LOCALE;
  const fallbackLocale = isString$7(options5.fallbackLocale) || isArray$8(options5.fallbackLocale) || isPlainObject$1(options5.fallbackLocale) || options5.fallbackLocale === false ? options5.fallbackLocale : locale2;
  const missing = isFunction$9(options5.missing) ? options5.missing : void 0;
  const missingWarn = isBoolean$1(options5.silentTranslationWarn) || isRegExp$2(options5.silentTranslationWarn) ? !options5.silentTranslationWarn : true;
  const fallbackWarn = isBoolean$1(options5.silentFallbackWarn) || isRegExp$2(options5.silentFallbackWarn) ? !options5.silentFallbackWarn : true;
  const fallbackRoot = isBoolean$1(options5.fallbackRoot) ? options5.fallbackRoot : true;
  const fallbackFormat = !!options5.formatFallbackMessages;
  const modifiers2 = isPlainObject$1(options5.modifiers) ? options5.modifiers : {};
  const pluralizationRules = options5.pluralizationRules;
  const postTranslation = isFunction$9(options5.postTranslation) ? options5.postTranslation : void 0;
  const warnHtmlMessage = isString$7(options5.warnHtmlInMessage) ? options5.warnHtmlInMessage !== "off" : true;
  const escapeParameter = !!options5.escapeParameterHtml;
  const inheritLocale = isBoolean$1(options5.sync) ? options5.sync : true;
  if (false) {
    warn$1(getWarnMessage(I18nWarnCodes.NOT_SUPPORTED_FORMATTER));
  }
  if (false) {
    warn$1(getWarnMessage(I18nWarnCodes.NOT_SUPPORTED_PRESERVE_DIRECTIVE));
  }
  let messages2 = options5.messages;
  if (isPlainObject$1(options5.sharedMessages)) {
    const sharedMessages = options5.sharedMessages;
    const locales = Object.keys(sharedMessages);
    messages2 = locales.reduce((messages22, locale22) => {
      const message3 = messages22[locale22] || (messages22[locale22] = {});
      assign$4(message3, sharedMessages[locale22]);
      return messages22;
    }, messages2 || {});
  }
  const { __i18n, __root, __injectWithOption } = options5;
  const datetimeFormats = options5.datetimeFormats;
  const numberFormats = options5.numberFormats;
  const flatJson = options5.flatJson;
  const translateExistCompatible = options5.translateExistCompatible;
  return {
    locale: locale2,
    fallbackLocale,
    messages: messages2,
    flatJson,
    datetimeFormats,
    numberFormats,
    missing,
    missingWarn,
    fallbackWarn,
    fallbackRoot,
    fallbackFormat,
    modifiers: modifiers2,
    pluralRules: pluralizationRules,
    postTranslation,
    warnHtmlMessage,
    escapeParameter,
    messageResolver: options5.messageResolver,
    inheritLocale,
    translateExistCompatible,
    __i18n,
    __root,
    __injectWithOption
  };
}
__name(convertComposerOptions, "convertComposerOptions");
function createVueI18n(options5 = {}, VueI18nLegacy) {
  {
    const composer = createComposer(convertComposerOptions(options5));
    const { __extender } = options5;
    const vueI18n = {
      // id
      id: composer.id,
      // locale
      get locale() {
        return composer.locale.value;
      },
      set locale(val) {
        composer.locale.value = val;
      },
      // fallbackLocale
      get fallbackLocale() {
        return composer.fallbackLocale.value;
      },
      set fallbackLocale(val) {
        composer.fallbackLocale.value = val;
      },
      // messages
      get messages() {
        return composer.messages.value;
      },
      // datetimeFormats
      get datetimeFormats() {
        return composer.datetimeFormats.value;
      },
      // numberFormats
      get numberFormats() {
        return composer.numberFormats.value;
      },
      // availableLocales
      get availableLocales() {
        return composer.availableLocales;
      },
      // formatter
      get formatter() {
        return {
          interpolate() {
            return [];
          }
        };
      },
      set formatter(val) {
      },
      // missing
      get missing() {
        return composer.getMissingHandler();
      },
      set missing(handler14) {
        composer.setMissingHandler(handler14);
      },
      // silentTranslationWarn
      get silentTranslationWarn() {
        return isBoolean$1(composer.missingWarn) ? !composer.missingWarn : composer.missingWarn;
      },
      set silentTranslationWarn(val) {
        composer.missingWarn = isBoolean$1(val) ? !val : val;
      },
      // silentFallbackWarn
      get silentFallbackWarn() {
        return isBoolean$1(composer.fallbackWarn) ? !composer.fallbackWarn : composer.fallbackWarn;
      },
      set silentFallbackWarn(val) {
        composer.fallbackWarn = isBoolean$1(val) ? !val : val;
      },
      // modifiers
      get modifiers() {
        return composer.modifiers;
      },
      // formatFallbackMessages
      get formatFallbackMessages() {
        return composer.fallbackFormat;
      },
      set formatFallbackMessages(val) {
        composer.fallbackFormat = val;
      },
      // postTranslation
      get postTranslation() {
        return composer.getPostTranslationHandler();
      },
      set postTranslation(handler14) {
        composer.setPostTranslationHandler(handler14);
      },
      // sync
      get sync() {
        return composer.inheritLocale;
      },
      set sync(val) {
        composer.inheritLocale = val;
      },
      // warnInHtmlMessage
      get warnHtmlInMessage() {
        return composer.warnHtmlMessage ? "warn" : "off";
      },
      set warnHtmlInMessage(val) {
        composer.warnHtmlMessage = val !== "off";
      },
      // escapeParameterHtml
      get escapeParameterHtml() {
        return composer.escapeParameter;
      },
      set escapeParameterHtml(val) {
        composer.escapeParameter = val;
      },
      // preserveDirectiveContent
      get preserveDirectiveContent() {
        return true;
      },
      set preserveDirectiveContent(val) {
      },
      // pluralizationRules
      get pluralizationRules() {
        return composer.pluralRules || {};
      },
      // for internal
      __composer: composer,
      // t
      t(...args) {
        const [arg1, arg2, arg3] = args;
        const options22 = {};
        let list2 = null;
        let named = null;
        if (!isString$7(arg1)) {
          throw createI18nError(I18nErrorCodes.INVALID_ARGUMENT);
        }
        const key = arg1;
        if (isString$7(arg2)) {
          options22.locale = arg2;
        } else if (isArray$8(arg2)) {
          list2 = arg2;
        } else if (isPlainObject$1(arg2)) {
          named = arg2;
        }
        if (isArray$8(arg3)) {
          list2 = arg3;
        } else if (isPlainObject$1(arg3)) {
          named = arg3;
        }
        return Reflect.apply(composer.t, composer, [
          key,
          list2 || named || {},
          options22
        ]);
      },
      rt(...args) {
        return Reflect.apply(composer.rt, composer, [...args]);
      },
      // tc
      tc(...args) {
        const [arg1, arg2, arg3] = args;
        const options22 = { plural: 1 };
        let list2 = null;
        let named = null;
        if (!isString$7(arg1)) {
          throw createI18nError(I18nErrorCodes.INVALID_ARGUMENT);
        }
        const key = arg1;
        if (isString$7(arg2)) {
          options22.locale = arg2;
        } else if (isNumber$5(arg2)) {
          options22.plural = arg2;
        } else if (isArray$8(arg2)) {
          list2 = arg2;
        } else if (isPlainObject$1(arg2)) {
          named = arg2;
        }
        if (isString$7(arg3)) {
          options22.locale = arg3;
        } else if (isArray$8(arg3)) {
          list2 = arg3;
        } else if (isPlainObject$1(arg3)) {
          named = arg3;
        }
        return Reflect.apply(composer.t, composer, [
          key,
          list2 || named || {},
          options22
        ]);
      },
      // te
      te(key, locale2) {
        return composer.te(key, locale2);
      },
      // tm
      tm(key) {
        return composer.tm(key);
      },
      // getLocaleMessage
      getLocaleMessage(locale2) {
        return composer.getLocaleMessage(locale2);
      },
      // setLocaleMessage
      setLocaleMessage(locale2, message3) {
        composer.setLocaleMessage(locale2, message3);
      },
      // mergeLocaleMessage
      mergeLocaleMessage(locale2, message3) {
        composer.mergeLocaleMessage(locale2, message3);
      },
      // d
      d(...args) {
        return Reflect.apply(composer.d, composer, [...args]);
      },
      // getDateTimeFormat
      getDateTimeFormat(locale2) {
        return composer.getDateTimeFormat(locale2);
      },
      // setDateTimeFormat
      setDateTimeFormat(locale2, format2) {
        composer.setDateTimeFormat(locale2, format2);
      },
      // mergeDateTimeFormat
      mergeDateTimeFormat(locale2, format2) {
        composer.mergeDateTimeFormat(locale2, format2);
      },
      // n
      n(...args) {
        return Reflect.apply(composer.n, composer, [...args]);
      },
      // getNumberFormat
      getNumberFormat(locale2) {
        return composer.getNumberFormat(locale2);
      },
      // setNumberFormat
      setNumberFormat(locale2, format2) {
        composer.setNumberFormat(locale2, format2);
      },
      // mergeNumberFormat
      mergeNumberFormat(locale2, format2) {
        composer.mergeNumberFormat(locale2, format2);
      },
      // getChoiceIndex
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      getChoiceIndex(choice, choicesLength) {
        return -1;
      }
    };
    vueI18n.__extender = __extender;
    if (false) {
      vueI18n.__enableEmitter = (emitter) => {
        const __composer = composer;
        __composer[EnableEmitter] && __composer[EnableEmitter](emitter);
      };
      vueI18n.__disableEmitter = () => {
        const __composer = composer;
        __composer[DisableEmitter] && __composer[DisableEmitter]();
      };
    }
    return vueI18n;
  }
}
__name(createVueI18n, "createVueI18n");
const baseFormatProps = {
  tag: {
    type: [String, Object]
  },
  locale: {
    type: String
  },
  scope: {
    type: String,
    // NOTE: avoid https://github.com/microsoft/rushstack/issues/1050
    validator: /* @__PURE__ */ __name((val) => val === "parent" || val === "global", "validator"),
    default: "parent"
    /* ComponentI18nScope */
  },
  i18n: {
    type: Object
  }
};
function getInterpolateArg({ slots }, keys2) {
  if (keys2.length === 1 && keys2[0] === "default") {
    const ret = slots.default ? slots.default() : [];
    return ret.reduce((slot, current) => {
      return [
        ...slot,
        // prettier-ignore
        ...current.type === Fragment$1 ? current.children : [current]
      ];
    }, []);
  } else {
    return keys2.reduce((arg, key) => {
      const slot = slots[key];
      if (slot) {
        arg[key] = slot();
      }
      return arg;
    }, create$1());
  }
}
__name(getInterpolateArg, "getInterpolateArg");
function getFragmentableTag(tag) {
  return Fragment$1;
}
__name(getFragmentableTag, "getFragmentableTag");
const TranslationImpl = /* @__PURE__ */ defineComponent({
  /* eslint-disable */
  name: "i18n-t",
  props: assign$4({
    keypath: {
      type: String,
      required: true
    },
    plural: {
      type: [Number, String],
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      validator: /* @__PURE__ */ __name((val) => isNumber$5(val) || !isNaN(val), "validator")
    }
  }, baseFormatProps),
  /* eslint-enable */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setup(props, context) {
    const { slots, attrs: attrs7 } = context;
    const i18n2 = props.i18n || useI18n({
      useScope: props.scope,
      __useComponent: true
    });
    return () => {
      const keys2 = Object.keys(slots).filter((key) => key !== "_");
      const options5 = create$1();
      if (props.locale) {
        options5.locale = props.locale;
      }
      if (props.plural !== void 0) {
        options5.plural = isString$7(props.plural) ? +props.plural : props.plural;
      }
      const arg = getInterpolateArg(context, keys2);
      const children = i18n2[TranslateVNodeSymbol](props.keypath, arg, options5);
      const assignedAttrs = assign$4(create$1(), attrs7);
      const tag = isString$7(props.tag) || isObject$c(props.tag) ? props.tag : getFragmentableTag();
      return h(tag, assignedAttrs, children);
    };
  }
});
const Translation = TranslationImpl;
const I18nT = Translation;
function isVNode(target2) {
  return isArray$8(target2) && !isString$7(target2[0]);
}
__name(isVNode, "isVNode");
function renderFormatter(props, context, slotKeys, partFormatter) {
  const { slots, attrs: attrs7 } = context;
  return () => {
    const options5 = { part: true };
    let overrides = create$1();
    if (props.locale) {
      options5.locale = props.locale;
    }
    if (isString$7(props.format)) {
      options5.key = props.format;
    } else if (isObject$c(props.format)) {
      if (isString$7(props.format.key)) {
        options5.key = props.format.key;
      }
      overrides = Object.keys(props.format).reduce((options22, prop2) => {
        return slotKeys.includes(prop2) ? assign$4(create$1(), options22, { [prop2]: props.format[prop2] }) : options22;
      }, create$1());
    }
    const parts2 = partFormatter(...[props.value, options5, overrides]);
    let children = [options5.key];
    if (isArray$8(parts2)) {
      children = parts2.map((part, index2) => {
        const slot = slots[part.type];
        const node3 = slot ? slot({ [part.type]: part.value, index: index2, parts: parts2 }) : [part.value];
        if (isVNode(node3)) {
          node3[0].key = `${part.type}-${index2}`;
        }
        return node3;
      });
    } else if (isString$7(parts2)) {
      children = [parts2];
    }
    const assignedAttrs = assign$4(create$1(), attrs7);
    const tag = isString$7(props.tag) || isObject$c(props.tag) ? props.tag : getFragmentableTag();
    return h(tag, assignedAttrs, children);
  };
}
__name(renderFormatter, "renderFormatter");
const NumberFormatImpl = /* @__PURE__ */ defineComponent({
  /* eslint-disable */
  name: "i18n-n",
  props: assign$4({
    value: {
      type: Number,
      required: true
    },
    format: {
      type: [String, Object]
    }
  }, baseFormatProps),
  /* eslint-enable */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setup(props, context) {
    const i18n2 = props.i18n || useI18n({
      useScope: props.scope,
      __useComponent: true
    });
    return renderFormatter(props, context, NUMBER_FORMAT_OPTIONS_KEYS, (...args) => (
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      i18n2[NumberPartsSymbol](...args)
    ));
  }
});
const NumberFormat = NumberFormatImpl;
const I18nN = NumberFormat;
const DatetimeFormatImpl = /* @__PURE__ */ defineComponent({
  /* eslint-disable */
  name: "i18n-d",
  props: assign$4({
    value: {
      type: [Number, Date],
      required: true
    },
    format: {
      type: [String, Object]
    }
  }, baseFormatProps),
  /* eslint-enable */
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  setup(props, context) {
    const i18n2 = props.i18n || useI18n({
      useScope: props.scope,
      __useComponent: true
    });
    return renderFormatter(props, context, DATETIME_FORMAT_OPTIONS_KEYS, (...args) => (
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      i18n2[DatetimePartsSymbol](...args)
    ));
  }
});
const DatetimeFormat = DatetimeFormatImpl;
const I18nD = DatetimeFormat;
function getComposer$2(i18n2, instance) {
  const i18nInternal = i18n2;
  if (i18n2.mode === "composition") {
    return i18nInternal.__getInstance(instance) || i18n2.global;
  } else {
    const vueI18n = i18nInternal.__getInstance(instance);
    return vueI18n != null ? vueI18n.__composer : i18n2.global.__composer;
  }
}
__name(getComposer$2, "getComposer$2");
function vTDirective(i18n2) {
  const _process = /* @__PURE__ */ __name((binding) => {
    const { instance, modifiers: modifiers2, value: value3 } = binding;
    if (!instance || !instance.$) {
      throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
    }
    const composer = getComposer$2(i18n2, instance.$);
    if (false) {
      warn$1(getWarnMessage(I18nWarnCodes.NOT_SUPPORTED_PRESERVE));
    }
    const parsedValue = parseValue(value3);
    return [
      Reflect.apply(composer.t, composer, [...makeParams(parsedValue)]),
      composer
    ];
  }, "_process");
  const register3 = /* @__PURE__ */ __name((el, binding) => {
    const [textContent, composer] = _process(binding);
    if (inBrowser && i18n2.global === composer) {
      el.__i18nWatcher = watch(composer.locale, () => {
        binding.instance && binding.instance.$forceUpdate();
      });
    }
    el.__composer = composer;
    el.textContent = textContent;
  }, "register");
  const unregister = /* @__PURE__ */ __name((el) => {
    if (inBrowser && el.__i18nWatcher) {
      el.__i18nWatcher();
      el.__i18nWatcher = void 0;
      delete el.__i18nWatcher;
    }
    if (el.__composer) {
      el.__composer = void 0;
      delete el.__composer;
    }
  }, "unregister");
  const update = /* @__PURE__ */ __name((el, { value: value3 }) => {
    if (el.__composer) {
      const composer = el.__composer;
      const parsedValue = parseValue(value3);
      el.textContent = Reflect.apply(composer.t, composer, [
        ...makeParams(parsedValue)
      ]);
    }
  }, "update");
  const getSSRProps = /* @__PURE__ */ __name((binding) => {
    const [textContent] = _process(binding);
    return { textContent };
  }, "getSSRProps");
  return {
    created: register3,
    unmounted: unregister,
    beforeUpdate: update,
    getSSRProps
  };
}
__name(vTDirective, "vTDirective");
function parseValue(value3) {
  if (isString$7(value3)) {
    return { path: value3 };
  } else if (isPlainObject$1(value3)) {
    if (!("path" in value3)) {
      throw createI18nError(I18nErrorCodes.REQUIRED_VALUE, "path");
    }
    return value3;
  } else {
    throw createI18nError(I18nErrorCodes.INVALID_VALUE);
  }
}
__name(parseValue, "parseValue");
function makeParams(value3) {
  const { path, locale: locale2, args, choice, plural } = value3;
  const options5 = {};
  const named = args || {};
  if (isString$7(locale2)) {
    options5.locale = locale2;
  }
  if (isNumber$5(choice)) {
    options5.plural = choice;
  }
  if (isNumber$5(plural)) {
    options5.plural = plural;
  }
  return [path, named, options5];
}
__name(makeParams, "makeParams");
function apply$1(app2, i18n2, ...options5) {
  const pluginOptions = isPlainObject$1(options5[0]) ? options5[0] : {};
  const useI18nComponentName = !!pluginOptions.useI18nComponentName;
  const globalInstall = isBoolean$1(pluginOptions.globalInstall) ? pluginOptions.globalInstall : true;
  if (false) {
    warn$1(getWarnMessage(I18nWarnCodes.COMPONENT_NAME_LEGACY_COMPATIBLE, {
      name: Translation.name
    }));
  }
  if (globalInstall) {
    [!useI18nComponentName ? Translation.name : "i18n", "I18nT"].forEach((name2) => app2.component(name2, Translation));
    [NumberFormat.name, "I18nN"].forEach((name2) => app2.component(name2, NumberFormat));
    [DatetimeFormat.name, "I18nD"].forEach((name2) => app2.component(name2, DatetimeFormat));
  }
  {
    app2.directive("t", vTDirective(i18n2));
  }
}
__name(apply$1, "apply$1");
const VueDevToolsLabels = {
  [
    "vue-devtools-plugin-vue-i18n"
    /* VueDevToolsIDs.PLUGIN */
  ]: "Vue I18n devtools",
  [
    "vue-i18n-resource-inspector"
    /* VueDevToolsIDs.CUSTOM_INSPECTOR */
  ]: "I18n Resources",
  [
    "vue-i18n-timeline"
    /* VueDevToolsIDs.TIMELINE */
  ]: "Vue I18n"
};
const VueDevToolsPlaceholders = {
  [
    "vue-i18n-resource-inspector"
    /* VueDevToolsIDs.CUSTOM_INSPECTOR */
  ]: "Search for scopes ..."
};
const VueDevToolsTimelineColors = {
  [
    "vue-i18n-timeline"
    /* VueDevToolsIDs.TIMELINE */
  ]: 16764185
};
const VUE_I18N_COMPONENT_TYPES = "vue-i18n: composer properties";
let devtoolsApi;
async function enableDevTools(app2, i18n2) {
  return new Promise((resolve2, reject3) => {
    try {
      setupDevtoolsPlugin({
        id: "vue-devtools-plugin-vue-i18n",
        label: VueDevToolsLabels[
          "vue-devtools-plugin-vue-i18n"
          /* VueDevToolsIDs.PLUGIN */
        ],
        packageName: "vue-i18n",
        homepage: "https://vue-i18n.intlify.dev",
        logo: "https://vue-i18n.intlify.dev/vue-i18n-devtools-logo.png",
        componentStateTypes: [VUE_I18N_COMPONENT_TYPES],
        app: app2
        // eslint-disable-line @typescript-eslint/no-explicit-any
      }, (api2) => {
        devtoolsApi = api2;
        api2.on.visitComponentTree(({ componentInstance, treeNode }) => {
          updateComponentTreeTags(componentInstance, treeNode, i18n2);
        });
        api2.on.inspectComponent(({ componentInstance, instanceData }) => {
          if (componentInstance.vnode.el && componentInstance.vnode.el.__VUE_I18N__ && instanceData) {
            if (i18n2.mode === "legacy") {
              if (componentInstance.vnode.el.__VUE_I18N__ !== i18n2.global.__composer) {
                inspectComposer(instanceData, componentInstance.vnode.el.__VUE_I18N__);
              }
            } else {
              inspectComposer(instanceData, componentInstance.vnode.el.__VUE_I18N__);
            }
          }
        });
        api2.addInspector({
          id: "vue-i18n-resource-inspector",
          label: VueDevToolsLabels[
            "vue-i18n-resource-inspector"
            /* VueDevToolsIDs.CUSTOM_INSPECTOR */
          ],
          icon: "language",
          treeFilterPlaceholder: VueDevToolsPlaceholders[
            "vue-i18n-resource-inspector"
            /* VueDevToolsIDs.CUSTOM_INSPECTOR */
          ]
        });
        api2.on.getInspectorTree((payload) => {
          if (payload.app === app2 && payload.inspectorId === "vue-i18n-resource-inspector") {
            registerScope(payload, i18n2);
          }
        });
        const roots = /* @__PURE__ */ new Map();
        api2.on.getInspectorState(async (payload) => {
          if (payload.app === app2 && payload.inspectorId === "vue-i18n-resource-inspector") {
            api2.unhighlightElement();
            inspectScope(payload, i18n2);
            if (payload.nodeId === "global") {
              if (!roots.has(payload.app)) {
                const [root34] = await api2.getComponentInstances(payload.app);
                roots.set(payload.app, root34);
              }
              api2.highlightElement(roots.get(payload.app));
            } else {
              const instance = getComponentInstance(payload.nodeId, i18n2);
              instance && api2.highlightElement(instance);
            }
          }
        });
        api2.on.editInspectorState((payload) => {
          if (payload.app === app2 && payload.inspectorId === "vue-i18n-resource-inspector") {
            editScope(payload, i18n2);
          }
        });
        api2.addTimelineLayer({
          id: "vue-i18n-timeline",
          label: VueDevToolsLabels[
            "vue-i18n-timeline"
            /* VueDevToolsIDs.TIMELINE */
          ],
          color: VueDevToolsTimelineColors[
            "vue-i18n-timeline"
            /* VueDevToolsIDs.TIMELINE */
          ]
        });
        resolve2(true);
      });
    } catch (e2) {
      console.error(e2);
      reject3(false);
    }
  });
}
__name(enableDevTools, "enableDevTools");
function getI18nScopeLable(instance) {
  return instance.type.name || instance.type.displayName || instance.type.__file || "Anonymous";
}
__name(getI18nScopeLable, "getI18nScopeLable");
function updateComponentTreeTags(instance, treeNode, i18n2) {
  const global2 = i18n2.mode === "composition" ? i18n2.global : i18n2.global.__composer;
  if (instance && instance.vnode.el && instance.vnode.el.__VUE_I18N__) {
    if (instance.vnode.el.__VUE_I18N__ !== global2) {
      const tag = {
        label: `i18n (${getI18nScopeLable(instance)} Scope)`,
        textColor: 0,
        backgroundColor: 16764185
      };
      treeNode.tags.push(tag);
    }
  }
}
__name(updateComponentTreeTags, "updateComponentTreeTags");
function inspectComposer(instanceData, composer) {
  const type = VUE_I18N_COMPONENT_TYPES;
  instanceData.state.push({
    type,
    key: "locale",
    editable: true,
    value: composer.locale.value
  });
  instanceData.state.push({
    type,
    key: "availableLocales",
    editable: false,
    value: composer.availableLocales
  });
  instanceData.state.push({
    type,
    key: "fallbackLocale",
    editable: true,
    value: composer.fallbackLocale.value
  });
  instanceData.state.push({
    type,
    key: "inheritLocale",
    editable: true,
    value: composer.inheritLocale
  });
  instanceData.state.push({
    type,
    key: "messages",
    editable: false,
    value: getLocaleMessageValue(composer.messages.value)
  });
  {
    instanceData.state.push({
      type,
      key: "datetimeFormats",
      editable: false,
      value: composer.datetimeFormats.value
    });
    instanceData.state.push({
      type,
      key: "numberFormats",
      editable: false,
      value: composer.numberFormats.value
    });
  }
}
__name(inspectComposer, "inspectComposer");
function getLocaleMessageValue(messages2) {
  const value3 = {};
  Object.keys(messages2).forEach((key) => {
    const v2 = messages2[key];
    if (isFunction$9(v2) && "source" in v2) {
      value3[key] = getMessageFunctionDetails(v2);
    } else if (isMessageAST(v2) && v2.loc && v2.loc.source) {
      value3[key] = v2.loc.source;
    } else if (isObject$c(v2)) {
      value3[key] = getLocaleMessageValue(v2);
    } else {
      value3[key] = v2;
    }
  });
  return value3;
}
__name(getLocaleMessageValue, "getLocaleMessageValue");
const ESC = {
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "&": "&amp;"
};
function escape$3(s2) {
  return s2.replace(/[<>"&]/g, escapeChar);
}
__name(escape$3, "escape$3");
function escapeChar(a2) {
  return ESC[a2] || a2;
}
__name(escapeChar, "escapeChar");
function getMessageFunctionDetails(func) {
  const argString = func.source ? `("${escape$3(func.source)}")` : `(?)`;
  return {
    _custom: {
      type: "function",
      display: `<span>ƒ</span> ${argString}`
    }
  };
}
__name(getMessageFunctionDetails, "getMessageFunctionDetails");
function registerScope(payload, i18n2) {
  payload.rootNodes.push({
    id: "global",
    label: "Global Scope"
  });
  const global2 = i18n2.mode === "composition" ? i18n2.global : i18n2.global.__composer;
  for (const [keyInstance, instance] of i18n2.__instances) {
    const composer = i18n2.mode === "composition" ? instance : instance.__composer;
    if (global2 === composer) {
      continue;
    }
    payload.rootNodes.push({
      id: composer.id.toString(),
      label: `${getI18nScopeLable(keyInstance)} Scope`
    });
  }
}
__name(registerScope, "registerScope");
function getComponentInstance(nodeId, i18n2) {
  let instance = null;
  if (nodeId !== "global") {
    for (const [component, composer] of i18n2.__instances.entries()) {
      if (composer.id.toString() === nodeId) {
        instance = component;
        break;
      }
    }
  }
  return instance;
}
__name(getComponentInstance, "getComponentInstance");
function getComposer$1(nodeId, i18n2) {
  if (nodeId === "global") {
    return i18n2.mode === "composition" ? i18n2.global : i18n2.global.__composer;
  } else {
    const instance = Array.from(i18n2.__instances.values()).find((item3) => item3.id.toString() === nodeId);
    if (instance) {
      return i18n2.mode === "composition" ? instance : instance.__composer;
    } else {
      return null;
    }
  }
}
__name(getComposer$1, "getComposer$1");
function inspectScope(payload, i18n2) {
  const composer = getComposer$1(payload.nodeId, i18n2);
  if (composer) {
    payload.state = makeScopeInspectState(composer);
  }
  return null;
}
__name(inspectScope, "inspectScope");
function makeScopeInspectState(composer) {
  const state = {};
  const localeType = "Locale related info";
  const localeStates = [
    {
      type: localeType,
      key: "locale",
      editable: true,
      value: composer.locale.value
    },
    {
      type: localeType,
      key: "fallbackLocale",
      editable: true,
      value: composer.fallbackLocale.value
    },
    {
      type: localeType,
      key: "availableLocales",
      editable: false,
      value: composer.availableLocales
    },
    {
      type: localeType,
      key: "inheritLocale",
      editable: true,
      value: composer.inheritLocale
    }
  ];
  state[localeType] = localeStates;
  const localeMessagesType = "Locale messages info";
  const localeMessagesStates = [
    {
      type: localeMessagesType,
      key: "messages",
      editable: false,
      value: getLocaleMessageValue(composer.messages.value)
    }
  ];
  state[localeMessagesType] = localeMessagesStates;
  {
    const datetimeFormatsType = "Datetime formats info";
    const datetimeFormatsStates = [
      {
        type: datetimeFormatsType,
        key: "datetimeFormats",
        editable: false,
        value: composer.datetimeFormats.value
      }
    ];
    state[datetimeFormatsType] = datetimeFormatsStates;
    const numberFormatsType = "Datetime formats info";
    const numberFormatsStates = [
      {
        type: numberFormatsType,
        key: "numberFormats",
        editable: false,
        value: composer.numberFormats.value
      }
    ];
    state[numberFormatsType] = numberFormatsStates;
  }
  return state;
}
__name(makeScopeInspectState, "makeScopeInspectState");
function addTimelineEvent(event, payload) {
  if (devtoolsApi) {
    let groupId;
    if (payload && "groupId" in payload) {
      groupId = payload.groupId;
      delete payload.groupId;
    }
    devtoolsApi.addTimelineEvent({
      layerId: "vue-i18n-timeline",
      event: {
        title: event,
        groupId,
        time: Date.now(),
        meta: {},
        data: payload || {},
        logType: event === "compile-error" ? "error" : event === "fallback" || event === "missing" ? "warning" : "default"
      }
    });
  }
}
__name(addTimelineEvent, "addTimelineEvent");
function editScope(payload, i18n2) {
  const composer = getComposer$1(payload.nodeId, i18n2);
  if (composer) {
    const [field2] = payload.path;
    if (field2 === "locale" && isString$7(payload.state.value)) {
      composer.locale.value = payload.state.value;
    } else if (field2 === "fallbackLocale" && (isString$7(payload.state.value) || isArray$8(payload.state.value) || isObject$c(payload.state.value))) {
      composer.fallbackLocale.value = payload.state.value;
    } else if (field2 === "inheritLocale" && isBoolean$1(payload.state.value)) {
      composer.inheritLocale = payload.state.value;
    }
  }
}
__name(editScope, "editScope");
function defineMixin(vuei18n, composer, i18n2) {
  return {
    beforeCreate() {
      const instance = getCurrentInstance();
      if (!instance) {
        throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
      }
      const options5 = this.$options;
      if (options5.i18n) {
        const optionsI18n = options5.i18n;
        if (options5.__i18n) {
          optionsI18n.__i18n = options5.__i18n;
        }
        optionsI18n.__root = composer;
        if (this === this.$root) {
          this.$i18n = mergeToGlobal(vuei18n, optionsI18n);
        } else {
          optionsI18n.__injectWithOption = true;
          optionsI18n.__extender = i18n2.__vueI18nExtend;
          this.$i18n = createVueI18n(optionsI18n);
          const _vueI18n = this.$i18n;
          if (_vueI18n.__extender) {
            _vueI18n.__disposer = _vueI18n.__extender(this.$i18n);
          }
        }
      } else if (options5.__i18n) {
        if (this === this.$root) {
          this.$i18n = mergeToGlobal(vuei18n, options5);
        } else {
          this.$i18n = createVueI18n({
            __i18n: options5.__i18n,
            __injectWithOption: true,
            __extender: i18n2.__vueI18nExtend,
            __root: composer
          });
          const _vueI18n = this.$i18n;
          if (_vueI18n.__extender) {
            _vueI18n.__disposer = _vueI18n.__extender(this.$i18n);
          }
        }
      } else {
        this.$i18n = vuei18n;
      }
      if (options5.__i18nGlobal) {
        adjustI18nResources(composer, options5, options5);
      }
      this.$t = (...args) => this.$i18n.t(...args);
      this.$rt = (...args) => this.$i18n.rt(...args);
      this.$tc = (...args) => this.$i18n.tc(...args);
      this.$te = (key, locale2) => this.$i18n.te(key, locale2);
      this.$d = (...args) => this.$i18n.d(...args);
      this.$n = (...args) => this.$i18n.n(...args);
      this.$tm = (key) => this.$i18n.tm(key);
      i18n2.__setInstance(instance, this.$i18n);
    },
    mounted() {
      if (false) {
        const _vueI18n = this.$i18n;
        this.$el.__VUE_I18N__ = _vueI18n.__composer;
        const emitter = this.__v_emitter = createEmitter();
        _vueI18n.__enableEmitter && _vueI18n.__enableEmitter(emitter);
        emitter.on("*", addTimelineEvent);
      }
    },
    unmounted() {
      const instance = getCurrentInstance();
      if (!instance) {
        throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
      }
      const _vueI18n = this.$i18n;
      if (false) {
        if (this.__v_emitter) {
          this.__v_emitter.off("*", addTimelineEvent);
          delete this.__v_emitter;
        }
        if (this.$i18n) {
          _vueI18n.__disableEmitter && _vueI18n.__disableEmitter();
          delete this.$el.__VUE_I18N__;
        }
      }
      delete this.$t;
      delete this.$rt;
      delete this.$tc;
      delete this.$te;
      delete this.$d;
      delete this.$n;
      delete this.$tm;
      if (_vueI18n.__disposer) {
        _vueI18n.__disposer();
        delete _vueI18n.__disposer;
        delete _vueI18n.__extender;
      }
      i18n2.__deleteInstance(instance);
      delete this.$i18n;
    }
  };
}
__name(defineMixin, "defineMixin");
function mergeToGlobal(g2, options5) {
  g2.locale = options5.locale || g2.locale;
  g2.fallbackLocale = options5.fallbackLocale || g2.fallbackLocale;
  g2.missing = options5.missing || g2.missing;
  g2.silentTranslationWarn = options5.silentTranslationWarn || g2.silentFallbackWarn;
  g2.silentFallbackWarn = options5.silentFallbackWarn || g2.silentFallbackWarn;
  g2.formatFallbackMessages = options5.formatFallbackMessages || g2.formatFallbackMessages;
  g2.postTranslation = options5.postTranslation || g2.postTranslation;
  g2.warnHtmlInMessage = options5.warnHtmlInMessage || g2.warnHtmlInMessage;
  g2.escapeParameterHtml = options5.escapeParameterHtml || g2.escapeParameterHtml;
  g2.sync = options5.sync || g2.sync;
  g2.__composer[SetPluralRulesSymbol](options5.pluralizationRules || g2.pluralizationRules);
  const messages2 = getLocaleMessages(g2.locale, {
    messages: options5.messages,
    __i18n: options5.__i18n
  });
  Object.keys(messages2).forEach((locale2) => g2.mergeLocaleMessage(locale2, messages2[locale2]));
  if (options5.datetimeFormats) {
    Object.keys(options5.datetimeFormats).forEach((locale2) => g2.mergeDateTimeFormat(locale2, options5.datetimeFormats[locale2]));
  }
  if (options5.numberFormats) {
    Object.keys(options5.numberFormats).forEach((locale2) => g2.mergeNumberFormat(locale2, options5.numberFormats[locale2]));
  }
  return g2;
}
__name(mergeToGlobal, "mergeToGlobal");
const I18nInjectionKey = /* @__PURE__ */ makeSymbol("global-vue-i18n");
function createI18n(options5 = {}, VueI18nLegacy) {
  const __legacyMode = __VUE_I18N_LEGACY_API__ && isBoolean$1(options5.legacy) ? options5.legacy : __VUE_I18N_LEGACY_API__;
  const __globalInjection = isBoolean$1(options5.globalInjection) ? options5.globalInjection : true;
  const __allowComposition = __VUE_I18N_LEGACY_API__ && __legacyMode ? !!options5.allowComposition : true;
  const __instances = /* @__PURE__ */ new Map();
  const [globalScope, __global] = createGlobal(options5, __legacyMode);
  const symbol = /* @__PURE__ */ makeSymbol(false ? "vue-i18n" : "");
  if (false) {
    if (__legacyMode && __allowComposition && true) {
      warn$1(getWarnMessage(I18nWarnCodes.NOTICE_DROP_ALLOW_COMPOSITION));
    }
  }
  function __getInstance(component) {
    return __instances.get(component) || null;
  }
  __name(__getInstance, "__getInstance");
  function __setInstance(component, instance) {
    __instances.set(component, instance);
  }
  __name(__setInstance, "__setInstance");
  function __deleteInstance(component) {
    __instances.delete(component);
  }
  __name(__deleteInstance, "__deleteInstance");
  {
    const i18n2 = {
      // mode
      get mode() {
        return __VUE_I18N_LEGACY_API__ && __legacyMode ? "legacy" : "composition";
      },
      // allowComposition
      get allowComposition() {
        return __allowComposition;
      },
      // install plugin
      async install(app2, ...options22) {
        if (false) {
          app2.__VUE_I18N__ = i18n2;
        }
        app2.__VUE_I18N_SYMBOL__ = symbol;
        app2.provide(app2.__VUE_I18N_SYMBOL__, i18n2);
        if (isPlainObject$1(options22[0])) {
          const opts = options22[0];
          i18n2.__composerExtend = opts.__composerExtend;
          i18n2.__vueI18nExtend = opts.__vueI18nExtend;
        }
        let globalReleaseHandler = null;
        if (!__legacyMode && __globalInjection) {
          globalReleaseHandler = injectGlobalFields(app2, i18n2.global);
        }
        if (__VUE_I18N_FULL_INSTALL__) {
          apply$1(app2, i18n2, ...options22);
        }
        if (__VUE_I18N_LEGACY_API__ && __legacyMode) {
          app2.mixin(defineMixin(__global, __global.__composer, i18n2));
        }
        const unmountApp = app2.unmount;
        app2.unmount = () => {
          globalReleaseHandler && globalReleaseHandler();
          i18n2.dispose();
          unmountApp();
        };
        if (false) {
          const ret = await enableDevTools(app2, i18n2);
          if (!ret) {
            throw createI18nError(I18nErrorCodes.CANNOT_SETUP_VUE_DEVTOOLS_PLUGIN);
          }
          const emitter = createEmitter();
          if (__legacyMode) {
            const _vueI18n = __global;
            _vueI18n.__enableEmitter && _vueI18n.__enableEmitter(emitter);
          } else {
            const _composer = __global;
            _composer[EnableEmitter] && _composer[EnableEmitter](emitter);
          }
          emitter.on("*", addTimelineEvent);
        }
      },
      // global accessor
      get global() {
        return __global;
      },
      dispose() {
        globalScope.stop();
      },
      // @internal
      __instances,
      // @internal
      __getInstance,
      // @internal
      __setInstance,
      // @internal
      __deleteInstance
    };
    return i18n2;
  }
}
__name(createI18n, "createI18n");
function useI18n(options5 = {}) {
  const instance = getCurrentInstance();
  if (instance == null) {
    throw createI18nError(I18nErrorCodes.MUST_BE_CALL_SETUP_TOP);
  }
  if (!instance.isCE && instance.appContext.app != null && !instance.appContext.app.__VUE_I18N_SYMBOL__) {
    throw createI18nError(I18nErrorCodes.NOT_INSTALLED);
  }
  const i18n2 = getI18nInstance(instance);
  const gl = getGlobalComposer(i18n2);
  const componentOptions = getComponentOptions(instance);
  const scope = getScope(options5, componentOptions);
  if (__VUE_I18N_LEGACY_API__) {
    if (i18n2.mode === "legacy" && !options5.__useComponent) {
      if (!i18n2.allowComposition) {
        throw createI18nError(I18nErrorCodes.NOT_AVAILABLE_IN_LEGACY_MODE);
      }
      return useI18nForLegacy(instance, scope, gl, options5);
    }
  }
  if (scope === "global") {
    adjustI18nResources(gl, options5, componentOptions);
    return gl;
  }
  if (scope === "parent") {
    let composer2 = getComposer(i18n2, instance, options5.__useComponent);
    if (composer2 == null) {
      if (false) {
        warn$1(getWarnMessage(I18nWarnCodes.NOT_FOUND_PARENT_SCOPE));
      }
      composer2 = gl;
    }
    return composer2;
  }
  const i18nInternal = i18n2;
  let composer = i18nInternal.__getInstance(instance);
  if (composer == null) {
    const composerOptions = assign$4({}, options5);
    if ("__i18n" in componentOptions) {
      composerOptions.__i18n = componentOptions.__i18n;
    }
    if (gl) {
      composerOptions.__root = gl;
    }
    composer = createComposer(composerOptions);
    if (i18nInternal.__composerExtend) {
      composer[DisposeSymbol] = i18nInternal.__composerExtend(composer);
    }
    setupLifeCycle(i18nInternal, instance, composer);
    i18nInternal.__setInstance(instance, composer);
  }
  return composer;
}
__name(useI18n, "useI18n");
const castToVueI18n = /* @__PURE__ */ __name(/* @__NO_SIDE_EFFECTS__ */ (i18n2) => {
  if (!(__VUE_I18N_BRIDGE__ in i18n2)) {
    throw createI18nError(I18nErrorCodes.NOT_COMPATIBLE_LEGACY_VUE_I18N);
  }
  return i18n2;
}, "castToVueI18n");
function createGlobal(options5, legacyMode, VueI18nLegacy) {
  const scope = effectScope();
  {
    const obj = __VUE_I18N_LEGACY_API__ && legacyMode ? scope.run(() => createVueI18n(options5)) : scope.run(() => createComposer(options5));
    if (obj == null) {
      throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
    }
    return [scope, obj];
  }
}
__name(createGlobal, "createGlobal");
function getI18nInstance(instance) {
  {
    const i18n2 = inject(!instance.isCE ? instance.appContext.app.__VUE_I18N_SYMBOL__ : I18nInjectionKey);
    if (!i18n2) {
      throw createI18nError(!instance.isCE ? I18nErrorCodes.UNEXPECTED_ERROR : I18nErrorCodes.NOT_INSTALLED_WITH_PROVIDE);
    }
    return i18n2;
  }
}
__name(getI18nInstance, "getI18nInstance");
function getScope(options5, componentOptions) {
  return isEmptyObject$1(options5) ? "__i18n" in componentOptions ? "local" : "global" : !options5.useScope ? "local" : options5.useScope;
}
__name(getScope, "getScope");
function getGlobalComposer(i18n2) {
  return i18n2.mode === "composition" ? i18n2.global : i18n2.global.__composer;
}
__name(getGlobalComposer, "getGlobalComposer");
function getComposer(i18n2, target2, useComponent = false) {
  let composer = null;
  const root34 = target2.root;
  let current = getParentComponentInstance(target2, useComponent);
  while (current != null) {
    const i18nInternal = i18n2;
    if (i18n2.mode === "composition") {
      composer = i18nInternal.__getInstance(current);
    } else {
      if (__VUE_I18N_LEGACY_API__) {
        const vueI18n = i18nInternal.__getInstance(current);
        if (vueI18n != null) {
          composer = vueI18n.__composer;
          if (useComponent && composer && !composer[InejctWithOptionSymbol]) {
            composer = null;
          }
        }
      }
    }
    if (composer != null) {
      break;
    }
    if (root34 === current) {
      break;
    }
    current = current.parent;
  }
  return composer;
}
__name(getComposer, "getComposer");
function getParentComponentInstance(target2, useComponent = false) {
  if (target2 == null) {
    return null;
  }
  {
    return !useComponent ? target2.parent : target2.vnode.ctx || target2.parent;
  }
}
__name(getParentComponentInstance, "getParentComponentInstance");
function setupLifeCycle(i18n2, target2, composer) {
  let emitter = null;
  {
    onMounted(() => {
      if (false) {
        target2.vnode.el.__VUE_I18N__ = composer;
        emitter = createEmitter();
        const _composer = composer;
        _composer[EnableEmitter] && _composer[EnableEmitter](emitter);
        emitter.on("*", addTimelineEvent);
      }
    }, target2);
    onUnmounted(() => {
      const _composer = composer;
      if (false) {
        emitter && emitter.off("*", addTimelineEvent);
        _composer[DisableEmitter] && _composer[DisableEmitter]();
        delete target2.vnode.el.__VUE_I18N__;
      }
      i18n2.__deleteInstance(target2);
      const dispose = _composer[DisposeSymbol];
      if (dispose) {
        dispose();
        delete _composer[DisposeSymbol];
      }
    }, target2);
  }
}
__name(setupLifeCycle, "setupLifeCycle");
function useI18nForLegacy(instance, scope, root34, options5 = {}) {
  const isLocalScope = scope === "local";
  const _composer = shallowRef(null);
  if (isLocalScope && instance.proxy && !(instance.proxy.$options.i18n || instance.proxy.$options.__i18n)) {
    throw createI18nError(I18nErrorCodes.MUST_DEFINE_I18N_OPTION_IN_ALLOW_COMPOSITION);
  }
  const _inheritLocale = isBoolean$1(options5.inheritLocale) ? options5.inheritLocale : !isString$7(options5.locale);
  const _locale = ref(
    // prettier-ignore
    !isLocalScope || _inheritLocale ? root34.locale.value : isString$7(options5.locale) ? options5.locale : DEFAULT_LOCALE
  );
  const _fallbackLocale = ref(
    // prettier-ignore
    !isLocalScope || _inheritLocale ? root34.fallbackLocale.value : isString$7(options5.fallbackLocale) || isArray$8(options5.fallbackLocale) || isPlainObject$1(options5.fallbackLocale) || options5.fallbackLocale === false ? options5.fallbackLocale : _locale.value
  );
  const _messages = ref(getLocaleMessages(_locale.value, options5));
  const _datetimeFormats = ref(isPlainObject$1(options5.datetimeFormats) ? options5.datetimeFormats : { [_locale.value]: {} });
  const _numberFormats = ref(isPlainObject$1(options5.numberFormats) ? options5.numberFormats : { [_locale.value]: {} });
  const _missingWarn = isLocalScope ? root34.missingWarn : isBoolean$1(options5.missingWarn) || isRegExp$2(options5.missingWarn) ? options5.missingWarn : true;
  const _fallbackWarn = isLocalScope ? root34.fallbackWarn : isBoolean$1(options5.fallbackWarn) || isRegExp$2(options5.fallbackWarn) ? options5.fallbackWarn : true;
  const _fallbackRoot = isLocalScope ? root34.fallbackRoot : isBoolean$1(options5.fallbackRoot) ? options5.fallbackRoot : true;
  const _fallbackFormat = !!options5.fallbackFormat;
  const _missing = isFunction$9(options5.missing) ? options5.missing : null;
  const _postTranslation = isFunction$9(options5.postTranslation) ? options5.postTranslation : null;
  const _warnHtmlMessage = isLocalScope ? root34.warnHtmlMessage : isBoolean$1(options5.warnHtmlMessage) ? options5.warnHtmlMessage : true;
  const _escapeParameter = !!options5.escapeParameter;
  const _modifiers = isLocalScope ? root34.modifiers : isPlainObject$1(options5.modifiers) ? options5.modifiers : {};
  const _pluralRules = options5.pluralRules || isLocalScope && root34.pluralRules;
  function trackReactivityValues() {
    return [
      _locale.value,
      _fallbackLocale.value,
      _messages.value,
      _datetimeFormats.value,
      _numberFormats.value
    ];
  }
  __name(trackReactivityValues, "trackReactivityValues");
  const locale2 = computed({
    get: /* @__PURE__ */ __name(() => {
      return _composer.value ? _composer.value.locale.value : _locale.value;
    }, "get"),
    set: /* @__PURE__ */ __name((val) => {
      if (_composer.value) {
        _composer.value.locale.value = val;
      }
      _locale.value = val;
    }, "set")
  });
  const fallbackLocale = computed({
    get: /* @__PURE__ */ __name(() => {
      return _composer.value ? _composer.value.fallbackLocale.value : _fallbackLocale.value;
    }, "get"),
    set: /* @__PURE__ */ __name((val) => {
      if (_composer.value) {
        _composer.value.fallbackLocale.value = val;
      }
      _fallbackLocale.value = val;
    }, "set")
  });
  const messages2 = computed(() => {
    if (_composer.value) {
      return _composer.value.messages.value;
    } else {
      return _messages.value;
    }
  });
  const datetimeFormats = computed(() => _datetimeFormats.value);
  const numberFormats = computed(() => _numberFormats.value);
  function getPostTranslationHandler() {
    return _composer.value ? _composer.value.getPostTranslationHandler() : _postTranslation;
  }
  __name(getPostTranslationHandler, "getPostTranslationHandler");
  function setPostTranslationHandler(handler14) {
    if (_composer.value) {
      _composer.value.setPostTranslationHandler(handler14);
    }
  }
  __name(setPostTranslationHandler, "setPostTranslationHandler");
  function getMissingHandler() {
    return _composer.value ? _composer.value.getMissingHandler() : _missing;
  }
  __name(getMissingHandler, "getMissingHandler");
  function setMissingHandler(handler14) {
    if (_composer.value) {
      _composer.value.setMissingHandler(handler14);
    }
  }
  __name(setMissingHandler, "setMissingHandler");
  function warpWithDeps(fn) {
    trackReactivityValues();
    return fn();
  }
  __name(warpWithDeps, "warpWithDeps");
  function t2(...args) {
    return _composer.value ? warpWithDeps(() => Reflect.apply(_composer.value.t, null, [...args])) : warpWithDeps(() => "");
  }
  __name(t2, "t");
  function rt(...args) {
    return _composer.value ? Reflect.apply(_composer.value.rt, null, [...args]) : "";
  }
  __name(rt, "rt");
  function d2(...args) {
    return _composer.value ? warpWithDeps(() => Reflect.apply(_composer.value.d, null, [...args])) : warpWithDeps(() => "");
  }
  __name(d2, "d");
  function n2(...args) {
    return _composer.value ? warpWithDeps(() => Reflect.apply(_composer.value.n, null, [...args])) : warpWithDeps(() => "");
  }
  __name(n2, "n");
  function tm(key) {
    return _composer.value ? _composer.value.tm(key) : {};
  }
  __name(tm, "tm");
  function te2(key, locale22) {
    return _composer.value ? _composer.value.te(key, locale22) : false;
  }
  __name(te2, "te");
  function getLocaleMessage(locale22) {
    return _composer.value ? _composer.value.getLocaleMessage(locale22) : {};
  }
  __name(getLocaleMessage, "getLocaleMessage");
  function setLocaleMessage(locale22, message3) {
    if (_composer.value) {
      _composer.value.setLocaleMessage(locale22, message3);
      _messages.value[locale22] = message3;
    }
  }
  __name(setLocaleMessage, "setLocaleMessage");
  function mergeLocaleMessage(locale22, message3) {
    if (_composer.value) {
      _composer.value.mergeLocaleMessage(locale22, message3);
    }
  }
  __name(mergeLocaleMessage, "mergeLocaleMessage");
  function getDateTimeFormat(locale22) {
    return _composer.value ? _composer.value.getDateTimeFormat(locale22) : {};
  }
  __name(getDateTimeFormat, "getDateTimeFormat");
  function setDateTimeFormat(locale22, format2) {
    if (_composer.value) {
      _composer.value.setDateTimeFormat(locale22, format2);
      _datetimeFormats.value[locale22] = format2;
    }
  }
  __name(setDateTimeFormat, "setDateTimeFormat");
  function mergeDateTimeFormat(locale22, format2) {
    if (_composer.value) {
      _composer.value.mergeDateTimeFormat(locale22, format2);
    }
  }
  __name(mergeDateTimeFormat, "mergeDateTimeFormat");
  function getNumberFormat(locale22) {
    return _composer.value ? _composer.value.getNumberFormat(locale22) : {};
  }
  __name(getNumberFormat, "getNumberFormat");
  function setNumberFormat(locale22, format2) {
    if (_composer.value) {
      _composer.value.setNumberFormat(locale22, format2);
      _numberFormats.value[locale22] = format2;
    }
  }
  __name(setNumberFormat, "setNumberFormat");
  function mergeNumberFormat(locale22, format2) {
    if (_composer.value) {
      _composer.value.mergeNumberFormat(locale22, format2);
    }
  }
  __name(mergeNumberFormat, "mergeNumberFormat");
  const wrapper = {
    get id() {
      return _composer.value ? _composer.value.id : -1;
    },
    locale: locale2,
    fallbackLocale,
    messages: messages2,
    datetimeFormats,
    numberFormats,
    get inheritLocale() {
      return _composer.value ? _composer.value.inheritLocale : _inheritLocale;
    },
    set inheritLocale(val) {
      if (_composer.value) {
        _composer.value.inheritLocale = val;
      }
    },
    get availableLocales() {
      return _composer.value ? _composer.value.availableLocales : Object.keys(_messages.value);
    },
    get modifiers() {
      return _composer.value ? _composer.value.modifiers : _modifiers;
    },
    get pluralRules() {
      return _composer.value ? _composer.value.pluralRules : _pluralRules;
    },
    get isGlobal() {
      return _composer.value ? _composer.value.isGlobal : false;
    },
    get missingWarn() {
      return _composer.value ? _composer.value.missingWarn : _missingWarn;
    },
    set missingWarn(val) {
      if (_composer.value) {
        _composer.value.missingWarn = val;
      }
    },
    get fallbackWarn() {
      return _composer.value ? _composer.value.fallbackWarn : _fallbackWarn;
    },
    set fallbackWarn(val) {
      if (_composer.value) {
        _composer.value.missingWarn = val;
      }
    },
    get fallbackRoot() {
      return _composer.value ? _composer.value.fallbackRoot : _fallbackRoot;
    },
    set fallbackRoot(val) {
      if (_composer.value) {
        _composer.value.fallbackRoot = val;
      }
    },
    get fallbackFormat() {
      return _composer.value ? _composer.value.fallbackFormat : _fallbackFormat;
    },
    set fallbackFormat(val) {
      if (_composer.value) {
        _composer.value.fallbackFormat = val;
      }
    },
    get warnHtmlMessage() {
      return _composer.value ? _composer.value.warnHtmlMessage : _warnHtmlMessage;
    },
    set warnHtmlMessage(val) {
      if (_composer.value) {
        _composer.value.warnHtmlMessage = val;
      }
    },
    get escapeParameter() {
      return _composer.value ? _composer.value.escapeParameter : _escapeParameter;
    },
    set escapeParameter(val) {
      if (_composer.value) {
        _composer.value.escapeParameter = val;
      }
    },
    t: t2,
    getPostTranslationHandler,
    setPostTranslationHandler,
    getMissingHandler,
    setMissingHandler,
    rt,
    d: d2,
    n: n2,
    tm,
    te: te2,
    getLocaleMessage,
    setLocaleMessage,
    mergeLocaleMessage,
    getDateTimeFormat,
    setDateTimeFormat,
    mergeDateTimeFormat,
    getNumberFormat,
    setNumberFormat,
    mergeNumberFormat
  };
  function sync(composer) {
    composer.locale.value = _locale.value;
    composer.fallbackLocale.value = _fallbackLocale.value;
    Object.keys(_messages.value).forEach((locale22) => {
      composer.mergeLocaleMessage(locale22, _messages.value[locale22]);
    });
    Object.keys(_datetimeFormats.value).forEach((locale22) => {
      composer.mergeDateTimeFormat(locale22, _datetimeFormats.value[locale22]);
    });
    Object.keys(_numberFormats.value).forEach((locale22) => {
      composer.mergeNumberFormat(locale22, _numberFormats.value[locale22]);
    });
    composer.escapeParameter = _escapeParameter;
    composer.fallbackFormat = _fallbackFormat;
    composer.fallbackRoot = _fallbackRoot;
    composer.fallbackWarn = _fallbackWarn;
    composer.missingWarn = _missingWarn;
    composer.warnHtmlMessage = _warnHtmlMessage;
  }
  __name(sync, "sync");
  onBeforeMount(() => {
    if (instance.proxy == null || instance.proxy.$i18n == null) {
      throw createI18nError(I18nErrorCodes.NOT_AVAILABLE_COMPOSITION_IN_LEGACY);
    }
    const composer = _composer.value = instance.proxy.$i18n.__composer;
    if (scope === "global") {
      _locale.value = composer.locale.value;
      _fallbackLocale.value = composer.fallbackLocale.value;
      _messages.value = composer.messages.value;
      _datetimeFormats.value = composer.datetimeFormats.value;
      _numberFormats.value = composer.numberFormats.value;
    } else if (isLocalScope) {
      sync(composer);
    }
  });
  return wrapper;
}
__name(useI18nForLegacy, "useI18nForLegacy");
const globalExportProps = [
  "locale",
  "fallbackLocale",
  "availableLocales"
];
const globalExportMethods = ["t", "rt", "d", "n", "tm", "te"];
function injectGlobalFields(app2, composer) {
  const i18n2 = /* @__PURE__ */ Object.create(null);
  globalExportProps.forEach((prop2) => {
    const desc = Object.getOwnPropertyDescriptor(composer, prop2);
    if (!desc) {
      throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
    }
    const wrap2 = isRef(desc.value) ? {
      get() {
        return desc.value.value;
      },
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      set(val) {
        desc.value.value = val;
      }
    } : {
      get() {
        return desc.get && desc.get();
      }
    };
    Object.defineProperty(i18n2, prop2, wrap2);
  });
  app2.config.globalProperties.$i18n = i18n2;
  globalExportMethods.forEach((method) => {
    const desc = Object.getOwnPropertyDescriptor(composer, method);
    if (!desc || !desc.value) {
      throw createI18nError(I18nErrorCodes.UNEXPECTED_ERROR);
    }
    Object.defineProperty(app2.config.globalProperties, `$${method}`, desc);
  });
  const dispose = /* @__PURE__ */ __name(() => {
    delete app2.config.globalProperties.$i18n;
    globalExportMethods.forEach((method) => {
      delete app2.config.globalProperties[`$${method}`];
    });
  }, "dispose");
  return dispose;
}
__name(injectGlobalFields, "injectGlobalFields");
{
  initFeatureFlags();
}
if (__INTLIFY_JIT_COMPILATION__) {
  registerMessageCompiler(compile$1);
} else {
  registerMessageCompiler(compileToFunction);
}
registerMessageResolver(resolveValue$1);
registerLocaleFallbacker(fallbackWithLocaleChain);
if (__INTLIFY_PROD_DEVTOOLS__) {
  const target2 = getGlobalThis();
  target2.__INTLIFY__ = true;
  setDevToolsHook(target2.__INTLIFY_DEVTOOLS_GLOBAL_HOOK__);
}
if (false) ;
const Comfy_BrowseTemplates$5 = {
  label: "Browse Templates"
};
const Comfy_Canvas_DeleteSelectedItems$5 = {
  label: "Delete Selected Items"
};
const Comfy_Canvas_FitView$5 = {
  label: "Fit view to selected nodes"
};
const Comfy_Canvas_ResetView$5 = {
  label: "Reset View"
};
const Comfy_Canvas_ToggleLinkVisibility$5 = {
  label: "Canvas Toggle Link Visibility"
};
const Comfy_Canvas_ToggleLock$5 = {
  label: "Canvas Toggle Lock"
};
const Comfy_Canvas_ToggleSelected_Pin$5 = {
  label: "Pin/Unpin Selected Items"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass$5 = {
  label: "Bypass/Unbypass Selected Nodes"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse$5 = {
  label: "Collapse/Expand Selected Nodes"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute$5 = {
  label: "Mute/Unmute Selected Nodes"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin$5 = {
  label: "Pin/Unpin Selected Nodes"
};
const Comfy_Canvas_ZoomIn$5 = {
  label: "Zoom In"
};
const Comfy_Canvas_ZoomOut$5 = {
  label: "Zoom Out"
};
const Comfy_ClearPendingTasks$5 = {
  label: "Clear Pending Tasks"
};
const Comfy_ClearWorkflow$5 = {
  label: "Clear Workflow"
};
const Comfy_DuplicateWorkflow$5 = {
  label: "Duplicate Current Workflow"
};
const Comfy_ExportWorkflow$5 = {
  label: "Export Workflow"
};
const Comfy_ExportWorkflowAPI$5 = {
  label: "Export Workflow (API Format)"
};
const Comfy_Feedback$5 = {
  label: "Give Feedback"
};
const Comfy_Graph_FitGroupToContents$5 = {
  label: "Fit Group To Contents"
};
const Comfy_Graph_GroupSelectedNodes$5 = {
  label: "Group Selected Nodes"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode$5 = {
  label: "Convert selected nodes to group node"
};
const Comfy_GroupNode_ManageGroupNodes$5 = {
  label: "Manage group nodes"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes$5 = {
  label: "Ungroup selected group nodes"
};
const Comfy_Help_AboutComfyUI$5 = {
  label: "Open About ComfyUI"
};
const Comfy_Help_OpenComfyOrgDiscord$5 = {
  label: "Open Comfy-Org Discord"
};
const Comfy_Help_OpenComfyUIDocs$5 = {
  label: "Open ComfyUI Docs"
};
const Comfy_Help_OpenComfyUIForum$5 = {
  label: "Open ComfyUI Forum"
};
const Comfy_Help_OpenComfyUIIssues$5 = {
  label: "Open ComfyUI Issues"
};
const Comfy_Interrupt$5 = {
  label: "Interrupt"
};
const Comfy_LoadDefaultWorkflow$5 = {
  label: "Load Default Workflow"
};
const Comfy_Manager_CustomNodesManager$5 = {
  label: "Custom Nodes Manager"
};
const Comfy_Manager_ToggleManagerProgressDialog$5 = {
  label: "Toggle Progress Dialog"
};
const Comfy_NewBlankWorkflow$5 = {
  label: "New Blank Workflow"
};
const Comfy_OpenClipspace$5 = {
  label: "Clipspace"
};
const Comfy_OpenWorkflow$5 = {
  label: "Open Workflow"
};
const Comfy_QueuePrompt$5 = {
  label: "Queue Prompt"
};
const Comfy_QueuePromptFront$5 = {
  label: "Queue Prompt (Front)"
};
const Comfy_Redo$5 = {
  label: "Redo"
};
const Comfy_RefreshNodeDefinitions$5 = {
  label: "Refresh Node Definitions"
};
const Comfy_SaveWorkflow$5 = {
  label: "Save Workflow"
};
const Comfy_SaveWorkflowAs$5 = {
  label: "Save Workflow As"
};
const Comfy_ShowSettingsDialog$5 = {
  label: "Show Settings Dialog"
};
const Comfy_ToggleTheme$5 = {
  label: "Toggle Theme (Dark/Light)"
};
const Comfy_Undo$5 = {
  label: "Undo"
};
const Workspace_CloseWorkflow$5 = {
  label: "Close Current Workflow"
};
const Workspace_NextOpenedWorkflow$5 = {
  label: "Next Opened Workflow"
};
const Workspace_PreviousOpenedWorkflow$5 = {
  label: "Previous Opened Workflow"
};
const Workspace_SearchBox_Toggle$5 = {
  label: "Toggle Search Box"
};
const Workspace_ToggleBottomPanel$5 = {
  label: "Toggle Bottom Panel"
};
const Workspace_ToggleFocusMode$5 = {
  label: "Toggle Focus Mode"
};
const Workspace_ToggleSidebarTab_queue$5 = {
  label: "Toggle Queue Sidebar",
  tooltip: "Queue"
};
const Workspace_ToggleSidebarTab_workflows$5 = {
  label: "Toggle Workflows Sidebar",
  tooltip: "Workflows"
};
const enCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "Open Custom Nodes Folder"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "Open Inputs Folder"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "Open Logs Folder"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "Open extra_model_paths.yaml"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "Open Models Folder"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "Open Outputs Folder"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "Open DevTools"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "Desktop User Guide"
  },
  "Comfy-Desktop_Quit": {
    label: "Quit"
  },
  "Comfy-Desktop_Reinstall": {
    label: "Reinstall"
  },
  "Comfy-Desktop_Restart": {
    label: "Restart"
  },
  Comfy_BrowseTemplates: Comfy_BrowseTemplates$5,
  Comfy_Canvas_DeleteSelectedItems: Comfy_Canvas_DeleteSelectedItems$5,
  Comfy_Canvas_FitView: Comfy_Canvas_FitView$5,
  Comfy_Canvas_ResetView: Comfy_Canvas_ResetView$5,
  Comfy_Canvas_ToggleLinkVisibility: Comfy_Canvas_ToggleLinkVisibility$5,
  Comfy_Canvas_ToggleLock: Comfy_Canvas_ToggleLock$5,
  Comfy_Canvas_ToggleSelected_Pin: Comfy_Canvas_ToggleSelected_Pin$5,
  Comfy_Canvas_ToggleSelectedNodes_Bypass: Comfy_Canvas_ToggleSelectedNodes_Bypass$5,
  Comfy_Canvas_ToggleSelectedNodes_Collapse: Comfy_Canvas_ToggleSelectedNodes_Collapse$5,
  Comfy_Canvas_ToggleSelectedNodes_Mute: Comfy_Canvas_ToggleSelectedNodes_Mute$5,
  Comfy_Canvas_ToggleSelectedNodes_Pin: Comfy_Canvas_ToggleSelectedNodes_Pin$5,
  Comfy_Canvas_ZoomIn: Comfy_Canvas_ZoomIn$5,
  Comfy_Canvas_ZoomOut: Comfy_Canvas_ZoomOut$5,
  Comfy_ClearPendingTasks: Comfy_ClearPendingTasks$5,
  Comfy_ClearWorkflow: Comfy_ClearWorkflow$5,
  Comfy_DuplicateWorkflow: Comfy_DuplicateWorkflow$5,
  Comfy_ExportWorkflow: Comfy_ExportWorkflow$5,
  Comfy_ExportWorkflowAPI: Comfy_ExportWorkflowAPI$5,
  Comfy_Feedback: Comfy_Feedback$5,
  Comfy_Graph_FitGroupToContents: Comfy_Graph_FitGroupToContents$5,
  Comfy_Graph_GroupSelectedNodes: Comfy_Graph_GroupSelectedNodes$5,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode: Comfy_GroupNode_ConvertSelectedNodesToGroupNode$5,
  Comfy_GroupNode_ManageGroupNodes: Comfy_GroupNode_ManageGroupNodes$5,
  Comfy_GroupNode_UngroupSelectedGroupNodes: Comfy_GroupNode_UngroupSelectedGroupNodes$5,
  Comfy_Help_AboutComfyUI: Comfy_Help_AboutComfyUI$5,
  Comfy_Help_OpenComfyOrgDiscord: Comfy_Help_OpenComfyOrgDiscord$5,
  Comfy_Help_OpenComfyUIDocs: Comfy_Help_OpenComfyUIDocs$5,
  Comfy_Help_OpenComfyUIForum: Comfy_Help_OpenComfyUIForum$5,
  Comfy_Help_OpenComfyUIIssues: Comfy_Help_OpenComfyUIIssues$5,
  Comfy_Interrupt: Comfy_Interrupt$5,
  Comfy_LoadDefaultWorkflow: Comfy_LoadDefaultWorkflow$5,
  Comfy_Manager_CustomNodesManager: Comfy_Manager_CustomNodesManager$5,
  Comfy_Manager_ToggleManagerProgressDialog: Comfy_Manager_ToggleManagerProgressDialog$5,
  Comfy_NewBlankWorkflow: Comfy_NewBlankWorkflow$5,
  Comfy_OpenClipspace: Comfy_OpenClipspace$5,
  Comfy_OpenWorkflow: Comfy_OpenWorkflow$5,
  Comfy_QueuePrompt: Comfy_QueuePrompt$5,
  Comfy_QueuePromptFront: Comfy_QueuePromptFront$5,
  Comfy_Redo: Comfy_Redo$5,
  Comfy_RefreshNodeDefinitions: Comfy_RefreshNodeDefinitions$5,
  Comfy_SaveWorkflow: Comfy_SaveWorkflow$5,
  Comfy_SaveWorkflowAs: Comfy_SaveWorkflowAs$5,
  Comfy_ShowSettingsDialog: Comfy_ShowSettingsDialog$5,
  Comfy_ToggleTheme: Comfy_ToggleTheme$5,
  Comfy_Undo: Comfy_Undo$5,
  Workspace_CloseWorkflow: Workspace_CloseWorkflow$5,
  Workspace_NextOpenedWorkflow: Workspace_NextOpenedWorkflow$5,
  Workspace_PreviousOpenedWorkflow: Workspace_PreviousOpenedWorkflow$5,
  Workspace_SearchBox_Toggle: Workspace_SearchBox_Toggle$5,
  Workspace_ToggleBottomPanel: Workspace_ToggleBottomPanel$5,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "Toggle Terminal Bottom Panel"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "Toggle Logs Bottom Panel"
  },
  Workspace_ToggleFocusMode: Workspace_ToggleFocusMode$5,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "Toggle Model Library Sidebar",
    tooltip: "Model Library"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "Toggle Node Library Sidebar",
    tooltip: "Node Library"
  },
  Workspace_ToggleSidebarTab_queue: Workspace_ToggleSidebarTab_queue$5,
  Workspace_ToggleSidebarTab_workflows: Workspace_ToggleSidebarTab_workflows$5
};
const g$5 = {
  currentUser: "Current user",
  empty: "Empty",
  noWorkflowsFound: "No workflows found.",
  comingSoon: "Coming Soon",
  firstTimeUIMessage: 'This is the first time you use the new UI. Choose "Menu > Use New Menu > Disabled" to restore the old UI.',
  download: "Download",
  "import": "Import",
  loadAllFolders: "Load All Folders",
  refresh: "Refresh",
  terminal: "Terminal",
  logs: "Logs",
  videoFailedToLoad: "Video failed to load",
  extensionName: "Extension Name",
  reloadToApplyChanges: "Reload to apply changes",
  insert: "Insert",
  systemInfo: "System Info",
  devices: "Devices",
  about: "About",
  add: "Add",
  confirm: "Confirm",
  reset: "Reset",
  resetKeybindingsTooltip: "Reset keybindings to default",
  customizeFolder: "Customize Folder",
  icon: "Icon",
  color: "Color",
  error: "Error",
  loading: "Loading",
  findIssues: "Find Issues",
  reportIssue: "Send Report",
  reportIssueTooltip: "Submit the error report to Comfy Org",
  reportSent: "Report Submitted",
  copyToClipboard: "Copy to Clipboard",
  openNewIssue: "Open New Issue",
  showReport: "Show Report",
  imageFailedToLoad: "Image failed to load",
  reconnecting: "Reconnecting",
  reconnected: "Reconnected",
  "delete": "Delete",
  rename: "Rename",
  save: "Save",
  saving: "Saving",
  no: "No",
  cancel: "Cancel",
  close: "Close",
  back: "Back",
  next: "Next",
  install: "Install",
  installing: "Installing",
  overwrite: "Overwrite",
  customize: "Customize",
  experimental: "BETA",
  deprecated: "DEPR",
  loadWorkflow: "Load Workflow",
  goToNode: "Go to Node",
  settings: "Settings",
  searchWorkflows: "Search Workflows",
  searchSettings: "Search Settings",
  searchNodes: "Search Nodes",
  searchModels: "Search Models",
  searchKeybindings: "Search Keybindings",
  searchExtensions: "Search Extensions",
  noResultsFound: "No Results Found",
  searchFailedMessage: "We couldn't find any settings matching your search. Try adjusting your search terms.",
  noTasksFound: "No Tasks Found",
  noTasksFoundMessage: "There are no tasks in the queue.",
  newFolder: "New Folder",
  enableAll: "Enable All",
  disableAll: "Disable All",
  command: "Command",
  keybinding: "Keybinding",
  upload: "Upload",
  "export": "Export",
  workflow: "Workflow",
  success: "Success",
  ok: "OK",
  feedback: "Feedback",
  "continue": "Continue",
  control_after_generate: "control after generate",
  control_before_generate: "control before generate",
  choose_file_to_upload: "choose file to upload",
  capture: "capture",
  nodes: "Nodes",
  community: "Community",
  all: "All",
  updated: "Updated",
  resultsCount: "Found {count} Results",
  status: "Status",
  description: "Description",
  name: "Name",
  category: "Category",
  sort: "Sort",
  filter: "Filter",
  apply: "Apply",
  enabled: "Enabled",
  installed: "Installed",
  restart: "Restart",
  missing: "Missing",
  inProgress: "In progress",
  completed: "Completed"
};
const manager$5 = {
  title: "Custom Nodes Manager",
  dependencies: "Dependencies",
  inWorkflow: "In Workflow",
  infoPanelEmpty: "Click an item to see the info",
  restartToApplyChanges: "To apply changes, please restart ComfyUI",
  loadingVersions: "Loading versions...",
  selectVersion: "Select Version",
  downloads: "Downloads",
  repository: "Repository",
  uninstall: "Uninstall",
  uninstalling: "Uninstalling",
  update: "Update",
  uninstallSelected: "Uninstall Selected",
  license: "License",
  nightlyVersion: "Nightly",
  latestVersion: "Latest",
  createdBy: "Created By",
  totalNodes: "Total Nodes",
  discoverCommunityContent: "Discover community-made Node Packs, Extensions, and more...",
  errorConnecting: "Error connecting to the Comfy Node Registry.",
  noResultsFound: "No results found matching your search.",
  tryDifferentSearch: "Please try a different search query.",
  tryAgainLater: "Please try again later.",
  nodePack: "Node Pack",
  searchPlaceholder: "Search",
  version: "Version",
  lastUpdated: "Last Updated",
  noDescription: "No description available",
  installSelected: "Install Selected",
  packsSelected: "Packs Selected",
  status: {
    active: "Active",
    pending: "Pending",
    flagged: "Flagged",
    deleted: "Deleted",
    banned: "Banned",
    unknown: "Unknown"
  },
  sort: {
    rating: "Rating",
    downloads: "Most Popular"
  },
  filter: {
    nodePack: "Node Pack",
    enabled: "Enabled",
    disabled: "Disabled"
  }
};
const issueReport$5 = {
  submitErrorReport: "Submit Error Report (Optional)",
  provideEmail: "Give us your email (optional)",
  provideAdditionalDetails: "Provide additional details (optional)",
  stackTrace: "Stack Trace",
  systemStats: "System Stats",
  contactFollowUp: "Contact me for follow up",
  notifyResolve: "Notify me when resolved",
  helpFix: "Help Fix This",
  rating: "Rating",
  feedbackTitle: "Help us improve ComfyUI by providing feedback",
  validation: {
    maxLength: "Message too long",
    invalidEmail: "Please enter a valid email address"
  }
};
const color$5 = {
  noColor: "No Color",
  "default": "Default",
  blue: "Blue",
  green: "Green",
  red: "Red",
  pink: "Pink",
  yellow: "Yellow",
  brown: "Brown",
  pale_blue: "Pale Blue",
  cyan: "Cyan",
  purple: "Purple",
  black: "Black",
  custom: "Custom"
};
const contextMenu$5 = {
  Inputs: "Inputs",
  Outputs: "Outputs",
  Properties: "Properties",
  "Properties Panel": "Properties Panel",
  Title: "Title",
  Mode: "Mode",
  Resize: "Resize",
  Collapse: "Collapse",
  Expand: "Expand",
  Pin: "Pin",
  Unpin: "Unpin",
  Clone: "Clone",
  Remove: "Remove",
  Colors: "Colors",
  Shapes: "Shapes",
  Bypass: "Bypass",
  "Copy (Clipspace)": "Copy (Clipspace)",
  "Convert Widget to Input": "Convert Widget to Input",
  "Convert Input to Widget": "Convert Input to Widget",
  "Add Node": "Add Node",
  "Add Group": "Add Group",
  "Convert to Group Node": "Convert to Group Node",
  "Manage Group Nodes": "Manage Group Nodes",
  "Add Group For Selected Nodes": "Add Group For Selected Nodes",
  "Save Selected as Template": "Save Selected as Template",
  "Node Templates": "Node Templates",
  Manage: "Manage",
  "Convert ": "Convert ",
  " to input": " to input",
  " to widget": " to widget",
  Search: "Search"
};
const icon$5 = {
  bookmark: "Bookmark",
  folder: "Folder",
  star: "Star",
  heart: "Heart",
  file: "File",
  inbox: "Inbox",
  box: "Box",
  briefcase: "Briefcase",
  "exclamation-triangle": "Warning"
};
const welcome$5 = {
  title: "Welcome to ComfyUI",
  getStarted: "Get Started"
};
const userSelect$5 = {
  newUser: "New user",
  enterUsername: "Enter a username",
  existingUser: "Existing user",
  selectUser: "Select a user",
  next: "Next"
};
const notSupported$5 = {
  title: "Your device is not supported",
  message: "Only following devices are supported:",
  learnMore: "Learn More",
  reportIssue: "Report Issue",
  supportedDevices: {
    macos: "MacOS (M1 or later)",
    windows: "Windows (Nvidia GPU with CUDA support)"
  },
  "continue": "Continue",
  continueTooltip: "I am sure my device is supported"
};
const downloadGit$5 = {
  title: "Download git",
  message: "Unable to locate git.  A working copy of git is required for normal operation.",
  instructions: "Please download and install the latest version for your operating system.  The Download git button below opens the git-scm.com downloads page.",
  warning: "If you are sure you do not need git installed, or there has been a mistake, you may click Skip to byapss this check.  Attempting to run ComfyUI without a working copy of git is not currently supported.",
  gitWebsite: "Download git",
  skip: "Skip"
};
const install$5 = {
  installLocation: "Install Location",
  migration: "Migration",
  desktopSettings: "Desktop Settings",
  chooseInstallationLocation: "Choose Installation Location",
  systemLocations: "System Locations",
  failedToSelectDirectory: "Failed to select directory",
  pathValidationFailed: "Failed to validate path",
  pathExists: "Directory already exists - please ensure you have backed up all data",
  cannotWrite: "Unable to write to the selected path",
  insufficientFreeSpace: "Insufficient space - minimum free space",
  isOneDrive: "OneDrive is not supported. Please install ComfyUI in another location.",
  nonDefaultDrive: "Please install ComfyUI on your system drive (eg. C:\\). Drives with different file systems may cause unpredicable issues. Models and other files can be stored on other drives after installation.",
  parentMissing: "Path does not exist - create the containing directory first",
  unhandledError: "Unknown error",
  installLocationDescription: "Select the directory for ComfyUI's user data. A python environment will be installed to the selected location.",
  installLocationTooltip: "ComfyUI's user data directory. Stores:\n- Python Environment\n- Models\n- Custom nodes\n",
  appDataLocationTooltip: "ComfyUI's app data directory. Stores:\n- Logs\n- Server configs",
  appPathLocationTooltip: "ComfyUI's app asset directory. Stores the ComfyUI code and assets",
  migrateFromExistingInstallation: "Migrate from Existing Installation",
  migrationSourcePathDescription: "If you have an existing ComfyUI installation, we can copy/link your existing user files and models to the new installation. Your existing ComfyUI installation will not be affected.",
  selectItemsToMigrate: "Select Items to Migrate",
  migrationOptional: "Migration is optional. If you don't have an existing installation, you can skip this step.",
  desktopAppSettings: "Desktop App Settings",
  desktopAppSettingsDescription: "Configure how ComfyUI behaves on your desktop. You can change these settings later.",
  gpu: "GPU",
  gpuSelection: {
    selectGpu: "Select GPU",
    selectGpuDescription: "Select the type of GPU you have",
    cpuMode: "CPU Mode",
    cpuModeDescription: "CPU mode is intended for developers and rare edge cases only.",
    cpuModeDescription2: "If you are not absolutely certain you need this, please ignore this box and select your GPU above.",
    enableCpuMode: "Enable CPU Mode",
    nvidiaDescription: "NVIDIA devices are directly supported using pytorch CUDA builds.",
    mpsDescription: "Apple Metal Performance Shaders are supported using pytorch nightly.",
    customSkipsPython: "This option skips the normal python setup.",
    customComfyNeedsPython: "ComfyUI will not work until python is setup",
    customManualVenv: "Manually configure python venv",
    customInstallRequirements: "Install all requirements and dependencies (e.g. custom torch)",
    customMayNotWork: "This is entirely unsupported, and may simply not work"
  },
  manualConfiguration: {
    title: "Manual Configuration",
    requirements: "Requirements",
    createVenv: "You will need to create a virtual environment in the following directory",
    virtualEnvironmentPath: "Virtual environment path",
    restartWhenFinished: "When you have finished configuring the virtual environment, please restart ComfyUI."
  },
  settings: {
    autoUpdate: "Automatic Updates",
    allowMetrics: "Usage Metrics",
    errorUpdatingConsent: "Error Updating Consent",
    errorUpdatingConsentDetail: "Failed to update metrics consent settings",
    autoUpdateDescription: "Automatically download updates when they become available. You will be notified before updates are installed.",
    allowMetricsDescription: "Help improve ComfyUI by sending anonymous usage metrics. No personal information or workflow content will be collected.",
    learnMoreAboutData: "Learn more about data collection",
    dataCollectionDialog: {
      title: "About Data Collection",
      whatWeCollect: "What we collect:",
      whatWeDoNotCollect: "What we don't collect:",
      collect: {
        errorReports: "Error message and stack trace",
        systemInfo: "Hardware, OS type, and app version",
        userJourneyEvents: "User journey events"
      },
      doNotCollect: {
        personalInformation: "Personal information",
        fileSystemInformation: "File system information",
        workflowContents: "Workflow contents",
        customNodeConfigurations: "Custom node configurations"
      },
      viewFullPolicy: "View full policy"
    },
    pythonMirrorPlaceholder: "Enter Python mirror URL",
    pypiMirrorPlaceholder: "Enter PyPI mirror URL",
    checkingMirrors: "Checking network access to python mirrors...",
    mirrorsReachable: "Network access to python mirrors is good",
    mirrorsUnreachable: "Network access to some python mirrors is bad",
    mirrorSettings: "Mirror Settings"
  },
  customNodes: "Custom Nodes",
  customNodesDescription: "Reinstall custom nodes from existing ComfyUI installations.",
  helpImprove: "Please help improve ComfyUI",
  moreInfo: "For more info, please read our",
  privacyPolicy: "privacy policy",
  metricsEnabled: "Metrics Enabled",
  metricsDisabled: "Metrics Disabled",
  updateConsent: "You previously opted in to reporting crashes. We are now tracking event-based metrics to help identify bugs and improve the app. No personal identifiable information is collected."
};
const serverStart$5 = {
  troubleshoot: "Troubleshoot",
  reportIssue: "Report Issue",
  openLogs: "Open Logs",
  showTerminal: "Show Terminal",
  process: {
    "initial-state": "Loading...",
    "python-setup": "Setting up Python Environment...",
    "starting-server": "Starting ComfyUI server...",
    ready: "Finishing...",
    error: "Unable to start ComfyUI Desktop"
  }
};
const serverConfig$5 = {
  modifiedConfigs: "You have modified the following server configurations. Restart to apply changes.",
  revertChanges: "Revert Changes",
  restart: "Restart"
};
const sideToolbar$5 = {
  themeToggle: "Toggle Theme",
  logout: "Logout",
  queue: "Queue",
  nodeLibrary: "Node Library",
  workflows: "Workflows",
  browseTemplates: "Browse example templates",
  openWorkflow: "Open workflow in local file system",
  newBlankWorkflow: "Create a new blank workflow",
  nodeLibraryTab: {
    sortOrder: "Sort Order"
  },
  modelLibrary: "Model Library",
  downloads: "Downloads",
  queueTab: {
    showFlatList: "Show Flat List",
    backToAllTasks: "Back to All Tasks",
    containImagePreview: "Fill Image Preview",
    coverImagePreview: "Fit Image Preview",
    clearPendingTasks: "Clear Pending Tasks",
    filter: "Filter Outputs",
    filters: {
      hideCached: "Hide Cached",
      hideCanceled: "Hide Canceled"
    }
  },
  workflowTab: {
    confirmDeleteTitle: "Delete workflow?",
    confirmDelete: "Are you sure you want to delete this workflow?",
    deleted: "Workflow deleted",
    deleteFailedTitle: "Delete failed",
    deleteFailed: "Attempt to delete the workflow failed.",
    dirtyCloseTitle: "Save Changes?",
    dirtyClose: "The files below have been changed.  Would you like to save them before closing?",
    dirtyCloseHint: "Hold Shift to close without prompt",
    confirmOverwriteTitle: "Overwrite existing file?",
    confirmOverwrite: "The file below already exists. Would you like to overwrite it?",
    workflowTreeType: {
      browse: "Browse",
      bookmarks: "Bookmarks",
      open: "Open"
    }
  }
};
const menu$5 = {
  hideMenu: "Hide Menu",
  showMenu: "Show Menu",
  batchCount: "Batch Count",
  batchCountTooltip: "The number of times the workflow generation should be queued",
  autoQueue: "Auto Queue",
  disabled: "Disabled",
  disabledTooltip: "The workflow will not be automatically queued",
  instant: "Instant",
  instantTooltip: "The workflow will be queued instantly after a generation finishes",
  onChange: "On Change",
  onChangeTooltip: "The workflow will be queued once a change is made",
  runWorkflow: "Run workflow (Shift to queue at front)",
  runWorkflowFront: "Run workflow (Queue at front)",
  run: "Run",
  execute: "Execute",
  interrupt: "Cancel current run",
  refresh: "Refresh node definitions",
  clipspace: "Open Clipspace",
  resetView: "Reset canvas view",
  clear: "Clear workflow",
  toggleBottomPanel: "Toggle Bottom Panel"
};
const tabMenu$5 = {
  duplicateTab: "Duplicate Tab",
  closeTab: "Close Tab",
  closeTabsToLeft: "Close Tabs to Left",
  closeTabsToRight: "Close Tabs to Right",
  closeOtherTabs: "Close Other Tabs",
  addToBookmarks: "Add to Bookmarks",
  removeFromBookmarks: "Remove from Bookmarks"
};
const templateWorkflows$5 = {
  title: "Get Started with a Template",
  category: {
    "ComfyUI Examples": "ComfyUI Examples",
    "Custom Nodes": "Custom Nodes",
    Basics: "Basics",
    Flux: "Flux",
    ControlNet: "ControlNet",
    Upscaling: "Upscaling",
    Video: "Video",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    "Area Composition": "Area Composition",
    "3D": "3D",
    Audio: "Audio"
  },
  template: {
    Flux: {
      flux_dev_checkpoint_example: "Flux Dev",
      flux_schnell: "Flux Schnell",
      flux_fill_inpaint_example: "Flux Inpaint",
      flux_fill_outpaint_example: "Flux Outpaint",
      flux_canny_model_example: "Flux Canny Model",
      flux_redux_model_example: "Flux Redux Model",
      flux_depth_lora_example: "Flux Depth Lora"
    },
    Basics: {
      "default": "Image Generation",
      image2image: "Image to Image",
      embedding_example: "Embedding",
      gligen_textbox_example: "Gligen Textbox",
      lora: "Lora",
      lora_multiple: "Lora Multiple",
      inpaint_example: "Inpaint",
      inpain_model_outpainting: "Outpaint"
    },
    ControlNet: {
      controlnet_example: "Scribble ControlNet",
      "2_pass_pose_worship": "Pose ControlNet 2 Pass",
      depth_controlnet: "Depth ControlNet",
      depth_t2i_adapter: "Depth T2I Adapter",
      mixing_controlnets: "Mixing ControlNets"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_latent_workflow: "Upscale",
      hiresfix_esrgan_workflow: "HiresFix ESRGAN Workflow",
      latent_upscale_different_prompt_model: "Latent Upscale Different Prompt Model"
    },
    Video: {
      text_to_video_wan: "Wan 2.1 Text to Video",
      image_to_video_wan: "Wan 2.1 Image to Video",
      image_to_video: "SVD Image to Video",
      txt_to_image_to_video: "SVD Text to Image to Video",
      ltxv_image_to_video: "LTXV Image to Video",
      ltxv_text_to_video: "LTXV Text to Video",
      mochi_text_to_video_example: "Mochi Text to Video",
      hunyuan_video_text_to_video: "Hunyuan Video Text to Video"
    },
    SD3_5: {
      sd3_5_simple_example: "SD3.5 Simple",
      sd3_5_large_canny_controlnet_example: "SD3.5 Large Canny ControlNet",
      sd3_5_large_depth: "SD3.5 Large Depth",
      sd3_5_large_blur: "SD3.5 Large Blur"
    },
    SDXL: {
      sdxl_simple_example: "SDXL Simple",
      sdxl_refiner_prompt_example: "SDXL Refiner Prompt",
      sdxl_revision_text_prompts: "SDXL Revision Text Prompts",
      sdxl_revision_zero_positive: "SDXL Revision Zero Positive",
      sdxlturbo_example: "SDXL Turbo"
    },
    "Area Composition": {
      area_composition: "Area Composition",
      area_composition_reversed: "Area Composition Reversed",
      area_composition_square_area_for_subject: "Area Composition Square Area for Subject"
    },
    "3D": {
      stable_zero123_example: "Stable Zero123",
      "hunyuan3d-non-multiview-train": "Hunyuan3D 2.0",
      "hunyuan-3d-multiview-elf": "Hunyuan3D 2.0 MV",
      "hunyuan-3d-turbo": "Hunyuan3D 2.0 MV Turbo"
    },
    Audio: {
      stable_audio_example: "Stable Audio"
    }
  }
};
const graphCanvasMenu$5 = {
  zoomIn: "Zoom In",
  zoomOut: "Zoom Out",
  resetView: "Reset View",
  fitView: "Fit View",
  selectMode: "Select Mode",
  panMode: "Pan Mode",
  toggleLinkVisibility: "Toggle Link Visibility"
};
const groupNode$5 = {
  create: "Create group node",
  enterName: "Enter name"
};
const nodeTemplates$5 = {
  saveAsTemplate: "Save as template",
  enterName: "Enter name"
};
const workflowService$5 = {
  exportWorkflow: "Export Workflow",
  enterFilename: "Enter the filename",
  saveWorkflow: "Save workflow"
};
const electronFileDownload$5 = {
  inProgress: "In Progress",
  pause: "Pause Download",
  paused: "Paused",
  resume: "Resume Download",
  cancel: "Cancel Download",
  cancelled: "Cancelled"
};
const maskEditor$5 = {
  Invert: "Invert",
  Clear: "Clear",
  "Brush Settings": "Brush Settings",
  "Brush Shape": "Brush Shape",
  Thickness: "Thickness",
  Opacity: "Opacity",
  Hardness: "Hardness",
  "Smoothing Precision": "Smoothing Precision",
  "Reset to Default": "Reset to Default",
  "Paint Bucket Settings": "Paint Bucket Settings",
  Tolerance: "Tolerance",
  "Fill Opacity": "Fill Opacity",
  "Color Select Settings": "Color Select Settings",
  "Selection Opacity": "Selection Opacity",
  "Live Preview": "Live Preview",
  "Apply to Whole Image": "Apply to Whole Image",
  Method: "Method",
  "Stop at mask": "Stop at mask",
  "Mask Tolerance": "Mask Tolerance",
  Layers: "Layers",
  "Mask Layer": "Mask Layer",
  "Mask Opacity": "Mask Opacity",
  "Image Layer": "Image Layer"
};
const menuLabels$5 = {
  Workflow: "Workflow",
  Edit: "Edit",
  Help: "Help",
  "Open Custom Nodes Folder": "Open Custom Nodes Folder",
  "Open Inputs Folder": "Open Inputs Folder",
  "Open Logs Folder": "Open Logs Folder",
  "Open extra_model_paths_yaml": "Open extra_model_paths.yaml",
  "Open Models Folder": "Open Models Folder",
  "Open Outputs Folder": "Open Outputs Folder",
  "Open DevTools": "Open DevTools",
  "Desktop User Guide": "Desktop User Guide",
  Quit: "Quit",
  Reinstall: "Reinstall",
  Restart: "Restart",
  "Browse Templates": "Browse Templates",
  "Delete Selected Items": "Delete Selected Items",
  "Fit view to selected nodes": "Fit view to selected nodes",
  "Reset View": "Reset View",
  "Canvas Toggle Link Visibility": "Canvas Toggle Link Visibility",
  "Canvas Toggle Lock": "Canvas Toggle Lock",
  "Pin/Unpin Selected Items": "Pin/Unpin Selected Items",
  "Bypass/Unbypass Selected Nodes": "Bypass/Unbypass Selected Nodes",
  "Collapse/Expand Selected Nodes": "Collapse/Expand Selected Nodes",
  "Mute/Unmute Selected Nodes": "Mute/Unmute Selected Nodes",
  "Pin/Unpin Selected Nodes": "Pin/Unpin Selected Nodes",
  "Zoom In": "Zoom In",
  "Zoom Out": "Zoom Out",
  "Clear Pending Tasks": "Clear Pending Tasks",
  "Clear Workflow": "Clear Workflow",
  "Duplicate Current Workflow": "Duplicate Current Workflow",
  Export: "Export",
  "Export (API)": "Export (API)",
  "Give Feedback": "Give Feedback",
  "Fit Group To Contents": "Fit Group To Contents",
  "Group Selected Nodes": "Group Selected Nodes",
  "Convert selected nodes to group node": "Convert selected nodes to group node",
  "Manage group nodes": "Manage group nodes",
  "Ungroup selected group nodes": "Ungroup selected group nodes",
  "About ComfyUI": "About ComfyUI",
  "Comfy-Org Discord": "Comfy-Org Discord",
  "ComfyUI Docs": "ComfyUI Docs",
  "ComfyUI Forum": "ComfyUI Forum",
  "ComfyUI Issues": "ComfyUI Issues",
  Interrupt: "Interrupt",
  "Load Default Workflow": "Load Default Workflow",
  "Custom Nodes Manager": "Custom Nodes Manager",
  "Toggle Progress Dialog": "Toggle Progress Dialog",
  New: "New",
  Clipspace: "Clipspace",
  Open: "Open",
  "Queue Prompt": "Queue Prompt",
  "Queue Prompt (Front)": "Queue Prompt (Front)",
  Redo: "Redo",
  "Refresh Node Definitions": "Refresh Node Definitions",
  Save: "Save",
  "Save As": "Save As",
  "Show Settings Dialog": "Show Settings Dialog",
  "Toggle Theme (Dark/Light)": "Toggle Theme (Dark/Light)",
  Undo: "Undo",
  "Close Current Workflow": "Close Current Workflow",
  "Next Opened Workflow": "Next Opened Workflow",
  "Previous Opened Workflow": "Previous Opened Workflow",
  "Toggle Search Box": "Toggle Search Box",
  "Toggle Bottom Panel": "Toggle Bottom Panel",
  "Toggle Terminal Bottom Panel": "Toggle Terminal Bottom Panel",
  "Toggle Logs Bottom Panel": "Toggle Logs Bottom Panel",
  "Toggle Focus Mode": "Toggle Focus Mode",
  "Toggle Model Library Sidebar": "Toggle Model Library Sidebar",
  "Toggle Node Library Sidebar": "Toggle Node Library Sidebar",
  "Toggle Queue Sidebar": "Toggle Queue Sidebar",
  "Toggle Workflows Sidebar": "Toggle Workflows Sidebar"
};
const desktopMenu$5 = {
  reinstall: "Reinstall",
  confirmReinstall: "This will clear your extra_models_config.yaml file,\nand begin installation again.\n\nAre you sure?",
  quit: "Quit",
  confirmQuit: "There are unsaved workflows open; any unsaved changes will be lost.  Ignore this and quit?"
};
const settingsCategories$5 = {
  "Comfy-Desktop": "Comfy-Desktop",
  General: "General",
  Appearance: "Appearance",
  ColorPalette: "Color Palette",
  Comfy: "Comfy",
  Workflow: "Workflow",
  DevMode: "Dev Mode",
  LiteGraph: "Lite Graph",
  "Node Widget": "Node Widget",
  Node: "Node",
  Extension: "Extension",
  Canvas: "Canvas",
  Link: "Link",
  Group: "Group",
  Menu: "Menu",
  Keybinding: "Keybinding",
  LinkRelease: "Link Release",
  Graph: "Graph",
  Locale: "Locale",
  "Mask Editor": "Mask Editor",
  BrushAdjustment: "Brush Adjustment",
  NewEditor: "New Editor",
  ModelLibrary: "Model Library",
  NodeInputConversionSubmenus: "Node Input Conversion Submenus",
  NodeLibrary: "Node Library",
  "Node Search Box": "Node Search Box",
  Pointer: "Pointer",
  Queue: "Queue",
  QueueButton: "Queue Button",
  RerouteBeta: "Reroute Beta",
  Server: "Server",
  Settings: "Settings",
  Sidebar: "Sidebar",
  "Tree Explorer": "Tree Explorer",
  Validation: "Validation",
  Window: "Window",
  "Server-Config": "Server-Config",
  About: "About",
  EditTokenWeight: "Edit Token Weight",
  CustomColorPalettes: "Custom Color Palettes",
  UV: "UV",
  ContextMenu: "Context Menu"
};
const serverConfigItems$5 = {
  listen: {
    name: "Host: The IP address to listen on"
  },
  port: {
    name: "Port: The port to listen on"
  },
  "tls-keyfile": {
    name: "TLS Key File: Path to TLS key file for HTTPS"
  },
  "tls-certfile": {
    name: "TLS Certificate File: Path to TLS certificate file for HTTPS"
  },
  "enable-cors-header": {
    name: 'Enable CORS header: Use "*" for all origins or specify domain'
  },
  "max-upload-size": {
    name: "Maximum upload size (MB)"
  },
  "cuda-device": {
    name: "CUDA device index to use"
  },
  "cuda-malloc": {
    name: "Use CUDA malloc for memory allocation"
  },
  "global-precision": {
    name: "Global floating point precision",
    tooltip: "Global floating point precision"
  },
  "unet-precision": {
    name: "UNET precision",
    tooltip: "UNET precision"
  },
  "vae-precision": {
    name: "VAE precision",
    tooltip: "VAE precision"
  },
  "cpu-vae": {
    name: "Run VAE on CPU"
  },
  "text-encoder-precision": {
    name: "Text Encoder precision",
    tooltip: "Text Encoder precision"
  },
  "force-channels-last": {
    name: "Force channels-last memory format"
  },
  directml: {
    name: "DirectML device index"
  },
  "disable-ipex-optimize": {
    name: "Disable IPEX optimization"
  },
  "preview-method": {
    name: "Method used for latent previews"
  },
  "preview-size": {
    name: "Size of preview images"
  },
  "cache-classic": {
    name: "Use classic cache system"
  },
  "cache-lru": {
    name: "Use LRU caching with a maximum of N node results cached.",
    tooltip: "May use more RAM/VRAM."
  },
  "cross-attention-method": {
    name: "Cross attention method"
  },
  "disable-xformers": {
    name: "Disable xFormers optimization"
  },
  "force-upcast-attention": {
    name: "Force attention upcast"
  },
  "dont-upcast-attention": {
    name: "Prevent attention upcast"
  },
  "vram-management": {
    name: "VRAM management mode"
  },
  "reserve-vram": {
    name: "Reserved VRAM (GB)",
    tooltip: "Set the amount of vram in GB you want to reserve for use by your OS/other software. By default some amount is reverved depending on your OS."
  },
  "default-hashing-function": {
    name: "Default hashing function for model files"
  },
  "disable-smart-memory": {
    name: "Disable smart memory management",
    tooltip: "Force ComfyUI to aggressively offload to regular ram instead of keeping models in vram when it can."
  },
  deterministic: {
    name: "Make pytorch use slower deterministic algorithms when it can.",
    tooltip: "Note that this might not make images deterministic in all cases."
  },
  fast: {
    name: "Enable some untested and potentially quality deteriorating optimizations."
  },
  "dont-print-server": {
    name: "Don't print server output to console."
  },
  "disable-metadata": {
    name: "Disable saving prompt metadata in files."
  },
  "disable-all-custom-nodes": {
    name: "Disable loading all custom nodes."
  },
  "log-level": {
    name: "Logging verbosity level"
  },
  "input-directory": {
    name: "Input directory"
  },
  "output-directory": {
    name: "Output directory"
  }
};
const serverConfigCategories$5 = {
  Network: "Network",
  CUDA: "CUDA",
  Inference: "Inference",
  Memory: "Memory",
  Preview: "Preview",
  Cache: "Cache",
  Attention: "Attention",
  General: "General",
  Directories: "Directories"
};
const nodeCategories$5 = {
  _for_testing: "_for_testing",
  custom_sampling: "custom_sampling",
  noise: "noise",
  sampling: "sampling",
  schedulers: "schedulers",
  guiders: "guiders",
  image: "image",
  preprocessors: "preprocessors",
  advanced: "advanced",
  loaders: "loaders",
  model_merging: "model_merging",
  attention_experiments: "attention_experiments",
  conditioning: "conditioning",
  flux: "flux",
  hooks: "hooks",
  combine: "combine",
  "cond single": "cond single",
  controlnet: "controlnet",
  inpaint: "inpaint",
  scheduling: "scheduling",
  create: "create",
  mask: "mask",
  deprecated: "deprecated",
  latent: "latent",
  video: "video",
  audio: "audio",
  "3d": "3d",
  ltxv: "ltxv",
  sd3: "sd3",
  sigmas: "sigmas",
  model_patches: "model_patches",
  unet: "unet",
  gligen: "gligen",
  video_models: "video_models",
  postprocessing: "postprocessing",
  transform: "transform",
  batch: "batch",
  upscaling: "upscaling",
  instructpix2pix: "instructpix2pix",
  compositing: "compositing",
  samplers: "samplers",
  operations: "operations",
  debug: "debug",
  model: "model",
  model_specific: "model_specific",
  "cond pair": "cond pair",
  photomaker: "photomaker",
  animation: "animation",
  api: "api",
  upscale_diffusion: "upscale_diffusion",
  clip: "clip",
  guidance: "guidance",
  stable_cascade: "stable_cascade",
  "3d_models": "3d_models",
  style_model: "style_model"
};
const dataTypes$5 = {
  AUDIO: "AUDIO",
  BOOLEAN: "BOOLEAN",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP_VISION",
  CLIP_VISION_OUTPUT: "CLIP_VISION_OUTPUT",
  COMBO: "COMBO",
  CONDITIONING: "CONDITIONING",
  CONTROL_NET: "CONTROL_NET",
  FLOAT: "FLOAT",
  FLOATS: "FLOATS",
  GLIGEN: "GLIGEN",
  GUIDER: "GUIDER",
  HOOK_KEYFRAMES: "HOOK_KEYFRAMES",
  HOOKS: "HOOKS",
  IMAGE: "IMAGE",
  INT: "INT",
  LATENT: "LATENT",
  LATENT_OPERATION: "LATENT_OPERATION",
  LOAD_3D: "LOAD_3D",
  LOAD_3D_ANIMATION: "LOAD_3D_ANIMATION",
  MASK: "MASK",
  MESH: "MESH",
  MODEL: "MODEL",
  NOISE: "NOISE",
  PHOTOMAKER: "PHOTOMAKER",
  SAMPLER: "SAMPLER",
  SIGMAS: "SIGMAS",
  STRING: "STRING",
  STYLE_MODEL: "STYLE_MODEL",
  TIMESTEPS_RANGE: "TIMESTEPS_RANGE",
  UPSCALE_MODEL: "UPSCALE_MODEL",
  VAE: "VAE",
  VOXEL: "VOXEL",
  WEBCAM: "WEBCAM"
};
const maintenance$5 = {
  title: "Maintenance",
  allOk: "No issues were detected.",
  status: "Status",
  detected: "Detected",
  refreshing: "Refreshing",
  None: "None",
  OK: "OK",
  Skipped: "Skipped",
  showManual: "Show maintenance tasks",
  confirmTitle: "Are you sure?",
  terminalDefaultMessage: "When you run a troubleshooting command, any output will be shown here.",
  consoleLogs: "Console Logs",
  error: {
    toastTitle: "Task error",
    taskFailed: "Task failed to run.",
    cannotContinue: "Unable to continue - errors remain",
    defaultDescription: "An error occurred while running a maintenance task."
  }
};
const missingModelsDialog$5 = {
  doNotAskAgain: "Don't show this again",
  missingModels: "Missing Models",
  missingModelsMessage: "When loading the graph, the following models were not found"
};
const desktopUpdate$5 = {
  title: "Updating ComfyUI Desktop",
  description: "ComfyUI Desktop is installing new dependencies.  This may take a few minutes.",
  terminalDefaultMessage: "Any console output from the update will be shown here."
};
const clipboard$5 = {
  successMessage: "Copied to clipboard",
  errorMessage: "Failed to copy to clipboard",
  errorNotSupported: "Clipboard API not supported in your browser"
};
const load3d$5 = {
  switchCamera: "Switch Camera",
  showGrid: "Show Grid",
  backgroundColor: "Background Color",
  lightIntensity: "Light Intensity",
  fov: "FOV",
  previewOutput: "Preview Output",
  uploadBackgroundImage: "Upload Background Image",
  removeBackgroundImage: "Remove Background Image",
  loadingModel: "Loading 3D Model...",
  upDirection: "Up Direction",
  materialMode: "Material Mode",
  scene: "Scene",
  model: "Model",
  camera: "Camera",
  light: "Light",
  switchingMaterialMode: "Switching Material Mode...",
  edgeThreshold: "Edge Threshold",
  "export": "Export",
  exportModel: "Export Model",
  exportingModel: "Exporting model..."
};
const en = {
  g: g$5,
  manager: manager$5,
  issueReport: issueReport$5,
  color: color$5,
  contextMenu: contextMenu$5,
  icon: icon$5,
  welcome: welcome$5,
  userSelect: userSelect$5,
  notSupported: notSupported$5,
  downloadGit: downloadGit$5,
  install: install$5,
  serverStart: serverStart$5,
  serverConfig: serverConfig$5,
  sideToolbar: sideToolbar$5,
  menu: menu$5,
  tabMenu: tabMenu$5,
  templateWorkflows: templateWorkflows$5,
  graphCanvasMenu: graphCanvasMenu$5,
  groupNode: groupNode$5,
  nodeTemplates: nodeTemplates$5,
  workflowService: workflowService$5,
  electronFileDownload: electronFileDownload$5,
  maskEditor: maskEditor$5,
  menuLabels: menuLabels$5,
  desktopMenu: desktopMenu$5,
  settingsCategories: settingsCategories$5,
  serverConfigItems: serverConfigItems$5,
  serverConfigCategories: serverConfigCategories$5,
  nodeCategories: nodeCategories$5,
  dataTypes: dataTypes$5,
  maintenance: maintenance$5,
  missingModelsDialog: missingModelsDialog$5,
  desktopUpdate: desktopUpdate$5,
  clipboard: clipboard$5,
  load3d: load3d$5
};
const AddNoise$5 = {
  display_name: "AddNoise",
  inputs: {
    model: {
      name: "model"
    },
    noise: {
      name: "noise"
    },
    sigmas: {
      name: "sigmas"
    },
    latent_image: {
      name: "latent_image"
    }
  }
};
const AlignYourStepsScheduler$5 = {
  display_name: "AlignYourStepsScheduler",
  inputs: {
    model_type: {
      name: "model_type"
    },
    steps: {
      name: "steps"
    },
    denoise: {
      name: "denoise"
    }
  }
};
const BasicGuider$5 = {
  display_name: "BasicGuider",
  inputs: {
    model: {
      name: "model"
    },
    conditioning: {
      name: "conditioning"
    }
  }
};
const BasicScheduler$5 = {
  display_name: "BasicScheduler",
  inputs: {
    model: {
      name: "model"
    },
    scheduler: {
      name: "scheduler"
    },
    steps: {
      name: "steps"
    },
    denoise: {
      name: "denoise"
    }
  }
};
const BetaSamplingScheduler$5 = {
  display_name: "BetaSamplingScheduler",
  inputs: {
    model: {
      name: "model"
    },
    steps: {
      name: "steps"
    },
    alpha: {
      name: "alpha"
    },
    beta: {
      name: "beta"
    }
  }
};
const Canny$5 = {
  display_name: "Canny",
  inputs: {
    image: {
      name: "image"
    },
    low_threshold: {
      name: "low_threshold"
    },
    high_threshold: {
      name: "high_threshold"
    }
  }
};
const CFGGuider$5 = {
  display_name: "CFGGuider",
  inputs: {
    model: {
      name: "model"
    },
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    cfg: {
      name: "cfg"
    }
  }
};
const CheckpointLoader$5 = {
  display_name: "Load Checkpoint With Config (DEPRECATED)",
  inputs: {
    config_name: {
      name: "config_name"
    },
    ckpt_name: {
      name: "ckpt_name"
    }
  }
};
const CheckpointLoaderSimple$5 = {
  display_name: "Load Checkpoint",
  description: "Loads a diffusion model checkpoint, diffusion models are used to denoise latents.",
  inputs: {
    ckpt_name: {
      name: "ckpt_name",
      tooltip: "The name of the checkpoint (model) to load."
    }
  },
  outputs: {
    "0": {
      tooltip: "The model used for denoising latents."
    },
    "1": {
      tooltip: "The CLIP model used for encoding text prompts."
    },
    "2": {
      tooltip: "The VAE model used for encoding and decoding images to and from latent space."
    }
  }
};
const CheckpointSave$5 = {
  display_name: "Save Checkpoint",
  inputs: {
    model: {
      name: "model"
    },
    clip: {
      name: "clip"
    },
    vae: {
      name: "vae"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const CLIPAttentionMultiply$5 = {
  display_name: "CLIPAttentionMultiply",
  inputs: {
    clip: {
      name: "clip"
    },
    q: {
      name: "q"
    },
    k: {
      name: "k"
    },
    v: {
      name: "v"
    },
    out: {
      name: "out"
    }
  }
};
const CLIPLoader$5 = {
  display_name: "Load CLIP",
  description: "[Recipes]\n\nstable_diffusion: clip-l\nstable_cascade: clip-g\nsd3: t5 xxl/ clip-g / clip-l\nstable_audio: t5 base\nmochi: t5 xxl\ncosmos: old t5 xxl\nlumina2: gemma 2 2B\nwan: umt5 xxl",
  inputs: {
    clip_name: {
      name: "clip_name"
    },
    type: {
      name: "type"
    },
    device: {
      name: "device"
    }
  }
};
const CLIPMergeAdd$5 = {
  display_name: "CLIPMergeAdd",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    }
  }
};
const CLIPMergeSimple$5 = {
  display_name: "CLIPMergeSimple",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const CLIPMergeSubtract$5 = {
  display_name: "CLIPMergeSubtract",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    multiplier: {
      name: "multiplier"
    }
  }
};
const CLIPSave$5 = {
  display_name: "CLIPSave",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const CLIPSetLastLayer$5 = {
  display_name: "CLIP Set Last Layer",
  inputs: {
    clip: {
      name: "clip"
    },
    stop_at_clip_layer: {
      name: "stop_at_clip_layer"
    }
  }
};
const CLIPTextEncode$5 = {
  display_name: "CLIP Text Encode (Prompt)",
  description: "Encodes a text prompt using a CLIP model into an embedding that can be used to guide the diffusion model towards generating specific images.",
  inputs: {
    text: {
      name: "text",
      tooltip: "The text to be encoded."
    },
    clip: {
      name: "clip",
      tooltip: "The CLIP model used for encoding the text."
    }
  },
  outputs: {
    "0": {
      tooltip: "A conditioning containing the embedded text used to guide the diffusion model."
    }
  }
};
const CLIPTextEncodeControlnet$5 = {
  display_name: "CLIPTextEncodeControlnet",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning: {
      name: "conditioning"
    },
    text: {
      name: "text"
    }
  }
};
const CLIPTextEncodeFlux$5 = {
  display_name: "CLIPTextEncodeFlux",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip_l"
    },
    t5xxl: {
      name: "t5xxl"
    },
    guidance: {
      name: "guidance"
    }
  }
};
const CLIPTextEncodeHunyuanDiT$5 = {
  display_name: "CLIPTextEncodeHunyuanDiT",
  inputs: {
    clip: {
      name: "clip"
    },
    bert: {
      name: "bert"
    },
    mt5xl: {
      name: "mt5xl"
    }
  }
};
const CLIPTextEncodeLumina2$5 = {
  display_name: "CLIP Text Encode for Lumina2",
  description: "Encodes a system prompt and a user prompt using a CLIP model into an embedding that can be used to guide the diffusion model towards generating specific images.",
  inputs: {
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2 provide two types of system prompts:Superior: You are an assistant designed to generate superior images with the superior degree of image-text alignment based on textual prompts or user prompts. Alignment: You are an assistant designed to generate high-quality images with the highest degree of image-text alignment based on textual prompts."
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "The text to be encoded."
    },
    clip: {
      name: "clip",
      tooltip: "The CLIP model used for encoding the text."
    }
  },
  outputs: {
    "0": {
      tooltip: "A conditioning containing the embedded text used to guide the diffusion model."
    }
  }
};
const CLIPTextEncodePixArtAlpha$5 = {
  display_name: "CLIPTextEncodePixArtAlpha",
  description: "Encodes text and sets the resolution conditioning for PixArt Alpha. Does not apply to PixArt Sigma.",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    text: {
      name: "text"
    },
    clip: {
      name: "clip"
    }
  }
};
const CLIPTextEncodeSD3$5 = {
  display_name: "CLIPTextEncodeSD3",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip_l"
    },
    clip_g: {
      name: "clip_g"
    },
    t5xxl: {
      name: "t5xxl"
    },
    empty_padding: {
      name: "empty_padding"
    }
  }
};
const CLIPTextEncodeSDXL$5 = {
  display_name: "CLIPTextEncodeSDXL",
  inputs: {
    clip: {
      name: "clip"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    crop_w: {
      name: "crop_w"
    },
    crop_h: {
      name: "crop_h"
    },
    target_width: {
      name: "target_width"
    },
    target_height: {
      name: "target_height"
    },
    text_g: {
      name: "text_g"
    },
    text_l: {
      name: "text_l"
    }
  }
};
const CLIPTextEncodeSDXLRefiner$5 = {
  display_name: "CLIPTextEncodeSDXLRefiner",
  inputs: {
    ascore: {
      name: "ascore"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    text: {
      name: "text"
    },
    clip: {
      name: "clip"
    }
  }
};
const CLIPVisionEncode$5 = {
  display_name: "CLIP Vision Encode",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    image: {
      name: "image"
    },
    crop: {
      name: "crop"
    }
  }
};
const CLIPVisionLoader$5 = {
  display_name: "Load CLIP Vision",
  inputs: {
    clip_name: {
      name: "clip_name"
    }
  }
};
const CombineHooks2$5 = {
  display_name: "Combine Hooks [2]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    }
  }
};
const CombineHooks4$5 = {
  display_name: "Combine Hooks [4]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    }
  }
};
const CombineHooks8$5 = {
  display_name: "Combine Hooks [8]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    },
    hooks_E: {
      name: "hooks_E"
    },
    hooks_F: {
      name: "hooks_F"
    },
    hooks_G: {
      name: "hooks_G"
    },
    hooks_H: {
      name: "hooks_H"
    }
  }
};
const ConditioningAverage$5 = {
  display_name: "ConditioningAverage",
  inputs: {
    conditioning_to: {
      name: "conditioning_to"
    },
    conditioning_from: {
      name: "conditioning_from"
    },
    conditioning_to_strength: {
      name: "conditioning_to_strength"
    }
  }
};
const ConditioningCombine$5 = {
  display_name: "Conditioning (Combine)",
  inputs: {
    conditioning_1: {
      name: "conditioning_1"
    },
    conditioning_2: {
      name: "conditioning_2"
    }
  }
};
const ConditioningConcat$5 = {
  display_name: "Conditioning (Concat)",
  inputs: {
    conditioning_to: {
      name: "conditioning_to"
    },
    conditioning_from: {
      name: "conditioning_from"
    }
  }
};
const ConditioningSetArea$5 = {
  display_name: "Conditioning (Set Area)",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    strength: {
      name: "strength"
    }
  }
};
const ConditioningSetAreaPercentage$5 = {
  display_name: "Conditioning (Set Area with Percentage)",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    strength: {
      name: "strength"
    }
  }
};
const ConditioningSetAreaPercentageVideo$5 = {
  display_name: "ConditioningSetAreaPercentageVideo",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    temporal: {
      name: "temporal"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    },
    strength: {
      name: "strength"
    }
  }
};
const ConditioningSetAreaStrength$5 = {
  display_name: "ConditioningSetAreaStrength",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    strength: {
      name: "strength"
    }
  }
};
const ConditioningSetDefaultCombine$5 = {
  display_name: "Cond Set Default Combine",
  inputs: {
    cond: {
      name: "cond"
    },
    cond_DEFAULT: {
      name: "cond_DEFAULT"
    },
    hooks: {
      name: "hooks"
    }
  }
};
const ConditioningSetMask$5 = {
  display_name: "Conditioning (Set Mask)",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    mask: {
      name: "mask"
    },
    strength: {
      name: "strength"
    },
    set_cond_area: {
      name: "set_cond_area"
    }
  }
};
const ConditioningSetProperties$5 = {
  display_name: "Cond Set Props",
  inputs: {
    cond_NEW: {
      name: "cond_NEW"
    },
    strength: {
      name: "strength"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    mask: {
      name: "mask"
    },
    hooks: {
      name: "hooks"
    },
    timesteps: {
      name: "timesteps"
    }
  }
};
const ConditioningSetPropertiesAndCombine$5 = {
  display_name: "Cond Set Props Combine",
  inputs: {
    cond: {
      name: "cond"
    },
    cond_NEW: {
      name: "cond_NEW"
    },
    strength: {
      name: "strength"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    mask: {
      name: "mask"
    },
    hooks: {
      name: "hooks"
    },
    timesteps: {
      name: "timesteps"
    }
  }
};
const ConditioningSetTimestepRange$5 = {
  display_name: "ConditioningSetTimestepRange",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    start: {
      name: "start"
    },
    end: {
      name: "end"
    }
  }
};
const ConditioningStableAudio$5 = {
  display_name: "ConditioningStableAudio",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    seconds_start: {
      name: "seconds_start"
    },
    seconds_total: {
      name: "seconds_total"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ConditioningTimestepsRange$5 = {
  display_name: "Timesteps Range",
  inputs: {
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    }
  },
  outputs: {
    "1": {
      name: "BEFORE_RANGE"
    },
    "2": {
      name: "AFTER_RANGE"
    }
  }
};
const ConditioningZeroOut$5 = {
  display_name: "ConditioningZeroOut",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const ControlNetApply$5 = {
  display_name: "Apply ControlNet (OLD)",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    control_net: {
      name: "control_net"
    },
    image: {
      name: "image"
    },
    strength: {
      name: "strength"
    }
  }
};
const ControlNetApplyAdvanced$5 = {
  display_name: "Apply ControlNet",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    control_net: {
      name: "control_net"
    },
    image: {
      name: "image"
    },
    strength: {
      name: "strength"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetApplySD3$5 = {
  display_name: "Apply Controlnet with VAE",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    control_net: {
      name: "control_net"
    },
    vae: {
      name: "vae"
    },
    image: {
      name: "image"
    },
    strength: {
      name: "strength"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetInpaintingAliMamaApply$5 = {
  display_name: "ControlNetInpaintingAliMamaApply",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    control_net: {
      name: "control_net"
    },
    vae: {
      name: "vae"
    },
    image: {
      name: "image"
    },
    mask: {
      name: "mask"
    },
    strength: {
      name: "strength"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetLoader$5 = {
  display_name: "Load ControlNet Model",
  inputs: {
    control_net_name: {
      name: "control_net_name"
    }
  }
};
const CosmosImageToVideoLatent$5 = {
  display_name: "CosmosImageToVideoLatent",
  inputs: {
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    },
    start_image: {
      name: "start_image"
    },
    end_image: {
      name: "end_image"
    }
  }
};
const CreateHookKeyframe$5 = {
  display_name: "Create Hook Keyframe",
  inputs: {
    strength_mult: {
      name: "strength_mult"
    },
    start_percent: {
      name: "start_percent"
    },
    prev_hook_kf: {
      name: "prev_hook_kf"
    }
  },
  outputs: {
    "0": {
      name: "HOOK_KF"
    }
  }
};
const CreateHookKeyframesFromFloats$5 = {
  display_name: "Create Hook Keyframes From Floats",
  inputs: {
    floats_strength: {
      name: "floats_strength"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    },
    print_keyframes: {
      name: "print_keyframes"
    },
    prev_hook_kf: {
      name: "prev_hook_kf"
    }
  },
  outputs: {
    "0": {
      name: "HOOK_KF"
    }
  }
};
const CreateHookKeyframesInterpolated$5 = {
  display_name: "Create Hook Keyframes Interp.",
  inputs: {
    strength_start: {
      name: "strength_start"
    },
    strength_end: {
      name: "strength_end"
    },
    interpolation: {
      name: "interpolation"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    },
    keyframes_count: {
      name: "keyframes_count"
    },
    print_keyframes: {
      name: "print_keyframes"
    },
    prev_hook_kf: {
      name: "prev_hook_kf"
    }
  },
  outputs: {
    "0": {
      name: "HOOK_KF"
    }
  }
};
const CreateHookLora$5 = {
  display_name: "Create Hook LoRA",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    strength_model: {
      name: "strength_model"
    },
    strength_clip: {
      name: "strength_clip"
    },
    prev_hooks: {
      name: "prev_hooks"
    }
  }
};
const CreateHookLoraModelOnly$5 = {
  display_name: "Create Hook LoRA (MO)",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    strength_model: {
      name: "strength_model"
    },
    prev_hooks: {
      name: "prev_hooks"
    }
  }
};
const CreateHookModelAsLora$5 = {
  display_name: "Create Hook Model as LoRA",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    },
    strength_model: {
      name: "strength_model"
    },
    strength_clip: {
      name: "strength_clip"
    },
    prev_hooks: {
      name: "prev_hooks"
    }
  }
};
const CreateHookModelAsLoraModelOnly$5 = {
  display_name: "Create Hook Model as LoRA (MO)",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    },
    strength_model: {
      name: "strength_model"
    },
    prev_hooks: {
      name: "prev_hooks"
    }
  }
};
const CropMask$5 = {
  display_name: "CropMask",
  inputs: {
    mask: {
      name: "mask"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    }
  }
};
const DiffControlNetLoader$5 = {
  display_name: "Load ControlNet Model (diff)",
  inputs: {
    model: {
      name: "model"
    },
    control_net_name: {
      name: "control_net_name"
    }
  }
};
const DifferentialDiffusion$5 = {
  display_name: "Differential Diffusion",
  inputs: {
    model: {
      name: "model"
    }
  }
};
const DiffusersLoader$5 = {
  display_name: "DiffusersLoader",
  inputs: {
    model_path: {
      name: "model_path"
    }
  }
};
const DisableNoise$5 = {
  display_name: "DisableNoise"
};
const DualCFGGuider$5 = {
  display_name: "DualCFGGuider",
  inputs: {
    model: {
      name: "model"
    },
    cond1: {
      name: "cond1"
    },
    cond2: {
      name: "cond2"
    },
    negative: {
      name: "negative"
    },
    cfg_conds: {
      name: "cfg_conds"
    },
    cfg_cond2_negative: {
      name: "cfg_cond2_negative"
    }
  }
};
const DualCLIPLoader$5 = {
  display_name: "DualCLIPLoader",
  description: "[Recipes]\n\nsdxl: clip-l, clip-g\nsd3: clip-l, clip-g / clip-l, t5 / clip-g, t5\nflux: clip-l, t5",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    type: {
      name: "type"
    },
    device: {
      name: "device"
    }
  }
};
const EmptyCosmosLatentVideo$5 = {
  display_name: "EmptyCosmosLatentVideo",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const EmptyHunyuanLatentVideo$5 = {
  display_name: "EmptyHunyuanLatentVideo",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const EmptyImage$5 = {
  display_name: "EmptyImage",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    batch_size: {
      name: "batch_size"
    },
    color: {
      name: "color"
    }
  }
};
const EmptyLatentAudio$5 = {
  display_name: "EmptyLatentAudio",
  inputs: {
    seconds: {
      name: "seconds"
    },
    batch_size: {
      name: "batch_size",
      tooltip: "The number of latent images in the batch."
    }
  }
};
const EmptyLatentHunyuan3Dv2$5 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    resolution: {
      name: "resolution"
    },
    batch_size: {
      name: "batch_size",
      tooltip: "The number of latent images in the batch."
    }
  }
};
const EmptyLatentImage$5 = {
  display_name: "Empty Latent Image",
  description: "Create a new batch of empty latent images to be denoised via sampling.",
  inputs: {
    width: {
      name: "width",
      tooltip: "The width of the latent images in pixels."
    },
    height: {
      name: "height",
      tooltip: "The height of the latent images in pixels."
    },
    batch_size: {
      name: "batch_size",
      tooltip: "The number of latent images in the batch."
    }
  },
  outputs: {
    "0": {
      tooltip: "The empty latent image batch."
    }
  }
};
const EmptyLTXVLatentVideo$5 = {
  display_name: "EmptyLTXVLatentVideo",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const EmptyMochiLatentVideo$5 = {
  display_name: "EmptyMochiLatentVideo",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const EmptySD3LatentImage$5 = {
  display_name: "EmptySD3LatentImage",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const ExponentialScheduler$5 = {
  display_name: "ExponentialScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const FeatherMask$5 = {
  display_name: "FeatherMask",
  inputs: {
    mask: {
      name: "mask"
    },
    left: {
      name: "left"
    },
    top: {
      name: "top"
    },
    right: {
      name: "right"
    },
    bottom: {
      name: "bottom"
    }
  }
};
const FlipSigmas$5 = {
  display_name: "FlipSigmas",
  inputs: {
    sigmas: {
      name: "sigmas"
    }
  }
};
const FluxDisableGuidance$5 = {
  display_name: "FluxDisableGuidance",
  description: "This node completely disables the guidance embed on Flux and Flux like models",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const FluxGuidance$5 = {
  display_name: "FluxGuidance",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    guidance: {
      name: "guidance"
    }
  }
};
const FreeU$5 = {
  display_name: "FreeU",
  inputs: {
    model: {
      name: "model"
    },
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2$5 = {
  display_name: "FreeU_V2",
  inputs: {
    model: {
      name: "model"
    },
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler$5 = {
  display_name: "GITSScheduler",
  inputs: {
    coeff: {
      name: "coeff"
    },
    steps: {
      name: "steps"
    },
    denoise: {
      name: "denoise"
    }
  }
};
const GLIGENLoader$5 = {
  display_name: "GLIGENLoader",
  inputs: {
    gligen_name: {
      name: "gligen_name"
    }
  }
};
const GLIGENTextBoxApply$5 = {
  display_name: "GLIGENTextBoxApply",
  inputs: {
    conditioning_to: {
      name: "conditioning_to"
    },
    clip: {
      name: "clip"
    },
    gligen_textbox_model: {
      name: "gligen_textbox_model"
    },
    text: {
      name: "text"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask$5 = {
  display_name: "GrowMask",
  inputs: {
    mask: {
      name: "mask"
    },
    expand: {
      name: "expand"
    },
    tapered_corners: {
      name: "tapered_corners"
    }
  }
};
const Hunyuan3Dv2Conditioning$5 = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "clip_vision_output"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView$5 = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    front: {
      name: "front"
    },
    left: {
      name: "left"
    },
    back: {
      name: "back"
    },
    right: {
      name: "right"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const HunyuanImageToVideo$5 = {
  display_name: "HunyuanImageToVideo",
  inputs: {
    positive: {
      name: "positive"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    },
    guidance_type: {
      name: "guidance_type"
    },
    start_image: {
      name: "start_image"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "latent"
    }
  }
};
const HypernetworkLoader$5 = {
  display_name: "HypernetworkLoader",
  inputs: {
    model: {
      name: "model"
    },
    hypernetwork_name: {
      name: "hypernetwork_name"
    },
    strength: {
      name: "strength"
    }
  }
};
const HyperTile$5 = {
  display_name: "HyperTile",
  inputs: {
    model: {
      name: "model"
    },
    tile_size: {
      name: "tile_size"
    },
    swap_size: {
      name: "swap_size"
    },
    max_depth: {
      name: "max_depth"
    },
    scale_depth: {
      name: "scale_depth"
    }
  }
};
const ImageBatch$5 = {
  display_name: "Batch Images",
  inputs: {
    image1: {
      name: "image1"
    },
    image2: {
      name: "image2"
    }
  }
};
const ImageBlend$5 = {
  display_name: "Image Blend",
  inputs: {
    image1: {
      name: "image1"
    },
    image2: {
      name: "image2"
    },
    blend_factor: {
      name: "blend_factor"
    },
    blend_mode: {
      name: "blend_mode"
    }
  }
};
const ImageBlur$5 = {
  display_name: "Image Blur",
  inputs: {
    image: {
      name: "image"
    },
    blur_radius: {
      name: "blur_radius"
    },
    sigma: {
      name: "sigma"
    }
  }
};
const ImageColorToMask$5 = {
  display_name: "ImageColorToMask",
  inputs: {
    image: {
      name: "image"
    },
    color: {
      name: "color"
    }
  }
};
const ImageCompositeMasked$5 = {
  display_name: "ImageCompositeMasked",
  inputs: {
    destination: {
      name: "destination"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    resize_source: {
      name: "resize_source"
    },
    mask: {
      name: "mask"
    }
  }
};
const ImageCrop$5 = {
  display_name: "Image Crop",
  inputs: {
    image: {
      name: "image"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch$5 = {
  display_name: "ImageFromBatch",
  inputs: {
    image: {
      name: "image"
    },
    batch_index: {
      name: "batch_index"
    },
    length: {
      name: "length"
    }
  }
};
const ImageInvert$5 = {
  display_name: "Invert Image",
  inputs: {
    image: {
      name: "image"
    }
  }
};
const ImageOnlyCheckpointLoader$5 = {
  display_name: "Image Only Checkpoint Loader (img2vid model)",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    }
  }
};
const ImageOnlyCheckpointSave$5 = {
  display_name: "ImageOnlyCheckpointSave",
  inputs: {
    model: {
      name: "model"
    },
    clip_vision: {
      name: "clip_vision"
    },
    vae: {
      name: "vae"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const ImagePadForOutpaint$5 = {
  display_name: "Pad Image for Outpainting",
  inputs: {
    image: {
      name: "image"
    },
    left: {
      name: "left"
    },
    top: {
      name: "top"
    },
    right: {
      name: "right"
    },
    bottom: {
      name: "bottom"
    },
    feathering: {
      name: "feathering"
    }
  }
};
const ImageQuantize$5 = {
  display_name: "Image Quantize",
  inputs: {
    image: {
      name: "image"
    },
    colors: {
      name: "colors"
    },
    dither: {
      name: "dither"
    }
  }
};
const ImageScale$5 = {
  display_name: "Upscale Image",
  inputs: {
    image: {
      name: "image"
    },
    upscale_method: {
      name: "upscale_method"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    crop: {
      name: "crop"
    }
  }
};
const ImageScaleBy$5 = {
  display_name: "Upscale Image By",
  inputs: {
    image: {
      name: "image"
    },
    upscale_method: {
      name: "upscale_method"
    },
    scale_by: {
      name: "scale_by"
    }
  }
};
const ImageScaleToTotalPixels$5 = {
  display_name: "Scale Image to Total Pixels",
  inputs: {
    image: {
      name: "image"
    },
    upscale_method: {
      name: "upscale_method"
    },
    megapixels: {
      name: "megapixels"
    }
  }
};
const ImageSharpen$5 = {
  display_name: "Image Sharpen",
  inputs: {
    image: {
      name: "image"
    },
    sharpen_radius: {
      name: "sharpen_radius"
    },
    sigma: {
      name: "sigma"
    },
    alpha: {
      name: "alpha"
    }
  }
};
const ImageToMask$5 = {
  display_name: "Convert Image to Mask",
  inputs: {
    image: {
      name: "image"
    },
    channel: {
      name: "channel"
    }
  }
};
const ImageUpscaleWithModel$5 = {
  display_name: "Upscale Image (using Model)",
  inputs: {
    upscale_model: {
      name: "upscale_model"
    },
    image: {
      name: "image"
    }
  }
};
const InpaintModelConditioning$5 = {
  display_name: "InpaintModelConditioning",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    vae: {
      name: "vae"
    },
    pixels: {
      name: "pixels"
    },
    mask: {
      name: "mask"
    },
    noise_mask: {
      name: "noise_mask",
      tooltip: "Add a noise mask to the latent so sampling will only happen within the mask. Might improve results or completely break things depending on the model."
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const InstructPixToPixConditioning$5 = {
  display_name: "InstructPixToPixConditioning",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    vae: {
      name: "vae"
    },
    pixels: {
      name: "pixels"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const InvertMask$5 = {
  display_name: "InvertMask",
  inputs: {
    mask: {
      name: "mask"
    }
  }
};
const JoinImageWithAlpha$5 = {
  display_name: "Join Image with Alpha",
  inputs: {
    image: {
      name: "image"
    },
    alpha: {
      name: "alpha"
    }
  }
};
const KarrasScheduler$5 = {
  display_name: "KarrasScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    rho: {
      name: "rho"
    }
  }
};
const KSampler$5 = {
  display_name: "KSampler",
  description: "Uses the provided model, positive and negative conditioning to denoise the latent image.",
  inputs: {
    model: {
      name: "model",
      tooltip: "The model used for denoising the input latent."
    },
    seed: {
      name: "seed",
      tooltip: "The random seed used for creating the noise."
    },
    steps: {
      name: "steps",
      tooltip: "The number of steps used in the denoising process."
    },
    cfg: {
      name: "cfg",
      tooltip: "The Classifier-Free Guidance scale balances creativity and adherence to the prompt. Higher values result in images more closely matching the prompt however too high values will negatively impact quality."
    },
    sampler_name: {
      name: "sampler_name",
      tooltip: "The algorithm used when sampling, this can affect the quality, speed, and style of the generated output."
    },
    scheduler: {
      name: "scheduler",
      tooltip: "The scheduler controls how noise is gradually removed to form the image."
    },
    positive: {
      name: "positive",
      tooltip: "The conditioning describing the attributes you want to include in the image."
    },
    negative: {
      name: "negative",
      tooltip: "The conditioning describing the attributes you want to exclude from the image."
    },
    latent_image: {
      name: "latent_image",
      tooltip: "The latent image to denoise."
    },
    denoise: {
      name: "denoise",
      tooltip: "The amount of denoising applied, lower values will maintain the structure of the initial image allowing for image to image sampling."
    },
    control_after_generate: {
      name: "control after generate"
    }
  },
  outputs: {
    "0": {
      tooltip: "The denoised latent."
    }
  }
};
const KSamplerAdvanced$5 = {
  display_name: "KSampler (Advanced)",
  inputs: {
    model: {
      name: "model"
    },
    add_noise: {
      name: "add_noise"
    },
    noise_seed: {
      name: "noise_seed"
    },
    steps: {
      name: "steps"
    },
    cfg: {
      name: "cfg"
    },
    sampler_name: {
      name: "sampler_name"
    },
    scheduler: {
      name: "scheduler"
    },
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    latent_image: {
      name: "latent_image"
    },
    start_at_step: {
      name: "start_at_step"
    },
    end_at_step: {
      name: "end_at_step"
    },
    return_with_leftover_noise: {
      name: "return_with_leftover_noise"
    },
    control_after_generate: {
      name: "control after generate"
    }
  }
};
const KSamplerSelect$5 = {
  display_name: "KSamplerSelect",
  inputs: {
    sampler_name: {
      name: "sampler_name"
    }
  }
};
const LaplaceScheduler$5 = {
  display_name: "LaplaceScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    mu: {
      name: "mu"
    },
    beta: {
      name: "beta"
    }
  }
};
const LatentAdd$5 = {
  display_name: "LatentAdd",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentApplyOperation$5 = {
  display_name: "LatentApplyOperation",
  inputs: {
    samples: {
      name: "samples"
    },
    operation: {
      name: "operation"
    }
  }
};
const LatentApplyOperationCFG$5 = {
  display_name: "LatentApplyOperationCFG",
  inputs: {
    model: {
      name: "model"
    },
    operation: {
      name: "operation"
    }
  }
};
const LatentBatch$5 = {
  display_name: "LatentBatch",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentBatchSeedBehavior$5 = {
  display_name: "LatentBatchSeedBehavior",
  inputs: {
    samples: {
      name: "samples"
    },
    seed_behavior: {
      name: "seed_behavior"
    }
  }
};
const LatentBlend$5 = {
  display_name: "Latent Blend",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    },
    blend_factor: {
      name: "blend_factor"
    }
  }
};
const LatentComposite$5 = {
  display_name: "Latent Composite",
  inputs: {
    samples_to: {
      name: "samples_to"
    },
    samples_from: {
      name: "samples_from"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    feather: {
      name: "feather"
    }
  }
};
const LatentCompositeMasked$5 = {
  display_name: "LatentCompositeMasked",
  inputs: {
    destination: {
      name: "destination"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    resize_source: {
      name: "resize_source"
    },
    mask: {
      name: "mask"
    }
  }
};
const LatentCrop$5 = {
  display_name: "Crop Latent",
  inputs: {
    samples: {
      name: "samples"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip$5 = {
  display_name: "Flip Latent",
  inputs: {
    samples: {
      name: "samples"
    },
    flip_method: {
      name: "flip_method"
    }
  }
};
const LatentFromBatch$5 = {
  display_name: "Latent From Batch",
  inputs: {
    samples: {
      name: "samples"
    },
    batch_index: {
      name: "batch_index"
    },
    length: {
      name: "length"
    }
  }
};
const LatentInterpolate$5 = {
  display_name: "LatentInterpolate",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const LatentMultiply$5 = {
  display_name: "LatentMultiply",
  inputs: {
    samples: {
      name: "samples"
    },
    multiplier: {
      name: "multiplier"
    }
  }
};
const LatentOperationSharpen$5 = {
  display_name: "LatentOperationSharpen",
  inputs: {
    sharpen_radius: {
      name: "sharpen_radius"
    },
    sigma: {
      name: "sigma"
    },
    alpha: {
      name: "alpha"
    }
  }
};
const LatentOperationTonemapReinhard$5 = {
  display_name: "LatentOperationTonemapReinhard",
  inputs: {
    multiplier: {
      name: "multiplier"
    }
  }
};
const LatentRotate$5 = {
  display_name: "Rotate Latent",
  inputs: {
    samples: {
      name: "samples"
    },
    rotation: {
      name: "rotation"
    }
  }
};
const LatentSubtract$5 = {
  display_name: "LatentSubtract",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentUpscale$5 = {
  display_name: "Upscale Latent",
  inputs: {
    samples: {
      name: "samples"
    },
    upscale_method: {
      name: "upscale_method"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    crop: {
      name: "crop"
    }
  }
};
const LatentUpscaleBy$5 = {
  display_name: "Upscale Latent By",
  inputs: {
    samples: {
      name: "samples"
    },
    upscale_method: {
      name: "upscale_method"
    },
    scale_by: {
      name: "scale_by"
    }
  }
};
const Load3D$5 = {
  display_name: "Load 3D",
  inputs: {
    model_file: {
      name: "model_file"
    },
    image: {
      name: "image"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    clear: {},
    "upload 3d model": {}
  },
  outputs: {
    "0": {
      name: "image"
    },
    "1": {
      name: "mask"
    },
    "2": {
      name: "mesh_path"
    }
  }
};
const Load3DAnimation$5 = {
  display_name: "Load 3D - Animation",
  inputs: {
    model_file: {
      name: "model_file"
    },
    image: {
      name: "image"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    clear: {},
    "upload 3d model": {}
  },
  outputs: {
    "0": {
      name: "image"
    },
    "1": {
      name: "mask"
    },
    "2": {
      name: "mesh_path"
    }
  }
};
const LoadAudio$5 = {
  display_name: "LoadAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    audioUI: {
      name: "audioUI"
    },
    upload: {
      name: "choose file to upload"
    }
  }
};
const LoadImage$5 = {
  display_name: "Load Image",
  inputs: {
    image: {
      name: "image"
    },
    upload: {
      name: "choose file to upload"
    }
  }
};
const LoadImageMask$5 = {
  display_name: "Load Image (as Mask)",
  inputs: {
    image: {
      name: "image"
    },
    channel: {
      name: "channel"
    },
    upload: {
      name: "choose file to upload"
    }
  }
};
const LoadImageOutput$5 = {
  display_name: "Load Image (from Outputs)",
  description: "Load an image from the output folder. When the refresh button is clicked, the node will update the image list and automatically select the first image, allowing for easy iteration.",
  inputs: {
    image: {
      name: "image"
    },
    refresh: {},
    upload: {
      name: "choose file to upload"
    }
  }
};
const LoadLatent$5 = {
  display_name: "LoadLatent",
  inputs: {
    latent: {
      name: "latent"
    }
  }
};
const LoraLoader$5 = {
  display_name: "Load LoRA",
  description: "LoRAs are used to modify diffusion and CLIP models, altering the way in which latents are denoised such as applying styles. Multiple LoRA nodes can be linked together.",
  inputs: {
    model: {
      name: "model",
      tooltip: "The diffusion model the LoRA will be applied to."
    },
    clip: {
      name: "clip",
      tooltip: "The CLIP model the LoRA will be applied to."
    },
    lora_name: {
      name: "lora_name",
      tooltip: "The name of the LoRA."
    },
    strength_model: {
      name: "strength_model",
      tooltip: "How strongly to modify the diffusion model. This value can be negative."
    },
    strength_clip: {
      name: "strength_clip",
      tooltip: "How strongly to modify the CLIP model. This value can be negative."
    }
  },
  outputs: {
    "0": {
      tooltip: "The modified diffusion model."
    },
    "1": {
      tooltip: "The modified CLIP model."
    }
  }
};
const LoraLoaderModelOnly$5 = {
  display_name: "LoraLoaderModelOnly",
  description: "LoRAs are used to modify diffusion and CLIP models, altering the way in which latents are denoised such as applying styles. Multiple LoRA nodes can be linked together.",
  inputs: {
    model: {
      name: "model"
    },
    lora_name: {
      name: "lora_name"
    },
    strength_model: {
      name: "strength_model"
    }
  },
  outputs: {
    "0": {
      tooltip: "The modified diffusion model."
    }
  }
};
const LoraSave$5 = {
  display_name: "Extract and Save Lora",
  inputs: {
    filename_prefix: {
      name: "filename_prefix"
    },
    rank: {
      name: "rank"
    },
    lora_type: {
      name: "lora_type"
    },
    bias_diff: {
      name: "bias_diff"
    },
    model_diff: {
      name: "model_diff",
      tooltip: "The ModelSubtract output to be converted to a lora."
    },
    text_encoder_diff: {
      name: "text_encoder_diff",
      tooltip: "The CLIPSubtract output to be converted to a lora."
    }
  }
};
const LTXVAddGuide$5 = {
  display_name: "LTXVAddGuide",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    vae: {
      name: "vae"
    },
    latent: {
      name: "latent"
    },
    image: {
      name: "image",
      tooltip: "Image or video to condition the latent video on. Must be 8*n + 1 frames.If the video is not 8*n + 1 frames, it will be cropped to the nearest 8*n + 1 frames."
    },
    frame_idx: {
      name: "frame_idx",
      tooltip: "Frame index to start the conditioning at. For single-frame images or videos with 1-8 frames, any frame_idx value is acceptable. For videos with 9+ frames, frame_idx must be divisible by 8, otherwise it will be rounded down to the nearest multiple of 8. Negative values are counted from the end of the video."
    },
    strength: {
      name: "strength"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVConditioning$5 = {
  display_name: "LTXVConditioning",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    frame_rate: {
      name: "frame_rate"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const LTXVCropGuides$5 = {
  display_name: "LTXVCropGuides",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    latent: {
      name: "latent"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVImgToVideo$5 = {
  display_name: "LTXVImgToVideo",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    vae: {
      name: "vae"
    },
    image: {
      name: "image"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVPreprocess$5 = {
  display_name: "LTXVPreprocess",
  inputs: {
    image: {
      name: "image"
    },
    img_compression: {
      name: "img_compression",
      tooltip: "Amount of compression to apply on image."
    }
  },
  outputs: {
    "0": {
      name: "output_image"
    }
  }
};
const LTXVScheduler$5 = {
  display_name: "LTXVScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    max_shift: {
      name: "max_shift"
    },
    base_shift: {
      name: "base_shift"
    },
    stretch: {
      name: "stretch",
      tooltip: "Stretch the sigmas to be in the range [terminal, 1]."
    },
    terminal: {
      name: "terminal",
      tooltip: "The terminal value of the sigmas after stretching."
    },
    latent: {
      name: "latent"
    }
  }
};
const Mahiro$5 = {
  display_name: "Mahiro is so cute that she deserves a better guidance function!! (。・ω・。)",
  description: "Modify the guidance to scale more on the 'direction' of the positive prompt rather than the difference between the negative prompt.",
  inputs: {
    model: {
      name: "model"
    }
  },
  outputs: {
    "0": {
      name: "patched_model"
    }
  }
};
const MaskComposite$5 = {
  display_name: "MaskComposite",
  inputs: {
    destination: {
      name: "destination"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    operation: {
      name: "operation"
    }
  }
};
const MaskToImage$5 = {
  display_name: "Convert Mask to Image",
  inputs: {
    mask: {
      name: "mask"
    }
  }
};
const ModelComputeDtype$5 = {
  display_name: "ModelComputeDtype",
  inputs: {
    model: {
      name: "model"
    },
    dtype: {
      name: "dtype"
    }
  }
};
const ModelMergeAdd$5 = {
  display_name: "ModelMergeAdd",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    }
  }
};
const ModelMergeAuraflow$5 = {
  display_name: "ModelMergeAuraflow",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    init_x_linear_: {
      name: "init_x_linear."
    },
    positional_encoding: {
      name: "positional_encoding"
    },
    cond_seq_linear_: {
      name: "cond_seq_linear."
    },
    register_tokens: {
      name: "register_tokens"
    },
    t_embedder_: {
      name: "t_embedder."
    },
    double_layers_0_: {
      name: "double_layers.0."
    },
    double_layers_1_: {
      name: "double_layers.1."
    },
    double_layers_2_: {
      name: "double_layers.2."
    },
    double_layers_3_: {
      name: "double_layers.3."
    },
    single_layers_0_: {
      name: "single_layers.0."
    },
    single_layers_1_: {
      name: "single_layers.1."
    },
    single_layers_2_: {
      name: "single_layers.2."
    },
    single_layers_3_: {
      name: "single_layers.3."
    },
    single_layers_4_: {
      name: "single_layers.4."
    },
    single_layers_5_: {
      name: "single_layers.5."
    },
    single_layers_6_: {
      name: "single_layers.6."
    },
    single_layers_7_: {
      name: "single_layers.7."
    },
    single_layers_8_: {
      name: "single_layers.8."
    },
    single_layers_9_: {
      name: "single_layers.9."
    },
    single_layers_10_: {
      name: "single_layers.10."
    },
    single_layers_11_: {
      name: "single_layers.11."
    },
    single_layers_12_: {
      name: "single_layers.12."
    },
    single_layers_13_: {
      name: "single_layers.13."
    },
    single_layers_14_: {
      name: "single_layers.14."
    },
    single_layers_15_: {
      name: "single_layers.15."
    },
    single_layers_16_: {
      name: "single_layers.16."
    },
    single_layers_17_: {
      name: "single_layers.17."
    },
    single_layers_18_: {
      name: "single_layers.18."
    },
    single_layers_19_: {
      name: "single_layers.19."
    },
    single_layers_20_: {
      name: "single_layers.20."
    },
    single_layers_21_: {
      name: "single_layers.21."
    },
    single_layers_22_: {
      name: "single_layers.22."
    },
    single_layers_23_: {
      name: "single_layers.23."
    },
    single_layers_24_: {
      name: "single_layers.24."
    },
    single_layers_25_: {
      name: "single_layers.25."
    },
    single_layers_26_: {
      name: "single_layers.26."
    },
    single_layers_27_: {
      name: "single_layers.27."
    },
    single_layers_28_: {
      name: "single_layers.28."
    },
    single_layers_29_: {
      name: "single_layers.29."
    },
    single_layers_30_: {
      name: "single_layers.30."
    },
    single_layers_31_: {
      name: "single_layers.31."
    },
    modF_: {
      name: "modF."
    },
    final_linear_: {
      name: "final_linear."
    }
  }
};
const ModelMergeBlocks$5 = {
  display_name: "ModelMergeBlocks",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    input: {
      name: "input"
    },
    middle: {
      name: "middle"
    },
    out: {
      name: "out"
    }
  }
};
const ModelMergeCosmos14B$5 = {
  display_name: "ModelMergeCosmos14B",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeCosmos7B$5 = {
  display_name: "ModelMergeCosmos7B",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeFlux1$5 = {
  display_name: "ModelMergeFlux1",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    img_in_: {
      name: "img_in."
    },
    time_in_: {
      name: "time_in."
    },
    guidance_in: {
      name: "guidance_in"
    },
    vector_in_: {
      name: "vector_in."
    },
    txt_in_: {
      name: "txt_in."
    },
    double_blocks_0_: {
      name: "double_blocks.0."
    },
    double_blocks_1_: {
      name: "double_blocks.1."
    },
    double_blocks_2_: {
      name: "double_blocks.2."
    },
    double_blocks_3_: {
      name: "double_blocks.3."
    },
    double_blocks_4_: {
      name: "double_blocks.4."
    },
    double_blocks_5_: {
      name: "double_blocks.5."
    },
    double_blocks_6_: {
      name: "double_blocks.6."
    },
    double_blocks_7_: {
      name: "double_blocks.7."
    },
    double_blocks_8_: {
      name: "double_blocks.8."
    },
    double_blocks_9_: {
      name: "double_blocks.9."
    },
    double_blocks_10_: {
      name: "double_blocks.10."
    },
    double_blocks_11_: {
      name: "double_blocks.11."
    },
    double_blocks_12_: {
      name: "double_blocks.12."
    },
    double_blocks_13_: {
      name: "double_blocks.13."
    },
    double_blocks_14_: {
      name: "double_blocks.14."
    },
    double_blocks_15_: {
      name: "double_blocks.15."
    },
    double_blocks_16_: {
      name: "double_blocks.16."
    },
    double_blocks_17_: {
      name: "double_blocks.17."
    },
    double_blocks_18_: {
      name: "double_blocks.18."
    },
    single_blocks_0_: {
      name: "single_blocks.0."
    },
    single_blocks_1_: {
      name: "single_blocks.1."
    },
    single_blocks_2_: {
      name: "single_blocks.2."
    },
    single_blocks_3_: {
      name: "single_blocks.3."
    },
    single_blocks_4_: {
      name: "single_blocks.4."
    },
    single_blocks_5_: {
      name: "single_blocks.5."
    },
    single_blocks_6_: {
      name: "single_blocks.6."
    },
    single_blocks_7_: {
      name: "single_blocks.7."
    },
    single_blocks_8_: {
      name: "single_blocks.8."
    },
    single_blocks_9_: {
      name: "single_blocks.9."
    },
    single_blocks_10_: {
      name: "single_blocks.10."
    },
    single_blocks_11_: {
      name: "single_blocks.11."
    },
    single_blocks_12_: {
      name: "single_blocks.12."
    },
    single_blocks_13_: {
      name: "single_blocks.13."
    },
    single_blocks_14_: {
      name: "single_blocks.14."
    },
    single_blocks_15_: {
      name: "single_blocks.15."
    },
    single_blocks_16_: {
      name: "single_blocks.16."
    },
    single_blocks_17_: {
      name: "single_blocks.17."
    },
    single_blocks_18_: {
      name: "single_blocks.18."
    },
    single_blocks_19_: {
      name: "single_blocks.19."
    },
    single_blocks_20_: {
      name: "single_blocks.20."
    },
    single_blocks_21_: {
      name: "single_blocks.21."
    },
    single_blocks_22_: {
      name: "single_blocks.22."
    },
    single_blocks_23_: {
      name: "single_blocks.23."
    },
    single_blocks_24_: {
      name: "single_blocks.24."
    },
    single_blocks_25_: {
      name: "single_blocks.25."
    },
    single_blocks_26_: {
      name: "single_blocks.26."
    },
    single_blocks_27_: {
      name: "single_blocks.27."
    },
    single_blocks_28_: {
      name: "single_blocks.28."
    },
    single_blocks_29_: {
      name: "single_blocks.29."
    },
    single_blocks_30_: {
      name: "single_blocks.30."
    },
    single_blocks_31_: {
      name: "single_blocks.31."
    },
    single_blocks_32_: {
      name: "single_blocks.32."
    },
    single_blocks_33_: {
      name: "single_blocks.33."
    },
    single_blocks_34_: {
      name: "single_blocks.34."
    },
    single_blocks_35_: {
      name: "single_blocks.35."
    },
    single_blocks_36_: {
      name: "single_blocks.36."
    },
    single_blocks_37_: {
      name: "single_blocks.37."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeLTXV$5 = {
  display_name: "ModelMergeLTXV",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "caption_projection."
    },
    transformer_blocks_0_: {
      name: "transformer_blocks.0."
    },
    transformer_blocks_1_: {
      name: "transformer_blocks.1."
    },
    transformer_blocks_2_: {
      name: "transformer_blocks.2."
    },
    transformer_blocks_3_: {
      name: "transformer_blocks.3."
    },
    transformer_blocks_4_: {
      name: "transformer_blocks.4."
    },
    transformer_blocks_5_: {
      name: "transformer_blocks.5."
    },
    transformer_blocks_6_: {
      name: "transformer_blocks.6."
    },
    transformer_blocks_7_: {
      name: "transformer_blocks.7."
    },
    transformer_blocks_8_: {
      name: "transformer_blocks.8."
    },
    transformer_blocks_9_: {
      name: "transformer_blocks.9."
    },
    transformer_blocks_10_: {
      name: "transformer_blocks.10."
    },
    transformer_blocks_11_: {
      name: "transformer_blocks.11."
    },
    transformer_blocks_12_: {
      name: "transformer_blocks.12."
    },
    transformer_blocks_13_: {
      name: "transformer_blocks.13."
    },
    transformer_blocks_14_: {
      name: "transformer_blocks.14."
    },
    transformer_blocks_15_: {
      name: "transformer_blocks.15."
    },
    transformer_blocks_16_: {
      name: "transformer_blocks.16."
    },
    transformer_blocks_17_: {
      name: "transformer_blocks.17."
    },
    transformer_blocks_18_: {
      name: "transformer_blocks.18."
    },
    transformer_blocks_19_: {
      name: "transformer_blocks.19."
    },
    transformer_blocks_20_: {
      name: "transformer_blocks.20."
    },
    transformer_blocks_21_: {
      name: "transformer_blocks.21."
    },
    transformer_blocks_22_: {
      name: "transformer_blocks.22."
    },
    transformer_blocks_23_: {
      name: "transformer_blocks.23."
    },
    transformer_blocks_24_: {
      name: "transformer_blocks.24."
    },
    transformer_blocks_25_: {
      name: "transformer_blocks.25."
    },
    transformer_blocks_26_: {
      name: "transformer_blocks.26."
    },
    transformer_blocks_27_: {
      name: "transformer_blocks.27."
    },
    scale_shift_table: {
      name: "scale_shift_table"
    },
    proj_out_: {
      name: "proj_out."
    }
  }
};
const ModelMergeMochiPreview$5 = {
  display_name: "ModelMergeMochiPreview",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_frequencies_: {
      name: "pos_frequencies."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    blocks_0_: {
      name: "blocks.0."
    },
    blocks_1_: {
      name: "blocks.1."
    },
    blocks_2_: {
      name: "blocks.2."
    },
    blocks_3_: {
      name: "blocks.3."
    },
    blocks_4_: {
      name: "blocks.4."
    },
    blocks_5_: {
      name: "blocks.5."
    },
    blocks_6_: {
      name: "blocks.6."
    },
    blocks_7_: {
      name: "blocks.7."
    },
    blocks_8_: {
      name: "blocks.8."
    },
    blocks_9_: {
      name: "blocks.9."
    },
    blocks_10_: {
      name: "blocks.10."
    },
    blocks_11_: {
      name: "blocks.11."
    },
    blocks_12_: {
      name: "blocks.12."
    },
    blocks_13_: {
      name: "blocks.13."
    },
    blocks_14_: {
      name: "blocks.14."
    },
    blocks_15_: {
      name: "blocks.15."
    },
    blocks_16_: {
      name: "blocks.16."
    },
    blocks_17_: {
      name: "blocks.17."
    },
    blocks_18_: {
      name: "blocks.18."
    },
    blocks_19_: {
      name: "blocks.19."
    },
    blocks_20_: {
      name: "blocks.20."
    },
    blocks_21_: {
      name: "blocks.21."
    },
    blocks_22_: {
      name: "blocks.22."
    },
    blocks_23_: {
      name: "blocks.23."
    },
    blocks_24_: {
      name: "blocks.24."
    },
    blocks_25_: {
      name: "blocks.25."
    },
    blocks_26_: {
      name: "blocks.26."
    },
    blocks_27_: {
      name: "blocks.27."
    },
    blocks_28_: {
      name: "blocks.28."
    },
    blocks_29_: {
      name: "blocks.29."
    },
    blocks_30_: {
      name: "blocks.30."
    },
    blocks_31_: {
      name: "blocks.31."
    },
    blocks_32_: {
      name: "blocks.32."
    },
    blocks_33_: {
      name: "blocks.33."
    },
    blocks_34_: {
      name: "blocks.34."
    },
    blocks_35_: {
      name: "blocks.35."
    },
    blocks_36_: {
      name: "blocks.36."
    },
    blocks_37_: {
      name: "blocks.37."
    },
    blocks_38_: {
      name: "blocks.38."
    },
    blocks_39_: {
      name: "blocks.39."
    },
    blocks_40_: {
      name: "blocks.40."
    },
    blocks_41_: {
      name: "blocks.41."
    },
    blocks_42_: {
      name: "blocks.42."
    },
    blocks_43_: {
      name: "blocks.43."
    },
    blocks_44_: {
      name: "blocks.44."
    },
    blocks_45_: {
      name: "blocks.45."
    },
    blocks_46_: {
      name: "blocks.46."
    },
    blocks_47_: {
      name: "blocks.47."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeSD1$5 = {
  display_name: "ModelMergeSD1",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    time_embed_: {
      name: "time_embed."
    },
    label_emb_: {
      name: "label_emb."
    },
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    out_: {
      name: "out."
    }
  }
};
const ModelMergeSD2$5 = {
  display_name: "ModelMergeSD2",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    time_embed_: {
      name: "time_embed."
    },
    label_emb_: {
      name: "label_emb."
    },
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    out_: {
      name: "out."
    }
  }
};
const ModelMergeSD3_2B$5 = {
  display_name: "ModelMergeSD3_2B",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    context_embedder_: {
      name: "context_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeSD35_Large$5 = {
  display_name: "ModelMergeSD35_Large",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    context_embedder_: {
      name: "context_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_24_: {
      name: "joint_blocks.24."
    },
    joint_blocks_25_: {
      name: "joint_blocks.25."
    },
    joint_blocks_26_: {
      name: "joint_blocks.26."
    },
    joint_blocks_27_: {
      name: "joint_blocks.27."
    },
    joint_blocks_28_: {
      name: "joint_blocks.28."
    },
    joint_blocks_29_: {
      name: "joint_blocks.29."
    },
    joint_blocks_30_: {
      name: "joint_blocks.30."
    },
    joint_blocks_31_: {
      name: "joint_blocks.31."
    },
    joint_blocks_32_: {
      name: "joint_blocks.32."
    },
    joint_blocks_33_: {
      name: "joint_blocks.33."
    },
    joint_blocks_34_: {
      name: "joint_blocks.34."
    },
    joint_blocks_35_: {
      name: "joint_blocks.35."
    },
    joint_blocks_36_: {
      name: "joint_blocks.36."
    },
    joint_blocks_37_: {
      name: "joint_blocks.37."
    },
    final_layer_: {
      name: "final_layer."
    }
  }
};
const ModelMergeSDXL$5 = {
  display_name: "ModelMergeSDXL",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    time_embed_: {
      name: "time_embed."
    },
    label_emb_: {
      name: "label_emb."
    },
    input_blocks_0: {
      name: "input_blocks.0"
    },
    input_blocks_1: {
      name: "input_blocks.1"
    },
    input_blocks_2: {
      name: "input_blocks.2"
    },
    input_blocks_3: {
      name: "input_blocks.3"
    },
    input_blocks_4: {
      name: "input_blocks.4"
    },
    input_blocks_5: {
      name: "input_blocks.5"
    },
    input_blocks_6: {
      name: "input_blocks.6"
    },
    input_blocks_7: {
      name: "input_blocks.7"
    },
    input_blocks_8: {
      name: "input_blocks.8"
    },
    middle_block_0: {
      name: "middle_block.0"
    },
    middle_block_1: {
      name: "middle_block.1"
    },
    middle_block_2: {
      name: "middle_block.2"
    },
    output_blocks_0: {
      name: "output_blocks.0"
    },
    output_blocks_1: {
      name: "output_blocks.1"
    },
    output_blocks_2: {
      name: "output_blocks.2"
    },
    output_blocks_3: {
      name: "output_blocks.3"
    },
    output_blocks_4: {
      name: "output_blocks.4"
    },
    output_blocks_5: {
      name: "output_blocks.5"
    },
    output_blocks_6: {
      name: "output_blocks.6"
    },
    output_blocks_7: {
      name: "output_blocks.7"
    },
    output_blocks_8: {
      name: "output_blocks.8"
    },
    out_: {
      name: "out."
    }
  }
};
const ModelMergeSimple$5 = {
  display_name: "ModelMergeSimple",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const ModelMergeSubtract$5 = {
  display_name: "ModelMergeSubtract",
  inputs: {
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    multiplier: {
      name: "multiplier"
    }
  }
};
const ModelSamplingAuraFlow$5 = {
  display_name: "ModelSamplingAuraFlow",
  inputs: {
    model: {
      name: "model"
    },
    shift: {
      name: "shift"
    }
  }
};
const ModelSamplingContinuousEDM$5 = {
  display_name: "ModelSamplingContinuousEDM",
  inputs: {
    model: {
      name: "model"
    },
    sampling: {
      name: "sampling"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingContinuousV$5 = {
  display_name: "ModelSamplingContinuousV",
  inputs: {
    model: {
      name: "model"
    },
    sampling: {
      name: "sampling"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingDiscrete$5 = {
  display_name: "ModelSamplingDiscrete",
  inputs: {
    model: {
      name: "model"
    },
    sampling: {
      name: "sampling"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux$5 = {
  display_name: "ModelSamplingFlux",
  inputs: {
    model: {
      name: "model"
    },
    max_shift: {
      name: "max_shift"
    },
    base_shift: {
      name: "base_shift"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    }
  }
};
const ModelSamplingLTXV$5 = {
  display_name: "ModelSamplingLTXV",
  inputs: {
    model: {
      name: "model"
    },
    max_shift: {
      name: "max_shift"
    },
    base_shift: {
      name: "base_shift"
    },
    latent: {
      name: "latent"
    }
  }
};
const ModelSamplingSD3$5 = {
  display_name: "ModelSamplingSD3",
  inputs: {
    model: {
      name: "model"
    },
    shift: {
      name: "shift"
    }
  }
};
const ModelSamplingStableCascade$5 = {
  display_name: "ModelSamplingStableCascade",
  inputs: {
    model: {
      name: "model"
    },
    shift: {
      name: "shift"
    }
  }
};
const ModelSave$5 = {
  display_name: "ModelSave",
  inputs: {
    model: {
      name: "model"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const Morphology$5 = {
  display_name: "ImageMorphology",
  inputs: {
    image: {
      name: "image"
    },
    operation: {
      name: "operation"
    },
    kernel_size: {
      name: "kernel_size"
    }
  }
};
const PairConditioningCombine$5 = {
  display_name: "Cond Pair Combine",
  inputs: {
    positive_A: {
      name: "positive_A"
    },
    negative_A: {
      name: "negative_A"
    },
    positive_B: {
      name: "positive_B"
    },
    negative_B: {
      name: "negative_B"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetDefaultCombine$5 = {
  display_name: "Cond Pair Set Default Combine",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    positive_DEFAULT: {
      name: "positive_DEFAULT"
    },
    negative_DEFAULT: {
      name: "negative_DEFAULT"
    },
    hooks: {
      name: "hooks"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetProperties$5 = {
  display_name: "Cond Pair Set Props",
  inputs: {
    positive_NEW: {
      name: "positive_NEW"
    },
    negative_NEW: {
      name: "negative_NEW"
    },
    strength: {
      name: "strength"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    mask: {
      name: "mask"
    },
    hooks: {
      name: "hooks"
    },
    timesteps: {
      name: "timesteps"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetPropertiesAndCombine$5 = {
  display_name: "Cond Pair Set Props Combine",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    positive_NEW: {
      name: "positive_NEW"
    },
    negative_NEW: {
      name: "negative_NEW"
    },
    strength: {
      name: "strength"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    mask: {
      name: "mask"
    },
    hooks: {
      name: "hooks"
    },
    timesteps: {
      name: "timesteps"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PatchModelAddDownscale$5 = {
  display_name: "PatchModelAddDownscale (Kohya Deep Shrink)",
  inputs: {
    model: {
      name: "model"
    },
    block_number: {
      name: "block_number"
    },
    downscale_factor: {
      name: "downscale_factor"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    },
    downscale_after_skip: {
      name: "downscale_after_skip"
    },
    downscale_method: {
      name: "downscale_method"
    },
    upscale_method: {
      name: "upscale_method"
    }
  }
};
const PerpNeg$5 = {
  display_name: "Perp-Neg (DEPRECATED by PerpNegGuider)",
  inputs: {
    model: {
      name: "model"
    },
    empty_conditioning: {
      name: "empty_conditioning"
    },
    neg_scale: {
      name: "neg_scale"
    }
  }
};
const PerpNegGuider$5 = {
  display_name: "PerpNegGuider",
  inputs: {
    model: {
      name: "model"
    },
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    empty_conditioning: {
      name: "empty_conditioning"
    },
    cfg: {
      name: "cfg"
    },
    neg_scale: {
      name: "neg_scale"
    }
  }
};
const PerturbedAttentionGuidance$5 = {
  display_name: "PerturbedAttentionGuidance",
  inputs: {
    model: {
      name: "model"
    },
    scale: {
      name: "scale"
    }
  }
};
const PhotoMakerEncode$5 = {
  display_name: "PhotoMakerEncode",
  inputs: {
    photomaker: {
      name: "photomaker"
    },
    image: {
      name: "image"
    },
    clip: {
      name: "clip"
    },
    text: {
      name: "text"
    }
  }
};
const PhotoMakerLoader$5 = {
  display_name: "PhotoMakerLoader",
  inputs: {
    photomaker_model_name: {
      name: "photomaker_model_name"
    }
  }
};
const PolyexponentialScheduler$5 = {
  display_name: "PolyexponentialScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    rho: {
      name: "rho"
    }
  }
};
const PorterDuffImageComposite$5 = {
  display_name: "Porter-Duff Image Composite",
  inputs: {
    source: {
      name: "source"
    },
    source_alpha: {
      name: "source_alpha"
    },
    destination: {
      name: "destination"
    },
    destination_alpha: {
      name: "destination_alpha"
    },
    mode: {
      name: "mode"
    }
  }
};
const Preview3D$5 = {
  display_name: "Preview 3D",
  inputs: {
    model_file: {
      name: "model_file"
    },
    image: {
      name: "image"
    }
  }
};
const Preview3DAnimation$5 = {
  display_name: "Preview 3D - Animation",
  inputs: {
    model_file: {
      name: "model_file"
    },
    image: {
      name: "image"
    }
  }
};
const PreviewAudio$5 = {
  display_name: "PreviewAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    audioUI: {
      name: "audioUI"
    }
  }
};
const PreviewImage$5 = {
  display_name: "Preview Image",
  description: "Saves the input images to your ComfyUI output directory.",
  inputs: {
    images: {
      name: "images"
    }
  }
};
const RandomNoise$5 = {
  display_name: "RandomNoise",
  inputs: {
    noise_seed: {
      name: "noise_seed"
    },
    control_after_generate: {
      name: "control after generate"
    }
  }
};
const RebatchImages$5 = {
  display_name: "Rebatch Images",
  inputs: {
    images: {
      name: "images"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const RebatchLatents$5 = {
  display_name: "Rebatch Latents",
  inputs: {
    latents: {
      name: "latents"
    },
    batch_size: {
      name: "batch_size"
    }
  }
};
const RenormCFG$5 = {
  display_name: "RenormCFG",
  inputs: {
    model: {
      name: "model"
    },
    cfg_trunc: {
      name: "cfg_trunc"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch$5 = {
  display_name: "RepeatImageBatch",
  inputs: {
    image: {
      name: "image"
    },
    amount: {
      name: "amount"
    }
  }
};
const RepeatLatentBatch$5 = {
  display_name: "Repeat Latent Batch",
  inputs: {
    samples: {
      name: "samples"
    },
    amount: {
      name: "amount"
    }
  }
};
const RescaleCFG$5 = {
  display_name: "RescaleCFG",
  inputs: {
    model: {
      name: "model"
    },
    multiplier: {
      name: "multiplier"
    }
  }
};
const SamplerCustom$5 = {
  display_name: "SamplerCustom",
  inputs: {
    model: {
      name: "model"
    },
    add_noise: {
      name: "add_noise"
    },
    noise_seed: {
      name: "noise_seed"
    },
    cfg: {
      name: "cfg"
    },
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    sampler: {
      name: "sampler"
    },
    sigmas: {
      name: "sigmas"
    },
    latent_image: {
      name: "latent_image"
    },
    control_after_generate: {
      name: "control after generate"
    }
  },
  outputs: {
    "0": {
      name: "output"
    },
    "1": {
      name: "denoised_output"
    }
  }
};
const SamplerCustomAdvanced$5 = {
  display_name: "SamplerCustomAdvanced",
  inputs: {
    noise: {
      name: "noise"
    },
    guider: {
      name: "guider"
    },
    sampler: {
      name: "sampler"
    },
    sigmas: {
      name: "sigmas"
    },
    latent_image: {
      name: "latent_image"
    }
  },
  outputs: {
    "0": {
      name: "output"
    },
    "1": {
      name: "denoised_output"
    }
  }
};
const SamplerDPMAdaptative$5 = {
  display_name: "SamplerDPMAdaptative",
  inputs: {
    order: {
      name: "order"
    },
    rtol: {
      name: "rtol"
    },
    atol: {
      name: "atol"
    },
    h_init: {
      name: "h_init"
    },
    pcoeff: {
      name: "pcoeff"
    },
    icoeff: {
      name: "icoeff"
    },
    dcoeff: {
      name: "dcoeff"
    },
    accept_safety: {
      name: "accept_safety"
    },
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_2M_SDE$5 = {
  display_name: "SamplerDPMPP_2M_SDE",
  inputs: {
    solver_type: {
      name: "solver_type"
    },
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    },
    noise_device: {
      name: "noise_device"
    }
  }
};
const SamplerDPMPP_2S_Ancestral$5 = {
  display_name: "SamplerDPMPP_2S_Ancestral",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_3M_SDE$5 = {
  display_name: "SamplerDPMPP_3M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    },
    noise_device: {
      name: "noise_device"
    }
  }
};
const SamplerDPMPP_SDE$5 = {
  display_name: "SamplerDPMPP_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    },
    r: {
      name: "r"
    },
    noise_device: {
      name: "noise_device"
    }
  }
};
const SamplerEulerAncestral$5 = {
  display_name: "SamplerEulerAncestral",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestralCFGPP$5 = {
  display_name: "SamplerEulerAncestralCFG++",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerCFGpp$5 = {
  display_name: "SamplerEulerCFG++",
  inputs: {
    version: {
      name: "version"
    }
  }
};
const SamplerLCMUpscale$5 = {
  display_name: "SamplerLCMUpscale",
  inputs: {
    scale_ratio: {
      name: "scale_ratio"
    },
    scale_steps: {
      name: "scale_steps"
    },
    upscale_method: {
      name: "upscale_method"
    }
  }
};
const SamplerLMS$5 = {
  display_name: "SamplerLMS",
  inputs: {
    order: {
      name: "order"
    }
  }
};
const SaveAnimatedPNG$5 = {
  display_name: "SaveAnimatedPNG",
  inputs: {
    images: {
      name: "images"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    fps: {
      name: "fps"
    },
    compress_level: {
      name: "compress_level"
    }
  }
};
const SaveAnimatedWEBP$5 = {
  display_name: "SaveAnimatedWEBP",
  inputs: {
    images: {
      name: "images"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    fps: {
      name: "fps"
    },
    lossless: {
      name: "lossless"
    },
    quality: {
      name: "quality"
    },
    method: {
      name: "method"
    }
  }
};
const SaveAudio$5 = {
  display_name: "SaveAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    audioUI: {
      name: "audioUI"
    }
  }
};
const SaveGLB$5 = {
  display_name: "SaveGLB",
  inputs: {
    mesh: {
      name: "mesh"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    image: {
      name: "image"
    }
  }
};
const SaveImage$5 = {
  display_name: "Save Image",
  description: "Saves the input images to your ComfyUI output directory.",
  inputs: {
    images: {
      name: "images",
      tooltip: "The images to save."
    },
    filename_prefix: {
      name: "filename_prefix",
      tooltip: "The prefix for the file to save. This may include formatting information such as %date:yyyy-MM-dd% or %Empty Latent Image.width% to include values from nodes."
    }
  }
};
const SaveImageWebsocket$5 = {
  display_name: "SaveImageWebsocket",
  inputs: {
    images: {
      name: "images"
    }
  }
};
const SaveLatent$5 = {
  display_name: "SaveLatent",
  inputs: {
    samples: {
      name: "samples"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const SaveWEBM$5 = {
  display_name: "SaveWEBM",
  inputs: {
    images: {
      name: "images"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    codec: {
      name: "codec"
    },
    fps: {
      name: "fps"
    },
    crf: {
      name: "crf",
      tooltip: "Higher crf means lower quality with a smaller file size, lower crf means higher quality higher filesize."
    }
  }
};
const SD_4XUpscale_Conditioning$5 = {
  display_name: "SD_4XUpscale_Conditioning",
  inputs: {
    images: {
      name: "images"
    },
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    scale_ratio: {
      name: "scale_ratio"
    },
    noise_augmentation: {
      name: "noise_augmentation"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const SDTurboScheduler$5 = {
  display_name: "SDTurboScheduler",
  inputs: {
    model: {
      name: "model"
    },
    steps: {
      name: "steps"
    },
    denoise: {
      name: "denoise"
    }
  }
};
const SelfAttentionGuidance$5 = {
  display_name: "Self-Attention Guidance",
  inputs: {
    model: {
      name: "model"
    },
    scale: {
      name: "scale"
    },
    blur_sigma: {
      name: "blur_sigma"
    }
  }
};
const SetClipHooks$5 = {
  display_name: "Set CLIP Hooks",
  inputs: {
    clip: {
      name: "clip"
    },
    apply_to_conds: {
      name: "apply_to_conds"
    },
    schedule_clip: {
      name: "schedule_clip"
    },
    hooks: {
      name: "hooks"
    }
  }
};
const SetFirstSigma$5 = {
  display_name: "SetFirstSigma",
  inputs: {
    sigmas: {
      name: "sigmas"
    },
    sigma: {
      name: "sigma"
    }
  }
};
const SetHookKeyframes$5 = {
  display_name: "Set Hook Keyframes",
  inputs: {
    hooks: {
      name: "hooks"
    },
    hook_kf: {
      name: "hook_kf"
    }
  }
};
const SetLatentNoiseMask$5 = {
  display_name: "Set Latent Noise Mask",
  inputs: {
    samples: {
      name: "samples"
    },
    mask: {
      name: "mask"
    }
  }
};
const SetUnionControlNetType$5 = {
  display_name: "SetUnionControlNetType",
  inputs: {
    control_net: {
      name: "control_net"
    },
    type: {
      name: "type"
    }
  }
};
const SkipLayerGuidanceDiT$5 = {
  display_name: "SkipLayerGuidanceDiT",
  description: "Generic version of SkipLayerGuidance node that can be used on every DiT model.",
  inputs: {
    model: {
      name: "model"
    },
    double_layers: {
      name: "double_layers"
    },
    single_layers: {
      name: "single_layers"
    },
    scale: {
      name: "scale"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    },
    rescaling_scale: {
      name: "rescaling_scale"
    }
  }
};
const SkipLayerGuidanceSD3$5 = {
  display_name: "SkipLayerGuidanceSD3",
  description: "Generic version of SkipLayerGuidance node that can be used on every DiT model.",
  inputs: {
    model: {
      name: "model"
    },
    layers: {
      name: "layers"
    },
    scale: {
      name: "scale"
    },
    start_percent: {
      name: "start_percent"
    },
    end_percent: {
      name: "end_percent"
    }
  }
};
const SolidMask$5 = {
  display_name: "SolidMask",
  inputs: {
    value: {
      name: "value"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    }
  }
};
const SplitImageWithAlpha$5 = {
  display_name: "Split Image with Alpha",
  inputs: {
    image: {
      name: "image"
    }
  }
};
const SplitSigmas$5 = {
  display_name: "SplitSigmas",
  inputs: {
    sigmas: {
      name: "sigmas"
    },
    step: {
      name: "step"
    }
  },
  outputs: {
    "0": {
      name: "high_sigmas"
    },
    "1": {
      name: "low_sigmas"
    }
  }
};
const SplitSigmasDenoise$5 = {
  display_name: "SplitSigmasDenoise",
  inputs: {
    sigmas: {
      name: "sigmas"
    },
    denoise: {
      name: "denoise"
    }
  },
  outputs: {
    "0": {
      name: "high_sigmas"
    },
    "1": {
      name: "low_sigmas"
    }
  }
};
const StableCascade_EmptyLatentImage$5 = {
  display_name: "StableCascade_EmptyLatentImage",
  inputs: {
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    compression: {
      name: "compression"
    },
    batch_size: {
      name: "batch_size"
    }
  },
  outputs: {
    "0": {
      name: "stage_c"
    },
    "1": {
      name: "stage_b"
    }
  }
};
const StableCascade_StageB_Conditioning$5 = {
  display_name: "StableCascade_StageB_Conditioning",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    stage_c: {
      name: "stage_c"
    }
  }
};
const StableCascade_StageC_VAEEncode$5 = {
  display_name: "StableCascade_StageC_VAEEncode",
  inputs: {
    image: {
      name: "image"
    },
    vae: {
      name: "vae"
    },
    compression: {
      name: "compression"
    }
  },
  outputs: {
    "0": {
      name: "stage_c"
    },
    "1": {
      name: "stage_b"
    }
  }
};
const StableCascade_SuperResolutionControlnet$5 = {
  display_name: "StableCascade_SuperResolutionControlnet",
  inputs: {
    image: {
      name: "image"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "controlnet_input"
    },
    "1": {
      name: "stage_c"
    },
    "2": {
      name: "stage_b"
    }
  }
};
const StableZero123_Conditioning$5 = {
  display_name: "StableZero123_Conditioning",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    batch_size: {
      name: "batch_size"
    },
    elevation: {
      name: "elevation"
    },
    azimuth: {
      name: "azimuth"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const StableZero123_Conditioning_Batched$5 = {
  display_name: "StableZero123_Conditioning_Batched",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    batch_size: {
      name: "batch_size"
    },
    elevation: {
      name: "elevation"
    },
    azimuth: {
      name: "azimuth"
    },
    elevation_batch_increment: {
      name: "elevation_batch_increment"
    },
    azimuth_batch_increment: {
      name: "azimuth_batch_increment"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const StyleModelApply$5 = {
  display_name: "Apply Style Model",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    style_model: {
      name: "style_model"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    strength: {
      name: "strength"
    },
    strength_type: {
      name: "strength_type"
    }
  }
};
const StyleModelLoader$5 = {
  display_name: "Load Style Model",
  inputs: {
    style_model_name: {
      name: "style_model_name"
    }
  }
};
const SV3D_Conditioning$5 = {
  display_name: "SV3D_Conditioning",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    video_frames: {
      name: "video_frames"
    },
    elevation: {
      name: "elevation"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const SVD_img2vid_Conditioning$5 = {
  display_name: "SVD_img2vid_Conditioning",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    video_frames: {
      name: "video_frames"
    },
    motion_bucket_id: {
      name: "motion_bucket_id"
    },
    fps: {
      name: "fps"
    },
    augmentation_level: {
      name: "augmentation_level"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo$5 = {
  display_name: "TextEncodeHunyuanVideo_ImageToVideo",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    prompt: {
      name: "prompt"
    },
    image_interleave: {
      name: "image_interleave",
      tooltip: "How much the image influences things vs the text prompt. Higher number means more influence from the text prompt."
    }
  }
};
const ThresholdMask$5 = {
  display_name: "ThresholdMask",
  inputs: {
    mask: {
      name: "mask"
    },
    value: {
      name: "value"
    }
  }
};
const TomePatchModel$5 = {
  display_name: "TomePatchModel",
  inputs: {
    model: {
      name: "model"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const TorchCompileModel$5 = {
  display_name: "TorchCompileModel",
  inputs: {
    model: {
      name: "model"
    },
    backend: {
      name: "backend"
    }
  }
};
const TripleCLIPLoader$5 = {
  display_name: "TripleCLIPLoader",
  description: "[Recipes]\n\nsd3: clip-l, clip-g, t5",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    clip_name3: {
      name: "clip_name3"
    }
  }
};
const unCLIPCheckpointLoader$5 = {
  display_name: "unCLIPCheckpointLoader",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    }
  }
};
const unCLIPConditioning$5 = {
  display_name: "unCLIPConditioning",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    strength: {
      name: "strength"
    },
    noise_augmentation: {
      name: "noise_augmentation"
    }
  }
};
const UNetCrossAttentionMultiply$5 = {
  display_name: "UNetCrossAttentionMultiply",
  inputs: {
    model: {
      name: "model"
    },
    q: {
      name: "q"
    },
    k: {
      name: "k"
    },
    v: {
      name: "v"
    },
    out: {
      name: "out"
    }
  }
};
const UNETLoader$5 = {
  display_name: "Load Diffusion Model",
  inputs: {
    unet_name: {
      name: "unet_name"
    },
    weight_dtype: {
      name: "weight_dtype"
    }
  }
};
const UNetSelfAttentionMultiply$5 = {
  display_name: "UNetSelfAttentionMultiply",
  inputs: {
    model: {
      name: "model"
    },
    q: {
      name: "q"
    },
    k: {
      name: "k"
    },
    v: {
      name: "v"
    },
    out: {
      name: "out"
    }
  }
};
const UNetTemporalAttentionMultiply$5 = {
  display_name: "UNetTemporalAttentionMultiply",
  inputs: {
    model: {
      name: "model"
    },
    self_structural: {
      name: "self_structural"
    },
    self_temporal: {
      name: "self_temporal"
    },
    cross_structural: {
      name: "cross_structural"
    },
    cross_temporal: {
      name: "cross_temporal"
    }
  }
};
const UpscaleModelLoader$5 = {
  display_name: "Load Upscale Model",
  inputs: {
    model_name: {
      name: "model_name"
    }
  }
};
const VAEDecode$5 = {
  display_name: "VAE Decode",
  description: "Decodes latent images back into pixel space images.",
  inputs: {
    samples: {
      name: "samples",
      tooltip: "The latent to be decoded."
    },
    vae: {
      name: "vae",
      tooltip: "The VAE model used for decoding the latent."
    }
  },
  outputs: {
    "0": {
      tooltip: "The decoded image."
    }
  }
};
const VAEDecodeAudio$5 = {
  display_name: "VAEDecodeAudio",
  inputs: {
    samples: {
      name: "samples"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D$5 = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    samples: {
      name: "samples"
    },
    vae: {
      name: "vae"
    },
    num_chunks: {
      name: "num_chunks"
    },
    octree_resolution: {
      name: "octree_resolution"
    }
  }
};
const VAEDecodeTiled$5 = {
  display_name: "VAE Decode (Tiled)",
  inputs: {
    samples: {
      name: "samples"
    },
    vae: {
      name: "vae"
    },
    tile_size: {
      name: "tile_size"
    },
    overlap: {
      name: "overlap"
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "Only used for video VAEs: Amount of frames to decode at a time."
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "Only used for video VAEs: Amount of frames to overlap."
    }
  }
};
const VAEEncode$5 = {
  display_name: "VAE Encode",
  inputs: {
    pixels: {
      name: "pixels"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio$5 = {
  display_name: "VAEEncodeAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint$5 = {
  display_name: "VAE Encode (for Inpainting)",
  inputs: {
    pixels: {
      name: "pixels"
    },
    vae: {
      name: "vae"
    },
    mask: {
      name: "mask"
    },
    grow_mask_by: {
      name: "grow_mask_by"
    }
  }
};
const VAEEncodeTiled$5 = {
  display_name: "VAE Encode (Tiled)",
  inputs: {
    pixels: {
      name: "pixels"
    },
    vae: {
      name: "vae"
    },
    tile_size: {
      name: "tile_size"
    },
    overlap: {
      name: "overlap"
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "Only used for video VAEs: Amount of frames to encode at a time."
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "Only used for video VAEs: Amount of frames to overlap."
    }
  }
};
const VAELoader$5 = {
  display_name: "Load VAE",
  inputs: {
    vae_name: {
      name: "vae_name"
    }
  }
};
const VAESave$5 = {
  display_name: "VAESave",
  inputs: {
    vae: {
      name: "vae"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const VideoLinearCFGGuidance$5 = {
  display_name: "VideoLinearCFGGuidance",
  inputs: {
    model: {
      name: "model"
    },
    min_cfg: {
      name: "min_cfg"
    }
  }
};
const VideoTriangleCFGGuidance$5 = {
  display_name: "VideoTriangleCFGGuidance",
  inputs: {
    model: {
      name: "model"
    },
    min_cfg: {
      name: "min_cfg"
    }
  }
};
const VoxelToMeshBasic$5 = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    voxel: {
      name: "voxel"
    },
    threshold: {
      name: "threshold"
    }
  }
};
const VPScheduler$5 = {
  display_name: "VPScheduler",
  inputs: {
    steps: {
      name: "steps"
    },
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    }
  }
};
const WanImageToVideo$5 = {
  display_name: "WanImageToVideo",
  inputs: {
    positive: {
      name: "positive"
    },
    negative: {
      name: "negative"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    length: {
      name: "length"
    },
    batch_size: {
      name: "batch_size"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    start_image: {
      name: "start_image"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const WebcamCapture$5 = {
  display_name: "Webcam Capture",
  inputs: {
    image: {
      name: "image"
    },
    width: {
      name: "width"
    },
    height: {
      name: "height"
    },
    capture_on_queue: {
      name: "capture_on_queue"
    },
    "waiting for camera___": {}
  }
};
const enNodes = {
  AddNoise: AddNoise$5,
  AlignYourStepsScheduler: AlignYourStepsScheduler$5,
  BasicGuider: BasicGuider$5,
  BasicScheduler: BasicScheduler$5,
  BetaSamplingScheduler: BetaSamplingScheduler$5,
  Canny: Canny$5,
  CFGGuider: CFGGuider$5,
  CheckpointLoader: CheckpointLoader$5,
  CheckpointLoaderSimple: CheckpointLoaderSimple$5,
  CheckpointSave: CheckpointSave$5,
  CLIPAttentionMultiply: CLIPAttentionMultiply$5,
  CLIPLoader: CLIPLoader$5,
  CLIPMergeAdd: CLIPMergeAdd$5,
  CLIPMergeSimple: CLIPMergeSimple$5,
  CLIPMergeSubtract: CLIPMergeSubtract$5,
  CLIPSave: CLIPSave$5,
  CLIPSetLastLayer: CLIPSetLastLayer$5,
  CLIPTextEncode: CLIPTextEncode$5,
  CLIPTextEncodeControlnet: CLIPTextEncodeControlnet$5,
  CLIPTextEncodeFlux: CLIPTextEncodeFlux$5,
  CLIPTextEncodeHunyuanDiT: CLIPTextEncodeHunyuanDiT$5,
  CLIPTextEncodeLumina2: CLIPTextEncodeLumina2$5,
  CLIPTextEncodePixArtAlpha: CLIPTextEncodePixArtAlpha$5,
  CLIPTextEncodeSD3: CLIPTextEncodeSD3$5,
  CLIPTextEncodeSDXL: CLIPTextEncodeSDXL$5,
  CLIPTextEncodeSDXLRefiner: CLIPTextEncodeSDXLRefiner$5,
  CLIPVisionEncode: CLIPVisionEncode$5,
  CLIPVisionLoader: CLIPVisionLoader$5,
  CombineHooks2: CombineHooks2$5,
  CombineHooks4: CombineHooks4$5,
  CombineHooks8: CombineHooks8$5,
  ConditioningAverage: ConditioningAverage$5,
  ConditioningCombine: ConditioningCombine$5,
  ConditioningConcat: ConditioningConcat$5,
  ConditioningSetArea: ConditioningSetArea$5,
  ConditioningSetAreaPercentage: ConditioningSetAreaPercentage$5,
  ConditioningSetAreaPercentageVideo: ConditioningSetAreaPercentageVideo$5,
  ConditioningSetAreaStrength: ConditioningSetAreaStrength$5,
  ConditioningSetDefaultCombine: ConditioningSetDefaultCombine$5,
  ConditioningSetMask: ConditioningSetMask$5,
  ConditioningSetProperties: ConditioningSetProperties$5,
  ConditioningSetPropertiesAndCombine: ConditioningSetPropertiesAndCombine$5,
  ConditioningSetTimestepRange: ConditioningSetTimestepRange$5,
  ConditioningStableAudio: ConditioningStableAudio$5,
  ConditioningTimestepsRange: ConditioningTimestepsRange$5,
  ConditioningZeroOut: ConditioningZeroOut$5,
  ControlNetApply: ControlNetApply$5,
  ControlNetApplyAdvanced: ControlNetApplyAdvanced$5,
  ControlNetApplySD3: ControlNetApplySD3$5,
  ControlNetInpaintingAliMamaApply: ControlNetInpaintingAliMamaApply$5,
  ControlNetLoader: ControlNetLoader$5,
  CosmosImageToVideoLatent: CosmosImageToVideoLatent$5,
  CreateHookKeyframe: CreateHookKeyframe$5,
  CreateHookKeyframesFromFloats: CreateHookKeyframesFromFloats$5,
  CreateHookKeyframesInterpolated: CreateHookKeyframesInterpolated$5,
  CreateHookLora: CreateHookLora$5,
  CreateHookLoraModelOnly: CreateHookLoraModelOnly$5,
  CreateHookModelAsLora: CreateHookModelAsLora$5,
  CreateHookModelAsLoraModelOnly: CreateHookModelAsLoraModelOnly$5,
  CropMask: CropMask$5,
  DiffControlNetLoader: DiffControlNetLoader$5,
  DifferentialDiffusion: DifferentialDiffusion$5,
  DiffusersLoader: DiffusersLoader$5,
  DisableNoise: DisableNoise$5,
  DualCFGGuider: DualCFGGuider$5,
  DualCLIPLoader: DualCLIPLoader$5,
  EmptyCosmosLatentVideo: EmptyCosmosLatentVideo$5,
  EmptyHunyuanLatentVideo: EmptyHunyuanLatentVideo$5,
  EmptyImage: EmptyImage$5,
  EmptyLatentAudio: EmptyLatentAudio$5,
  EmptyLatentHunyuan3Dv2: EmptyLatentHunyuan3Dv2$5,
  EmptyLatentImage: EmptyLatentImage$5,
  EmptyLTXVLatentVideo: EmptyLTXVLatentVideo$5,
  EmptyMochiLatentVideo: EmptyMochiLatentVideo$5,
  EmptySD3LatentImage: EmptySD3LatentImage$5,
  ExponentialScheduler: ExponentialScheduler$5,
  FeatherMask: FeatherMask$5,
  FlipSigmas: FlipSigmas$5,
  FluxDisableGuidance: FluxDisableGuidance$5,
  FluxGuidance: FluxGuidance$5,
  FreeU: FreeU$5,
  FreeU_V2: FreeU_V2$5,
  GITSScheduler: GITSScheduler$5,
  GLIGENLoader: GLIGENLoader$5,
  GLIGENTextBoxApply: GLIGENTextBoxApply$5,
  GrowMask: GrowMask$5,
  Hunyuan3Dv2Conditioning: Hunyuan3Dv2Conditioning$5,
  Hunyuan3Dv2ConditioningMultiView: Hunyuan3Dv2ConditioningMultiView$5,
  HunyuanImageToVideo: HunyuanImageToVideo$5,
  HypernetworkLoader: HypernetworkLoader$5,
  HyperTile: HyperTile$5,
  ImageBatch: ImageBatch$5,
  ImageBlend: ImageBlend$5,
  ImageBlur: ImageBlur$5,
  ImageColorToMask: ImageColorToMask$5,
  ImageCompositeMasked: ImageCompositeMasked$5,
  ImageCrop: ImageCrop$5,
  ImageFromBatch: ImageFromBatch$5,
  ImageInvert: ImageInvert$5,
  ImageOnlyCheckpointLoader: ImageOnlyCheckpointLoader$5,
  ImageOnlyCheckpointSave: ImageOnlyCheckpointSave$5,
  ImagePadForOutpaint: ImagePadForOutpaint$5,
  ImageQuantize: ImageQuantize$5,
  ImageScale: ImageScale$5,
  ImageScaleBy: ImageScaleBy$5,
  ImageScaleToTotalPixels: ImageScaleToTotalPixels$5,
  ImageSharpen: ImageSharpen$5,
  ImageToMask: ImageToMask$5,
  ImageUpscaleWithModel: ImageUpscaleWithModel$5,
  InpaintModelConditioning: InpaintModelConditioning$5,
  InstructPixToPixConditioning: InstructPixToPixConditioning$5,
  InvertMask: InvertMask$5,
  JoinImageWithAlpha: JoinImageWithAlpha$5,
  KarrasScheduler: KarrasScheduler$5,
  KSampler: KSampler$5,
  KSamplerAdvanced: KSamplerAdvanced$5,
  KSamplerSelect: KSamplerSelect$5,
  LaplaceScheduler: LaplaceScheduler$5,
  LatentAdd: LatentAdd$5,
  LatentApplyOperation: LatentApplyOperation$5,
  LatentApplyOperationCFG: LatentApplyOperationCFG$5,
  LatentBatch: LatentBatch$5,
  LatentBatchSeedBehavior: LatentBatchSeedBehavior$5,
  LatentBlend: LatentBlend$5,
  LatentComposite: LatentComposite$5,
  LatentCompositeMasked: LatentCompositeMasked$5,
  LatentCrop: LatentCrop$5,
  LatentFlip: LatentFlip$5,
  LatentFromBatch: LatentFromBatch$5,
  LatentInterpolate: LatentInterpolate$5,
  LatentMultiply: LatentMultiply$5,
  LatentOperationSharpen: LatentOperationSharpen$5,
  LatentOperationTonemapReinhard: LatentOperationTonemapReinhard$5,
  LatentRotate: LatentRotate$5,
  LatentSubtract: LatentSubtract$5,
  LatentUpscale: LatentUpscale$5,
  LatentUpscaleBy: LatentUpscaleBy$5,
  Load3D: Load3D$5,
  Load3DAnimation: Load3DAnimation$5,
  LoadAudio: LoadAudio$5,
  LoadImage: LoadImage$5,
  LoadImageMask: LoadImageMask$5,
  LoadImageOutput: LoadImageOutput$5,
  LoadLatent: LoadLatent$5,
  LoraLoader: LoraLoader$5,
  LoraLoaderModelOnly: LoraLoaderModelOnly$5,
  LoraSave: LoraSave$5,
  LTXVAddGuide: LTXVAddGuide$5,
  LTXVConditioning: LTXVConditioning$5,
  LTXVCropGuides: LTXVCropGuides$5,
  LTXVImgToVideo: LTXVImgToVideo$5,
  LTXVPreprocess: LTXVPreprocess$5,
  LTXVScheduler: LTXVScheduler$5,
  Mahiro: Mahiro$5,
  MaskComposite: MaskComposite$5,
  MaskToImage: MaskToImage$5,
  ModelComputeDtype: ModelComputeDtype$5,
  ModelMergeAdd: ModelMergeAdd$5,
  ModelMergeAuraflow: ModelMergeAuraflow$5,
  ModelMergeBlocks: ModelMergeBlocks$5,
  ModelMergeCosmos14B: ModelMergeCosmos14B$5,
  ModelMergeCosmos7B: ModelMergeCosmos7B$5,
  ModelMergeFlux1: ModelMergeFlux1$5,
  ModelMergeLTXV: ModelMergeLTXV$5,
  ModelMergeMochiPreview: ModelMergeMochiPreview$5,
  ModelMergeSD1: ModelMergeSD1$5,
  ModelMergeSD2: ModelMergeSD2$5,
  ModelMergeSD3_2B: ModelMergeSD3_2B$5,
  ModelMergeSD35_Large: ModelMergeSD35_Large$5,
  ModelMergeSDXL: ModelMergeSDXL$5,
  ModelMergeSimple: ModelMergeSimple$5,
  ModelMergeSubtract: ModelMergeSubtract$5,
  ModelSamplingAuraFlow: ModelSamplingAuraFlow$5,
  ModelSamplingContinuousEDM: ModelSamplingContinuousEDM$5,
  ModelSamplingContinuousV: ModelSamplingContinuousV$5,
  ModelSamplingDiscrete: ModelSamplingDiscrete$5,
  ModelSamplingFlux: ModelSamplingFlux$5,
  ModelSamplingLTXV: ModelSamplingLTXV$5,
  ModelSamplingSD3: ModelSamplingSD3$5,
  ModelSamplingStableCascade: ModelSamplingStableCascade$5,
  ModelSave: ModelSave$5,
  Morphology: Morphology$5,
  PairConditioningCombine: PairConditioningCombine$5,
  PairConditioningSetDefaultCombine: PairConditioningSetDefaultCombine$5,
  PairConditioningSetProperties: PairConditioningSetProperties$5,
  PairConditioningSetPropertiesAndCombine: PairConditioningSetPropertiesAndCombine$5,
  PatchModelAddDownscale: PatchModelAddDownscale$5,
  PerpNeg: PerpNeg$5,
  PerpNegGuider: PerpNegGuider$5,
  PerturbedAttentionGuidance: PerturbedAttentionGuidance$5,
  PhotoMakerEncode: PhotoMakerEncode$5,
  PhotoMakerLoader: PhotoMakerLoader$5,
  PolyexponentialScheduler: PolyexponentialScheduler$5,
  PorterDuffImageComposite: PorterDuffImageComposite$5,
  Preview3D: Preview3D$5,
  Preview3DAnimation: Preview3DAnimation$5,
  PreviewAudio: PreviewAudio$5,
  PreviewImage: PreviewImage$5,
  RandomNoise: RandomNoise$5,
  RebatchImages: RebatchImages$5,
  RebatchLatents: RebatchLatents$5,
  RenormCFG: RenormCFG$5,
  RepeatImageBatch: RepeatImageBatch$5,
  RepeatLatentBatch: RepeatLatentBatch$5,
  RescaleCFG: RescaleCFG$5,
  SamplerCustom: SamplerCustom$5,
  SamplerCustomAdvanced: SamplerCustomAdvanced$5,
  SamplerDPMAdaptative: SamplerDPMAdaptative$5,
  SamplerDPMPP_2M_SDE: SamplerDPMPP_2M_SDE$5,
  SamplerDPMPP_2S_Ancestral: SamplerDPMPP_2S_Ancestral$5,
  SamplerDPMPP_3M_SDE: SamplerDPMPP_3M_SDE$5,
  SamplerDPMPP_SDE: SamplerDPMPP_SDE$5,
  SamplerEulerAncestral: SamplerEulerAncestral$5,
  SamplerEulerAncestralCFGPP: SamplerEulerAncestralCFGPP$5,
  SamplerEulerCFGpp: SamplerEulerCFGpp$5,
  SamplerLCMUpscale: SamplerLCMUpscale$5,
  SamplerLMS: SamplerLMS$5,
  SaveAnimatedPNG: SaveAnimatedPNG$5,
  SaveAnimatedWEBP: SaveAnimatedWEBP$5,
  SaveAudio: SaveAudio$5,
  SaveGLB: SaveGLB$5,
  SaveImage: SaveImage$5,
  SaveImageWebsocket: SaveImageWebsocket$5,
  SaveLatent: SaveLatent$5,
  SaveWEBM: SaveWEBM$5,
  SD_4XUpscale_Conditioning: SD_4XUpscale_Conditioning$5,
  SDTurboScheduler: SDTurboScheduler$5,
  SelfAttentionGuidance: SelfAttentionGuidance$5,
  SetClipHooks: SetClipHooks$5,
  SetFirstSigma: SetFirstSigma$5,
  SetHookKeyframes: SetHookKeyframes$5,
  SetLatentNoiseMask: SetLatentNoiseMask$5,
  SetUnionControlNetType: SetUnionControlNetType$5,
  SkipLayerGuidanceDiT: SkipLayerGuidanceDiT$5,
  SkipLayerGuidanceSD3: SkipLayerGuidanceSD3$5,
  SolidMask: SolidMask$5,
  SplitImageWithAlpha: SplitImageWithAlpha$5,
  SplitSigmas: SplitSigmas$5,
  SplitSigmasDenoise: SplitSigmasDenoise$5,
  StableCascade_EmptyLatentImage: StableCascade_EmptyLatentImage$5,
  StableCascade_StageB_Conditioning: StableCascade_StageB_Conditioning$5,
  StableCascade_StageC_VAEEncode: StableCascade_StageC_VAEEncode$5,
  StableCascade_SuperResolutionControlnet: StableCascade_SuperResolutionControlnet$5,
  StableZero123_Conditioning: StableZero123_Conditioning$5,
  StableZero123_Conditioning_Batched: StableZero123_Conditioning_Batched$5,
  StyleModelApply: StyleModelApply$5,
  StyleModelLoader: StyleModelLoader$5,
  SV3D_Conditioning: SV3D_Conditioning$5,
  SVD_img2vid_Conditioning: SVD_img2vid_Conditioning$5,
  TextEncodeHunyuanVideo_ImageToVideo: TextEncodeHunyuanVideo_ImageToVideo$5,
  ThresholdMask: ThresholdMask$5,
  TomePatchModel: TomePatchModel$5,
  TorchCompileModel: TorchCompileModel$5,
  TripleCLIPLoader: TripleCLIPLoader$5,
  unCLIPCheckpointLoader: unCLIPCheckpointLoader$5,
  unCLIPConditioning: unCLIPConditioning$5,
  UNetCrossAttentionMultiply: UNetCrossAttentionMultiply$5,
  UNETLoader: UNETLoader$5,
  UNetSelfAttentionMultiply: UNetSelfAttentionMultiply$5,
  UNetTemporalAttentionMultiply: UNetTemporalAttentionMultiply$5,
  UpscaleModelLoader: UpscaleModelLoader$5,
  VAEDecode: VAEDecode$5,
  VAEDecodeAudio: VAEDecodeAudio$5,
  VAEDecodeHunyuan3D: VAEDecodeHunyuan3D$5,
  VAEDecodeTiled: VAEDecodeTiled$5,
  VAEEncode: VAEEncode$5,
  VAEEncodeAudio: VAEEncodeAudio$5,
  VAEEncodeForInpaint: VAEEncodeForInpaint$5,
  VAEEncodeTiled: VAEEncodeTiled$5,
  VAELoader: VAELoader$5,
  VAESave: VAESave$5,
  VideoLinearCFGGuidance: VideoLinearCFGGuidance$5,
  VideoTriangleCFGGuidance: VideoTriangleCFGGuidance$5,
  VoxelToMeshBasic: VoxelToMeshBasic$5,
  VPScheduler: VPScheduler$5,
  WanImageToVideo: WanImageToVideo$5,
  WebcamCapture: WebcamCapture$5
};
const Comfy_Canvas_SelectionToolbox$5 = {
  name: "Show selection toolbox"
};
const Comfy_ConfirmClear$5 = {
  name: "Require confirmation when clearing workflow"
};
const Comfy_DevMode$5 = {
  name: "Enable dev mode options (API save, etc.)"
};
const Comfy_DisableFloatRounding$5 = {
  name: "Disable default float widget rounding.",
  tooltip: "(requires page reload) Cannot disable round when round is set by the node in the backend."
};
const Comfy_DisableSliders$5 = {
  name: "Disable node widget sliders"
};
const Comfy_DOMClippingEnabled$5 = {
  name: "Enable DOM element clipping (enabling may reduce performance)"
};
const Comfy_EditAttention_Delta$5 = {
  name: "Ctrl+up/down precision"
};
const Comfy_EnableTooltips$5 = {
  name: "Enable Tooltips"
};
const Comfy_EnableWorkflowViewRestore$5 = {
  name: "Save and restore canvas position and zoom level in workflows"
};
const Comfy_FloatRoundingPrecision$5 = {
  name: "Float widget rounding decimal places [0 = auto].",
  tooltip: "(requires page reload)"
};
const Comfy_Graph_CanvasInfo$5 = {
  name: "Show canvas info on bottom left corner (fps, etc.)"
};
const Comfy_Graph_CanvasMenu$5 = {
  name: "Show graph canvas menu"
};
const Comfy_Graph_CtrlShiftZoom$5 = {
  name: "Enable fast-zoom shortcut (Ctrl + Shift + Drag)"
};
const Comfy_Graph_LinkMarkers$5 = {
  name: "Link midpoint markers",
  options: {
    None: "None",
    Circle: "Circle",
    Arrow: "Arrow"
  }
};
const Comfy_Graph_ZoomSpeed$5 = {
  name: "Canvas zoom speed"
};
const Comfy_Group_DoubleClickTitleToEdit$5 = {
  name: "Double click group title to edit"
};
const Comfy_GroupSelectedNodes_Padding$5 = {
  name: "Group selected nodes padding"
};
const Comfy_LinkRelease_Action$5 = {
  name: "Action on link release (No modifier)",
  options: {
    "context menu": "context menu",
    "search box": "search box",
    "no action": "no action"
  }
};
const Comfy_LinkRelease_ActionShift$5 = {
  name: "Action on link release (Shift)",
  options: {
    "context menu": "context menu",
    "search box": "search box",
    "no action": "no action"
  }
};
const Comfy_LinkRenderMode$5 = {
  name: "Link Render Mode",
  options: {
    Straight: "Straight",
    Linear: "Linear",
    Spline: "Spline",
    Hidden: "Hidden"
  }
};
const Comfy_Locale$5 = {
  name: "Language"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed$5 = {
  name: "Brush adjustment speed multiplier",
  tooltip: "Controls how quickly the brush size and hardness change when adjusting. Higher values mean faster changes."
};
const Comfy_MaskEditor_UseDominantAxis$5 = {
  name: "Lock brush adjustment to dominant axis",
  tooltip: "When enabled, brush adjustments will only affect size OR hardness based on which direction you move more"
};
const Comfy_MaskEditor_UseNewEditor$5 = {
  name: "Use new mask editor",
  tooltip: "Switch to the new mask editor interface"
};
const Comfy_ModelLibrary_AutoLoadAll$5 = {
  name: "Automatically load all model folders",
  tooltip: "If true, all folders will load as soon as you open the model library (this may cause delays while it loads). If false, root level model folders will only load once you click on them."
};
const Comfy_ModelLibrary_NameFormat$5 = {
  name: "What name to display in the model library tree view",
  tooltip: 'Select "filename" to render a simplified view of the raw filename (without directory or ".safetensors" extension) in the model list. Select "title" to display the configurable model metadata title.',
  options: {
    filename: "filename",
    title: "title"
  }
};
const Comfy_Node_AutoSnapLinkToSlot$5 = {
  name: "Auto snap link to node slot",
  tooltip: "When dragging a link over a node, the link automatically snap to a viable input slot on the node"
};
const Comfy_Node_BypassAllLinksOnDelete$5 = {
  name: "Keep all links when deleting nodes",
  tooltip: "When deleting a node, attempt to reconnect all of its input and output links (bypassing the deleted node)"
};
const Comfy_Node_DoubleClickTitleToEdit$5 = {
  name: "Double click node title to edit"
};
const Comfy_Node_MiddleClickRerouteNode$5 = {
  name: "Middle-click creates a new Reroute node"
};
const Comfy_Node_Opacity$5 = {
  name: "Node opacity"
};
const Comfy_Node_ShowDeprecated$5 = {
  name: "Show deprecated nodes in search",
  tooltip: "Deprecated nodes are hidden by default in the UI, but remain functional in existing workflows that use them."
};
const Comfy_Node_ShowExperimental$5 = {
  name: "Show experimental nodes in search",
  tooltip: "Experimental nodes are marked as such in the UI and may be subject to significant changes or removal in future versions. Use with caution in production workflows"
};
const Comfy_Node_SnapHighlightsNode$5 = {
  name: "Snap highlights node",
  tooltip: "When dragging a link over a node with viable input slot, highlight the node"
};
const Comfy_NodeBadge_NodeIdBadgeMode$5 = {
  name: "Node ID badge mode",
  options: {
    None: "None",
    "Show all": "Show all"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode$5 = {
  name: "Node life cycle badge mode",
  options: {
    None: "None",
    "Show all": "Show all"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode$5 = {
  name: "Node source badge mode",
  options: {
    None: "None",
    "Show all": "Show all",
    "Hide built-in": "Hide built-in"
  }
};
const Comfy_NodeInputConversionSubmenus$5 = {
  name: "In the node context menu, place the entries that convert between input/widget in sub-menus."
};
const Comfy_NodeSearchBoxImpl$5 = {
  name: "Node search box implementation",
  options: {
    "default": "default",
    "litegraph (legacy)": "litegraph (legacy)"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview$5 = {
  name: "Node preview",
  tooltip: "Only applies to the default implementation"
};
const Comfy_NodeSearchBoxImpl_ShowCategory$5 = {
  name: "Show node category in search results",
  tooltip: "Only applies to the default implementation"
};
const Comfy_NodeSearchBoxImpl_ShowIdName$5 = {
  name: "Show node id name in search results",
  tooltip: "Only applies to the default implementation"
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency$5 = {
  name: "Show node frequency in search results",
  tooltip: "Only applies to the default implementation"
};
const Comfy_NodeSuggestions_number$5 = {
  name: "Number of nodes suggestions",
  tooltip: "Only for litegraph searchbox/context menu"
};
const Comfy_Pointer_ClickBufferTime$5 = {
  name: "Pointer click drift delay",
  tooltip: "After pressing a pointer button down, this is the maximum time (in milliseconds) that pointer movement can be ignored for.\n\nHelps prevent objects from being unintentionally nudged if the pointer is moved whilst clicking."
};
const Comfy_Pointer_ClickDrift$5 = {
  name: "Pointer click drift (maximum distance)",
  tooltip: "If the pointer moves more than this distance while holding a button down, it is considered dragging (rather than clicking).\n\nHelps prevent objects from being unintentionally nudged if the pointer is moved whilst clicking."
};
const Comfy_Pointer_DoubleClickTime$5 = {
  name: "Double click interval (maximum)",
  tooltip: "The maximum time in milliseconds between the two clicks of a double-click.  Increasing this value may assist if double-clicks are sometimes not registered."
};
const Comfy_PreviewFormat$5 = {
  name: "Preview image format",
  tooltip: "When displaying a preview in the image widget, convert it to a lightweight image, e.g. webp, jpeg, webp;50, etc."
};
const Comfy_PromptFilename$5 = {
  name: "Prompt for filename when saving workflow"
};
const Comfy_Queue_MaxHistoryItems$5 = {
  name: "Queue history size",
  tooltip: "The maximum number of tasks that show in the queue history."
};
const Comfy_QueueButton_BatchCountLimit$5 = {
  name: "Batch count limit",
  tooltip: "The maximum number of tasks added to the queue at one button click"
};
const Comfy_RerouteBeta$5 = {
  name: "Opt-in to the reroute beta test",
  tooltip: "No longer has any effect; reroutes are always enabled."
};
const Comfy_Sidebar_Location$5 = {
  name: "Sidebar location",
  options: {
    left: "left",
    right: "right"
  }
};
const Comfy_Sidebar_Size$5 = {
  name: "Sidebar size",
  options: {
    normal: "normal",
    small: "small"
  }
};
const Comfy_SnapToGrid_GridSize$5 = {
  name: "Snap to grid size",
  tooltip: "When dragging and resizing nodes while holding shift they will be aligned to the grid, this controls the size of that grid."
};
const Comfy_TextareaWidget_FontSize$5 = {
  name: "Textarea widget font size"
};
const Comfy_TextareaWidget_Spellcheck$5 = {
  name: "Textarea widget spellcheck"
};
const Comfy_TreeExplorer_ItemPadding$5 = {
  name: "Tree explorer item padding"
};
const Comfy_UseNewMenu$5 = {
  name: "Use new menu",
  options: {
    Disabled: "Disabled",
    Top: "Top",
    Bottom: "Bottom"
  }
};
const Comfy_Validation_NodeDefs$5 = {
  name: "Validate node definitions (slow)",
  tooltip: "Recommended for node developers. This will validate all node definitions on startup."
};
const Comfy_Validation_Workflows$5 = {
  name: "Validate workflows"
};
const Comfy_WidgetControlMode$5 = {
  name: "Widget control mode",
  tooltip: "Controls when widget values are updated (randomize/increment/decrement), either before the prompt is queued or after.",
  options: {
    before: "before",
    after: "after"
  }
};
const Comfy_Window_UnloadConfirmation$5 = {
  name: "Show confirmation when closing window"
};
const Comfy_Workflow_ConfirmDelete$5 = {
  name: "Show confirmation when deleting workflows"
};
const Comfy_Workflow_ShowMissingModelsWarning$5 = {
  name: "Show missing models warning"
};
const Comfy_Workflow_ShowMissingNodesWarning$5 = {
  name: "Show missing nodes warning"
};
const Comfy_Workflow_SortNodeIdOnSave$5 = {
  name: "Sort node IDs when saving workflow"
};
const Comfy_Workflow_WorkflowTabsPosition$5 = {
  name: "Opened workflows position",
  options: {
    Sidebar: "Sidebar",
    Topbar: "Topbar",
    "Topbar (2nd-row)": "Topbar (2nd-row)"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold$5 = {
  name: "Low quality rendering zoom threshold",
  tooltip: "Render low quality shapes when zoomed out"
};
const LiteGraph_Canvas_MaximumFps$5 = {
  name: "Maximum FPS",
  tooltip: "The maximum frames per second that the canvas is allowed to render. Caps GPU usage at the cost of smoothness. If 0, the screen refresh rate is used. Default: 0"
};
const LiteGraph_ContextMenu_Scaling$5 = {
  name: "Scale node combo widget menus (lists) when zoomed in"
};
const LiteGraph_Node_TooltipDelay$5 = {
  name: "Tooltip Delay"
};
const pysssss_SnapToGrid$5 = {
  name: "Always snap to grid"
};
const enSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "Automatically check for updates"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "Send anonymous usage metrics"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "Pypi Install Mirror",
    tooltip: "Default pip install mirror"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Python Install Mirror",
    tooltip: "Managed Python installations are downloaded from the Astral python-build-standalone project. This variable can be set to a mirror URL to use a different source for Python installations. The provided URL will replace https://github.com/astral-sh/python-build-standalone/releases/download in, e.g., https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gz. Distributions can be read from a local directory by using the file:// URL scheme."
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "Torch Install Mirror",
    tooltip: "Pip install mirror for pytorch"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "Window Style",
    tooltip: "Custom: Replace the system title bar with ComfyUI's Top menu",
    options: {
      "default": "default",
      custom: "custom"
    }
  },
  Comfy_Canvas_SelectionToolbox: Comfy_Canvas_SelectionToolbox$5,
  Comfy_ConfirmClear: Comfy_ConfirmClear$5,
  Comfy_DevMode: Comfy_DevMode$5,
  Comfy_DisableFloatRounding: Comfy_DisableFloatRounding$5,
  Comfy_DisableSliders: Comfy_DisableSliders$5,
  Comfy_DOMClippingEnabled: Comfy_DOMClippingEnabled$5,
  Comfy_EditAttention_Delta: Comfy_EditAttention_Delta$5,
  Comfy_EnableTooltips: Comfy_EnableTooltips$5,
  Comfy_EnableWorkflowViewRestore: Comfy_EnableWorkflowViewRestore$5,
  Comfy_FloatRoundingPrecision: Comfy_FloatRoundingPrecision$5,
  Comfy_Graph_CanvasInfo: Comfy_Graph_CanvasInfo$5,
  Comfy_Graph_CanvasMenu: Comfy_Graph_CanvasMenu$5,
  Comfy_Graph_CtrlShiftZoom: Comfy_Graph_CtrlShiftZoom$5,
  Comfy_Graph_LinkMarkers: Comfy_Graph_LinkMarkers$5,
  Comfy_Graph_ZoomSpeed: Comfy_Graph_ZoomSpeed$5,
  Comfy_Group_DoubleClickTitleToEdit: Comfy_Group_DoubleClickTitleToEdit$5,
  Comfy_GroupSelectedNodes_Padding: Comfy_GroupSelectedNodes_Padding$5,
  Comfy_LinkRelease_Action: Comfy_LinkRelease_Action$5,
  Comfy_LinkRelease_ActionShift: Comfy_LinkRelease_ActionShift$5,
  Comfy_LinkRenderMode: Comfy_LinkRenderMode$5,
  Comfy_Locale: Comfy_Locale$5,
  Comfy_MaskEditor_BrushAdjustmentSpeed: Comfy_MaskEditor_BrushAdjustmentSpeed$5,
  Comfy_MaskEditor_UseDominantAxis: Comfy_MaskEditor_UseDominantAxis$5,
  Comfy_MaskEditor_UseNewEditor: Comfy_MaskEditor_UseNewEditor$5,
  Comfy_ModelLibrary_AutoLoadAll: Comfy_ModelLibrary_AutoLoadAll$5,
  Comfy_ModelLibrary_NameFormat: Comfy_ModelLibrary_NameFormat$5,
  Comfy_Node_AutoSnapLinkToSlot: Comfy_Node_AutoSnapLinkToSlot$5,
  Comfy_Node_BypassAllLinksOnDelete: Comfy_Node_BypassAllLinksOnDelete$5,
  Comfy_Node_DoubleClickTitleToEdit: Comfy_Node_DoubleClickTitleToEdit$5,
  Comfy_Node_MiddleClickRerouteNode: Comfy_Node_MiddleClickRerouteNode$5,
  Comfy_Node_Opacity: Comfy_Node_Opacity$5,
  Comfy_Node_ShowDeprecated: Comfy_Node_ShowDeprecated$5,
  Comfy_Node_ShowExperimental: Comfy_Node_ShowExperimental$5,
  Comfy_Node_SnapHighlightsNode: Comfy_Node_SnapHighlightsNode$5,
  Comfy_NodeBadge_NodeIdBadgeMode: Comfy_NodeBadge_NodeIdBadgeMode$5,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode: Comfy_NodeBadge_NodeLifeCycleBadgeMode$5,
  Comfy_NodeBadge_NodeSourceBadgeMode: Comfy_NodeBadge_NodeSourceBadgeMode$5,
  Comfy_NodeInputConversionSubmenus: Comfy_NodeInputConversionSubmenus$5,
  Comfy_NodeSearchBoxImpl: Comfy_NodeSearchBoxImpl$5,
  Comfy_NodeSearchBoxImpl_NodePreview: Comfy_NodeSearchBoxImpl_NodePreview$5,
  Comfy_NodeSearchBoxImpl_ShowCategory: Comfy_NodeSearchBoxImpl_ShowCategory$5,
  Comfy_NodeSearchBoxImpl_ShowIdName: Comfy_NodeSearchBoxImpl_ShowIdName$5,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency: Comfy_NodeSearchBoxImpl_ShowNodeFrequency$5,
  Comfy_NodeSuggestions_number: Comfy_NodeSuggestions_number$5,
  Comfy_Pointer_ClickBufferTime: Comfy_Pointer_ClickBufferTime$5,
  Comfy_Pointer_ClickDrift: Comfy_Pointer_ClickDrift$5,
  Comfy_Pointer_DoubleClickTime: Comfy_Pointer_DoubleClickTime$5,
  Comfy_PreviewFormat: Comfy_PreviewFormat$5,
  Comfy_PromptFilename: Comfy_PromptFilename$5,
  Comfy_Queue_MaxHistoryItems: Comfy_Queue_MaxHistoryItems$5,
  Comfy_QueueButton_BatchCountLimit: Comfy_QueueButton_BatchCountLimit$5,
  Comfy_RerouteBeta: Comfy_RerouteBeta$5,
  Comfy_Sidebar_Location: Comfy_Sidebar_Location$5,
  Comfy_Sidebar_Size: Comfy_Sidebar_Size$5,
  Comfy_SnapToGrid_GridSize: Comfy_SnapToGrid_GridSize$5,
  Comfy_TextareaWidget_FontSize: Comfy_TextareaWidget_FontSize$5,
  Comfy_TextareaWidget_Spellcheck: Comfy_TextareaWidget_Spellcheck$5,
  Comfy_TreeExplorer_ItemPadding: Comfy_TreeExplorer_ItemPadding$5,
  Comfy_UseNewMenu: Comfy_UseNewMenu$5,
  Comfy_Validation_NodeDefs: Comfy_Validation_NodeDefs$5,
  Comfy_Validation_Workflows: Comfy_Validation_Workflows$5,
  Comfy_WidgetControlMode: Comfy_WidgetControlMode$5,
  Comfy_Window_UnloadConfirmation: Comfy_Window_UnloadConfirmation$5,
  Comfy_Workflow_ConfirmDelete: Comfy_Workflow_ConfirmDelete$5,
  Comfy_Workflow_ShowMissingModelsWarning: Comfy_Workflow_ShowMissingModelsWarning$5,
  Comfy_Workflow_ShowMissingNodesWarning: Comfy_Workflow_ShowMissingNodesWarning$5,
  Comfy_Workflow_SortNodeIdOnSave: Comfy_Workflow_SortNodeIdOnSave$5,
  Comfy_Workflow_WorkflowTabsPosition: Comfy_Workflow_WorkflowTabsPosition$5,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold: LiteGraph_Canvas_LowQualityRenderingZoomThreshold$5,
  LiteGraph_Canvas_MaximumFps: LiteGraph_Canvas_MaximumFps$5,
  LiteGraph_ContextMenu_Scaling: LiteGraph_ContextMenu_Scaling$5,
  LiteGraph_Node_TooltipDelay: LiteGraph_Node_TooltipDelay$5,
  pysssss_SnapToGrid: pysssss_SnapToGrid$5
};
const Comfy_BrowseTemplates$4 = {
  label: "Parcourir les modèles"
};
const Comfy_Canvas_DeleteSelectedItems$4 = {
  label: "Supprimer les éléments sélectionnés"
};
const Comfy_Canvas_FitView$4 = {
  label: "Ajuster la vue aux nœuds sélectionnés"
};
const Comfy_Canvas_ResetView$4 = {
  label: "Réinitialiser la vue"
};
const Comfy_Canvas_ToggleLinkVisibility$4 = {
  label: "Basculer la visibilité du lien sur le canevas"
};
const Comfy_Canvas_ToggleLock$4 = {
  label: "Basculer le verrouillage du canevas"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass$4 = {
  label: "Contourner/Ne pas contourner les nœuds sélectionnés"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse$4 = {
  label: "Réduire/Étendre les nœuds sélectionnés"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute$4 = {
  label: "Mettre en sourdine/Activer le son des nœuds sélectionnés"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin$4 = {
  label: "Épingler/Désépingler les nœuds sélectionnés"
};
const Comfy_Canvas_ToggleSelected_Pin$4 = {
  label: "Épingler/Désépingler les éléments sélectionnés"
};
const Comfy_Canvas_ZoomIn$4 = {
  label: "Zoom avant"
};
const Comfy_Canvas_ZoomOut$4 = {
  label: "Zoom arrière"
};
const Comfy_ClearPendingTasks$4 = {
  label: "Effacer les tâches en attente"
};
const Comfy_ClearWorkflow$4 = {
  label: "Effacer le flux de travail"
};
const Comfy_DuplicateWorkflow$4 = {
  label: "Dupliquer le flux de travail actuel"
};
const Comfy_ExportWorkflow$4 = {
  label: "Exporter le flux de travail"
};
const Comfy_ExportWorkflowAPI$4 = {
  label: "Exporter le flux de travail (format API)"
};
const Comfy_Feedback$4 = {
  label: "Retour d'information"
};
const Comfy_Graph_FitGroupToContents$4 = {
  label: "Ajuster le groupe au contenu"
};
const Comfy_Graph_GroupSelectedNodes$4 = {
  label: "Grouper les nœuds sélectionnés"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode$4 = {
  label: "Convertir les nœuds sélectionnés en nœud de groupe"
};
const Comfy_GroupNode_ManageGroupNodes$4 = {
  label: "Gérer les nœuds de groupe"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes$4 = {
  label: "Dégrouper les nœuds de groupe sélectionnés"
};
const Comfy_Help_AboutComfyUI$4 = {
  label: "Ouvrir À propos de ComfyUI"
};
const Comfy_Help_OpenComfyOrgDiscord$4 = {
  label: "Ouvrir Comfy-Org Discord"
};
const Comfy_Help_OpenComfyUIDocs$4 = {
  label: "Ouvrir les documents ComfyUI"
};
const Comfy_Help_OpenComfyUIForum$4 = {
  label: "Ouvrir le forum Comfy-Org"
};
const Comfy_Help_OpenComfyUIIssues$4 = {
  label: "Ouvrir les problèmes ComfyUI"
};
const Comfy_Interrupt$4 = {
  label: "Interrompre"
};
const Comfy_LoadDefaultWorkflow$4 = {
  label: "Charger le flux de travail par défaut"
};
const Comfy_Manager_CustomNodesManager$4 = {
  label: "Gestionnaire de Nœuds Personnalisés"
};
const Comfy_Manager_ToggleManagerProgressDialog$4 = {
  label: "Basculer la boîte de dialogue de progression"
};
const Comfy_NewBlankWorkflow$4 = {
  label: "Nouveau flux de travail vierge"
};
const Comfy_OpenClipspace$4 = {
  label: "Espace de clip"
};
const Comfy_OpenWorkflow$4 = {
  label: "Ouvrir le flux de travail"
};
const Comfy_QueuePrompt$4 = {
  label: "Invite de file d'attente"
};
const Comfy_QueuePromptFront$4 = {
  label: "Invite de file d'attente (avant)"
};
const Comfy_Redo$4 = {
  label: "Refaire"
};
const Comfy_RefreshNodeDefinitions$4 = {
  label: "Actualiser les définitions de nœud"
};
const Comfy_SaveWorkflow$4 = {
  label: "Enregistrer le flux de travail"
};
const Comfy_SaveWorkflowAs$4 = {
  label: "Enregistrer le flux de travail sous"
};
const Comfy_ShowSettingsDialog$4 = {
  label: "Afficher la boîte de dialogue des paramètres"
};
const Comfy_ToggleTheme$4 = {
  label: "Changer de thème (Sombre/Clair)"
};
const Comfy_Undo$4 = {
  label: "Annuler"
};
const Workspace_CloseWorkflow$4 = {
  label: "Fermer le flux de travail actuel"
};
const Workspace_NextOpenedWorkflow$4 = {
  label: "Flux de travail ouvert suivant"
};
const Workspace_PreviousOpenedWorkflow$4 = {
  label: "Flux de travail ouvert précédent"
};
const Workspace_SearchBox_Toggle$4 = {
  label: "Basculer la boîte de recherche"
};
const Workspace_ToggleBottomPanel$4 = {
  label: "Basculer le panneau inférieur"
};
const Workspace_ToggleFocusMode$4 = {
  label: "Basculer le mode focus"
};
const Workspace_ToggleSidebarTab_queue$4 = {
  label: "Basculer la barre latérale de la file d'attente",
  tooltip: "File d'attente"
};
const Workspace_ToggleSidebarTab_workflows$4 = {
  label: "Basculer la barre latérale des flux de travail",
  tooltip: "Flux de travail"
};
const frCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "Ouvrir le dossier des nœuds personnalisés"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "Ouvrir le dossier des entrées"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "Ouvrir le dossier des journaux"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "Ouvrir extra_model_paths.yaml"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "Ouvrir le dossier des modèles"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "Ouvrir le dossier des sorties"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "Ouvrir les outils de développement"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "Guide de l'utilisateur du bureau"
  },
  "Comfy-Desktop_Quit": {
    label: "Quitter"
  },
  "Comfy-Desktop_Reinstall": {
    label: "Réinstaller"
  },
  "Comfy-Desktop_Restart": {
    label: "Redémarrer"
  },
  Comfy_BrowseTemplates: Comfy_BrowseTemplates$4,
  Comfy_Canvas_DeleteSelectedItems: Comfy_Canvas_DeleteSelectedItems$4,
  Comfy_Canvas_FitView: Comfy_Canvas_FitView$4,
  Comfy_Canvas_ResetView: Comfy_Canvas_ResetView$4,
  Comfy_Canvas_ToggleLinkVisibility: Comfy_Canvas_ToggleLinkVisibility$4,
  Comfy_Canvas_ToggleLock: Comfy_Canvas_ToggleLock$4,
  Comfy_Canvas_ToggleSelectedNodes_Bypass: Comfy_Canvas_ToggleSelectedNodes_Bypass$4,
  Comfy_Canvas_ToggleSelectedNodes_Collapse: Comfy_Canvas_ToggleSelectedNodes_Collapse$4,
  Comfy_Canvas_ToggleSelectedNodes_Mute: Comfy_Canvas_ToggleSelectedNodes_Mute$4,
  Comfy_Canvas_ToggleSelectedNodes_Pin: Comfy_Canvas_ToggleSelectedNodes_Pin$4,
  Comfy_Canvas_ToggleSelected_Pin: Comfy_Canvas_ToggleSelected_Pin$4,
  Comfy_Canvas_ZoomIn: Comfy_Canvas_ZoomIn$4,
  Comfy_Canvas_ZoomOut: Comfy_Canvas_ZoomOut$4,
  Comfy_ClearPendingTasks: Comfy_ClearPendingTasks$4,
  Comfy_ClearWorkflow: Comfy_ClearWorkflow$4,
  Comfy_DuplicateWorkflow: Comfy_DuplicateWorkflow$4,
  Comfy_ExportWorkflow: Comfy_ExportWorkflow$4,
  Comfy_ExportWorkflowAPI: Comfy_ExportWorkflowAPI$4,
  Comfy_Feedback: Comfy_Feedback$4,
  Comfy_Graph_FitGroupToContents: Comfy_Graph_FitGroupToContents$4,
  Comfy_Graph_GroupSelectedNodes: Comfy_Graph_GroupSelectedNodes$4,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode: Comfy_GroupNode_ConvertSelectedNodesToGroupNode$4,
  Comfy_GroupNode_ManageGroupNodes: Comfy_GroupNode_ManageGroupNodes$4,
  Comfy_GroupNode_UngroupSelectedGroupNodes: Comfy_GroupNode_UngroupSelectedGroupNodes$4,
  Comfy_Help_AboutComfyUI: Comfy_Help_AboutComfyUI$4,
  Comfy_Help_OpenComfyOrgDiscord: Comfy_Help_OpenComfyOrgDiscord$4,
  Comfy_Help_OpenComfyUIDocs: Comfy_Help_OpenComfyUIDocs$4,
  Comfy_Help_OpenComfyUIForum: Comfy_Help_OpenComfyUIForum$4,
  Comfy_Help_OpenComfyUIIssues: Comfy_Help_OpenComfyUIIssues$4,
  Comfy_Interrupt: Comfy_Interrupt$4,
  Comfy_LoadDefaultWorkflow: Comfy_LoadDefaultWorkflow$4,
  Comfy_Manager_CustomNodesManager: Comfy_Manager_CustomNodesManager$4,
  Comfy_Manager_ToggleManagerProgressDialog: Comfy_Manager_ToggleManagerProgressDialog$4,
  Comfy_NewBlankWorkflow: Comfy_NewBlankWorkflow$4,
  Comfy_OpenClipspace: Comfy_OpenClipspace$4,
  Comfy_OpenWorkflow: Comfy_OpenWorkflow$4,
  Comfy_QueuePrompt: Comfy_QueuePrompt$4,
  Comfy_QueuePromptFront: Comfy_QueuePromptFront$4,
  Comfy_Redo: Comfy_Redo$4,
  Comfy_RefreshNodeDefinitions: Comfy_RefreshNodeDefinitions$4,
  Comfy_SaveWorkflow: Comfy_SaveWorkflow$4,
  Comfy_SaveWorkflowAs: Comfy_SaveWorkflowAs$4,
  Comfy_ShowSettingsDialog: Comfy_ShowSettingsDialog$4,
  Comfy_ToggleTheme: Comfy_ToggleTheme$4,
  Comfy_Undo: Comfy_Undo$4,
  Workspace_CloseWorkflow: Workspace_CloseWorkflow$4,
  Workspace_NextOpenedWorkflow: Workspace_NextOpenedWorkflow$4,
  Workspace_PreviousOpenedWorkflow: Workspace_PreviousOpenedWorkflow$4,
  Workspace_SearchBox_Toggle: Workspace_SearchBox_Toggle$4,
  Workspace_ToggleBottomPanel: Workspace_ToggleBottomPanel$4,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "Basculer le panneau inférieur du terminal"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "Basculer le panneau inférieur des journaux"
  },
  Workspace_ToggleFocusMode: Workspace_ToggleFocusMode$4,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "Basculer la barre latérale de la bibliothèque de modèles",
    tooltip: "Bibliothèque de modèles"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "Basculer la barre latérale de la bibliothèque de nœuds",
    tooltip: "Bibliothèque de nœuds"
  },
  Workspace_ToggleSidebarTab_queue: Workspace_ToggleSidebarTab_queue$4,
  Workspace_ToggleSidebarTab_workflows: Workspace_ToggleSidebarTab_workflows$4
};
const clipboard$4 = {
  errorMessage: "Échec de la copie dans le presse-papiers",
  errorNotSupported: "L'API du presse-papiers n'est pas prise en charge par votre navigateur",
  successMessage: "Copié dans le presse-papiers"
};
const color$4 = {
  black: "Noir",
  blue: "Bleu",
  brown: "Marron",
  custom: "Personnalisé",
  cyan: "Cyan",
  "default": "Par défaut",
  green: "Vert",
  noColor: "Pas de couleur",
  pale_blue: "Bleu pâle",
  pink: "Rose",
  purple: "Violet",
  red: "Rouge",
  yellow: "Jaune"
};
const contextMenu$4 = {
  " to input": " en entrée",
  " to widget": " en widget",
  "Add Group": "Ajouter un Groupe",
  "Add Group For Selected Nodes": "Ajouter un Groupe pour les Nœuds Sélectionnés",
  "Add Node": "Ajouter un Nœud",
  Bypass: "Contourner",
  Clone: "Cloner",
  Collapse: "Réduire",
  Colors: "Couleurs",
  "Convert ": "Convertir ",
  "Convert Input to Widget": "Convertir l'Entrée en Widget",
  "Convert Widget to Input": "Convertir le Widget en Entrée",
  "Convert to Group Node": "Convertir en Nœud de Groupe",
  "Copy (Clipspace)": "Copier (Clipspace)",
  Expand: "Développer",
  Inputs: "Entrées",
  Manage: "Gérer",
  "Manage Group Nodes": "Gérer les Nœuds de Groupe",
  Mode: "Mode",
  "Node Templates": "Modèles de Nœuds",
  Outputs: "Sorties",
  Pin: "Épingler",
  Properties: "Propriétés",
  "Properties Panel": "Panneau des Propriétés",
  Remove: "Supprimer",
  Resize: "Redimensionner",
  "Save Selected as Template": "Enregistrer la Sélection comme Modèle",
  Search: "Recherche",
  Shapes: "Formes",
  Title: "Titre",
  Unpin: "Désépingler"
};
const dataTypes$4 = {
  AUDIO: "AUDIO",
  BOOLEAN: "BOOLEAN",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP_VISION",
  CLIP_VISION_OUTPUT: "SORTIE_CLIP_VISION",
  COMBO: "COMBO",
  CONDITIONING: "CONDITIONNEMENT",
  CONTROL_NET: "RESEAU_DE_CONTROLE",
  FLOAT: "FLOTTANT",
  FLOATS: "FLOTTANTS",
  GLIGEN: "GLIGEN",
  GUIDER: "GUIDE",
  HOOKS: "CROCHETS",
  HOOK_KEYFRAMES: "CLEFS_DE_CROCHET",
  IMAGE: "IMAGE",
  INT: "ENTIER",
  LATENT: "LATENT",
  LATENT_OPERATION: "OPERATION_LATENTE",
  LOAD_3D: "CHARGER_3D",
  LOAD_3D_ANIMATION: "CHARGER_ANIMATION_3D",
  MASK: "MASQUE",
  MESH: "MAILLAGE",
  MODEL: "MODÈLE",
  NOISE: "BRUIT",
  PHOTOMAKER: "PHOTOMAKER",
  SAMPLER: "ÉCHANTILLONNEUR",
  SIGMAS: "SIGMAS",
  STRING: "CHAÎNE",
  STYLE_MODEL: "MODÈLE_DE_STYLE",
  TIMESTEPS_RANGE: "PLAGE_DES_ÉTAPES_TEMPORELLES",
  UPSCALE_MODEL: "MODÈLE_DE_MISE_À_L'ÉCHELLE",
  VAE: "VAE",
  VOXEL: "VOXEL",
  WEBCAM: "WEBCAM"
};
const desktopMenu$4 = {
  confirmQuit: "Il y a des flux de travail non enregistrés ouverts; toutes les modifications non enregistrées seront perdues. Ignorer cela et quitter?",
  confirmReinstall: "Cela effacera votre fichier extra_models_config.yaml,\net commencera l'installation à nouveau.\n\nÊtes-vous sûr ?",
  quit: "Quitter",
  reinstall: "Réinstaller"
};
const desktopUpdate$4 = {
  description: "ComfyUI Desktop installe de nouvelles dépendances. Cela peut prendre quelques minutes.",
  terminalDefaultMessage: "Toute sortie de console de la mise à jour sera affichée ici.",
  title: "Mise à jour de ComfyUI Desktop"
};
const downloadGit$4 = {
  gitWebsite: "Télécharger git",
  instructions: "Veuillez télécharger et installer la dernière version pour votre système d'exploitation. Le bouton Télécharger git ci-dessous ouvre la page de téléchargement de git-scm.com.",
  message: "Impossible de localiser git. Une copie fonctionnelle de git est nécessaire pour un fonctionnement normal.",
  skip: "Passer",
  title: "Télécharger git",
  warning: "Si vous êtes sûr de ne pas avoir besoin de git installé, ou s'il y a eu une erreur, vous pouvez cliquer sur Passer pour contourner cette vérification. Essayer de faire fonctionner ComfyUI sans une copie fonctionnelle de git n'est actuellement pas pris en charge."
};
const electronFileDownload$4 = {
  cancel: "Annuler le téléchargement",
  cancelled: "Annulé",
  inProgress: "En cours",
  pause: "Pause du téléchargement",
  paused: "En pause",
  resume: "Reprendre le téléchargement"
};
const g$4 = {
  about: "À propos",
  add: "Ajouter",
  all: "Tout",
  apply: "Appliquer",
  back: "Retour",
  cancel: "Annuler",
  capture: "capture",
  category: "Catégorie",
  choose_file_to_upload: "choisissez le fichier à télécharger",
  close: "Fermer",
  color: "Couleur",
  comingSoon: "Bientôt disponible",
  command: "Commande",
  community: "Communauté",
  completed: "Terminé",
  confirm: "Confirmer",
  "continue": "Continuer",
  control_after_generate: "contrôle après génération",
  control_before_generate: "contrôle avant génération",
  copyToClipboard: "Copier dans le presse-papiers",
  currentUser: "Utilisateur actuel",
  customize: "Personnaliser",
  customizeFolder: "Personnaliser le dossier",
  "delete": "Supprimer",
  deprecated: "DEPR",
  description: "Description",
  devices: "Appareils",
  disableAll: "Désactiver tout",
  download: "Télécharger",
  empty: "Vide",
  enableAll: "Activer tout",
  enabled: "Activé",
  error: "Erreur",
  experimental: "BETA",
  "export": "Exportation",
  extensionName: "Nom de l'extension",
  feedback: "Commentaires",
  filter: "Filtrer",
  findIssues: "Trouver des problèmes",
  firstTimeUIMessage: `C'est la première fois que vous utilisez la nouvelle interface utilisateur. Choisissez "Menu > Utiliser le nouveau menu > Désactivé" pour restaurer l'ancienne interface utilisateur.`,
  goToNode: "Aller au nœud",
  icon: "Icône",
  imageFailedToLoad: "Échec du chargement de l'image",
  "import": "Importer",
  inProgress: "En cours",
  insert: "Insérer",
  install: "Installer",
  installed: "Installé",
  installing: "Installation",
  keybinding: "Raccourci clavier",
  loadAllFolders: "Charger tous les dossiers",
  loadWorkflow: "Charger le flux de travail",
  loading: "Chargement",
  logs: "Journaux",
  missing: "Manquant",
  name: "Nom",
  newFolder: "Nouveau dossier",
  next: "Suivant",
  no: "Non",
  noResultsFound: "Aucun résultat trouvé",
  noTasksFound: "Aucune tâche trouvée",
  noTasksFoundMessage: "Il n'y a pas de tâches dans la file d'attente.",
  noWorkflowsFound: "Aucun flux de travail trouvé.",
  nodes: "Nœuds",
  ok: "OK",
  openNewIssue: "Ouvrir un nouveau problème",
  overwrite: "Écraser",
  reconnected: "Reconnecté",
  reconnecting: "Reconnexion",
  refresh: "Rafraîchir",
  reloadToApplyChanges: "Recharger pour appliquer les modifications",
  rename: "Renommer",
  reportIssue: "Envoyer le rapport",
  reportIssueTooltip: "Soumettre le rapport d'erreur à Comfy Org",
  reportSent: "Rapport soumis",
  reset: "Réinitialiser",
  resetKeybindingsTooltip: "Réinitialiser les raccourcis clavier par défaut",
  restart: "Redémarrer",
  resultsCount: "{count} Résultats Trouvés",
  save: "Enregistrer",
  saving: "Enregistrement",
  searchExtensions: "Rechercher des extensions",
  searchFailedMessage: "Nous n'avons trouvé aucun paramètre correspondant à votre recherche. Essayez d'ajuster vos termes de recherche.",
  searchKeybindings: "Rechercher des raccourcis clavier",
  searchModels: "Rechercher des modèles",
  searchNodes: "Rechercher des nœuds",
  searchSettings: "Rechercher des paramètres",
  searchWorkflows: "Rechercher des flux de travail",
  settings: "Paramètres",
  showReport: "Afficher le rapport",
  sort: "Trier",
  status: "Statut",
  success: "Succès",
  systemInfo: "Informations système",
  terminal: "Terminal",
  updated: "Mis à jour",
  upload: "Téléverser",
  videoFailedToLoad: "Échec du chargement de la vidéo",
  workflow: "Flux de travail"
};
const graphCanvasMenu$4 = {
  fitView: "Adapter la vue",
  panMode: "Mode panoramique",
  resetView: "Réinitialiser la vue",
  selectMode: "Mode sélection",
  toggleLinkVisibility: "Basculer la visibilité des liens",
  zoomIn: "Zoom avant",
  zoomOut: "Zoom arrière"
};
const groupNode$4 = {
  create: "Créer un nœud de groupe",
  enterName: "Entrer le nom"
};
const icon$4 = {
  bookmark: "Favori",
  box: "Boîte",
  briefcase: "Porte-documents",
  "exclamation-triangle": "Avertissement",
  file: "Fichier",
  folder: "Dossier",
  heart: "Cœur",
  inbox: "Boîte de réception",
  star: "Étoile"
};
const install$4 = {
  appDataLocationTooltip: "Répertoire des données de l'application ComfyUI. Stocke :\n- Logs\n- Configurations du serveur",
  appPathLocationTooltip: "Répertoire des ressources de l'application ComfyUI. Stocke le code et les ressources de ComfyUI",
  cannotWrite: "Impossible d'écrire sur le chemin sélectionné",
  chooseInstallationLocation: "Choisissez l'emplacement d'installation",
  customNodes: "Nœuds personnalisés",
  customNodesDescription: "Réinstallez les nœuds personnalisés à partir des installations existantes de ComfyUI.",
  desktopAppSettings: "Paramètres de l'application de bureau",
  desktopAppSettingsDescription: "Configurez comment ComfyUI se comporte sur votre bureau. Vous pouvez modifier ces paramètres plus tard.",
  desktopSettings: "Paramètres de bureau",
  failedToSelectDirectory: "Échec de la sélection du répertoire",
  gpu: "GPU",
  gpuSelection: {
    cpuMode: "Mode CPU",
    cpuModeDescription: "Le mode CPU est destiné aux développeurs et aux cas limites rares uniquement.",
    cpuModeDescription2: "Si vous n'êtes pas absolument certain d'en avoir besoin, veuillez ignorer cette case et sélectionnez votre GPU ci-dessus.",
    customComfyNeedsPython: "ComfyUI ne fonctionnera pas tant que python n'est pas configuré",
    customInstallRequirements: "Installez toutes les exigences et dépendances (par exemple, torch personnalisé)",
    customManualVenv: "Configurer manuellement l'environnement virtuel python",
    customMayNotWork: "Ceci n'est pas du tout pris en charge, et peut simplement ne pas fonctionner",
    customSkipsPython: "Cette option saute la configuration python normale.",
    enableCpuMode: "Activer le mode CPU",
    mpsDescription: "Les shaders de performance métallique d'Apple sont pris en charge en utilisant la version nocturne de pytorch.",
    nvidiaDescription: "Les appareils NVIDIA sont directement pris en charge en utilisant les builds CUDA de pytorch.",
    selectGpu: "Sélectionnez le GPU",
    selectGpuDescription: "Sélectionnez le type de GPU que vous avez"
  },
  helpImprove: "Veuillez aider à améliorer ComfyUI",
  installLocation: "Emplacement d'installation",
  installLocationDescription: "Sélectionnez le répertoire pour les données utilisateur de ComfyUI. Un environnement python sera installé à l'emplacement sélectionné. Veuillez vous assurer que le disque sélectionné a suffisamment d'espace (~15GB) restant.",
  installLocationTooltip: "Répertoire des données utilisateur de ComfyUI. Stocke :\n- Environnement Python\n- Modèles\n- Nœuds personnalisés\n",
  insufficientFreeSpace: "Espace insuffisant - espace libre minimum",
  isOneDrive: "L'installation dans OneDrive peut causer des problèmes. Nous recommandons fortement d'installer dans un emplacement non-OneDrive.",
  manualConfiguration: {
    createVenv: "Vous devrez créer un environnement virtuel dans le répertoire suivant",
    requirements: "Exigences",
    restartWhenFinished: "Lorsque vous avez terminé de configurer l'environnement virtuel, veuillez redémarrer ComfyUI.",
    title: "Configuration manuelle",
    virtualEnvironmentPath: "Chemin de l'environnement virtuel"
  },
  metricsDisabled: "Métriques désactivées",
  metricsEnabled: "Métriques activées",
  migrateFromExistingInstallation: "Migrer à partir d'une installation existante",
  migration: "Migration",
  migrationOptional: "La migration est facultative. Si vous n'avez pas d'installation existante, vous pouvez sauter cette étape.",
  migrationSourcePathDescription: "Si vous avez une installation existante de ComfyUI, nous pouvons copier/lier vos fichiers utilisateur et modèles existants à la nouvelle installation. Votre installation existante de ComfyUI ne sera pas affectée.",
  moreInfo: "Pour plus d'informations, veuillez lire notre",
  nonDefaultDrive: "Veuillez installer ComfyUI sur le disque système de votre ordinateur (par exemple C:\\). Les disques avec des systèmes de fichiers différents peuvent causer des problèmes imprévisibles. Les modèles et autres fichiers peuvent être stockés sur d'autres disques après l'installation.",
  parentMissing: "Le chemin n'existe pas - créez d'abord le répertoire contenant",
  pathExists: "Le répertoire existe déjà - veuillez vous assurer que vous avez sauvegardé toutes les données",
  pathValidationFailed: "Échec de la validation du chemin",
  privacyPolicy: "politique de confidentialité",
  selectItemsToMigrate: "Sélectionnez les éléments à migrer",
  settings: {
    allowMetrics: "Métriques d'utilisation",
    allowMetricsDescription: "Aidez à améliorer ComfyUI en envoyant des métriques d'utilisation anonymes. Aucune information personnelle ou contenu de flux de travail ne sera collecté.",
    autoUpdate: "Mises à jour automatiques",
    autoUpdateDescription: "Téléchargez et installez automatiquement les mises à jour lorsqu'elles deviennent disponibles. Vous serez toujours informé avant l'installation des mises à jour.",
    checkingMirrors: "Vérification de l'accès réseau aux miroirs python...",
    dataCollectionDialog: {
      collect: {
        errorReports: "Message d'erreur et trace de la pile",
        systemInfo: "Matériel, type de système d'exploitation et version de l'application",
        userJourneyEvents: "Événements du parcours utilisateur"
      },
      doNotCollect: {
        customNodeConfigurations: "Configurations de nœud personnalisées",
        fileSystemInformation: "Informations sur le système de fichiers",
        personalInformation: "Informations personnelles",
        workflowContents: "Contenus du flux de travail"
      },
      title: "À propos de la collecte de données",
      viewFullPolicy: "Voir la politique complète",
      whatWeCollect: "Ce que nous collectons :",
      whatWeDoNotCollect: "Ce que nous ne collectons pas :"
    },
    errorUpdatingConsent: "Erreur de mise à jour du consentement",
    errorUpdatingConsentDetail: "Échec de la mise à jour des paramètres de consentement aux métriques",
    learnMoreAboutData: "En savoir plus sur la collecte de données",
    mirrorSettings: "Paramètres du Miroir",
    mirrorsReachable: "L'accès réseau aux miroirs python est bon",
    mirrorsUnreachable: "L'accès au réseau à certains miroirs python est mauvais",
    pypiMirrorPlaceholder: "Entrez l'URL du miroir PyPI",
    pythonMirrorPlaceholder: "Entrez l'URL du miroir Python"
  },
  systemLocations: "Emplacements système",
  unhandledError: "Erreur inconnue",
  updateConsent: "Vous avez précédemment accepté de signaler les plantages. Nous suivons maintenant des métriques basées sur les événements pour aider à identifier les bugs et améliorer l'application. Aucune information personnelle identifiable n'est collectée."
};
const issueReport$4 = {
  contactFollowUp: "Contactez-moi pour un suivi",
  feedbackTitle: "Aidez-nous à améliorer ComfyUI en fournissant des commentaires",
  helpFix: "Aidez à résoudre cela",
  notifyResolve: "Prévenez-moi lorsque résolu",
  provideAdditionalDetails: "Fournir des détails supplémentaires (facultatif)",
  provideEmail: "Donnez-nous votre email (Facultatif)",
  rating: "Évaluation",
  stackTrace: "Trace de la pile",
  submitErrorReport: "Soumettre un rapport d'erreur (Facultatif)",
  systemStats: "Statistiques du système",
  validation: {
    invalidEmail: "Veuillez entrer une adresse e-mail valide",
    maxLength: "Message trop long"
  }
};
const load3d$4 = {
  backgroundColor: "Couleur de fond",
  camera: "Caméra",
  edgeThreshold: "Seuil de Bordure",
  "export": "Exportation",
  exportModel: "Exportation du modèle",
  exportingModel: "Exportation du modèle en cours...",
  fov: "FOV",
  light: "Lumière",
  lightIntensity: "Intensité de la lumière",
  loadingModel: "Chargement du modèle 3D...",
  materialMode: "Mode Matériel",
  model: "Modèle",
  previewOutput: "Aperçu de la sortie",
  removeBackgroundImage: "Supprimer l'image de fond",
  scene: "Scène",
  showGrid: "Afficher la grille",
  switchCamera: "Changer de caméra",
  switchingMaterialMode: "Changement de mode de matériau...",
  upDirection: "Direction Haut",
  uploadBackgroundImage: "Télécharger l'image de fond"
};
const maintenance$4 = {
  None: "Aucun",
  OK: "OK",
  Skipped: "Ignoré",
  allOk: "Aucun problème détecté.",
  confirmTitle: "Êtes-vous sûr ?",
  consoleLogs: "Journaux de la console",
  detected: "Détecté",
  error: {
    cannotContinue: "Impossible de continuer - des erreurs subsistent",
    defaultDescription: "Une erreur s'est produite lors de l'exécution d'une tâche de maintenance.",
    taskFailed: "La tâche a échoué.",
    toastTitle: "Erreur de tâche"
  },
  refreshing: "Actualisation",
  showManual: "Afficher les tâches de maintenance",
  status: "Statut",
  terminalDefaultMessage: "Lorsque vous exécutez une commande de dépannage, toute sortie sera affichée ici.",
  title: "Maintenance"
};
const manager$4 = {
  createdBy: "Créé par",
  dependencies: "Dépendances",
  discoverCommunityContent: "Découvrez les packs de nœuds, extensions et plus encore créés par la communauté...",
  downloads: "Téléchargements",
  errorConnecting: "Erreur de connexion au registre de nœuds Comfy.",
  filter: {
    disabled: "Désactivé",
    enabled: "Activé",
    nodePack: "Pack de Nœuds"
  },
  inWorkflow: "Dans le flux de travail",
  infoPanelEmpty: "Cliquez sur un élément pour voir les informations",
  installSelected: "Installer sélectionné",
  lastUpdated: "Dernière mise à jour",
  latestVersion: "Dernière",
  license: "Licence",
  loadingVersions: "Chargement des versions...",
  nightlyVersion: "Nocturne",
  noDescription: "Aucune description disponible",
  noResultsFound: "Aucun résultat trouvé correspondant à votre recherche.",
  nodePack: "Pack de Nœuds",
  packsSelected: "Packs sélectionnés",
  repository: "Référentiel",
  restartToApplyChanges: "Pour appliquer les modifications, veuillez redémarrer ComfyUI",
  searchPlaceholder: "Recherche",
  selectVersion: "Sélectionner la version",
  sort: {
    downloads: "Le plus populaire",
    rating: "Évaluation"
  },
  status: {
    active: "Actif",
    banned: "Banni",
    deleted: "Supprimé",
    flagged: "Signalé",
    pending: "En attente",
    unknown: "Inconnu"
  },
  title: "Gestionnaire de Nœuds Personnalisés",
  totalNodes: "Total de Nœuds",
  tryAgainLater: "Veuillez réessayer plus tard.",
  tryDifferentSearch: "Veuillez essayer une autre requête de recherche.",
  uninstall: "Désinstaller",
  uninstallSelected: "Désinstaller sélectionné",
  uninstalling: "Désinstallation",
  update: "Mettre à jour",
  version: "Version"
};
const maskEditor$4 = {
  "Apply to Whole Image": "Appliquer à toute l'image",
  "Brush Settings": "Paramètres de brosse",
  "Brush Shape": "Forme de brosse",
  Clear: "Effacer",
  "Color Select Settings": "Paramètres de sélection de couleur",
  "Fill Opacity": "Opacité de remplissage",
  Hardness: "Dureté",
  "Image Layer": "Couche d'image",
  Invert: "Inverser",
  Layers: "Couches",
  "Live Preview": "Aperçu en direct",
  "Mask Layer": "Couche de masque",
  "Mask Opacity": "Opacité du masque",
  "Mask Tolerance": "Tolérance du masque",
  Method: "Méthode",
  Opacity: "Opacité",
  "Paint Bucket Settings": "Paramètres du seau de peinture",
  "Reset to Default": "Réinitialiser par défaut",
  "Selection Opacity": "Opacité de sélection",
  "Smoothing Precision": "Précision de lissage",
  "Stop at mask": "Arrêter au masque",
  Thickness: "Épaisseur",
  Tolerance: "Tolérance"
};
const menu$4 = {
  autoQueue: "File d'attente automatique",
  batchCount: "Nombre de lots",
  batchCountTooltip: "Le nombre de fois que la génération du flux de travail doit être mise en file d'attente",
  clear: "Effacer le flux de travail",
  clipspace: "Ouvrir Clipspace",
  disabled: "Désactivé",
  disabledTooltip: "Le flux de travail ne sera pas mis en file d'attente automatiquement",
  execute: "Exécuter",
  hideMenu: "Masquer le menu",
  instant: "Instantané",
  instantTooltip: "Le flux de travail sera mis en file d'attente immédiatement après la fin d'une génération",
  interrupt: "Annuler l'exécution en cours",
  onChange: "Sur modification",
  onChangeTooltip: "Le flux de travail sera mis en file d'attente une fois une modification effectuée",
  refresh: "Actualiser les définitions des nœuds",
  resetView: "Réinitialiser la vue du canevas",
  run: "Exécuter",
  runWorkflow: "Exécuter le workflow (Maj pour mettre en file d'attente en premier)",
  runWorkflowFront: "Exécuter le workflow (Mettre en file d'attente en premier)",
  showMenu: "Afficher le menu",
  toggleBottomPanel: "Basculer le panneau inférieur"
};
const menuLabels$4 = {
  "About ComfyUI": "À propos de ComfyUI",
  "Browse Templates": "Parcourir les modèles",
  "Bypass/Unbypass Selected Nodes": "Contourner/Ne pas contourner les nœuds sélectionnés",
  "Canvas Toggle Link Visibility": "Basculer la visibilité du lien de la toile",
  "Canvas Toggle Lock": "Basculer le verrouillage de la toile",
  "Clear Pending Tasks": "Effacer les tâches en attente",
  "Clear Workflow": "Effacer le flux de travail",
  Clipspace: "Espace de clip",
  "Close Current Workflow": "Fermer le flux de travail actuel",
  "Collapse/Expand Selected Nodes": "Réduire/Étendre les nœuds sélectionnés",
  "Comfy-Org Discord": "Discord de Comfy-Org",
  "ComfyUI Docs": "Docs de ComfyUI",
  "ComfyUI Forum": "Forum ComfyUI",
  "ComfyUI Issues": "Problèmes de ComfyUI",
  "Convert selected nodes to group node": "Convertir les nœuds sélectionnés en nœud de groupe",
  "Custom Nodes Manager": "Gestionnaire de Nœuds Personnalisés",
  "Delete Selected Items": "Supprimer les éléments sélectionnés",
  "Desktop User Guide": "Guide de l'utilisateur de bureau",
  "Duplicate Current Workflow": "Dupliquer le flux de travail actuel",
  Edit: "Éditer",
  Export: "Exporter",
  "Export (API)": "Exporter (API)",
  "Fit Group To Contents": "Ajuster le groupe au contenu",
  "Fit view to selected nodes": "Ajuster la vue aux nœuds sélectionnés",
  "Give Feedback": "Donnez votre avis",
  "Group Selected Nodes": "Grouper les nœuds sélectionnés",
  Help: "Aide",
  Interrupt: "Interrompre",
  "Load Default Workflow": "Charger le flux de travail par défaut",
  "Manage group nodes": "Gérer les nœuds de groupe",
  "Mute/Unmute Selected Nodes": "Mettre en sourdine/Activer le son des nœuds sélectionnés",
  New: "Nouveau",
  "Next Opened Workflow": "Prochain flux de travail ouvert",
  Open: "Ouvrir",
  "Open Custom Nodes Folder": "Ouvrir le dossier des nœuds personnalisés",
  "Open DevTools": "Ouvrir DevTools",
  "Open Inputs Folder": "Ouvrir le dossier des entrées",
  "Open Logs Folder": "Ouvrir le dossier des journaux",
  "Open Models Folder": "Ouvrir le dossier des modèles",
  "Open Outputs Folder": "Ouvrir le dossier des sorties",
  "Open extra_model_paths_yaml": "Ouvrir extra_model_paths.yaml",
  "Pin/Unpin Selected Items": "Épingler/Désépingler les éléments sélectionnés",
  "Pin/Unpin Selected Nodes": "Épingler/Désépingler les nœuds sélectionnés",
  "Previous Opened Workflow": "Flux de travail ouvert précédent",
  "Queue Prompt": "Invite de file d'attente",
  "Queue Prompt (Front)": "Invite de file d'attente (Front)",
  Quit: "Quitter",
  Redo: "Refaire",
  "Refresh Node Definitions": "Actualiser les définitions de nœud",
  Reinstall: "Réinstaller",
  "Reset View": "Réinitialiser la vue",
  Restart: "Redémarrer",
  Save: "Enregistrer",
  "Save As": "Enregistrer sous",
  "Show Settings Dialog": "Afficher la boîte de dialogue des paramètres",
  "Toggle Bottom Panel": "Basculer le panneau inférieur",
  "Toggle Focus Mode": "Basculer le mode focus",
  "Toggle Logs Bottom Panel": "Basculer le panneau inférieur des journaux",
  "Toggle Model Library Sidebar": "Basculer la barre latérale de la bibliothèque de modèles",
  "Toggle Node Library Sidebar": "Basculer la barre latérale de la bibliothèque de nœuds",
  "Toggle Progress Dialog": "Basculer la boîte de dialogue de progression",
  "Toggle Queue Sidebar": "Basculer la barre latérale de la file d'attente",
  "Toggle Search Box": "Basculer la boîte de recherche",
  "Toggle Terminal Bottom Panel": "Basculer le panneau inférieur du terminal",
  "Toggle Theme (Dark/Light)": "Basculer le thème (Sombre/Clair)",
  "Toggle Workflows Sidebar": "Basculer la barre latérale des flux de travail",
  Undo: "Annuler",
  "Ungroup selected group nodes": "Dégrouper les nœuds de groupe sélectionnés",
  Workflow: "Flux de travail",
  "Zoom In": "Zoom avant",
  "Zoom Out": "Zoom arrière"
};
const missingModelsDialog$4 = {
  doNotAskAgain: "Ne plus afficher ce message",
  missingModels: "Modèles manquants",
  missingModelsMessage: "Lors du chargement du graphique, les modèles suivants n'ont pas été trouvés"
};
const nodeCategories$4 = {
  "3d": "3d",
  "3d_models": "modèles_3d",
  _for_testing: "_pour_test",
  advanced: "avancé",
  animation: "animation",
  api: "api",
  attention_experiments: "expériences_d'attention",
  audio: "audio",
  batch: "lot",
  clip: "clip",
  combine: "combiner",
  compositing: "composition",
  "cond pair": "cond pair",
  "cond single": "cond unique",
  conditioning: "conditionnement",
  controlnet: "controlnet",
  create: "créer",
  custom_sampling: "échantillonnage_personnalisé",
  debug: "débogage",
  deprecated: "déprécié",
  flux: "flux",
  gligen: "gligen",
  guidance: "guidance",
  guiders: "guides",
  hooks: "crochets",
  image: "image",
  inpaint: "inpaint",
  instructpix2pix: "instructpix2pix",
  latent: "latent",
  loaders: "chargeurs",
  ltxv: "ltxv",
  mask: "masque",
  model: "modèle",
  model_merging: "fusion_de_modèles",
  model_patches: "patches_de_modèle",
  model_specific: "spécifique_au_modèle",
  noise: "bruit",
  operations: "opérations",
  photomaker: "photomaker",
  postprocessing: "post-traitement",
  preprocessors: "préprocesseurs",
  samplers: "échantillonneurs",
  sampling: "échantillonnage",
  schedulers: "planificateurs",
  scheduling: "planification",
  sd3: "sd3",
  sigmas: "sigmas",
  stable_cascade: "stable_cascade",
  style_model: "modèle_de_style",
  transform: "transformer",
  unet: "unet",
  upscale_diffusion: "diffusion_de_mise_à_l'échelle",
  upscaling: "mise_à_l'échelle",
  video: "vidéo",
  video_models: "modèles_vidéo"
};
const nodeTemplates$4 = {
  enterName: "Entrez le nom",
  saveAsTemplate: "Enregistrer comme modèle"
};
const notSupported$4 = {
  "continue": "Continuer",
  continueTooltip: "Je suis sûr que mon appareil est pris en charge",
  learnMore: "En savoir plus",
  message: "Seuls les appareils suivants sont pris en charge :",
  reportIssue: "Signaler un problème",
  supportedDevices: {
    macos: "MacOS (M1 ou ultérieur)",
    windows: "Windows (GPU Nvidia avec support CUDA)"
  },
  title: "Votre appareil n'est pas pris en charge"
};
const serverConfig$4 = {
  modifiedConfigs: "Vous avez modifié les configurations suivantes du serveur. Redémarrez pour appliquer les modifications.",
  restart: "Redémarrer",
  revertChanges: "Annuler les modifications"
};
const serverConfigCategories$4 = {
  Attention: "Attention",
  CUDA: "CUDA",
  Cache: "Cache",
  Directories: "Répertoires",
  General: "Général",
  Inference: "Inférence",
  Memory: "Mémoire",
  Network: "Réseau",
  Preview: "Aperçu"
};
const serverConfigItems$4 = {
  "cache-classic": {
    name: "Utiliser le système de cache classique"
  },
  "cache-lru": {
    name: "Utiliser le cache LRU avec un maximum de N résultats de nœuds mis en cache.",
    tooltip: "Peut utiliser plus de RAM/VRAM."
  },
  "cpu-vae": {
    name: "Exécuter VAE sur CPU"
  },
  "cross-attention-method": {
    name: "Méthode d'attention croisée"
  },
  "cuda-device": {
    name: "Index de l'appareil CUDA à utiliser"
  },
  "cuda-malloc": {
    name: "Utiliser CUDA malloc pour l'allocation de mémoire"
  },
  "default-hashing-function": {
    name: "Fonction de hachage par défaut pour les fichiers de modèle"
  },
  deterministic: {
    name: "Faire utiliser à pytorch des algorithmes déterministes plus lents quand il le peut.",
    tooltip: "Notez que cela peut ne pas rendre les images déterministes dans tous les cas."
  },
  directml: {
    name: "Index de l'appareil DirectML"
  },
  "disable-all-custom-nodes": {
    name: "Désactiver le chargement de tous les nœuds personnalisés."
  },
  "disable-ipex-optimize": {
    name: "Désactiver l'optimisation IPEX"
  },
  "disable-metadata": {
    name: "Désactiver l'enregistrement des métadonnées d'invite dans les fichiers."
  },
  "disable-smart-memory": {
    name: "Désactiver la gestion intelligente de la mémoire",
    tooltip: "Force ComfyUI à décharger agressivement vers la ram régulière au lieu de garder les modèles dans la vram quand il le peut."
  },
  "disable-xformers": {
    name: "Désactiver l'optimisation xFormers"
  },
  "dont-print-server": {
    name: "Ne pas imprimer la sortie du serveur sur la console."
  },
  "dont-upcast-attention": {
    name: "Prévenir l'attention de conversion ascendante"
  },
  "enable-cors-header": {
    name: `Activer l'en-tête CORS: Utilisez "*" pour toutes les origines ou spécifiez le domaine`
  },
  fast: {
    name: "Activer certaines optimisations non testées et potentiellement dégradantes pour la qualité."
  },
  "force-channels-last": {
    name: "Forcer le format de mémoire des derniers canaux"
  },
  "force-upcast-attention": {
    name: "Forcer l'attention de conversion ascendante"
  },
  "global-precision": {
    name: "Précision globale des points flottants",
    tooltip: "Précision globale des points flottants"
  },
  "input-directory": {
    name: "Répertoire d'entrée"
  },
  listen: {
    name: "Hôte: L'adresse IP à écouter"
  },
  "log-level": {
    name: "Niveau de verbosité de la journalisation"
  },
  "max-upload-size": {
    name: "Taille maximale de téléchargement (MB)"
  },
  "output-directory": {
    name: "Répertoire de sortie"
  },
  port: {
    name: "Port: Le port à écouter"
  },
  "preview-method": {
    name: "Méthode utilisée pour les aperçus latents"
  },
  "preview-size": {
    name: "Taille des images d'aperçu"
  },
  "reserve-vram": {
    name: "VRAM réservée (GB)",
    tooltip: "Définissez la quantité de vram en GB que vous souhaitez réserver pour l'utilisation de votre OS/autres logiciels. Par défaut, une certaine quantité est réservée en fonction de votre OS."
  },
  "text-encoder-precision": {
    name: "Précision de l'encodeur de texte",
    tooltip: "Précision de l'encodeur de texte"
  },
  "tls-certfile": {
    name: "Fichier de certificat TLS: Chemin vers le fichier de certificat TLS pour HTTPS"
  },
  "tls-keyfile": {
    name: "Fichier de clé TLS: Chemin vers le fichier de clé TLS pour HTTPS"
  },
  "unet-precision": {
    name: "Précision UNET",
    tooltip: "Précision UNET"
  },
  "vae-precision": {
    name: "Précision VAE",
    tooltip: "Précision VAE"
  },
  "vram-management": {
    name: "Mode de gestion de la VRAM"
  }
};
const serverStart$4 = {
  openLogs: "Ouvrir les journaux",
  process: {
    error: "Impossible de démarrer ComfyUI Desktop",
    "initial-state": "Chargement...",
    "python-setup": "Configuration de l'environnement Python...",
    ready: "Finalisation...",
    "starting-server": "Démarrage du serveur ComfyUI..."
  },
  reportIssue: "Signaler un problème",
  showTerminal: "Afficher le terminal",
  troubleshoot: "Dépannage"
};
const settingsCategories$4 = {
  About: "À Propos",
  Appearance: "Apparence",
  BrushAdjustment: "Ajustement de Brosse",
  Canvas: "Toile",
  ColorPalette: "Palette de Couleurs",
  Comfy: "Confort",
  "Comfy-Desktop": "Comfy-Desktop",
  ContextMenu: "Menu Contextuel",
  CustomColorPalettes: "Palettes de Couleurs Personnalisées",
  DevMode: "Mode Développeur",
  EditTokenWeight: "Modifier le Poids du Jeton",
  Extension: "Extension",
  General: "Général",
  Graph: "Graphique",
  Group: "Groupe",
  Keybinding: "Raccourci Clavier",
  Link: "Lien",
  LinkRelease: "Libération de Lien",
  LiteGraph: "Lite Graph",
  Locale: "Locale",
  "Mask Editor": "Éditeur de Masque",
  Menu: "Menu",
  ModelLibrary: "Bibliothèque de Modèles",
  NewEditor: "Nouvel Éditeur",
  Node: "Nœud",
  "Node Search Box": "Boîte de Recherche de Nœud",
  "Node Widget": "Widget de Nœud",
  NodeInputConversionSubmenus: "Sous-menus de Conversion d'Entrée de Nœud",
  NodeLibrary: "Bibliothèque de Nœuds",
  Pointer: "Pointeur",
  Queue: "File d'Attente",
  QueueButton: "Bouton de File d'Attente",
  RerouteBeta: "Reroute Beta",
  Server: "Serveur",
  "Server-Config": "Config-Serveur",
  Settings: "Paramètres",
  Sidebar: "Barre Latérale",
  "Tree Explorer": "Explorateur d'Arbre",
  UV: "UV",
  Validation: "Validation",
  Window: "Fenêtre",
  Workflow: "Flux de Travail"
};
const sideToolbar$4 = {
  browseTemplates: "Parcourir les modèles d'exemple",
  downloads: "Téléchargements",
  logout: "Déconnexion",
  modelLibrary: "Bibliothèque de modèles",
  newBlankWorkflow: "Créer un nouveau flux de travail vierge",
  nodeLibrary: "Bibliothèque de nœuds",
  nodeLibraryTab: {
    sortOrder: "Ordre de tri"
  },
  openWorkflow: "Ouvrir le flux de travail dans le système de fichiers local",
  queue: "File d'attente",
  queueTab: {
    backToAllTasks: "Retour à toutes les tâches",
    clearPendingTasks: "Effacer les tâches en attente",
    containImagePreview: "Remplir l'aperçu de l'image",
    coverImagePreview: "Adapter l'aperçu de l'image",
    filter: "Filtrer les sorties",
    filters: {
      hideCached: "Masquer le cache",
      hideCanceled: "Masquer les annulations"
    },
    showFlatList: "Afficher la liste plate"
  },
  themeToggle: "Changer de thème",
  workflowTab: {
    confirmDelete: "Êtes-vous sûr de vouloir supprimer ce flux de travail ?",
    confirmDeleteTitle: "Supprimer le flux de travail ?",
    confirmOverwrite: "Le fichier ci-dessous existe déjà. Souhaitez-vous le remplacer ?",
    confirmOverwriteTitle: "Écraser le fichier existant ?",
    deleteFailed: "La tentative de suppression du flux de travail a échoué.",
    deleteFailedTitle: "Échec de la suppression",
    deleted: "Flux de travail supprimé",
    dirtyClose: "Les fichiers ci-dessous ont été modifiés. Souhaitez-vous les enregistrer avant de fermer ?",
    dirtyCloseHint: "Maintenez Shift pour fermer sans invite",
    dirtyCloseTitle: "Enregistrer les modifications ?",
    workflowTreeType: {
      bookmarks: "Favoris",
      browse: "Parcourir",
      open: "Ouvrir"
    }
  },
  workflows: "Flux de travail"
};
const tabMenu$4 = {
  addToBookmarks: "Ajouter aux Favoris",
  closeOtherTabs: "Fermer les autres onglets",
  closeTab: "Fermer l'onglet",
  closeTabsToLeft: "Fermer les onglets à gauche",
  closeTabsToRight: "Fermer les onglets à droite",
  duplicateTab: "Dupliquer l'onglet",
  removeFromBookmarks: "Retirer des Favoris"
};
const templateWorkflows$4 = {
  category: {
    "3D": "3D",
    "Area Composition": "Composition de zone",
    Audio: "Audio",
    Basics: "Basiques",
    "ComfyUI Examples": "Exemples ComfyUI",
    ControlNet: "ControlNet",
    "Custom Nodes": "Nœuds personnalisés",
    Flux: "Flux",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    Upscaling: "Mise à l'échelle",
    Video: "Vidéo"
  },
  template: {
    "3D": {
      "hunyuan-3d-multiview-elf": "Hunyuan3D Multivue",
      "hunyuan-3d-turbo": "Hunyuan3D Turbo",
      "hunyuan3d-non-multiview-train": "Hunyuan3D",
      stable_zero123_example: "Stable Zero123"
    },
    "Area Composition": {
      area_composition: "Composition de Zone",
      area_composition_reversed: "Composition de Zone Inversée",
      area_composition_square_area_for_subject: "Composition de Zone Carrée pour le Sujet"
    },
    Audio: {
      stable_audio_example: "Stable Audio"
    },
    Basics: {
      "default": "Génération d'Image",
      embedding_example: "Intégration",
      gligen_textbox_example: "Boîte de Texte Gligen",
      image2image: "Image à Image",
      inpain_model_outpainting: "Modèle Inpaint Outpainting",
      inpaint_example: "Inpaint",
      lora: "Lora",
      lora_multiple: "Lora Multiple"
    },
    ControlNet: {
      "2_pass_pose_worship": "2 Passes Pose Worship",
      controlnet_example: "ControlNet",
      depth_controlnet: "Profondeur ControlNet",
      depth_t2i_adapter: "Adaptateur Profondeur T2I",
      mixing_controlnets: "Mélange de ControlNets"
    },
    Flux: {
      flux_canny_model_example: "Flux Canny Model",
      flux_depth_lora_example: "Flux Depth Lora",
      flux_dev_checkpoint_example: "Flux Dev",
      flux_fill_inpaint_example: "Flux Inpaint",
      flux_fill_outpaint_example: "Flux Outpaint",
      flux_redux_model_example: "Flux Redux Model",
      flux_schnell: "Flux Schnell"
    },
    SD3_5: {
      sd3_5_large_blur: "SD3.5 Grand Flou",
      sd3_5_large_canny_controlnet_example: "SD3.5 Grand Canny ControlNet",
      sd3_5_large_depth: "SD3.5 Grande Profondeur",
      sd3_5_simple_example: "SD3.5 Simple"
    },
    SDXL: {
      sdxl_refiner_prompt_example: "SDXL Refiner Prompt",
      sdxl_revision_text_prompts: "Révisions de Texte SDXL",
      sdxl_revision_zero_positive: "Révision Zéro Positive SDXL",
      sdxl_simple_example: "SDXL Simple",
      sdxlturbo_example: "SDXL Turbo"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_esrgan_workflow: "Flux de Travail ESRGAN HiresFix",
      hiresfix_latent_workflow: "Flux de Travail Latent HiresFix",
      latent_upscale_different_prompt_model: "Modèle d'Agrandissement Latent Différent Prompt"
    },
    Video: {
      hunyuan_video_text_to_video: "Texte à Vidéo Hunyuan",
      image_to_video: "Image à Vidéo",
      image_to_video_wan: "Wan 2.1 Image à Vidéo",
      ltxv_image_to_video: "LTXV Image à Vidéo",
      ltxv_text_to_video: "LTXV Texte à Vidéo",
      mochi_text_to_video_example: "Exemple de Texte à Vidéo Mochi",
      text_to_video_wan: "Wan 2.1 Texte à Vidéo",
      txt_to_image_to_video: "Texte à Image à Vidéo"
    }
  },
  title: "Commencez avec un modèle"
};
const userSelect$4 = {
  enterUsername: "Entrez un nom d'utilisateur",
  existingUser: "Utilisateur existant",
  newUser: "Nouvel utilisateur",
  next: "Suivant",
  selectUser: "Sélectionnez un utilisateur"
};
const welcome$4 = {
  getStarted: "Commencer",
  title: "Bienvenue sur ComfyUI"
};
const workflowService$4 = {
  enterFilename: "Entrez le nom du fichier",
  exportWorkflow: "Exporter le flux de travail",
  saveWorkflow: "Enregistrer le flux de travail"
};
const fr = {
  clipboard: clipboard$4,
  color: color$4,
  contextMenu: contextMenu$4,
  dataTypes: dataTypes$4,
  desktopMenu: desktopMenu$4,
  desktopUpdate: desktopUpdate$4,
  downloadGit: downloadGit$4,
  electronFileDownload: electronFileDownload$4,
  g: g$4,
  graphCanvasMenu: graphCanvasMenu$4,
  groupNode: groupNode$4,
  icon: icon$4,
  install: install$4,
  issueReport: issueReport$4,
  load3d: load3d$4,
  maintenance: maintenance$4,
  manager: manager$4,
  maskEditor: maskEditor$4,
  menu: menu$4,
  menuLabels: menuLabels$4,
  missingModelsDialog: missingModelsDialog$4,
  nodeCategories: nodeCategories$4,
  nodeTemplates: nodeTemplates$4,
  notSupported: notSupported$4,
  serverConfig: serverConfig$4,
  serverConfigCategories: serverConfigCategories$4,
  serverConfigItems: serverConfigItems$4,
  serverStart: serverStart$4,
  settingsCategories: settingsCategories$4,
  sideToolbar: sideToolbar$4,
  tabMenu: tabMenu$4,
  templateWorkflows: templateWorkflows$4,
  userSelect: userSelect$4,
  welcome: welcome$4,
  workflowService: workflowService$4
};
const AddNoise$4 = {
  display_name: "AjouterBruit",
  inputs: {
    latent_image: {
      name: "image_latente"
    },
    model: {
      name: "modèle"
    },
    noise: {
      name: "bruit"
    },
    sigmas: {
      name: "sigmas"
    }
  }
};
const AlignYourStepsScheduler$4 = {
  display_name: "PlanificateurAlignezVosÉtapes",
  inputs: {
    denoise: {
      name: "débruitage"
    },
    model_type: {
      name: "type_de_modèle"
    },
    steps: {
      name: "étapes"
    }
  }
};
const BasicGuider$4 = {
  display_name: "GuideBasique",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    model: {
      name: "modèle"
    }
  }
};
const BasicScheduler$4 = {
  display_name: "PlanificateurBasique",
  inputs: {
    denoise: {
      name: "débruitage"
    },
    model: {
      name: "modèle"
    },
    scheduler: {
      name: "planificateur"
    },
    steps: {
      name: "étapes"
    }
  }
};
const BetaSamplingScheduler$4 = {
  display_name: "PlanificateurÉchantillonnageBeta",
  inputs: {
    alpha: {
      name: "alpha"
    },
    beta: {
      name: "beta"
    },
    model: {
      name: "modèle"
    },
    steps: {
      name: "étapes"
    }
  }
};
const CFGGuider$4 = {
  display_name: "GuideCFG",
  inputs: {
    cfg: {
      name: "cfg"
    },
    model: {
      name: "modèle"
    },
    negative: {
      name: "négative"
    },
    positive: {
      name: "positive"
    }
  }
};
const CLIPAttentionMultiply$4 = {
  display_name: "MultiplierAttentionCLIP",
  inputs: {
    clip: {
      name: "clip"
    },
    k: {
      name: "k"
    },
    out: {
      name: "sortie"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const CLIPLoader$4 = {
  description: "[Recettes]\n\nstable_diffusion: clip-l\nstable_cascade: clip-g\nsd3: t5 / clip-g / clip-l\nstable_audio: t5\nmochi: t5\ncosmos: old t5 xxl",
  display_name: "Charger CLIP",
  inputs: {
    clip_name: {
      name: "clip_name"
    },
    device: {
      name: "appareil"
    },
    type: {
      name: "type"
    }
  }
};
const CLIPMergeAdd$4 = {
  display_name: "CLIPMergeAdd",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    }
  }
};
const CLIPMergeSimple$4 = {
  display_name: "CLIPMergeSimple",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const CLIPMergeSubtract$4 = {
  display_name: "CLIPMergeSubtract",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    multiplier: {
      name: "multiplier"
    }
  }
};
const CLIPSave$4 = {
  display_name: "CLIPSave",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "filename_prefix"
    }
  }
};
const CLIPSetLastLayer$4 = {
  display_name: "CLIP Définir Dernière Couche",
  inputs: {
    clip: {
      name: "clip"
    },
    stop_at_clip_layer: {
      name: "stop_at_clip_layer"
    }
  }
};
const CLIPTextEncode$4 = {
  description: "Encode une invite de texte à l'aide d'un modèle CLIP en une intégration qui peut être utilisée pour guider le modèle de diffusion vers la génération d'images spécifiques.",
  display_name: "CLIP Text Encode (Prompt)",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "Le modèle CLIP utilisé pour encoder le texte."
    },
    text: {
      name: "text",
      tooltip: "Le texte à encoder."
    }
  },
  outputs: {
    "0": {
      tooltip: "Une condition contenant le texte intégré utilisé pour guider le modèle de diffusion."
    }
  }
};
const CLIPTextEncodeControlnet$4 = {
  display_name: "CLIPTextEncodeControlnet",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning: {
      name: "conditioning"
    },
    text: {
      name: "text"
    }
  }
};
const CLIPTextEncodeFlux$4 = {
  display_name: "CLIPTextEncodeFlux",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip_l"
    },
    guidance: {
      name: "guidance"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeHunyuanDiT$4 = {
  display_name: "CLIPTextEncodeHunyuanDiT",
  inputs: {
    bert: {
      name: "bert"
    },
    clip: {
      name: "clip"
    },
    mt5xl: {
      name: "mt5xl"
    }
  }
};
const CLIPTextEncodeLumina2$4 = {
  description: "Encode une invite système et une invite utilisateur à l'aide d'un modèle CLIP en une intégration qui peut être utilisée pour guider le modèle de diffusion vers la génération d'images spécifiques.",
  display_name: "CLIP Text Encode pour Lumina2",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "Le modèle CLIP utilisé pour encoder le texte."
    },
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2 propose deux types d'invites système : Supérieur : Vous êtes un assistant conçu pour générer des images supérieures avec le degré supérieur d'alignement image-texte basé sur des invites textuelles ou des invites utilisateur. Alignement : Vous êtes un assistant conçu pour générer des images de haute qualité avec le plus haut degré d'alignement image-texte basé sur des invites textuelles."
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "Le texte à encoder."
    }
  },
  outputs: {
    "0": {
      tooltip: "Une condition contenant le texte intégré utilisé pour guider le modèle de diffusion."
    }
  }
};
const CLIPTextEncodePixArtAlpha$4 = {
  description: "Encode le texte et définit la condition de résolution pour PixArt Alpha. Ne s'applique pas à PixArt Sigma.",
  display_name: "CLIPTextEncodePixArtAlpha",
  inputs: {
    clip: {
      name: "clip"
    },
    height: {
      name: "height"
    },
    text: {
      name: "text"
    },
    width: {
      name: "width"
    }
  }
};
const CLIPTextEncodeSD3$4 = {
  display_name: "CLIPTextEncodeSD3",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_g: {
      name: "clip_g"
    },
    clip_l: {
      name: "clip_l"
    },
    empty_padding: {
      name: "remplissage_vide"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeSDXL$4 = {
  display_name: "CLIPTextEncodeSDXL",
  inputs: {
    clip: {
      name: "clip"
    },
    crop_h: {
      name: "crop_h"
    },
    crop_w: {
      name: "crop_w"
    },
    height: {
      name: "hauteur"
    },
    target_height: {
      name: "hauteur_cible"
    },
    target_width: {
      name: "largeur_cible"
    },
    text_g: {
      name: "text_g"
    },
    text_l: {
      name: "text_l"
    },
    width: {
      name: "largeur"
    }
  }
};
const CLIPTextEncodeSDXLRefiner$4 = {
  display_name: "CLIPTextEncodeSDXLRefiner",
  inputs: {
    ascore: {
      name: "ascore"
    },
    clip: {
      name: "clip"
    },
    height: {
      name: "hauteur"
    },
    text: {
      name: "texte"
    },
    width: {
      name: "largeur"
    }
  }
};
const CLIPVisionEncode$4 = {
  display_name: "CLIP Vision Encode",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    crop: {
      name: "crop"
    },
    image: {
      name: "image"
    }
  }
};
const CLIPVisionLoader$4 = {
  display_name: "Charger CLIP Vision",
  inputs: {
    clip_name: {
      name: "nom_clip"
    }
  }
};
const Canny$4 = {
  display_name: "Canny",
  inputs: {
    high_threshold: {
      name: "seuil_haut"
    },
    image: {
      name: "image"
    },
    low_threshold: {
      name: "seuil_bas"
    }
  }
};
const CheckpointLoader$4 = {
  display_name: "Charger Point de Contrôle Avec Config (OBSOLÈTE)",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt"
    },
    config_name: {
      name: "nom_config"
    }
  }
};
const CheckpointLoaderSimple$4 = {
  description: "Charge un point de contrôle de modèle de diffusion, les modèles de diffusion sont utilisés pour débruiter les latents.",
  display_name: "Charger Point de Contrôle",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt",
      tooltip: "Le nom du point de contrôle (modèle) à charger."
    }
  },
  outputs: {
    "0": {
      tooltip: "Le modèle utilisé pour débruiter les latents."
    },
    "1": {
      tooltip: "Le modèle CLIP utilisé pour encoder les invites de texte."
    },
    "2": {
      tooltip: "Le modèle VAE utilisé pour encoder et décoder les images en espace latent et vice versa."
    }
  }
};
const CheckpointSave$4 = {
  display_name: "Sauvegarder Point de Contrôle",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "préfixe_nom_fichier"
    },
    model: {
      name: "modèle"
    },
    vae: {
      name: "vae"
    }
  }
};
const CombineHooks2$4 = {
  display_name: "Combiner Hooks [2]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    }
  }
};
const CombineHooks4$4 = {
  display_name: "Combiner Hooks [4]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    }
  }
};
const CombineHooks8$4 = {
  display_name: "Combiner Hooks [8]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    },
    hooks_E: {
      name: "hooks_E"
    },
    hooks_F: {
      name: "hooks_F"
    },
    hooks_G: {
      name: "hooks_G"
    },
    hooks_H: {
      name: "hooks_H"
    }
  }
};
const ConditioningAverage$4 = {
  display_name: "Moyenne de Conditionnement",
  inputs: {
    conditioning_from: {
      name: "conditionnement_de"
    },
    conditioning_to: {
      name: "conditionnement_à"
    },
    conditioning_to_strength: {
      name: "force_conditionnement_à"
    }
  }
};
const ConditioningCombine$4 = {
  display_name: "Conditionnement (Combiner)",
  inputs: {
    conditioning_1: {
      name: "conditionnement_1"
    },
    conditioning_2: {
      name: "conditionnement_2"
    }
  }
};
const ConditioningConcat$4 = {
  display_name: "Conditionnement (Concat)",
  inputs: {
    conditioning_from: {
      name: "conditionnement_de"
    },
    conditioning_to: {
      name: "conditionnement_vers"
    }
  }
};
const ConditioningSetArea$4 = {
  display_name: "Conditionnement (Définir Zone)",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    height: {
      name: "hauteur"
    },
    strength: {
      name: "force"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentage$4 = {
  display_name: "Conditionnement (Définir Zone avec Pourcentage)",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    height: {
      name: "hauteur"
    },
    strength: {
      name: "force"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentageVideo$4 = {
  display_name: "Pourcentage de la zone de conditionnement vidéo",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    height: {
      name: "hauteur"
    },
    strength: {
      name: "force"
    },
    temporal: {
      name: "temporel"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    }
  }
};
const ConditioningSetAreaStrength$4 = {
  display_name: "ConditionnementDéfinirForceZone",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    strength: {
      name: "force"
    }
  }
};
const ConditioningSetDefaultCombine$4 = {
  display_name: "Cond Définir Combinaison par Défaut",
  inputs: {
    cond: {
      name: "cond"
    },
    cond_DEFAULT: {
      name: "cond_DEFAULT"
    },
    hooks: {
      name: "hooks"
    }
  }
};
const ConditioningSetMask$4 = {
  display_name: "Conditionnement (Définir Masque)",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    mask: {
      name: "masque"
    },
    set_cond_area: {
      name: "définir_zone_cond"
    },
    strength: {
      name: "force"
    }
  }
};
const ConditioningSetProperties$4 = {
  display_name: "Cond Définir Propriétés",
  inputs: {
    cond_NEW: {
      name: "cond_NOUVEAU"
    },
    hooks: {
      name: "hooks"
    },
    mask: {
      name: "masque"
    },
    set_cond_area: {
      name: "définir_zone_cond"
    },
    strength: {
      name: "force"
    },
    timesteps: {
      name: "pas_de_temps"
    }
  }
};
const ConditioningSetPropertiesAndCombine$4 = {
  display_name: "Cond Définir Propriétés Combinaison",
  inputs: {
    cond: {
      name: "cond"
    },
    cond_NEW: {
      name: "cond_NOUVEAU"
    },
    hooks: {
      name: "hooks"
    },
    mask: {
      name: "masque"
    },
    set_cond_area: {
      name: "définir_zone_cond"
    },
    strength: {
      name: "force"
    },
    timesteps: {
      name: "pas_de_temps"
    }
  }
};
const ConditioningSetTimestepRange$4 = {
  display_name: "ConditionnementDéfinirPlagePasDeTemps",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    end: {
      name: "fin"
    },
    start: {
      name: "début"
    }
  }
};
const ConditioningStableAudio$4 = {
  display_name: "ConditionnementStableAudio",
  inputs: {
    negative: {
      name: "négative"
    },
    positive: {
      name: "positive"
    },
    seconds_start: {
      name: "secondes_début"
    },
    seconds_total: {
      name: "secondes_total"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négative"
    }
  }
};
const ConditioningTimestepsRange$4 = {
  display_name: "Plage de pas de temps",
  inputs: {
    end_percent: {
      name: "end_percent"
    },
    start_percent: {
      name: "start_percent"
    }
  },
  outputs: {
    "1": {
      name: "AVANT_PLAGE"
    },
    "2": {
      name: "APRÈS_PLAGE"
    }
  }
};
const ConditioningZeroOut$4 = {
  display_name: "ConditioningZeroOut",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const ControlNetApply$4 = {
  display_name: "Appliquer ControlNet (ANCIEN)",
  inputs: {
    conditioning: {
      name: "conditioning"
    },
    control_net: {
      name: "control_net"
    },
    image: {
      name: "image"
    },
    strength: {
      name: "strength"
    }
  }
};
const ControlNetApplyAdvanced$4 = {
  display_name: "Appliquer ControlNet",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "end_percent"
    },
    image: {
      name: "image"
    },
    negative: {
      name: "negative"
    },
    positive: {
      name: "positive"
    },
    start_percent: {
      name: "start_percent"
    },
    strength: {
      name: "strength"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetApplySD3$4 = {
  display_name: "Appliquer Controlnet avec VAE",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "end_percent"
    },
    image: {
      name: "image"
    },
    negative: {
      name: "negative"
    },
    positive: {
      name: "positive"
    },
    start_percent: {
      name: "start_percent"
    },
    strength: {
      name: "strength"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetInpaintingAliMamaApply$4 = {
  display_name: "ControlNetInpaintingAliMamaApply",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "end_percent"
    },
    image: {
      name: "image"
    },
    mask: {
      name: "mask"
    },
    negative: {
      name: "negative"
    },
    positive: {
      name: "positive"
    },
    start_percent: {
      name: "start_percent"
    },
    strength: {
      name: "strength"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const ControlNetLoader$4 = {
  display_name: "Charger le modèle ControlNet",
  inputs: {
    control_net_name: {
      name: "control_net_name"
    }
  }
};
const CosmosImageToVideoLatent$4 = {
  display_name: "CosmosImageVersVidéoLatent",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    end_image: {
      name: "image_de_fin"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    start_image: {
      name: "image_de_départ"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "largeur"
    }
  }
};
const CreateHookKeyframe$4 = {
  display_name: "Créer une image clé de crochet",
  inputs: {
    prev_hook_kf: {
      name: "prev_hook_kf"
    },
    start_percent: {
      name: "start_percent"
    },
    strength_mult: {
      name: "strength_mult"
    }
  },
  outputs: {
    "0": {
      name: "HOOK_KF"
    }
  }
};
const CreateHookKeyframesFromFloats$4 = {
  display_name: "Créer des images clés de crochet à partir de flottants",
  inputs: {
    end_percent: {
      name: "pourcentage_fin"
    },
    floats_strength: {
      name: "force_flottants"
    },
    prev_hook_kf: {
      name: "precedent_crochet_kf"
    },
    print_keyframes: {
      name: "imprimer_images_cles"
    },
    start_percent: {
      name: "pourcentage_debut"
    }
  },
  outputs: {
    "0": {
      name: "CROCHET_KF"
    }
  }
};
const CreateHookKeyframesInterpolated$4 = {
  display_name: "Créer des images clés de crochet interpolées.",
  inputs: {
    end_percent: {
      name: "pourcentage_fin"
    },
    interpolation: {
      name: "interpolation"
    },
    keyframes_count: {
      name: "compte_images_cles"
    },
    prev_hook_kf: {
      name: "precedent_crochet_kf"
    },
    print_keyframes: {
      name: "imprimer_images_cles"
    },
    start_percent: {
      name: "pourcentage_debut"
    },
    strength_end: {
      name: "force_fin"
    },
    strength_start: {
      name: "force_debut"
    }
  },
  outputs: {
    "0": {
      name: "CROCHET_KF"
    }
  }
};
const CreateHookLora$4 = {
  display_name: "Créer un crochet LoRA",
  inputs: {
    lora_name: {
      name: "nom_lora"
    },
    prev_hooks: {
      name: "crochets_precedents"
    },
    strength_clip: {
      name: "force_clip"
    },
    strength_model: {
      name: "force_modele"
    }
  }
};
const CreateHookLoraModelOnly$4 = {
  display_name: "Créer un crochet LoRA (MO)",
  inputs: {
    lora_name: {
      name: "nom_lora"
    },
    prev_hooks: {
      name: "crochets_precedents"
    },
    strength_model: {
      name: "force_modele"
    }
  }
};
const CreateHookModelAsLora$4 = {
  display_name: "Créer un modèle de crochet comme LoRA",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt"
    },
    prev_hooks: {
      name: "crochets_precedents"
    },
    strength_clip: {
      name: "force_clip"
    },
    strength_model: {
      name: "force_modele"
    }
  }
};
const CreateHookModelAsLoraModelOnly$4 = {
  display_name: "Créer un modèle de crochet comme LoRA (MO)",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt"
    },
    prev_hooks: {
      name: "crochets_precedents"
    },
    strength_model: {
      name: "force_modele"
    }
  }
};
const CropMask$4 = {
  display_name: "CropMask",
  inputs: {
    height: {
      name: "hauteur"
    },
    mask: {
      name: "masque"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const DiffControlNetLoader$4 = {
  display_name: "Charger le modèle ControlNet (diff)",
  inputs: {
    control_net_name: {
      name: "nom_control_net"
    },
    model: {
      name: "modèle"
    }
  }
};
const DifferentialDiffusion$4 = {
  display_name: "Diffusion différentielle",
  inputs: {
    model: {
      name: "modèle"
    }
  }
};
const DiffusersLoader$4 = {
  display_name: "Chargeur de diffuseurs",
  inputs: {
    model_path: {
      name: "chemin_modèle"
    }
  }
};
const DisableNoise$4 = {
  display_name: "DésactiverBruit"
};
const DualCFGGuider$4 = {
  display_name: "GuideurDualCFG",
  inputs: {
    cfg_cond2_negative: {
      name: "cfg_cond2_négatif"
    },
    cfg_conds: {
      name: "cfg_conds"
    },
    cond1: {
      name: "cond1"
    },
    cond2: {
      name: "cond2"
    },
    model: {
      name: "modèle"
    },
    negative: {
      name: "négatif"
    }
  }
};
const DualCLIPLoader$4 = {
  description: "[Recettes]\n\nsdxl: clip-l, clip-g\nsd3: clip-l, clip-g / clip-l, t5 / clip-g, t5\nflux: clip-l, t5",
  display_name: "ChargeurDualCLIP",
  inputs: {
    clip_name1: {
      name: "nom_clip1"
    },
    clip_name2: {
      name: "nom_clip2"
    },
    device: {
      name: "appareil"
    },
    type: {
      name: "type"
    }
  }
};
const EmptyCosmosLatentVideo$4 = {
  display_name: "VidéoLatenteCosmosVide",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    width: {
      name: "largeur"
    }
  }
};
const EmptyHunyuanLatentVideo$4 = {
  display_name: "EmptyHunyuanLatentVideo",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    width: {
      name: "largeur"
    }
  }
};
const EmptyImage$4 = {
  display_name: "ImageVide",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    color: {
      name: "couleur"
    },
    height: {
      name: "hauteur"
    },
    width: {
      name: "largeur"
    }
  }
};
const EmptyLTXVLatentVideo$4 = {
  display_name: "EmptyLTXVLatentVideo",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    width: {
      name: "largeur"
    }
  }
};
const EmptyLatentAudio$4 = {
  display_name: "AudioLatentVide",
  inputs: {
    batch_size: {
      name: "taille_du_lot",
      tooltip: "Le nombre d'images latentes dans le lot."
    },
    seconds: {
      name: "secondes"
    }
  }
};
const EmptyLatentHunyuan3Dv2$4 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    batch_size: {
      name: "taille_du_lot",
      tooltip: "Le nombre d'images latentes dans le lot."
    },
    resolution: {
      name: "résolution"
    }
  }
};
const EmptyLatentImage$4 = {
  description: "Créez un nouveau lot d'images latentes vides à débruiter via l'échantillonnage.",
  display_name: "Image Latente Vide",
  inputs: {
    batch_size: {
      name: "taille_du_lot",
      tooltip: "Le nombre d'images latentes dans le lot."
    },
    height: {
      name: "hauteur",
      tooltip: "La hauteur des images latentes en pixels."
    },
    width: {
      name: "largeur",
      tooltip: "La largeur des images latentes en pixels."
    }
  },
  outputs: {
    "0": {
      tooltip: "Le lot d'images latentes vides."
    }
  }
};
const EmptyMochiLatentVideo$4 = {
  display_name: "EmptyMochiLatentVideo",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    width: {
      name: "largeur"
    }
  }
};
const EmptySD3LatentImage$4 = {
  display_name: "EmptySD3LatentImage",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    height: {
      name: "hauteur"
    },
    width: {
      name: "largeur"
    }
  }
};
const ExponentialScheduler$4 = {
  display_name: "PlanificateurExponentiel",
  inputs: {
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "étapes"
    }
  }
};
const FeatherMask$4 = {
  display_name: "MasquePlume",
  inputs: {
    bottom: {
      name: "bas"
    },
    left: {
      name: "gauche"
    },
    mask: {
      name: "masque"
    },
    right: {
      name: "droite"
    },
    top: {
      name: "haut"
    }
  }
};
const FlipSigmas$4 = {
  display_name: "InverserSigmas",
  inputs: {
    sigmas: {
      name: "sigmas"
    }
  }
};
const FluxDisableGuidance$4 = {
  description: "Ce nœud désactive complètement l'intégration de guidage sur les modèles Flux et similaires à Flux",
  display_name: "FluxDisableGuidance",
  inputs: {
    conditioning: {
      name: "conditionnement"
    }
  }
};
const FluxGuidance$4 = {
  display_name: "GuidageFlux",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    guidance: {
      name: "guidage"
    }
  }
};
const FreeU$4 = {
  display_name: "FreeU",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "modèle"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2$4 = {
  display_name: "FreeU_V2",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "modèle"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler$4 = {
  display_name: "GITSScheduler",
  inputs: {
    coeff: {
      name: "coeff"
    },
    denoise: {
      name: "débruitage"
    },
    steps: {
      name: "étapes"
    }
  }
};
const GLIGENLoader$4 = {
  display_name: "GLIGENLoader",
  inputs: {
    gligen_name: {
      name: "nom_gligen"
    }
  }
};
const GLIGENTextBoxApply$4 = {
  display_name: "GLIGENTextBoxApply",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning_to: {
      name: "conditionnement_à"
    },
    gligen_textbox_model: {
      name: "modèle_boîte_texte_gligen"
    },
    height: {
      name: "hauteur"
    },
    text: {
      name: "texte"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask$4 = {
  display_name: "GrowMask",
  inputs: {
    expand: {
      name: "agrandir"
    },
    mask: {
      name: "masque"
    },
    tapered_corners: {
      name: "coins_évasés"
    }
  }
};
const Hunyuan3Dv2Conditioning$4 = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "sortie_vision_clip"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView$4 = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    back: {
      name: "arrière"
    },
    front: {
      name: "avant"
    },
    left: {
      name: "gauche"
    },
    right: {
      name: "droite"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    }
  }
};
const HunyuanImageToVideo$4 = {
  display_name: "HunyuanImageToVideo",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    guidance_type: {
      name: "type_de_guidage"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    positive: {
      name: "positive"
    },
    start_image: {
      name: "image_de_départ"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "latent"
    }
  }
};
const HyperTile$4 = {
  display_name: "HyperTile",
  inputs: {
    max_depth: {
      name: "profondeur_max"
    },
    model: {
      name: "modèle"
    },
    scale_depth: {
      name: "échelle_profondeur"
    },
    swap_size: {
      name: "taille_échange"
    },
    tile_size: {
      name: "taille_tuile"
    }
  }
};
const HypernetworkLoader$4 = {
  display_name: "HypernetworkLoader",
  inputs: {
    hypernetwork_name: {
      name: "nom_hypernetwork"
    },
    model: {
      name: "modèle"
    },
    strength: {
      name: "force"
    }
  }
};
const ImageBatch$4 = {
  display_name: "Images en lot",
  inputs: {
    image1: {
      name: "image1"
    },
    image2: {
      name: "image2"
    }
  }
};
const ImageBlend$4 = {
  display_name: "Mélange d'images",
  inputs: {
    blend_factor: {
      name: "facteur_mélange"
    },
    blend_mode: {
      name: "mode_mélange"
    },
    image1: {
      name: "image1"
    },
    image2: {
      name: "image2"
    }
  }
};
const ImageBlur$4 = {
  display_name: "Flou d'image",
  inputs: {
    blur_radius: {
      name: "rayon_flou"
    },
    image: {
      name: "image"
    },
    sigma: {
      name: "sigma"
    }
  }
};
const ImageColorToMask$4 = {
  display_name: "ImageCouleurEnMasque",
  inputs: {
    color: {
      name: "couleur"
    },
    image: {
      name: "image"
    }
  }
};
const ImageCompositeMasked$4 = {
  display_name: "ImageCompositeMasked",
  inputs: {
    destination: {
      name: "destination"
    },
    mask: {
      name: "masque"
    },
    resize_source: {
      name: "redimensionner_source"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageCrop$4 = {
  display_name: "Rogner l'image",
  inputs: {
    height: {
      name: "hauteur"
    },
    image: {
      name: "image"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch$4 = {
  display_name: "ImageDeBatch",
  inputs: {
    batch_index: {
      name: "index_de_lot"
    },
    image: {
      name: "image"
    },
    length: {
      name: "longueur"
    }
  }
};
const ImageInvert$4 = {
  display_name: "Inverser l'image",
  inputs: {
    image: {
      name: "image"
    }
  }
};
const ImageOnlyCheckpointLoader$4 = {
  display_name: "Chargeur de points de contrôle uniquement pour image (modèle img2vid)",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt"
    }
  }
};
const ImageOnlyCheckpointSave$4 = {
  display_name: "ImageOnlyCheckpointSave",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    filename_prefix: {
      name: "préfixe_de_nom_de_fichier"
    },
    model: {
      name: "modèle"
    },
    vae: {
      name: "vae"
    }
  }
};
const ImagePadForOutpaint$4 = {
  display_name: "Rembourrage d'image pour la peinture extérieure",
  inputs: {
    bottom: {
      name: "bas"
    },
    feathering: {
      name: "adoucissement"
    },
    image: {
      name: "image"
    },
    left: {
      name: "gauche"
    },
    right: {
      name: "droite"
    },
    top: {
      name: "haut"
    }
  }
};
const ImageQuantize$4 = {
  display_name: "Quantification d'image",
  inputs: {
    colors: {
      name: "couleurs"
    },
    dither: {
      name: "dither"
    },
    image: {
      name: "image"
    }
  }
};
const ImageScale$4 = {
  display_name: "Agrandir l'image",
  inputs: {
    crop: {
      name: "crop"
    },
    height: {
      name: "hauteur"
    },
    image: {
      name: "image"
    },
    upscale_method: {
      name: "méthode_d'agrandissement"
    },
    width: {
      name: "largeur"
    }
  }
};
const ImageScaleBy$4 = {
  display_name: "Agrandir l'image par",
  inputs: {
    image: {
      name: "image"
    },
    scale_by: {
      name: "agrandir_par"
    },
    upscale_method: {
      name: "méthode_d'agrandissement"
    }
  }
};
const ImageScaleToTotalPixels$4 = {
  display_name: "Redimensionner l'image en fonction du nombre total de pixels",
  inputs: {
    image: {
      name: "image"
    },
    megapixels: {
      name: "mégapixels"
    },
    upscale_method: {
      name: "méthode_d'agrandissement"
    }
  }
};
const ImageSharpen$4 = {
  display_name: "Affiner l'image",
  inputs: {
    alpha: {
      name: "alpha"
    },
    image: {
      name: "image"
    },
    sharpen_radius: {
      name: "rayon_d'affûtage"
    },
    sigma: {
      name: "sigma"
    }
  }
};
const ImageToMask$4 = {
  display_name: "Convertir Image en Masque",
  inputs: {
    channel: {
      name: "canal"
    },
    image: {
      name: "image"
    }
  }
};
const ImageUpscaleWithModel$4 = {
  display_name: "Agrandir l'Image (à l'aide du Modèle)",
  inputs: {
    image: {
      name: "image"
    },
    upscale_model: {
      name: "modèle_d'agrandissement"
    }
  }
};
const InpaintModelConditioning$4 = {
  display_name: "InpaintModelConditioning",
  inputs: {
    mask: {
      name: "masque"
    },
    negative: {
      name: "négatif"
    },
    noise_mask: {
      name: "masque_de_bruit",
      tooltip: "Ajoutez un masque de bruit au latent pour que l'échantillonnage ne se produise que dans le masque. Peut améliorer les résultats ou complètement les détruire en fonction du modèle."
    },
    pixels: {
      name: "pixels"
    },
    positive: {
      name: "positive"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const InstructPixToPixConditioning$4 = {
  display_name: "InstructPixToPixConditioning",
  inputs: {
    negative: {
      name: "négatif"
    },
    pixels: {
      name: "pixels"
    },
    positive: {
      name: "positive"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const InvertMask$4 = {
  display_name: "InverserMasque",
  inputs: {
    mask: {
      name: "masque"
    }
  }
};
const JoinImageWithAlpha$4 = {
  display_name: "Joindre Image avec Alpha",
  inputs: {
    alpha: {
      name: "alpha"
    },
    image: {
      name: "image"
    }
  }
};
const KSampler$4 = {
  description: "Utilise le modèle fourni, le conditionnement positif et négatif pour débruiter l'image latente.",
  display_name: "KSampler",
  inputs: {
    cfg: {
      name: "cfg",
      tooltip: "L'échelle de guidage sans classificateur équilibre la créativité et l'adhérence à l'invite. Des valeurs plus élevées donnent des images correspondant plus étroitement à l'invite, cependant des valeurs trop élevées auront un impact négatif sur la qualité."
    },
    control_after_generate: {
      name: "contrôle après génération"
    },
    denoise: {
      name: "denoise",
      tooltip: "La quantité de débruitage appliquée, des valeurs plus faibles maintiendront la structure de l'image initiale permettant un échantillonnage d'image à image."
    },
    latent_image: {
      name: "latent_image",
      tooltip: "L'image latente à débruiter."
    },
    model: {
      name: "model",
      tooltip: "Le modèle utilisé pour débruiter l'entrée latente."
    },
    negative: {
      name: "negative",
      tooltip: "Le conditionnement décrivant les attributs que vous voulez exclure de l'image."
    },
    positive: {
      name: "positive",
      tooltip: "Le conditionnement décrivant les attributs que vous voulez inclure dans l'image."
    },
    sampler_name: {
      name: "sampler_name",
      tooltip: "L'algorithme utilisé lors de l'échantillonnage, cela peut affecter la qualité, la vitesse et le style de la sortie générée."
    },
    scheduler: {
      name: "scheduler",
      tooltip: "Le planificateur contrôle comment le bruit est progressivement éliminé pour former l'image."
    },
    seed: {
      name: "seed",
      tooltip: "La graine aléatoire utilisée pour créer le bruit."
    },
    steps: {
      name: "steps",
      tooltip: "Le nombre d'étapes utilisées dans le processus de débruitage."
    }
  },
  outputs: {
    "0": {
      tooltip: "Le latent débruité."
    }
  }
};
const KSamplerAdvanced$4 = {
  display_name: "KSampler (Avancé)",
  inputs: {
    add_noise: {
      name: "add_noise"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "contrôle après génération"
    },
    end_at_step: {
      name: "end_at_step"
    },
    latent_image: {
      name: "latent_image"
    },
    model: {
      name: "model"
    },
    negative: {
      name: "negative"
    },
    noise_seed: {
      name: "noise_seed"
    },
    positive: {
      name: "positive"
    },
    return_with_leftover_noise: {
      name: "return_with_leftover_noise"
    },
    sampler_name: {
      name: "sampler_name"
    },
    scheduler: {
      name: "scheduler"
    },
    start_at_step: {
      name: "start_at_step"
    },
    steps: {
      name: "steps"
    }
  }
};
const KSamplerSelect$4 = {
  display_name: "KSamplerSelect",
  inputs: {
    sampler_name: {
      name: "sampler_name"
    }
  }
};
const KarrasScheduler$4 = {
  display_name: "PlanificateurKarras",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "étapes"
    }
  }
};
const LTXVAddGuide$4 = {
  display_name: "LTXVAddGuide",
  inputs: {
    frame_idx: {
      name: "indice_de_l'image",
      tooltip: "Indice de l'image pour commencer le conditionnement. Pour les images uniques ou les vidéos de 1 à 8 images, toute valeur d'indice de l'image est acceptable. Pour les vidéos de 9 images ou plus, l'indice de l'image doit être divisible par 8, sinon il sera arrondi à la baisse au multiple de 8 le plus proche. Les valeurs négatives sont comptées à partir de la fin de la vidéo."
    },
    image: {
      name: "image",
      tooltip: "Image ou vidéo pour conditionner la vidéo latente. Doit être 8*n + 1 images. Si la vidéo n'est pas 8*n + 1 images, elle sera coupée au plus proche 8*n + 1 images."
    },
    latent: {
      name: "latent"
    },
    negative: {
      name: "négatif"
    },
    positive: {
      name: "positive"
    },
    strength: {
      name: "force"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVConditioning$4 = {
  display_name: "LTXVConditioning",
  inputs: {
    frame_rate: {
      name: "frame_rate"
    },
    negative: {
      name: "negative"
    },
    positive: {
      name: "positive"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const LTXVCropGuides$4 = {
  display_name: "LTXVCropGuides",
  inputs: {
    latent: {
      name: "latent"
    },
    negative: {
      name: "négatif"
    },
    positive: {
      name: "positive"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVImgToVideo$4 = {
  display_name: "LTXVImgToVideo",
  inputs: {
    batch_size: {
      name: "batch_size"
    },
    height: {
      name: "height"
    },
    image: {
      name: "image"
    },
    length: {
      name: "length"
    },
    negative: {
      name: "negative"
    },
    positive: {
      name: "positive"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "width"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    },
    "2": {
      name: "latent"
    }
  }
};
const LTXVPreprocess$4 = {
  display_name: "LTXVPreprocess",
  inputs: {
    image: {
      name: "image"
    },
    img_compression: {
      name: "compression_d'image",
      tooltip: "Quantité de compression à appliquer sur l'image."
    }
  },
  outputs: {
    "0": {
      name: "image_de_sortie"
    }
  }
};
const LTXVScheduler$4 = {
  display_name: "LTXVScheduler",
  inputs: {
    base_shift: {
      name: "décalage_base"
    },
    latent: {
      name: "latent"
    },
    max_shift: {
      name: "décalage_max"
    },
    steps: {
      name: "étapes"
    },
    stretch: {
      name: "étirement",
      tooltip: "Étirez les sigmas pour être dans la plage [terminal, 1]."
    },
    terminal: {
      name: "terminal",
      tooltip: "La valeur terminale des sigmas après étirement."
    }
  }
};
const LaplaceScheduler$4 = {
  display_name: "LaplaceScheduler",
  inputs: {
    beta: {
      name: "beta"
    },
    mu: {
      name: "mu"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "steps"
    }
  }
};
const LatentAdd$4 = {
  display_name: "LatentAdd",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentApplyOperation$4 = {
  display_name: "LatentApplyOperation",
  inputs: {
    operation: {
      name: "operation"
    },
    samples: {
      name: "samples"
    }
  }
};
const LatentApplyOperationCFG$4 = {
  display_name: "LatentApplyOperationCFG",
  inputs: {
    model: {
      name: "model"
    },
    operation: {
      name: "operation"
    }
  }
};
const LatentBatch$4 = {
  display_name: "LatentBatch",
  inputs: {
    samples1: {
      name: "échantillons1"
    },
    samples2: {
      name: "échantillons2"
    }
  }
};
const LatentBatchSeedBehavior$4 = {
  display_name: "Comportement de la Graine LatentBatch",
  inputs: {
    samples: {
      name: "échantillons"
    },
    seed_behavior: {
      name: "comportement_de_graine"
    }
  }
};
const LatentBlend$4 = {
  display_name: "Mélange Latent",
  inputs: {
    blend_factor: {
      name: "facteur_de_mélange"
    },
    samples1: {
      name: "échantillons1"
    },
    samples2: {
      name: "échantillons2"
    }
  }
};
const LatentComposite$4 = {
  display_name: "Composite Latent",
  inputs: {
    feather: {
      name: "plume"
    },
    samples_from: {
      name: "échantillons_de"
    },
    samples_to: {
      name: "échantillons_vers"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCompositeMasked$4 = {
  display_name: "Composite Latent Masqué",
  inputs: {
    destination: {
      name: "destination"
    },
    mask: {
      name: "masque"
    },
    resize_source: {
      name: "redimensionner_source"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCrop$4 = {
  display_name: "Couper Latent",
  inputs: {
    height: {
      name: "hauteur"
    },
    samples: {
      name: "échantillons"
    },
    width: {
      name: "largeur"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip$4 = {
  display_name: "Retourner Latent",
  inputs: {
    flip_method: {
      name: "méthode_de_retournement"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const LatentFromBatch$4 = {
  display_name: "Latent De Batch",
  inputs: {
    batch_index: {
      name: "index_de_batch"
    },
    length: {
      name: "longueur"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const LatentInterpolate$4 = {
  display_name: "Interpoler Latent",
  inputs: {
    ratio: {
      name: "ratio"
    },
    samples1: {
      name: "échantillons1"
    },
    samples2: {
      name: "échantillons2"
    }
  }
};
const LatentMultiply$4 = {
  display_name: "Multiplier Latent",
  inputs: {
    multiplier: {
      name: "multiplicateur"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const LatentOperationSharpen$4 = {
  display_name: "Opération d'Affûtage Latent",
  inputs: {
    alpha: {
      name: "alpha"
    },
    sharpen_radius: {
      name: "rayon_d'affûtage"
    },
    sigma: {
      name: "sigma"
    }
  }
};
const LatentOperationTonemapReinhard$4 = {
  display_name: "Opération de Mappage de Tons Reinhard Latent",
  inputs: {
    multiplier: {
      name: "multiplicateur"
    }
  }
};
const LatentRotate$4 = {
  display_name: "Tourner Latent",
  inputs: {
    rotation: {
      name: "rotation"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const LatentSubtract$4 = {
  display_name: "Soustraction Latente",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentUpscale$4 = {
  display_name: "Mise à l'échelle Latente",
  inputs: {
    crop: {
      name: "recadrage"
    },
    height: {
      name: "hauteur"
    },
    samples: {
      name: "samples"
    },
    upscale_method: {
      name: "méthode_de_mise_à_l'échelle"
    },
    width: {
      name: "largeur"
    }
  }
};
const LatentUpscaleBy$4 = {
  display_name: "Mise à l'échelle Latente Par",
  inputs: {
    samples: {
      name: "samples"
    },
    scale_by: {
      name: "mise_à_l'échelle_par"
    },
    upscale_method: {
      name: "méthode_de_mise_à_l'échelle"
    }
  }
};
const Load3D$4 = {
  display_name: "Charger 3D",
  inputs: {
    clear: {},
    height: {
      name: "hauteur"
    },
    image: {
      name: "image"
    },
    model_file: {
      name: "fichier_modèle"
    },
    "upload 3d model": {},
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "image"
    },
    "1": {
      name: "masque"
    },
    "2": {
      name: "chemin_maillage"
    }
  }
};
const Load3DAnimation$4 = {
  display_name: "Charger 3D - Animation",
  inputs: {
    clear: {},
    height: {
      name: "hauteur"
    },
    image: {
      name: "image"
    },
    model_file: {
      name: "fichier_modèle"
    },
    "upload 3d model": {},
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "image"
    },
    "1": {
      name: "masque"
    },
    "2": {
      name: "chemin_maillage"
    }
  }
};
const LoadAudio$4 = {
  display_name: "ChargerAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    audioUI: {
      name: "audioUI"
    },
    upload: {
      name: "choisissez le fichier à télécharger"
    }
  }
};
const LoadImage$4 = {
  display_name: "Charger Image",
  inputs: {
    image: {
      name: "image"
    },
    upload: {
      name: "choisissez le fichier à télécharger"
    }
  }
};
const LoadImageMask$4 = {
  display_name: "Charger Image (comme Masque)",
  inputs: {
    channel: {
      name: "canal"
    },
    image: {
      name: "image"
    },
    upload: {
      name: "choisissez le fichier à télécharger"
    }
  }
};
const LoadImageOutput$4 = {
  description: "Chargez une image à partir du dossier de sortie. Lorsque le bouton de rafraîchissement est cliqué, le nœud mettra à jour la liste des images et sélectionnera automatiquement la première image, permettant une itération facile.",
  display_name: "Charger l'image (à partir des sorties)",
  inputs: {
    image: {
      name: "image"
    },
    refresh: {},
    upload: {
      name: "choisissez le fichier à télécharger"
    }
  }
};
const LoadLatent$4 = {
  display_name: "ChargerLatent",
  inputs: {
    latent: {
      name: "latent"
    }
  }
};
const LoraLoader$4 = {
  description: "Les LoRAs sont utilisés pour modifier les modèles de diffusion et CLIP, modifiant la manière dont les latents sont débruités comme l'application de styles. Plusieurs nœuds LoRA peuvent être liés ensemble.",
  display_name: "Charger LoRA",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "Le modèle CLIP auquel le LoRA sera appliqué."
    },
    lora_name: {
      name: "lora_name",
      tooltip: "Le nom du LoRA."
    },
    model: {
      name: "model",
      tooltip: "Le modèle de diffusion auquel le LoRA sera appliqué."
    },
    strength_clip: {
      name: "strength_clip",
      tooltip: "À quel point modifier le modèle CLIP. Cette valeur peut être négative."
    },
    strength_model: {
      name: "strength_model",
      tooltip: "À quel point modifier le modèle de diffusion. Cette valeur peut être négative."
    }
  },
  outputs: {
    "0": {
      tooltip: "Le modèle de diffusion modifié."
    },
    "1": {
      tooltip: "Le modèle CLIP modifié."
    }
  }
};
const LoraLoaderModelOnly$4 = {
  description: "Les LoRAs sont utilisés pour modifier les modèles de diffusion et CLIP, modifiant la manière dont les latents sont débruités comme l'application de styles. Plusieurs nœuds LoRA peuvent être liés ensemble.",
  display_name: "LoraLoaderModelOnly",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    model: {
      name: "model"
    },
    strength_model: {
      name: "strength_model"
    }
  },
  outputs: {
    "0": {
      tooltip: "Le modèle de diffusion modifié."
    }
  }
};
const LoraSave$4 = {
  display_name: "Extraire et Sauvegarder Lora",
  inputs: {
    bias_diff: {
      name: "bias_diff"
    },
    filename_prefix: {
      name: "filename_prefix"
    },
    lora_type: {
      name: "lora_type"
    },
    model_diff: {
      name: "model_diff",
      tooltip: "La sortie ModelSubtract à convertir en lora."
    },
    rank: {
      name: "rank"
    },
    text_encoder_diff: {
      name: "text_encoder_diff",
      tooltip: "La sortie CLIPSubtract à convertir en lora."
    }
  }
};
const Mahiro$4 = {
  description: "Modifiez le guidage pour qu'il se concentre davantage sur la 'direction' de l'invite positive plutôt que sur la différence avec l'invite négative.",
  display_name: "Mahiro est si mignonne qu'elle mérite une meilleure fonction de guidage!! (。・ω・。)",
  inputs: {
    model: {
      name: "modèle"
    }
  },
  outputs: {
    "0": {
      name: "modèle_modifié"
    }
  }
};
const MaskComposite$4 = {
  display_name: "MaskComposite",
  inputs: {
    destination: {
      name: "destination"
    },
    operation: {
      name: "opération"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const MaskToImage$4 = {
  display_name: "Convertir le masque en image",
  inputs: {
    mask: {
      name: "masque"
    }
  }
};
const ModelComputeDtype$4 = {
  display_name: "ModelComputeDtype",
  inputs: {
    dtype: {
      name: "dtype"
    },
    model: {
      name: "modèle"
    }
  }
};
const ModelMergeAdd$4 = {
  display_name: "ModelMergeAdd",
  inputs: {
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    }
  }
};
const ModelMergeAuraflow$4 = {
  display_name: "ModelMergeAuraflow",
  inputs: {
    cond_seq_linear_: {
      name: "cond_seq_linear."
    },
    double_layers_0_: {
      name: "double_layers.0."
    },
    double_layers_1_: {
      name: "double_layers.1."
    },
    double_layers_2_: {
      name: "double_layers.2."
    },
    double_layers_3_: {
      name: "double_layers.3."
    },
    final_linear_: {
      name: "final_linear."
    },
    init_x_linear_: {
      name: "init_x_linear."
    },
    modF_: {
      name: "modF."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    positional_encoding: {
      name: "codage_positionnel"
    },
    register_tokens: {
      name: "enregistrer_tokens"
    },
    single_layers_0_: {
      name: "single_layers.0."
    },
    single_layers_10_: {
      name: "single_layers.10."
    },
    single_layers_11_: {
      name: "single_layers.11."
    },
    single_layers_12_: {
      name: "single_layers.12."
    },
    single_layers_13_: {
      name: "single_layers.13."
    },
    single_layers_14_: {
      name: "single_layers.14."
    },
    single_layers_15_: {
      name: "single_layers.15."
    },
    single_layers_16_: {
      name: "single_layers.16."
    },
    single_layers_17_: {
      name: "single_layers.17."
    },
    single_layers_18_: {
      name: "single_layers.18."
    },
    single_layers_19_: {
      name: "single_layers.19."
    },
    single_layers_1_: {
      name: "single_layers.1."
    },
    single_layers_20_: {
      name: "single_layers.20."
    },
    single_layers_21_: {
      name: "single_layers.21."
    },
    single_layers_22_: {
      name: "single_layers.22."
    },
    single_layers_23_: {
      name: "single_layers.23."
    },
    single_layers_24_: {
      name: "single_layers.24."
    },
    single_layers_25_: {
      name: "single_layers.25."
    },
    single_layers_26_: {
      name: "single_layers.26."
    },
    single_layers_27_: {
      name: "single_layers.27."
    },
    single_layers_28_: {
      name: "single_layers.28."
    },
    single_layers_29_: {
      name: "single_layers.29."
    },
    single_layers_2_: {
      name: "single_layers.2."
    },
    single_layers_30_: {
      name: "single_layers.30."
    },
    single_layers_31_: {
      name: "single_layers.31."
    },
    single_layers_3_: {
      name: "single_layers.3."
    },
    single_layers_4_: {
      name: "single_layers.4."
    },
    single_layers_5_: {
      name: "single_layers.5."
    },
    single_layers_6_: {
      name: "single_layers.6."
    },
    single_layers_7_: {
      name: "single_layers.7."
    },
    single_layers_8_: {
      name: "single_layers.8."
    },
    single_layers_9_: {
      name: "single_layers.9."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeBlocks$4 = {
  display_name: "ModelMergeBlocks",
  inputs: {
    input: {
      name: "entrée"
    },
    middle: {
      name: "milieu"
    },
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    out: {
      name: "sortie"
    }
  }
};
const ModelMergeCosmos14B$4 = {
  display_name: "ModelMergeCosmos14B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "couche_finale."
    },
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeCosmos7B$4 = {
  display_name: "ModelMergeCosmos7B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeFlux1$4 = {
  display_name: "ModelMergeFlux1",
  inputs: {
    double_blocks_0_: {
      name: "double_blocks.0."
    },
    double_blocks_10_: {
      name: "double_blocks.10."
    },
    double_blocks_11_: {
      name: "double_blocks.11."
    },
    double_blocks_12_: {
      name: "double_blocks.12."
    },
    double_blocks_13_: {
      name: "double_blocks.13."
    },
    double_blocks_14_: {
      name: "double_blocks.14."
    },
    double_blocks_15_: {
      name: "double_blocks.15."
    },
    double_blocks_16_: {
      name: "double_blocks.16."
    },
    double_blocks_17_: {
      name: "double_blocks.17."
    },
    double_blocks_18_: {
      name: "double_blocks.18."
    },
    double_blocks_1_: {
      name: "double_blocks.1."
    },
    double_blocks_2_: {
      name: "double_blocks.2."
    },
    double_blocks_3_: {
      name: "double_blocks.3."
    },
    double_blocks_4_: {
      name: "double_blocks.4."
    },
    double_blocks_5_: {
      name: "double_blocks.5."
    },
    double_blocks_6_: {
      name: "double_blocks.6."
    },
    double_blocks_7_: {
      name: "double_blocks.7."
    },
    double_blocks_8_: {
      name: "double_blocks.8."
    },
    double_blocks_9_: {
      name: "double_blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    guidance_in: {
      name: "guidance_in"
    },
    img_in_: {
      name: "img_in."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    single_blocks_0_: {
      name: "single_blocks.0."
    },
    single_blocks_10_: {
      name: "single_blocks.10."
    },
    single_blocks_11_: {
      name: "single_blocks.11."
    },
    single_blocks_12_: {
      name: "single_blocks.12."
    },
    single_blocks_13_: {
      name: "single_blocks.13."
    },
    single_blocks_14_: {
      name: "single_blocks.14."
    },
    single_blocks_15_: {
      name: "single_blocks.15."
    },
    single_blocks_16_: {
      name: "single_blocks.16."
    },
    single_blocks_17_: {
      name: "single_blocks.17."
    },
    single_blocks_18_: {
      name: "single_blocks.18."
    },
    single_blocks_19_: {
      name: "single_blocks.19."
    },
    single_blocks_1_: {
      name: "single_blocks.1."
    },
    single_blocks_20_: {
      name: "single_blocks.20."
    },
    single_blocks_21_: {
      name: "single_blocks.21."
    },
    single_blocks_22_: {
      name: "single_blocks.22."
    },
    single_blocks_23_: {
      name: "single_blocks.23."
    },
    single_blocks_24_: {
      name: "single_blocks.24."
    },
    single_blocks_25_: {
      name: "single_blocks.25."
    },
    single_blocks_26_: {
      name: "single_blocks.26."
    },
    single_blocks_27_: {
      name: "single_blocks.27."
    },
    single_blocks_28_: {
      name: "single_blocks.28."
    },
    single_blocks_29_: {
      name: "single_blocks.29."
    },
    single_blocks_2_: {
      name: "single_blocks.2."
    },
    single_blocks_30_: {
      name: "single_blocks.30."
    },
    single_blocks_31_: {
      name: "single_blocks.31."
    },
    single_blocks_32_: {
      name: "single_blocks.32."
    },
    single_blocks_33_: {
      name: "single_blocks.33."
    },
    single_blocks_34_: {
      name: "single_blocks.34."
    },
    single_blocks_35_: {
      name: "single_blocks.35."
    },
    single_blocks_36_: {
      name: "single_blocks.36."
    },
    single_blocks_37_: {
      name: "single_blocks.37."
    },
    single_blocks_3_: {
      name: "single_blocks.3."
    },
    single_blocks_4_: {
      name: "single_blocks.4."
    },
    single_blocks_5_: {
      name: "single_blocks.5."
    },
    single_blocks_6_: {
      name: "single_blocks.6."
    },
    single_blocks_7_: {
      name: "single_blocks.7."
    },
    single_blocks_8_: {
      name: "single_blocks.8."
    },
    single_blocks_9_: {
      name: "single_blocks.9."
    },
    time_in_: {
      name: "time_in."
    },
    txt_in_: {
      name: "txt_in."
    },
    vector_in_: {
      name: "vector_in."
    }
  }
};
const ModelMergeLTXV$4 = {
  display_name: "ModelMergeLTXV",
  inputs: {
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "projection_de_légende."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    proj_out_: {
      name: "proj_out."
    },
    scale_shift_table: {
      name: "table_de_décalage_d'échelle"
    },
    transformer_blocks_0_: {
      name: "blocs_transformateurs.0."
    },
    transformer_blocks_10_: {
      name: "blocs_transformateurs.10."
    },
    transformer_blocks_11_: {
      name: "blocs_transformateurs.11."
    },
    transformer_blocks_12_: {
      name: "blocs_transformateurs.12."
    },
    transformer_blocks_13_: {
      name: "blocs_transformateurs.13."
    },
    transformer_blocks_14_: {
      name: "blocs_transformateurs.14."
    },
    transformer_blocks_15_: {
      name: "blocs_transformateurs.15."
    },
    transformer_blocks_16_: {
      name: "blocs_transformateurs.16."
    },
    transformer_blocks_17_: {
      name: "blocs_transformateurs.17."
    },
    transformer_blocks_18_: {
      name: "blocs_transformateurs.18."
    },
    transformer_blocks_19_: {
      name: "blocs_transformateurs.19."
    },
    transformer_blocks_1_: {
      name: "blocs_transformateurs.1."
    },
    transformer_blocks_20_: {
      name: "blocs_transformateurs.20."
    },
    transformer_blocks_21_: {
      name: "blocs_transformateurs.21."
    },
    transformer_blocks_22_: {
      name: "blocs_transformateurs.22."
    },
    transformer_blocks_23_: {
      name: "blocs_transformateurs.23."
    },
    transformer_blocks_24_: {
      name: "blocs_transformateurs.24."
    },
    transformer_blocks_25_: {
      name: "blocs_transformateurs.25."
    },
    transformer_blocks_26_: {
      name: "blocs_transformateurs.26."
    },
    transformer_blocks_27_: {
      name: "blocs_transformateurs.27."
    },
    transformer_blocks_2_: {
      name: "blocs_transformateurs.2."
    },
    transformer_blocks_3_: {
      name: "blocs_transformateurs.3."
    },
    transformer_blocks_4_: {
      name: "blocs_transformateurs.4."
    },
    transformer_blocks_5_: {
      name: "blocs_transformateurs.5."
    },
    transformer_blocks_6_: {
      name: "blocs_transformateurs.6."
    },
    transformer_blocks_7_: {
      name: "blocs_transformateurs.7."
    },
    transformer_blocks_8_: {
      name: "blocs_transformateurs.8."
    },
    transformer_blocks_9_: {
      name: "blocs_transformateurs.9."
    }
  }
};
const ModelMergeMochiPreview$4 = {
  display_name: "Aperçu de la Fusion de Modèles Mochi",
  inputs: {
    blocks_0_: {
      name: "blocs.0."
    },
    blocks_10_: {
      name: "blocs.10."
    },
    blocks_11_: {
      name: "blocs.11."
    },
    blocks_12_: {
      name: "blocs.12."
    },
    blocks_13_: {
      name: "blocs.13."
    },
    blocks_14_: {
      name: "blocs.14."
    },
    blocks_15_: {
      name: "blocs.15."
    },
    blocks_16_: {
      name: "blocs.16."
    },
    blocks_17_: {
      name: "blocs.17."
    },
    blocks_18_: {
      name: "blocs.18."
    },
    blocks_19_: {
      name: "blocs.19."
    },
    blocks_1_: {
      name: "blocs.1."
    },
    blocks_20_: {
      name: "blocs.20."
    },
    blocks_21_: {
      name: "blocs.21."
    },
    blocks_22_: {
      name: "blocs.22."
    },
    blocks_23_: {
      name: "blocs.23."
    },
    blocks_24_: {
      name: "blocs.24."
    },
    blocks_25_: {
      name: "blocs.25."
    },
    blocks_26_: {
      name: "blocs.26."
    },
    blocks_27_: {
      name: "blocs.27."
    },
    blocks_28_: {
      name: "blocs.28."
    },
    blocks_29_: {
      name: "blocs.29."
    },
    blocks_2_: {
      name: "blocs.2."
    },
    blocks_30_: {
      name: "blocs.30."
    },
    blocks_31_: {
      name: "blocs.31."
    },
    blocks_32_: {
      name: "blocs.32."
    },
    blocks_33_: {
      name: "blocs.33."
    },
    blocks_34_: {
      name: "blocs.34."
    },
    blocks_35_: {
      name: "blocs.35."
    },
    blocks_36_: {
      name: "blocs.36."
    },
    blocks_37_: {
      name: "blocs.37."
    },
    blocks_38_: {
      name: "blocs.38."
    },
    blocks_39_: {
      name: "blocs.39."
    },
    blocks_3_: {
      name: "blocs.3."
    },
    blocks_40_: {
      name: "blocs.40."
    },
    blocks_41_: {
      name: "blocs.41."
    },
    blocks_42_: {
      name: "blocs.42."
    },
    blocks_43_: {
      name: "blocs.43."
    },
    blocks_44_: {
      name: "blocs.44."
    },
    blocks_45_: {
      name: "blocs.45."
    },
    blocks_46_: {
      name: "blocs.46."
    },
    blocks_47_: {
      name: "blocs.47."
    },
    blocks_4_: {
      name: "blocs.4."
    },
    blocks_5_: {
      name: "blocs.5."
    },
    blocks_6_: {
      name: "blocs.6."
    },
    blocks_7_: {
      name: "blocs.7."
    },
    blocks_8_: {
      name: "blocs.8."
    },
    blocks_9_: {
      name: "blocs.9."
    },
    final_layer_: {
      name: "couche_finale."
    },
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    pos_frequencies_: {
      name: "pos_frequences."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeSD1$4 = {
  display_name: "ModelMergeSD1",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD2$4 = {
  display_name: "ModelMergeSD2",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD35_Large$4 = {
  display_name: "ModelMergeSD35_Large",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_24_: {
      name: "joint_blocks.24."
    },
    joint_blocks_25_: {
      name: "joint_blocks.25."
    },
    joint_blocks_26_: {
      name: "joint_blocks.26."
    },
    joint_blocks_27_: {
      name: "joint_blocks.27."
    },
    joint_blocks_28_: {
      name: "joint_blocks.28."
    },
    joint_blocks_29_: {
      name: "joint_blocks.29."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_30_: {
      name: "joint_blocks.30."
    },
    joint_blocks_31_: {
      name: "joint_blocks.31."
    },
    joint_blocks_32_: {
      name: "joint_blocks.32."
    },
    joint_blocks_33_: {
      name: "joint_blocks.33."
    },
    joint_blocks_34_: {
      name: "joint_blocks.34."
    },
    joint_blocks_35_: {
      name: "joint_blocks.35."
    },
    joint_blocks_36_: {
      name: "joint_blocks.36."
    },
    joint_blocks_37_: {
      name: "joint_blocks.37."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSD3_2B$4 = {
  display_name: "ModelMergeSD3_2B",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "couche_finale."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSDXL$4 = {
  display_name: "ModelMergeSDXL",
  inputs: {
    input_blocks_0: {
      name: "input_blocks.0"
    },
    input_blocks_1: {
      name: "input_blocks.1"
    },
    input_blocks_2: {
      name: "input_blocks.2"
    },
    input_blocks_3: {
      name: "input_blocks.3"
    },
    input_blocks_4: {
      name: "input_blocks.4"
    },
    input_blocks_5: {
      name: "input_blocks.5"
    },
    input_blocks_6: {
      name: "input_blocks.6"
    },
    input_blocks_7: {
      name: "input_blocks.7"
    },
    input_blocks_8: {
      name: "input_blocks.8"
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0: {
      name: "middle_block.0"
    },
    middle_block_1: {
      name: "middle_block.1"
    },
    middle_block_2: {
      name: "middle_block.2"
    },
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0: {
      name: "output_blocks.0"
    },
    output_blocks_1: {
      name: "output_blocks.1"
    },
    output_blocks_2: {
      name: "output_blocks.2"
    },
    output_blocks_3: {
      name: "output_blocks.3"
    },
    output_blocks_4: {
      name: "output_blocks.4"
    },
    output_blocks_5: {
      name: "output_blocks.5"
    },
    output_blocks_6: {
      name: "output_blocks.6"
    },
    output_blocks_7: {
      name: "output_blocks.7"
    },
    output_blocks_8: {
      name: "output_blocks.8"
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSimple$4 = {
  display_name: "ModelMergeSimple",
  inputs: {
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const ModelMergeSubtract$4 = {
  display_name: "ModelMergeSubtract",
  inputs: {
    model1: {
      name: "modèle1"
    },
    model2: {
      name: "modèle2"
    },
    multiplier: {
      name: "multiplicateur"
    }
  }
};
const ModelSamplingAuraFlow$4 = {
  display_name: "ModelSamplingAuraFlow",
  inputs: {
    model: {
      name: "modèle"
    },
    shift: {
      name: "décalage"
    }
  }
};
const ModelSamplingContinuousEDM$4 = {
  display_name: "ModelSamplingContinuousEDM",
  inputs: {
    model: {
      name: "modèle"
    },
    sampling: {
      name: "échantillonnage"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingContinuousV$4 = {
  display_name: "ModelSamplingContinuousV",
  inputs: {
    model: {
      name: "modèle"
    },
    sampling: {
      name: "échantillonnage"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingDiscrete$4 = {
  display_name: "ModèleÉchantillonnageDiscret",
  inputs: {
    model: {
      name: "modèle"
    },
    sampling: {
      name: "échantillonnage"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux$4 = {
  display_name: "ModèleÉchantillonnageFlux",
  inputs: {
    base_shift: {
      name: "décalage_base"
    },
    height: {
      name: "hauteur"
    },
    max_shift: {
      name: "décalage_max"
    },
    model: {
      name: "modèle"
    },
    width: {
      name: "largeur"
    }
  }
};
const ModelSamplingLTXV$4 = {
  display_name: "ModèleÉchantillonnageLTXV",
  inputs: {
    base_shift: {
      name: "décalage_base"
    },
    latent: {
      name: "latent"
    },
    max_shift: {
      name: "décalage_max"
    },
    model: {
      name: "modèle"
    }
  }
};
const ModelSamplingSD3$4 = {
  display_name: "ModèleÉchantillonnageSD3",
  inputs: {
    model: {
      name: "modèle"
    },
    shift: {
      name: "décalage"
    }
  }
};
const ModelSamplingStableCascade$4 = {
  display_name: "ModèleÉchantillonnageStableCascade",
  inputs: {
    model: {
      name: "modèle"
    },
    shift: {
      name: "décalage"
    }
  }
};
const ModelSave$4 = {
  display_name: "ModèleEnregistrer",
  inputs: {
    filename_prefix: {
      name: "préfixe_fichier"
    },
    model: {
      name: "modèle"
    }
  }
};
const Morphology$4 = {
  display_name: "ImageMorphologie",
  inputs: {
    image: {
      name: "image"
    },
    kernel_size: {
      name: "taille_noyau"
    },
    operation: {
      name: "opération"
    }
  }
};
const PairConditioningCombine$4 = {
  display_name: "Cond Pair Combiner",
  inputs: {
    negative_A: {
      name: "negative_A"
    },
    negative_B: {
      name: "negative_B"
    },
    positive_A: {
      name: "positive_A"
    },
    positive_B: {
      name: "positive_B"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetDefaultCombine$4 = {
  display_name: "Cond Pair Définir Combiner par Défaut",
  inputs: {
    hooks: {
      name: "hooks"
    },
    negative: {
      name: "negative"
    },
    negative_DEFAULT: {
      name: "negative_DEFAULT"
    },
    positive: {
      name: "positive"
    },
    positive_DEFAULT: {
      name: "positive_DEFAULT"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetProperties$4 = {
  display_name: "Cond Pair Définir Propriétés",
  inputs: {
    hooks: {
      name: "hooks"
    },
    mask: {
      name: "masque"
    },
    negative_NEW: {
      name: "negative_NEW"
    },
    positive_NEW: {
      name: "positive_NEW"
    },
    set_cond_area: {
      name: "définir_zone_cond"
    },
    strength: {
      name: "force"
    },
    timesteps: {
      name: "pas_de_temps"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PairConditioningSetPropertiesAndCombine$4 = {
  display_name: "Cond Pair Set Props Combine",
  inputs: {
    hooks: {
      name: "crochets"
    },
    mask: {
      name: "masque"
    },
    negative: {
      name: "negative"
    },
    negative_NEW: {
      name: "negative_NEW"
    },
    positive: {
      name: "positive"
    },
    positive_NEW: {
      name: "positive_NEW"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    strength: {
      name: "force"
    },
    timesteps: {
      name: "pas de temps"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "negative"
    }
  }
};
const PatchModelAddDownscale$4 = {
  display_name: "PatchModelAddDownscale (Kohya Deep Shrink)",
  inputs: {
    block_number: {
      name: "numéro de bloc"
    },
    downscale_after_skip: {
      name: "réduction après saut"
    },
    downscale_factor: {
      name: "facteur de réduction"
    },
    downscale_method: {
      name: "méthode de réduction"
    },
    end_percent: {
      name: "pourcentage de fin"
    },
    model: {
      name: "modèle"
    },
    start_percent: {
      name: "pourcentage de départ"
    },
    upscale_method: {
      name: "méthode d'agrandissement"
    }
  }
};
const PerpNeg$4 = {
  display_name: "Perp-Neg (OBSOLÈTE par PerpNegGuider)",
  inputs: {
    empty_conditioning: {
      name: "conditionnement vide"
    },
    model: {
      name: "modèle"
    },
    neg_scale: {
      name: "échelle nég"
    }
  }
};
const PerpNegGuider$4 = {
  display_name: "PerpNegGuider",
  inputs: {
    cfg: {
      name: "cfg"
    },
    empty_conditioning: {
      name: "conditionnement vide"
    },
    model: {
      name: "modèle"
    },
    neg_scale: {
      name: "échelle nég"
    },
    negative: {
      name: "négative"
    },
    positive: {
      name: "positive"
    }
  }
};
const PerturbedAttentionGuidance$4 = {
  display_name: "PerturbedAttentionGuidance",
  inputs: {
    model: {
      name: "modèle"
    },
    scale: {
      name: "échelle"
    }
  }
};
const PhotoMakerEncode$4 = {
  display_name: "PhotoMakerEncode",
  inputs: {
    clip: {
      name: "clip"
    },
    image: {
      name: "image"
    },
    photomaker: {
      name: "photomaker"
    },
    text: {
      name: "texte"
    }
  }
};
const PhotoMakerLoader$4 = {
  display_name: "PhotoMakerLoader",
  inputs: {
    photomaker_model_name: {
      name: "nom_du_modèle_photomaker"
    }
  }
};
const PolyexponentialScheduler$4 = {
  display_name: "PolyexponentialScheduler",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "étapes"
    }
  }
};
const PorterDuffImageComposite$4 = {
  display_name: "Composite d'image Porter-Duff",
  inputs: {
    destination: {
      name: "destination"
    },
    destination_alpha: {
      name: "alpha_destination"
    },
    mode: {
      name: "mode"
    },
    source: {
      name: "source"
    },
    source_alpha: {
      name: "alpha_source"
    }
  }
};
const Preview3D$4 = {
  display_name: "Aperçu 3D",
  inputs: {
    image: {
      name: "image"
    },
    model_file: {
      name: "fichier_modèle"
    }
  }
};
const Preview3DAnimation$4 = {
  display_name: "Aperçu 3D - Animation",
  inputs: {
    image: {
      name: "image"
    },
    model_file: {
      name: "fichier_modèle"
    }
  }
};
const PreviewAudio$4 = {
  display_name: "AperçuAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    audioUI: {
      name: "audioUI"
    }
  }
};
const PreviewImage$4 = {
  description: "Enregistre les images d'entrée dans votre répertoire de sortie ComfyUI.",
  display_name: "Aperçu Image",
  inputs: {
    images: {
      name: "images"
    }
  }
};
const RandomNoise$4 = {
  display_name: "BruitAléatoire",
  inputs: {
    control_after_generate: {
      name: "contrôle après génération"
    },
    noise_seed: {
      name: "graine_de_bruit"
    }
  }
};
const RebatchImages$4 = {
  display_name: "Rebatch Images",
  inputs: {
    batch_size: {
      name: "taille_de_lot"
    },
    images: {
      name: "images"
    }
  }
};
const RebatchLatents$4 = {
  display_name: "Rebatch Latents",
  inputs: {
    batch_size: {
      name: "taille_de_lot"
    },
    latents: {
      name: "latents"
    }
  }
};
const RenormCFG$4 = {
  display_name: "RenormCFG",
  inputs: {
    cfg_trunc: {
      name: "cfg_trunc"
    },
    model: {
      name: "modèle"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch$4 = {
  display_name: "RépéterLotImage",
  inputs: {
    amount: {
      name: "quantité"
    },
    image: {
      name: "image"
    }
  }
};
const RepeatLatentBatch$4 = {
  display_name: "Répéter Lot Latent",
  inputs: {
    amount: {
      name: "quantité"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const RescaleCFG$4 = {
  display_name: "RescaleCFG",
  inputs: {
    model: {
      name: "modèle"
    },
    multiplier: {
      name: "multiplicateur"
    }
  }
};
const SDTurboScheduler$4 = {
  display_name: "SDTurboScheduler",
  inputs: {
    denoise: {
      name: "débruitage"
    },
    model: {
      name: "modèle"
    },
    steps: {
      name: "étapes"
    }
  }
};
const SD_4XUpscale_Conditioning$4 = {
  display_name: "SD_4XUpscale_Conditioning",
  inputs: {
    images: {
      name: "images"
    },
    negative: {
      name: "négatif"
    },
    noise_augmentation: {
      name: "augmentation_du_bruit"
    },
    positive: {
      name: "positive"
    },
    scale_ratio: {
      name: "ratio_d'échelle"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const SV3D_Conditioning$4 = {
  display_name: "SV3D_Conditioning",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "élévation"
    },
    height: {
      name: "hauteur"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "cadres_vidéo"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const SVD_img2vid_Conditioning$4 = {
  display_name: "SVD_img2vid_Conditioning",
  inputs: {
    augmentation_level: {
      name: "niveau_d'augmentation"
    },
    clip_vision: {
      name: "clip_vision"
    },
    fps: {
      name: "fps"
    },
    height: {
      name: "hauteur"
    },
    init_image: {
      name: "init_image"
    },
    motion_bucket_id: {
      name: "id_seau_de_mouvement"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "cadres_vidéo"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const SamplerCustom$4 = {
  display_name: "ÉchantillonneurPersonnalisé",
  inputs: {
    add_noise: {
      name: "ajouter_bruit"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "contrôle après génération"
    },
    latent_image: {
      name: "image_latente"
    },
    model: {
      name: "modèle"
    },
    negative: {
      name: "négative"
    },
    noise_seed: {
      name: "graine_de_bruit"
    },
    positive: {
      name: "positive"
    },
    sampler: {
      name: "échantillonneur"
    },
    sigmas: {
      name: "sigmas"
    }
  },
  outputs: {
    "0": {
      name: "sortie"
    },
    "1": {
      name: "sortie_débruitée"
    }
  }
};
const SamplerCustomAdvanced$4 = {
  display_name: "ÉchantillonneurPersonnaliséAvancé",
  inputs: {
    guider: {
      name: "guide"
    },
    latent_image: {
      name: "image_latente"
    },
    noise: {
      name: "bruit"
    },
    sampler: {
      name: "échantillonneur"
    },
    sigmas: {
      name: "sigmas"
    }
  },
  outputs: {
    "0": {
      name: "sortie"
    },
    "1": {
      name: "sortie_débruitée"
    }
  }
};
const SamplerDPMAdaptative$4 = {
  display_name: "SamplerDPMAdaptative",
  inputs: {
    accept_safety: {
      name: "accept_safety"
    },
    atol: {
      name: "atol"
    },
    dcoeff: {
      name: "dcoeff"
    },
    eta: {
      name: "eta"
    },
    h_init: {
      name: "h_init"
    },
    icoeff: {
      name: "icoeff"
    },
    order: {
      name: "ordre"
    },
    pcoeff: {
      name: "pcoeff"
    },
    rtol: {
      name: "rtol"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerDPMPP_2M_SDE$4 = {
  display_name: "SamplerDPMPP_2M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "appareil_bruit"
    },
    s_noise: {
      name: "s_bruit"
    },
    solver_type: {
      name: "type_solveur"
    }
  }
};
const SamplerDPMPP_2S_Ancestral$4 = {
  display_name: "SamplerDPMPP_2S_Ancestral",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerDPMPP_3M_SDE$4 = {
  display_name: "SamplerDPMPP_3M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "appareil_bruit"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerDPMPP_SDE$4 = {
  display_name: "SamplerDPMPP_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "appareil_bruit"
    },
    r: {
      name: "r"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerEulerAncestral$4 = {
  display_name: "SamplerEulerAncestral",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerEulerAncestralCFGPP$4 = {
  display_name: "SamplerEulerAncestralCFG++",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_bruit"
    }
  }
};
const SamplerEulerCFGpp$4 = {
  display_name: "SamplerEulerCFG++",
  inputs: {
    version: {
      name: "version"
    }
  }
};
const SamplerLCMUpscale$4 = {
  display_name: "SamplerLCMUpscale",
  inputs: {
    scale_ratio: {
      name: "ratio_échelle"
    },
    scale_steps: {
      name: "étapes_échelle"
    },
    upscale_method: {
      name: "méthode_agrandissement"
    }
  }
};
const SamplerLMS$4 = {
  display_name: "SamplerLMS",
  inputs: {
    order: {
      name: "ordre"
    }
  }
};
const SaveAnimatedPNG$4 = {
  display_name: "EnregistrerPNGAnimé",
  inputs: {
    compress_level: {
      name: "niveau_compression"
    },
    filename_prefix: {
      name: "préfixe_nom_fichier"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "images"
    }
  }
};
const SaveAnimatedWEBP$4 = {
  display_name: "EnregistrerWEBPAnimé",
  inputs: {
    filename_prefix: {
      name: "préfixe_du_nom_de_fichier"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "images"
    },
    lossless: {
      name: "sans_perte"
    },
    method: {
      name: "méthode"
    },
    quality: {
      name: "qualité"
    }
  }
};
const SaveAudio$4 = {
  display_name: "EnregistrerAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    audioUI: {
      name: "audioUI"
    },
    filename_prefix: {
      name: "préfixe_du_nom_de_fichier"
    }
  }
};
const SaveGLB$4 = {
  display_name: "SaveGLB",
  inputs: {
    filename_prefix: {
      name: "préfixe_du_nom_de_fichier"
    },
    image: {
      name: "image"
    },
    mesh: {
      name: "maillage"
    }
  }
};
const SaveImage$4 = {
  description: "Enregistre les images d'entrée dans votre répertoire de sortie ComfyUI.",
  display_name: "Enregistrer Image",
  inputs: {
    filename_prefix: {
      name: "préfixe_du_nom_de_fichier",
      tooltip: "Le préfixe pour le fichier à enregistrer. Cela peut inclure des informations de formatage telles que %date:yyyy-MM-dd% ou %Empty Latent Image.width% pour inclure des valeurs à partir de nœuds."
    },
    images: {
      name: "images",
      tooltip: "Les images à enregistrer."
    }
  }
};
const SaveImageWebsocket$4 = {
  display_name: "EnregistrerImageWebsocket",
  inputs: {
    images: {
      name: "images"
    }
  }
};
const SaveLatent$4 = {
  display_name: "EnregistrerLatent",
  inputs: {
    filename_prefix: {
      name: "préfixe_du_nom_de_fichier"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const SaveWEBM$4 = {
  display_name: "EnregistrerWEBM",
  inputs: {
    codec: {
      name: "codec"
    },
    crf: {
      name: "crf",
      tooltip: "Un crf plus élevé signifie une qualité inférieure avec une taille de fichier plus petite, un crf plus bas signifie une qualité supérieure avec une taille de fichier plus grande."
    },
    filename_prefix: {
      name: "préfixe_de_nom_de_fichier"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "images"
    }
  }
};
const SelfAttentionGuidance$4 = {
  display_name: "Guidance d'Auto-Attention",
  inputs: {
    blur_sigma: {
      name: "blur_sigma"
    },
    model: {
      name: "modèle"
    },
    scale: {
      name: "échelle"
    }
  }
};
const SetClipHooks$4 = {
  display_name: "Définir les Crochets CLIP",
  inputs: {
    apply_to_conds: {
      name: "appliquer_à_conds"
    },
    clip: {
      name: "clip"
    },
    hooks: {
      name: "crochets"
    },
    schedule_clip: {
      name: "programmer_clip"
    }
  }
};
const SetFirstSigma$4 = {
  display_name: "DéfinirPremierSigma",
  inputs: {
    sigma: {
      name: "sigma"
    },
    sigmas: {
      name: "sigmas"
    }
  }
};
const SetHookKeyframes$4 = {
  display_name: "Définir les Images Clés de Crochet",
  inputs: {
    hook_kf: {
      name: "crochet_kf"
    },
    hooks: {
      name: "crochets"
    }
  }
};
const SetLatentNoiseMask$4 = {
  display_name: "Définir le Masque de Bruit Latent",
  inputs: {
    mask: {
      name: "masque"
    },
    samples: {
      name: "échantillons"
    }
  }
};
const SetUnionControlNetType$4 = {
  display_name: "Définir le Type de Réseau de Contrôle d'Union",
  inputs: {
    control_net: {
      name: "réseau_de_contrôle"
    },
    type: {
      name: "type"
    }
  }
};
const SkipLayerGuidanceDiT$4 = {
  description: "Version générique du nœud SkipLayerGuidance qui peut être utilisée sur chaque modèle DiT.",
  display_name: "SkipLayerGuidanceDiT",
  inputs: {
    double_layers: {
      name: "double_couches"
    },
    end_percent: {
      name: "pourcentage_de_fin"
    },
    model: {
      name: "modèle"
    },
    rescaling_scale: {
      name: "échelle_de_redimensionnement"
    },
    scale: {
      name: "échelle"
    },
    single_layers: {
      name: "couches_simples"
    },
    start_percent: {
      name: "pourcentage_de_départ"
    }
  }
};
const SkipLayerGuidanceSD3$4 = {
  description: "Version générique du nœud SkipLayerGuidance qui peut être utilisée sur chaque modèle DiT.",
  display_name: "SkipLayerGuidanceSD3",
  inputs: {
    end_percent: {
      name: "pourcentage_de_fin"
    },
    layers: {
      name: "couches"
    },
    model: {
      name: "modèle"
    },
    scale: {
      name: "échelle"
    },
    start_percent: {
      name: "pourcentage_de_départ"
    }
  }
};
const SolidMask$4 = {
  display_name: "SolidMask",
  inputs: {
    height: {
      name: "hauteur"
    },
    value: {
      name: "valeur"
    },
    width: {
      name: "largeur"
    }
  }
};
const SplitImageWithAlpha$4 = {
  display_name: "Diviser l'image avec Alpha",
  inputs: {
    image: {
      name: "image"
    }
  }
};
const SplitSigmas$4 = {
  display_name: "SplitSigmas",
  inputs: {
    sigmas: {
      name: "sigmas"
    },
    step: {
      name: "étape"
    }
  },
  outputs: {
    "0": {
      name: "high_sigmas"
    },
    "1": {
      name: "low_sigmas"
    }
  }
};
const SplitSigmasDenoise$4 = {
  display_name: "SplitSigmasDenoise",
  inputs: {
    denoise: {
      name: "réduction_du_bruit"
    },
    sigmas: {
      name: "sigmas"
    }
  },
  outputs: {
    "0": {
      name: "high_sigmas"
    },
    "1": {
      name: "low_sigmas"
    }
  }
};
const StableCascade_EmptyLatentImage$4 = {
  display_name: "StableCascade_EmptyLatentImage",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    compression: {
      name: "compression"
    },
    height: {
      name: "hauteur"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "stage_c"
    },
    "1": {
      name: "stage_b"
    }
  }
};
const StableCascade_StageB_Conditioning$4 = {
  display_name: "StableCascade_StageB_Conditioning",
  inputs: {
    conditioning: {
      name: "conditionnement"
    },
    stage_c: {
      name: "stage_c"
    }
  }
};
const StableCascade_StageC_VAEEncode$4 = {
  display_name: "StableCascade_StageC_VAEEncode",
  inputs: {
    compression: {
      name: "compression"
    },
    image: {
      name: "image"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "stage_c"
    },
    "1": {
      name: "stage_b"
    }
  }
};
const StableCascade_SuperResolutionControlnet$4 = {
  display_name: "StableCascade_SuperResolutionControlnet",
  inputs: {
    image: {
      name: "image"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "entrée_controlnet"
    },
    "1": {
      name: "étape_c"
    },
    "2": {
      name: "étape_b"
    }
  }
};
const StableZero123_Conditioning$4 = {
  display_name: "StableZero123_Conditioning",
  inputs: {
    azimuth: {
      name: "azimut"
    },
    batch_size: {
      name: "taille_lot"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "élévation"
    },
    height: {
      name: "hauteur"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const StableZero123_Conditioning_Batched$4 = {
  display_name: "StableZero123_Conditioning_Batched",
  inputs: {
    azimuth: {
      name: "azimut"
    },
    azimuth_batch_increment: {
      name: "incrément_lot_azimut"
    },
    batch_size: {
      name: "taille_lot"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "élévation"
    },
    elevation_batch_increment: {
      name: "incrément_lot_élévation"
    },
    height: {
      name: "hauteur"
    },
    init_image: {
      name: "init_image"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positif"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const StyleModelApply$4 = {
  display_name: "Appliquer le modèle de style",
  inputs: {
    clip_vision_output: {
      name: "sortie_clip_vision"
    },
    conditioning: {
      name: "conditionnement"
    },
    strength: {
      name: "force"
    },
    strength_type: {
      name: "type_de_force"
    },
    style_model: {
      name: "modèle_de_style"
    }
  }
};
const StyleModelLoader$4 = {
  display_name: "Charger le modèle de style",
  inputs: {
    style_model_name: {
      name: "nom_du_modèle_de_style"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo$4 = {
  display_name: "TextEncodeHunyuanVideo_ImageToVideo",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_vision_output: {
      name: "sortie_vision_clip"
    },
    image_interleave: {
      name: "entrelacement_image",
      tooltip: "À quel point l'image influence les choses par rapport à l'invite de texte. Un nombre plus élevé signifie plus d'influence de l'invite de texte."
    },
    prompt: {
      name: "invite"
    }
  }
};
const ThresholdMask$4 = {
  display_name: "SeuilMasque",
  inputs: {
    mask: {
      name: "masque"
    },
    value: {
      name: "valeur"
    }
  }
};
const TomePatchModel$4 = {
  display_name: "ModèlePatchTome",
  inputs: {
    model: {
      name: "modèle"
    },
    ratio: {
      name: "ratio"
    }
  }
};
const TorchCompileModel$4 = {
  display_name: "ModèleCompilationTorch",
  inputs: {
    backend: {
      name: "backend"
    },
    model: {
      name: "modèle"
    }
  }
};
const TripleCLIPLoader$4 = {
  description: "[Recettes]\n\nsd3: clip-l, clip-g, t5",
  display_name: "ChargeurTripleCLIP",
  inputs: {
    clip_name1: {
      name: "nom_clip1"
    },
    clip_name2: {
      name: "nom_clip2"
    },
    clip_name3: {
      name: "nom_clip3"
    }
  }
};
const UNETLoader$4 = {
  display_name: "Charger Modèle Diffusion",
  inputs: {
    unet_name: {
      name: "nom_unet"
    },
    weight_dtype: {
      name: "dtype_poids"
    }
  }
};
const UNetCrossAttentionMultiply$4 = {
  display_name: "UNetMultiplicationAttentionCroisée",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "modèle"
    },
    out: {
      name: "sortie"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetSelfAttentionMultiply$4 = {
  display_name: "UNetMultiplicationAutoAttention",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "modèle"
    },
    out: {
      name: "sortie"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetTemporalAttentionMultiply$4 = {
  display_name: "UNetTemporalAttentionMultiply",
  inputs: {
    cross_structural: {
      name: "cross_structural"
    },
    cross_temporal: {
      name: "cross_temporal"
    },
    model: {
      name: "modèle"
    },
    self_structural: {
      name: "self_structural"
    },
    self_temporal: {
      name: "self_temporal"
    }
  }
};
const UpscaleModelLoader$4 = {
  display_name: "Charger le modèle de mise à l'échelle",
  inputs: {
    model_name: {
      name: "nom_du_modèle"
    }
  }
};
const VAEDecode$4 = {
  description: "Décode les images latentes en images d'espace de pixels.",
  display_name: "VAE Decode",
  inputs: {
    samples: {
      name: "échantillons",
      tooltip: "Le latent à décoder."
    },
    vae: {
      name: "vae",
      tooltip: "Le modèle VAE utilisé pour le décodage du latent."
    }
  },
  outputs: {
    "0": {
      tooltip: "L'image décodée."
    }
  }
};
const VAEDecodeAudio$4 = {
  display_name: "VAEDecodeAudio",
  inputs: {
    samples: {
      name: "échantillons"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D$4 = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    num_chunks: {
      name: "nombre_de_morceaux"
    },
    octree_resolution: {
      name: "résolution_octree"
    },
    samples: {
      name: "échantillons"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeTiled$4 = {
  display_name: "VAE Decode (Tiled)",
  inputs: {
    overlap: {
      name: "chevauchement"
    },
    samples: {
      name: "échantillons"
    },
    temporal_overlap: {
      name: "chevauchement_temporel",
      tooltip: "Uniquement utilisé pour les VAE vidéo : Nombre de trames à chevaucher."
    },
    temporal_size: {
      name: "taille_temporelle",
      tooltip: "Uniquement utilisé pour les VAE vidéo : Nombre de trames à décoder à la fois."
    },
    tile_size: {
      name: "taille_de_tuile"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncode$4 = {
  display_name: "VAE Encode",
  inputs: {
    pixels: {
      name: "pixels"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio$4 = {
  display_name: "VAEEncodeAudio",
  inputs: {
    audio: {
      name: "audio"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint$4 = {
  display_name: "VAE Encode (pour Inpainting)",
  inputs: {
    grow_mask_by: {
      name: "agrandir_masque_par"
    },
    mask: {
      name: "masque"
    },
    pixels: {
      name: "pixels"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeTiled$4 = {
  display_name: "VAE Encode (Tiled)",
  inputs: {
    overlap: {
      name: "chevauchement"
    },
    pixels: {
      name: "pixels"
    },
    temporal_overlap: {
      name: "chevauchement_temporel",
      tooltip: "Uniquement utilisé pour les VAE vidéo : Nombre de trames à chevaucher."
    },
    temporal_size: {
      name: "taille_temporelle",
      tooltip: "Uniquement utilisé pour les VAE vidéo : Nombre de trames à encoder à la fois."
    },
    tile_size: {
      name: "taille_de_tuile"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAELoader$4 = {
  display_name: "Charger VAE",
  inputs: {
    vae_name: {
      name: "nom_vae"
    }
  }
};
const VAESave$4 = {
  display_name: "VAESauvegarder",
  inputs: {
    filename_prefix: {
      name: "préfixe_de_fichier"
    },
    vae: {
      name: "vae"
    }
  }
};
const VPScheduler$4 = {
  display_name: "PlanificateurVP",
  inputs: {
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    },
    steps: {
      name: "étapes"
    }
  }
};
const VideoLinearCFGGuidance$4 = {
  display_name: "Guidance VideoLinearCFG",
  inputs: {
    min_cfg: {
      name: "min_cfg"
    },
    model: {
      name: "modèle"
    }
  }
};
const VideoTriangleCFGGuidance$4 = {
  display_name: "Guidance VideoTriangleCFG",
  inputs: {
    min_cfg: {
      name: "min_cfg"
    },
    model: {
      name: "modèle"
    }
  }
};
const VoxelToMeshBasic$4 = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    threshold: {
      name: "seuil"
    },
    voxel: {
      name: "voxel"
    }
  }
};
const WanImageToVideo$4 = {
  display_name: "WanImageVersVidéo",
  inputs: {
    batch_size: {
      name: "taille_du_lot"
    },
    clip_vision_output: {
      name: "sortie_vision_clip"
    },
    height: {
      name: "hauteur"
    },
    length: {
      name: "longueur"
    },
    negative: {
      name: "négatif"
    },
    positive: {
      name: "positive"
    },
    start_image: {
      name: "image_de_départ"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "largeur"
    }
  },
  outputs: {
    "0": {
      name: "positive"
    },
    "1": {
      name: "négatif"
    },
    "2": {
      name: "latent"
    }
  }
};
const WebcamCapture$4 = {
  display_name: "Capture Webcam",
  inputs: {
    capture_on_queue: {
      name: "capture_en_file_d'attente"
    },
    height: {
      name: "hauteur"
    },
    image: {
      name: "image"
    },
    "waiting for camera___": {},
    width: {
      name: "largeur"
    }
  }
};
const unCLIPCheckpointLoader$4 = {
  display_name: "ChargeurPointContrôleunCLIP",
  inputs: {
    ckpt_name: {
      name: "nom_ckpt"
    }
  }
};
const unCLIPConditioning$4 = {
  display_name: "ConditionnementunCLIP",
  inputs: {
    clip_vision_output: {
      name: "sortie_vision_clip"
    },
    conditioning: {
      name: "conditionnement"
    },
    noise_augmentation: {
      name: "augmentation_bruit"
    },
    strength: {
      name: "force"
    }
  }
};
const frNodes = {
  AddNoise: AddNoise$4,
  AlignYourStepsScheduler: AlignYourStepsScheduler$4,
  BasicGuider: BasicGuider$4,
  BasicScheduler: BasicScheduler$4,
  BetaSamplingScheduler: BetaSamplingScheduler$4,
  CFGGuider: CFGGuider$4,
  CLIPAttentionMultiply: CLIPAttentionMultiply$4,
  CLIPLoader: CLIPLoader$4,
  CLIPMergeAdd: CLIPMergeAdd$4,
  CLIPMergeSimple: CLIPMergeSimple$4,
  CLIPMergeSubtract: CLIPMergeSubtract$4,
  CLIPSave: CLIPSave$4,
  CLIPSetLastLayer: CLIPSetLastLayer$4,
  CLIPTextEncode: CLIPTextEncode$4,
  CLIPTextEncodeControlnet: CLIPTextEncodeControlnet$4,
  CLIPTextEncodeFlux: CLIPTextEncodeFlux$4,
  CLIPTextEncodeHunyuanDiT: CLIPTextEncodeHunyuanDiT$4,
  CLIPTextEncodeLumina2: CLIPTextEncodeLumina2$4,
  CLIPTextEncodePixArtAlpha: CLIPTextEncodePixArtAlpha$4,
  CLIPTextEncodeSD3: CLIPTextEncodeSD3$4,
  CLIPTextEncodeSDXL: CLIPTextEncodeSDXL$4,
  CLIPTextEncodeSDXLRefiner: CLIPTextEncodeSDXLRefiner$4,
  CLIPVisionEncode: CLIPVisionEncode$4,
  CLIPVisionLoader: CLIPVisionLoader$4,
  Canny: Canny$4,
  CheckpointLoader: CheckpointLoader$4,
  CheckpointLoaderSimple: CheckpointLoaderSimple$4,
  CheckpointSave: CheckpointSave$4,
  CombineHooks2: CombineHooks2$4,
  CombineHooks4: CombineHooks4$4,
  CombineHooks8: CombineHooks8$4,
  ConditioningAverage: ConditioningAverage$4,
  ConditioningCombine: ConditioningCombine$4,
  ConditioningConcat: ConditioningConcat$4,
  ConditioningSetArea: ConditioningSetArea$4,
  ConditioningSetAreaPercentage: ConditioningSetAreaPercentage$4,
  ConditioningSetAreaPercentageVideo: ConditioningSetAreaPercentageVideo$4,
  ConditioningSetAreaStrength: ConditioningSetAreaStrength$4,
  ConditioningSetDefaultCombine: ConditioningSetDefaultCombine$4,
  ConditioningSetMask: ConditioningSetMask$4,
  ConditioningSetProperties: ConditioningSetProperties$4,
  ConditioningSetPropertiesAndCombine: ConditioningSetPropertiesAndCombine$4,
  ConditioningSetTimestepRange: ConditioningSetTimestepRange$4,
  ConditioningStableAudio: ConditioningStableAudio$4,
  ConditioningTimestepsRange: ConditioningTimestepsRange$4,
  ConditioningZeroOut: ConditioningZeroOut$4,
  ControlNetApply: ControlNetApply$4,
  ControlNetApplyAdvanced: ControlNetApplyAdvanced$4,
  ControlNetApplySD3: ControlNetApplySD3$4,
  ControlNetInpaintingAliMamaApply: ControlNetInpaintingAliMamaApply$4,
  ControlNetLoader: ControlNetLoader$4,
  CosmosImageToVideoLatent: CosmosImageToVideoLatent$4,
  CreateHookKeyframe: CreateHookKeyframe$4,
  CreateHookKeyframesFromFloats: CreateHookKeyframesFromFloats$4,
  CreateHookKeyframesInterpolated: CreateHookKeyframesInterpolated$4,
  CreateHookLora: CreateHookLora$4,
  CreateHookLoraModelOnly: CreateHookLoraModelOnly$4,
  CreateHookModelAsLora: CreateHookModelAsLora$4,
  CreateHookModelAsLoraModelOnly: CreateHookModelAsLoraModelOnly$4,
  CropMask: CropMask$4,
  DiffControlNetLoader: DiffControlNetLoader$4,
  DifferentialDiffusion: DifferentialDiffusion$4,
  DiffusersLoader: DiffusersLoader$4,
  DisableNoise: DisableNoise$4,
  DualCFGGuider: DualCFGGuider$4,
  DualCLIPLoader: DualCLIPLoader$4,
  EmptyCosmosLatentVideo: EmptyCosmosLatentVideo$4,
  EmptyHunyuanLatentVideo: EmptyHunyuanLatentVideo$4,
  EmptyImage: EmptyImage$4,
  EmptyLTXVLatentVideo: EmptyLTXVLatentVideo$4,
  EmptyLatentAudio: EmptyLatentAudio$4,
  EmptyLatentHunyuan3Dv2: EmptyLatentHunyuan3Dv2$4,
  EmptyLatentImage: EmptyLatentImage$4,
  EmptyMochiLatentVideo: EmptyMochiLatentVideo$4,
  EmptySD3LatentImage: EmptySD3LatentImage$4,
  ExponentialScheduler: ExponentialScheduler$4,
  FeatherMask: FeatherMask$4,
  FlipSigmas: FlipSigmas$4,
  FluxDisableGuidance: FluxDisableGuidance$4,
  FluxGuidance: FluxGuidance$4,
  FreeU: FreeU$4,
  FreeU_V2: FreeU_V2$4,
  GITSScheduler: GITSScheduler$4,
  GLIGENLoader: GLIGENLoader$4,
  GLIGENTextBoxApply: GLIGENTextBoxApply$4,
  GrowMask: GrowMask$4,
  Hunyuan3Dv2Conditioning: Hunyuan3Dv2Conditioning$4,
  Hunyuan3Dv2ConditioningMultiView: Hunyuan3Dv2ConditioningMultiView$4,
  HunyuanImageToVideo: HunyuanImageToVideo$4,
  HyperTile: HyperTile$4,
  HypernetworkLoader: HypernetworkLoader$4,
  ImageBatch: ImageBatch$4,
  ImageBlend: ImageBlend$4,
  ImageBlur: ImageBlur$4,
  ImageColorToMask: ImageColorToMask$4,
  ImageCompositeMasked: ImageCompositeMasked$4,
  ImageCrop: ImageCrop$4,
  ImageFromBatch: ImageFromBatch$4,
  ImageInvert: ImageInvert$4,
  ImageOnlyCheckpointLoader: ImageOnlyCheckpointLoader$4,
  ImageOnlyCheckpointSave: ImageOnlyCheckpointSave$4,
  ImagePadForOutpaint: ImagePadForOutpaint$4,
  ImageQuantize: ImageQuantize$4,
  ImageScale: ImageScale$4,
  ImageScaleBy: ImageScaleBy$4,
  ImageScaleToTotalPixels: ImageScaleToTotalPixels$4,
  ImageSharpen: ImageSharpen$4,
  ImageToMask: ImageToMask$4,
  ImageUpscaleWithModel: ImageUpscaleWithModel$4,
  InpaintModelConditioning: InpaintModelConditioning$4,
  InstructPixToPixConditioning: InstructPixToPixConditioning$4,
  InvertMask: InvertMask$4,
  JoinImageWithAlpha: JoinImageWithAlpha$4,
  KSampler: KSampler$4,
  KSamplerAdvanced: KSamplerAdvanced$4,
  KSamplerSelect: KSamplerSelect$4,
  KarrasScheduler: KarrasScheduler$4,
  LTXVAddGuide: LTXVAddGuide$4,
  LTXVConditioning: LTXVConditioning$4,
  LTXVCropGuides: LTXVCropGuides$4,
  LTXVImgToVideo: LTXVImgToVideo$4,
  LTXVPreprocess: LTXVPreprocess$4,
  LTXVScheduler: LTXVScheduler$4,
  LaplaceScheduler: LaplaceScheduler$4,
  LatentAdd: LatentAdd$4,
  LatentApplyOperation: LatentApplyOperation$4,
  LatentApplyOperationCFG: LatentApplyOperationCFG$4,
  LatentBatch: LatentBatch$4,
  LatentBatchSeedBehavior: LatentBatchSeedBehavior$4,
  LatentBlend: LatentBlend$4,
  LatentComposite: LatentComposite$4,
  LatentCompositeMasked: LatentCompositeMasked$4,
  LatentCrop: LatentCrop$4,
  LatentFlip: LatentFlip$4,
  LatentFromBatch: LatentFromBatch$4,
  LatentInterpolate: LatentInterpolate$4,
  LatentMultiply: LatentMultiply$4,
  LatentOperationSharpen: LatentOperationSharpen$4,
  LatentOperationTonemapReinhard: LatentOperationTonemapReinhard$4,
  LatentRotate: LatentRotate$4,
  LatentSubtract: LatentSubtract$4,
  LatentUpscale: LatentUpscale$4,
  LatentUpscaleBy: LatentUpscaleBy$4,
  Load3D: Load3D$4,
  Load3DAnimation: Load3DAnimation$4,
  LoadAudio: LoadAudio$4,
  LoadImage: LoadImage$4,
  LoadImageMask: LoadImageMask$4,
  LoadImageOutput: LoadImageOutput$4,
  LoadLatent: LoadLatent$4,
  LoraLoader: LoraLoader$4,
  LoraLoaderModelOnly: LoraLoaderModelOnly$4,
  LoraSave: LoraSave$4,
  Mahiro: Mahiro$4,
  MaskComposite: MaskComposite$4,
  MaskToImage: MaskToImage$4,
  ModelComputeDtype: ModelComputeDtype$4,
  ModelMergeAdd: ModelMergeAdd$4,
  ModelMergeAuraflow: ModelMergeAuraflow$4,
  ModelMergeBlocks: ModelMergeBlocks$4,
  ModelMergeCosmos14B: ModelMergeCosmos14B$4,
  ModelMergeCosmos7B: ModelMergeCosmos7B$4,
  ModelMergeFlux1: ModelMergeFlux1$4,
  ModelMergeLTXV: ModelMergeLTXV$4,
  ModelMergeMochiPreview: ModelMergeMochiPreview$4,
  ModelMergeSD1: ModelMergeSD1$4,
  ModelMergeSD2: ModelMergeSD2$4,
  ModelMergeSD35_Large: ModelMergeSD35_Large$4,
  ModelMergeSD3_2B: ModelMergeSD3_2B$4,
  ModelMergeSDXL: ModelMergeSDXL$4,
  ModelMergeSimple: ModelMergeSimple$4,
  ModelMergeSubtract: ModelMergeSubtract$4,
  ModelSamplingAuraFlow: ModelSamplingAuraFlow$4,
  ModelSamplingContinuousEDM: ModelSamplingContinuousEDM$4,
  ModelSamplingContinuousV: ModelSamplingContinuousV$4,
  ModelSamplingDiscrete: ModelSamplingDiscrete$4,
  ModelSamplingFlux: ModelSamplingFlux$4,
  ModelSamplingLTXV: ModelSamplingLTXV$4,
  ModelSamplingSD3: ModelSamplingSD3$4,
  ModelSamplingStableCascade: ModelSamplingStableCascade$4,
  ModelSave: ModelSave$4,
  Morphology: Morphology$4,
  PairConditioningCombine: PairConditioningCombine$4,
  PairConditioningSetDefaultCombine: PairConditioningSetDefaultCombine$4,
  PairConditioningSetProperties: PairConditioningSetProperties$4,
  PairConditioningSetPropertiesAndCombine: PairConditioningSetPropertiesAndCombine$4,
  PatchModelAddDownscale: PatchModelAddDownscale$4,
  PerpNeg: PerpNeg$4,
  PerpNegGuider: PerpNegGuider$4,
  PerturbedAttentionGuidance: PerturbedAttentionGuidance$4,
  PhotoMakerEncode: PhotoMakerEncode$4,
  PhotoMakerLoader: PhotoMakerLoader$4,
  PolyexponentialScheduler: PolyexponentialScheduler$4,
  PorterDuffImageComposite: PorterDuffImageComposite$4,
  Preview3D: Preview3D$4,
  Preview3DAnimation: Preview3DAnimation$4,
  PreviewAudio: PreviewAudio$4,
  PreviewImage: PreviewImage$4,
  RandomNoise: RandomNoise$4,
  RebatchImages: RebatchImages$4,
  RebatchLatents: RebatchLatents$4,
  RenormCFG: RenormCFG$4,
  RepeatImageBatch: RepeatImageBatch$4,
  RepeatLatentBatch: RepeatLatentBatch$4,
  RescaleCFG: RescaleCFG$4,
  SDTurboScheduler: SDTurboScheduler$4,
  SD_4XUpscale_Conditioning: SD_4XUpscale_Conditioning$4,
  SV3D_Conditioning: SV3D_Conditioning$4,
  SVD_img2vid_Conditioning: SVD_img2vid_Conditioning$4,
  SamplerCustom: SamplerCustom$4,
  SamplerCustomAdvanced: SamplerCustomAdvanced$4,
  SamplerDPMAdaptative: SamplerDPMAdaptative$4,
  SamplerDPMPP_2M_SDE: SamplerDPMPP_2M_SDE$4,
  SamplerDPMPP_2S_Ancestral: SamplerDPMPP_2S_Ancestral$4,
  SamplerDPMPP_3M_SDE: SamplerDPMPP_3M_SDE$4,
  SamplerDPMPP_SDE: SamplerDPMPP_SDE$4,
  SamplerEulerAncestral: SamplerEulerAncestral$4,
  SamplerEulerAncestralCFGPP: SamplerEulerAncestralCFGPP$4,
  SamplerEulerCFGpp: SamplerEulerCFGpp$4,
  SamplerLCMUpscale: SamplerLCMUpscale$4,
  SamplerLMS: SamplerLMS$4,
  SaveAnimatedPNG: SaveAnimatedPNG$4,
  SaveAnimatedWEBP: SaveAnimatedWEBP$4,
  SaveAudio: SaveAudio$4,
  SaveGLB: SaveGLB$4,
  SaveImage: SaveImage$4,
  SaveImageWebsocket: SaveImageWebsocket$4,
  SaveLatent: SaveLatent$4,
  SaveWEBM: SaveWEBM$4,
  SelfAttentionGuidance: SelfAttentionGuidance$4,
  SetClipHooks: SetClipHooks$4,
  SetFirstSigma: SetFirstSigma$4,
  SetHookKeyframes: SetHookKeyframes$4,
  SetLatentNoiseMask: SetLatentNoiseMask$4,
  SetUnionControlNetType: SetUnionControlNetType$4,
  SkipLayerGuidanceDiT: SkipLayerGuidanceDiT$4,
  SkipLayerGuidanceSD3: SkipLayerGuidanceSD3$4,
  SolidMask: SolidMask$4,
  SplitImageWithAlpha: SplitImageWithAlpha$4,
  SplitSigmas: SplitSigmas$4,
  SplitSigmasDenoise: SplitSigmasDenoise$4,
  StableCascade_EmptyLatentImage: StableCascade_EmptyLatentImage$4,
  StableCascade_StageB_Conditioning: StableCascade_StageB_Conditioning$4,
  StableCascade_StageC_VAEEncode: StableCascade_StageC_VAEEncode$4,
  StableCascade_SuperResolutionControlnet: StableCascade_SuperResolutionControlnet$4,
  StableZero123_Conditioning: StableZero123_Conditioning$4,
  StableZero123_Conditioning_Batched: StableZero123_Conditioning_Batched$4,
  StyleModelApply: StyleModelApply$4,
  StyleModelLoader: StyleModelLoader$4,
  TextEncodeHunyuanVideo_ImageToVideo: TextEncodeHunyuanVideo_ImageToVideo$4,
  ThresholdMask: ThresholdMask$4,
  TomePatchModel: TomePatchModel$4,
  TorchCompileModel: TorchCompileModel$4,
  TripleCLIPLoader: TripleCLIPLoader$4,
  UNETLoader: UNETLoader$4,
  UNetCrossAttentionMultiply: UNetCrossAttentionMultiply$4,
  UNetSelfAttentionMultiply: UNetSelfAttentionMultiply$4,
  UNetTemporalAttentionMultiply: UNetTemporalAttentionMultiply$4,
  UpscaleModelLoader: UpscaleModelLoader$4,
  VAEDecode: VAEDecode$4,
  VAEDecodeAudio: VAEDecodeAudio$4,
  VAEDecodeHunyuan3D: VAEDecodeHunyuan3D$4,
  VAEDecodeTiled: VAEDecodeTiled$4,
  VAEEncode: VAEEncode$4,
  VAEEncodeAudio: VAEEncodeAudio$4,
  VAEEncodeForInpaint: VAEEncodeForInpaint$4,
  VAEEncodeTiled: VAEEncodeTiled$4,
  VAELoader: VAELoader$4,
  VAESave: VAESave$4,
  VPScheduler: VPScheduler$4,
  VideoLinearCFGGuidance: VideoLinearCFGGuidance$4,
  VideoTriangleCFGGuidance: VideoTriangleCFGGuidance$4,
  VoxelToMeshBasic: VoxelToMeshBasic$4,
  WanImageToVideo: WanImageToVideo$4,
  WebcamCapture: WebcamCapture$4,
  unCLIPCheckpointLoader: unCLIPCheckpointLoader$4,
  unCLIPConditioning: unCLIPConditioning$4
};
const Comfy_Canvas_SelectionToolbox$4 = {
  name: "Afficher la boîte à outils de sélection"
};
const Comfy_ConfirmClear$4 = {
  name: "Demander une confirmation lors de l'effacement du flux de travail"
};
const Comfy_DOMClippingEnabled$4 = {
  name: "Activer le découpage des éléments DOM (peut réduire les performances)"
};
const Comfy_DevMode$4 = {
  name: "Activer les options du mode développeur (sauvegarde API, etc.)"
};
const Comfy_DisableFloatRounding$4 = {
  name: "Désactiver l'arrondi par défaut du widget flottant.",
  tooltip: "(nécessite le rechargement de la page) Impossible de désactiver l'arrondi lorsque l'arrondi est défini par le nœud dans le backend."
};
const Comfy_DisableSliders$4 = {
  name: "Désactiver les curseurs du widget de nœud"
};
const Comfy_EditAttention_Delta$4 = {
  name: "Précision Ctrl+haut/bas"
};
const Comfy_EnableTooltips$4 = {
  name: "Activer les infobulles"
};
const Comfy_EnableWorkflowViewRestore$4 = {
  name: "Sauvegarder et restaurer la position et le niveau de zoom du canevas dans les flux de travail"
};
const Comfy_FloatRoundingPrecision$4 = {
  name: "Nombre de décimales pour l'arrondi du widget flottant [0 = auto].",
  tooltip: "(nécessite le rechargement de la page)"
};
const Comfy_Graph_CanvasInfo$4 = {
  name: "Afficher les informations du canevas en bas à gauche (fps, etc.)"
};
const Comfy_Graph_CanvasMenu$4 = {
  name: "Afficher le menu du canevas graphique"
};
const Comfy_Graph_CtrlShiftZoom$4 = {
  name: "Activer le raccourci de zoom rapide (Ctrl + Shift + Glisser)"
};
const Comfy_Graph_LinkMarkers$4 = {
  name: "Marqueurs de point médian du lien",
  options: {
    Arrow: "Flèche",
    Circle: "Cercle",
    None: "Aucun"
  }
};
const Comfy_Graph_ZoomSpeed$4 = {
  name: "Vitesse de zoom du canevas"
};
const Comfy_GroupSelectedNodes_Padding$4 = {
  name: "Marge des nœuds sélectionnés dans le groupe"
};
const Comfy_Group_DoubleClickTitleToEdit$4 = {
  name: "Double-cliquer sur le titre du groupe pour le modifier"
};
const Comfy_LinkRelease_Action$4 = {
  name: "Action lors du relâchement du lien (sans modificateur)",
  options: {
    "context menu": "menu contextuel",
    "no action": "aucune action",
    "search box": "boîte de recherche"
  }
};
const Comfy_LinkRelease_ActionShift$4 = {
  name: "Action lors du relâchement du lien (Shift)",
  options: {
    "context menu": "menu contextuel",
    "no action": "aucune action",
    "search box": "boîte de recherche"
  }
};
const Comfy_LinkRenderMode$4 = {
  name: "Mode de rendu du lien",
  options: {
    Hidden: "Caché",
    Linear: "Linéaire",
    Spline: "Spline",
    Straight: "Droit"
  }
};
const Comfy_Locale$4 = {
  name: "Langue"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed$4 = {
  name: "Multiplicateur de vitesse d'ajustement du pinceau",
  tooltip: "Contrôle la rapidité de changement de la taille et de la dureté du pinceau lors de l'ajustement. Des valeurs plus élevées signifient des changements plus rapides."
};
const Comfy_MaskEditor_UseDominantAxis$4 = {
  name: "Verrouiller l'ajustement du pinceau sur l'axe dominant",
  tooltip: "Lorsqu'il est activé, les ajustements du pinceau n'affecteront que la taille OU la dureté en fonction de la direction dans laquelle vous bougez le plus"
};
const Comfy_MaskEditor_UseNewEditor$4 = {
  name: "Utiliser le nouvel éditeur de masque",
  tooltip: "Passer à la nouvelle interface de l'éditeur de masque"
};
const Comfy_ModelLibrary_AutoLoadAll$4 = {
  name: "Charger automatiquement tous les dossiers de modèles",
  tooltip: "Si vrai, tous les dossiers seront chargés dès que vous ouvrez la bibliothèque de modèles (cela peut causer des retards pendant le chargement). Si faux, les dossiers de modèles de niveau racine ne seront chargés que lorsque vous cliquerez dessus."
};
const Comfy_ModelLibrary_NameFormat$4 = {
  name: "Quel nom afficher dans l'arborescence de la bibliothèque de modèles",
  options: {
    filename: "nom de fichier",
    title: "titre"
  },
  tooltip: 'Sélectionnez "filename" pour afficher une vue simplifiée du nom de fichier brut (sans répertoire ou extension ".safetensors") dans la liste des modèles. Sélectionnez "title" pour afficher le titre configurable des métadonnées du modèle.'
};
const Comfy_NodeBadge_NodeIdBadgeMode$4 = {
  name: "Mode de badge d'identifiant de nœud",
  options: {
    None: "Aucun",
    "Show all": "Afficher tout"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode$4 = {
  name: "Mode de badge de cycle de vie du nœud",
  options: {
    None: "Aucun",
    "Show all": "Afficher tout"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode$4 = {
  name: "Mode de badge de source de nœud",
  options: {
    "Hide built-in": "Cacher intégré",
    None: "Aucun",
    "Show all": "Afficher tout"
  }
};
const Comfy_NodeInputConversionSubmenus$4 = {
  name: "Dans le menu contextuel du nœud, placez les entrées qui convertissent entre l'entrée/widget dans des sous-menus."
};
const Comfy_NodeSearchBoxImpl$4 = {
  name: "Implémentation de la boîte de recherche de nœud",
  options: {
    "default": "par défaut",
    "litegraph (legacy)": "litegraph (héritage)"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview$4 = {
  name: "Aperçu du nœud",
  tooltip: "S'applique uniquement à l'implémentation par défaut"
};
const Comfy_NodeSearchBoxImpl_ShowCategory$4 = {
  name: "Afficher la catégorie de nœud dans les résultats de recherche",
  tooltip: "S'applique uniquement à l'implémentation par défaut"
};
const Comfy_NodeSearchBoxImpl_ShowIdName$4 = {
  name: "Afficher le nom de l'identifiant du nœud dans les résultats de recherche",
  tooltip: "S'applique uniquement à l'implémentation par défaut"
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency$4 = {
  name: "Afficher la fréquence du nœud dans les résultats de recherche",
  tooltip: "S'applique uniquement à l'implémentation par défaut"
};
const Comfy_NodeSuggestions_number$4 = {
  name: "Nombre de suggestions de nœuds",
  tooltip: "Uniquement pour la boîte de recherche/contexte du menu litegraph"
};
const Comfy_Node_AutoSnapLinkToSlot$4 = {
  name: "Lien d'ancrage automatique à l'emplacement du nœud",
  tooltip: "Lorsque vous faites glisser un lien sur un nœud, le lien se fixe automatiquement à une fente d'entrée viable sur le nœud"
};
const Comfy_Node_BypassAllLinksOnDelete$4 = {
  name: "Conserver tous les liens lors de la suppression de nœuds",
  tooltip: "Lors de la suppression d'un nœud, tentez de reconnecter tous ses liens d'entrée et de sortie (en contournant le nœud supprimé)"
};
const Comfy_Node_DoubleClickTitleToEdit$4 = {
  name: "Double-cliquez sur le titre du nœud pour le modifier"
};
const Comfy_Node_MiddleClickRerouteNode$4 = {
  name: "Le clic du milieu crée un nouveau nœud de réacheminement"
};
const Comfy_Node_Opacity$4 = {
  name: "Opacité du nœud"
};
const Comfy_Node_ShowDeprecated$4 = {
  name: "Afficher les nœuds obsolètes dans la recherche",
  tooltip: "Les nœuds obsolètes sont cachés par défaut dans l'interface utilisateur, mais restent fonctionnels dans les flux de travail existants qui les utilisent."
};
const Comfy_Node_ShowExperimental$4 = {
  name: "Afficher les nœuds expérimentaux dans la recherche",
  tooltip: "Les nœuds expérimentaux sont marqués comme tels dans l'interface utilisateur et peuvent être sujets à des modifications importantes ou à une suppression dans les versions futures. À utiliser avec prudence dans les flux de travail de production"
};
const Comfy_Node_SnapHighlightsNode$4 = {
  name: "Le snap met en évidence le nœud",
  tooltip: "Lorsque vous faites glisser un lien sur un nœud avec une fente d'entrée viable, mettez en évidence le nœud"
};
const Comfy_Pointer_ClickBufferTime$4 = {
  name: "Délai de dérive du clic du pointeur",
  tooltip: "Après avoir appuyé sur un bouton de pointeur, c'est le temps maximum (en millisecondes) que le mouvement du pointeur peut être ignoré.\n\nAide à prévenir que les objets soient déplacés involontairement si le pointeur est déplacé lors du clic."
};
const Comfy_Pointer_ClickDrift$4 = {
  name: "Dérive du clic du pointeur (distance maximale)",
  tooltip: "Si le pointeur se déplace plus que cette distance en maintenant un bouton enfoncé, il est considéré comme un glissement (plutôt qu'un clic).\n\nAide à prévenir que les objets soient déplacés involontairement si le pointeur est déplacé lors du clic."
};
const Comfy_Pointer_DoubleClickTime$4 = {
  name: "Intervalle de double clic (maximum)",
  tooltip: "Le temps maximum en millisecondes entre les deux clics d'un double-clic. Augmenter cette valeur peut aider si les double-clics ne sont parfois pas enregistrés."
};
const Comfy_PreviewFormat$4 = {
  name: "Format de l'image de prévisualisation",
  tooltip: "Lors de l'affichage d'une prévisualisation dans le widget d'image, convertissez-la en une image légère, par exemple webp, jpeg, webp;50, etc."
};
const Comfy_PromptFilename$4 = {
  name: "Demander le nom du fichier lors de l'enregistrement du flux de travail"
};
const Comfy_QueueButton_BatchCountLimit$4 = {
  name: "Limite du nombre de lots",
  tooltip: "Le nombre maximum de tâches ajoutées à la file d'attente en un seul clic de bouton"
};
const Comfy_Queue_MaxHistoryItems$4 = {
  name: "Taille de l'historique de la file d'attente",
  tooltip: "Le nombre maximum de tâches qui s'affichent dans l'historique de la file d'attente."
};
const Comfy_RerouteBeta$4 = {
  name: "Participer au test bêta de reroute",
  tooltip: "Active les nouveaux reroutes natifs.\n\nLes reroutes peuvent être ajoutés en maintenant alt et en glissant à partir d'une ligne de lien, ou sur le menu de lien.\n\nLa désactivation de cette option est non destructive - les reroutes sont cachés."
};
const Comfy_Sidebar_Location$4 = {
  name: "Emplacement de la barre latérale",
  options: {
    left: "gauche",
    right: "droite"
  }
};
const Comfy_Sidebar_Size$4 = {
  name: "Taille de la barre latérale",
  options: {
    normal: "normal",
    small: "petit"
  }
};
const Comfy_SnapToGrid_GridSize$4 = {
  name: "Taille de la grille d'alignement",
  tooltip: "Lors du déplacement et du redimensionnement des nœuds tout en maintenant shift, ils seront alignés sur la grille, cela contrôle la taille de cette grille."
};
const Comfy_TextareaWidget_FontSize$4 = {
  name: "Taille de la police du widget de zone de texte"
};
const Comfy_TextareaWidget_Spellcheck$4 = {
  name: "Vérification orthographique du widget de zone de texte"
};
const Comfy_TreeExplorer_ItemPadding$4 = {
  name: "Espacement des éléments de l'explorateur d'arborescence"
};
const Comfy_UseNewMenu$4 = {
  name: "Utiliser le nouveau menu",
  options: {
    Bottom: "Bas",
    Disabled: "Désactivé",
    Top: "Haut"
  }
};
const Comfy_Validation_NodeDefs$4 = {
  name: "Valider les définitions de nœuds (lent)",
  tooltip: "Recommandé pour les développeurs de nœuds. Cela validera toutes les définitions de nœuds au démarrage."
};
const Comfy_Validation_Workflows$4 = {
  name: "Valider les flux de travail"
};
const Comfy_WidgetControlMode$4 = {
  name: "Mode de contrôle du widget",
  options: {
    after: "après",
    before: "avant"
  },
  tooltip: "Contrôle quand les valeurs du widget sont mises à jour (randomize/increment/decrement), soit avant que l'invite ne soit mise en file d'attente, soit après."
};
const Comfy_Window_UnloadConfirmation$4 = {
  name: "Afficher une confirmation lors de la fermeture de la fenêtre"
};
const Comfy_Workflow_ConfirmDelete$4 = {
  name: "Afficher une confirmation lors de la suppression des flux de travail"
};
const Comfy_Workflow_ShowMissingModelsWarning$4 = {
  name: "Afficher l'avertissement des modèles manquants"
};
const Comfy_Workflow_ShowMissingNodesWarning$4 = {
  name: "Afficher l'avertissement des nœuds manquants"
};
const Comfy_Workflow_SortNodeIdOnSave$4 = {
  name: "Trier les ID de nœuds lors de l'enregistrement du flux de travail"
};
const Comfy_Workflow_WorkflowTabsPosition$4 = {
  name: "Position des flux de travail ouverts",
  options: {
    Sidebar: "Barre latérale",
    Topbar: "Barre supérieure",
    "Topbar (2nd-row)": "Barre supérieure (2ème rangée)"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold$4 = {
  name: "Seuil de zoom pour le rendu de faible qualité",
  tooltip: "Rendre des formes de faible qualité lorsqu'on est dézoomé"
};
const LiteGraph_Canvas_MaximumFps$4 = {
  name: "FPS maximum",
  tooltip: "Le nombre maximum d'images par seconde que le canevas est autorisé à rendre. Limite l'utilisation du GPU au détriment de la fluidité. Si 0, le taux de rafraîchissement de l'écran est utilisé. Par défaut : 0"
};
const LiteGraph_ContextMenu_Scaling$4 = {
  name: "Mise à l'échelle des menus de widgets combinés de nœuds (listes) lors du zoom"
};
const LiteGraph_Node_TooltipDelay$4 = {
  name: "Délai d'infobulle"
};
const pysssss_SnapToGrid$4 = {
  name: "Toujours aligner sur la grille"
};
const frSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "Vérifier automatiquement les mises à jour"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "Envoyer des métriques d'utilisation anonymes"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "Miroir d'installation Pypi",
    tooltip: "Miroir d'installation pip par défaut"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Miroir d'installation Python",
    tooltip: "Les installations Python gérées sont téléchargées depuis le projet Astral python-build-standalone. Cette variable peut être définie sur une URL de miroir pour utiliser une source différente pour les installations Python. L'URL fournie remplacera https://github.com/astral-sh/python-build-standalone/releases/download dans, par exemple, https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gz. Les distributions peuvent être lues à partir d'un répertoire local en utilisant le schéma d'URL file://."
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "Miroir d'installation Torch",
    tooltip: "Miroir d'installation Pip pour pytorch"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "Style de fenêtre",
    options: {
      custom: "personnalisé",
      "default": "défaut"
    },
    tooltip: "Choisissez l'option personnalisée pour masquer la barre de titre du système"
  },
  Comfy_Canvas_SelectionToolbox: Comfy_Canvas_SelectionToolbox$4,
  Comfy_ConfirmClear: Comfy_ConfirmClear$4,
  Comfy_DOMClippingEnabled: Comfy_DOMClippingEnabled$4,
  Comfy_DevMode: Comfy_DevMode$4,
  Comfy_DisableFloatRounding: Comfy_DisableFloatRounding$4,
  Comfy_DisableSliders: Comfy_DisableSliders$4,
  Comfy_EditAttention_Delta: Comfy_EditAttention_Delta$4,
  Comfy_EnableTooltips: Comfy_EnableTooltips$4,
  Comfy_EnableWorkflowViewRestore: Comfy_EnableWorkflowViewRestore$4,
  Comfy_FloatRoundingPrecision: Comfy_FloatRoundingPrecision$4,
  Comfy_Graph_CanvasInfo: Comfy_Graph_CanvasInfo$4,
  Comfy_Graph_CanvasMenu: Comfy_Graph_CanvasMenu$4,
  Comfy_Graph_CtrlShiftZoom: Comfy_Graph_CtrlShiftZoom$4,
  Comfy_Graph_LinkMarkers: Comfy_Graph_LinkMarkers$4,
  Comfy_Graph_ZoomSpeed: Comfy_Graph_ZoomSpeed$4,
  Comfy_GroupSelectedNodes_Padding: Comfy_GroupSelectedNodes_Padding$4,
  Comfy_Group_DoubleClickTitleToEdit: Comfy_Group_DoubleClickTitleToEdit$4,
  Comfy_LinkRelease_Action: Comfy_LinkRelease_Action$4,
  Comfy_LinkRelease_ActionShift: Comfy_LinkRelease_ActionShift$4,
  Comfy_LinkRenderMode: Comfy_LinkRenderMode$4,
  Comfy_Locale: Comfy_Locale$4,
  Comfy_MaskEditor_BrushAdjustmentSpeed: Comfy_MaskEditor_BrushAdjustmentSpeed$4,
  Comfy_MaskEditor_UseDominantAxis: Comfy_MaskEditor_UseDominantAxis$4,
  Comfy_MaskEditor_UseNewEditor: Comfy_MaskEditor_UseNewEditor$4,
  Comfy_ModelLibrary_AutoLoadAll: Comfy_ModelLibrary_AutoLoadAll$4,
  Comfy_ModelLibrary_NameFormat: Comfy_ModelLibrary_NameFormat$4,
  Comfy_NodeBadge_NodeIdBadgeMode: Comfy_NodeBadge_NodeIdBadgeMode$4,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode: Comfy_NodeBadge_NodeLifeCycleBadgeMode$4,
  Comfy_NodeBadge_NodeSourceBadgeMode: Comfy_NodeBadge_NodeSourceBadgeMode$4,
  Comfy_NodeInputConversionSubmenus: Comfy_NodeInputConversionSubmenus$4,
  Comfy_NodeSearchBoxImpl: Comfy_NodeSearchBoxImpl$4,
  Comfy_NodeSearchBoxImpl_NodePreview: Comfy_NodeSearchBoxImpl_NodePreview$4,
  Comfy_NodeSearchBoxImpl_ShowCategory: Comfy_NodeSearchBoxImpl_ShowCategory$4,
  Comfy_NodeSearchBoxImpl_ShowIdName: Comfy_NodeSearchBoxImpl_ShowIdName$4,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency: Comfy_NodeSearchBoxImpl_ShowNodeFrequency$4,
  Comfy_NodeSuggestions_number: Comfy_NodeSuggestions_number$4,
  Comfy_Node_AutoSnapLinkToSlot: Comfy_Node_AutoSnapLinkToSlot$4,
  Comfy_Node_BypassAllLinksOnDelete: Comfy_Node_BypassAllLinksOnDelete$4,
  Comfy_Node_DoubleClickTitleToEdit: Comfy_Node_DoubleClickTitleToEdit$4,
  Comfy_Node_MiddleClickRerouteNode: Comfy_Node_MiddleClickRerouteNode$4,
  Comfy_Node_Opacity: Comfy_Node_Opacity$4,
  Comfy_Node_ShowDeprecated: Comfy_Node_ShowDeprecated$4,
  Comfy_Node_ShowExperimental: Comfy_Node_ShowExperimental$4,
  Comfy_Node_SnapHighlightsNode: Comfy_Node_SnapHighlightsNode$4,
  Comfy_Pointer_ClickBufferTime: Comfy_Pointer_ClickBufferTime$4,
  Comfy_Pointer_ClickDrift: Comfy_Pointer_ClickDrift$4,
  Comfy_Pointer_DoubleClickTime: Comfy_Pointer_DoubleClickTime$4,
  Comfy_PreviewFormat: Comfy_PreviewFormat$4,
  Comfy_PromptFilename: Comfy_PromptFilename$4,
  Comfy_QueueButton_BatchCountLimit: Comfy_QueueButton_BatchCountLimit$4,
  Comfy_Queue_MaxHistoryItems: Comfy_Queue_MaxHistoryItems$4,
  Comfy_RerouteBeta: Comfy_RerouteBeta$4,
  Comfy_Sidebar_Location: Comfy_Sidebar_Location$4,
  Comfy_Sidebar_Size: Comfy_Sidebar_Size$4,
  Comfy_SnapToGrid_GridSize: Comfy_SnapToGrid_GridSize$4,
  Comfy_TextareaWidget_FontSize: Comfy_TextareaWidget_FontSize$4,
  Comfy_TextareaWidget_Spellcheck: Comfy_TextareaWidget_Spellcheck$4,
  Comfy_TreeExplorer_ItemPadding: Comfy_TreeExplorer_ItemPadding$4,
  Comfy_UseNewMenu: Comfy_UseNewMenu$4,
  Comfy_Validation_NodeDefs: Comfy_Validation_NodeDefs$4,
  Comfy_Validation_Workflows: Comfy_Validation_Workflows$4,
  Comfy_WidgetControlMode: Comfy_WidgetControlMode$4,
  Comfy_Window_UnloadConfirmation: Comfy_Window_UnloadConfirmation$4,
  Comfy_Workflow_ConfirmDelete: Comfy_Workflow_ConfirmDelete$4,
  Comfy_Workflow_ShowMissingModelsWarning: Comfy_Workflow_ShowMissingModelsWarning$4,
  Comfy_Workflow_ShowMissingNodesWarning: Comfy_Workflow_ShowMissingNodesWarning$4,
  Comfy_Workflow_SortNodeIdOnSave: Comfy_Workflow_SortNodeIdOnSave$4,
  Comfy_Workflow_WorkflowTabsPosition: Comfy_Workflow_WorkflowTabsPosition$4,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold: LiteGraph_Canvas_LowQualityRenderingZoomThreshold$4,
  LiteGraph_Canvas_MaximumFps: LiteGraph_Canvas_MaximumFps$4,
  LiteGraph_ContextMenu_Scaling: LiteGraph_ContextMenu_Scaling$4,
  LiteGraph_Node_TooltipDelay: LiteGraph_Node_TooltipDelay$4,
  pysssss_SnapToGrid: pysssss_SnapToGrid$4
};
const Comfy_BrowseTemplates$3 = {
  label: "テンプレートを参照"
};
const Comfy_Canvas_DeleteSelectedItems$3 = {
  label: "選択したアイテムを削除"
};
const Comfy_Canvas_FitView$3 = {
  label: "選択したノードにビューを合わせる"
};
const Comfy_Canvas_ResetView$3 = {
  label: "ビューをリセット"
};
const Comfy_Canvas_ToggleLinkVisibility$3 = {
  label: "キャンバスのリンク表示を切り替える"
};
const Comfy_Canvas_ToggleLock$3 = {
  label: "キャンバスのロックを切り替える"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass$3 = {
  label: "選択したノードのバイパス/バイパス解除"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse$3 = {
  label: "選択したノードの折りたたみ/展開"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute$3 = {
  label: "選択したノードのミュート/ミュート解除"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin$3 = {
  label: "選択したノードのピン留め/ピン留め解除"
};
const Comfy_Canvas_ToggleSelected_Pin$3 = {
  label: "選択したアイテムのピン留め/ピン留め解除"
};
const Comfy_Canvas_ZoomIn$3 = {
  label: "ズームイン"
};
const Comfy_Canvas_ZoomOut$3 = {
  label: "ズームアウト"
};
const Comfy_ClearPendingTasks$3 = {
  label: "保留中のタスクをクリア"
};
const Comfy_ClearWorkflow$3 = {
  label: "ワークフローをクリア"
};
const Comfy_DuplicateWorkflow$3 = {
  label: "現在のワークフローを複製"
};
const Comfy_ExportWorkflow$3 = {
  label: "ワークフローをエクスポート"
};
const Comfy_ExportWorkflowAPI$3 = {
  label: "ワークフローをエクスポート（API形式）"
};
const Comfy_Feedback$3 = {
  label: "フィードバック"
};
const Comfy_Graph_FitGroupToContents$3 = {
  label: "グループを内容に合わせて調整"
};
const Comfy_Graph_GroupSelectedNodes$3 = {
  label: "選択したノードをグループ化"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode$3 = {
  label: "選択したノードをグループノードに変換"
};
const Comfy_GroupNode_ManageGroupNodes$3 = {
  label: "グループノードの管理"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes$3 = {
  label: "選択したグループノードのグループ解除"
};
const Comfy_Help_AboutComfyUI$3 = {
  label: "ComfyUIについてを開く"
};
const Comfy_Help_OpenComfyOrgDiscord$3 = {
  label: "Comfy-OrgのDiscordを開く"
};
const Comfy_Help_OpenComfyUIDocs$3 = {
  label: "ComfyUIのドキュメントを開く"
};
const Comfy_Help_OpenComfyUIForum$3 = {
  label: "Comfy-Orgフォーラムを開く"
};
const Comfy_Help_OpenComfyUIIssues$3 = {
  label: "ComfyUIの問題を開く"
};
const Comfy_Interrupt$3 = {
  label: "中断"
};
const Comfy_LoadDefaultWorkflow$3 = {
  label: "デフォルトのワークフローを読み込む"
};
const Comfy_Manager_CustomNodesManager$3 = {
  label: "カスタムノードマネージャ"
};
const Comfy_Manager_ToggleManagerProgressDialog$3 = {
  label: "プログレスダイアログの切り替え"
};
const Comfy_NewBlankWorkflow$3 = {
  label: "新しい空のワークフロー"
};
const Comfy_OpenClipspace$3 = {
  label: "クリップスペース"
};
const Comfy_OpenWorkflow$3 = {
  label: "ワークフローを開く"
};
const Comfy_QueuePrompt$3 = {
  label: "キュープロンプト"
};
const Comfy_QueuePromptFront$3 = {
  label: "キュープロンプト（フロント）"
};
const Comfy_Redo$3 = {
  label: "やり直す"
};
const Comfy_RefreshNodeDefinitions$3 = {
  label: "ノード定義を更新"
};
const Comfy_SaveWorkflow$3 = {
  label: "ワークフローを保存する"
};
const Comfy_SaveWorkflowAs$3 = {
  label: "名前を付けてワークフローを保存"
};
const Comfy_ShowSettingsDialog$3 = {
  label: "設定ダイアログを表示"
};
const Comfy_ToggleTheme$3 = {
  label: "テーマの切り替え（ダーク/ライト）"
};
const Comfy_Undo$3 = {
  label: "元に戻す"
};
const Workspace_CloseWorkflow$3 = {
  label: "現在のワークフローを閉じる"
};
const Workspace_NextOpenedWorkflow$3 = {
  label: "次の開いたワークフロー"
};
const Workspace_PreviousOpenedWorkflow$3 = {
  label: "前の開いたワークフロー"
};
const Workspace_SearchBox_Toggle$3 = {
  label: "検索ボックスの切り替え"
};
const Workspace_ToggleBottomPanel$3 = {
  label: "パネル下部の切り替え"
};
const Workspace_ToggleFocusMode$3 = {
  label: "フォーカスモードの切り替え"
};
const Workspace_ToggleSidebarTab_queue$3 = {
  label: "キューサイドバーの切り替え",
  tooltip: "キュー"
};
const Workspace_ToggleSidebarTab_workflows$3 = {
  label: "ワークフローサイドバーの切り替え",
  tooltip: "ワークフロー"
};
const jaCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "カスタムノードフォルダを開く"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "入力フォルダを開く"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "ログフォルダを開く"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "extra_model_paths.yamlを開く"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "モデルフォルダを開く"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "出力フォルダを開く"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "DevToolsを開く"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "デスクトップユーザーガイド"
  },
  "Comfy-Desktop_Quit": {
    label: "終了"
  },
  "Comfy-Desktop_Reinstall": {
    label: "再インストール"
  },
  "Comfy-Desktop_Restart": {
    label: "再起動"
  },
  Comfy_BrowseTemplates: Comfy_BrowseTemplates$3,
  Comfy_Canvas_DeleteSelectedItems: Comfy_Canvas_DeleteSelectedItems$3,
  Comfy_Canvas_FitView: Comfy_Canvas_FitView$3,
  Comfy_Canvas_ResetView: Comfy_Canvas_ResetView$3,
  Comfy_Canvas_ToggleLinkVisibility: Comfy_Canvas_ToggleLinkVisibility$3,
  Comfy_Canvas_ToggleLock: Comfy_Canvas_ToggleLock$3,
  Comfy_Canvas_ToggleSelectedNodes_Bypass: Comfy_Canvas_ToggleSelectedNodes_Bypass$3,
  Comfy_Canvas_ToggleSelectedNodes_Collapse: Comfy_Canvas_ToggleSelectedNodes_Collapse$3,
  Comfy_Canvas_ToggleSelectedNodes_Mute: Comfy_Canvas_ToggleSelectedNodes_Mute$3,
  Comfy_Canvas_ToggleSelectedNodes_Pin: Comfy_Canvas_ToggleSelectedNodes_Pin$3,
  Comfy_Canvas_ToggleSelected_Pin: Comfy_Canvas_ToggleSelected_Pin$3,
  Comfy_Canvas_ZoomIn: Comfy_Canvas_ZoomIn$3,
  Comfy_Canvas_ZoomOut: Comfy_Canvas_ZoomOut$3,
  Comfy_ClearPendingTasks: Comfy_ClearPendingTasks$3,
  Comfy_ClearWorkflow: Comfy_ClearWorkflow$3,
  Comfy_DuplicateWorkflow: Comfy_DuplicateWorkflow$3,
  Comfy_ExportWorkflow: Comfy_ExportWorkflow$3,
  Comfy_ExportWorkflowAPI: Comfy_ExportWorkflowAPI$3,
  Comfy_Feedback: Comfy_Feedback$3,
  Comfy_Graph_FitGroupToContents: Comfy_Graph_FitGroupToContents$3,
  Comfy_Graph_GroupSelectedNodes: Comfy_Graph_GroupSelectedNodes$3,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode: Comfy_GroupNode_ConvertSelectedNodesToGroupNode$3,
  Comfy_GroupNode_ManageGroupNodes: Comfy_GroupNode_ManageGroupNodes$3,
  Comfy_GroupNode_UngroupSelectedGroupNodes: Comfy_GroupNode_UngroupSelectedGroupNodes$3,
  Comfy_Help_AboutComfyUI: Comfy_Help_AboutComfyUI$3,
  Comfy_Help_OpenComfyOrgDiscord: Comfy_Help_OpenComfyOrgDiscord$3,
  Comfy_Help_OpenComfyUIDocs: Comfy_Help_OpenComfyUIDocs$3,
  Comfy_Help_OpenComfyUIForum: Comfy_Help_OpenComfyUIForum$3,
  Comfy_Help_OpenComfyUIIssues: Comfy_Help_OpenComfyUIIssues$3,
  Comfy_Interrupt: Comfy_Interrupt$3,
  Comfy_LoadDefaultWorkflow: Comfy_LoadDefaultWorkflow$3,
  Comfy_Manager_CustomNodesManager: Comfy_Manager_CustomNodesManager$3,
  Comfy_Manager_ToggleManagerProgressDialog: Comfy_Manager_ToggleManagerProgressDialog$3,
  Comfy_NewBlankWorkflow: Comfy_NewBlankWorkflow$3,
  Comfy_OpenClipspace: Comfy_OpenClipspace$3,
  Comfy_OpenWorkflow: Comfy_OpenWorkflow$3,
  Comfy_QueuePrompt: Comfy_QueuePrompt$3,
  Comfy_QueuePromptFront: Comfy_QueuePromptFront$3,
  Comfy_Redo: Comfy_Redo$3,
  Comfy_RefreshNodeDefinitions: Comfy_RefreshNodeDefinitions$3,
  Comfy_SaveWorkflow: Comfy_SaveWorkflow$3,
  Comfy_SaveWorkflowAs: Comfy_SaveWorkflowAs$3,
  Comfy_ShowSettingsDialog: Comfy_ShowSettingsDialog$3,
  Comfy_ToggleTheme: Comfy_ToggleTheme$3,
  Comfy_Undo: Comfy_Undo$3,
  Workspace_CloseWorkflow: Workspace_CloseWorkflow$3,
  Workspace_NextOpenedWorkflow: Workspace_NextOpenedWorkflow$3,
  Workspace_PreviousOpenedWorkflow: Workspace_PreviousOpenedWorkflow$3,
  Workspace_SearchBox_Toggle: Workspace_SearchBox_Toggle$3,
  Workspace_ToggleBottomPanel: Workspace_ToggleBottomPanel$3,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "ターミナルパネル下部の切り替え"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "ログパネル下部の切り替え"
  },
  Workspace_ToggleFocusMode: Workspace_ToggleFocusMode$3,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "モデルライブラリサイドバーの切り替え",
    tooltip: "モデルライブラリ"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "ノードライブラリサイドバーの切り替え",
    tooltip: "ノードライブラリ"
  },
  Workspace_ToggleSidebarTab_queue: Workspace_ToggleSidebarTab_queue$3,
  Workspace_ToggleSidebarTab_workflows: Workspace_ToggleSidebarTab_workflows$3
};
const clipboard$3 = {
  errorMessage: "クリップボードへのコピーに失敗しました",
  errorNotSupported: "お使いのブラウザではクリップボードAPIがサポートされていません",
  successMessage: "クリップボードにコピーしました"
};
const color$3 = {
  black: "黒",
  blue: "青",
  brown: "ブラウン",
  custom: "カスタム",
  cyan: "シアン",
  "default": "デフォルト",
  green: "緑",
  noColor: "色なし",
  pale_blue: "淡い青",
  pink: "ピンク",
  purple: "パープル",
  red: "赤",
  yellow: "黄色"
};
const contextMenu$3 = {
  " to input": " 入力へ",
  " to widget": " ウィジェットへ",
  "Add Group": "グループを追加",
  "Add Group For Selected Nodes": "選択したノードのグループを追加",
  "Add Node": "ノードを追加",
  Bypass: "バイパス",
  Clone: "クローン",
  Collapse: "折りたたむ",
  Colors: "色",
  "Convert ": "変換 ",
  "Convert Input to Widget": "入力をウィジェットに変換",
  "Convert Widget to Input": "ウィジェットを入力に変換",
  "Convert to Group Node": "グループノードに変換",
  "Copy (Clipspace)": "コピー (Clipspace)",
  Expand: "展開",
  Inputs: "入力",
  Manage: "管理",
  "Manage Group Nodes": "グループノードを管理",
  Mode: "モード",
  "Node Templates": "ノードテンプレート",
  Outputs: "出力",
  Pin: "ピン",
  Properties: "プロパティ",
  "Properties Panel": "プロパティパネル",
  Remove: "削除",
  Resize: "リサイズ",
  "Save Selected as Template": "選択したものをテンプレートとして保存",
  Search: "検索",
  Shapes: "形",
  Title: "タイトル",
  Unpin: "ピンを解除"
};
const dataTypes$3 = {
  AUDIO: "オーディオ",
  BOOLEAN: "ブール",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP_VISION",
  CLIP_VISION_OUTPUT: "CLIP_VISION_OUTPUT",
  COMBO: "コンボ",
  CONDITIONING: "条件付け",
  CONTROL_NET: "コントロールネット",
  FLOAT: "浮動小数点",
  FLOATS: "浮動小数点数",
  GLIGEN: "GLIGEN",
  GUIDER: "ガイダー",
  HOOKS: "フック",
  HOOK_KEYFRAMES: "フックキーフレーム",
  IMAGE: "画像",
  INT: "整数",
  LATENT: "潜在",
  LATENT_OPERATION: "潜在操作",
  LOAD_3D: "3Dをロード",
  LOAD_3D_ANIMATION: "3Dアニメーションをロード",
  MASK: "マスク",
  MESH: "メッシュ",
  MODEL: "モデル",
  NOISE: "ノイズ",
  PHOTOMAKER: "PHOTOMAKER",
  SAMPLER: "サンプラー",
  SIGMAS: "シグマ",
  STRING: "文字列",
  STYLE_MODEL: "スタイルモデル",
  TIMESTEPS_RANGE: "タイムステップの範囲",
  UPSCALE_MODEL: "アップスケールモデル",
  VAE: "VAE",
  VOXEL: "ボクセル",
  WEBCAM: "ウェブカメラ"
};
const desktopMenu$3 = {
  confirmQuit: "保存されていないワークフローを終了しようとしています。保存されていない変更はすべて失われます。これを無視して終了しますか？",
  confirmReinstall: "これにより、extra_models_config.yamlファイルがクリアされ、再インストールが開始されます。本当によろしいですか？",
  quit: "終了",
  reinstall: "再インストール"
};
const desktopUpdate$3 = {
  description: "ComfyUIデスクトップは新しい依存関係をインストールしています。これには数分かかる場合があります。",
  terminalDefaultMessage: "更新からの任意のコンソール出力はここに表示されます。",
  title: "ComfyUIデスクトップの更新"
};
const downloadGit$3 = {
  gitWebsite: "Gitをダウンロード",
  instructions: "お使いのオペレーティングシステムに最新のバージョンをダウンロードしてインストールしてください。以下の「Gitをダウンロード」ボタンをクリックすると、git-scm.comのダウンロードページが開きます。",
  message: "Gitを見つけることができません。正常に動作するためには、Gitの作業コピーが必要です。",
  skip: "スキップ",
  title: "Gitをダウンロード",
  warning: "Gitがインストールされていなくても問題ないと確信している場合、または間違いがあった場合は、「スキップ」をクリックしてこのチェックをスキップできます。作業コピーのない状態でComfyUIを実行することは現在サポートされていません。"
};
const electronFileDownload$3 = {
  cancel: "ダウンロードをキャンセル",
  cancelled: "キャンセルされました",
  inProgress: "ダウンロード中",
  pause: "ダウンロードを一時停止",
  paused: "一時停止",
  resume: "ダウンロードを再開"
};
const g$3 = {
  about: "情報",
  add: "追加",
  all: "すべて",
  apply: "適用する",
  back: "戻る",
  cancel: "キャンセル",
  capture: "キャプチャ",
  category: "カテゴリ",
  choose_file_to_upload: "アップロードするファイルを選択",
  close: "閉じる",
  color: "色",
  comingSoon: "近日公開",
  command: "コマンド",
  community: "コミュニティ",
  completed: "完了",
  confirm: "確認",
  "continue": "続ける",
  control_after_generate: "生成後の制御",
  control_before_generate: "生成前の制御",
  copyToClipboard: "クリップボードにコピー",
  currentUser: "現在のユーザー",
  customize: "カスタマイズ",
  customizeFolder: "フォルダーをカスタマイズ",
  "delete": "削除",
  deprecated: "非推奨",
  description: "説明",
  devices: "デバイス",
  disableAll: "すべて無効にする",
  download: "ダウンロード",
  empty: "空",
  enableAll: "すべて有効にする",
  enabled: "有効",
  error: "エラー",
  experimental: "ベータ",
  "export": "エクスポート",
  extensionName: "拡張機能名",
  feedback: "フィードバック",
  filter: "フィルタ",
  findIssues: "問題を見つける",
  firstTimeUIMessage: "新しいUIを初めて使用しています。「メニュー > 新しいメニューを使用 > 無効」を選択することで古いUIに戻すことが可能です。",
  goToNode: "ノードに移動",
  icon: "アイコン",
  imageFailedToLoad: "画像の読み込みに失敗しました",
  "import": "インポート",
  inProgress: "進行中",
  insert: "挿入",
  install: "インストール",
  installed: "インストール済み",
  installing: "インストール中",
  keybinding: "キーバインディング",
  loadAllFolders: "すべてのフォルダーを読み込む",
  loadWorkflow: "ワークフローを読み込む",
  loading: "読み込み中",
  logs: "ログ",
  missing: "不足している",
  name: "名前",
  newFolder: "新しいフォルダー",
  next: "次へ",
  no: "いいえ",
  noResultsFound: "結果が見つかりません",
  noTasksFound: "タスクが見つかりません",
  noTasksFoundMessage: "キューにタスクがありません。",
  noWorkflowsFound: "ワークフローが見つかりません。",
  nodes: "ノード",
  ok: "OK",
  openNewIssue: "新しい問題を開く",
  overwrite: "上書き",
  reconnected: "再接続されました",
  reconnecting: "再接続中",
  refresh: "更新",
  reloadToApplyChanges: "変更を適用するには再読み込みしてください",
  rename: "名前を変更",
  reportIssue: "報告する",
  reportIssueTooltip: "エラーレポートをComfy Orgに送信",
  reportSent: "レポートが送信されました",
  reset: "リセット",
  resetKeybindingsTooltip: "キーバインディングをデフォルトにリセット",
  restart: "再起動",
  resultsCount: "{count}件の結果が見つかりました",
  save: "保存",
  saving: "保存中",
  searchExtensions: "拡張機能を検索",
  searchFailedMessage: "検索に一致する設定が見つかりませんでした。検索キーワードを調整してみてください。",
  searchKeybindings: "キーバインディングを検索",
  searchModels: "モデルを検索",
  searchNodes: "ノードを検索",
  searchSettings: "設定を検索",
  searchWorkflows: "ワークフローを検索",
  settings: "設定",
  showReport: "レポートを表示",
  sort: "並び替え",
  status: "ステータス",
  success: "成功",
  systemInfo: "システム情報",
  terminal: "ターミナル",
  updated: "更新済み",
  upload: "アップロード",
  videoFailedToLoad: "ビデオの読み込みに失敗しました",
  workflow: "ワークフロー"
};
const graphCanvasMenu$3 = {
  fitView: "ビューに合わせる",
  panMode: "パンモード",
  resetView: "ビューをリセット",
  selectMode: "選択モード",
  toggleLinkVisibility: "リンクの表示切り替え",
  zoomIn: "拡大",
  zoomOut: "縮小"
};
const groupNode$3 = {
  create: "グループノードを作成",
  enterName: "名前を入力"
};
const icon$3 = {
  bookmark: "ブックマーク",
  box: "ボックス",
  briefcase: "ブリーフケース",
  "exclamation-triangle": "警告",
  file: "ファイル",
  folder: "フォルダー",
  heart: "ハート",
  inbox: "受信トレイ",
  star: "星"
};
const install$3 = {
  appDataLocationTooltip: "ComfyUIのアプリデータディレクトリ。保存内容:\n- ログ\n- サーバー設定",
  appPathLocationTooltip: "ComfyUIのアプリ資産ディレクトリ。ComfyUIのコードとアセットを保存します",
  cannotWrite: "選択したパスに書き込むことができません",
  chooseInstallationLocation: "インストール先を選択",
  customNodes: "カスタムノード",
  customNodesDescription: "既存のComfyUIインストールからカスタムノードを再インストールします。",
  desktopAppSettings: "デスクトップアプリの設定",
  desktopAppSettingsDescription: "ComfyUIのデスクトップでの動作を設定します。これらの設定は後で変更可能です。",
  desktopSettings: "デスクトップ設定",
  failedToSelectDirectory: "ディレクトリの選択に失敗しました",
  gpu: "GPU",
  gpuSelection: {
    cpuMode: "CPUモード",
    cpuModeDescription: "CPUモードは開発者や、まれなエッジケースのみを対象としています。",
    cpuModeDescription2: "これが絶対に必要であることが確定していない場合は、このボックスを無視して上でGPUを選択してください。",
    customComfyNeedsPython: "ComfyUIはpythonがセットアップされるまで動作しません",
    customInstallRequirements: "すべての要件と依存関係をインストールする（例：カスタムtorch）",
    customManualVenv: "python venvを手動で設定する",
    customMayNotWork: "これは完全にサポートされておらず、単純に動作しない場合があります。",
    customSkipsPython: "このオプションは通常のpythonセットアップをスキップします。",
    enableCpuMode: "CPUモードを有効にする",
    mpsDescription: "Apple Metal Performance Shadersは、pytorch nightlyを使用してサポートされています。",
    nvidiaDescription: "NVIDIAデバイスは、pytorch CUDAビルドを使用して直接サポートされています。",
    selectGpu: "GPUを選択",
    selectGpuDescription: "所有しているGPUのタイプを選択してください"
  },
  helpImprove: "ComfyUIの改善にご協力ください",
  installLocation: "インストール先",
  installLocationDescription: "ComfyUIのユーザーデータを保存するディレクトリを選択してください。Python環境が選択した場所にインストールされます。選択したディスクに約15GBの空き容量が必要です。",
  installLocationTooltip: "ComfyUIのユーザーデータディレクトリ。保存内容:\n- Python環境\n- モデル\n- カスタムノード\n",
  insufficientFreeSpace: "空き容量が不足しています - 最低限の空き容量",
  isOneDrive: "OneDriveにインストールすると問題が発生する可能性があります。非OneDriveの場所にインストールすることを強くお勧めします。",
  manualConfiguration: {
    createVenv: "次のディレクトリに仮想環境を作成する必要があります",
    requirements: "要件",
    restartWhenFinished: "仮想環境の設定が完了したら、ComfyUIを再起動してください。",
    title: "マニュアル設定",
    virtualEnvironmentPath: "仮想環境のパス"
  },
  metricsDisabled: "メトリクスを無効にする",
  metricsEnabled: "メトリクスを有効にする",
  migrateFromExistingInstallation: "既存のインストールから移行",
  migration: "移行",
  migrationOptional: "移行は任意です。既存のインストールがない場合、このステップをスキップできます。",
  migrationSourcePathDescription: "既存のComfyUIインストールがある場合、既存のユーザーファイルとモデルを新しいインストールにコピー/リンクすることができます。既存のComfyUIインストールは影響を受けません。",
  moreInfo: "詳しくはこちらをご覧ください",
  nonDefaultDrive: "ComfyUIをシステムドライブ（例：C:\\）にインストールしてください。異なるファイルシステムを持つドライブでは、予測不能な問題が発生する可能性があります。インストール後にモデルやその他のファイルを他のドライブに保存することができます。",
  parentMissing: "パスが存在しません - 最初に含まれるディレクトリを作成してください",
  pathExists: "ディレクトリはすでに存在します - すべてのデータをバックアップしたことを確認してください",
  pathValidationFailed: "パスの検証に失敗しました",
  privacyPolicy: "プライバシーポリシー",
  selectItemsToMigrate: "移行する項目を選択",
  settings: {
    allowMetrics: "使用状況のメトリクス",
    allowMetricsDescription: "匿名の使用状況メトリクスを送信してComfyUIを改善します。個人情報やワークフローの内容は収集されません。",
    autoUpdate: "自動更新",
    autoUpdateDescription: "更新が利用可能になると、自動的にダウンロードおよびインストールを行います。インストール前に通知が表示されます。",
    checkingMirrors: "Pythonミラーへのネットワークアクセスを確認中...",
    dataCollectionDialog: {
      collect: {
        errorReports: "エラーメッセージとスタックトレース",
        systemInfo: "ハードウェア、OSタイプ、アプリバージョン",
        userJourneyEvents: "ユーザージャーニーイベント"
      },
      doNotCollect: {
        customNodeConfigurations: "カスタムノードの設定",
        fileSystemInformation: "ファイルシステム情報",
        personalInformation: "個人情報",
        workflowContents: "ワークフローの内容"
      },
      title: "データ収集について",
      viewFullPolicy: "完全なポリシーを見る",
      whatWeCollect: "収集内容:",
      whatWeDoNotCollect: "収集しない内容:"
    },
    errorUpdatingConsent: "同意の更新エラー",
    errorUpdatingConsentDetail: "メトリクスの同意設定の更新に失敗しました",
    learnMoreAboutData: "データ収集の詳細を見る",
    mirrorSettings: "ミラー設定",
    mirrorsReachable: "Pythonミラーへのネットワークアクセスは良好です",
    mirrorsUnreachable: "一部のpythonミラーへのネットワークアクセスが悪い",
    pypiMirrorPlaceholder: "PyPIミラーURLを入力してください",
    pythonMirrorPlaceholder: "PythonミラーURLを入力してください"
  },
  systemLocations: "システムの場所",
  unhandledError: "未知のエラー",
  updateConsent: "以前、クラッシュレポートを報告することに同意していました。現在、バグの特定とアプリの改善を助けるためにイベントベースのメトリクスを追跡しています。個人を特定できる情報は収集されません。"
};
const issueReport$3 = {
  contactFollowUp: "フォローアップのために私に連絡する",
  feedbackTitle: "フィードバックを提供してComfyUIの改善にご協力ください",
  helpFix: "これを修正するのを助ける",
  notifyResolve: "解決したときに通知する",
  provideAdditionalDetails: "追加の詳細を提供する（オプション）",
  provideEmail: "あなたのメールアドレスを教えてください（オプション）",
  rating: "評価",
  stackTrace: "スタックトレース",
  submitErrorReport: "エラーレポートを提出する（オプション）",
  systemStats: "システム統計",
  validation: {
    invalidEmail: "有効なメールアドレスを入力してください",
    maxLength: "メッセージが長すぎます"
  }
};
const load3d$3 = {
  backgroundColor: "背景色",
  camera: "カメラ",
  edgeThreshold: "エッジ閾値",
  "export": "エクスポート",
  exportModel: "モデルをエクスポート",
  exportingModel: "モデルをエクスポート中...",
  fov: "FOV",
  light: "ライト",
  lightIntensity: "光の強度",
  loadingModel: "3Dモデルを読み込んでいます...",
  materialMode: "マテリアルモード",
  model: "モデル",
  previewOutput: "出力のプレビュー",
  removeBackgroundImage: "背景画像を削除",
  scene: "シーン",
  showGrid: "グリッドを表示",
  switchCamera: "カメラを切り替える",
  switchingMaterialMode: "マテリアルモードの切り替え中...",
  upDirection: "上方向",
  uploadBackgroundImage: "背景画像をアップロード"
};
const maintenance$3 = {
  None: "なし",
  OK: "OK",
  Skipped: "スキップされました",
  allOk: "問題は検出されませんでした。",
  confirmTitle: "よろしいですか？",
  consoleLogs: "コンソールログ",
  detected: "検出されました",
  error: {
    cannotContinue: "続行できません - エラーが残っています",
    defaultDescription: "メンテナンスタスクの実行中にエラーが発生しました。",
    taskFailed: "タスクの実行に失敗しました。",
    toastTitle: "タスクエラー"
  },
  refreshing: "更新中",
  showManual: "メンテナンスタスクを表示",
  status: "ステータス",
  terminalDefaultMessage: "トラブルシューティングコマンドを実行すると、出力はここに表示されます。",
  title: "メンテナンス"
};
const manager$3 = {
  createdBy: "作成者",
  dependencies: "依存関係",
  discoverCommunityContent: "コミュニティが作成したノードパック、拡張機能などを探す...",
  downloads: "ダウンロード",
  errorConnecting: "Comfy Node Registryへの接続エラー。",
  filter: {
    disabled: "無効",
    enabled: "有効",
    nodePack: "ノードパック"
  },
  inWorkflow: "ワークフロー内",
  infoPanelEmpty: "アイテムをクリックして情報を表示します",
  installSelected: "選択したものをインストール",
  lastUpdated: "最終更新日",
  latestVersion: "最新",
  license: "ライセンス",
  loadingVersions: "バージョンを読み込んでいます...",
  nightlyVersion: "ナイトリー",
  noDescription: "説明はありません",
  noResultsFound: "検索に一致する結果が見つかりませんでした。",
  nodePack: "ノードパック",
  packsSelected: "選択したパック",
  repository: "リポジトリ",
  restartToApplyChanges: "変更を適用するには、ComfyUIを再起動してください",
  searchPlaceholder: "検索",
  selectVersion: "バージョンを選択",
  sort: {
    downloads: "最も人気",
    rating: "評価"
  },
  status: {
    active: "アクティブ",
    banned: "禁止",
    deleted: "削除済み",
    flagged: "フラグ付き",
    pending: "保留中",
    unknown: "不明"
  },
  title: "カスタムノードマネージャ",
  totalNodes: "合計ノード数",
  tryAgainLater: "後ほど再試行してください。",
  tryDifferentSearch: "別の検索クエリを試してみてください。",
  uninstall: "アンインストール",
  uninstallSelected: "選択したものをアンインストール",
  uninstalling: "アンインストール中",
  update: "更新",
  version: "バージョン"
};
const maskEditor$3 = {
  "Apply to Whole Image": "全画像に適用",
  "Brush Settings": "ブラシ設定",
  "Brush Shape": "ブラシ形状",
  Clear: "クリア",
  "Color Select Settings": "色選択設定",
  "Fill Opacity": "塗りつぶしの不透明度",
  Hardness: "硬さ",
  "Image Layer": "画像レイヤー",
  Invert: "反転",
  Layers: "レイヤー",
  "Live Preview": "ライブプレビュー",
  "Mask Layer": "マスクレイヤー",
  "Mask Opacity": "マスクの不透明度",
  "Mask Tolerance": "マスクの許容範囲",
  Method: "方法",
  Opacity: "不透明度",
  "Paint Bucket Settings": "ペイントバケツ設定",
  "Reset to Default": "デフォルトにリセット",
  "Selection Opacity": "選択範囲の不透明度",
  "Smoothing Precision": "スムージング精度",
  "Stop at mask": "マスクで停止",
  Thickness: "厚さ",
  Tolerance: "許容範囲"
};
const menu$3 = {
  autoQueue: "自動キュー",
  batchCount: "バッチ数",
  batchCountTooltip: "ワークフロー生成回数",
  clear: "ワークフローをクリア",
  clipspace: "クリップスペースを開く",
  disabled: "無効",
  disabledTooltip: "ワークフローは自動的にキューに追加されません",
  execute: "実行",
  hideMenu: "メニューを隠す",
  instant: "即時",
  instantTooltip: "生成完了後すぐにキューに追加",
  interrupt: "現在の実行を中止",
  onChange: "変更時",
  onChangeTooltip: "変更が行われるとワークフローがキューに追加されます",
  refresh: "ノードを更新",
  resetView: "ビューをリセット",
  run: "実行する",
  runWorkflow: "ワークフローを実行する (Shiftで先頭にキュー)",
  runWorkflowFront: "ワークフローを実行する (先頭にキュー)",
  showMenu: "メニューを表示",
  toggleBottomPanel: "下部パネルを切り替え"
};
const menuLabels$3 = {
  "About ComfyUI": "ComfyUIについて",
  "Browse Templates": "テンプレートを参照",
  "Bypass/Unbypass Selected Nodes": "選択したノードのバイパス/バイパス解除",
  "Canvas Toggle Link Visibility": "キャンバスのリンク表示を切り替え",
  "Canvas Toggle Lock": "キャンバスのロックを切り替え",
  "Clear Pending Tasks": "保留中のタスクをクリア",
  "Clear Workflow": "ワークフローをクリア",
  Clipspace: "クリップスペース",
  "Close Current Workflow": "現在のワークフローを閉じる",
  "Collapse/Expand Selected Nodes": "選択したノードの折りたたみ/展開",
  "Comfy-Org Discord": "Comfy-Org Discord",
  "ComfyUI Docs": "ComfyUIのドキュメント",
  "ComfyUI Forum": "ComfyUI フォーラム",
  "ComfyUI Issues": "ComfyUIの問題",
  "Convert selected nodes to group node": "選択したノードをグループノードに変換",
  "Custom Nodes Manager": "カスタムノードマネージャ",
  "Delete Selected Items": "選択したアイテムを削除",
  "Desktop User Guide": "デスクトップユーザーガイド",
  "Duplicate Current Workflow": "現在のワークフローを複製",
  Edit: "編集",
  Export: "エクスポート",
  "Export (API)": "エクスポート (API)",
  "Fit Group To Contents": "グループを内容に合わせる",
  "Fit view to selected nodes": "選択したノードにビューを合わせる",
  "Give Feedback": "フィードバックを送る",
  "Group Selected Nodes": "選択したノードをグループ化",
  Help: "ヘルプ",
  Interrupt: "中断",
  "Load Default Workflow": "デフォルトワークフローを読み込む",
  "Manage group nodes": "グループノードを管理",
  "Mute/Unmute Selected Nodes": "選択したノードのミュート/ミュート解除",
  New: "新規",
  "Next Opened Workflow": "次に開いたワークフロー",
  Open: "開く",
  "Open Custom Nodes Folder": "カスタムノードフォルダを開く",
  "Open DevTools": "DevToolsを開く",
  "Open Inputs Folder": "入力フォルダを開く",
  "Open Logs Folder": "ログフォルダを開く",
  "Open Models Folder": "モデルフォルダを開く",
  "Open Outputs Folder": "出力フォルダを開く",
  "Open extra_model_paths_yaml": "extra_model_paths.yamlを開く",
  "Pin/Unpin Selected Items": "選択したアイテムのピン留め/ピン留め解除",
  "Pin/Unpin Selected Nodes": "選択したノードのピン留め/ピン留め解除",
  "Previous Opened Workflow": "前に開いたワークフロー",
  "Queue Prompt": "キューのプロンプト",
  "Queue Prompt (Front)": "キューのプロンプト (前面)",
  Quit: "終了",
  Redo: "やり直す",
  "Refresh Node Definitions": "ノード定義を更新",
  Reinstall: "再インストール",
  "Reset View": "ビューをリセット",
  Restart: "再起動",
  Save: "保存",
  "Save As": "名前を付けて保存",
  "Show Settings Dialog": "設定ダイアログを表示",
  "Toggle Bottom Panel": "下部パネルの切り替え",
  "Toggle Focus Mode": "フォーカスモードの切り替え",
  "Toggle Logs Bottom Panel": "ログパネル下部を切り替え",
  "Toggle Model Library Sidebar": "モデルライブラリサイドバーを切り替え",
  "Toggle Node Library Sidebar": "ノードライブラリサイドバーを切り替え",
  "Toggle Progress Dialog": "進行状況ダイアログの切り替え",
  "Toggle Queue Sidebar": "キューサイドバーを切り替え",
  "Toggle Search Box": "検索ボックスの切り替え",
  "Toggle Terminal Bottom Panel": "ターミナルパネル下部を切り替え",
  "Toggle Theme (Dark/Light)": "テーマを切り替え（ダーク/ライト）",
  "Toggle Workflows Sidebar": "ワークフローサイドバーを切り替え",
  Undo: "元に戻す",
  "Ungroup selected group nodes": "選択したグループノードのグループ解除",
  Workflow: "ワークフロー",
  "Zoom In": "ズームイン",
  "Zoom Out": "ズームアウト"
};
const missingModelsDialog$3 = {
  doNotAskAgain: "再度表示しない",
  missingModels: "モデルが見つかりません",
  missingModelsMessage: "グラフを読み込む際に、次のモデルが見つかりませんでした"
};
const nodeCategories$3 = {
  "3d": "3d",
  "3d_models": "3Dモデル",
  _for_testing: "_テスト用",
  advanced: "高度な機能",
  animation: "アニメーション",
  api: "API",
  attention_experiments: "アテンション実験",
  audio: "オーディオ",
  batch: "バッチ",
  clip: "クリップ",
  combine: "結合",
  compositing: "合成",
  "cond pair": "条件ペア",
  "cond single": "条件単体",
  conditioning: "条件付け",
  controlnet: "コントロールネット",
  create: "作成",
  custom_sampling: "カスタムサンプリング",
  debug: "デバッグ",
  deprecated: "非推奨",
  flux: "flux",
  gligen: "グライジェン",
  guidance: "ガイダンス",
  guiders: "ガイダー",
  hooks: "フック",
  image: "画像",
  inpaint: "インペイント",
  instructpix2pix: "インストラクションピクス2ピクス",
  latent: "潜在",
  loaders: "ローダー",
  ltxv: "LTXV",
  mask: "マスク",
  model: "モデル",
  model_merging: "モデルマージ",
  model_patches: "モデルパッチ",
  model_specific: "モデル特有",
  noise: "ノイズ",
  operations: "操作",
  photomaker: "photomaker",
  postprocessing: "ポストプロセッシング",
  preprocessors: "前処理",
  samplers: "サンプラー",
  sampling: "サンプリング",
  schedulers: "スケジューラー",
  scheduling: "スケジューリング",
  sd3: "SD3",
  sigmas: "シグマ",
  stable_cascade: "安定したカスケード",
  style_model: "スタイルモデル",
  transform: "変換",
  unet: "U-Net",
  upscale_diffusion: "アップスケール拡散",
  upscaling: "アップスケーリング",
  video: "ビデオ",
  video_models: "ビデオモデル"
};
const nodeTemplates$3 = {
  enterName: "名前を入力",
  saveAsTemplate: "テンプレートとして保存"
};
const notSupported$3 = {
  "continue": "続ける",
  continueTooltip: "私のデバイスはサポートされていると確信しています",
  learnMore: "詳細を見る",
  message: "以下のデバイスのみサポートされています:",
  reportIssue: "問題を報告",
  supportedDevices: {
    macos: "MacOS (M1以降)",
    windows: "Windows (CUDA対応のNvidia GPU)"
  },
  title: "お使いのデバイスはサポートされていません"
};
const serverConfig$3 = {
  modifiedConfigs: "以下のサーバー設定を変更しました。変更を適用するには再起動してください。",
  restart: "再起動",
  revertChanges: "変更を元に戻す"
};
const serverConfigCategories$3 = {
  Attention: "アテンション",
  CUDA: "CUDA",
  Cache: "キャッシュ",
  Directories: "ディレクトリ",
  General: "一般",
  Inference: "推論",
  Memory: "メモリ",
  Network: "ネットワーク",
  Preview: "プレビュー"
};
const serverConfigItems$3 = {
  "cache-classic": {
    name: "クラシックキャッシュシステムを使用する"
  },
  "cache-lru": {
    name: "最大Nノード結果をキャッシュするLRUキャッシングを使用する。",
    tooltip: "RAM/VRAMを多く使用する可能性があります。"
  },
  "cpu-vae": {
    name: "CPUでVAEを実行する"
  },
  "cross-attention-method": {
    name: "クロスアテンションメソッド"
  },
  "cuda-device": {
    name: "使用するCUDAデバイスインデックス"
  },
  "cuda-malloc": {
    name: "メモリ割り当てにCUDA mallocを使用する"
  },
  "default-hashing-function": {
    name: "モデルファイルのデフォルトハッシュ関数"
  },
  deterministic: {
    name: "可能な場合、PyTorchが遅い決定論的アルゴリズムを使用する。",
    tooltip: "これにより、すべてのケースで画像が決定論的になるわけではないことに注意してください。"
  },
  directml: {
    name: "DirectMLデバイスインデックス"
  },
  "disable-all-custom-nodes": {
    name: "すべてのカスタムノードの読み込みを無効にする。"
  },
  "disable-ipex-optimize": {
    name: "IPEX最適化を無効にする"
  },
  "disable-metadata": {
    name: "ファイルにプロンプトメタデータを保存しない。"
  },
  "disable-smart-memory": {
    name: "スマートメモリ管理を無効にする",
    tooltip: "ComfyUIがモデルをVRAMに保持する代わりに、通常のRAMに積極的にオフロードするように強制します。"
  },
  "disable-xformers": {
    name: "xFormers最適化を無効にする"
  },
  "dont-print-server": {
    name: "サーバー出力をコンソールに表示しない。"
  },
  "dont-upcast-attention": {
    name: "アテンションのアップキャストを防ぐ"
  },
  "enable-cors-header": {
    name: 'CORSヘッダーを有効にする: "*"を使用してすべてのオリジンを許可するか、ドメインを指定する'
  },
  fast: {
    name: "未テストの潜在的に品質を低下させる最適化を有効にする。"
  },
  "force-channels-last": {
    name: "チャネルを最後に強制するメモリ形式"
  },
  "force-upcast-attention": {
    name: "アテンションのアップキャストを強制する"
  },
  "global-precision": {
    name: "グローバル浮動小数点精度",
    tooltip: "グローバル浮動小数点精度"
  },
  "input-directory": {
    name: "入力ディレクトリ"
  },
  listen: {
    name: "ホスト：リッスンするIPアドレス"
  },
  "log-level": {
    name: "ログの冗長性レベル"
  },
  "max-upload-size": {
    name: "最大アップロードサイズ (MB)"
  },
  "output-directory": {
    name: "出力ディレクトリ"
  },
  port: {
    name: "ポート：リッスンするポート"
  },
  "preview-method": {
    name: "潜在プレビューに使用されるメソッド"
  },
  "preview-size": {
    name: "プレビュー画像のサイズ"
  },
  "reserve-vram": {
    name: "予約済みVRAM (GB)",
    tooltip: "OS/他のソフトウェアで使用するために予約したいVRAMの量をGB単位で設定します。デフォルトでは、OSに応じていくらかの量が予約されます。"
  },
  "text-encoder-precision": {
    name: "テキストエンコーダー精度",
    tooltip: "テキストエンコーダー精度"
  },
  "tls-certfile": {
    name: "TLS証明書ファイル: HTTPS用のTLS証明書ファイルのパス"
  },
  "tls-keyfile": {
    name: "TLSキーファイル: HTTPS用のTLSキーファイルのパス"
  },
  "unet-precision": {
    name: "UNET精度",
    tooltip: "UNET精度"
  },
  "vae-precision": {
    name: "VAE精度",
    tooltip: "VAE精度"
  },
  "vram-management": {
    name: "VRAM管理モード"
  }
};
const serverStart$3 = {
  openLogs: "ログを開く",
  process: {
    error: "ComfyUIデスクトップを起動できません",
    "initial-state": "読み込み中...",
    "python-setup": "Python環境を設定中...",
    ready: "完了中...",
    "starting-server": "ComfyUIサーバーを起動中..."
  },
  reportIssue: "問題を報告",
  showTerminal: "ターミナルを表示",
  troubleshoot: "トラブルシューティング"
};
const settingsCategories$3 = {
  About: "情報",
  Appearance: "外観",
  BrushAdjustment: "ブラシ調整",
  Canvas: "キャンバス",
  ColorPalette: "カラーパレット",
  Comfy: "Comfy",
  "Comfy-Desktop": "Comfyデスクトップ",
  ContextMenu: "コンテキストメニュー",
  CustomColorPalettes: "カスタムカラーパレット",
  DevMode: "開発モード",
  EditTokenWeight: "トークンの重みを編集",
  Extension: "拡張",
  General: "一般",
  Graph: "グラフ",
  Group: "グループ",
  Keybinding: "キー割り当て",
  Link: "リンク",
  LinkRelease: "リンク解除",
  LiteGraph: "Lite Graph",
  Locale: "ロケール",
  "Mask Editor": "マスクエディタ",
  Menu: "メニュー",
  ModelLibrary: "モデルライブラリ",
  NewEditor: "新しいエディタ",
  Node: "ノード",
  "Node Search Box": "ノード検索ボックス",
  "Node Widget": "ノードウィジェット",
  NodeInputConversionSubmenus: "ノード入力変換サブメニュー",
  NodeLibrary: "ノードライブラリ",
  Pointer: "ポインタ",
  Queue: "キュー",
  QueueButton: "キューボタン",
  RerouteBeta: "ルート変更ベータ",
  Server: "サーバー",
  "Server-Config": "サーバー設定",
  Settings: "設定",
  Sidebar: "サイドバー",
  "Tree Explorer": "ツリーエクスプローラー",
  UV: "UV",
  Validation: "検証",
  Window: "ウィンドウ",
  Workflow: "ワークフロー"
};
const sideToolbar$3 = {
  browseTemplates: "サンプルテンプレートを表示",
  downloads: "ダウンロード",
  logout: "ログアウト",
  modelLibrary: "モデルライブラリ",
  newBlankWorkflow: "新しい空のワークフローを作成",
  nodeLibrary: "ノードライブラリ",
  nodeLibraryTab: {
    sortOrder: "並び順"
  },
  openWorkflow: "ローカルでワークフローを開く",
  queue: "キュー",
  queueTab: {
    backToAllTasks: "すべてのタスクに戻る",
    clearPendingTasks: "保留中のタスクをクリア",
    containImagePreview: "画像プレビューを含める",
    coverImagePreview: "画像プレビューに合わせる",
    filter: "出力をフィルタ",
    filters: {
      hideCached: "キャッシュを非表示",
      hideCanceled: "キャンセル済みを非表示"
    },
    showFlatList: "フラットリストを表示"
  },
  themeToggle: "テーマの切り替え",
  workflowTab: {
    confirmDelete: "このワークフローを削除してもよろしいですか？",
    confirmDeleteTitle: "ワークフローを削除しますか？",
    confirmOverwrite: "以下のファイルはすでに存在します。上書きしますか？",
    confirmOverwriteTitle: "既存のファイルを上書きしますか？",
    deleteFailed: "ワークフローの削除を試みましたが、失敗しました。",
    deleteFailedTitle: "削除に失敗しました",
    deleted: "ワークフローが削除されました",
    dirtyClose: "以下のファイルが変更されました。閉じる前に保存しますか？",
    dirtyCloseHint: "Shiftキーを押しながら閉じると、プロンプトなしで閉じます",
    dirtyCloseTitle: "変更を保存しますか？",
    workflowTreeType: {
      bookmarks: "ブックマーク",
      browse: "ブラウズ",
      open: "開く"
    }
  },
  workflows: "ワークフロー"
};
const tabMenu$3 = {
  addToBookmarks: "ブックマークに追加",
  closeOtherTabs: "他のタブを閉じる",
  closeTab: "タブを閉じる",
  closeTabsToLeft: "左のタブを閉じる",
  closeTabsToRight: "右のタブを閉じる",
  duplicateTab: "タブを複製",
  removeFromBookmarks: "ブックマークから削除"
};
const templateWorkflows$3 = {
  category: {
    "3D": "3D",
    "Area Composition": "エリア構成",
    Audio: "オーディオ",
    Basics: "基本",
    "ComfyUI Examples": "ComfyUIの例",
    ControlNet: "ControlNet",
    "Custom Nodes": "カスタムノード",
    Flux: "Flux",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    Upscaling: "アップスケーリング",
    Video: "ビデオ"
  },
  template: {
    "3D": {
      "hunyuan-3d-multiview-elf": "Hunyuan3D マルチビュー",
      "hunyuan-3d-turbo": "Hunyuan3D ターボ",
      "hunyuan3d-non-multiview-train": "Hunyuan3D",
      stable_zero123_example: "Stable Zero123"
    },
    "Area Composition": {
      area_composition: "エリア構成",
      area_composition_reversed: "エリア構成反転",
      area_composition_square_area_for_subject: "主題のためのエリア構成スクエア"
    },
    Audio: {
      stable_audio_example: "Stable Audio"
    },
    Basics: {
      "default": "画像生成",
      embedding_example: "埋め込み",
      gligen_textbox_example: "Gligenテキストボックス",
      image2image: "画像から画像へ",
      inpain_model_outpainting: "InpaintモデルのOutpainting",
      inpaint_example: "Inpaint",
      lora: "Lora",
      lora_multiple: "Lora複数"
    },
    ControlNet: {
      "2_pass_pose_worship": "2 Pass Pose Worship",
      controlnet_example: "ControlNet",
      depth_controlnet: "Depth ControlNet",
      depth_t2i_adapter: "Depth T2Iアダプタ",
      mixing_controlnets: "ControlNetsの混合"
    },
    Flux: {
      flux_canny_model_example: "Flux Cannyモデル",
      flux_depth_lora_example: "Flux Depth Lora",
      flux_dev_checkpoint_example: "Flux Dev",
      flux_fill_inpaint_example: "Flux Inpaint",
      flux_fill_outpaint_example: "Flux Outpaint",
      flux_redux_model_example: "Flux Reduxモデル",
      flux_schnell: "Flux Schnell"
    },
    SD3_5: {
      sd3_5_large_blur: "SD3.5 ラージブラー",
      sd3_5_large_canny_controlnet_example: "SD3.5 ラージキャニーコントロールネット",
      sd3_5_large_depth: "SD3.5 ラージデプス",
      sd3_5_simple_example: "SD3.5 シンプル"
    },
    SDXL: {
      sdxl_refiner_prompt_example: "SDXL Refinerプロンプト",
      sdxl_revision_text_prompts: "SDXL Revisionテキストプロンプト",
      sdxl_revision_zero_positive: "SDXL Revisionゼロポジティブ",
      sdxl_simple_example: "SDXLシンプル",
      sdxlturbo_example: "SDXLターボ"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_esrgan_workflow: "HiresFix ESRGANワークフロー",
      hiresfix_latent_workflow: "HiresFix Latentワークフロー",
      latent_upscale_different_prompt_model: "Latent Upscale異なるプロンプトモデル"
    },
    Video: {
      hunyuan_video_text_to_video: "Hunyuanビデオテキストからビデオへ",
      image_to_video: "画像からビデオへ",
      image_to_video_wan: "Wan 2.1 画像からビデオへ",
      ltxv_image_to_video: "LTXV画像からビデオへ",
      ltxv_text_to_video: "LTXVテキストからビデオへ",
      mochi_text_to_video_example: "Mochiテキストからビデオへ",
      text_to_video_wan: "Wan 2.1 テキストからビデオへ",
      txt_to_image_to_video: "テキストから画像へ、画像からビデオへ"
    }
  },
  title: "テンプレートを利用して開始"
};
const userSelect$3 = {
  enterUsername: "ユーザー名を入力してください",
  existingUser: "既存のユーザー",
  newUser: "新しいユーザー",
  next: "次へ",
  selectUser: "ユーザーを選択"
};
const welcome$3 = {
  getStarted: "はじめる",
  title: "ComfyUIへようこそ"
};
const workflowService$3 = {
  enterFilename: "ファイル名を入力",
  exportWorkflow: "ワークフローをエクスポート",
  saveWorkflow: "ワークフローを保存"
};
const ja = {
  clipboard: clipboard$3,
  color: color$3,
  contextMenu: contextMenu$3,
  dataTypes: dataTypes$3,
  desktopMenu: desktopMenu$3,
  desktopUpdate: desktopUpdate$3,
  downloadGit: downloadGit$3,
  electronFileDownload: electronFileDownload$3,
  g: g$3,
  graphCanvasMenu: graphCanvasMenu$3,
  groupNode: groupNode$3,
  icon: icon$3,
  install: install$3,
  issueReport: issueReport$3,
  load3d: load3d$3,
  maintenance: maintenance$3,
  manager: manager$3,
  maskEditor: maskEditor$3,
  menu: menu$3,
  menuLabels: menuLabels$3,
  missingModelsDialog: missingModelsDialog$3,
  nodeCategories: nodeCategories$3,
  nodeTemplates: nodeTemplates$3,
  notSupported: notSupported$3,
  serverConfig: serverConfig$3,
  serverConfigCategories: serverConfigCategories$3,
  serverConfigItems: serverConfigItems$3,
  serverStart: serverStart$3,
  settingsCategories: settingsCategories$3,
  sideToolbar: sideToolbar$3,
  tabMenu: tabMenu$3,
  templateWorkflows: templateWorkflows$3,
  userSelect: userSelect$3,
  welcome: welcome$3,
  workflowService: workflowService$3
};
const AddNoise$3 = {
  display_name: "ノイズを追加",
  inputs: {
    latent_image: {
      name: "潜在イメージ"
    },
    model: {
      name: "モデル"
    },
    noise: {
      name: "ノイズ"
    },
    sigmas: {
      name: "シグマ"
    }
  }
};
const AlignYourStepsScheduler$3 = {
  display_name: "ステップを整列",
  inputs: {
    denoise: {
      name: "ノイズ除去"
    },
    model_type: {
      name: "モデルタイプ"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const BasicGuider$3 = {
  display_name: "基本ガイダー",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    },
    model: {
      name: "モデル"
    }
  }
};
const BasicScheduler$3 = {
  display_name: "基本スケジューラー",
  inputs: {
    denoise: {
      name: "ノイズ除去"
    },
    model: {
      name: "モデル"
    },
    scheduler: {
      name: "スケジューラ"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const BetaSamplingScheduler$3 = {
  display_name: "ベータサンプリングスケジューラー",
  inputs: {
    alpha: {
      name: "アルファ"
    },
    beta: {
      name: "ベータ"
    },
    model: {
      name: "モデル"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const CFGGuider$3 = {
  display_name: "CFGガイダー",
  inputs: {
    cfg: {
      name: "cfg"
    },
    model: {
      name: "モデル"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    }
  }
};
const CLIPAttentionMultiply$3 = {
  display_name: "CLIP注意の乗算",
  inputs: {
    clip: {
      name: "clip"
    },
    k: {
      name: "k"
    },
    out: {
      name: "出力"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const CLIPLoader$3 = {
  description: "[レシピ]\n\nstable_diffusion: clip-l\nstable_cascade: clip-g\nsd3: t5 / clip-g / clip-l\nstable_audio: t5\nmochi: t5\ncosmos: old t5 xxl",
  display_name: "CLIPを読み込む",
  inputs: {
    clip_name: {
      name: "clip名"
    },
    device: {
      name: "デバイス"
    },
    type: {
      name: "タイプ"
    }
  }
};
const CLIPMergeAdd$3 = {
  display_name: "CLIPマージ追加",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    }
  }
};
const CLIPMergeSimple$3 = {
  display_name: "CLIPマージシンプル",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    ratio: {
      name: "比率"
    }
  }
};
const CLIPMergeSubtract$3 = {
  display_name: "CLIPマージ減算",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    multiplier: {
      name: "乗数"
    }
  }
};
const CLIPSave$3 = {
  display_name: "CLIPを保存",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "ファイル名プレフィックス"
    }
  }
};
const CLIPSetLastLayer$3 = {
  display_name: "CLIPの最終層を設定",
  inputs: {
    clip: {
      name: "クリップ"
    },
    stop_at_clip_layer: {
      name: "クリップ_レイヤーで停止"
    }
  }
};
const CLIPTextEncode$3 = {
  description: "テキストプロンプトをCLIPモデルを使用してエンコードし、特定の画像を生成するために拡散モデルをガイドするために使用できる埋め込みに変換します。",
  display_name: "CLIPテキストエンコード（プロンプト）",
  inputs: {
    clip: {
      name: "クリップ",
      tooltip: "テキストのエンコードに使用されるCLIPモデル。"
    },
    text: {
      name: "テキスト",
      tooltip: "エンコードするテキスト。"
    }
  },
  outputs: {
    "0": {
      tooltip: "拡散モデルをガイドするために使用される埋め込まれたテキストを含む条件付け。"
    }
  }
};
const CLIPTextEncodeControlnet$3 = {
  display_name: "CLIPテキストエンコードコントロールネット",
  inputs: {
    clip: {
      name: "クリップ"
    },
    conditioning: {
      name: "コンディショニング"
    },
    text: {
      name: "テキスト"
    }
  }
};
const CLIPTextEncodeFlux$3 = {
  display_name: "CLIPテキストエンコードフラックス",
  inputs: {
    clip: {
      name: "クリップ"
    },
    clip_l: {
      name: "クリップ_l"
    },
    guidance: {
      name: "ガイダンス"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeHunyuanDiT$3 = {
  display_name: "CLIPテキストエンコードフンユアンDiT",
  inputs: {
    bert: {
      name: "bert"
    },
    clip: {
      name: "クリップ"
    },
    mt5xl: {
      name: "mt5xl"
    }
  }
};
const CLIPTextEncodeLumina2$3 = {
  description: "CLIPモデルを使用してシステムプロンプトとユーザープロンプトをエンコードし、特定の画像の生成をガイドするために使用できる埋め込みを生成します。",
  display_name: "CLIP Text Encode for Lumina2",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "テキストのエンコードに使用されるCLIPモデル。"
    },
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2は2種類のシステムプロンプトを提供します：Superior: あなたは、テキストプロンプトまたはユーザープロンプトに基づいて優れた画像と画像テキストの整列度を生成するためのアシスタントです。 Alignment: あなたは、テキストプロンプトに基づいて高品質の画像と最高度の画像テキストの整列度を生成するためのアシスタントです。"
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "エンコードするテキスト。"
    }
  },
  outputs: {
    "0": {
      tooltip: "拡散モデルをガイドするために使用される埋め込まれたテキストを含む条件付け。"
    }
  }
};
const CLIPTextEncodePixArtAlpha$3 = {
  description: "テキストをエンコードし、PixArt Alphaの解像度条件を設定します。PixArt Sigmaには適用されません。",
  display_name: "CLIPTextEncodePixArtAlpha",
  inputs: {
    clip: {
      name: "clip"
    },
    height: {
      name: "高さ"
    },
    text: {
      name: "テキスト"
    },
    width: {
      name: "幅"
    }
  }
};
const CLIPTextEncodeSD3$3 = {
  display_name: "CLIPテキストエンコードSD3",
  inputs: {
    clip: {
      name: "クリップ"
    },
    clip_g: {
      name: "クリップ_g"
    },
    clip_l: {
      name: "クリップ_l"
    },
    empty_padding: {
      name: "空のパディング"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeSDXL$3 = {
  display_name: "CLIPテキストエンコードSDXL",
  inputs: {
    clip: {
      name: "クリップ"
    },
    crop_h: {
      name: "crop_h"
    },
    crop_w: {
      name: "crop_w"
    },
    height: {
      name: "高さ"
    },
    target_height: {
      name: "目標の高さ"
    },
    target_width: {
      name: "目標の幅"
    },
    text_g: {
      name: "テキスト_g"
    },
    text_l: {
      name: "テキスト_l"
    },
    width: {
      name: "幅"
    }
  }
};
const CLIPTextEncodeSDXLRefiner$3 = {
  display_name: "CLIPテキストエンコードSDXLリファイナー",
  inputs: {
    ascore: {
      name: "ascore"
    },
    clip: {
      name: "クリップ"
    },
    height: {
      name: "高さ"
    },
    text: {
      name: "テキスト"
    },
    width: {
      name: "幅"
    }
  }
};
const CLIPVisionEncode$3 = {
  display_name: "CLIPビジョンエンコード",
  inputs: {
    clip_vision: {
      name: "クリップビジョン"
    },
    crop: {
      name: "クロップ"
    },
    image: {
      name: "画像"
    }
  }
};
const CLIPVisionLoader$3 = {
  display_name: "CLIPビジョンを読み込む",
  inputs: {
    clip_name: {
      name: "クリップ名"
    }
  }
};
const Canny$3 = {
  display_name: "キャニー",
  inputs: {
    high_threshold: {
      name: "高い閾値"
    },
    image: {
      name: "イメージ"
    },
    low_threshold: {
      name: "低い閾値"
    }
  }
};
const CheckpointLoader$3 = {
  display_name: "設定でチェックポイントを読み込む（非推奨）",
  inputs: {
    ckpt_name: {
      name: "ckpt名"
    },
    config_name: {
      name: "設定名"
    }
  }
};
const CheckpointLoaderSimple$3 = {
  description: "拡散モデルのチェックポイントを読み込みます。拡散モデルは潜在変数のノイズを除去するために使用されます。",
  display_name: "チェックポイントを読み込む",
  inputs: {
    ckpt_name: {
      name: "ckpt名",
      tooltip: "読み込むチェックポイント（モデル）の名前。"
    }
  },
  outputs: {
    "0": {
      tooltip: "潜在変数のデノイズに使用されるモデル。"
    },
    "1": {
      tooltip: "テキストプロンプトをエンコードするために使用されるCLIPモデル。"
    },
    "2": {
      tooltip: "画像を潜在空間にエンコードおよびデコードするために使用されるVAEモデル。"
    }
  }
};
const CheckpointSave$3 = {
  display_name: "チェックポイントを保存",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    model: {
      name: "モデル"
    },
    vae: {
      name: "vae"
    }
  }
};
const CombineHooks2$3 = {
  display_name: "フックを組み合わせる [2]",
  inputs: {
    hooks_A: {
      name: "フック_A"
    },
    hooks_B: {
      name: "フック_B"
    }
  }
};
const CombineHooks4$3 = {
  display_name: "フックを組み合わせる [4]",
  inputs: {
    hooks_A: {
      name: "フック_A"
    },
    hooks_B: {
      name: "フック_B"
    },
    hooks_C: {
      name: "フック_C"
    },
    hooks_D: {
      name: "フック_D"
    }
  }
};
const CombineHooks8$3 = {
  display_name: "フックを組み合わせる [8]",
  inputs: {
    hooks_A: {
      name: "フック_A"
    },
    hooks_B: {
      name: "フック_B"
    },
    hooks_C: {
      name: "フック_C"
    },
    hooks_D: {
      name: "フック_D"
    },
    hooks_E: {
      name: "フック_E"
    },
    hooks_F: {
      name: "フック_F"
    },
    hooks_G: {
      name: "フック_G"
    },
    hooks_H: {
      name: "フック_H"
    }
  }
};
const ConditioningAverage$3 = {
  display_name: "条件付け平均",
  inputs: {
    conditioning_from: {
      name: "条件付け元"
    },
    conditioning_to: {
      name: "条件付け先"
    },
    conditioning_to_strength: {
      name: "条件付け先の強度"
    }
  }
};
const ConditioningCombine$3 = {
  display_name: "条件付け（組み合わせ）",
  inputs: {
    conditioning_1: {
      name: "条件付け_1"
    },
    conditioning_2: {
      name: "条件付け_2"
    }
  }
};
const ConditioningConcat$3 = {
  display_name: "条件付け（連結）",
  inputs: {
    conditioning_from: {
      name: "条件付け元"
    },
    conditioning_to: {
      name: "条件付け先"
    }
  }
};
const ConditioningSetArea$3 = {
  display_name: "条件付け（エリア設定）",
  inputs: {
    conditioning: {
      name: "条件付け"
    },
    height: {
      name: "高さ"
    },
    strength: {
      name: "強度"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentage$3 = {
  display_name: "条件付け（パーセンテージでエリア設定）",
  inputs: {
    conditioning: {
      name: "条件付け"
    },
    height: {
      name: "高さ"
    },
    strength: {
      name: "強度"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentageVideo$3 = {
  display_name: "ビデオの条件設定エリアのパーセンテージ",
  inputs: {
    conditioning: {
      name: "条件設定"
    },
    height: {
      name: "高さ"
    },
    strength: {
      name: "強度"
    },
    temporal: {
      name: "時間的"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    }
  }
};
const ConditioningSetAreaStrength$3 = {
  display_name: "条件付けエリア強度",
  inputs: {
    conditioning: {
      name: "条件付け"
    },
    strength: {
      name: "強度"
    }
  }
};
const ConditioningSetDefaultCombine$3 = {
  display_name: "条件付けデフォルト組み合わせを設定",
  inputs: {
    cond: {
      name: "条件"
    },
    cond_DEFAULT: {
      name: "デフォルト条件"
    },
    hooks: {
      name: "フック"
    }
  }
};
const ConditioningSetMask$3 = {
  display_name: "条件付け（マスク設定）",
  inputs: {
    conditioning: {
      name: "条件付け"
    },
    mask: {
      name: "マスク"
    },
    set_cond_area: {
      name: "条件付けエリア設定"
    },
    strength: {
      name: "強度"
    }
  }
};
const ConditioningSetProperties$3 = {
  display_name: "条件付けプロパティ設定",
  inputs: {
    cond_NEW: {
      name: "新しい条件"
    },
    hooks: {
      name: "フック"
    },
    mask: {
      name: "マスク"
    },
    set_cond_area: {
      name: "条件付けエリア設定"
    },
    strength: {
      name: "強度"
    },
    timesteps: {
      name: "タイムステップ"
    }
  }
};
const ConditioningSetPropertiesAndCombine$3 = {
  display_name: "条件付けプロパティ設定と組み合わせ",
  inputs: {
    cond: {
      name: "条件"
    },
    cond_NEW: {
      name: "新しい条件"
    },
    hooks: {
      name: "フック"
    },
    mask: {
      name: "マスク"
    },
    set_cond_area: {
      name: "条件付けエリア設定"
    },
    strength: {
      name: "強度"
    },
    timesteps: {
      name: "タイムステップ"
    }
  }
};
const ConditioningSetTimestepRange$3 = {
  display_name: "条件付けタイムステップ範囲",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    },
    end: {
      name: "終了"
    },
    start: {
      name: "開始"
    }
  }
};
const ConditioningStableAudio$3 = {
  display_name: "ConditioningStableAudio",
  inputs: {
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    seconds_start: {
      name: "秒_開始"
    },
    seconds_total: {
      name: "秒_合計"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const ConditioningTimestepsRange$3 = {
  display_name: "タイムステップ範囲",
  inputs: {
    end_percent: {
      name: "終了パーセント"
    },
    start_percent: {
      name: "開始パーセント"
    }
  },
  outputs: {
    "1": {
      name: "範囲前"
    },
    "2": {
      name: "範囲後"
    }
  }
};
const ConditioningZeroOut$3 = {
  display_name: "条件付けゼロアウト",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    }
  }
};
const ControlNetApply$3 = {
  display_name: "ControlNetを適用（旧）",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    },
    control_net: {
      name: "コントロールネット"
    },
    image: {
      name: "画像"
    },
    strength: {
      name: "強度"
    }
  }
};
const ControlNetApplyAdvanced$3 = {
  display_name: "ControlNetを適用",
  inputs: {
    control_net: {
      name: "コントロールネット"
    },
    end_percent: {
      name: "終了パーセント"
    },
    image: {
      name: "画像"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    start_percent: {
      name: "開始パーセント"
    },
    strength: {
      name: "強度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const ControlNetApplySD3$3 = {
  display_name: "VAEでControlNetを適用",
  inputs: {
    control_net: {
      name: "コントロールネット"
    },
    end_percent: {
      name: "終了パーセント"
    },
    image: {
      name: "画像"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    start_percent: {
      name: "開始パーセント"
    },
    strength: {
      name: "強度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const ControlNetInpaintingAliMamaApply$3 = {
  display_name: "ControlNetインペインティングAliMamaを適用",
  inputs: {
    control_net: {
      name: "コントロールネット"
    },
    end_percent: {
      name: "終了パーセント"
    },
    image: {
      name: "画像"
    },
    mask: {
      name: "マスク"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    start_percent: {
      name: "開始パーセント"
    },
    strength: {
      name: "強度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const ControlNetLoader$3 = {
  display_name: "ControlNetモデルを読み込む",
  inputs: {
    control_net_name: {
      name: "コントロールネット名"
    }
  }
};
const CosmosImageToVideoLatent$3 = {
  display_name: "CosmosImageToVideoLatent",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    end_image: {
      name: "終了画像"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    start_image: {
      name: "開始画像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  }
};
const CreateHookKeyframe$3 = {
  display_name: "フックキーフレームを作成",
  inputs: {
    prev_hook_kf: {
      name: "前のフックキーフレーム"
    },
    start_percent: {
      name: "開始パーセント"
    },
    strength_mult: {
      name: "強度倍数"
    }
  },
  outputs: {
    "0": {
      name: "フックKF"
    }
  }
};
const CreateHookKeyframesFromFloats$3 = {
  display_name: "フックキーフレームを浮動小数点から作成",
  inputs: {
    end_percent: {
      name: "終了パーセント"
    },
    floats_strength: {
      name: "浮動小数点数の強度"
    },
    prev_hook_kf: {
      name: "前のフックキーフレーム"
    },
    print_keyframes: {
      name: "キーフレームを印刷"
    },
    start_percent: {
      name: "開始パーセント"
    }
  },
  outputs: {
    "0": {
      name: "フックKF"
    }
  }
};
const CreateHookKeyframesInterpolated$3 = {
  display_name: "フックキーフレームを補間",
  inputs: {
    end_percent: {
      name: "end_percent"
    },
    interpolation: {
      name: "補間"
    },
    keyframes_count: {
      name: "キーフレーム数"
    },
    prev_hook_kf: {
      name: "prev_hook_kf"
    },
    print_keyframes: {
      name: "キーフレームを印刷"
    },
    start_percent: {
      name: "start_percent"
    },
    strength_end: {
      name: "strength_end"
    },
    strength_start: {
      name: "strength_start"
    }
  },
  outputs: {
    "0": {
      name: "フックKF"
    }
  }
};
const CreateHookLora$3 = {
  display_name: "フックLoRAを作成",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    prev_hooks: {
      name: "prev_hooks"
    },
    strength_clip: {
      name: "strength_clip"
    },
    strength_model: {
      name: "strength_model"
    }
  }
};
const CreateHookLoraModelOnly$3 = {
  display_name: "フックLoRA（モデルのみ）",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    prev_hooks: {
      name: "prev_hooks"
    },
    strength_model: {
      name: "strength_model"
    }
  }
};
const CreateHookModelAsLora$3 = {
  display_name: "フックモデルをLoRAとして作成",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    },
    prev_hooks: {
      name: "prev_hooks"
    },
    strength_clip: {
      name: "strength_clip"
    },
    strength_model: {
      name: "strength_model"
    }
  }
};
const CreateHookModelAsLoraModelOnly$3 = {
  display_name: "フックモデルをLoRAとして作成（モデルのみ）",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    },
    prev_hooks: {
      name: "prev_hooks"
    },
    strength_model: {
      name: "strength_model"
    }
  }
};
const CropMask$3 = {
  display_name: "マスクをトリミング",
  inputs: {
    height: {
      name: "高さ"
    },
    mask: {
      name: "マスク"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const DiffControlNetLoader$3 = {
  display_name: "ControlNetモデルを読み込む（diff）",
  inputs: {
    control_net_name: {
      name: "control_net_name"
    },
    model: {
      name: "モデル"
    }
  }
};
const DifferentialDiffusion$3 = {
  display_name: "差分拡散",
  inputs: {
    model: {
      name: "モデル"
    }
  }
};
const DiffusersLoader$3 = {
  display_name: "ディフューザーを読み込む",
  inputs: {
    model_path: {
      name: "モデルパス"
    }
  }
};
const DisableNoise$3 = {
  display_name: "ノイズを無効にする"
};
const DualCFGGuider$3 = {
  display_name: "デュアルCFGガイダー",
  inputs: {
    cfg_cond2_negative: {
      name: "cfg_cond2_negative"
    },
    cfg_conds: {
      name: "cfg_conds"
    },
    cond1: {
      name: "cond1"
    },
    cond2: {
      name: "cond2"
    },
    model: {
      name: "モデル"
    },
    negative: {
      name: "ネガティブ"
    }
  }
};
const DualCLIPLoader$3 = {
  description: "[レシピ]\n\nsdxl: clip-l, clip-g\nsd3: clip-l, clip-g / clip-l, t5 / clip-g, t5\nflux: clip-l, t5",
  display_name: "デュアルCLIPを読み込む",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    device: {
      name: "デバイス"
    },
    type: {
      name: "タイプ"
    }
  }
};
const EmptyCosmosLatentVideo$3 = {
  display_name: "EmptyCosmosLatentVideo",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    width: {
      name: "幅"
    }
  }
};
const EmptyHunyuanLatentVideo$3 = {
  display_name: "EmptyHunyuanLatentVideo",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    width: {
      name: "幅"
    }
  }
};
const EmptyImage$3 = {
  display_name: "空の画像",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    color: {
      name: "色"
    },
    height: {
      name: "高さ"
    },
    width: {
      name: "幅"
    }
  }
};
const EmptyLTXVLatentVideo$3 = {
  display_name: "空のLTXV潜在ビデオ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    width: {
      name: "幅"
    }
  }
};
const EmptyLatentAudio$3 = {
  display_name: "空の潜在音声",
  inputs: {
    batch_size: {
      name: "バッチサイズ",
      tooltip: "バッチ内の潜在画像の数。"
    },
    seconds: {
      name: "秒"
    }
  }
};
const EmptyLatentHunyuan3Dv2$3 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    batch_size: {
      name: "バッチサイズ",
      tooltip: "バッチ内の潜在画像の数。"
    },
    resolution: {
      name: "解像度"
    }
  }
};
const EmptyLatentImage$3 = {
  description: "サンプリングを通じてノイズを除去するための空の潜在画像の新しいバッチを作成します。",
  display_name: "空の潜在画像",
  inputs: {
    batch_size: {
      name: "バッチサイズ",
      tooltip: "バッチ内の潜在画像の数。"
    },
    height: {
      name: "高さ",
      tooltip: "潜在画像の高さ（ピクセル単位）。"
    },
    width: {
      name: "幅",
      tooltip: "潜在画像の幅（ピクセル単位）。"
    }
  },
  outputs: {
    "0": {
      tooltip: "空の潜在画像バッチ。"
    }
  }
};
const EmptyMochiLatentVideo$3 = {
  display_name: "空のMochi潜在ビデオ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    width: {
      name: "幅"
    }
  }
};
const EmptySD3LatentImage$3 = {
  display_name: "空のSD3潜在画像",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    width: {
      name: "幅"
    }
  }
};
const ExponentialScheduler$3 = {
  display_name: "指数スケジューラー",
  inputs: {
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const FeatherMask$3 = {
  display_name: "フェザー マスク",
  inputs: {
    bottom: {
      name: "下"
    },
    left: {
      name: "左"
    },
    mask: {
      name: "マスク"
    },
    right: {
      name: "右"
    },
    top: {
      name: "上"
    }
  }
};
const FlipSigmas$3 = {
  display_name: "シグマを反転",
  inputs: {
    sigmas: {
      name: "sigmas"
    }
  }
};
const FluxDisableGuidance$3 = {
  description: "このノードはFluxおよびFluxのようなモデルのガイダンス埋め込みを完全に無効にします",
  display_name: "FluxDisableGuidance",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const FluxGuidance$3 = {
  display_name: "フラックスガイダンス",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    },
    guidance: {
      name: "ガイダンス"
    }
  }
};
const FreeU$3 = {
  display_name: "FreeU",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "モデル"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2$3 = {
  display_name: "FreeU_V2",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "モデル"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler$3 = {
  display_name: "GITSスケジューラー",
  inputs: {
    coeff: {
      name: "係数"
    },
    denoise: {
      name: "ノイズ除去"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const GLIGENLoader$3 = {
  display_name: "GLIGENを読み込む",
  inputs: {
    gligen_name: {
      name: "gligen_name"
    }
  }
};
const GLIGENTextBoxApply$3 = {
  display_name: "GLIGENテキストボックスを適用",
  inputs: {
    clip: {
      name: "クリップ"
    },
    conditioning_to: {
      name: "条件付け先"
    },
    gligen_textbox_model: {
      name: "gligen_textbox_model"
    },
    height: {
      name: "高さ"
    },
    text: {
      name: "テキスト"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask$3 = {
  display_name: "マスクを拡大",
  inputs: {
    expand: {
      name: "拡大"
    },
    mask: {
      name: "マスク"
    },
    tapered_corners: {
      name: "テーパードコーナー"
    }
  }
};
const Hunyuan3Dv2Conditioning$3 = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "clip_vision_output"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView$3 = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    back: {
      name: "バック"
    },
    front: {
      name: "フロント"
    },
    left: {
      name: "左"
    },
    right: {
      name: "右"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const HunyuanImageToVideo$3 = {
  display_name: "HunyuanImageToVideo",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    guidance_type: {
      name: "ガイダンスタイプ"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    positive: {
      name: "ポジティブ"
    },
    start_image: {
      name: "開始画像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "潜在"
    }
  }
};
const HyperTile$3 = {
  display_name: "ハイパータイル",
  inputs: {
    max_depth: {
      name: "最大深度"
    },
    model: {
      name: "モデル"
    },
    scale_depth: {
      name: "スケール深度"
    },
    swap_size: {
      name: "スワップサイズ"
    },
    tile_size: {
      name: "タイルサイズ"
    }
  }
};
const HypernetworkLoader$3 = {
  display_name: "ハイパーネットワークを読み込む",
  inputs: {
    hypernetwork_name: {
      name: "hypernetwork_name"
    },
    model: {
      name: "モデル"
    },
    strength: {
      name: "強度"
    }
  }
};
const ImageBatch$3 = {
  display_name: "画像バッチ",
  inputs: {
    image1: {
      name: "画像1"
    },
    image2: {
      name: "画像2"
    }
  }
};
const ImageBlend$3 = {
  display_name: "画像ブレンド",
  inputs: {
    blend_factor: {
      name: "ブレンドファクター"
    },
    blend_mode: {
      name: "ブレンドモード"
    },
    image1: {
      name: "画像1"
    },
    image2: {
      name: "画像2"
    }
  }
};
const ImageBlur$3 = {
  display_name: "画像ぼかし",
  inputs: {
    blur_radius: {
      name: "ブラーレイディウス"
    },
    image: {
      name: "画像"
    },
    sigma: {
      name: "シグマ"
    }
  }
};
const ImageColorToMask$3 = {
  display_name: "画像色をマスクに変換",
  inputs: {
    color: {
      name: "色"
    },
    image: {
      name: "画像"
    }
  }
};
const ImageCompositeMasked$3 = {
  display_name: "マスクされた画像合成",
  inputs: {
    destination: {
      name: "宛先"
    },
    mask: {
      name: "マスク"
    },
    resize_source: {
      name: "ソースのリサイズ"
    },
    source: {
      name: "ソース"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageCrop$3 = {
  display_name: "画像トリミング",
  inputs: {
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch$3 = {
  display_name: "バッチから画像を取得",
  inputs: {
    batch_index: {
      name: "バッチインデックス"
    },
    image: {
      name: "画像"
    },
    length: {
      name: "長さ"
    }
  }
};
const ImageInvert$3 = {
  display_name: "画像を反転",
  inputs: {
    image: {
      name: "画像"
    }
  }
};
const ImageOnlyCheckpointLoader$3 = {
  display_name: "画像のみのチェックポイントローダー（img2vidモデル）",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    }
  }
};
const ImageOnlyCheckpointSave$3 = {
  display_name: "画像のみのチェックポイント保存",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    model: {
      name: "モデル"
    },
    vae: {
      name: "vae"
    }
  }
};
const ImagePadForOutpaint$3 = {
  display_name: "アウトペイント用に画像をパッド",
  inputs: {
    bottom: {
      name: "下"
    },
    feathering: {
      name: "フェザリング"
    },
    image: {
      name: "画像"
    },
    left: {
      name: "左"
    },
    right: {
      name: "右"
    },
    top: {
      name: "上"
    }
  }
};
const ImageQuantize$3 = {
  display_name: "画像を量子化",
  inputs: {
    colors: {
      name: "色"
    },
    dither: {
      name: "ディザリング"
    },
    image: {
      name: "画像"
    }
  }
};
const ImageScale$3 = {
  display_name: "画像を拡大",
  inputs: {
    crop: {
      name: "クロップ"
    },
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    upscale_method: {
      name: "拡大方法"
    },
    width: {
      name: "幅"
    }
  }
};
const ImageScaleBy$3 = {
  display_name: "画像を拡大（指定サイズ）",
  inputs: {
    image: {
      name: "画像"
    },
    scale_by: {
      name: "スケールバイ"
    },
    upscale_method: {
      name: "拡大方法"
    }
  }
};
const ImageScaleToTotalPixels$3 = {
  display_name: "画像を総ピクセルにスケール",
  inputs: {
    image: {
      name: "画像"
    },
    megapixels: {
      name: "メガピクセル"
    },
    upscale_method: {
      name: "拡大方法"
    }
  }
};
const ImageSharpen$3 = {
  display_name: "画像をシャープ化",
  inputs: {
    alpha: {
      name: "アルファ"
    },
    image: {
      name: "画像"
    },
    sharpen_radius: {
      name: "シャープ化半径"
    },
    sigma: {
      name: "シグマ"
    }
  }
};
const ImageToMask$3 = {
  display_name: "画像をマスクに変換",
  inputs: {
    channel: {
      name: "チャンネル"
    },
    image: {
      name: "画像"
    }
  }
};
const ImageUpscaleWithModel$3 = {
  display_name: "モデルを使用して画像を拡大",
  inputs: {
    image: {
      name: "画像"
    },
    upscale_model: {
      name: "拡大モデル"
    }
  }
};
const InpaintModelConditioning$3 = {
  display_name: "インペイントモデル条件付け",
  inputs: {
    mask: {
      name: "マスク"
    },
    negative: {
      name: "ネガティブ"
    },
    noise_mask: {
      name: "ノイズマスク",
      tooltip: "潜在にノイズマスクを追加し、サンプリングがマスク内でのみ行われるようにします。モデルによっては結果が改善されるか、完全に壊れる可能性があります。"
    },
    pixels: {
      name: "ピクセル"
    },
    positive: {
      name: "ポジティブ"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const InstructPixToPixConditioning$3 = {
  display_name: "PixToPix条件付け",
  inputs: {
    negative: {
      name: "ネガティブ"
    },
    pixels: {
      name: "ピクセル"
    },
    positive: {
      name: "ポジティブ"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const InvertMask$3 = {
  display_name: "マスクを反転",
  inputs: {
    mask: {
      name: "マスク"
    }
  }
};
const JoinImageWithAlpha$3 = {
  display_name: "アルファで画像を結合",
  inputs: {
    alpha: {
      name: "アルファ"
    },
    image: {
      name: "画像"
    }
  }
};
const KSampler$3 = {
  description: "提供されたモデル、正の条件付けと負の条件付けを使用して潜在画像のノイズを除去します。",
  display_name: "Kサンプラー",
  inputs: {
    cfg: {
      name: "cfg",
      tooltip: "Classifier-Free Guidanceスケールは、創造性とプロンプトへの遵守のバランスを取ります。値が高いほど、生成される画像はプロンプトにより近くなりますが、値が高すぎると品質に悪影響を及ぼす可能性があります。"
    },
    control_after_generate: {
      name: "生成後の制御"
    },
    denoise: {
      name: "ノイズ除去",
      tooltip: "適用されるデノイズの量。値が低いほど、初期画像の構造を維持し、画像から画像へのサンプリングが可能になります。"
    },
    latent_image: {
      name: "潜在画像",
      tooltip: "デノイズする潜在画像。"
    },
    model: {
      name: "モデル",
      tooltip: "入力潜在のデノイズに使用されるモデル。"
    },
    negative: {
      name: "ネガティブ",
      tooltip: "画像から除外したい属性を説明する条件付け。"
    },
    positive: {
      name: "ポジティブ",
      tooltip: "画像に含めたい属性を説明する条件付け。"
    },
    sampler_name: {
      name: "サンプラー名",
      tooltip: "サンプリング時に使用されるアルゴリズムで、生成される出力の品質、速度、スタイルに影響を与える可能性があります。"
    },
    scheduler: {
      name: "スケジューラ",
      tooltip: "スケジューラは、ノイズが徐々に除去されて画像が形成される方法を制御します。"
    },
    seed: {
      name: "シード",
      tooltip: "ノイズを生成するために使用されるランダムシード。"
    },
    steps: {
      name: "ステップ",
      tooltip: "デノイズプロセスで使用されるステップ数。"
    }
  },
  outputs: {
    "0": {
      tooltip: "デノイズされた潜在変数。"
    }
  }
};
const KSamplerAdvanced$3 = {
  display_name: "Kサンプラー（高度）",
  inputs: {
    add_noise: {
      name: "ノイズ追加"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "生成後の制御"
    },
    end_at_step: {
      name: "ステップ終了"
    },
    latent_image: {
      name: "潜在画像"
    },
    model: {
      name: "モデル"
    },
    negative: {
      name: "ネガティブ"
    },
    noise_seed: {
      name: "ノイズシード"
    },
    positive: {
      name: "ポジティブ"
    },
    return_with_leftover_noise: {
      name: "残りのノイズと一緒に返す"
    },
    sampler_name: {
      name: "サンプラー名"
    },
    scheduler: {
      name: "スケジューラ"
    },
    start_at_step: {
      name: "ステップ開始"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const KSamplerSelect$3 = {
  display_name: "Kサンプラー選択",
  inputs: {
    sampler_name: {
      name: "サンプラー名"
    }
  }
};
const KarrasScheduler$3 = {
  display_name: "カラススケジューラー",
  inputs: {
    rho: {
      name: "ロー"
    },
    sigma_max: {
      name: "シグマ_最大"
    },
    sigma_min: {
      name: "シグマ_最小"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const LTXVAddGuide$3 = {
  display_name: "LTXVAddGuide",
  inputs: {
    frame_idx: {
      name: "フレームインデックス",
      tooltip: "条件付けを開始するフレームインデックス。単一フレームの画像や1-8フレームのビデオの場合、任意のframe_idx値が許容されます。9フレーム以上のビデオの場合、frame_idxは8で割り切れる数でなければならず、そうでない場合は最も近い8の倍数に切り捨てられます。負の値はビデオの終わりから数えます。"
    },
    image: {
      name: "画像",
      tooltip: "潜在ビデオの条件付けに使用する画像またはビデオ。フレーム数は8*n + 1でなければなりません。ビデオが8*n + 1フレームでない場合、最も近い8*n + 1フレームに切り取られます。"
    },
    latent: {
      name: "潜在"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    strength: {
      name: "強度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const LTXVConditioning$3 = {
  display_name: "LTXV条件付け",
  inputs: {
    frame_rate: {
      name: "フレームレート"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const LTXVCropGuides$3 = {
  display_name: "LTXVCropGuides",
  inputs: {
    latent: {
      name: "潜在"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const LTXVImgToVideo$3 = {
  display_name: "LTXV画像からビデオへ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    length: {
      name: "長さ"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const LTXVPreprocess$3 = {
  display_name: "LTXVPreprocess",
  inputs: {
    image: {
      name: "画像"
    },
    img_compression: {
      name: "画像圧縮",
      tooltip: "画像に適用する圧縮の量。"
    }
  },
  outputs: {
    "0": {
      name: "出力画像"
    }
  }
};
const LTXVScheduler$3 = {
  display_name: "LTXVスケジューラー",
  inputs: {
    base_shift: {
      name: "基本シフト"
    },
    latent: {
      name: "潜在"
    },
    max_shift: {
      name: "最大シフト"
    },
    steps: {
      name: "ステップ"
    },
    stretch: {
      name: "ストレッチ",
      tooltip: "シグマを[terminal, 1]の範囲に伸ばします。"
    },
    terminal: {
      name: "端末",
      tooltip: "ストレッチ後のシグマの端末値。"
    }
  }
};
const LaplaceScheduler$3 = {
  display_name: "ラプラススケジューラー",
  inputs: {
    beta: {
      name: "ベータ"
    },
    mu: {
      name: "ミュー"
    },
    sigma_max: {
      name: "シグマ_最大"
    },
    sigma_min: {
      name: "シグマ_最小"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const LatentAdd$3 = {
  display_name: "潜在追加",
  inputs: {
    samples1: {
      name: "サンプル1"
    },
    samples2: {
      name: "サンプル2"
    }
  }
};
const LatentApplyOperation$3 = {
  display_name: "潜在操作を適用",
  inputs: {
    operation: {
      name: "操作"
    },
    samples: {
      name: "サンプル"
    }
  }
};
const LatentApplyOperationCFG$3 = {
  display_name: "潜在操作CFGを適用",
  inputs: {
    model: {
      name: "モデル"
    },
    operation: {
      name: "操作"
    }
  }
};
const LatentBatch$3 = {
  display_name: "潜在バッチ",
  inputs: {
    samples1: {
      name: "サンプル1"
    },
    samples2: {
      name: "サンプル2"
    }
  }
};
const LatentBatchSeedBehavior$3 = {
  display_name: "潜在バッチシード動作",
  inputs: {
    samples: {
      name: "サンプル"
    },
    seed_behavior: {
      name: "シード行動"
    }
  }
};
const LatentBlend$3 = {
  display_name: "潜在ブレンド",
  inputs: {
    blend_factor: {
      name: "ブレンド係数"
    },
    samples1: {
      name: "サンプル1"
    },
    samples2: {
      name: "サンプル2"
    }
  }
};
const LatentComposite$3 = {
  display_name: "潜在合成",
  inputs: {
    feather: {
      name: "フェザー"
    },
    samples_from: {
      name: "samples_from"
    },
    samples_to: {
      name: "samples_to"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCompositeMasked$3 = {
  display_name: "マスクされた潜在合成",
  inputs: {
    destination: {
      name: "destination"
    },
    mask: {
      name: "マスク"
    },
    resize_source: {
      name: "resize_source"
    },
    source: {
      name: "source"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCrop$3 = {
  display_name: "潜在トリミング",
  inputs: {
    height: {
      name: "高さ"
    },
    samples: {
      name: "samples"
    },
    width: {
      name: "幅"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip$3 = {
  display_name: "潜在反転",
  inputs: {
    flip_method: {
      name: "反転方法"
    },
    samples: {
      name: "samples"
    }
  }
};
const LatentFromBatch$3 = {
  display_name: "バッチから潜在を取得",
  inputs: {
    batch_index: {
      name: "バッチインデックス"
    },
    length: {
      name: "長さ"
    },
    samples: {
      name: "samples"
    }
  }
};
const LatentInterpolate$3 = {
  display_name: "潜在補間",
  inputs: {
    ratio: {
      name: "比率"
    },
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentMultiply$3 = {
  display_name: "潜在乗算",
  inputs: {
    multiplier: {
      name: "乗数"
    },
    samples: {
      name: "samples"
    }
  }
};
const LatentOperationSharpen$3 = {
  display_name: "潜在操作シャープ化",
  inputs: {
    alpha: {
      name: "アルファ"
    },
    sharpen_radius: {
      name: "シャープ化半径"
    },
    sigma: {
      name: "シグマ"
    }
  }
};
const LatentOperationTonemapReinhard$3 = {
  display_name: "潜在操作トーンマップライナード",
  inputs: {
    multiplier: {
      name: "乗数"
    }
  }
};
const LatentRotate$3 = {
  display_name: "潜在回転",
  inputs: {
    rotation: {
      name: "回転"
    },
    samples: {
      name: "samples"
    }
  }
};
const LatentSubtract$3 = {
  display_name: "潜在減算",
  inputs: {
    samples1: {
      name: "samples1"
    },
    samples2: {
      name: "samples2"
    }
  }
};
const LatentUpscale$3 = {
  display_name: "潜在を拡大",
  inputs: {
    crop: {
      name: "クロップ"
    },
    height: {
      name: "高さ"
    },
    samples: {
      name: "samples"
    },
    upscale_method: {
      name: "拡大方法"
    },
    width: {
      name: "幅"
    }
  }
};
const LatentUpscaleBy$3 = {
  display_name: "潜在を拡大（指定サイズ）",
  inputs: {
    samples: {
      name: "samples"
    },
    scale_by: {
      name: "スケールバイ"
    },
    upscale_method: {
      name: "拡大方法"
    }
  }
};
const Load3D$3 = {
  display_name: "3Dを読み込む",
  inputs: {
    clear: {},
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    model_file: {
      name: "モデルファイル"
    },
    "upload 3d model": {},
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "画像"
    },
    "1": {
      name: "マスク"
    },
    "2": {
      name: "メッシュパス"
    }
  }
};
const Load3DAnimation$3 = {
  display_name: "3Dを読み込む - アニメーション",
  inputs: {
    clear: {},
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    model_file: {
      name: "モデルファイル"
    },
    "upload 3d model": {},
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "画像"
    },
    "1": {
      name: "マスク"
    },
    "2": {
      name: "メッシュパス"
    }
  }
};
const LoadAudio$3 = {
  display_name: "音声を読み込む",
  inputs: {
    audio: {
      name: "オーディオ"
    },
    audioUI: {
      name: "audioUI"
    },
    upload: {
      name: "アップロードするファイルを選択"
    }
  }
};
const LoadImage$3 = {
  display_name: "画像を読み込む",
  inputs: {
    image: {
      name: "画像"
    },
    upload: {
      name: "アップロードするファイルを選択"
    }
  }
};
const LoadImageMask$3 = {
  display_name: "画像を読み込む（マスクとして）",
  inputs: {
    channel: {
      name: "チャンネル"
    },
    image: {
      name: "画像"
    },
    upload: {
      name: "アップロードするファイルを選択"
    }
  }
};
const LoadImageOutput$3 = {
  description: "出力フォルダから画像を読み込みます。更新ボタンをクリックすると、ノードは画像リストを更新し、自動的に最初の画像を選択します。これにより、簡単に反復処理が可能になります。",
  display_name: "画像の読み込み（出力から）",
  inputs: {
    image: {
      name: "画像"
    },
    refresh: {},
    upload: {
      name: "アップロードするファイルを選択"
    }
  }
};
const LoadLatent$3 = {
  display_name: "潜在を読み込む",
  inputs: {
    latent: {
      name: "latent"
    }
  }
};
const LoraLoader$3 = {
  description: "LoRAは拡散およびCLIPモデルを修正するために使用され、潜在のノイズ除去方法を変更します。複数のLoRAノードを連結できます。",
  display_name: "LoRAを読み込む",
  inputs: {
    clip: {
      name: "クリップ",
      tooltip: "LoRAが適用されるCLIPモデル。"
    },
    lora_name: {
      name: "lora_name",
      tooltip: "LoRAの名前。"
    },
    model: {
      name: "モデル",
      tooltip: "LoRAが適用される拡散モデル。"
    },
    strength_clip: {
      name: "クリップの強度",
      tooltip: "CLIPモデルをどの程度変更するか。この値は負の値になる可能性があります。"
    },
    strength_model: {
      name: "モデルの強度",
      tooltip: "拡散モデルをどの程度変更するか。この値は負の値になる可能性があります。"
    }
  },
  outputs: {
    "0": {
      tooltip: "修正された拡散モデル。"
    },
    "1": {
      tooltip: "修正されたCLIPモデル。"
    }
  }
};
const LoraLoaderModelOnly$3 = {
  description: "LoRAは拡散およびCLIPモデルを修正するために使用され、潜在のノイズ除去方法を変更します。複数のLoRAノードを連結できます。",
  display_name: "LoRAローダーモデルのみ",
  inputs: {
    lora_name: {
      name: "lora_name"
    },
    model: {
      name: "モデル"
    },
    strength_model: {
      name: "モデルの強度"
    }
  },
  outputs: {
    "0": {
      tooltip: "修正された拡散モデル。"
    }
  }
};
const LoraSave$3 = {
  display_name: "LoRAを抽出して保存",
  inputs: {
    bias_diff: {
      name: "バイアスの差"
    },
    filename_prefix: {
      name: "ファイル名のプレフィックス"
    },
    lora_type: {
      name: "lora_type"
    },
    model_diff: {
      name: "モデルの差",
      tooltip: "loraに変換されるModelSubtract出力。"
    },
    rank: {
      name: "ランク"
    },
    text_encoder_diff: {
      name: "テキストエンコーダの差",
      tooltip: "loraに変換されるCLIPSubtract出力。"
    }
  }
};
const Mahiro$3 = {
  description: "ネガティブなプロンプトとの差ではなく、ポジティブなプロンプトの「方向」によりスケールするようにガイダンスを修正します。",
  display_name: "Mahiroはとても可愛いので、より良いガイダンス機能が必要です!! (。・ω・。)",
  inputs: {
    model: {
      name: "モデル"
    }
  },
  outputs: {
    "0": {
      name: "パッチ適用モデル"
    }
  }
};
const MaskComposite$3 = {
  display_name: "マスク合成",
  inputs: {
    destination: {
      name: "目的地"
    },
    operation: {
      name: "操作"
    },
    source: {
      name: "ソース"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const MaskToImage$3 = {
  display_name: "マスクを画像に変換",
  inputs: {
    mask: {
      name: "マスク"
    }
  }
};
const ModelComputeDtype$3 = {
  display_name: "ModelComputeDtype",
  inputs: {
    dtype: {
      name: "dtype"
    },
    model: {
      name: "モデル"
    }
  }
};
const ModelMergeAdd$3 = {
  display_name: "モデルマージ追加",
  inputs: {
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    }
  }
};
const ModelMergeAuraflow$3 = {
  display_name: "モデルマージオーラフロー",
  inputs: {
    cond_seq_linear_: {
      name: "cond_seq_linear."
    },
    double_layers_0_: {
      name: "double_layers.0."
    },
    double_layers_1_: {
      name: "double_layers.1."
    },
    double_layers_2_: {
      name: "double_layers.2."
    },
    double_layers_3_: {
      name: "double_layers.3."
    },
    final_linear_: {
      name: "final_linear."
    },
    init_x_linear_: {
      name: "init_x_linear."
    },
    modF_: {
      name: "modF."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    positional_encoding: {
      name: "位置エンコーディング"
    },
    register_tokens: {
      name: "トークンを登録"
    },
    single_layers_0_: {
      name: "single_layers.0."
    },
    single_layers_10_: {
      name: "single_layers.10."
    },
    single_layers_11_: {
      name: "single_layers.11."
    },
    single_layers_12_: {
      name: "single_layers.12."
    },
    single_layers_13_: {
      name: "single_layers.13."
    },
    single_layers_14_: {
      name: "single_layers.14."
    },
    single_layers_15_: {
      name: "single_layers.15."
    },
    single_layers_16_: {
      name: "single_layers.16."
    },
    single_layers_17_: {
      name: "single_layers.17."
    },
    single_layers_18_: {
      name: "single_layers.18."
    },
    single_layers_19_: {
      name: "single_layers.19."
    },
    single_layers_1_: {
      name: "single_layers.1."
    },
    single_layers_20_: {
      name: "single_layers.20."
    },
    single_layers_21_: {
      name: "single_layers.21."
    },
    single_layers_22_: {
      name: "single_layers.22."
    },
    single_layers_23_: {
      name: "single_layers.23."
    },
    single_layers_24_: {
      name: "single_layers.24."
    },
    single_layers_25_: {
      name: "single_layers.25."
    },
    single_layers_26_: {
      name: "single_layers.26."
    },
    single_layers_27_: {
      name: "single_layers.27."
    },
    single_layers_28_: {
      name: "single_layers.28."
    },
    single_layers_29_: {
      name: "single_layers.29."
    },
    single_layers_2_: {
      name: "single_layers.2."
    },
    single_layers_30_: {
      name: "single_layers.30."
    },
    single_layers_31_: {
      name: "single_layers.31."
    },
    single_layers_3_: {
      name: "single_layers.3."
    },
    single_layers_4_: {
      name: "single_layers.4."
    },
    single_layers_5_: {
      name: "single_layers.5."
    },
    single_layers_6_: {
      name: "single_layers.6."
    },
    single_layers_7_: {
      name: "single_layers.7."
    },
    single_layers_8_: {
      name: "single_layers.8."
    },
    single_layers_9_: {
      name: "single_layers.9."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeBlocks$3 = {
  display_name: "モデルマージブロック",
  inputs: {
    input: {
      name: "入力"
    },
    middle: {
      name: "中間"
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    out: {
      name: "出力"
    }
  }
};
const ModelMergeCosmos14B$3 = {
  display_name: "ModelMergeCosmos14B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeCosmos7B$3 = {
  display_name: "ModelMergeCosmos7B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeFlux1$3 = {
  display_name: "モデルマージフラックス1",
  inputs: {
    double_blocks_0_: {
      name: "double_blocks.0."
    },
    double_blocks_10_: {
      name: "double_blocks.10."
    },
    double_blocks_11_: {
      name: "double_blocks.11."
    },
    double_blocks_12_: {
      name: "double_blocks.12."
    },
    double_blocks_13_: {
      name: "double_blocks.13."
    },
    double_blocks_14_: {
      name: "double_blocks.14."
    },
    double_blocks_15_: {
      name: "double_blocks.15."
    },
    double_blocks_16_: {
      name: "double_blocks.16."
    },
    double_blocks_17_: {
      name: "double_blocks.17."
    },
    double_blocks_18_: {
      name: "double_blocks.18."
    },
    double_blocks_1_: {
      name: "double_blocks.1."
    },
    double_blocks_2_: {
      name: "double_blocks.2."
    },
    double_blocks_3_: {
      name: "double_blocks.3."
    },
    double_blocks_4_: {
      name: "double_blocks.4."
    },
    double_blocks_5_: {
      name: "double_blocks.5."
    },
    double_blocks_6_: {
      name: "double_blocks.6."
    },
    double_blocks_7_: {
      name: "double_blocks.7."
    },
    double_blocks_8_: {
      name: "double_blocks.8."
    },
    double_blocks_9_: {
      name: "double_blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    guidance_in: {
      name: "guidance_in"
    },
    img_in_: {
      name: "img_in."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    single_blocks_0_: {
      name: "single_blocks.0."
    },
    single_blocks_10_: {
      name: "single_blocks.10."
    },
    single_blocks_11_: {
      name: "single_blocks.11."
    },
    single_blocks_12_: {
      name: "single_blocks.12."
    },
    single_blocks_13_: {
      name: "single_blocks.13."
    },
    single_blocks_14_: {
      name: "single_blocks.14."
    },
    single_blocks_15_: {
      name: "single_blocks.15."
    },
    single_blocks_16_: {
      name: "single_blocks.16."
    },
    single_blocks_17_: {
      name: "single_blocks.17."
    },
    single_blocks_18_: {
      name: "single_blocks.18."
    },
    single_blocks_19_: {
      name: "single_blocks.19."
    },
    single_blocks_1_: {
      name: "single_blocks.1."
    },
    single_blocks_20_: {
      name: "single_blocks.20."
    },
    single_blocks_21_: {
      name: "single_blocks.21."
    },
    single_blocks_22_: {
      name: "single_blocks.22."
    },
    single_blocks_23_: {
      name: "single_blocks.23."
    },
    single_blocks_24_: {
      name: "single_blocks.24."
    },
    single_blocks_25_: {
      name: "single_blocks.25."
    },
    single_blocks_26_: {
      name: "single_blocks.26."
    },
    single_blocks_27_: {
      name: "single_blocks.27."
    },
    single_blocks_28_: {
      name: "single_blocks.28."
    },
    single_blocks_29_: {
      name: "single_blocks.29."
    },
    single_blocks_2_: {
      name: "single_blocks.2."
    },
    single_blocks_30_: {
      name: "single_blocks.30."
    },
    single_blocks_31_: {
      name: "single_blocks.31."
    },
    single_blocks_32_: {
      name: "single_blocks.32."
    },
    single_blocks_33_: {
      name: "single_blocks.33."
    },
    single_blocks_34_: {
      name: "single_blocks.34."
    },
    single_blocks_35_: {
      name: "single_blocks.35."
    },
    single_blocks_36_: {
      name: "single_blocks.36."
    },
    single_blocks_37_: {
      name: "single_blocks.37."
    },
    single_blocks_3_: {
      name: "single_blocks.3."
    },
    single_blocks_4_: {
      name: "single_blocks.4."
    },
    single_blocks_5_: {
      name: "single_blocks.5."
    },
    single_blocks_6_: {
      name: "single_blocks.6."
    },
    single_blocks_7_: {
      name: "single_blocks.7."
    },
    single_blocks_8_: {
      name: "single_blocks.8."
    },
    single_blocks_9_: {
      name: "single_blocks.9."
    },
    time_in_: {
      name: "time_in."
    },
    txt_in_: {
      name: "txt_in."
    },
    vector_in_: {
      name: "vector_in."
    }
  }
};
const ModelMergeLTXV$3 = {
  display_name: "モデルマージLTXV",
  inputs: {
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "キャプション投影."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    proj_out_: {
      name: "proj_out."
    },
    scale_shift_table: {
      name: "スケールシフトテーブル"
    },
    transformer_blocks_0_: {
      name: "トランスフォーマーブロック.0."
    },
    transformer_blocks_10_: {
      name: "トランスフォーマーブロック.10."
    },
    transformer_blocks_11_: {
      name: "トランスフォーマーブロック.11."
    },
    transformer_blocks_12_: {
      name: "トランスフォーマーブロック.12."
    },
    transformer_blocks_13_: {
      name: "トランスフォーマーブロック.13."
    },
    transformer_blocks_14_: {
      name: "トランスフォーマーブロック.14."
    },
    transformer_blocks_15_: {
      name: "トランスフォーマーブロック.15."
    },
    transformer_blocks_16_: {
      name: "トランスフォーマーブロック.16."
    },
    transformer_blocks_17_: {
      name: "トランスフォーマーブロック.17."
    },
    transformer_blocks_18_: {
      name: "トランスフォーマーブロック.18."
    },
    transformer_blocks_19_: {
      name: "トランスフォーマーブロック.19."
    },
    transformer_blocks_1_: {
      name: "トランスフォーマーブロック.1."
    },
    transformer_blocks_20_: {
      name: "トランスフォーマーブロック.20."
    },
    transformer_blocks_21_: {
      name: "トランスフォーマーブロック.21."
    },
    transformer_blocks_22_: {
      name: "トランスフォーマーブロック.22."
    },
    transformer_blocks_23_: {
      name: "トランスフォーマーブロック.23."
    },
    transformer_blocks_24_: {
      name: "トランスフォーマーブロック.24."
    },
    transformer_blocks_25_: {
      name: "トランスフォーマーブロック.25."
    },
    transformer_blocks_26_: {
      name: "トランスフォーマーブロック.26."
    },
    transformer_blocks_27_: {
      name: "トランスフォーマーブロック.27."
    },
    transformer_blocks_2_: {
      name: "トランスフォーマーブロック.2."
    },
    transformer_blocks_3_: {
      name: "トランスフォーマーブロック.3."
    },
    transformer_blocks_4_: {
      name: "トランスフォーマーブロック.4."
    },
    transformer_blocks_5_: {
      name: "トランスフォーマーブロック.5."
    },
    transformer_blocks_6_: {
      name: "トランスフォーマーブロック.6."
    },
    transformer_blocks_7_: {
      name: "トランスフォーマーブロック.7."
    },
    transformer_blocks_8_: {
      name: "トランスフォーマーブロック.8."
    },
    transformer_blocks_9_: {
      name: "トランスフォーマーブロック.9."
    }
  }
};
const ModelMergeMochiPreview$3 = {
  display_name: "モデルマージMochiプレビュー",
  inputs: {
    blocks_0_: {
      name: "blocks.0."
    },
    blocks_10_: {
      name: "blocks.10."
    },
    blocks_11_: {
      name: "blocks.11."
    },
    blocks_12_: {
      name: "blocks.12."
    },
    blocks_13_: {
      name: "blocks.13."
    },
    blocks_14_: {
      name: "blocks.14."
    },
    blocks_15_: {
      name: "blocks.15."
    },
    blocks_16_: {
      name: "blocks.16."
    },
    blocks_17_: {
      name: "blocks.17."
    },
    blocks_18_: {
      name: "blocks.18."
    },
    blocks_19_: {
      name: "blocks.19."
    },
    blocks_1_: {
      name: "blocks.1."
    },
    blocks_20_: {
      name: "blocks.20."
    },
    blocks_21_: {
      name: "blocks.21."
    },
    blocks_22_: {
      name: "blocks.22."
    },
    blocks_23_: {
      name: "blocks.23."
    },
    blocks_24_: {
      name: "blocks.24."
    },
    blocks_25_: {
      name: "blocks.25."
    },
    blocks_26_: {
      name: "blocks.26."
    },
    blocks_27_: {
      name: "blocks.27."
    },
    blocks_28_: {
      name: "blocks.28."
    },
    blocks_29_: {
      name: "blocks.29."
    },
    blocks_2_: {
      name: "blocks.2."
    },
    blocks_30_: {
      name: "blocks.30."
    },
    blocks_31_: {
      name: "blocks.31."
    },
    blocks_32_: {
      name: "blocks.32."
    },
    blocks_33_: {
      name: "blocks.33."
    },
    blocks_34_: {
      name: "blocks.34."
    },
    blocks_35_: {
      name: "blocks.35."
    },
    blocks_36_: {
      name: "blocks.36."
    },
    blocks_37_: {
      name: "blocks.37."
    },
    blocks_38_: {
      name: "blocks.38."
    },
    blocks_39_: {
      name: "blocks.39."
    },
    blocks_3_: {
      name: "blocks.3."
    },
    blocks_40_: {
      name: "blocks.40."
    },
    blocks_41_: {
      name: "blocks.41."
    },
    blocks_42_: {
      name: "blocks.42."
    },
    blocks_43_: {
      name: "blocks.43."
    },
    blocks_44_: {
      name: "blocks.44."
    },
    blocks_45_: {
      name: "blocks.45."
    },
    blocks_46_: {
      name: "blocks.46."
    },
    blocks_47_: {
      name: "blocks.47."
    },
    blocks_4_: {
      name: "blocks.4."
    },
    blocks_5_: {
      name: "blocks.5."
    },
    blocks_6_: {
      name: "blocks.6."
    },
    blocks_7_: {
      name: "blocks.7."
    },
    blocks_8_: {
      name: "blocks.8."
    },
    blocks_9_: {
      name: "blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    pos_frequencies_: {
      name: "pos_frequencies."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeSD1$3 = {
  display_name: "モデルマージSD1",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD2$3 = {
  display_name: "モデルマージSD2",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD35_Large$3 = {
  display_name: "モデルマージSD35_Large",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_24_: {
      name: "joint_blocks.24."
    },
    joint_blocks_25_: {
      name: "joint_blocks.25."
    },
    joint_blocks_26_: {
      name: "joint_blocks.26."
    },
    joint_blocks_27_: {
      name: "joint_blocks.27."
    },
    joint_blocks_28_: {
      name: "joint_blocks.28."
    },
    joint_blocks_29_: {
      name: "joint_blocks.29."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_30_: {
      name: "joint_blocks.30."
    },
    joint_blocks_31_: {
      name: "joint_blocks.31."
    },
    joint_blocks_32_: {
      name: "joint_blocks.32."
    },
    joint_blocks_33_: {
      name: "joint_blocks.33."
    },
    joint_blocks_34_: {
      name: "joint_blocks.34."
    },
    joint_blocks_35_: {
      name: "joint_blocks.35."
    },
    joint_blocks_36_: {
      name: "joint_blocks.36."
    },
    joint_blocks_37_: {
      name: "joint_blocks.37."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSD3_2B$3 = {
  display_name: "モデルマージSD3_2B",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSDXL$3 = {
  display_name: "モデルマージSDXL",
  inputs: {
    input_blocks_0: {
      name: "input_blocks.0"
    },
    input_blocks_1: {
      name: "input_blocks.1"
    },
    input_blocks_2: {
      name: "input_blocks.2"
    },
    input_blocks_3: {
      name: "input_blocks.3"
    },
    input_blocks_4: {
      name: "input_blocks.4"
    },
    input_blocks_5: {
      name: "input_blocks.5"
    },
    input_blocks_6: {
      name: "input_blocks.6"
    },
    input_blocks_7: {
      name: "input_blocks.7"
    },
    input_blocks_8: {
      name: "input_blocks.8"
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0: {
      name: "middle_block.0"
    },
    middle_block_1: {
      name: "middle_block.1"
    },
    middle_block_2: {
      name: "middle_block.2"
    },
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0: {
      name: "output_blocks.0"
    },
    output_blocks_1: {
      name: "output_blocks.1"
    },
    output_blocks_2: {
      name: "output_blocks.2"
    },
    output_blocks_3: {
      name: "output_blocks.3"
    },
    output_blocks_4: {
      name: "output_blocks.4"
    },
    output_blocks_5: {
      name: "output_blocks.5"
    },
    output_blocks_6: {
      name: "output_blocks.6"
    },
    output_blocks_7: {
      name: "output_blocks.7"
    },
    output_blocks_8: {
      name: "output_blocks.8"
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSimple$3 = {
  display_name: "モデルマージシンプル",
  inputs: {
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    ratio: {
      name: "比率"
    }
  }
};
const ModelMergeSubtract$3 = {
  display_name: "モデルマージ減算",
  inputs: {
    model1: {
      name: "モデル1"
    },
    model2: {
      name: "モデル2"
    },
    multiplier: {
      name: "乗数"
    }
  }
};
const ModelSamplingAuraFlow$3 = {
  display_name: "モデルサンプリングオーラフロー",
  inputs: {
    model: {
      name: "モデル"
    },
    shift: {
      name: "シフト"
    }
  }
};
const ModelSamplingContinuousEDM$3 = {
  display_name: "モデルサンプリング連続EDM",
  inputs: {
    model: {
      name: "モデル"
    },
    sampling: {
      name: "サンプリング"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingContinuousV$3 = {
  display_name: "モデルサンプリング連続V",
  inputs: {
    model: {
      name: "モデル"
    },
    sampling: {
      name: "サンプリング"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingDiscrete$3 = {
  display_name: "モデルサンプリング離散",
  inputs: {
    model: {
      name: "モデル"
    },
    sampling: {
      name: "サンプリング"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux$3 = {
  display_name: "モデルサンプリングフラックス",
  inputs: {
    base_shift: {
      name: "基本シフト"
    },
    height: {
      name: "高さ"
    },
    max_shift: {
      name: "最大シフト"
    },
    model: {
      name: "モデル"
    },
    width: {
      name: "幅"
    }
  }
};
const ModelSamplingLTXV$3 = {
  display_name: "モデルサンプリングLTXV",
  inputs: {
    base_shift: {
      name: "基本シフト"
    },
    latent: {
      name: "潜在"
    },
    max_shift: {
      name: "最大シフト"
    },
    model: {
      name: "モデル"
    }
  }
};
const ModelSamplingSD3$3 = {
  display_name: "モデルサンプリングSD3",
  inputs: {
    model: {
      name: "モデル"
    },
    shift: {
      name: "シフト"
    }
  }
};
const ModelSamplingStableCascade$3 = {
  display_name: "モデルサンプリング安定カスケード",
  inputs: {
    model: {
      name: "モデル"
    },
    shift: {
      name: "シフト"
    }
  }
};
const ModelSave$3 = {
  display_name: "モデルを保存",
  inputs: {
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    model: {
      name: "モデル"
    }
  }
};
const Morphology$3 = {
  display_name: "画像形態学",
  inputs: {
    image: {
      name: "画像"
    },
    kernel_size: {
      name: "カーネルサイズ"
    },
    operation: {
      name: "操作"
    }
  }
};
const PairConditioningCombine$3 = {
  display_name: "ペア条件付け組み合わせ",
  inputs: {
    negative_A: {
      name: "ネガティブ_A"
    },
    negative_B: {
      name: "ネガティブ_B"
    },
    positive_A: {
      name: "ポジティブ_A"
    },
    positive_B: {
      name: "ポジティブ_B"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const PairConditioningSetDefaultCombine$3 = {
  display_name: "ペア条件付けデフォルト組み合わせを設定",
  inputs: {
    hooks: {
      name: "フック"
    },
    negative: {
      name: "ネガティブ"
    },
    negative_DEFAULT: {
      name: "ネガティブ_DEFAULT"
    },
    positive: {
      name: "ポジティブ"
    },
    positive_DEFAULT: {
      name: "ポジティブ_DEFAULT"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const PairConditioningSetProperties$3 = {
  display_name: "ペア条件付けプロパティ設定",
  inputs: {
    hooks: {
      name: "フック"
    },
    mask: {
      name: "マスク"
    },
    negative_NEW: {
      name: "ネガティブ_NEW"
    },
    positive_NEW: {
      name: "ポジティブ_NEW"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    strength: {
      name: "強度"
    },
    timesteps: {
      name: "タイムステップ"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const PairConditioningSetPropertiesAndCombine$3 = {
  display_name: "ペア条件付けプロパティ設定と組み合わせ",
  inputs: {
    hooks: {
      name: "フック"
    },
    mask: {
      name: "マスク"
    },
    negative: {
      name: "ネガティブ"
    },
    negative_NEW: {
      name: "ネガティブ_NEW"
    },
    positive: {
      name: "ポジティブ"
    },
    positive_NEW: {
      name: "ポジティブ_NEW"
    },
    set_cond_area: {
      name: "set_cond_area"
    },
    strength: {
      name: "強度"
    },
    timesteps: {
      name: "タイムステップ"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    }
  }
};
const PatchModelAddDownscale$3 = {
  display_name: "パッチモデル追加ダウンスケール（Kohya Deep Shrink）",
  inputs: {
    block_number: {
      name: "ブロック番号"
    },
    downscale_after_skip: {
      name: "スキップ後のダウンスケール"
    },
    downscale_factor: {
      name: "ダウンスケール係数"
    },
    downscale_method: {
      name: "ダウンスケール方法"
    },
    end_percent: {
      name: "終了パーセント"
    },
    model: {
      name: "モデル"
    },
    start_percent: {
      name: "開始パーセント"
    },
    upscale_method: {
      name: "アップスケール方法"
    }
  }
};
const PerpNeg$3 = {
  display_name: "Perp-Neg（PerpNegGuiderによって非推奨）",
  inputs: {
    empty_conditioning: {
      name: "空のコンディショニング"
    },
    model: {
      name: "モデル"
    },
    neg_scale: {
      name: "ネガティブスケール"
    }
  }
};
const PerpNegGuider$3 = {
  display_name: "PerpNegガイダー",
  inputs: {
    cfg: {
      name: "cfg"
    },
    empty_conditioning: {
      name: "空のコンディショニング"
    },
    model: {
      name: "モデル"
    },
    neg_scale: {
      name: "ネガティブスケール"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    }
  }
};
const PerturbedAttentionGuidance$3 = {
  display_name: "摂動注意ガイダンス",
  inputs: {
    model: {
      name: "モデル"
    },
    scale: {
      name: "スケール"
    }
  }
};
const PhotoMakerEncode$3 = {
  display_name: "フォトメーカーエンコード",
  inputs: {
    clip: {
      name: "clip"
    },
    image: {
      name: "画像"
    },
    photomaker: {
      name: "photomaker"
    },
    text: {
      name: "テキスト"
    }
  }
};
const PhotoMakerLoader$3 = {
  display_name: "フォトメーカーを読み込む",
  inputs: {
    photomaker_model_name: {
      name: "photomakerモデル名"
    }
  }
};
const PolyexponentialScheduler$3 = {
  display_name: "ポリ指数スケジューラー",
  inputs: {
    rho: {
      name: "ロー"
    },
    sigma_max: {
      name: "シグママックス"
    },
    sigma_min: {
      name: "シグマミン"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const PorterDuffImageComposite$3 = {
  display_name: "ポーターダフ画像合成",
  inputs: {
    destination: {
      name: "デスティネーション"
    },
    destination_alpha: {
      name: "デスティネーションアルファ"
    },
    mode: {
      name: "モード"
    },
    source: {
      name: "ソース"
    },
    source_alpha: {
      name: "ソースアルファ"
    }
  }
};
const Preview3D$3 = {
  display_name: "3Dプレビュー",
  inputs: {
    image: {
      name: "画像"
    },
    model_file: {
      name: "モデルファイル"
    }
  }
};
const Preview3DAnimation$3 = {
  display_name: "プレビュー 3D - アニメーション",
  inputs: {
    image: {
      name: "画像"
    },
    model_file: {
      name: "モデルファイル"
    }
  }
};
const PreviewAudio$3 = {
  display_name: "オーディオプレビュー",
  inputs: {
    audio: {
      name: "オーディオ"
    },
    audioUI: {
      name: "audioUI"
    }
  }
};
const PreviewImage$3 = {
  description: "入力画像をComfyUI出力ディレクトリに保存します。",
  display_name: "画像プレビュー",
  inputs: {
    images: {
      name: "画像"
    }
  }
};
const RandomNoise$3 = {
  display_name: "ランダムノイズ",
  inputs: {
    control_after_generate: {
      name: "生成後の制御"
    },
    noise_seed: {
      name: "ノイズシード"
    }
  }
};
const RebatchImages$3 = {
  display_name: "画像を再バッチ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    images: {
      name: "画像"
    }
  }
};
const RebatchLatents$3 = {
  display_name: "潜在を再バッチ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    latents: {
      name: "潜在変数"
    }
  }
};
const RenormCFG$3 = {
  display_name: "RenormCFG",
  inputs: {
    cfg_trunc: {
      name: "cfg_trunc"
    },
    model: {
      name: "モデル"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch$3 = {
  display_name: "画像バッチを繰り返す",
  inputs: {
    amount: {
      name: "量"
    },
    image: {
      name: "画像"
    }
  }
};
const RepeatLatentBatch$3 = {
  display_name: "潜在バッチを繰り返す",
  inputs: {
    amount: {
      name: "量"
    },
    samples: {
      name: "サンプル"
    }
  }
};
const RescaleCFG$3 = {
  display_name: "CFGを再スケール",
  inputs: {
    model: {
      name: "モデル"
    },
    multiplier: {
      name: "乗数"
    }
  }
};
const SDTurboScheduler$3 = {
  display_name: "SDターボスケジューラー",
  inputs: {
    denoise: {
      name: "ノイズ除去"
    },
    model: {
      name: "モデル"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const SD_4XUpscale_Conditioning$3 = {
  display_name: "SD_4X拡大条件付け",
  inputs: {
    images: {
      name: "画像"
    },
    negative: {
      name: "ネガティブ"
    },
    noise_augmentation: {
      name: "ノイズ増強"
    },
    positive: {
      name: "ポジティブ"
    },
    scale_ratio: {
      name: "スケール比"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const SV3D_Conditioning$3 = {
  display_name: "SV3D条件付け",
  inputs: {
    clip_vision: {
      name: "クリップビジョン"
    },
    elevation: {
      name: "高度"
    },
    height: {
      name: "高さ"
    },
    init_image: {
      name: "初期画像"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "ビデオフレーム"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const SVD_img2vid_Conditioning$3 = {
  display_name: "SVD_img2vid条件付け",
  inputs: {
    augmentation_level: {
      name: "増強レベル"
    },
    clip_vision: {
      name: "clip_vision"
    },
    fps: {
      name: "fps"
    },
    height: {
      name: "高さ"
    },
    init_image: {
      name: "初期画像"
    },
    motion_bucket_id: {
      name: "モーションバケットID"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "ビデオフレーム"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const SamplerCustom$3 = {
  display_name: "カスタムサンプラー",
  inputs: {
    add_noise: {
      name: "ノイズを追加"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "生成後の制御"
    },
    latent_image: {
      name: "潜在画像"
    },
    model: {
      name: "モデル"
    },
    negative: {
      name: "ネガティブ"
    },
    noise_seed: {
      name: "ノイズシード"
    },
    positive: {
      name: "ポジティブ"
    },
    sampler: {
      name: "サンプラー"
    },
    sigmas: {
      name: "シグマ"
    }
  },
  outputs: {
    "0": {
      name: "出力"
    },
    "1": {
      name: "デノイズ出力"
    }
  }
};
const SamplerCustomAdvanced$3 = {
  display_name: "カスタムサンプラー（高度）",
  inputs: {
    guider: {
      name: "ガイダー"
    },
    latent_image: {
      name: "潜在イメージ"
    },
    noise: {
      name: "ノイズ"
    },
    sampler: {
      name: "サンプラー"
    },
    sigmas: {
      name: "シグマ"
    }
  },
  outputs: {
    "0": {
      name: "出力"
    },
    "1": {
      name: "デノイズ出力"
    }
  }
};
const SamplerDPMAdaptative$3 = {
  display_name: "サンプラーDPM適応",
  inputs: {
    accept_safety: {
      name: "accept_safety"
    },
    atol: {
      name: "atol"
    },
    dcoeff: {
      name: "dcoeff"
    },
    eta: {
      name: "eta"
    },
    h_init: {
      name: "h_init"
    },
    icoeff: {
      name: "icoeff"
    },
    order: {
      name: "順序"
    },
    pcoeff: {
      name: "pcoeff"
    },
    rtol: {
      name: "rtol"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_2M_SDE$3 = {
  display_name: "サンプラーDPMPP_2M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "ノイズデバイス"
    },
    s_noise: {
      name: "s_noise"
    },
    solver_type: {
      name: "ソルバータイプ"
    }
  }
};
const SamplerDPMPP_2S_Ancestral$3 = {
  display_name: "サンプラーDPMPP_2S_祖先",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_3M_SDE$3 = {
  display_name: "サンプラーDPMPP_3M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "ノイズデバイス"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_SDE$3 = {
  display_name: "サンプラーDPMPP_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "ノイズデバイス"
    },
    r: {
      name: "r"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestral$3 = {
  display_name: "サンプラーオイラー祖先",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestralCFGPP$3 = {
  display_name: "サンプラーオイラー祖先CFG++",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerCFGpp$3 = {
  display_name: "サンプラーオイラーCFG++",
  inputs: {
    version: {
      name: "バージョン"
    }
  }
};
const SamplerLCMUpscale$3 = {
  display_name: "サンプラーLCM拡大",
  inputs: {
    scale_ratio: {
      name: "スケール比"
    },
    scale_steps: {
      name: "スケールステップ"
    },
    upscale_method: {
      name: "アップスケール方法"
    }
  }
};
const SamplerLMS$3 = {
  display_name: "サンプラーLMS",
  inputs: {
    order: {
      name: "順序"
    }
  }
};
const SaveAnimatedPNG$3 = {
  display_name: "アニメーションPNGを保存",
  inputs: {
    compress_level: {
      name: "圧縮レベル"
    },
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "画像"
    }
  }
};
const SaveAnimatedWEBP$3 = {
  display_name: "アニメーションWEBPを保存",
  inputs: {
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "画像"
    },
    lossless: {
      name: "ロスレス"
    },
    method: {
      name: "方法"
    },
    quality: {
      name: "品質"
    }
  }
};
const SaveAudio$3 = {
  display_name: "オーディオを保存",
  inputs: {
    audio: {
      name: "オーディオ"
    },
    audioUI: {
      name: "audioUI"
    },
    filename_prefix: {
      name: "ファイル名_プレフィックス"
    }
  }
};
const SaveGLB$3 = {
  display_name: "SaveGLB",
  inputs: {
    filename_prefix: {
      name: "ファイル名のプレフィックス"
    },
    image: {
      name: "画像"
    },
    mesh: {
      name: "メッシュ"
    }
  }
};
const SaveImage$3 = {
  description: "入力画像をComfyUI出力ディレクトリに保存します。",
  display_name: "画像を保存",
  inputs: {
    filename_prefix: {
      name: "ファイル名_プレフィックス",
      tooltip: "保存するファイルのプレフィックス。この中には、ノードからの値を含めるために、%date:yyyy-MM-dd%や%Empty Latent Image.width%などのフォーマット情報が含まれる場合があります。"
    },
    images: {
      name: "画像",
      tooltip: "保存する画像。"
    }
  }
};
const SaveImageWebsocket$3 = {
  display_name: "画像を保存するWebSocket",
  inputs: {
    images: {
      name: "画像"
    }
  }
};
const SaveLatent$3 = {
  display_name: "潜在を保存",
  inputs: {
    filename_prefix: {
      name: "ファイル名_プレフィックス"
    },
    samples: {
      name: "サンプル"
    }
  }
};
const SaveWEBM$3 = {
  display_name: "SaveWEBM",
  inputs: {
    codec: {
      name: "コーデック"
    },
    crf: {
      name: "crf",
      tooltip: "crfが高いほどファイルサイズは小さくなりますが、品質は低下します。逆に、crfが低いほど品質は高くなりますが、ファイルサイズは大きくなります。"
    },
    filename_prefix: {
      name: "ファイル名の接頭辞"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "画像"
    }
  }
};
const SelfAttentionGuidance$3 = {
  display_name: "自己注意ガイダンス",
  inputs: {
    blur_sigma: {
      name: "ブラーシグマ"
    },
    model: {
      name: "モデル"
    },
    scale: {
      name: "スケール"
    }
  }
};
const SetClipHooks$3 = {
  display_name: "CLIPフックを設定",
  inputs: {
    apply_to_conds: {
      name: "apply_to_conds"
    },
    clip: {
      name: "クリップ"
    },
    hooks: {
      name: "フック"
    },
    schedule_clip: {
      name: "schedule_clip"
    }
  }
};
const SetFirstSigma$3 = {
  display_name: "SetFirstSigma",
  inputs: {
    sigma: {
      name: "シグマ"
    },
    sigmas: {
      name: "シグマ"
    }
  }
};
const SetHookKeyframes$3 = {
  display_name: "フックキーフレームを設定",
  inputs: {
    hook_kf: {
      name: "フック_kf"
    },
    hooks: {
      name: "フック"
    }
  }
};
const SetLatentNoiseMask$3 = {
  display_name: "潜在ノイズマスクを設定",
  inputs: {
    mask: {
      name: "マスク"
    },
    samples: {
      name: "サンプル"
    }
  }
};
const SetUnionControlNetType$3 = {
  display_name: "Union ControlNetタイプを設定",
  inputs: {
    control_net: {
      name: "control_net"
    },
    type: {
      name: "タイプ"
    }
  }
};
const SkipLayerGuidanceDiT$3 = {
  description: "すべてのDiTモデルで使用できるSkipLayerGuidanceノードの一般的なバージョン。",
  display_name: "SkipLayerGuidanceDiT",
  inputs: {
    double_layers: {
      name: "ダブルレイヤー"
    },
    end_percent: {
      name: "終了パーセント"
    },
    model: {
      name: "モデル"
    },
    rescaling_scale: {
      name: "リスケーリングスケール"
    },
    scale: {
      name: "スケール"
    },
    single_layers: {
      name: "シングルレイヤー"
    },
    start_percent: {
      name: "開始パーセント"
    }
  }
};
const SkipLayerGuidanceSD3$3 = {
  description: "すべてのDiTモデルで使用できるSkipLayerGuidanceノードの一般的なバージョン。",
  display_name: "SkipLayerGuidanceSD3",
  inputs: {
    end_percent: {
      name: "終了パーセント"
    },
    layers: {
      name: "レイヤー"
    },
    model: {
      name: "モデル"
    },
    scale: {
      name: "スケール"
    },
    start_percent: {
      name: "開始パーセント"
    }
  }
};
const SolidMask$3 = {
  display_name: "ソリッドマスク",
  inputs: {
    height: {
      name: "高さ"
    },
    value: {
      name: "値"
    },
    width: {
      name: "幅"
    }
  }
};
const SplitImageWithAlpha$3 = {
  display_name: "アルファで画像を分割",
  inputs: {
    image: {
      name: "画像"
    }
  }
};
const SplitSigmas$3 = {
  display_name: "シグマを分割",
  inputs: {
    sigmas: {
      name: "シグマ"
    },
    step: {
      name: "ステップ"
    }
  },
  outputs: {
    "0": {
      name: "高シグマ"
    },
    "1": {
      name: "低シグマ"
    }
  }
};
const SplitSigmasDenoise$3 = {
  display_name: "シグマを分割してノイズ除去",
  inputs: {
    denoise: {
      name: "ノイズ除去"
    },
    sigmas: {
      name: "シグマ"
    }
  },
  outputs: {
    "0": {
      name: "高シグマ"
    },
    "1": {
      name: "低シグマ"
    }
  }
};
const StableCascade_EmptyLatentImage$3 = {
  display_name: "安定カスケード_空の潜在画像",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    compression: {
      name: "圧縮"
    },
    height: {
      name: "高さ"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ステージC"
    },
    "1": {
      name: "ステージB"
    }
  }
};
const StableCascade_StageB_Conditioning$3 = {
  display_name: "安定カスケード_ステージB条件付け",
  inputs: {
    conditioning: {
      name: "コンディショニング"
    },
    stage_c: {
      name: "ステージc"
    }
  }
};
const StableCascade_StageC_VAEEncode$3 = {
  display_name: "安定カスケード_ステージC_VAEエンコード",
  inputs: {
    compression: {
      name: "圧縮"
    },
    image: {
      name: "画像"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ステージC"
    },
    "1": {
      name: "ステージB"
    }
  }
};
const StableCascade_SuperResolutionControlnet$3 = {
  display_name: "安定カスケード_超解像Controlnet",
  inputs: {
    image: {
      name: "画像"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "コントロールネット入力"
    },
    "1": {
      name: "ステージC"
    },
    "2": {
      name: "ステージB"
    }
  }
};
const StableZero123_Conditioning$3 = {
  display_name: "安定ゼロ123条件付け",
  inputs: {
    azimuth: {
      name: "方位角"
    },
    batch_size: {
      name: "バッチサイズ"
    },
    clip_vision: {
      name: "クリップビジョン"
    },
    elevation: {
      name: "高度"
    },
    height: {
      name: "高さ"
    },
    init_image: {
      name: "初期画像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const StableZero123_Conditioning_Batched$3 = {
  display_name: "安定ゼロ123条件付け（バッチ）",
  inputs: {
    azimuth: {
      name: "方位角"
    },
    azimuth_batch_increment: {
      name: "方位角バッチ増分"
    },
    batch_size: {
      name: "バッチサイズ"
    },
    clip_vision: {
      name: "クリップビジョン"
    },
    elevation: {
      name: "高度"
    },
    elevation_batch_increment: {
      name: "高度バッチ増分"
    },
    height: {
      name: "高さ"
    },
    init_image: {
      name: "初期画像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const StyleModelApply$3 = {
  display_name: "スタイルモデルを適用",
  inputs: {
    clip_vision_output: {
      name: "クリップビジョン出力"
    },
    conditioning: {
      name: "コンディショニング"
    },
    strength: {
      name: "強度"
    },
    strength_type: {
      name: "強度タイプ"
    },
    style_model: {
      name: "スタイルモデル"
    }
  }
};
const StyleModelLoader$3 = {
  display_name: "スタイルモデルを読み込む",
  inputs: {
    style_model_name: {
      name: "スタイルモデル名"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo$3 = {
  display_name: "TextEncodeHunyuanVideo_ImageToVideo",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    image_interleave: {
      name: "画像インターリーブ",
      tooltip: "画像がテキストプロンプトと比べてどれだけ影響を与えるか。数値が大きいほどテキストプロンプトからの影響が大きくなります。"
    },
    prompt: {
      name: "プロンプト"
    }
  }
};
const ThresholdMask$3 = {
  display_name: "しきい値マスク",
  inputs: {
    mask: {
      name: "マスク"
    },
    value: {
      name: "値"
    }
  }
};
const TomePatchModel$3 = {
  display_name: "トメパッチモデル",
  inputs: {
    model: {
      name: "モデル"
    },
    ratio: {
      name: "比率"
    }
  }
};
const TorchCompileModel$3 = {
  display_name: "Torchコンパイルモデル",
  inputs: {
    backend: {
      name: "バックエンド"
    },
    model: {
      name: "モデル"
    }
  }
};
const TripleCLIPLoader$3 = {
  description: "[レシピ]\n\nsd3: clip-l, clip-g, t5",
  display_name: "トリプルCLIPを読み込む",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    clip_name3: {
      name: "clip_name3"
    }
  }
};
const UNETLoader$3 = {
  display_name: "拡散モデルを読み込む",
  inputs: {
    unet_name: {
      name: "unet_name"
    },
    weight_dtype: {
      name: "重みdtype"
    }
  }
};
const UNetCrossAttentionMultiply$3 = {
  display_name: "UNetクロス注意の乗算",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "モデル"
    },
    out: {
      name: "出力"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetSelfAttentionMultiply$3 = {
  display_name: "UNet自己注意の乗算",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "モデル"
    },
    out: {
      name: "出力"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetTemporalAttentionMultiply$3 = {
  display_name: "UNet時間的注意の乗算",
  inputs: {
    cross_structural: {
      name: "クロス構造"
    },
    cross_temporal: {
      name: "クロス時間"
    },
    model: {
      name: "モデル"
    },
    self_structural: {
      name: "自己構造"
    },
    self_temporal: {
      name: "自己時間"
    }
  }
};
const UpscaleModelLoader$3 = {
  display_name: "拡大モデルを読み込む",
  inputs: {
    model_name: {
      name: "モデル名"
    }
  }
};
const VAEDecode$3 = {
  description: "潜在画像をピクセル空間画像にデコードします。",
  display_name: "VAEデコード",
  inputs: {
    samples: {
      name: "サンプル",
      tooltip: "デコードされる潜在。"
    },
    vae: {
      name: "vae",
      tooltip: "潜在のデコードに使用されるVAEモデル。"
    }
  },
  outputs: {
    "0": {
      tooltip: "デコードされた画像。"
    }
  }
};
const VAEDecodeAudio$3 = {
  display_name: "VAEデコード音声",
  inputs: {
    samples: {
      name: "サンプル"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D$3 = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    num_chunks: {
      name: "num_chunks"
    },
    octree_resolution: {
      name: "octree_resolution"
    },
    samples: {
      name: "サンプル"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeTiled$3 = {
  display_name: "VAEデコード（タイル）",
  inputs: {
    overlap: {
      name: "オーバーラップ"
    },
    samples: {
      name: "サンプル"
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "ビデオVAE専用：重複するフレームの数。"
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "ビデオVAE専用：一度にデコードするフレームの数。"
    },
    tile_size: {
      name: "タイルサイズ"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncode$3 = {
  display_name: "VAEエンコード",
  inputs: {
    pixels: {
      name: "ピクセル"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio$3 = {
  display_name: "VAEエンコード音声",
  inputs: {
    audio: {
      name: "オーディオ"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint$3 = {
  display_name: "VAEエンコード（インペイント用）",
  inputs: {
    grow_mask_by: {
      name: "マスクの拡大"
    },
    mask: {
      name: "マスク"
    },
    pixels: {
      name: "ピクセル"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeTiled$3 = {
  display_name: "VAEエンコード（タイル）",
  inputs: {
    overlap: {
      name: "オーバーラップ"
    },
    pixels: {
      name: "ピクセル"
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "ビデオVAE専用：重複するフレームの数。"
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "ビデオVAE専用：一度にエンコードするフレームの数。"
    },
    tile_size: {
      name: "タイルサイズ"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAELoader$3 = {
  display_name: "VAEを読み込む",
  inputs: {
    vae_name: {
      name: "vae_name"
    }
  }
};
const VAESave$3 = {
  display_name: "VAEを保存",
  inputs: {
    filename_prefix: {
      name: "ファイル名プレフィックス"
    },
    vae: {
      name: "vae"
    }
  }
};
const VPScheduler$3 = {
  display_name: "VPスケジューラー",
  inputs: {
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    },
    steps: {
      name: "ステップ"
    }
  }
};
const VideoLinearCFGGuidance$3 = {
  display_name: "ビデオ線形CFGガイダンス",
  inputs: {
    min_cfg: {
      name: "最小cfg"
    },
    model: {
      name: "モデル"
    }
  }
};
const VideoTriangleCFGGuidance$3 = {
  display_name: "ビデオ三角形CFGガイダンス",
  inputs: {
    min_cfg: {
      name: "最小cfg"
    },
    model: {
      name: "モデル"
    }
  }
};
const VoxelToMeshBasic$3 = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    threshold: {
      name: "閾値"
    },
    voxel: {
      name: "ボクセル"
    }
  }
};
const WanImageToVideo$3 = {
  display_name: "Wan画像からビデオへ",
  inputs: {
    batch_size: {
      name: "バッチサイズ"
    },
    clip_vision_output: {
      name: "clipビジョン出力"
    },
    height: {
      name: "高さ"
    },
    length: {
      name: "長さ"
    },
    negative: {
      name: "ネガティブ"
    },
    positive: {
      name: "ポジティブ"
    },
    start_image: {
      name: "開始画像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "幅"
    }
  },
  outputs: {
    "0": {
      name: "ポジティブ"
    },
    "1": {
      name: "ネガティブ"
    },
    "2": {
      name: "潜在"
    }
  }
};
const WebcamCapture$3 = {
  display_name: "ウェブカメラキャプチャ",
  inputs: {
    capture_on_queue: {
      name: "キューでキャプチャ"
    },
    height: {
      name: "高さ"
    },
    image: {
      name: "画像"
    },
    "waiting for camera___": {},
    width: {
      name: "幅"
    }
  }
};
const unCLIPCheckpointLoader$3 = {
  display_name: "unCLIPチェックポイントローダー",
  inputs: {
    ckpt_name: {
      name: "ckpt_name"
    }
  }
};
const unCLIPConditioning$3 = {
  display_name: "unCLIP条件付け",
  inputs: {
    clip_vision_output: {
      name: "clip_vision_output"
    },
    conditioning: {
      name: "コンディショニング"
    },
    noise_augmentation: {
      name: "ノイズ増強"
    },
    strength: {
      name: "強度"
    }
  }
};
const jaNodes = {
  AddNoise: AddNoise$3,
  AlignYourStepsScheduler: AlignYourStepsScheduler$3,
  BasicGuider: BasicGuider$3,
  BasicScheduler: BasicScheduler$3,
  BetaSamplingScheduler: BetaSamplingScheduler$3,
  CFGGuider: CFGGuider$3,
  CLIPAttentionMultiply: CLIPAttentionMultiply$3,
  CLIPLoader: CLIPLoader$3,
  CLIPMergeAdd: CLIPMergeAdd$3,
  CLIPMergeSimple: CLIPMergeSimple$3,
  CLIPMergeSubtract: CLIPMergeSubtract$3,
  CLIPSave: CLIPSave$3,
  CLIPSetLastLayer: CLIPSetLastLayer$3,
  CLIPTextEncode: CLIPTextEncode$3,
  CLIPTextEncodeControlnet: CLIPTextEncodeControlnet$3,
  CLIPTextEncodeFlux: CLIPTextEncodeFlux$3,
  CLIPTextEncodeHunyuanDiT: CLIPTextEncodeHunyuanDiT$3,
  CLIPTextEncodeLumina2: CLIPTextEncodeLumina2$3,
  CLIPTextEncodePixArtAlpha: CLIPTextEncodePixArtAlpha$3,
  CLIPTextEncodeSD3: CLIPTextEncodeSD3$3,
  CLIPTextEncodeSDXL: CLIPTextEncodeSDXL$3,
  CLIPTextEncodeSDXLRefiner: CLIPTextEncodeSDXLRefiner$3,
  CLIPVisionEncode: CLIPVisionEncode$3,
  CLIPVisionLoader: CLIPVisionLoader$3,
  Canny: Canny$3,
  CheckpointLoader: CheckpointLoader$3,
  CheckpointLoaderSimple: CheckpointLoaderSimple$3,
  CheckpointSave: CheckpointSave$3,
  CombineHooks2: CombineHooks2$3,
  CombineHooks4: CombineHooks4$3,
  CombineHooks8: CombineHooks8$3,
  ConditioningAverage: ConditioningAverage$3,
  ConditioningCombine: ConditioningCombine$3,
  ConditioningConcat: ConditioningConcat$3,
  ConditioningSetArea: ConditioningSetArea$3,
  ConditioningSetAreaPercentage: ConditioningSetAreaPercentage$3,
  ConditioningSetAreaPercentageVideo: ConditioningSetAreaPercentageVideo$3,
  ConditioningSetAreaStrength: ConditioningSetAreaStrength$3,
  ConditioningSetDefaultCombine: ConditioningSetDefaultCombine$3,
  ConditioningSetMask: ConditioningSetMask$3,
  ConditioningSetProperties: ConditioningSetProperties$3,
  ConditioningSetPropertiesAndCombine: ConditioningSetPropertiesAndCombine$3,
  ConditioningSetTimestepRange: ConditioningSetTimestepRange$3,
  ConditioningStableAudio: ConditioningStableAudio$3,
  ConditioningTimestepsRange: ConditioningTimestepsRange$3,
  ConditioningZeroOut: ConditioningZeroOut$3,
  ControlNetApply: ControlNetApply$3,
  ControlNetApplyAdvanced: ControlNetApplyAdvanced$3,
  ControlNetApplySD3: ControlNetApplySD3$3,
  ControlNetInpaintingAliMamaApply: ControlNetInpaintingAliMamaApply$3,
  ControlNetLoader: ControlNetLoader$3,
  CosmosImageToVideoLatent: CosmosImageToVideoLatent$3,
  CreateHookKeyframe: CreateHookKeyframe$3,
  CreateHookKeyframesFromFloats: CreateHookKeyframesFromFloats$3,
  CreateHookKeyframesInterpolated: CreateHookKeyframesInterpolated$3,
  CreateHookLora: CreateHookLora$3,
  CreateHookLoraModelOnly: CreateHookLoraModelOnly$3,
  CreateHookModelAsLora: CreateHookModelAsLora$3,
  CreateHookModelAsLoraModelOnly: CreateHookModelAsLoraModelOnly$3,
  CropMask: CropMask$3,
  DiffControlNetLoader: DiffControlNetLoader$3,
  DifferentialDiffusion: DifferentialDiffusion$3,
  DiffusersLoader: DiffusersLoader$3,
  DisableNoise: DisableNoise$3,
  DualCFGGuider: DualCFGGuider$3,
  DualCLIPLoader: DualCLIPLoader$3,
  EmptyCosmosLatentVideo: EmptyCosmosLatentVideo$3,
  EmptyHunyuanLatentVideo: EmptyHunyuanLatentVideo$3,
  EmptyImage: EmptyImage$3,
  EmptyLTXVLatentVideo: EmptyLTXVLatentVideo$3,
  EmptyLatentAudio: EmptyLatentAudio$3,
  EmptyLatentHunyuan3Dv2: EmptyLatentHunyuan3Dv2$3,
  EmptyLatentImage: EmptyLatentImage$3,
  EmptyMochiLatentVideo: EmptyMochiLatentVideo$3,
  EmptySD3LatentImage: EmptySD3LatentImage$3,
  ExponentialScheduler: ExponentialScheduler$3,
  FeatherMask: FeatherMask$3,
  FlipSigmas: FlipSigmas$3,
  FluxDisableGuidance: FluxDisableGuidance$3,
  FluxGuidance: FluxGuidance$3,
  FreeU: FreeU$3,
  FreeU_V2: FreeU_V2$3,
  GITSScheduler: GITSScheduler$3,
  GLIGENLoader: GLIGENLoader$3,
  GLIGENTextBoxApply: GLIGENTextBoxApply$3,
  GrowMask: GrowMask$3,
  Hunyuan3Dv2Conditioning: Hunyuan3Dv2Conditioning$3,
  Hunyuan3Dv2ConditioningMultiView: Hunyuan3Dv2ConditioningMultiView$3,
  HunyuanImageToVideo: HunyuanImageToVideo$3,
  HyperTile: HyperTile$3,
  HypernetworkLoader: HypernetworkLoader$3,
  ImageBatch: ImageBatch$3,
  ImageBlend: ImageBlend$3,
  ImageBlur: ImageBlur$3,
  ImageColorToMask: ImageColorToMask$3,
  ImageCompositeMasked: ImageCompositeMasked$3,
  ImageCrop: ImageCrop$3,
  ImageFromBatch: ImageFromBatch$3,
  ImageInvert: ImageInvert$3,
  ImageOnlyCheckpointLoader: ImageOnlyCheckpointLoader$3,
  ImageOnlyCheckpointSave: ImageOnlyCheckpointSave$3,
  ImagePadForOutpaint: ImagePadForOutpaint$3,
  ImageQuantize: ImageQuantize$3,
  ImageScale: ImageScale$3,
  ImageScaleBy: ImageScaleBy$3,
  ImageScaleToTotalPixels: ImageScaleToTotalPixels$3,
  ImageSharpen: ImageSharpen$3,
  ImageToMask: ImageToMask$3,
  ImageUpscaleWithModel: ImageUpscaleWithModel$3,
  InpaintModelConditioning: InpaintModelConditioning$3,
  InstructPixToPixConditioning: InstructPixToPixConditioning$3,
  InvertMask: InvertMask$3,
  JoinImageWithAlpha: JoinImageWithAlpha$3,
  KSampler: KSampler$3,
  KSamplerAdvanced: KSamplerAdvanced$3,
  KSamplerSelect: KSamplerSelect$3,
  KarrasScheduler: KarrasScheduler$3,
  LTXVAddGuide: LTXVAddGuide$3,
  LTXVConditioning: LTXVConditioning$3,
  LTXVCropGuides: LTXVCropGuides$3,
  LTXVImgToVideo: LTXVImgToVideo$3,
  LTXVPreprocess: LTXVPreprocess$3,
  LTXVScheduler: LTXVScheduler$3,
  LaplaceScheduler: LaplaceScheduler$3,
  LatentAdd: LatentAdd$3,
  LatentApplyOperation: LatentApplyOperation$3,
  LatentApplyOperationCFG: LatentApplyOperationCFG$3,
  LatentBatch: LatentBatch$3,
  LatentBatchSeedBehavior: LatentBatchSeedBehavior$3,
  LatentBlend: LatentBlend$3,
  LatentComposite: LatentComposite$3,
  LatentCompositeMasked: LatentCompositeMasked$3,
  LatentCrop: LatentCrop$3,
  LatentFlip: LatentFlip$3,
  LatentFromBatch: LatentFromBatch$3,
  LatentInterpolate: LatentInterpolate$3,
  LatentMultiply: LatentMultiply$3,
  LatentOperationSharpen: LatentOperationSharpen$3,
  LatentOperationTonemapReinhard: LatentOperationTonemapReinhard$3,
  LatentRotate: LatentRotate$3,
  LatentSubtract: LatentSubtract$3,
  LatentUpscale: LatentUpscale$3,
  LatentUpscaleBy: LatentUpscaleBy$3,
  Load3D: Load3D$3,
  Load3DAnimation: Load3DAnimation$3,
  LoadAudio: LoadAudio$3,
  LoadImage: LoadImage$3,
  LoadImageMask: LoadImageMask$3,
  LoadImageOutput: LoadImageOutput$3,
  LoadLatent: LoadLatent$3,
  LoraLoader: LoraLoader$3,
  LoraLoaderModelOnly: LoraLoaderModelOnly$3,
  LoraSave: LoraSave$3,
  Mahiro: Mahiro$3,
  MaskComposite: MaskComposite$3,
  MaskToImage: MaskToImage$3,
  ModelComputeDtype: ModelComputeDtype$3,
  ModelMergeAdd: ModelMergeAdd$3,
  ModelMergeAuraflow: ModelMergeAuraflow$3,
  ModelMergeBlocks: ModelMergeBlocks$3,
  ModelMergeCosmos14B: ModelMergeCosmos14B$3,
  ModelMergeCosmos7B: ModelMergeCosmos7B$3,
  ModelMergeFlux1: ModelMergeFlux1$3,
  ModelMergeLTXV: ModelMergeLTXV$3,
  ModelMergeMochiPreview: ModelMergeMochiPreview$3,
  ModelMergeSD1: ModelMergeSD1$3,
  ModelMergeSD2: ModelMergeSD2$3,
  ModelMergeSD35_Large: ModelMergeSD35_Large$3,
  ModelMergeSD3_2B: ModelMergeSD3_2B$3,
  ModelMergeSDXL: ModelMergeSDXL$3,
  ModelMergeSimple: ModelMergeSimple$3,
  ModelMergeSubtract: ModelMergeSubtract$3,
  ModelSamplingAuraFlow: ModelSamplingAuraFlow$3,
  ModelSamplingContinuousEDM: ModelSamplingContinuousEDM$3,
  ModelSamplingContinuousV: ModelSamplingContinuousV$3,
  ModelSamplingDiscrete: ModelSamplingDiscrete$3,
  ModelSamplingFlux: ModelSamplingFlux$3,
  ModelSamplingLTXV: ModelSamplingLTXV$3,
  ModelSamplingSD3: ModelSamplingSD3$3,
  ModelSamplingStableCascade: ModelSamplingStableCascade$3,
  ModelSave: ModelSave$3,
  Morphology: Morphology$3,
  PairConditioningCombine: PairConditioningCombine$3,
  PairConditioningSetDefaultCombine: PairConditioningSetDefaultCombine$3,
  PairConditioningSetProperties: PairConditioningSetProperties$3,
  PairConditioningSetPropertiesAndCombine: PairConditioningSetPropertiesAndCombine$3,
  PatchModelAddDownscale: PatchModelAddDownscale$3,
  PerpNeg: PerpNeg$3,
  PerpNegGuider: PerpNegGuider$3,
  PerturbedAttentionGuidance: PerturbedAttentionGuidance$3,
  PhotoMakerEncode: PhotoMakerEncode$3,
  PhotoMakerLoader: PhotoMakerLoader$3,
  PolyexponentialScheduler: PolyexponentialScheduler$3,
  PorterDuffImageComposite: PorterDuffImageComposite$3,
  Preview3D: Preview3D$3,
  Preview3DAnimation: Preview3DAnimation$3,
  PreviewAudio: PreviewAudio$3,
  PreviewImage: PreviewImage$3,
  RandomNoise: RandomNoise$3,
  RebatchImages: RebatchImages$3,
  RebatchLatents: RebatchLatents$3,
  RenormCFG: RenormCFG$3,
  RepeatImageBatch: RepeatImageBatch$3,
  RepeatLatentBatch: RepeatLatentBatch$3,
  RescaleCFG: RescaleCFG$3,
  SDTurboScheduler: SDTurboScheduler$3,
  SD_4XUpscale_Conditioning: SD_4XUpscale_Conditioning$3,
  SV3D_Conditioning: SV3D_Conditioning$3,
  SVD_img2vid_Conditioning: SVD_img2vid_Conditioning$3,
  SamplerCustom: SamplerCustom$3,
  SamplerCustomAdvanced: SamplerCustomAdvanced$3,
  SamplerDPMAdaptative: SamplerDPMAdaptative$3,
  SamplerDPMPP_2M_SDE: SamplerDPMPP_2M_SDE$3,
  SamplerDPMPP_2S_Ancestral: SamplerDPMPP_2S_Ancestral$3,
  SamplerDPMPP_3M_SDE: SamplerDPMPP_3M_SDE$3,
  SamplerDPMPP_SDE: SamplerDPMPP_SDE$3,
  SamplerEulerAncestral: SamplerEulerAncestral$3,
  SamplerEulerAncestralCFGPP: SamplerEulerAncestralCFGPP$3,
  SamplerEulerCFGpp: SamplerEulerCFGpp$3,
  SamplerLCMUpscale: SamplerLCMUpscale$3,
  SamplerLMS: SamplerLMS$3,
  SaveAnimatedPNG: SaveAnimatedPNG$3,
  SaveAnimatedWEBP: SaveAnimatedWEBP$3,
  SaveAudio: SaveAudio$3,
  SaveGLB: SaveGLB$3,
  SaveImage: SaveImage$3,
  SaveImageWebsocket: SaveImageWebsocket$3,
  SaveLatent: SaveLatent$3,
  SaveWEBM: SaveWEBM$3,
  SelfAttentionGuidance: SelfAttentionGuidance$3,
  SetClipHooks: SetClipHooks$3,
  SetFirstSigma: SetFirstSigma$3,
  SetHookKeyframes: SetHookKeyframes$3,
  SetLatentNoiseMask: SetLatentNoiseMask$3,
  SetUnionControlNetType: SetUnionControlNetType$3,
  SkipLayerGuidanceDiT: SkipLayerGuidanceDiT$3,
  SkipLayerGuidanceSD3: SkipLayerGuidanceSD3$3,
  SolidMask: SolidMask$3,
  SplitImageWithAlpha: SplitImageWithAlpha$3,
  SplitSigmas: SplitSigmas$3,
  SplitSigmasDenoise: SplitSigmasDenoise$3,
  StableCascade_EmptyLatentImage: StableCascade_EmptyLatentImage$3,
  StableCascade_StageB_Conditioning: StableCascade_StageB_Conditioning$3,
  StableCascade_StageC_VAEEncode: StableCascade_StageC_VAEEncode$3,
  StableCascade_SuperResolutionControlnet: StableCascade_SuperResolutionControlnet$3,
  StableZero123_Conditioning: StableZero123_Conditioning$3,
  StableZero123_Conditioning_Batched: StableZero123_Conditioning_Batched$3,
  StyleModelApply: StyleModelApply$3,
  StyleModelLoader: StyleModelLoader$3,
  TextEncodeHunyuanVideo_ImageToVideo: TextEncodeHunyuanVideo_ImageToVideo$3,
  ThresholdMask: ThresholdMask$3,
  TomePatchModel: TomePatchModel$3,
  TorchCompileModel: TorchCompileModel$3,
  TripleCLIPLoader: TripleCLIPLoader$3,
  UNETLoader: UNETLoader$3,
  UNetCrossAttentionMultiply: UNetCrossAttentionMultiply$3,
  UNetSelfAttentionMultiply: UNetSelfAttentionMultiply$3,
  UNetTemporalAttentionMultiply: UNetTemporalAttentionMultiply$3,
  UpscaleModelLoader: UpscaleModelLoader$3,
  VAEDecode: VAEDecode$3,
  VAEDecodeAudio: VAEDecodeAudio$3,
  VAEDecodeHunyuan3D: VAEDecodeHunyuan3D$3,
  VAEDecodeTiled: VAEDecodeTiled$3,
  VAEEncode: VAEEncode$3,
  VAEEncodeAudio: VAEEncodeAudio$3,
  VAEEncodeForInpaint: VAEEncodeForInpaint$3,
  VAEEncodeTiled: VAEEncodeTiled$3,
  VAELoader: VAELoader$3,
  VAESave: VAESave$3,
  VPScheduler: VPScheduler$3,
  VideoLinearCFGGuidance: VideoLinearCFGGuidance$3,
  VideoTriangleCFGGuidance: VideoTriangleCFGGuidance$3,
  VoxelToMeshBasic: VoxelToMeshBasic$3,
  WanImageToVideo: WanImageToVideo$3,
  WebcamCapture: WebcamCapture$3,
  unCLIPCheckpointLoader: unCLIPCheckpointLoader$3,
  unCLIPConditioning: unCLIPConditioning$3
};
const Comfy_Canvas_SelectionToolbox$3 = {
  name: "選択ツールボックスを表示"
};
const Comfy_ConfirmClear$3 = {
  name: "ワークフローをクリアする際に確認を要求する"
};
const Comfy_DOMClippingEnabled$3 = {
  name: "DOM要素のクリッピングを有効にする（有効にするとパフォーマンスが低下する可能性があります）"
};
const Comfy_DevMode$3 = {
  name: "開発モードオプションを有効にする（API保存など）"
};
const Comfy_DisableFloatRounding$3 = {
  name: "デフォルトの浮動小数点ウィジェットの丸めを無効にする。",
  tooltip: "(ページの再読み込みが必要) バックエンドのノードで丸めが設定されている場合、丸めを無効にすることはできません。"
};
const Comfy_DisableSliders$3 = {
  name: "ノードウィジェットスライダーを無効にする"
};
const Comfy_EditAttention_Delta$3 = {
  name: "Ctrl+上/下の精度"
};
const Comfy_EnableTooltips$3 = {
  name: "ツールチップを有効にする"
};
const Comfy_EnableWorkflowViewRestore$3 = {
  name: "ワークフロー内のキャンバスの位置とズームレベルを保存および復元する"
};
const Comfy_FloatRoundingPrecision$3 = {
  name: "浮動小数点ウィジェットの丸め小数点数 [0 = 自動]。",
  tooltip: "(ページの再読み込みが必要)"
};
const Comfy_Graph_CanvasInfo$3 = {
  name: "左下隅にキャンバス情報を表示する（fpsなど）"
};
const Comfy_Graph_CanvasMenu$3 = {
  name: "グラフキャンバスメニューを表示する"
};
const Comfy_Graph_CtrlShiftZoom$3 = {
  name: "ファストズームショートカットを有効にする（Ctrl + Shift + ドラッグ）"
};
const Comfy_Graph_LinkMarkers$3 = {
  name: "リンク中点マーカー",
  options: {
    Arrow: "矢印",
    Circle: "円",
    None: "なし"
  }
};
const Comfy_Graph_ZoomSpeed$3 = {
  name: "キャンバスズーム速度"
};
const Comfy_GroupSelectedNodes_Padding$3 = {
  name: "選択したノードのパディング"
};
const Comfy_Group_DoubleClickTitleToEdit$3 = {
  name: "グループタイトルをダブルクリックして編集"
};
const Comfy_LinkRelease_Action$3 = {
  name: "リンクリリース時のアクション（修飾子なし）",
  options: {
    "context menu": "コンテキストメニュー",
    "no action": "アクションなし",
    "search box": "検索ボックス"
  }
};
const Comfy_LinkRelease_ActionShift$3 = {
  name: "リンクリリース時のアクション（Shift）",
  options: {
    "context menu": "コンテキストメニュー",
    "no action": "アクションなし",
    "search box": "検索ボックス"
  }
};
const Comfy_LinkRenderMode$3 = {
  name: "リンクレンダーモード",
  options: {
    Hidden: "隠す",
    Linear: "リニア",
    Spline: "スプライン",
    Straight: "ストレート"
  }
};
const Comfy_Locale$3 = {
  name: "言語"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed$3 = {
  name: "ブラシ調整速度の倍率",
  tooltip: "調整時にブラシのサイズと硬さがどれだけ速く変化するかを制御します。値が高いほど、変化が速くなります。"
};
const Comfy_MaskEditor_UseDominantAxis$3 = {
  name: "ブラシ調整を優先軸に固定する",
  tooltip: "有効にすると、ブラシの調整は、どの方向に多く動かすかに基づいて、サイズまたは硬さのいずれかにのみ影響します。"
};
const Comfy_MaskEditor_UseNewEditor$3 = {
  name: "新しいマスクエディタを使用する",
  tooltip: "新しいマスクエディタインターフェースに切り替えます。"
};
const Comfy_ModelLibrary_AutoLoadAll$3 = {
  name: "すべてのモデルフォルダーを自動的に読み込む",
  tooltip: "trueの場合、モデルライブラリを開くとすぐにすべてのフォルダーが読み込まれます（これにより読み込み中に遅延が発生する可能性があります）。falseの場合、ルートレベルのモデルフォルダーはクリックするまで読み込まれません。"
};
const Comfy_ModelLibrary_NameFormat$3 = {
  name: "モデルライブラリツリービューに表示する名前",
  options: {
    filename: "ファイル名",
    title: "タイトル"
  },
  tooltip: '"ファイル名"を選択すると、モデルリストにディレクトリや".safetensors"拡張子なしの生のファイル名の簡略化されたビューが表示されます。"タイトル"を選択すると、設定可能なモデルメタデータタイトルが表示されます。'
};
const Comfy_NodeBadge_NodeIdBadgeMode$3 = {
  name: "ノードIDバッジモード",
  options: {
    None: "なし",
    "Show all": "すべて表示"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode$3 = {
  name: "ノードライフサイクルバッジモード",
  options: {
    None: "なし",
    "Show all": "すべて表示"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode$3 = {
  name: "ノードソースバッジモード",
  options: {
    "Hide built-in": "組み込みを隠す",
    None: "なし",
    "Show all": "すべて表示"
  }
};
const Comfy_NodeInputConversionSubmenus$3 = {
  name: "ノードのコンテキストメニューに、入力/ウィジェット間の変換を行うエントリをサブメニューに配置します。"
};
const Comfy_NodeSearchBoxImpl$3 = {
  name: "ノード検索ボックスの実装",
  options: {
    "default": "デフォルト",
    "litegraph (legacy)": "litegraph (レガシー)"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview$3 = {
  name: "ノードプレビュー",
  tooltip: "デフォルトの実装にのみ適用されます"
};
const Comfy_NodeSearchBoxImpl_ShowCategory$3 = {
  name: "検索結果にノードカテゴリを表示",
  tooltip: "デフォルトの実装にのみ適用されます"
};
const Comfy_NodeSearchBoxImpl_ShowIdName$3 = {
  name: "検索結果にノードID名を表示",
  tooltip: "デフォルトの実装にのみ適用されます"
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency$3 = {
  name: "検索結果にノード頻度を表示",
  tooltip: "デフォルトの実装にのみ適用されます"
};
const Comfy_NodeSuggestions_number$3 = {
  name: "ノード提案の数",
  tooltip: "ライトグラフの検索ボックス/コンテキストメニュー専用"
};
const Comfy_Node_AutoSnapLinkToSlot$3 = {
  name: "ノードスロットにリンクを自動スナップ",
  tooltip: "ノードの上にリンクをドラッグすると、リンクがノードの有効な入力スロットに自動的にスナップします"
};
const Comfy_Node_BypassAllLinksOnDelete$3 = {
  name: "ノード削除時にすべてのリンクを保持",
  tooltip: "ノードを削除する際、削除されたノードをバイパスしてすべての入力および出力リンクを再接続しようとします"
};
const Comfy_Node_DoubleClickTitleToEdit$3 = {
  name: "ノードタイトルをダブルクリックして編集"
};
const Comfy_Node_MiddleClickRerouteNode$3 = {
  name: "ミドルクリックで新しいリルートノードを作成"
};
const Comfy_Node_Opacity$3 = {
  name: "ノードの不透明度"
};
const Comfy_Node_ShowDeprecated$3 = {
  name: "検索で非推奨ノードを表示",
  tooltip: "非推奨ノードはデフォルトでUIに隠されていますが、それを使用する既存のワークフローでは機能し続けます。"
};
const Comfy_Node_ShowExperimental$3 = {
  name: "検索で実験的ノードを表示",
  tooltip: "実験的ノードはUIでそのようにマークされており、将来のバージョンで大幅な変更や削除の対象となる可能性があります。生産ワークフローでの使用には注意が必要です"
};
const Comfy_Node_SnapHighlightsNode$3 = {
  name: "スナップハイライトノード",
  tooltip: "有効な入力スロットを持つノードの上にリンクをドラッグすると、ノードがハイライトされます"
};
const Comfy_Pointer_ClickBufferTime$3 = {
  name: "ポインタークリックドリフト遅延",
  tooltip: "ポインターボタンを押した後、ポインタの動きが無視される最大時間（ミリ秒単位）です。\n\nクリック中にポインタが移動した場合、オブジェクトが意図せず動かされるのを防ぎます。"
};
const Comfy_Pointer_ClickDrift$3 = {
  name: "ポインタークリックドリフト（最大距離）",
  tooltip: "ボタンを押し続けている間にポインタがこの距離以上移動した場合、クリックではなくドラッグと見なされます。\n\nクリック中にポインタが移動した場合、オブジェクトが意図せず動かされるのを防ぎます。"
};
const Comfy_Pointer_DoubleClickTime$3 = {
  name: "ダブルクリック間隔（最大）",
  tooltip: "ダブルクリックの2回のクリック間の最大時間（ミリ秒単位）。この値を増やすことで、ダブルクリックが時々登録されない場合に助けになるかもしれません。"
};
const Comfy_PreviewFormat$3 = {
  name: "プレビュー画像フォーマット",
  tooltip: "画像ウィジェットでプレビューを表示する際、軽量画像に変換します（例：webp、jpeg、webp;50など）。"
};
const Comfy_PromptFilename$3 = {
  name: "ワークフローを保存する際にファイル名を入力するよう促す"
};
const Comfy_QueueButton_BatchCountLimit$3 = {
  name: "バッチ数制限",
  tooltip: "1回のボタンクリックでキューに追加できるタスクの最大数"
};
const Comfy_Queue_MaxHistoryItems$3 = {
  name: "キュー履歴サイズ",
  tooltip: "キュー履歴に表示されるタスクの最大数。"
};
const Comfy_RerouteBeta$3 = {
  name: "リルートベータテストに参加する",
  tooltip: "新しいネイティブリルートを有効にします。\n\nリルートは、リンクラインからドラッグしながらaltを押すか、リンクメニューで追加できます。\n\nこのオプションを無効にしても破壊的ではなく、リルートは隠されます。"
};
const Comfy_Sidebar_Location$3 = {
  name: "サイドバーの位置",
  options: {
    left: "左",
    right: "右"
  }
};
const Comfy_Sidebar_Size$3 = {
  name: "サイドバーのサイズ",
  options: {
    normal: "通常",
    small: "小"
  }
};
const Comfy_SnapToGrid_GridSize$3 = {
  name: "グリッドサイズにスナップ",
  tooltip: "シフトを押しながらノードをドラッグおよびサイズ変更すると、グリッドに整列されます。これにより、そのグリッドのサイズが制御されます。"
};
const Comfy_TextareaWidget_FontSize$3 = {
  name: "テキストエリアウィジェットのフォントサイズ"
};
const Comfy_TextareaWidget_Spellcheck$3 = {
  name: "テキストエリアウィジェットのスペルチェック"
};
const Comfy_TreeExplorer_ItemPadding$3 = {
  name: "ツリーエクスプローラーアイテムのパディング"
};
const Comfy_UseNewMenu$3 = {
  name: "新しいメニューを使用",
  options: {
    Bottom: "下",
    Disabled: "無効",
    Top: "上"
  }
};
const Comfy_Validation_NodeDefs$3 = {
  name: "ノード定義を検証（遅い）",
  tooltip: "ノード開発者に推奨されます。これにより、起動時にすべてのノード定義が検証されます。"
};
const Comfy_Validation_Workflows$3 = {
  name: "ワークフローを検証"
};
const Comfy_WidgetControlMode$3 = {
  name: "ウィジェット制御モード",
  options: {
    after: "後",
    before: "前"
  },
  tooltip: "ウィジェットの値が更新されるタイミングを制御します（ランダム化/インクリメント/デクリメント）、プロンプトがキューに入れられる前または後のいずれかです。"
};
const Comfy_Window_UnloadConfirmation$3 = {
  name: "ウィンドウを閉じるときに確認を表示"
};
const Comfy_Workflow_ConfirmDelete$3 = {
  name: "ワークフローを削除する際に確認を表示"
};
const Comfy_Workflow_ShowMissingModelsWarning$3 = {
  name: "欠落しているモデルの警告を表示"
};
const Comfy_Workflow_ShowMissingNodesWarning$3 = {
  name: "欠落しているノードの警告を表示"
};
const Comfy_Workflow_SortNodeIdOnSave$3 = {
  name: "ワークフローを保存する際にノードIDをソート"
};
const Comfy_Workflow_WorkflowTabsPosition$3 = {
  name: "開いているワークフローの位置",
  options: {
    Sidebar: "サイドバー",
    Topbar: "トップバー",
    "Topbar (2nd-row)": "トップバー（2行目）"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold$3 = {
  name: "低品質レンダリングズーム閾値",
  tooltip: "ズームアウト時に低品質の形状をレンダリングする"
};
const LiteGraph_Canvas_MaximumFps$3 = {
  name: "最大FPS",
  tooltip: "キャンバスがレンダリングできる最大フレーム数です。スムーズさの代わりにGPU使用量を制限します。0の場合、画面のリフレッシュレートが使用されます。デフォルト：0"
};
const LiteGraph_ContextMenu_Scaling$3 = {
  name: "ズームイン時にノードコンボウィジェットメニュー（リスト）をスケーリングする"
};
const LiteGraph_Node_TooltipDelay$3 = {
  name: "ツールチップ遅延"
};
const pysssss_SnapToGrid$3 = {
  name: "常にグリッドにスナップ"
};
const jaSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "自動的に更新を確認する"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "匿名の使用統計を送信する"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "Pypi インストールミラー",
    tooltip: "デフォルトの pip インストールミラー"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Python Install Mirror",
    tooltip: "管理されたPythonのインストールは、Astral python-build-standaloneプロジェクトからダウンロードされます。この変数は、Pythonのインストールのための異なるソースを使用するためのミラーURLに設定することができます。提供されたURLは、例えば、https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gzの中でhttps://github.com/astral-sh/python-build-standalone/releases/downloadを置き換えます。ディストリビューションは、file:// URLスキームを使用してローカルディレクトリから読み取ることができます。"
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "Torch Install Mirror",
    tooltip: "pytorchのpipインストールミラー"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "ウィンドウスタイル",
    options: {
      custom: "カスタム",
      "default": "デフォルト"
    },
    tooltip: "システムタイトルバーを非表示にするにはカスタムオプションを選択してください"
  },
  Comfy_Canvas_SelectionToolbox: Comfy_Canvas_SelectionToolbox$3,
  Comfy_ConfirmClear: Comfy_ConfirmClear$3,
  Comfy_DOMClippingEnabled: Comfy_DOMClippingEnabled$3,
  Comfy_DevMode: Comfy_DevMode$3,
  Comfy_DisableFloatRounding: Comfy_DisableFloatRounding$3,
  Comfy_DisableSliders: Comfy_DisableSliders$3,
  Comfy_EditAttention_Delta: Comfy_EditAttention_Delta$3,
  Comfy_EnableTooltips: Comfy_EnableTooltips$3,
  Comfy_EnableWorkflowViewRestore: Comfy_EnableWorkflowViewRestore$3,
  Comfy_FloatRoundingPrecision: Comfy_FloatRoundingPrecision$3,
  Comfy_Graph_CanvasInfo: Comfy_Graph_CanvasInfo$3,
  Comfy_Graph_CanvasMenu: Comfy_Graph_CanvasMenu$3,
  Comfy_Graph_CtrlShiftZoom: Comfy_Graph_CtrlShiftZoom$3,
  Comfy_Graph_LinkMarkers: Comfy_Graph_LinkMarkers$3,
  Comfy_Graph_ZoomSpeed: Comfy_Graph_ZoomSpeed$3,
  Comfy_GroupSelectedNodes_Padding: Comfy_GroupSelectedNodes_Padding$3,
  Comfy_Group_DoubleClickTitleToEdit: Comfy_Group_DoubleClickTitleToEdit$3,
  Comfy_LinkRelease_Action: Comfy_LinkRelease_Action$3,
  Comfy_LinkRelease_ActionShift: Comfy_LinkRelease_ActionShift$3,
  Comfy_LinkRenderMode: Comfy_LinkRenderMode$3,
  Comfy_Locale: Comfy_Locale$3,
  Comfy_MaskEditor_BrushAdjustmentSpeed: Comfy_MaskEditor_BrushAdjustmentSpeed$3,
  Comfy_MaskEditor_UseDominantAxis: Comfy_MaskEditor_UseDominantAxis$3,
  Comfy_MaskEditor_UseNewEditor: Comfy_MaskEditor_UseNewEditor$3,
  Comfy_ModelLibrary_AutoLoadAll: Comfy_ModelLibrary_AutoLoadAll$3,
  Comfy_ModelLibrary_NameFormat: Comfy_ModelLibrary_NameFormat$3,
  Comfy_NodeBadge_NodeIdBadgeMode: Comfy_NodeBadge_NodeIdBadgeMode$3,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode: Comfy_NodeBadge_NodeLifeCycleBadgeMode$3,
  Comfy_NodeBadge_NodeSourceBadgeMode: Comfy_NodeBadge_NodeSourceBadgeMode$3,
  Comfy_NodeInputConversionSubmenus: Comfy_NodeInputConversionSubmenus$3,
  Comfy_NodeSearchBoxImpl: Comfy_NodeSearchBoxImpl$3,
  Comfy_NodeSearchBoxImpl_NodePreview: Comfy_NodeSearchBoxImpl_NodePreview$3,
  Comfy_NodeSearchBoxImpl_ShowCategory: Comfy_NodeSearchBoxImpl_ShowCategory$3,
  Comfy_NodeSearchBoxImpl_ShowIdName: Comfy_NodeSearchBoxImpl_ShowIdName$3,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency: Comfy_NodeSearchBoxImpl_ShowNodeFrequency$3,
  Comfy_NodeSuggestions_number: Comfy_NodeSuggestions_number$3,
  Comfy_Node_AutoSnapLinkToSlot: Comfy_Node_AutoSnapLinkToSlot$3,
  Comfy_Node_BypassAllLinksOnDelete: Comfy_Node_BypassAllLinksOnDelete$3,
  Comfy_Node_DoubleClickTitleToEdit: Comfy_Node_DoubleClickTitleToEdit$3,
  Comfy_Node_MiddleClickRerouteNode: Comfy_Node_MiddleClickRerouteNode$3,
  Comfy_Node_Opacity: Comfy_Node_Opacity$3,
  Comfy_Node_ShowDeprecated: Comfy_Node_ShowDeprecated$3,
  Comfy_Node_ShowExperimental: Comfy_Node_ShowExperimental$3,
  Comfy_Node_SnapHighlightsNode: Comfy_Node_SnapHighlightsNode$3,
  Comfy_Pointer_ClickBufferTime: Comfy_Pointer_ClickBufferTime$3,
  Comfy_Pointer_ClickDrift: Comfy_Pointer_ClickDrift$3,
  Comfy_Pointer_DoubleClickTime: Comfy_Pointer_DoubleClickTime$3,
  Comfy_PreviewFormat: Comfy_PreviewFormat$3,
  Comfy_PromptFilename: Comfy_PromptFilename$3,
  Comfy_QueueButton_BatchCountLimit: Comfy_QueueButton_BatchCountLimit$3,
  Comfy_Queue_MaxHistoryItems: Comfy_Queue_MaxHistoryItems$3,
  Comfy_RerouteBeta: Comfy_RerouteBeta$3,
  Comfy_Sidebar_Location: Comfy_Sidebar_Location$3,
  Comfy_Sidebar_Size: Comfy_Sidebar_Size$3,
  Comfy_SnapToGrid_GridSize: Comfy_SnapToGrid_GridSize$3,
  Comfy_TextareaWidget_FontSize: Comfy_TextareaWidget_FontSize$3,
  Comfy_TextareaWidget_Spellcheck: Comfy_TextareaWidget_Spellcheck$3,
  Comfy_TreeExplorer_ItemPadding: Comfy_TreeExplorer_ItemPadding$3,
  Comfy_UseNewMenu: Comfy_UseNewMenu$3,
  Comfy_Validation_NodeDefs: Comfy_Validation_NodeDefs$3,
  Comfy_Validation_Workflows: Comfy_Validation_Workflows$3,
  Comfy_WidgetControlMode: Comfy_WidgetControlMode$3,
  Comfy_Window_UnloadConfirmation: Comfy_Window_UnloadConfirmation$3,
  Comfy_Workflow_ConfirmDelete: Comfy_Workflow_ConfirmDelete$3,
  Comfy_Workflow_ShowMissingModelsWarning: Comfy_Workflow_ShowMissingModelsWarning$3,
  Comfy_Workflow_ShowMissingNodesWarning: Comfy_Workflow_ShowMissingNodesWarning$3,
  Comfy_Workflow_SortNodeIdOnSave: Comfy_Workflow_SortNodeIdOnSave$3,
  Comfy_Workflow_WorkflowTabsPosition: Comfy_Workflow_WorkflowTabsPosition$3,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold: LiteGraph_Canvas_LowQualityRenderingZoomThreshold$3,
  LiteGraph_Canvas_MaximumFps: LiteGraph_Canvas_MaximumFps$3,
  LiteGraph_ContextMenu_Scaling: LiteGraph_ContextMenu_Scaling$3,
  LiteGraph_Node_TooltipDelay: LiteGraph_Node_TooltipDelay$3,
  pysssss_SnapToGrid: pysssss_SnapToGrid$3
};
const Comfy_BrowseTemplates$2 = {
  label: "템플릿 탐색"
};
const Comfy_Canvas_DeleteSelectedItems$2 = {
  label: "선택한 항목 삭제"
};
const Comfy_Canvas_FitView$2 = {
  label: "선택한 노드에 뷰 맞추기"
};
const Comfy_Canvas_ResetView$2 = {
  label: "뷰 재설정"
};
const Comfy_Canvas_ToggleLinkVisibility$2 = {
  label: "캔버스 링크 가시성 토글"
};
const Comfy_Canvas_ToggleLock$2 = {
  label: "캔버스 잠금 토글"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass$2 = {
  label: "선택한 노드 우회/우회 해제"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse$2 = {
  label: "선택한 노드 축소/확장"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute$2 = {
  label: "선택한 노드 음소거/음소거 해제"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin$2 = {
  label: "선택한 노드 고정/고정 해제"
};
const Comfy_Canvas_ToggleSelected_Pin$2 = {
  label: "선택한 항목 고정/고정 해제"
};
const Comfy_Canvas_ZoomIn$2 = {
  label: "확대"
};
const Comfy_Canvas_ZoomOut$2 = {
  label: "축소"
};
const Comfy_ClearPendingTasks$2 = {
  label: "보류 중인 작업 지우기"
};
const Comfy_ClearWorkflow$2 = {
  label: "워크플로 지우기"
};
const Comfy_DuplicateWorkflow$2 = {
  label: "현재 워크플로우 복제"
};
const Comfy_ExportWorkflow$2 = {
  label: "워크플로 내보내기"
};
const Comfy_ExportWorkflowAPI$2 = {
  label: "워크플로 내보내기 (API 형식)"
};
const Comfy_Feedback$2 = {
  label: "피드백"
};
const Comfy_Graph_FitGroupToContents$2 = {
  label: "그룹을 내용에 맞게 맞추기"
};
const Comfy_Graph_GroupSelectedNodes$2 = {
  label: "선택한 노드 그룹화"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode$2 = {
  label: "선택한 노드를 그룹 노드로 변환"
};
const Comfy_GroupNode_ManageGroupNodes$2 = {
  label: "그룹 노드 관리"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes$2 = {
  label: "선택한 그룹 노드 분리"
};
const Comfy_Help_AboutComfyUI$2 = {
  label: "ComfyUI 정보 열기"
};
const Comfy_Help_OpenComfyOrgDiscord$2 = {
  label: "Comfy-Org 디스코드 열기"
};
const Comfy_Help_OpenComfyUIDocs$2 = {
  label: "ComfyUI 문서 열기"
};
const Comfy_Help_OpenComfyUIForum$2 = {
  label: "Comfy-Org 포럼 열기"
};
const Comfy_Help_OpenComfyUIIssues$2 = {
  label: "ComfyUI 문제 열기"
};
const Comfy_Interrupt$2 = {
  label: "중단"
};
const Comfy_LoadDefaultWorkflow$2 = {
  label: "기본 워크플로 로드"
};
const Comfy_Manager_CustomNodesManager$2 = {
  label: "사용자 정의 노드 관리자"
};
const Comfy_Manager_ToggleManagerProgressDialog$2 = {
  label: "진행 상황 대화 상자 전환"
};
const Comfy_NewBlankWorkflow$2 = {
  label: "새로운 빈 워크플로"
};
const Comfy_OpenClipspace$2 = {
  label: "클립스페이스"
};
const Comfy_OpenWorkflow$2 = {
  label: "워크플로 열기"
};
const Comfy_QueuePrompt$2 = {
  label: "실행 큐에 프롬프트 추가"
};
const Comfy_QueuePromptFront$2 = {
  label: "실행 큐 맨 앞에 프롬프트 추가"
};
const Comfy_Redo$2 = {
  label: "다시 실행"
};
const Comfy_RefreshNodeDefinitions$2 = {
  label: "노드 정의 새로 고침"
};
const Comfy_SaveWorkflow$2 = {
  label: "워크플로 저장"
};
const Comfy_SaveWorkflowAs$2 = {
  label: "다른 이름으로 워크플로 저장"
};
const Comfy_ShowSettingsDialog$2 = {
  label: "설정 대화상자 보기"
};
const Comfy_ToggleTheme$2 = {
  label: "밝기 테마 전환 (어두운/밝은)"
};
const Comfy_Undo$2 = {
  label: "실행 취소"
};
const Workspace_CloseWorkflow$2 = {
  label: "현재 워크플로우 닫기"
};
const Workspace_NextOpenedWorkflow$2 = {
  label: "다음 열린 워크플로"
};
const Workspace_PreviousOpenedWorkflow$2 = {
  label: "이전 열린 워크플로"
};
const Workspace_SearchBox_Toggle$2 = {
  label: "검색 상자 토글"
};
const Workspace_ToggleBottomPanel$2 = {
  label: "하단 패널 토글"
};
const Workspace_ToggleFocusMode$2 = {
  label: "포커스 모드 토글"
};
const Workspace_ToggleSidebarTab_queue$2 = {
  label: "실행 큐 사이드바 토글",
  tooltip: "실행 큐"
};
const Workspace_ToggleSidebarTab_workflows$2 = {
  label: "워크플로 사이드바 토글",
  tooltip: "워크플로"
};
const koCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "사용자 정의 노드 폴더 열기"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "입력 폴더 열기"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "로그 폴더 열기"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "extra_model_paths.yaml 열기"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "모델 폴더 열기"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "출력 폴더 열기"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "DevTools 열기"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "데스크톱 사용자 가이드"
  },
  "Comfy-Desktop_Quit": {
    label: "종료"
  },
  "Comfy-Desktop_Reinstall": {
    label: "재설치"
  },
  "Comfy-Desktop_Restart": {
    label: "재시작"
  },
  Comfy_BrowseTemplates: Comfy_BrowseTemplates$2,
  Comfy_Canvas_DeleteSelectedItems: Comfy_Canvas_DeleteSelectedItems$2,
  Comfy_Canvas_FitView: Comfy_Canvas_FitView$2,
  Comfy_Canvas_ResetView: Comfy_Canvas_ResetView$2,
  Comfy_Canvas_ToggleLinkVisibility: Comfy_Canvas_ToggleLinkVisibility$2,
  Comfy_Canvas_ToggleLock: Comfy_Canvas_ToggleLock$2,
  Comfy_Canvas_ToggleSelectedNodes_Bypass: Comfy_Canvas_ToggleSelectedNodes_Bypass$2,
  Comfy_Canvas_ToggleSelectedNodes_Collapse: Comfy_Canvas_ToggleSelectedNodes_Collapse$2,
  Comfy_Canvas_ToggleSelectedNodes_Mute: Comfy_Canvas_ToggleSelectedNodes_Mute$2,
  Comfy_Canvas_ToggleSelectedNodes_Pin: Comfy_Canvas_ToggleSelectedNodes_Pin$2,
  Comfy_Canvas_ToggleSelected_Pin: Comfy_Canvas_ToggleSelected_Pin$2,
  Comfy_Canvas_ZoomIn: Comfy_Canvas_ZoomIn$2,
  Comfy_Canvas_ZoomOut: Comfy_Canvas_ZoomOut$2,
  Comfy_ClearPendingTasks: Comfy_ClearPendingTasks$2,
  Comfy_ClearWorkflow: Comfy_ClearWorkflow$2,
  Comfy_DuplicateWorkflow: Comfy_DuplicateWorkflow$2,
  Comfy_ExportWorkflow: Comfy_ExportWorkflow$2,
  Comfy_ExportWorkflowAPI: Comfy_ExportWorkflowAPI$2,
  Comfy_Feedback: Comfy_Feedback$2,
  Comfy_Graph_FitGroupToContents: Comfy_Graph_FitGroupToContents$2,
  Comfy_Graph_GroupSelectedNodes: Comfy_Graph_GroupSelectedNodes$2,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode: Comfy_GroupNode_ConvertSelectedNodesToGroupNode$2,
  Comfy_GroupNode_ManageGroupNodes: Comfy_GroupNode_ManageGroupNodes$2,
  Comfy_GroupNode_UngroupSelectedGroupNodes: Comfy_GroupNode_UngroupSelectedGroupNodes$2,
  Comfy_Help_AboutComfyUI: Comfy_Help_AboutComfyUI$2,
  Comfy_Help_OpenComfyOrgDiscord: Comfy_Help_OpenComfyOrgDiscord$2,
  Comfy_Help_OpenComfyUIDocs: Comfy_Help_OpenComfyUIDocs$2,
  Comfy_Help_OpenComfyUIForum: Comfy_Help_OpenComfyUIForum$2,
  Comfy_Help_OpenComfyUIIssues: Comfy_Help_OpenComfyUIIssues$2,
  Comfy_Interrupt: Comfy_Interrupt$2,
  Comfy_LoadDefaultWorkflow: Comfy_LoadDefaultWorkflow$2,
  Comfy_Manager_CustomNodesManager: Comfy_Manager_CustomNodesManager$2,
  Comfy_Manager_ToggleManagerProgressDialog: Comfy_Manager_ToggleManagerProgressDialog$2,
  Comfy_NewBlankWorkflow: Comfy_NewBlankWorkflow$2,
  Comfy_OpenClipspace: Comfy_OpenClipspace$2,
  Comfy_OpenWorkflow: Comfy_OpenWorkflow$2,
  Comfy_QueuePrompt: Comfy_QueuePrompt$2,
  Comfy_QueuePromptFront: Comfy_QueuePromptFront$2,
  Comfy_Redo: Comfy_Redo$2,
  Comfy_RefreshNodeDefinitions: Comfy_RefreshNodeDefinitions$2,
  Comfy_SaveWorkflow: Comfy_SaveWorkflow$2,
  Comfy_SaveWorkflowAs: Comfy_SaveWorkflowAs$2,
  Comfy_ShowSettingsDialog: Comfy_ShowSettingsDialog$2,
  Comfy_ToggleTheme: Comfy_ToggleTheme$2,
  Comfy_Undo: Comfy_Undo$2,
  Workspace_CloseWorkflow: Workspace_CloseWorkflow$2,
  Workspace_NextOpenedWorkflow: Workspace_NextOpenedWorkflow$2,
  Workspace_PreviousOpenedWorkflow: Workspace_PreviousOpenedWorkflow$2,
  Workspace_SearchBox_Toggle: Workspace_SearchBox_Toggle$2,
  Workspace_ToggleBottomPanel: Workspace_ToggleBottomPanel$2,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "터미널 하단 패널 토글"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "로그 하단 패널 토글"
  },
  Workspace_ToggleFocusMode: Workspace_ToggleFocusMode$2,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "모델 라이브러리 사이드바 토글",
    tooltip: "모델 라이브러리"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "노드 라이브러리 사이드바 토글",
    tooltip: "노드 라이브러리"
  },
  Workspace_ToggleSidebarTab_queue: Workspace_ToggleSidebarTab_queue$2,
  Workspace_ToggleSidebarTab_workflows: Workspace_ToggleSidebarTab_workflows$2
};
const clipboard$2 = {
  errorMessage: "클립보드에 복사하지 못했습니다",
  errorNotSupported: "브라우저가 클립보드 API를 지원하지 않습니다.",
  successMessage: "클립보드에 복사됨"
};
const color$2 = {
  black: "검정색",
  blue: "파란색",
  brown: "갈색",
  custom: "사용자 정의",
  cyan: "청록색",
  "default": "기본값",
  green: "초록색",
  noColor: "색 없음",
  pale_blue: "흐린 파랑색",
  pink: "분홍색",
  purple: "보라색",
  red: "빨간색",
  yellow: "노란색"
};
const contextMenu$2 = {
  " to input": " 위젯을 입력으로",
  " to widget": " 입력을 위젯으로",
  "Add Group": "그룹 추가",
  "Add Group For Selected Nodes": "선택한 노드 그룹 추가",
  "Add Node": "노드 추가",
  Bypass: "실행 건너뛰기",
  Clone: "복제",
  Collapse: "접기",
  Colors: "색상",
  "Convert ": "[변환] ",
  "Convert Input to Widget": "입력을 위젯으로 변환",
  "Convert Widget to Input": "위젯을 입력으로 변환",
  "Convert to Group Node": "그룹 노드로 변환",
  "Copy (Clipspace)": "복사 (Clipspace)",
  Expand: "확장",
  Inputs: "입력",
  Manage: "관리",
  "Manage Group Nodes": "그룹 노드 관리",
  Mode: "모드",
  "Node Templates": "노드 템플릿",
  Outputs: "출력",
  Pin: "고정",
  Properties: "속성",
  "Properties Panel": "속성 패널",
  Remove: "제거",
  Resize: "크기 조정",
  "Save Selected as Template": "선택된 부분을 템플릿으로 저장",
  Search: "검색",
  Shapes: "형태",
  Title: "제목",
  Unpin: "고정 해제"
};
const dataTypes$2 = {
  AUDIO: "오디오",
  BOOLEAN: "논리값",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP_VISION",
  CLIP_VISION_OUTPUT: "CLIP_VISION 출력",
  COMBO: "콤보",
  CONDITIONING: "조건",
  CONTROL_NET: "컨트롤넷",
  FLOAT: "실수",
  FLOATS: "실수 배열",
  GLIGEN: "GLIGEN",
  GUIDER: "가이드",
  HOOKS: "후크",
  HOOK_KEYFRAMES: "후크 키프레임",
  IMAGE: "이미지",
  INT: "정수",
  LATENT: "잠재 데이터",
  LATENT_OPERATION: "잠재 연산",
  LOAD_3D: "3D 로드",
  LOAD_3D_ANIMATION: "3D 애니메이션 로드",
  MASK: "마스크",
  MESH: "메시",
  MODEL: "모델",
  NOISE: "노이즈",
  PHOTOMAKER: "PHOTOMAKER",
  SAMPLER: "샘플러",
  SIGMAS: "시그마",
  STRING: "문자열",
  STYLE_MODEL: "스타일 모델",
  TIMESTEPS_RANGE: "타임스텝 범위",
  UPSCALE_MODEL: "업스케일 모델",
  VAE: "VAE",
  VOXEL: "복셀",
  WEBCAM: "웹캠"
};
const desktopMenu$2 = {
  confirmQuit: "저장되지 않은 워크플로가 열려 있습니다. 저장되지 않은 변경 사항은 모두 손실됩니다. 이를 무시하고 종료하시겠습니까?",
  confirmReinstall: "이 작업은 extra_models_config.yaml 파일을 지우고 설치를 다시 시작합니다. 정말로 진행하시겠습니까?",
  quit: "종료",
  reinstall: "재설치"
};
const desktopUpdate$2 = {
  description: "ComfyUI 데스크톱이 새로운 종속성을 설치하고 있습니다. 이 작업은 몇 분 정도 걸릴 수 있습니다.",
  terminalDefaultMessage: "업데이트 콘솔 출력은 여기에 표시됩니다.",
  title: "ComfyUI 데스크톱 업데이트 중"
};
const downloadGit$2 = {
  gitWebsite: "git 프로그램 다운로드",
  instructions: "운영 체제에 맞는 최신 버전을 다운로드하여 설치하십시오. 아래의 'git 프로그램 다운로드' 버튼을 클릭하면 git-scm.com 다운로드 페이지가 열립니다.",
  message: "git 프로그램을 찾을 수 없습니다. 정상적인 작업을 위해서는 git 프로그램이 필요합니다.",
  skip: "건너뛰기",
  title: "git 프로그램 다운로드",
  warning: "git 프로그램이 이미 설치된 것이 확실하다면, 이 검사 단계를 스킵할 수 있습니다. 현재는 정상적으로 실행 가능한 git 프로그램이 없는 경우, ComfyUI를 실행할 수 없습니다."
};
const electronFileDownload$2 = {
  cancel: "다운로드 취소",
  cancelled: "취소됨",
  inProgress: "진행 중",
  pause: "다운로드 일시 중지",
  paused: "일시 중지됨",
  resume: "다운로드 재개"
};
const g$2 = {
  about: "정보",
  add: "추가",
  all: "모두",
  apply: "적용",
  back: "뒤로",
  cancel: "취소",
  capture: "캡처",
  category: "카테고리",
  choose_file_to_upload: "업로드할 파일 선택",
  close: "닫기",
  color: "색상",
  comingSoon: "곧 출시 예정",
  command: "명령",
  community: "커뮤니티",
  completed: "완료됨",
  confirm: "확인",
  "continue": "계속",
  control_after_generate: "생성 후 제어",
  control_before_generate: "생성 전 제어",
  copyToClipboard: "클립보드에 복사",
  currentUser: "현재 사용자",
  customize: "사용자 정의",
  customizeFolder: "폴더 사용자 정의",
  "delete": "삭제",
  deprecated: "사용 중단",
  description: "설명",
  devices: "장치",
  disableAll: "모두 비활성화",
  download: "다운로드",
  empty: "비어 있음",
  enableAll: "모두 활성화",
  enabled: "활성화됨",
  error: "오류",
  experimental: "베타",
  "export": "내보내기",
  extensionName: "확장 이름",
  feedback: "피드백",
  filter: "필터",
  findIssues: "문제 찾기",
  firstTimeUIMessage: '새 UI를 처음 사용합니다. "메뉴 > 새 메뉴 사용 > 비활성화"를 선택하여 이전 UI로 복원하세요.',
  goToNode: "노드로 이동",
  icon: "아이콘",
  imageFailedToLoad: "이미지를 로드하지 못했습니다.",
  "import": "가져오기",
  inProgress: "진행 중",
  insert: "삽입",
  install: "설치",
  installed: "설치됨",
  installing: "설치 중",
  keybinding: "키 바인딩",
  loadAllFolders: "모든 폴더 로드",
  loadWorkflow: "워크플로 로드",
  loading: "로딩 중",
  logs: "로그",
  missing: "누락됨",
  name: "이름",
  newFolder: "새 폴더",
  next: "다음",
  no: "아니오",
  noResultsFound: "결과를 찾을 수 없습니다.",
  noTasksFound: "작업을 찾을 수 없습니다.",
  noTasksFoundMessage: "대기열에 작업이 없습니다.",
  noWorkflowsFound: "워크플로를 찾을 수 없습니다.",
  nodes: "노드",
  ok: "확인",
  openNewIssue: "새 문제 열기",
  overwrite: "덮어쓰기",
  reconnected: "재연결됨",
  reconnecting: "재연결 중",
  refresh: "새로 고침",
  reloadToApplyChanges: "변경 사항을 적용하려면 새로 고침하세요.",
  rename: "이름 바꾸기",
  reportIssue: "보고서 보내기",
  reportIssueTooltip: "Comfy Org에 오류 보고서를 제출합니다.",
  reportSent: "보고서 제출됨",
  reset: "재설정",
  resetKeybindingsTooltip: "키 바인딩을 기본값으로 재설정",
  restart: "재시작",
  resultsCount: "{count} 개의 결과를 찾았습니다",
  save: "저장",
  saving: "저장 중",
  searchExtensions: "확장 검색",
  searchFailedMessage: "검색어와 일치하는 설정을 찾을 수 없습니다. 검색어를 조정해 보세요.",
  searchKeybindings: "키 바인딩 검색",
  searchModels: "모델 검색",
  searchNodes: "노드 검색",
  searchSettings: "설정 검색",
  searchWorkflows: "워크플로 검색",
  settings: "설정",
  showReport: "보고서 보기",
  sort: "정렬",
  status: "상태",
  success: "성공",
  systemInfo: "시스템 정보",
  terminal: "터미널",
  updated: "업데이트 됨",
  upload: "업로드",
  videoFailedToLoad: "비디오를 로드하지 못했습니다.",
  workflow: "워크플로"
};
const graphCanvasMenu$2 = {
  fitView: "보기 맞춤",
  panMode: "팬 모드",
  resetView: "보기 재설정",
  selectMode: "선택 모드",
  toggleLinkVisibility: "링크 가시성 전환",
  zoomIn: "확대",
  zoomOut: "축소"
};
const groupNode$2 = {
  create: "그룹 노드 만들기",
  enterName: "이름 입력"
};
const icon$2 = {
  bookmark: "북마크",
  box: "상자",
  briefcase: "서류가방",
  "exclamation-triangle": "경고",
  file: "파일",
  folder: "폴더",
  heart: "하트",
  inbox: "받은 편지함",
  star: "별"
};
const install$2 = {
  appDataLocationTooltip: "ComfyUI의 앱 데이터 디렉토리. 저장소:\n- 로그\n- 서버 구성",
  appPathLocationTooltip: "ComfyUI의 앱 에셋 디렉토리. ComfyUI 코드 및 에셋을 저장합니다.",
  cannotWrite: "선택한 경로에 쓸 수 없습니다",
  chooseInstallationLocation: "설치 위치 선택",
  customNodes: "사용자 정의 노드",
  customNodesDescription: "기존 ComfyUI 설치에서 사용자 정의 노드를 다시 설치합니다.",
  desktopAppSettings: "데스크탑 앱 설정",
  desktopAppSettingsDescription: "ComfyUI가 데스크탑에서 어떻게 작동하는지 구성하세요. 이 설정은 나중에 변경할 수 있습니다.",
  desktopSettings: "데스크탑 설정",
  failedToSelectDirectory: "디렉토리 선택 실패",
  gpu: "GPU",
  gpuSelection: {
    cpuMode: "CPU 모드",
    cpuModeDescription: "CPU 모드는 개발자와 드문 경우에만 사용됩니다.",
    cpuModeDescription2: "이것이 필요한지 확실하지 않다면, 이 상자를 무시하고 위에서 GPU를 선택하세요.",
    customComfyNeedsPython: "Python이 설정되지 않으면 ComfyUI가 작동하지 않습니다",
    customInstallRequirements: "모든 요구 사항과 종속성 설치 (예: 사용자 정의 torch)",
    customManualVenv: "Python venv를 수동으로 구성",
    customMayNotWork: "이것은 전혀 지원되지 않으며, 작동하지 않을 수 있습니다",
    customSkipsPython: "이 옵션은 일반 Python 설정을 건너뜁니다.",
    enableCpuMode: "CPU 모드 활성화",
    mpsDescription: "Apple Metal Performance Shaders는 pytorch nightly를 사용하여 지원됩니다.",
    nvidiaDescription: "NVIDIA 장치는 pytorch CUDA 빌드를 사용하여 직접 지원됩니다.",
    selectGpu: "GPU 선택",
    selectGpuDescription: "소유한 GPU 유형을 선택하세요"
  },
  helpImprove: "ComfyUI 개선에 도움을 주세요",
  installLocation: "설치 위치",
  installLocationDescription: "ComfyUI의 사용자 데이터 디렉토리를 선택하십시오. 선택한 위치에 Python 환경이 설치됩니다. 선택한 디스크에 충분한 공간(~15GB)이 남아 있는지 확인하십시오.",
  installLocationTooltip: "ComfyUI의 사용자 데이터 디렉토리. 저장소:\n- Python 환경\n- 모델\n- 사용자 정의 노드\n",
  insufficientFreeSpace: "공간이 부족합니다 - 최소한의 여유 공간",
  isOneDrive: "OneDrive에 설치하면 문제가 발생할 수 있습니다. OneDrive가 아닌 위치에 설치하는 것을 강력히 권장합니다.",
  manualConfiguration: {
    createVenv: "다음 디렉토리에 가상 환경을 생성해야 합니다",
    requirements: "요구 사항",
    restartWhenFinished: "가상 환경 구성을 완료하면 ComfyUI를 다시 시작해주세요.",
    title: "수동 구성",
    virtualEnvironmentPath: "가상 환경 경로"
  },
  metricsDisabled: "데이터 수집 비활성화",
  metricsEnabled: "데이터 수집 활성화",
  migrateFromExistingInstallation: "기존 설치에서 마이그레이션",
  migration: "마이그레이션",
  migrationOptional: "마이그레이션은 선택 사항입니다. 기존에 설치된 것이 없다면, 이 단계를 건너뛸 수 있습니다.",
  migrationSourcePathDescription: "기존에 설치된 ComfyUI가 있으면, 기존 사용자 파일과 모델을 새 설치본으로 복사하거나 링크 할 수 있습니다. 기존의 ComfyUI 설치는 영향을 받지 않습니다.",
  moreInfo: "더 많은 정보를 원하시면, 다음을 읽어주세요",
  nonDefaultDrive: "ComfyUI를 시스템 드라이브(예: C:\\)에 설치하십시오. 다른 파일 시스템을 가진 드라이브는 예측할 수 없는 문제를 일으킬 수 있습니다. 설치 후에는 모델 및 기타 파일을 다른 드라이브에 저장할 수 있습니다.",
  parentMissing: "경로가 존재하지 않습니다 - 먼저 포함하는 디렉토리를 생성하세요",
  pathExists: "디렉토리가 이미 존재합니다 - 모든 데이터를 백업했는지 확인해 주세요",
  pathValidationFailed: "경로 유효성 검사 실패",
  privacyPolicy: "개인정보 보호정책",
  selectItemsToMigrate: "마이그레이션 항목 선택",
  settings: {
    allowMetrics: "사용 통계",
    allowMetricsDescription: "익명의 사용 통계를 보내 ComfyUI를 개선하는 데 도움을 줍니다. 개인 정보나 워크플로 내용은 수집되지 않습니다.",
    autoUpdate: "자동 업데이트",
    autoUpdateDescription: "업데이트가 가능해지면 자동으로 다운로드하고 설치합니다. 업데이트가 설치되기 전에 항상 알림을 받습니다.",
    checkingMirrors: "Python 미러에 대한 네트워크 액세스 확인 중...",
    dataCollectionDialog: {
      collect: {
        errorReports: "오류 메시지 및 스택 추적",
        systemInfo: "하드웨어, OS 유형, 앱 버전",
        userJourneyEvents: "사용자 행동 흐름 이벤트"
      },
      doNotCollect: {
        customNodeConfigurations: "커스텀 노드 구성",
        fileSystemInformation: "파일 시스템 정보",
        personalInformation: "개인 정보",
        workflowContents: "워크플로 내용"
      },
      title: "데이터 수집 안내",
      viewFullPolicy: "전체 정책 보기",
      whatWeCollect: "수집하는 정보:",
      whatWeDoNotCollect: "수집하지 않는 정보:"
    },
    errorUpdatingConsent: "데이터 수집 동의 설정 업데이트 오류",
    errorUpdatingConsentDetail: "데이터 수집 동의 설정 업데이트에 실패했습니다",
    learnMoreAboutData: "데이터 수집에 대해 더 알아보기",
    mirrorSettings: "미러 URL 설정",
    mirrorsReachable: "Python 미러에 대한 네트워크 액세스가 좋습니다",
    mirrorsUnreachable: "일부 Python 미러에 대한 네트워크 접근이 나쁩니다",
    pypiMirrorPlaceholder: "PyPI 미러 URL 입력",
    pythonMirrorPlaceholder: "Python 미러 URL 입력"
  },
  systemLocations: "시스템 위치",
  unhandledError: "알 수 없는 오류",
  updateConsent: "이전에 충돌 보고에 동의하셨습니다. 이제 버그를 식별하고 앱을 개선하기 위해 이벤트 기반 통계 정보의 추적을 시작합니다. 개인을 식별할 수 있는 정보는 수집되지 않습니다."
};
const issueReport$2 = {
  contactFollowUp: "추적 조사를 위해 연락해 주세요",
  feedbackTitle: "피드백을 제공함으로써 ComfyUI를 개선하는 데 도움을 주십시오",
  helpFix: "이 문제 해결에 도움을 주세요",
  notifyResolve: "해결되었을 때 알려주세요",
  provideAdditionalDetails: "추가 세부 사항 제공 (선택 사항)",
  provideEmail: "이메일을 알려주세요 (선택 사항)",
  rating: "평가",
  stackTrace: "스택 추적",
  submitErrorReport: "오류 보고서 제출 (선택 사항)",
  systemStats: "시스템 통계",
  validation: {
    invalidEmail: "유효한 이메일 주소를 입력해 주세요",
    maxLength: "메시지가 너무 깁니다"
  }
};
const load3d$2 = {
  backgroundColor: "배경색",
  camera: "카메라",
  edgeThreshold: "엣지 임계값",
  "export": "수출",
  exportModel: "모델 수출",
  exportingModel: "모델 수출 중...",
  fov: "FOV",
  light: "빛",
  lightIntensity: "조명 강도",
  loadingModel: "3D 모델 로딩 중...",
  materialMode: "재질 모드",
  model: "모델",
  previewOutput: "출력 미리보기",
  removeBackgroundImage: "배경 이미지 제거",
  scene: "장면",
  showGrid: "그리드 표시",
  switchCamera: "카메라 전환",
  switchingMaterialMode: "재질 모드 전환 중...",
  upDirection: "위 방향",
  uploadBackgroundImage: "배경 이미지 업로드"
};
const maintenance$2 = {
  None: "없음",
  OK: "확인",
  Skipped: "건너뜀",
  allOk: "문제가 발견되지 않았습니다.",
  confirmTitle: "확실합니까?",
  consoleLogs: "콘솔 로그",
  detected: "감지됨",
  error: {
    cannotContinue: "계속할 수 없습니다 - 오류가 남아 있습니다",
    defaultDescription: "유지 보수 작업을 실행하는 동안 오류가 발생했습니다.",
    taskFailed: "작업 실행에 실패했습니다.",
    toastTitle: "작업 오류"
  },
  refreshing: "새로 고침 중",
  showManual: "유지 보수 작업 보기",
  status: "상태",
  terminalDefaultMessage: "문제 해결 명령을 실행하면 출력이 여기에 표시됩니다.",
  title: "유지 보수"
};
const manager$2 = {
  createdBy: "작성자",
  dependencies: "의존성",
  discoverCommunityContent: "커뮤니티에서 만든 노드 팩 및 확장 프로그램을 찾아보세요...",
  downloads: "다운로드",
  errorConnecting: "Comfy Node Registry에 연결하는 중 오류가 발생했습니다.",
  filter: {
    disabled: "비활성화",
    enabled: "활성화",
    nodePack: "노드 팩"
  },
  inWorkflow: "워크플로우 내",
  infoPanelEmpty: "정보를 보려면 항목을 클릭하세요",
  installSelected: "선택한 항목 설치",
  lastUpdated: "마지막 업데이트",
  latestVersion: "최신",
  license: "라이선스",
  loadingVersions: "버전 로딩 중...",
  nightlyVersion: "최신 테스트 버전(nightly)",
  noDescription: "설명이 없습니다",
  noResultsFound: "검색과 일치하는 결과가 없습니다.",
  nodePack: "노드 팩",
  packsSelected: "선택한 노드 팩",
  repository: "저장소",
  restartToApplyChanges: "변경 사항을 적용하려면 ComfyUI를 재시작해 주세요",
  searchPlaceholder: "검색",
  selectVersion: "버전 선택",
  sort: {
    downloads: "가장 인기 있는",
    rating: "평점"
  },
  status: {
    active: "활성",
    banned: "차단됨",
    deleted: "삭제됨",
    flagged: "검토 대상",
    pending: "대기 중",
    unknown: "알 수 없음"
  },
  title: "사용자 정의 노드 관리자",
  totalNodes: "총 노드",
  tryAgainLater: "나중에 다시 시도해 주세요.",
  tryDifferentSearch: "다른 검색어를 시도해 주세요.",
  uninstall: "제거",
  uninstallSelected: "선택 항목 제거",
  uninstalling: "제거 중",
  update: "업데이트",
  version: "버전"
};
const maskEditor$2 = {
  "Apply to Whole Image": "전체 이미지에 적용",
  "Brush Settings": "브러시 설정",
  "Brush Shape": "브러시 모양",
  Clear: "지우기",
  "Color Select Settings": "색상 선택 설정",
  "Fill Opacity": "채우기 투명도",
  Hardness: "경도",
  "Image Layer": "이미지 레이어",
  Invert: "반전",
  Layers: "레이어",
  "Live Preview": "실시간 미리보기",
  "Mask Layer": "마스크 레이어",
  "Mask Opacity": "마스크 투명도",
  "Mask Tolerance": "마스크 허용 오차",
  Method: "방법",
  Opacity: "투명도",
  "Paint Bucket Settings": "페인트 버킷 설정",
  "Reset to Default": "기본값으로 재설정",
  "Selection Opacity": "선택 투명도",
  "Smoothing Precision": "스무딩 정밀도",
  "Stop at mask": "마스크에서 중지",
  Thickness: "두께",
  Tolerance: "허용 오차"
};
const menu$2 = {
  autoQueue: "자동 실행 큐",
  batchCount: "배치 수",
  batchCountTooltip: "워크플로 작업을 실행 큐에 반복 추가할 횟수",
  clear: "워크플로 비우기",
  clipspace: "클립스페이스 열기",
  disabled: "비활성화됨",
  disabledTooltip: "워크플로 작업을 자동으로 실행 큐에 추가하지 않습니다.",
  execute: "실행",
  hideMenu: "메뉴 숨기기",
  instant: "즉시",
  instantTooltip: "워크플로 실행이 완료되면 즉시 실행 큐에 추가합니다.",
  interrupt: "현재 실행 취소",
  onChange: "변경 시",
  onChangeTooltip: "변경이 있는 경우에만 워크플로를 실행 큐에 추가합니다.",
  refresh: "노드 정의 새로 고침",
  resetView: "캔버스 보기 재설정",
  run: "실행",
  runWorkflow: "워크플로우 실행 (시프트 키와 함께 클릭시 가장 먼저 실행)",
  runWorkflowFront: "워크플로우 실행 (가장 먼저 실행)",
  showMenu: "메뉴 표시",
  toggleBottomPanel: "하단 패널 전환"
};
const menuLabels$2 = {
  "About ComfyUI": "ComfyUI에 대하여",
  "Browse Templates": "템플릿 탐색",
  "Bypass/Unbypass Selected Nodes": "선택한 노드 우회/우회 해제",
  "Canvas Toggle Link Visibility": "캔버스 토글 링크 가시성",
  "Canvas Toggle Lock": "캔버스 토글 잠금",
  "Clear Pending Tasks": "보류 중인 작업 제거하기",
  "Clear Workflow": "워크플로 지우기",
  Clipspace: "클립스페이스",
  "Close Current Workflow": "현재 워크플로 닫기",
  "Collapse/Expand Selected Nodes": "선택한 노드 축소/확장",
  "Comfy-Org Discord": "Comfy-Org 디스코드",
  "ComfyUI Docs": "ComfyUI 문서",
  "ComfyUI Forum": "ComfyUI 포럼",
  "ComfyUI Issues": "ComfyUI 이슈 페이지",
  "Convert selected nodes to group node": "선택한 노드를 그룹 노드로 변환",
  "Custom Nodes Manager": "사용자 정의 노드 관리자",
  "Delete Selected Items": "선택한 항목 삭제",
  "Desktop User Guide": "데스크톱 사용자 가이드",
  "Duplicate Current Workflow": "현재 워크플로 복제",
  Edit: "편집",
  Export: "내보내기",
  "Export (API)": "내보내기 (API)",
  "Fit Group To Contents": "그룹을 내용에 맞게 조정",
  "Fit view to selected nodes": "선택한 노드에 맞게 보기 조정",
  "Give Feedback": "피드백 제공",
  "Group Selected Nodes": "선택한 노드 그룹화",
  Help: "도움말",
  Interrupt: "중단",
  "Load Default Workflow": "기본 워크플로 불러오기",
  "Manage group nodes": "그룹 노드 관리",
  "Mute/Unmute Selected Nodes": "선택한 노드 활성화/비활성화",
  New: "새로 만들기",
  "Next Opened Workflow": "다음 열린 워크플로",
  Open: "열기",
  "Open Custom Nodes Folder": "사용자 정의 노드 폴더 열기",
  "Open DevTools": "개발자 도구 열기",
  "Open Inputs Folder": "입력 폴더 열기",
  "Open Logs Folder": "로그 폴더 열기",
  "Open Models Folder": "모델 폴더 열기",
  "Open Outputs Folder": "출력 폴더 열기",
  "Open extra_model_paths_yaml": "extra_model_paths.yaml 열기",
  "Pin/Unpin Selected Items": "선택한 항목 고정/고정 해제",
  "Pin/Unpin Selected Nodes": "선택한 노드 고정/고정 해제",
  "Previous Opened Workflow": "이전 열린 워크플로",
  "Queue Prompt": "실행 큐에 프롬프트 추가",
  "Queue Prompt (Front)": "실행 큐 맨 앞에 프롬프트 추가",
  Quit: "종료",
  Redo: "다시 실행",
  "Refresh Node Definitions": "노드 정의 새로 고침",
  Reinstall: "재설치",
  "Reset View": "보기 초기화",
  Restart: "재시작",
  Save: "저장",
  "Save As": "다른 이름으로 저장",
  "Show Settings Dialog": "설정 대화상자 표시",
  "Toggle Bottom Panel": "하단 패널 전환",
  "Toggle Focus Mode": "포커스 모드 전환",
  "Toggle Logs Bottom Panel": "로그 하단 패널 전환",
  "Toggle Model Library Sidebar": "모델 라이브러리 사이드바 전환",
  "Toggle Node Library Sidebar": "노드 라이브러리 사이드바 전환",
  "Toggle Progress Dialog": "진행 상황 대화 상자 전환",
  "Toggle Queue Sidebar": "실행 큐 사이드바 전환",
  "Toggle Search Box": "검색 상자 전환",
  "Toggle Terminal Bottom Panel": "터미널 하단 패널 전환",
  "Toggle Theme (Dark/Light)": "테마 전환 (어두운/밝은)",
  "Toggle Workflows Sidebar": "워크플로 사이드바 전환",
  Undo: "실행 취소",
  "Ungroup selected group nodes": "선택한 그룹 노드 그룹 해제",
  Workflow: "워크플로",
  "Zoom In": "확대",
  "Zoom Out": "축소"
};
const missingModelsDialog$2 = {
  doNotAskAgain: "다시 보지 않기",
  missingModels: "모델이 없습니다",
  missingModelsMessage: "그래프를 로드할 때 다음 모델을 찾을 수 없었습니다"
};
const nodeCategories$2 = {
  "3d": "3d",
  "3d_models": "3D 모델",
  _for_testing: "_테스트용",
  advanced: "고급",
  animation: "애니메이션",
  api: "API",
  attention_experiments: "어텐션 실험",
  audio: "오디오",
  batch: "배치",
  clip: "클립",
  combine: "결합",
  compositing: "합성",
  "cond pair": "조건 쌍",
  "cond single": "단일 조건",
  conditioning: "조건화",
  controlnet: "컨트롤넷",
  create: "생성",
  custom_sampling: "사용자 정의 샘플링",
  debug: "디버그",
  deprecated: "지원 중단",
  flux: "flux",
  gligen: "글리젠",
  guidance: "가이드",
  guiders: "가이드",
  hooks: "후크",
  image: "이미지",
  inpaint: "인페인팅",
  instructpix2pix: "InstructPix2Pix",
  latent: "잠재 데이터",
  loaders: "로더",
  ltxv: "ltxv",
  mask: "마스크",
  model: "모델",
  model_merging: "모델 병합",
  model_patches: "모델 패치",
  model_specific: "모델 특정",
  noise: "노이즈",
  operations: "연산",
  photomaker: "포토메이커",
  postprocessing: "후처리",
  preprocessors: "전처리기",
  samplers: "샘플러",
  sampling: "샘플링",
  schedulers: "스케줄러",
  scheduling: "스케줄링",
  sd3: "sd3",
  sigmas: "시그마",
  stable_cascade: "Stable Cascade",
  style_model: "스타일 모델",
  transform: "변환",
  unet: "UNet",
  upscale_diffusion: "업스케일 확산",
  upscaling: "업스케일링",
  video: "비디오",
  video_models: "비디오 모델"
};
const nodeTemplates$2 = {
  enterName: "이름 입력",
  saveAsTemplate: "템플릿으로 저장"
};
const notSupported$2 = {
  "continue": "계속",
  continueTooltip: "내 장치가 지원되는 장치가 확실합니다.",
  learnMore: "자세히 알아보기",
  message: "다음 장치만 지원됩니다:",
  reportIssue: "이슈 보고",
  supportedDevices: {
    macos: "MacOS (M1 이상)",
    windows: "Windows (CUDA 지원 Nvidia GPU)"
  },
  title: "이 장치는 지원되지 않습니다."
};
const serverConfig$2 = {
  modifiedConfigs: "다음 서버 구성을 수정했습니다. 변경 사항을 적용하려면 다시 시작하세오.",
  restart: "다시 시작",
  revertChanges: "변경 사항 되돌리기"
};
const serverConfigCategories$2 = {
  Attention: "어텐션",
  CUDA: "CUDA",
  Cache: "캐시",
  Directories: "디렉토리",
  General: "일반",
  Inference: "추론",
  Memory: "메모리",
  Network: "네트워크",
  Preview: "미리보기"
};
const serverConfigItems$2 = {
  "cache-classic": {
    name: "예전 방식의 공격적 캐시 시스템 사용"
  },
  "cache-lru": {
    name: "최대 N개 노드 결과를 캐시하는 LRU(Least Recently Used) 캐싱 사용.",
    tooltip: "RAM/VRAM 사용량이 증가합니다"
  },
  "cpu-vae": {
    name: "CPU에서 VAE 실행"
  },
  "cross-attention-method": {
    name: "교차 어텐션 방법"
  },
  "cuda-device": {
    name: "사용할 CUDA 장치 번호"
  },
  "cuda-malloc": {
    name: "메모리 할당에 CUDA malloc 사용"
  },
  "default-hashing-function": {
    name: "모델 파일의 기본 해싱 함수"
  },
  deterministic: {
    name: "사용 가능한 경우 pytorch가 느리지만 결정론적인 알고리즘을 사용하도록 설정합니다.",
    tooltip: "주의: 이 옵션이 항상 결정론적 이미지를 보장하지는 않습니다."
  },
  directml: {
    name: "DirectML 장치 번호"
  },
  "disable-all-custom-nodes": {
    name: "모든 사용자 정의 노드 로드 비활성화."
  },
  "disable-ipex-optimize": {
    name: "IPEX 최적화 비활성화"
  },
  "disable-metadata": {
    name: "파일에 프롬프트(워크플로) 메타데이터 저장 비활성화."
  },
  "disable-smart-memory": {
    name: "스마트 메모리 관리 비활성화",
    tooltip: "ComfyUI가 모델을 VRAM에 유지하는 대신 시스템 메모리로 공격적으로 오프로드하도록 강제합니다."
  },
  "disable-xformers": {
    name: "xFormers 최적화 비활성화"
  },
  "dont-print-server": {
    name: "서버 출력을 콘솔에 출력하지 않음."
  },
  "dont-upcast-attention": {
    name: "어텐션 업캐스트 방지"
  },
  "enable-cors-header": {
    name: 'CORS 헤더 활성화: 모든 출처에 대해 "*" 사용 또는 도메인 지정'
  },
  fast: {
    name: "테스트되지 않고 품질 저하 가능성이 있는 실험적 최적화 기능을 활성화 합니다."
  },
  "force-channels-last": {
    name: "channels-last 메모리 형식 강제 적용"
  },
  "force-upcast-attention": {
    name: "어텐션 업캐스트 강제 적용"
  },
  "global-precision": {
    name: "전역 부동 소수점 정밀도",
    tooltip: "전역 부동 소수점 정밀도"
  },
  "input-directory": {
    name: "입력 디렉토리"
  },
  listen: {
    name: "호스트: 접속될 IP 주소"
  },
  "log-level": {
    name: "로그 출력 수준"
  },
  "max-upload-size": {
    name: "최대 업로드 크기 (MB)"
  },
  "output-directory": {
    name: "출력 디렉토리"
  },
  port: {
    name: "포트: 접속될 포트"
  },
  "preview-method": {
    name: "잠재 데이터 미리보기 방법"
  },
  "preview-size": {
    name: "미리보기 최대 이미지 크기"
  },
  "reserve-vram": {
    name: "예약된 VRAM (GB)",
    tooltip: "OS/기타 소프트웨어에서 사용하기 위해 예약할 VRAM의 양을 GB 단위로 설정합니다. 기본적으로 OS에 따라 일부 양이 예약됩니다."
  },
  "text-encoder-precision": {
    name: "텍스트 인코더 정밀도",
    tooltip: "텍스트 인코더 정밀도"
  },
  "tls-certfile": {
    name: "TLS 인증서 파일: HTTPS용 TLS 인증서 파일 경로"
  },
  "tls-keyfile": {
    name: "TLS 키 파일: HTTPS용 TLS 키 파일 경로"
  },
  "unet-precision": {
    name: "UNET 정밀도",
    tooltip: "UNET 정밀도"
  },
  "vae-precision": {
    name: "VAE 정밀도",
    tooltip: "VAE 정밀도"
  },
  "vram-management": {
    name: "VRAM 관리 모드"
  }
};
const serverStart$2 = {
  openLogs: "로그 열기",
  process: {
    error: "ComfyUI Desktop을 시작할 수 없습니다",
    "initial-state": "로딩 중...",
    "python-setup": "Python 환경 설정 중...",
    ready: "마무리 중...",
    "starting-server": "ComfyUI 서버 시작 중..."
  },
  reportIssue: "문제 보고",
  showTerminal: "터미널 보기",
  troubleshoot: "문제 해결"
};
const settingsCategories$2 = {
  About: "정보",
  Appearance: "모양",
  BrushAdjustment: "브러시 조정",
  Canvas: "캔버스",
  ColorPalette: "색상 팔레트",
  Comfy: "Comfy",
  "Comfy-Desktop": "Comfy-Desktop",
  ContextMenu: "컨텍스트 메뉴",
  CustomColorPalettes: "사용자 정의 색상 팔레트",
  DevMode: "개발자 모드",
  EditTokenWeight: "토큰 가중치 편집",
  Extension: "확장",
  General: "일반",
  Graph: "그래프",
  Group: "그룹",
  Keybinding: "키 바인딩",
  Link: "링크",
  LinkRelease: "링크 해제",
  LiteGraph: "LiteGraph",
  Locale: "언어 설정",
  "Mask Editor": "마스크 편집기",
  Menu: "메뉴",
  ModelLibrary: "모델 라이브러리",
  NewEditor: "새 편집기",
  Node: "노드",
  "Node Search Box": "노드 검색 상자",
  "Node Widget": "노드 위젯",
  NodeInputConversionSubmenus: "노드 입력 변환 하위 메뉴",
  NodeLibrary: "노드 라이브러리",
  Pointer: "포인터",
  Queue: "실행 큐",
  QueueButton: "실행 큐 버튼",
  RerouteBeta: "경로재설정 베타",
  Server: "서버",
  "Server-Config": "서버 구성",
  Settings: "설정",
  Sidebar: "사이드바",
  "Tree Explorer": "트리 탐색기",
  UV: "UV",
  Validation: "검증",
  Window: "창",
  Workflow: "워크플로"
};
const sideToolbar$2 = {
  browseTemplates: "예제 템플릿 탐색",
  downloads: "다운로드",
  logout: "로그아웃",
  modelLibrary: "모델 라이브러리",
  newBlankWorkflow: "새 빈 워크플로 만들기",
  nodeLibrary: "노드 라이브러리",
  nodeLibraryTab: {
    sortOrder: "정렬 순서"
  },
  openWorkflow: "로컬 파일 시스템에서 워크플로 열기",
  queue: "실행 큐",
  queueTab: {
    backToAllTasks: "모든 작업으로 돌아가기",
    clearPendingTasks: "보류 중인 작업 지우기",
    containImagePreview: "이미지 미리보기 채우기",
    coverImagePreview: "이미지 미리보기 맞추기",
    filter: "출력 필터",
    filters: {
      hideCached: "캐시 숨기기",
      hideCanceled: "취소된 작업 숨기기"
    },
    showFlatList: "평면 목록 표시"
  },
  themeToggle: "테마 전환",
  workflowTab: {
    confirmDelete: "정말로 이 워크플로를 삭제하시겠습니까?",
    confirmDeleteTitle: "워크플로 삭제",
    confirmOverwrite: "아래 파일이 이미 존재합니다. 덮어쓰시겠습니까?",
    confirmOverwriteTitle: "기존 파일 덮어쓰기?",
    deleteFailed: "워크플로 삭제를 시도했으나 실패했습니다.",
    deleteFailedTitle: "삭제 실패",
    deleted: "워크플로가 삭제되었습니다.",
    dirtyClose: "아래 파일들이 변경되었습니다. 닫기 전에 저장하시겠습니까?",
    dirtyCloseHint: "프롬프트 없이 닫으려면 Shift를 누르세요",
    dirtyCloseTitle: "변경 사항 저장",
    workflowTreeType: {
      bookmarks: "북마크",
      browse: "찾아보기",
      open: "열기"
    }
  },
  workflows: "워크플로"
};
const tabMenu$2 = {
  addToBookmarks: "북마크에 추가",
  closeOtherTabs: "다른 탭 닫기",
  closeTab: "탭 닫기",
  closeTabsToLeft: "왼쪽 탭 닫기",
  closeTabsToRight: "오른쪽 탭 닫기",
  duplicateTab: "탭 복제",
  removeFromBookmarks: "북마크에서 제거"
};
const templateWorkflows$2 = {
  category: {
    "3D": "3D",
    "Area Composition": "영역 구성",
    Audio: "오디오",
    Basics: "기본",
    "ComfyUI Examples": "ComfyUI 예시",
    ControlNet: "컨트롤넷",
    "Custom Nodes": "사용자 정의 노드",
    Flux: "FLUX",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    Upscaling: "업스케일링",
    Video: "비디오"
  },
  template: {
    "3D": {
      "hunyuan-3d-multiview-elf": "Hunyuan3D 다중뷰",
      "hunyuan-3d-turbo": "Hunyuan3D 터보",
      "hunyuan3d-non-multiview-train": "Hunyuan3D",
      stable_zero123_example: "스테이블 제로123"
    },
    "Area Composition": {
      area_composition: "영역 구성",
      area_composition_reversed: "역 영역 구성",
      area_composition_square_area_for_subject: "주제를 위한 사각형 영역 구성"
    },
    Audio: {
      stable_audio_example: "스테이블 오디오"
    },
    Basics: {
      "default": "이미지 생성",
      embedding_example: "임베딩 예제",
      gligen_textbox_example: "글리젠 텍스트박스 예제",
      image2image: "이미지로 이미지 생성 예제",
      inpain_model_outpainting: "인페인트 모델 아웃페인팅",
      inpaint_example: "인페인트",
      lora: "로라",
      lora_multiple: "다중 로라"
    },
    ControlNet: {
      "2_pass_pose_worship": "2 패스 경배 포즈",
      controlnet_example: "컨트롤넷",
      depth_controlnet: "깊이 컨트롤넷",
      depth_t2i_adapter: "깊이 T2I 어댑터",
      mixing_controlnets: "컨트롤넷 섞기"
    },
    Flux: {
      flux_canny_model_example: "FLUX 캐니 모델 예제",
      flux_depth_lora_example: "FLUX 깊이 로라 예제",
      flux_dev_checkpoint_example: "FLUX Dev 예제",
      flux_fill_inpaint_example: "FLUX 인페인트 예제",
      flux_fill_outpaint_example: "FLUX 아웃페인트 예제",
      flux_redux_model_example: "FLUX Redux 모델 예제",
      flux_schnell: "FLUX Schnell"
    },
    SD3_5: {
      sd3_5_large_blur: "SD3.5 Large 블러 컨트롤넷",
      sd3_5_large_canny_controlnet_example: "SD3.5 Large 캐니 컨트롤넷",
      sd3_5_large_depth: "SD3.5 Large 깊이 컨트롤넷",
      sd3_5_simple_example: "간단한 SD3.5 예제"
    },
    SDXL: {
      sdxl_refiner_prompt_example: "SDXL 리파이너 프롬프트",
      sdxl_revision_text_prompts: "SDXL Revision 텍스트 프롬프트",
      sdxl_revision_zero_positive: "SDXL Revision Zero Positive",
      sdxl_simple_example: "간단한 SDXL 예제",
      sdxlturbo_example: "SDXL 터보"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_esrgan_workflow: "HiresFix ESRGAN 워크플로우",
      hiresfix_latent_workflow: "HiresFix Latent 워크플로우",
      latent_upscale_different_prompt_model: "Latent Upscale 다른 프롬프트 모델"
    },
    Video: {
      hunyuan_video_text_to_video: "텍스트 -> 비디오 (Hunyuan Video)",
      image_to_video: "이미지 -> 동영상",
      image_to_video_wan: "Wan 2.1 이미지에서 비디오로",
      ltxv_image_to_video: "이미지 -> 동영상 (LTXV)",
      ltxv_text_to_video: "텍스트 -> 동영상 (LTXV)",
      mochi_text_to_video_example: "텍스트 -> 동영상 (Mochi)",
      text_to_video_wan: "Wan 2.1 텍스트를 비디오로",
      txt_to_image_to_video: "텍스트 -> 이미지 -> 동영상"
    }
  },
  title: "템플릿으로 시작하기"
};
const userSelect$2 = {
  enterUsername: "사용자 이름 입력",
  existingUser: "기존 사용자",
  newUser: "새 사용자",
  next: "다음",
  selectUser: "사용자 선택"
};
const welcome$2 = {
  getStarted: "시작하기",
  title: "ComfyUI에 오신 것을 환영합니다"
};
const workflowService$2 = {
  enterFilename: "파일 이름 입력",
  exportWorkflow: "워크플로 내보내기",
  saveWorkflow: "워크플로 저장"
};
const ko = {
  clipboard: clipboard$2,
  color: color$2,
  contextMenu: contextMenu$2,
  dataTypes: dataTypes$2,
  desktopMenu: desktopMenu$2,
  desktopUpdate: desktopUpdate$2,
  downloadGit: downloadGit$2,
  electronFileDownload: electronFileDownload$2,
  g: g$2,
  graphCanvasMenu: graphCanvasMenu$2,
  groupNode: groupNode$2,
  icon: icon$2,
  install: install$2,
  issueReport: issueReport$2,
  load3d: load3d$2,
  maintenance: maintenance$2,
  manager: manager$2,
  maskEditor: maskEditor$2,
  menu: menu$2,
  menuLabels: menuLabels$2,
  missingModelsDialog: missingModelsDialog$2,
  nodeCategories: nodeCategories$2,
  nodeTemplates: nodeTemplates$2,
  notSupported: notSupported$2,
  serverConfig: serverConfig$2,
  serverConfigCategories: serverConfigCategories$2,
  serverConfigItems: serverConfigItems$2,
  serverStart: serverStart$2,
  settingsCategories: settingsCategories$2,
  sideToolbar: sideToolbar$2,
  tabMenu: tabMenu$2,
  templateWorkflows: templateWorkflows$2,
  userSelect: userSelect$2,
  welcome: welcome$2,
  workflowService: workflowService$2
};
const AddNoise$2 = {
  display_name: "노이즈 추가",
  inputs: {
    latent_image: {
      name: "잠재 이미지"
    },
    model: {
      name: "모델"
    },
    noise: {
      name: "노이즈"
    },
    sigmas: {
      name: "시그마 배열"
    }
  }
};
const AlignYourStepsScheduler$2 = {
  display_name: "AlignYourSteps 스케쥴러",
  inputs: {
    denoise: {
      name: "노이즈 제거양"
    },
    model_type: {
      name: "모델 유형"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const BasicGuider$2 = {
  display_name: "기본 가이드",
  inputs: {
    conditioning: {
      name: "조건"
    },
    model: {
      name: "모델"
    }
  }
};
const BasicScheduler$2 = {
  display_name: "기본 스케줄러",
  inputs: {
    denoise: {
      name: "노이즈 제거양"
    },
    model: {
      name: "모델"
    },
    scheduler: {
      name: "스케줄러"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const BetaSamplingScheduler$2 = {
  display_name: "베타 샘플링 스케줄러",
  inputs: {
    alpha: {
      name: "알파"
    },
    beta: {
      name: "베타"
    },
    model: {
      name: "모델"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const CFGGuider$2 = {
  display_name: "CFG 가이드",
  inputs: {
    cfg: {
      name: "cfg"
    },
    model: {
      name: "모델"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    }
  }
};
const CLIPAttentionMultiply$2 = {
  display_name: "CLIP 어텐션 곱하기",
  inputs: {
    clip: {
      name: "clip"
    },
    k: {
      name: "k"
    },
    out: {
      name: "out"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const CLIPLoader$2 = {
  description: "[조합법]\n\nstable_diffusion: clip-l\nstable_cascade: clip-g\nsd3: t5 / clip-g / clip-l\nstable_audio: t5\nmochi: t5\ncosmos: old t5 xxl",
  display_name: "CLIP 로드",
  inputs: {
    clip_name: {
      name: "CLIP 파일명"
    },
    device: {
      name: "장치"
    },
    type: {
      name: "유형"
    }
  }
};
const CLIPMergeAdd$2 = {
  display_name: "CLIP 병합 (더하기)",
  inputs: {
    clip1: {
      name: "CLIP1"
    },
    clip2: {
      name: "CLIP2"
    }
  }
};
const CLIPMergeSimple$2 = {
  display_name: "CLIP 병합 (단순)",
  inputs: {
    clip1: {
      name: "CLIP1"
    },
    clip2: {
      name: "CLIP2"
    },
    ratio: {
      name: "비율"
    }
  }
};
const CLIPMergeSubtract$2 = {
  display_name: "CLIP 병합 (빼기)",
  inputs: {
    clip1: {
      name: "CLIP1"
    },
    clip2: {
      name: "CLIP2"
    },
    multiplier: {
      name: "배율"
    }
  }
};
const CLIPSave$2 = {
  display_name: "CLIP 저장",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "파일명 접두사"
    }
  }
};
const CLIPSetLastLayer$2 = {
  display_name: "CLIP 마지막 레이어 설정",
  inputs: {
    clip: {
      name: "clip"
    },
    stop_at_clip_layer: {
      name: "CLIP 레이어 중단점"
    }
  }
};
const CLIPTextEncode$2 = {
  description: "CLIP 모델을 사용하여 텍스트 프롬프트를 인코딩하여 확산 모델이 특정 이미지를 생성하도록 유도하는 임베딩으로 변환합니다.",
  display_name: "CLIP 텍스트 인코딩 (프롬프트)",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "텍스트 인코딩에 사용되는 CLIP 모델입니다."
    },
    text: {
      name: "프롬프트 텍스트",
      tooltip: "인코딩할 텍스트입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "확산 모델을 유도하는 데 사용되는 텍스트 임베딩을 포함하는 조건입니다."
    }
  }
};
const CLIPTextEncodeControlnet$2 = {
  display_name: "CLIP 텍스트 인코딩 (컨트롤넷)",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning: {
      name: "조건"
    },
    text: {
      name: "프롬프트 텍스트"
    }
  }
};
const CLIPTextEncodeFlux$2 = {
  display_name: "CLIP 텍스트 인코딩 (FLUX)",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip-l 프롬프트"
    },
    guidance: {
      name: "가이던스"
    },
    t5xxl: {
      name: "t5xxl 프롬프트"
    }
  }
};
const CLIPTextEncodeHunyuanDiT$2 = {
  display_name: "CLIP 텍스트 인코딩 (HunyuanDiT)",
  inputs: {
    bert: {
      name: "bert 프롬프트"
    },
    clip: {
      name: "clip"
    },
    mt5xl: {
      name: "mt5xl 프롬프트"
    }
  }
};
const CLIPTextEncodeLumina2$2 = {
  description: "CLIP 모델을 사용하여 시스템 프롬프트와 사용자 프롬프트를 인코딩하여 특정 이미지를 생성하는 데 사용할 수 있는 임베딩으로 변환합니다.",
  display_name: "CLIP 텍스트 인코딩 (Lumina2)",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "텍스트를 인코딩하는 데 사용되는 CLIP 모델입니다."
    },
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2는 두 가지 유형의 시스템 프롬프트를 제공합니다.\nSuperior: 텍스트 프롬프트 또는 사용자 프롬프트를 기반으로 우수한 이미지-텍스트 정렬 정도로 우수한 이미지를 생성하도록 설계된 도우미입니다.\nAlignment: 텍스트 프롬프트를 기반으로 이미지-텍스트 정렬의 최고 수준으로 고품질 이미지를 생성하도록 설계된 도우미입니다."
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "인코딩할 텍스트입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "확산 모델을 유도하는 데 사용되는 텍스트 임베딩을 포함하는 조건입니다."
    }
  }
};
const CLIPTextEncodePixArtAlpha$2 = {
  description: "텍스트를 인코딩하고 PixArt Alpha의 해상도 조건을 설정합니다. PixArt Sigma에는 적용되지 않습니다.",
  display_name: "CLIPTextEncodePixArtAlpha",
  inputs: {
    clip: {
      name: "clip"
    },
    height: {
      name: "높이"
    },
    text: {
      name: "프롬프트 텍스트"
    },
    width: {
      name: "너비"
    }
  }
};
const CLIPTextEncodeSD3$2 = {
  display_name: "CLIP 텍스트 인코딩 (SD3)",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_g: {
      name: "clip-g 프롬프트"
    },
    clip_l: {
      name: "clip-l 프롬프트"
    },
    empty_padding: {
      name: "빈_패딩"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeSDXL$2 = {
  display_name: "CLIP 텍스트 인코딩 (SDXL)",
  inputs: {
    clip: {
      name: "clip"
    },
    crop_h: {
      name: "크롭 높이"
    },
    crop_w: {
      name: "크롭 너비"
    },
    height: {
      name: "높이"
    },
    target_height: {
      name: "목표 높이"
    },
    target_width: {
      name: "목표 너비"
    },
    text_g: {
      name: "clip-g 프롬프트"
    },
    text_l: {
      name: "clip-l 프롬프트"
    },
    width: {
      name: "너비"
    }
  }
};
const CLIPTextEncodeSDXLRefiner$2 = {
  display_name: "CLIP 텍스트 인코딩 (SDXL Refiner)",
  inputs: {
    ascore: {
      name: "ascore"
    },
    clip: {
      name: "clip"
    },
    height: {
      name: "높이"
    },
    text: {
      name: "텍스트"
    },
    width: {
      name: "너비"
    }
  }
};
const CLIPVisionEncode$2 = {
  display_name: "CLIP_VISION 인코딩",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    crop: {
      name: "자르기 방법"
    },
    image: {
      name: "이미지"
    }
  }
};
const CLIPVisionLoader$2 = {
  display_name: "CLIP_VISION 로드",
  inputs: {
    clip_name: {
      name: "CLIP 파일명"
    }
  }
};
const Canny$2 = {
  display_name: "Canny 경계 필터",
  inputs: {
    high_threshold: {
      name: "높은 임계값"
    },
    image: {
      name: "이미지"
    },
    low_threshold: {
      name: "낮은 임계값"
    }
  }
};
const CheckpointLoader$2 = {
  display_name: "구성으로 체크포인트 로드 (지원 중단)",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명"
    },
    config_name: {
      name: "설정 이름"
    }
  }
};
const CheckpointLoaderSimple$2 = {
  description: "확산 모델 체크포인트를 로드합니다. 확산 모델은 잠재 데이터의 노이즈를 제거하는 데 사용됩니다.",
  display_name: "체크포인트 로드",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명",
      tooltip: "로드할 체크포인트(모델)의 이름입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "노이즈 제거를 위한 잠재 모델입니다."
    },
    "1": {
      tooltip: "텍스트 프롬프트를 인코딩하는 데 사용되는 CLIP 모델입니다."
    },
    "2": {
      tooltip: "이미지를 잠재 공간으로 인코딩하고 디코딩하는 데 사용되는 VAE 모델입니다."
    }
  }
};
const CheckpointSave$2 = {
  display_name: "체크포인트 저장",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "파일명 접두사"
    },
    model: {
      name: "모델"
    },
    vae: {
      name: "vae"
    }
  }
};
const CombineHooks2$2 = {
  display_name: "후크 결합 [2]",
  inputs: {
    hooks_A: {
      name: "후크 A"
    },
    hooks_B: {
      name: "후크 B"
    }
  }
};
const CombineHooks4$2 = {
  display_name: "후크 결합 [4]",
  inputs: {
    hooks_A: {
      name: "후크 A"
    },
    hooks_B: {
      name: "후크 B"
    },
    hooks_C: {
      name: "후크 C"
    },
    hooks_D: {
      name: "후크 D"
    }
  }
};
const CombineHooks8$2 = {
  display_name: "후크 결합 [8]",
  inputs: {
    hooks_A: {
      name: "후크 A"
    },
    hooks_B: {
      name: "후크 B"
    },
    hooks_C: {
      name: "후크 C"
    },
    hooks_D: {
      name: "후크 D"
    },
    hooks_E: {
      name: "후크 E"
    },
    hooks_F: {
      name: "후크 F"
    },
    hooks_G: {
      name: "후크 G"
    },
    hooks_H: {
      name: "후크 H"
    }
  }
};
const ConditioningAverage$2 = {
  display_name: "조건 (평균)",
  inputs: {
    conditioning_from: {
      name: "추가 조건"
    },
    conditioning_to: {
      name: "대상 조건"
    },
    conditioning_to_strength: {
      name: "대상 조건 강도"
    }
  }
};
const ConditioningCombine$2 = {
  display_name: "조건 (결합)",
  inputs: {
    conditioning_1: {
      name: "조건 1"
    },
    conditioning_2: {
      name: "조건 2"
    }
  }
};
const ConditioningConcat$2 = {
  display_name: "조건 (연결)",
  inputs: {
    conditioning_from: {
      name: "추가 조건"
    },
    conditioning_to: {
      name: "대상 조건"
    }
  }
};
const ConditioningSetArea$2 = {
  display_name: "조건 (영역 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    height: {
      name: "높이"
    },
    strength: {
      name: "강도"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentage$2 = {
  display_name: "조건 (비율로 영역 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    height: {
      name: "높이"
    },
    strength: {
      name: "강도"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentageVideo$2 = {
  display_name: "비디오 조건 (비율로 영역 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    height: {
      name: "높이"
    },
    strength: {
      name: "강도"
    },
    temporal: {
      name: "시간"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    }
  }
};
const ConditioningSetAreaStrength$2 = {
  display_name: "조건 (영역 강도 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    strength: {
      name: "강도"
    }
  }
};
const ConditioningSetDefaultCombine$2 = {
  display_name: "조건 (기본 결합 설정)",
  inputs: {
    cond: {
      name: "조건"
    },
    cond_DEFAULT: {
      name: "기본 조건"
    },
    hooks: {
      name: "후크"
    }
  }
};
const ConditioningSetMask$2 = {
  display_name: "조건 (마스크 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    mask: {
      name: "마스크"
    },
    set_cond_area: {
      name: "조건 영역 설정"
    },
    strength: {
      name: "강도"
    }
  }
};
const ConditioningSetProperties$2 = {
  display_name: "조건 (속성 설정)",
  inputs: {
    cond_NEW: {
      name: "새 조건"
    },
    hooks: {
      name: "후크"
    },
    mask: {
      name: "마스크"
    },
    set_cond_area: {
      name: "조건 영역 설정"
    },
    strength: {
      name: "강도"
    },
    timesteps: {
      name: "타임스텝 범위"
    }
  }
};
const ConditioningSetPropertiesAndCombine$2 = {
  display_name: "조건 (속성 설정 및 결합)",
  inputs: {
    cond: {
      name: "조건"
    },
    cond_NEW: {
      name: "새 조건"
    },
    hooks: {
      name: "후크"
    },
    mask: {
      name: "마스크"
    },
    set_cond_area: {
      name: "조건 영역 설정"
    },
    strength: {
      name: "강도"
    },
    timesteps: {
      name: "타임스텝 범위"
    }
  }
};
const ConditioningSetTimestepRange$2 = {
  display_name: "조건 (타임스텝 범위 설정)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    end: {
      name: "끝"
    },
    start: {
      name: "시작"
    }
  }
};
const ConditioningStableAudio$2 = {
  display_name: "Stable Audio 조건 설정",
  inputs: {
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    seconds_start: {
      name: "시작(초)"
    },
    seconds_total: {
      name: "전체(초)"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const ConditioningTimestepsRange$2 = {
  display_name: "조건 (타임스텝 범위)",
  inputs: {
    end_percent: {
      name: "종료 퍼센트"
    },
    start_percent: {
      name: "시작 퍼센트"
    }
  },
  outputs: {
    "1": {
      name: "이전 범위"
    },
    "2": {
      name: "이후 범위"
    }
  }
};
const ConditioningZeroOut$2 = {
  display_name: "조건 (0으로 출력)",
  inputs: {
    conditioning: {
      name: "조건"
    }
  }
};
const ControlNetApply$2 = {
  display_name: "컨트롤넷 적용 (구형)",
  inputs: {
    conditioning: {
      name: "조건"
    },
    control_net: {
      name: "컨트롤넷"
    },
    image: {
      name: "이미지"
    },
    strength: {
      name: "강도"
    }
  }
};
const ControlNetApplyAdvanced$2 = {
  display_name: "컨트롤넷 적용",
  inputs: {
    control_net: {
      name: "컨트롤넷"
    },
    end_percent: {
      name: "종료 퍼센트"
    },
    image: {
      name: "이미지"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    strength: {
      name: "강도"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const ControlNetApplySD3$2 = {
  display_name: "컨트롤넷을 VAE와 함께 적용",
  inputs: {
    control_net: {
      name: "컨트롤넷"
    },
    end_percent: {
      name: "종료 퍼센트"
    },
    image: {
      name: "이미지"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    strength: {
      name: "강도"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const ControlNetInpaintingAliMamaApply$2 = {
  display_name: "컨트롤넷 인페인팅 AliMama 적용",
  inputs: {
    control_net: {
      name: "컨트롤넷"
    },
    end_percent: {
      name: "종료 퍼센트"
    },
    image: {
      name: "이미지"
    },
    mask: {
      name: "마스크"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    strength: {
      name: "강도"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const ControlNetLoader$2 = {
  display_name: "컨트롤넷 모델 로드",
  inputs: {
    control_net_name: {
      name: "컨트롤넷 파일명"
    }
  }
};
const CosmosImageToVideoLatent$2 = {
  display_name: "CosmosImageToVideoLatent",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    end_image: {
      name: "끝 이미지"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    start_image: {
      name: "시작 이미지"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  }
};
const CreateHookKeyframe$2 = {
  display_name: "후크 키프레임 생성",
  inputs: {
    prev_hook_kf: {
      name: "이전 KF 후크"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    strength_mult: {
      name: "강도 곱"
    }
  },
  outputs: {
    "0": {
      name: "KF 후크"
    }
  }
};
const CreateHookKeyframesFromFloats$2 = {
  display_name: "실수로 후크 키프레임 생성",
  inputs: {
    end_percent: {
      name: "종료 퍼센트"
    },
    floats_strength: {
      name: "실수 강도"
    },
    prev_hook_kf: {
      name: "이전 KF 후크"
    },
    print_keyframes: {
      name: "키프레임 출력"
    },
    start_percent: {
      name: "시작 퍼센트"
    }
  },
  outputs: {
    "0": {
      name: "KF 후크"
    }
  }
};
const CreateHookKeyframesInterpolated$2 = {
  display_name: "보간된 후크 키프레임 생성",
  inputs: {
    end_percent: {
      name: "종료 퍼센트"
    },
    interpolation: {
      name: "보간"
    },
    keyframes_count: {
      name: "키프레임 카운트"
    },
    prev_hook_kf: {
      name: "이전 KF 후크"
    },
    print_keyframes: {
      name: "키프레임 출력"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    strength_end: {
      name: "종료 강도"
    },
    strength_start: {
      name: "시작 강도"
    }
  },
  outputs: {
    "0": {
      name: "KF 후크"
    }
  }
};
const CreateHookLora$2 = {
  display_name: "후크 LoRA 생성",
  inputs: {
    lora_name: {
      name: "LoRA 파일명"
    },
    prev_hooks: {
      name: "이전 후크"
    },
    strength_clip: {
      name: "CLIP 강도"
    },
    strength_model: {
      name: "모델 강도"
    }
  }
};
const CreateHookLoraModelOnly$2 = {
  display_name: "후크 LoRA 생성 (모델 전용)",
  inputs: {
    lora_name: {
      name: "LoRA 파일명"
    },
    prev_hooks: {
      name: "이전 후크"
    },
    strength_model: {
      name: "모델 강도"
    }
  }
};
const CreateHookModelAsLora$2 = {
  display_name: "후크 모델을 LoRA로 생성",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명"
    },
    prev_hooks: {
      name: "이전 후크"
    },
    strength_clip: {
      name: "CLIP 강도"
    },
    strength_model: {
      name: "모델 강도"
    }
  }
};
const CreateHookModelAsLoraModelOnly$2 = {
  display_name: "후크 모델을 LoRA로 생성 (모델 전용)",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명"
    },
    prev_hooks: {
      name: "이전 후크"
    },
    strength_model: {
      name: "모델 강도"
    }
  }
};
const CropMask$2 = {
  display_name: "마스크 자르기",
  inputs: {
    height: {
      name: "높이"
    },
    mask: {
      name: "마스크"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const DiffControlNetLoader$2 = {
  display_name: "컨트롤넷 모델 로드 (차이)",
  inputs: {
    control_net_name: {
      name: "컨트롤넷 파일명"
    },
    model: {
      name: "모델"
    }
  }
};
const DifferentialDiffusion$2 = {
  display_name: "차등 확산",
  inputs: {
    model: {
      name: "모델"
    }
  }
};
const DiffusersLoader$2 = {
  display_name: "Diffusers 로드",
  inputs: {
    model_path: {
      name: "모델 경로"
    }
  }
};
const DisableNoise$2 = {
  display_name: "노이즈 비활성화"
};
const DualCFGGuider$2 = {
  display_name: "이중 CFG 가이드",
  inputs: {
    cfg_cond2_negative: {
      name: "(조건2 - 부정 조건) cfg"
    },
    cfg_conds: {
      name: "전체 조건 cfg"
    },
    cond1: {
      name: "조건1"
    },
    cond2: {
      name: "조건2"
    },
    model: {
      name: "모델"
    },
    negative: {
      name: "부정 조건"
    }
  }
};
const DualCLIPLoader$2 = {
  description: "[조합법]\n\nsdxl: clip-l, clip-g\nsd3: clip-l, clip-g / clip-l, t5 / clip-g, t5\nflux: clip-l, t5",
  display_name: "이중 CLIP 로드",
  inputs: {
    clip_name1: {
      name: "CLIP 파일명1"
    },
    clip_name2: {
      name: "CLIP 파일명2"
    },
    device: {
      name: "장치"
    },
    type: {
      name: "유형"
    }
  }
};
const EmptyCosmosLatentVideo$2 = {
  display_name: "빈 잠재 비디오 (Cosmos)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    width: {
      name: "너비"
    }
  }
};
const EmptyHunyuanLatentVideo$2 = {
  display_name: "빈 잠재 비디오 (Hunyuan)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    width: {
      name: "너비"
    }
  }
};
const EmptyImage$2 = {
  display_name: "빈 이미지",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    color: {
      name: "색"
    },
    height: {
      name: "높이"
    },
    width: {
      name: "너비"
    }
  }
};
const EmptyLTXVLatentVideo$2 = {
  display_name: "빈 잠재 비디오 (LTXV)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    width: {
      name: "너비"
    }
  }
};
const EmptyLatentAudio$2 = {
  display_name: "빈 잠재 오디오",
  inputs: {
    batch_size: {
      name: "배치 크기",
      tooltip: "배치의 잠재 이미지 수입니다."
    },
    seconds: {
      name: "초"
    }
  }
};
const EmptyLatentHunyuan3Dv2$2 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    batch_size: {
      name: "배치 크기",
      tooltip: "배치에 있는 잠재 이미지의 수입니다."
    },
    resolution: {
      name: "해상도"
    }
  }
};
const EmptyLatentImage$2 = {
  description: "샘플링을 통해 디노이즈할 빈 잠재 이미지의 새 배치를 생성합니다.",
  display_name: "빈 잠재 이미지",
  inputs: {
    batch_size: {
      name: "배치 크기",
      tooltip: "배치의 잠재 이미지 수입니다."
    },
    height: {
      name: "높이",
      tooltip: "잠재 이미지의 높이(픽셀)입니다."
    },
    width: {
      name: "너비",
      tooltip: "잠재 이미지의 너비(픽셀)입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "빈 잠재 이미지 배치입니다."
    }
  }
};
const EmptyMochiLatentVideo$2 = {
  display_name: "빈 잠재 비디오 (Mochi)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    width: {
      name: "너비"
    }
  }
};
const EmptySD3LatentImage$2 = {
  display_name: "빈 잠재 이미지 (SD3)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    width: {
      name: "너비"
    }
  }
};
const ExponentialScheduler$2 = {
  display_name: "지수 스케줄러",
  inputs: {
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const FeatherMask$2 = {
  display_name: "마스크 가장자리 흐리게",
  inputs: {
    bottom: {
      name: "아래쪽"
    },
    left: {
      name: "왼쪽"
    },
    mask: {
      name: "마스크"
    },
    right: {
      name: "오른쪽"
    },
    top: {
      name: "위쪽"
    }
  }
};
const FlipSigmas$2 = {
  display_name: "시그마 배열 뒤집기",
  inputs: {
    sigmas: {
      name: "시그마 배열"
    }
  }
};
const FluxDisableGuidance$2 = {
  description: "이 노드는 Flux 및 Flux와 유사한 모델에서 가이던스 임베드를 완전히 비활성화합니다",
  display_name: "가이드 비활성화 (FLUX)",
  inputs: {
    conditioning: {
      name: "조건"
    }
  }
};
const FluxGuidance$2 = {
  display_name: "FLUX 가이드",
  inputs: {
    conditioning: {
      name: "조건"
    },
    guidance: {
      name: "지침"
    }
  }
};
const FreeU$2 = {
  display_name: "FreeU",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "모델"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2$2 = {
  display_name: "FreeU V2",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "모델"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler$2 = {
  display_name: "GITS 스케줄러",
  inputs: {
    coeff: {
      name: "계수"
    },
    denoise: {
      name: "노이즈 제거양"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const GLIGENLoader$2 = {
  display_name: "GLIGEN 로드",
  inputs: {
    gligen_name: {
      name: "gligen 파일명"
    }
  }
};
const GLIGENTextBoxApply$2 = {
  display_name: "GLIGEN 텍스트 박스 적용",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning_to: {
      name: "조건 대상"
    },
    gligen_textbox_model: {
      name: "gligen 텍스트상자 모델"
    },
    height: {
      name: "높이"
    },
    text: {
      name: "텍스트"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask$2 = {
  display_name: "마스크 확장",
  inputs: {
    expand: {
      name: "확장"
    },
    mask: {
      name: "마스크"
    },
    tapered_corners: {
      name: "마름모 모서리"
    }
  }
};
const Hunyuan3Dv2Conditioning$2 = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "clip_vision_output"
    }
  },
  outputs: {
    "0": {
      name: "긍정적"
    },
    "1": {
      name: "부정적"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView$2 = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    back: {
      name: "뒤"
    },
    front: {
      name: "앞"
    },
    left: {
      name: "왼쪽"
    },
    right: {
      name: "오른쪽"
    }
  },
  outputs: {
    "0": {
      name: "긍정적"
    },
    "1": {
      name: "부정적"
    }
  }
};
const HunyuanImageToVideo$2 = {
  display_name: "HunyuanImageToVideo",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    guidance_type: {
      name: "가이던스 유형"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    positive: {
      name: "긍정 조건"
    },
    start_image: {
      name: "시작 이미지"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "잠재 비디오"
    }
  }
};
const HyperTile$2 = {
  display_name: "하이퍼 타일",
  inputs: {
    max_depth: {
      name: "최대 깊이"
    },
    model: {
      name: "모델"
    },
    scale_depth: {
      name: "스케일 깊이"
    },
    swap_size: {
      name: "스왑 크기"
    },
    tile_size: {
      name: "타일 크기"
    }
  }
};
const HypernetworkLoader$2 = {
  display_name: "하이퍼네트워크 로드",
  inputs: {
    hypernetwork_name: {
      name: "하이퍼네트워크 이름"
    },
    model: {
      name: "모델"
    },
    strength: {
      name: "강도"
    }
  }
};
const ImageBatch$2 = {
  display_name: "이미지 배치",
  inputs: {
    image1: {
      name: "이미지1"
    },
    image2: {
      name: "이미지2"
    }
  }
};
const ImageBlend$2 = {
  display_name: "이미지 혼합",
  inputs: {
    blend_factor: {
      name: "혼합 계수"
    },
    blend_mode: {
      name: "혼합 모드"
    },
    image1: {
      name: "이미지1"
    },
    image2: {
      name: "이미지2"
    }
  }
};
const ImageBlur$2 = {
  display_name: "이미지 흐림",
  inputs: {
    blur_radius: {
      name: "블러 반경"
    },
    image: {
      name: "이미지"
    },
    sigma: {
      name: "시그마"
    }
  }
};
const ImageColorToMask$2 = {
  display_name: "이미지 색상을 마스크로 변환",
  inputs: {
    color: {
      name: "색상"
    },
    image: {
      name: "이미지"
    }
  }
};
const ImageCompositeMasked$2 = {
  display_name: "마스크된 이미지 합성",
  inputs: {
    destination: {
      name: "대상"
    },
    mask: {
      name: "마스크"
    },
    resize_source: {
      name: "원본 크기 조정"
    },
    source: {
      name: "원본"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageCrop$2 = {
  display_name: "이미지 자르기",
  inputs: {
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch$2 = {
  display_name: "배치에서 이미지 가져오기",
  inputs: {
    batch_index: {
      name: "배치 번호"
    },
    image: {
      name: "이미지"
    },
    length: {
      name: "길이"
    }
  }
};
const ImageInvert$2 = {
  display_name: "이미지 반전",
  inputs: {
    image: {
      name: "이미지"
    }
  }
};
const ImageOnlyCheckpointLoader$2 = {
  display_name: "이미지 전용 체크포인트 로드 (img2vid 모델)",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명"
    }
  }
};
const ImageOnlyCheckpointSave$2 = {
  display_name: "이미지 전용 체크포인트 저장",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    filename_prefix: {
      name: "파일명 접두사"
    },
    model: {
      name: "모델"
    },
    vae: {
      name: "vae"
    }
  }
};
const ImagePadForOutpaint$2 = {
  display_name: "아웃페인팅을 위한 이미지 패딩",
  inputs: {
    bottom: {
      name: "아래"
    },
    feathering: {
      name: "가장자리 흐림"
    },
    image: {
      name: "이미지"
    },
    left: {
      name: "왼쪽"
    },
    right: {
      name: "오른쪽"
    },
    top: {
      name: "위"
    }
  }
};
const ImageQuantize$2 = {
  display_name: "이미지 양자화",
  inputs: {
    colors: {
      name: "색상"
    },
    dither: {
      name: "디더링"
    },
    image: {
      name: "이미지"
    }
  }
};
const ImageScale$2 = {
  display_name: "이미지 확대",
  inputs: {
    crop: {
      name: "자르기"
    },
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    upscale_method: {
      name: "확대 방법"
    },
    width: {
      name: "너비"
    }
  }
};
const ImageScaleBy$2 = {
  display_name: "이미지 확대 비율",
  inputs: {
    image: {
      name: "이미지"
    },
    scale_by: {
      name: "배율"
    },
    upscale_method: {
      name: "확대 방법"
    }
  }
};
const ImageScaleToTotalPixels$2 = {
  display_name: "총 픽셀 수에 맞춰 이미지 크기 조정",
  inputs: {
    image: {
      name: "이미지"
    },
    megapixels: {
      name: "메가픽셀수"
    },
    upscale_method: {
      name: "확대 방법"
    }
  }
};
const ImageSharpen$2 = {
  display_name: "이미지 선명화",
  inputs: {
    alpha: {
      name: "알파"
    },
    image: {
      name: "이미지"
    },
    sharpen_radius: {
      name: "선명화 반경"
    },
    sigma: {
      name: "시그마"
    }
  }
};
const ImageToMask$2 = {
  display_name: "이미지를 마스크로 변환",
  inputs: {
    channel: {
      name: "채널"
    },
    image: {
      name: "이미지"
    }
  }
};
const ImageUpscaleWithModel$2 = {
  display_name: "모델을 사용한 이미지 확대",
  inputs: {
    image: {
      name: "이미지"
    },
    upscale_model: {
      name: "확대 모델"
    }
  }
};
const InpaintModelConditioning$2 = {
  display_name: "인페인팅 모델 조건 설정",
  inputs: {
    mask: {
      name: "마스크"
    },
    negative: {
      name: "부정 조건"
    },
    noise_mask: {
      name: "노이즈 마스크",
      tooltip: "잠재 데이터에 노이즈 마스크를 추가하여 샘플링이 마스크 내에서만 발생하도록 합니다. 모델에 따라 결과가 개선되거나 완전히 망가질 수 있습니다."
    },
    pixels: {
      name: "픽셀 이미지"
    },
    positive: {
      name: "긍정 조건"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 데이터"
    }
  }
};
const InstructPixToPixConditioning$2 = {
  display_name: "InstructPixToPix 조건 설정",
  inputs: {
    negative: {
      name: "부정 조건"
    },
    pixels: {
      name: "픽셀"
    },
    positive: {
      name: "긍정 조건"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 이미지"
    }
  }
};
const InvertMask$2 = {
  display_name: "마스크 반전",
  inputs: {
    mask: {
      name: "마스크"
    }
  }
};
const JoinImageWithAlpha$2 = {
  display_name: "알파와 함께 이미지 결합",
  inputs: {
    alpha: {
      name: "알파"
    },
    image: {
      name: "이미지"
    }
  }
};
const KSampler$2 = {
  description: "제공된 모델, 긍정 및 부정 조건을 사용하여 잠재 데이터를 디노이즈합니다.",
  display_name: "KSampler",
  inputs: {
    cfg: {
      name: "cfg",
      tooltip: "Classifier-Free Guidance 스케일은 창의성과 프롬프트 준수를 균형 있게 조절합니다. 값이 높을수록 프롬프트와 더 밀접하게 일치하는 이미지가 생성되지만, 너무 높은 값은 품질에 부정적인 영향을 미칠 수 있습니다."
    },
    control_after_generate: {
      name: "생성 후 제어"
    },
    denoise: {
      name: "노이즈 제거양",
      tooltip: "적용되는 노이즈 제거의 양으로, 낮은 값은 초기 이미지의 구조를 유지하여 이미지 간 샘플링을 가능하게 합니다."
    },
    latent_image: {
      name: "잠재 데이터",
      tooltip: "노이즈 제거할 잠재 데이터입니다."
    },
    model: {
      name: "모델",
      tooltip: "입력 잠재 데이터의 노이즈 제거에 사용되는 모델입니다."
    },
    negative: {
      name: "부정 조건",
      tooltip: "이미지에서 제외하고 싶은 속성을 설명하는 조건입니다."
    },
    positive: {
      name: "긍정 조건",
      tooltip: "이미지에 포함하고 싶은 속성을 설명하는 조건입니다."
    },
    sampler_name: {
      name: "샘플러 이름",
      tooltip: "샘플링 시 사용되는 알고리즘으로, 생성된 출력의 품질, 속도 및 스타일에 영향을 미칠 수 있습니다."
    },
    scheduler: {
      name: "스케줄러",
      tooltip: "스케줄러는 노이즈가 점진적으로 제거되어 이미지를 형성하는 방식을 제어합니다."
    },
    seed: {
      name: "시드",
      tooltip: "노이즈 생성을 위한 랜덤 시드입니다."
    },
    steps: {
      name: "스텝수",
      tooltip: "노이즈 제거 과정에서 사용되는 단계 수입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "노이즈가 제거된 잠재 데이터입니다."
    }
  }
};
const KSamplerAdvanced$2 = {
  display_name: "고급 KSampler",
  inputs: {
    add_noise: {
      name: "노이즈 추가"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "생성 후 제어"
    },
    end_at_step: {
      name: "종료 스텝"
    },
    latent_image: {
      name: "잠재 데이터"
    },
    model: {
      name: "모델"
    },
    negative: {
      name: "부정 조건"
    },
    noise_seed: {
      name: "노이즈 시드"
    },
    positive: {
      name: "긍정 조건"
    },
    return_with_leftover_noise: {
      name: "잔여 노이즈 반환"
    },
    sampler_name: {
      name: "샘플러 이름"
    },
    scheduler: {
      name: "스케줄러"
    },
    start_at_step: {
      name: "시작 스텝"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const KSamplerSelect$2 = {
  display_name: "KSampler (선택)",
  inputs: {
    sampler_name: {
      name: "샘플러 이름"
    }
  }
};
const KarrasScheduler$2 = {
  display_name: "Karras 스케줄러",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "최대 시그마"
    },
    sigma_min: {
      name: "최소 시그마"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const LTXVAddGuide$2 = {
  display_name: "LTXV 가이드 추가",
  inputs: {
    frame_idx: {
      name: "프레임 번호",
      tooltip: "조건을 시작할 프레임 번호. 단일 프레임 이미지 또는 1-8 프레임의 비디오의 경우 어떤 프레임 번호 값도 허용됩니다. 9+ 프레임의 비디오의 경우, 프레임 번호는 8의 배수여야 합니다. 그렇지 않으면 가장 가까운 8의 배수로 내림됩니다. 음수 값은 비디오의 끝에서부터 계산됩니다."
    },
    image: {
      name: "이미지",
      tooltip: "잠재 비디오에 조건을 부여하는 이미지 또는 비디오. 8*n + 1 프레임이어야 합니다. 비디오가 8*n + 1 프레임이 아닌 경우 가장 가까운 8*n + 1 프레임으로 자릅니다."
    },
    latent: {
      name: "잠재 비디오"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    strength: {
      name: "강도"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 비디오"
    }
  }
};
const LTXVConditioning$2 = {
  display_name: "LTXV 조건 설정",
  inputs: {
    frame_rate: {
      name: "프레임율"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const LTXVCropGuides$2 = {
  display_name: "LTXV 가이드 자르기",
  inputs: {
    latent: {
      name: "잠재 비디오"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 비디오"
    }
  }
};
const LTXVImgToVideo$2 = {
  display_name: "이미지를 비디오로 (LTXV)",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    length: {
      name: "길이"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 데이터"
    }
  }
};
const LTXVPreprocess$2 = {
  display_name: "LTXV 전처리",
  inputs: {
    image: {
      name: "이미지"
    },
    img_compression: {
      name: "이미지 압축",
      tooltip: "이미지에 적용할 압축의 양."
    }
  },
  outputs: {
    "0": {
      name: "출력 이미지"
    }
  }
};
const LTXVScheduler$2 = {
  display_name: "LTXV 스케줄러",
  inputs: {
    base_shift: {
      name: "기반 시프트"
    },
    latent: {
      name: "잠재 비디오"
    },
    max_shift: {
      name: "최대 시프트"
    },
    steps: {
      name: "스텝수"
    },
    stretch: {
      name: "늘이기",
      tooltip: "시그마를 [종료값, 1] 범위로 늘립니다."
    },
    terminal: {
      name: "종료값",
      tooltip: "늘린 후 시그마의 종료값입니다."
    }
  }
};
const LaplaceScheduler$2 = {
  display_name: "라플라스 스케줄러",
  inputs: {
    beta: {
      name: "beta"
    },
    mu: {
      name: "mu"
    },
    sigma_max: {
      name: "최대 시그마"
    },
    sigma_min: {
      name: "최소 시그마"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const LatentAdd$2 = {
  display_name: "잠재 데이터 연산 (더하기)",
  inputs: {
    samples1: {
      name: "잠재 데이터1"
    },
    samples2: {
      name: "잠재 데이터2"
    }
  }
};
const LatentApplyOperation$2 = {
  display_name: "잠재 데이터 연산 (연산 적용)",
  inputs: {
    operation: {
      name: "연산"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const LatentApplyOperationCFG$2 = {
  display_name: "잠재 데이터 CFG 연산 (연산 적용)",
  inputs: {
    model: {
      name: "모델"
    },
    operation: {
      name: "연산"
    }
  }
};
const LatentBatch$2 = {
  display_name: "잠재 데이터 배치 연결",
  inputs: {
    samples1: {
      name: "잠재 데이터1"
    },
    samples2: {
      name: "잠재 데이터2"
    }
  }
};
const LatentBatchSeedBehavior$2 = {
  display_name: "잠재 데이터 배치 시드 동작",
  inputs: {
    samples: {
      name: "잠재 데이터"
    },
    seed_behavior: {
      name: "시드 동작"
    }
  }
};
const LatentBlend$2 = {
  display_name: "잠재 데이터 연산 (혼합)",
  inputs: {
    blend_factor: {
      name: "혼합 계수"
    },
    samples1: {
      name: "잠재 데이터1"
    },
    samples2: {
      name: "잠재 데이터2"
    }
  }
};
const LatentComposite$2 = {
  display_name: "잠재 데이터 합성 (위치 기반)",
  inputs: {
    feather: {
      name: "가장자리 흐림"
    },
    samples_from: {
      name: "추가 잠재 데이터"
    },
    samples_to: {
      name: "대상 잠재 데이터"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCompositeMasked$2 = {
  display_name: "잠재 데이터 합성 (마스크 기반)",
  inputs: {
    destination: {
      name: "대상"
    },
    mask: {
      name: "마스크"
    },
    resize_source: {
      name: "원본 크기 조정"
    },
    source: {
      name: "원본"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCrop$2 = {
  display_name: "잠재 데이터 자르기",
  inputs: {
    height: {
      name: "높이"
    },
    samples: {
      name: "잠재 데이터"
    },
    width: {
      name: "너비"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip$2 = {
  display_name: "잠재 데이터 연산 (뒤집기)",
  inputs: {
    flip_method: {
      name: "뒤집기 방법"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const LatentFromBatch$2 = {
  display_name: "배치에서 잠재 데이터 가져오기",
  inputs: {
    batch_index: {
      name: "배치_인덱스"
    },
    length: {
      name: "길이"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const LatentInterpolate$2 = {
  display_name: "잠재 데이터 연산 (보간)",
  inputs: {
    ratio: {
      name: "비율"
    },
    samples1: {
      name: "잠재 데이터1"
    },
    samples2: {
      name: "잠재 데이터2"
    }
  }
};
const LatentMultiply$2 = {
  display_name: "잠재 데이터 연산 (곱하기)",
  inputs: {
    multiplier: {
      name: "배율"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const LatentOperationSharpen$2 = {
  display_name: "잠재 데이터 연산 (선명화)",
  inputs: {
    alpha: {
      name: "알파"
    },
    sharpen_radius: {
      name: "선명화 반경"
    },
    sigma: {
      name: "시그마"
    }
  }
};
const LatentOperationTonemapReinhard$2 = {
  display_name: "잠재 데이터 연산 (톤맵 레인하르트)",
  inputs: {
    multiplier: {
      name: "배율"
    }
  }
};
const LatentRotate$2 = {
  display_name: "잠재 데이터 연산 (회전)",
  inputs: {
    rotation: {
      name: "회전"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const LatentSubtract$2 = {
  display_name: "잠재 데이터 연산 (빼기)",
  inputs: {
    samples1: {
      name: "잠재 데이터1"
    },
    samples2: {
      name: "잠재 데이터2"
    }
  }
};
const LatentUpscale$2 = {
  display_name: "잠재 데이터 크기 조정",
  inputs: {
    crop: {
      name: "자르기"
    },
    height: {
      name: "높이"
    },
    samples: {
      name: "잠재 데이터"
    },
    upscale_method: {
      name: "업스케일 방법"
    },
    width: {
      name: "너비"
    }
  }
};
const LatentUpscaleBy$2 = {
  display_name: "잠재 데이터 크기 배율 조정",
  inputs: {
    samples: {
      name: "잠재 데이터"
    },
    scale_by: {
      name: "확대율"
    },
    upscale_method: {
      name: "확대 방법"
    }
  }
};
const Load3D$2 = {
  display_name: "3D 로드",
  inputs: {
    clear: {},
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    model_file: {
      name: "모델 파일"
    },
    "upload 3d model": {},
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "이미지"
    },
    "1": {
      name: "마스크"
    },
    "2": {
      name: "메시 경로"
    }
  }
};
const Load3DAnimation$2 = {
  display_name: "3D 로드 - 애니메이션",
  inputs: {
    clear: {},
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    model_file: {
      name: "모델 파일"
    },
    "upload 3d model": {},
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "이미지"
    },
    "1": {
      name: "마스크"
    },
    "2": {
      name: "메시 경로"
    }
  }
};
const LoadAudio$2 = {
  display_name: "오디오 로드",
  inputs: {
    audio: {
      name: "오디오"
    },
    audioUI: {
      name: "오디오UI"
    },
    upload: {
      name: "업로드할 파일 선택"
    }
  }
};
const LoadImage$2 = {
  display_name: "이미지 로드",
  inputs: {
    image: {
      name: "이미지"
    },
    upload: {
      name: "업로드할 파일 선택"
    }
  }
};
const LoadImageMask$2 = {
  display_name: "마스크 이미지 로드",
  inputs: {
    channel: {
      name: "채널"
    },
    image: {
      name: "이미지"
    },
    upload: {
      name: "업로드할 파일 선택"
    }
  }
};
const LoadImageOutput$2 = {
  description: "입력(input) 폴더 대신 출력(output) 폴더에서 이미지를 로드합니다. 새로 고침 버튼을 클릭하면 노드는 이미지 목록을 업데이트하고 자동으로 첫 번째 이미지를 선택하여 쉬운 반복을 가능하게 합니다.",
  display_name: "이미지 로드 (출력에서)",
  inputs: {
    image: {
      name: "이미지"
    },
    refresh: {},
    upload: {
      name: "업로드할 파일 선택"
    }
  }
};
const LoadLatent$2 = {
  display_name: "잠재 데이터 로드",
  inputs: {
    latent: {
      name: "잠재 데이터"
    }
  }
};
const LoraLoader$2 = {
  description: "LoRA는 확산 모델과 CLIP 모델을 부분적으로 변경해서, 잠재 데이터의 노이즈 제거 방향을 바꿉니다. 여러 LoRA 노드를 연결할 수 있습니다.",
  display_name: "LoRA 로드",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "LoRA가 적용될 CLIP 모델입니다."
    },
    lora_name: {
      name: "LoRA 이름",
      tooltip: "LoRA의 이름입니다."
    },
    model: {
      name: "모델",
      tooltip: "LoRA가 적용될 확산 모델입니다."
    },
    strength_clip: {
      name: "clip 강도",
      tooltip: "CLIP 모델을 적용하는 강도입니다. 이 값은 음수가 될 수 있습니다."
    },
    strength_model: {
      name: "모델 강도",
      tooltip: "확산 모델을 적용하는 강도입니다. 이 값은 음수가 될 수 있습니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "수정된 확산 모델입니다."
    },
    "1": {
      tooltip: "수정된 CLIP 모델입니다."
    }
  }
};
const LoraLoaderModelOnly$2 = {
  description: "LoRA는 확산 모델과 CLIP 모델을 부분적으로 변경해서, 잠재 데이터의 노이즈 제거 방향을 바꿉니다. 여러 LoRA 노드를 연결할 수 있습니다. (이 노드는 CLIP 모델은 로드하지 않습니다.)",
  display_name: "LoRA 로드 (모델 전용)",
  inputs: {
    lora_name: {
      name: "LoRA 이름"
    },
    model: {
      name: "모델"
    },
    strength_model: {
      name: "모델 강도"
    }
  },
  outputs: {
    "0": {
      tooltip: "수정된 확산 모델입니다."
    }
  }
};
const LoraSave$2 = {
  display_name: "LoRA 추출 및 저장",
  inputs: {
    bias_diff: {
      name: "차이 편향"
    },
    filename_prefix: {
      name: "파일명 접두사"
    },
    lora_type: {
      name: "LoRA 유형"
    },
    model_diff: {
      name: "모델 차이",
      tooltip: "LoRA로 변환 될 ModelSubtract 출력입니다."
    },
    rank: {
      name: "순위"
    },
    text_encoder_diff: {
      name: "텍스트 인코더 차이",
      tooltip: "LoRA로 변환 될 CLIPSubtract 출력입니다."
    }
  }
};
const Mahiro$2 = {
  description: "노이즈 제거의 '방향'을 긍정 조건과 부정 조건 차에 의한 것 보다는 긍정 조건 방향으로 더 크게 작동하도록 가이더 동작을 변경합니다.",
  display_name: "마히로",
  inputs: {
    model: {
      name: "모델"
    }
  },
  outputs: {
    "0": {
      name: "변경된 모델"
    }
  }
};
const MaskComposite$2 = {
  display_name: "마스크 합성",
  inputs: {
    destination: {
      name: "대상"
    },
    operation: {
      name: "연산"
    },
    source: {
      name: "원본"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const MaskToImage$2 = {
  display_name: "마스크를 이미지로 변환",
  inputs: {
    mask: {
      name: "마스크"
    }
  }
};
const ModelComputeDtype$2 = {
  display_name: "ModelComputeDtype",
  inputs: {
    dtype: {
      name: "dtype"
    },
    model: {
      name: "모델"
    }
  }
};
const ModelMergeAdd$2 = {
  display_name: "모델 병합 (더하기)",
  inputs: {
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    }
  }
};
const ModelMergeAuraflow$2 = {
  display_name: "모델 병합 (AuraFlow)",
  inputs: {
    cond_seq_linear_: {
      name: "cond_seq_linear."
    },
    double_layers_0_: {
      name: "double_layers.0."
    },
    double_layers_1_: {
      name: "double_layers.1."
    },
    double_layers_2_: {
      name: "double_layers.2."
    },
    double_layers_3_: {
      name: "double_layers.3."
    },
    final_linear_: {
      name: "final_linear."
    },
    init_x_linear_: {
      name: "init_x_linear."
    },
    modF_: {
      name: "modF."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    positional_encoding: {
      name: "positional_encoding"
    },
    register_tokens: {
      name: "register_tokens"
    },
    single_layers_0_: {
      name: "single_layers.0."
    },
    single_layers_10_: {
      name: "single_layers.10."
    },
    single_layers_11_: {
      name: "single_layers.11."
    },
    single_layers_12_: {
      name: "single_layers.12."
    },
    single_layers_13_: {
      name: "single_layers.13."
    },
    single_layers_14_: {
      name: "single_layers.14."
    },
    single_layers_15_: {
      name: "single_layers.15."
    },
    single_layers_16_: {
      name: "single_layers.16."
    },
    single_layers_17_: {
      name: "single_layers.17."
    },
    single_layers_18_: {
      name: "single_layers.18."
    },
    single_layers_19_: {
      name: "single_layers.19."
    },
    single_layers_1_: {
      name: "single_layers.1."
    },
    single_layers_20_: {
      name: "single_layers.20."
    },
    single_layers_21_: {
      name: "single_layers.21."
    },
    single_layers_22_: {
      name: "single_layers.22."
    },
    single_layers_23_: {
      name: "single_layers.23."
    },
    single_layers_24_: {
      name: "single_layers.24."
    },
    single_layers_25_: {
      name: "single_layers.25."
    },
    single_layers_26_: {
      name: "single_layers.26."
    },
    single_layers_27_: {
      name: "single_layers.27."
    },
    single_layers_28_: {
      name: "single_layers.28."
    },
    single_layers_29_: {
      name: "single_layers.29."
    },
    single_layers_2_: {
      name: "single_layers.2."
    },
    single_layers_30_: {
      name: "single_layers.30."
    },
    single_layers_31_: {
      name: "single_layers.31."
    },
    single_layers_3_: {
      name: "single_layers.3."
    },
    single_layers_4_: {
      name: "single_layers.4."
    },
    single_layers_5_: {
      name: "single_layers.5."
    },
    single_layers_6_: {
      name: "single_layers.6."
    },
    single_layers_7_: {
      name: "single_layers.7."
    },
    single_layers_8_: {
      name: "single_layers.8."
    },
    single_layers_9_: {
      name: "single_layers.9."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeBlocks$2 = {
  display_name: "모델 병합 (블록)",
  inputs: {
    input: {
      name: "input"
    },
    middle: {
      name: "middle"
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    out: {
      name: "out"
    }
  }
};
const ModelMergeCosmos14B$2 = {
  display_name: "모델 병합 (Cosmos 14B)",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeCosmos7B$2 = {
  display_name: "모델 병합 (Cosmos 7B)",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeFlux1$2 = {
  display_name: "모델 병합 (FLUX.1)",
  inputs: {
    double_blocks_0_: {
      name: "double_blocks.0."
    },
    double_blocks_10_: {
      name: "double_blocks.10."
    },
    double_blocks_11_: {
      name: "double_blocks.11."
    },
    double_blocks_12_: {
      name: "double_blocks.12."
    },
    double_blocks_13_: {
      name: "double_blocks.13."
    },
    double_blocks_14_: {
      name: "double_blocks.14."
    },
    double_blocks_15_: {
      name: "double_blocks.15."
    },
    double_blocks_16_: {
      name: "double_blocks.16."
    },
    double_blocks_17_: {
      name: "double_blocks.17."
    },
    double_blocks_18_: {
      name: "double_blocks.18."
    },
    double_blocks_1_: {
      name: "double_blocks.1."
    },
    double_blocks_2_: {
      name: "double_blocks.2."
    },
    double_blocks_3_: {
      name: "double_blocks.3."
    },
    double_blocks_4_: {
      name: "double_blocks.4."
    },
    double_blocks_5_: {
      name: "double_blocks.5."
    },
    double_blocks_6_: {
      name: "double_blocks.6."
    },
    double_blocks_7_: {
      name: "double_blocks.7."
    },
    double_blocks_8_: {
      name: "double_blocks.8."
    },
    double_blocks_9_: {
      name: "double_blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    guidance_in: {
      name: "guidance_in"
    },
    img_in_: {
      name: "img_in."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    single_blocks_0_: {
      name: "single_blocks.0."
    },
    single_blocks_10_: {
      name: "single_blocks.10."
    },
    single_blocks_11_: {
      name: "single_blocks.11."
    },
    single_blocks_12_: {
      name: "single_blocks.12."
    },
    single_blocks_13_: {
      name: "single_blocks.13."
    },
    single_blocks_14_: {
      name: "single_blocks.14."
    },
    single_blocks_15_: {
      name: "single_blocks.15."
    },
    single_blocks_16_: {
      name: "single_blocks.16."
    },
    single_blocks_17_: {
      name: "single_blocks.17."
    },
    single_blocks_18_: {
      name: "single_blocks.18."
    },
    single_blocks_19_: {
      name: "single_blocks.19."
    },
    single_blocks_1_: {
      name: "single_blocks.1."
    },
    single_blocks_20_: {
      name: "single_blocks.20."
    },
    single_blocks_21_: {
      name: "single_blocks.21."
    },
    single_blocks_22_: {
      name: "single_blocks.22."
    },
    single_blocks_23_: {
      name: "single_blocks.23."
    },
    single_blocks_24_: {
      name: "single_blocks.24."
    },
    single_blocks_25_: {
      name: "single_blocks.25."
    },
    single_blocks_26_: {
      name: "single_blocks.26."
    },
    single_blocks_27_: {
      name: "single_blocks.27."
    },
    single_blocks_28_: {
      name: "single_blocks.28."
    },
    single_blocks_29_: {
      name: "single_blocks.29."
    },
    single_blocks_2_: {
      name: "single_blocks.2."
    },
    single_blocks_30_: {
      name: "single_blocks.30."
    },
    single_blocks_31_: {
      name: "single_blocks.31."
    },
    single_blocks_32_: {
      name: "single_blocks.32."
    },
    single_blocks_33_: {
      name: "single_blocks.33."
    },
    single_blocks_34_: {
      name: "single_blocks.34."
    },
    single_blocks_35_: {
      name: "single_blocks.35."
    },
    single_blocks_36_: {
      name: "single_blocks.36."
    },
    single_blocks_37_: {
      name: "single_blocks.37."
    },
    single_blocks_3_: {
      name: "single_blocks.3."
    },
    single_blocks_4_: {
      name: "single_blocks.4."
    },
    single_blocks_5_: {
      name: "single_blocks.5."
    },
    single_blocks_6_: {
      name: "single_blocks.6."
    },
    single_blocks_7_: {
      name: "single_blocks.7."
    },
    single_blocks_8_: {
      name: "single_blocks.8."
    },
    single_blocks_9_: {
      name: "single_blocks.9."
    },
    time_in_: {
      name: "time_in."
    },
    txt_in_: {
      name: "txt_in."
    },
    vector_in_: {
      name: "vector_in."
    }
  }
};
const ModelMergeLTXV$2 = {
  display_name: "모델 병합 (LTXV)",
  inputs: {
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "caption_projection."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    proj_out_: {
      name: "proj_out."
    },
    scale_shift_table: {
      name: "scale_shift_table"
    },
    transformer_blocks_0_: {
      name: "transformer_blocks.0."
    },
    transformer_blocks_10_: {
      name: "transformer_blocks.10."
    },
    transformer_blocks_11_: {
      name: "transformer_blocks.11."
    },
    transformer_blocks_12_: {
      name: "transformer_blocks.12."
    },
    transformer_blocks_13_: {
      name: "transformer_blocks.13."
    },
    transformer_blocks_14_: {
      name: "transformer_blocks.14."
    },
    transformer_blocks_15_: {
      name: "transformer_blocks.15."
    },
    transformer_blocks_16_: {
      name: "transformer_blocks.16."
    },
    transformer_blocks_17_: {
      name: "transformer_blocks.17."
    },
    transformer_blocks_18_: {
      name: "transformer_blocks.18."
    },
    transformer_blocks_19_: {
      name: "transformer_blocks.19."
    },
    transformer_blocks_1_: {
      name: "transformer_blocks.1."
    },
    transformer_blocks_20_: {
      name: "transformer_blocks.20."
    },
    transformer_blocks_21_: {
      name: "transformer_blocks.21."
    },
    transformer_blocks_22_: {
      name: "transformer_blocks.22."
    },
    transformer_blocks_23_: {
      name: "transformer_blocks.23."
    },
    transformer_blocks_24_: {
      name: "transformer_blocks.24."
    },
    transformer_blocks_25_: {
      name: "transformer_blocks.25."
    },
    transformer_blocks_26_: {
      name: "transformer_blocks.26."
    },
    transformer_blocks_27_: {
      name: "transformer_blocks.27."
    },
    transformer_blocks_2_: {
      name: "transformer_blocks.2."
    },
    transformer_blocks_3_: {
      name: "transformer_blocks.3."
    },
    transformer_blocks_4_: {
      name: "transformer_blocks.4."
    },
    transformer_blocks_5_: {
      name: "transformer_blocks.5."
    },
    transformer_blocks_6_: {
      name: "transformer_blocks.6."
    },
    transformer_blocks_7_: {
      name: "transformer_blocks.7."
    },
    transformer_blocks_8_: {
      name: "transformer_blocks.8."
    },
    transformer_blocks_9_: {
      name: "transformer_blocks.9."
    }
  }
};
const ModelMergeMochiPreview$2 = {
  display_name: "모델 병합 (Mochi Preview)",
  inputs: {
    blocks_0_: {
      name: "blocks.0."
    },
    blocks_10_: {
      name: "blocks.10."
    },
    blocks_11_: {
      name: "blocks.11."
    },
    blocks_12_: {
      name: "blocks.12."
    },
    blocks_13_: {
      name: "blocks.13."
    },
    blocks_14_: {
      name: "blocks.14."
    },
    blocks_15_: {
      name: "blocks.15."
    },
    blocks_16_: {
      name: "blocks.16."
    },
    blocks_17_: {
      name: "blocks.17."
    },
    blocks_18_: {
      name: "blocks.18."
    },
    blocks_19_: {
      name: "blocks.19."
    },
    blocks_1_: {
      name: "blocks.1."
    },
    blocks_20_: {
      name: "blocks.20."
    },
    blocks_21_: {
      name: "blocks.21."
    },
    blocks_22_: {
      name: "blocks.22."
    },
    blocks_23_: {
      name: "blocks.23."
    },
    blocks_24_: {
      name: "blocks.24."
    },
    blocks_25_: {
      name: "blocks.25."
    },
    blocks_26_: {
      name: "blocks.26."
    },
    blocks_27_: {
      name: "blocks.27."
    },
    blocks_28_: {
      name: "blocks.28."
    },
    blocks_29_: {
      name: "blocks.29."
    },
    blocks_2_: {
      name: "blocks.2."
    },
    blocks_30_: {
      name: "blocks.30."
    },
    blocks_31_: {
      name: "blocks.31."
    },
    blocks_32_: {
      name: "blocks.32."
    },
    blocks_33_: {
      name: "blocks.33."
    },
    blocks_34_: {
      name: "blocks.34."
    },
    blocks_35_: {
      name: "blocks.35."
    },
    blocks_36_: {
      name: "blocks.36."
    },
    blocks_37_: {
      name: "blocks.37."
    },
    blocks_38_: {
      name: "blocks.38."
    },
    blocks_39_: {
      name: "blocks.39."
    },
    blocks_3_: {
      name: "blocks.3."
    },
    blocks_40_: {
      name: "blocks.40."
    },
    blocks_41_: {
      name: "blocks.41."
    },
    blocks_42_: {
      name: "blocks.42."
    },
    blocks_43_: {
      name: "blocks.43."
    },
    blocks_44_: {
      name: "blocks.44."
    },
    blocks_45_: {
      name: "blocks.45."
    },
    blocks_46_: {
      name: "blocks.46."
    },
    blocks_47_: {
      name: "blocks.47."
    },
    blocks_4_: {
      name: "blocks.4."
    },
    blocks_5_: {
      name: "blocks.5."
    },
    blocks_6_: {
      name: "blocks.6."
    },
    blocks_7_: {
      name: "blocks.7."
    },
    blocks_8_: {
      name: "blocks.8."
    },
    blocks_9_: {
      name: "blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    pos_frequencies_: {
      name: "pos_frequencies."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeSD1$2 = {
  display_name: "모델 병합 (SD1)",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_blocks.0."
    },
    middle_block_1_: {
      name: "middle_blocks.1."
    },
    middle_block_2_: {
      name: "middle_blocks.2."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "out_blocks.0."
    },
    output_blocks_10_: {
      name: "out_blocks.10."
    },
    output_blocks_11_: {
      name: "out_blocks.11."
    },
    output_blocks_1_: {
      name: "out_blocks.1."
    },
    output_blocks_2_: {
      name: "out_blocks.2."
    },
    output_blocks_3_: {
      name: "out_blocks.3."
    },
    output_blocks_4_: {
      name: "out_blocks.4."
    },
    output_blocks_5_: {
      name: "out_blocks.5."
    },
    output_blocks_6_: {
      name: "out_blocks.6."
    },
    output_blocks_7_: {
      name: "out_blocks.7."
    },
    output_blocks_8_: {
      name: "out_blocks.8."
    },
    output_blocks_9_: {
      name: "out_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD2$2 = {
  display_name: "모델 병합 (SD2)",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_blocks.0."
    },
    middle_block_1_: {
      name: "middle_blocks.1."
    },
    middle_block_2_: {
      name: "middle_blocks.2."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "out_blocks.0."
    },
    output_blocks_10_: {
      name: "out_blocks.10."
    },
    output_blocks_11_: {
      name: "out_blocks.11."
    },
    output_blocks_1_: {
      name: "out_blocks.1."
    },
    output_blocks_2_: {
      name: "out_blocks.2."
    },
    output_blocks_3_: {
      name: "out_blocks.3."
    },
    output_blocks_4_: {
      name: "out_blocks.4."
    },
    output_blocks_5_: {
      name: "out_blocks.5."
    },
    output_blocks_6_: {
      name: "out_blocks.6."
    },
    output_blocks_7_: {
      name: "out_blocks.7."
    },
    output_blocks_8_: {
      name: "out_blocks.8."
    },
    output_blocks_9_: {
      name: "out_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD35_Large$2 = {
  display_name: "모델 병합 (SD35 Large)",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_24_: {
      name: "joint_blocks.24."
    },
    joint_blocks_25_: {
      name: "joint_blocks.25."
    },
    joint_blocks_26_: {
      name: "joint_blocks.26."
    },
    joint_blocks_27_: {
      name: "joint_blocks.27."
    },
    joint_blocks_28_: {
      name: "joint_blocks.28."
    },
    joint_blocks_29_: {
      name: "joint_blocks.29."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_30_: {
      name: "joint_blocks.30."
    },
    joint_blocks_31_: {
      name: "joint_blocks.31."
    },
    joint_blocks_32_: {
      name: "joint_blocks.32."
    },
    joint_blocks_33_: {
      name: "joint_blocks.33."
    },
    joint_blocks_34_: {
      name: "joint_blocks.34."
    },
    joint_blocks_35_: {
      name: "joint_blocks.35."
    },
    joint_blocks_36_: {
      name: "joint_blocks.36."
    },
    joint_blocks_37_: {
      name: "joint_blocks.37."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSD3_2B$2 = {
  display_name: "모델 병합 (SD3 2B)",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSDXL$2 = {
  display_name: "모델 병합 (SDXL)",
  inputs: {
    input_blocks_0: {
      name: "input_blocks.0"
    },
    input_blocks_1: {
      name: "input_blocks.1"
    },
    input_blocks_2: {
      name: "input_blocks.2"
    },
    input_blocks_3: {
      name: "input_blocks.3"
    },
    input_blocks_4: {
      name: "input_blocks.4"
    },
    input_blocks_5: {
      name: "input_blocks.5"
    },
    input_blocks_6: {
      name: "input_blocks.6"
    },
    input_blocks_7: {
      name: "input_blocks.7"
    },
    input_blocks_8: {
      name: "input_blocks.8"
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0: {
      name: "middle_block.0"
    },
    middle_block_1: {
      name: "middle_block.1"
    },
    middle_block_2: {
      name: "middle_block.2"
    },
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0: {
      name: "output_blocks.0"
    },
    output_blocks_1: {
      name: "output_blocks.1"
    },
    output_blocks_2: {
      name: "output_blocks.2"
    },
    output_blocks_3: {
      name: "output_blocks.3"
    },
    output_blocks_4: {
      name: "output_blocks.4"
    },
    output_blocks_5: {
      name: "output_blocks.5"
    },
    output_blocks_6: {
      name: "output_blocks.6"
    },
    output_blocks_7: {
      name: "output_blocks.7"
    },
    output_blocks_8: {
      name: "output_blocks.8"
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSimple$2 = {
  display_name: "모델 병합 (단순)",
  inputs: {
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    ratio: {
      name: "비율"
    }
  }
};
const ModelMergeSubtract$2 = {
  display_name: "모델 병합 (빼기)",
  inputs: {
    model1: {
      name: "모델1"
    },
    model2: {
      name: "모델2"
    },
    multiplier: {
      name: "배율"
    }
  }
};
const ModelSamplingAuraFlow$2 = {
  display_name: "모델 샘플링 (AuraFlow)",
  inputs: {
    model: {
      name: "모델"
    },
    shift: {
      name: "시프트"
    }
  }
};
const ModelSamplingContinuousEDM$2 = {
  display_name: "모델 샘플링 (연속 EDM)",
  inputs: {
    model: {
      name: "모델"
    },
    sampling: {
      name: "샘플링"
    },
    sigma_max: {
      name: "최대 시그마"
    },
    sigma_min: {
      name: "최소 시그마"
    }
  }
};
const ModelSamplingContinuousV$2 = {
  display_name: "모델 샘플링 (연속 V)",
  inputs: {
    model: {
      name: "모델"
    },
    sampling: {
      name: "샘플링"
    },
    sigma_max: {
      name: "최대 시그마"
    },
    sigma_min: {
      name: "최소 시그마"
    }
  }
};
const ModelSamplingDiscrete$2 = {
  display_name: "모델 샘플링 (이산)",
  inputs: {
    model: {
      name: "모델"
    },
    sampling: {
      name: "샘플링"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux$2 = {
  display_name: "모델 샘플링 (FLUX)",
  inputs: {
    base_shift: {
      name: "기본_시프트"
    },
    height: {
      name: "높이"
    },
    max_shift: {
      name: "최대 시프트"
    },
    model: {
      name: "모델"
    },
    width: {
      name: "너비"
    }
  }
};
const ModelSamplingLTXV$2 = {
  display_name: "모델 샘플링 (LTXV)",
  inputs: {
    base_shift: {
      name: "기반 시프트"
    },
    latent: {
      name: "잠재 비디오"
    },
    max_shift: {
      name: "최대 시프트"
    },
    model: {
      name: "모델"
    }
  }
};
const ModelSamplingSD3$2 = {
  display_name: "모델 샘플링 (SD3)",
  inputs: {
    model: {
      name: "모델"
    },
    shift: {
      name: "시프트"
    }
  }
};
const ModelSamplingStableCascade$2 = {
  display_name: "모델 샘플링 (StableCascade)",
  inputs: {
    model: {
      name: "모델"
    },
    shift: {
      name: "시프트"
    }
  }
};
const ModelSave$2 = {
  display_name: "모델 저장",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사"
    },
    model: {
      name: "모델"
    }
  }
};
const Morphology$2 = {
  display_name: "이미지 형태 변환",
  inputs: {
    image: {
      name: "이미지"
    },
    kernel_size: {
      name: "커널 크기"
    },
    operation: {
      name: "연산"
    }
  }
};
const PairConditioningCombine$2 = {
  display_name: "조건 쌍 (결합)",
  inputs: {
    negative_A: {
      name: "부정 조건 A"
    },
    negative_B: {
      name: "부정 조건 B"
    },
    positive_A: {
      name: "긍정 조건 A"
    },
    positive_B: {
      name: "긍정 조건 B"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const PairConditioningSetDefaultCombine$2 = {
  display_name: "조건 쌍 (기본 결합 설정)",
  inputs: {
    hooks: {
      name: "후크"
    },
    negative: {
      name: "부정 조건"
    },
    negative_DEFAULT: {
      name: "기본 부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    positive_DEFAULT: {
      name: "기본 긍정 조건"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const PairConditioningSetProperties$2 = {
  display_name: "조건 쌍 (속성 설정)",
  inputs: {
    hooks: {
      name: "후크"
    },
    mask: {
      name: "마스크"
    },
    negative_NEW: {
      name: "새 부정 조건"
    },
    positive_NEW: {
      name: "새 긍정 조건"
    },
    set_cond_area: {
      name: "조건 영역 설정"
    },
    strength: {
      name: "강도"
    },
    timesteps: {
      name: "타임스텝 범위"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const PairConditioningSetPropertiesAndCombine$2 = {
  display_name: "조건 쌍 (속성 설정 및 결합)",
  inputs: {
    hooks: {
      name: "후크"
    },
    mask: {
      name: "마스크"
    },
    negative: {
      name: "부정 조건"
    },
    negative_NEW: {
      name: "새 부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    positive_NEW: {
      name: "새 긍정 조건"
    },
    set_cond_area: {
      name: "조건 영역 설정"
    },
    strength: {
      name: "강도"
    },
    timesteps: {
      name: "타임스텝 범위"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    }
  }
};
const PatchModelAddDownscale$2 = {
  display_name: "다운스케일 추가 모델 패치 (Kohya Deep Shrink)",
  inputs: {
    block_number: {
      name: "블록 번호"
    },
    downscale_after_skip: {
      name: "스킵 후 다운스케일"
    },
    downscale_factor: {
      name: "다운스케일 배율"
    },
    downscale_method: {
      name: "다운스케일 방법"
    },
    end_percent: {
      name: "종료 퍼센트"
    },
    model: {
      name: "모델"
    },
    start_percent: {
      name: "시작 퍼센트"
    },
    upscale_method: {
      name: "업스케일 방법"
    }
  }
};
const PerpNeg$2 = {
  display_name: "Perp-Neg (PerpNegGuider에 의해 지원 중단됨)",
  inputs: {
    empty_conditioning: {
      name: "빈 조건"
    },
    model: {
      name: "모델"
    },
    neg_scale: {
      name: "부정 스케일"
    }
  }
};
const PerpNegGuider$2 = {
  display_name: "PerpNeg 가이드",
  inputs: {
    cfg: {
      name: "cfg"
    },
    empty_conditioning: {
      name: "빈 조건"
    },
    model: {
      name: "모델"
    },
    neg_scale: {
      name: "부정 스케일"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    }
  }
};
const PerturbedAttentionGuidance$2 = {
  display_name: "교란 어텐션 유도 (PAG)",
  inputs: {
    model: {
      name: "모델"
    },
    scale: {
      name: "스케일"
    }
  }
};
const PhotoMakerEncode$2 = {
  display_name: "포토메이커 인코딩",
  inputs: {
    clip: {
      name: "clip"
    },
    image: {
      name: "이미지"
    },
    photomaker: {
      name: "포토메이커 모델"
    },
    text: {
      name: "텍스트"
    }
  }
};
const PhotoMakerLoader$2 = {
  display_name: "포토메이커 로드",
  inputs: {
    photomaker_model_name: {
      name: "포토메이커 파일명"
    }
  }
};
const PolyexponentialScheduler$2 = {
  display_name: "다항 지수 스케줄러",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "최대 시그마"
    },
    sigma_min: {
      name: "최소 시그마"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const PorterDuffImageComposite$2 = {
  display_name: "포터-더프 이미지 합성",
  inputs: {
    destination: {
      name: "대상"
    },
    destination_alpha: {
      name: "대상 알파"
    },
    mode: {
      name: "모드"
    },
    source: {
      name: "원본"
    },
    source_alpha: {
      name: "원본 알파"
    }
  }
};
const Preview3D$2 = {
  display_name: "3D 미리보기",
  inputs: {
    image: {
      name: "이미지"
    },
    model_file: {
      name: "모델 파일"
    }
  }
};
const Preview3DAnimation$2 = {
  display_name: "3D 미리보기 - 애니메이션",
  inputs: {
    image: {
      name: "이미지"
    },
    model_file: {
      name: "모델 파일"
    }
  }
};
const PreviewAudio$2 = {
  display_name: "오디오 미리듣기",
  inputs: {
    audio: {
      name: "오디오"
    },
    audioUI: {
      name: "오디오UI"
    }
  }
};
const PreviewImage$2 = {
  description: "입력 이미지를 ComfyUI 의 임시(temp) 폴더에 저장합니다.",
  display_name: "이미지 미리보기",
  inputs: {
    images: {
      name: "이미지"
    }
  }
};
const RandomNoise$2 = {
  display_name: "무작위 노이즈",
  inputs: {
    control_after_generate: {
      name: "생성 후 제어"
    },
    noise_seed: {
      name: "노이즈 시드"
    }
  }
};
const RebatchImages$2 = {
  display_name: "이미지 배치 재배치",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    images: {
      name: "이미지"
    }
  }
};
const RebatchLatents$2 = {
  display_name: "잠재 데이터 배치 재배치",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    latents: {
      name: "잠재 데이터"
    }
  }
};
const RenormCFG$2 = {
  display_name: "RenormCFG",
  inputs: {
    cfg_trunc: {
      name: "cfg_trunc"
    },
    model: {
      name: "모델"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch$2 = {
  display_name: "이미지 반복 배치 생성",
  inputs: {
    amount: {
      name: "개수"
    },
    image: {
      name: "이미지"
    }
  }
};
const RepeatLatentBatch$2 = {
  display_name: "잠재 데이터 반복 배치 생성",
  inputs: {
    amount: {
      name: "개수"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const RescaleCFG$2 = {
  display_name: "CFG 리스케일",
  inputs: {
    model: {
      name: "모델"
    },
    multiplier: {
      name: "배율"
    }
  }
};
const SDTurboScheduler$2 = {
  display_name: "SD-Turbo 스케줄러",
  inputs: {
    denoise: {
      name: "노이즈 제거양"
    },
    model: {
      name: "모델"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const SD_4XUpscale_Conditioning$2 = {
  display_name: "SD_4X 확대 조건 설정",
  inputs: {
    images: {
      name: "이미지"
    },
    negative: {
      name: "부정 조건"
    },
    noise_augmentation: {
      name: "노이즈 증강"
    },
    positive: {
      name: "긍정 조건"
    },
    scale_ratio: {
      name: "확대율"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 이미지"
    }
  }
};
const SV3D_Conditioning$2 = {
  display_name: "SV3D 조건 설정",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "고도"
    },
    height: {
      name: "높이"
    },
    init_image: {
      name: "초기 이미지"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "비디오 프레임"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 데이터"
    }
  }
};
const SVD_img2vid_Conditioning$2 = {
  display_name: "이미지를 비디오로 조건 설정 (SVD)",
  inputs: {
    augmentation_level: {
      name: "증강 레벨"
    },
    clip_vision: {
      name: "clip_vision"
    },
    fps: {
      name: "fps"
    },
    height: {
      name: "높이"
    },
    init_image: {
      name: "초기 이미지"
    },
    motion_bucket_id: {
      name: "모션 버킷 ID"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "비디오 프레임"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 비디오"
    }
  }
};
const SamplerCustom$2 = {
  display_name: "사용자 정의 샘플러",
  inputs: {
    add_noise: {
      name: "노이즈 추가"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "생성 후 제어"
    },
    latent_image: {
      name: "잠재 데이터"
    },
    model: {
      name: "모델"
    },
    negative: {
      name: "부정 조건"
    },
    noise_seed: {
      name: "노이즈 시드"
    },
    positive: {
      name: "긍정 조건"
    },
    sampler: {
      name: "샘플러"
    },
    sigmas: {
      name: "시그마 배열"
    }
  },
  outputs: {
    "0": {
      name: "출력"
    },
    "1": {
      name: "노이즈 제거된 출력"
    }
  }
};
const SamplerCustomAdvanced$2 = {
  display_name: "고급 사용자 정의 샘플러",
  inputs: {
    guider: {
      name: "가이더"
    },
    latent_image: {
      name: "잠재 데이터"
    },
    noise: {
      name: "노이즈"
    },
    sampler: {
      name: "샘플러"
    },
    sigmas: {
      name: "시그마 배열"
    }
  },
  outputs: {
    "0": {
      name: "출력"
    },
    "1": {
      name: "노이즈 제거된 출력"
    }
  }
};
const SamplerDPMAdaptative$2 = {
  display_name: "DPMAdaptive 샘플러",
  inputs: {
    accept_safety: {
      name: "accept_safety"
    },
    atol: {
      name: "atol"
    },
    dcoeff: {
      name: "dcoeff"
    },
    eta: {
      name: "eta"
    },
    h_init: {
      name: "초기 h"
    },
    icoeff: {
      name: "icoeff"
    },
    order: {
      name: "order"
    },
    pcoeff: {
      name: "pcoeff"
    },
    rtol: {
      name: "rtol"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_2M_SDE$2 = {
  display_name: "DPMPP_2M_SDE 샘플러러",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "노이즈 생성 장치"
    },
    s_noise: {
      name: "s_noise"
    },
    solver_type: {
      name: "Solver 유형"
    }
  }
};
const SamplerDPMPP_2S_Ancestral$2 = {
  display_name: "DPMPP_2S_Ancestral 샘플러",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_3M_SDE$2 = {
  display_name: "DPMPP_3M_SDE 샘플러",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "노이즈 생성 장치"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_SDE$2 = {
  display_name: "DPMPP_SDE 샘플러",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "노이즈 생성 장치"
    },
    r: {
      name: "r"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestral$2 = {
  display_name: "Eluer Ancestral 샘플러",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestralCFGPP$2 = {
  display_name: "Eluer Acnestral CFG++ 샘플러",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerCFGpp$2 = {
  display_name: "Eluer CFG++ 샘플러",
  inputs: {
    version: {
      name: "버전"
    }
  }
};
const SamplerLCMUpscale$2 = {
  display_name: "LCM 확대 샘플러",
  inputs: {
    scale_ratio: {
      name: "확대율"
    },
    scale_steps: {
      name: "스텝수"
    },
    upscale_method: {
      name: "업스케일 방법"
    }
  }
};
const SamplerLMS$2 = {
  display_name: "LMS 샘플러",
  inputs: {
    order: {
      name: "순서"
    }
  }
};
const SaveAnimatedPNG$2 = {
  display_name: "애니메이션 PNG 저장",
  inputs: {
    compress_level: {
      name: "압축 레벨"
    },
    filename_prefix: {
      name: "파일명 접두사"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "이미지"
    }
  }
};
const SaveAnimatedWEBP$2 = {
  display_name: "애니메이션 WEBP 저장",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "이미지"
    },
    lossless: {
      name: "무손실"
    },
    method: {
      name: "방법"
    },
    quality: {
      name: "품질"
    }
  }
};
const SaveAudio$2 = {
  display_name: "오디오 저장",
  inputs: {
    audio: {
      name: "오디오"
    },
    audioUI: {
      name: "오디오UI"
    },
    filename_prefix: {
      name: "파일명 접두사"
    }
  }
};
const SaveGLB$2 = {
  display_name: "SaveGLB",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사"
    },
    image: {
      name: "이미지"
    },
    mesh: {
      name: "메시"
    }
  }
};
const SaveImage$2 = {
  description: "입력 이미지를 ComfyUI 출력 디렉토리에 저장합니다.",
  display_name: "이미지 저장",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사",
      tooltip: "저장할 파일의 접두사입니다. 여기에는 %date:yyyy-MM-dd% 또는 %Empty Latent Image.width%와 같은 형식 정보가 포함되어 노드의 값을 포함할 수 있습니다."
    },
    images: {
      name: "이미지",
      tooltip: "저장할 이미지입니다."
    }
  }
};
const SaveImageWebsocket$2 = {
  display_name: "이미지 웹소켓 전송",
  inputs: {
    images: {
      name: "이미지"
    }
  }
};
const SaveLatent$2 = {
  display_name: "잠재 데이터 저장",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const SaveWEBM$2 = {
  display_name: "동영상 저장 (WEBM)",
  inputs: {
    codec: {
      name: "코덱"
    },
    crf: {
      name: "crf",
      tooltip: "crf가 높을수록 파일 크기는 작지만 품질은 낮아집니다. crf가 낮을수록 파일 크기는 커지지만 품질은 높아집니다."
    },
    filename_prefix: {
      name: "파일명_접두사"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "이미지"
    }
  }
};
const SelfAttentionGuidance$2 = {
  display_name: "셀프 어텐션 가이드",
  inputs: {
    blur_sigma: {
      name: "블러 시그마"
    },
    model: {
      name: "모델"
    },
    scale: {
      name: "스케일"
    }
  }
};
const SetClipHooks$2 = {
  display_name: "CLIP 후크 설정",
  inputs: {
    apply_to_conds: {
      name: "조건에 적용"
    },
    clip: {
      name: "clip"
    },
    hooks: {
      name: "후크"
    },
    schedule_clip: {
      name: "clip 스케쥴 사용"
    }
  }
};
const SetFirstSigma$2 = {
  display_name: "SetFirstSigma",
  inputs: {
    sigma: {
      name: "시그마"
    },
    sigmas: {
      name: "시그마 배열"
    }
  }
};
const SetHookKeyframes$2 = {
  display_name: "후크 키프레임 설정",
  inputs: {
    hook_kf: {
      name: "KF 후크"
    },
    hooks: {
      name: "후크"
    }
  }
};
const SetLatentNoiseMask$2 = {
  display_name: "잠재 데이터에 노이즈 마스크 설정",
  inputs: {
    mask: {
      name: "마스크"
    },
    samples: {
      name: "잠재 데이터"
    }
  }
};
const SetUnionControlNetType$2 = {
  display_name: "통합 컨트롤넷 유형 설정",
  inputs: {
    control_net: {
      name: "컨트롤넷"
    },
    type: {
      name: "유형"
    }
  }
};
const SkipLayerGuidanceDiT$2 = {
  description: "모든 DiT 모델에서 사용할 수 있는 '레이어 건너뛰기 가이던스' 노드의 범용 버전입니다.",
  display_name: "레이어 건너뛰기 가이던스 (DiT)",
  inputs: {
    double_layers: {
      name: "double_layers"
    },
    end_percent: {
      name: "종료 퍼센트"
    },
    model: {
      name: "모델"
    },
    rescaling_scale: {
      name: "리스케일 크기"
    },
    scale: {
      name: "크기"
    },
    single_layers: {
      name: "single_layers"
    },
    start_percent: {
      name: "시작 퍼센트"
    }
  }
};
const SkipLayerGuidanceSD3$2 = {
  description: "SD3 용 레이어 건너뛰기 가이던스 노드입니다.",
  display_name: "레이어 건너뛰기 가이던스 (SD3)",
  inputs: {
    end_percent: {
      name: "종료 퍼센트"
    },
    layers: {
      name: "layers"
    },
    model: {
      name: "모델"
    },
    scale: {
      name: "크기"
    },
    start_percent: {
      name: "시작 퍼센트"
    }
  }
};
const SolidMask$2 = {
  display_name: "단색 마스크",
  inputs: {
    height: {
      name: "높이"
    },
    value: {
      name: "값"
    },
    width: {
      name: "너비"
    }
  }
};
const SplitImageWithAlpha$2 = {
  display_name: "이미지와 알파채널 분리",
  inputs: {
    image: {
      name: "이미지"
    }
  }
};
const SplitSigmas$2 = {
  display_name: "시그마 배열 분할 (스텝)",
  inputs: {
    sigmas: {
      name: "시그마 배열"
    },
    step: {
      name: "분할 스텝"
    }
  },
  outputs: {
    "0": {
      name: "높은 시그마 배열"
    },
    "1": {
      name: "낮은 시그마 배열"
    }
  }
};
const SplitSigmasDenoise$2 = {
  display_name: "시그마 배열 분할 (노이즈 제거양)",
  inputs: {
    denoise: {
      name: "노이즈 제거양"
    },
    sigmas: {
      name: "시그마 배열"
    }
  },
  outputs: {
    "0": {
      name: "높은 시그마 배열"
    },
    "1": {
      name: "낮은 시그마 배열"
    }
  }
};
const StableCascade_EmptyLatentImage$2 = {
  display_name: "StableCascade 빈 잠재 이미지",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    compression: {
      name: "압축"
    },
    height: {
      name: "높이"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "StageC 잠재 이미지"
    },
    "1": {
      name: "StageB 잠재 이미지"
    }
  }
};
const StableCascade_StageB_Conditioning$2 = {
  display_name: "StableCascasde_StageB 조건 설정",
  inputs: {
    conditioning: {
      name: "조건"
    },
    stage_c: {
      name: "StageC 잠재 이미지"
    }
  }
};
const StableCascade_StageC_VAEEncode$2 = {
  display_name: "StableCascade_StageC VAE 인코딩",
  inputs: {
    compression: {
      name: "압축"
    },
    image: {
      name: "이미지"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "StageC 잠재 이미지"
    },
    "1": {
      name: "StageB 잠재 이미지"
    }
  }
};
const StableCascade_SuperResolutionControlnet$2 = {
  display_name: "StableCascade 초고해상도 컨트롤넷",
  inputs: {
    image: {
      name: "이미지"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "controlnet_input"
    },
    "1": {
      name: "StageC 잠재 이미지"
    },
    "2": {
      name: "StageB 잠재 이미지"
    }
  }
};
const StableZero123_Conditioning$2 = {
  display_name: "StableZero123 조건 설정",
  inputs: {
    azimuth: {
      name: "방위각"
    },
    batch_size: {
      name: "배치 크기"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "고도"
    },
    height: {
      name: "높이"
    },
    init_image: {
      name: "초기 이미지"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 데이터"
    }
  }
};
const StableZero123_Conditioning_Batched$2 = {
  display_name: "StableZero123 조건 설정_배치",
  inputs: {
    azimuth: {
      name: "방위각"
    },
    azimuth_batch_increment: {
      name: "방위각 배치 증가"
    },
    batch_size: {
      name: "배치 크기"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "고도"
    },
    elevation_batch_increment: {
      name: "고도 배치 증가"
    },
    height: {
      name: "높이"
    },
    init_image: {
      name: "초기 이미지"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 데이터"
    }
  }
};
const StyleModelApply$2 = {
  display_name: "스타일 모델 적용",
  inputs: {
    clip_vision_output: {
      name: "clip_vision 출력"
    },
    conditioning: {
      name: "조건"
    },
    strength: {
      name: "강도"
    },
    strength_type: {
      name: "강도 유형"
    },
    style_model: {
      name: "스타일 모델"
    }
  }
};
const StyleModelLoader$2 = {
  display_name: "스타일 모델 로드",
  inputs: {
    style_model_name: {
      name: "스타일 모델 이름"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo$2 = {
  display_name: "텍스트 인코딩 (HunyuanVideo 이미지를 비디오로)",
  inputs: {
    clip: {
      name: "클립"
    },
    clip_vision_output: {
      name: "클립 비전 출력"
    },
    image_interleave: {
      name: "이미지 인터리브",
      tooltip: "이미지가 텍스트 프롬프트와 비교하여 얼마나 영향을 미치는지. 높은 숫자는 텍스트 프롬프트로부터 더 많은 영향을 받음을 의미합니다."
    },
    prompt: {
      name: "프롬프트"
    }
  }
};
const ThresholdMask$2 = {
  display_name: "임계값 마스크",
  inputs: {
    mask: {
      name: "마스크"
    },
    value: {
      name: "값"
    }
  }
};
const TomePatchModel$2 = {
  display_name: "토큰 병합(ToMe) 모델 패치",
  inputs: {
    model: {
      name: "모델"
    },
    ratio: {
      name: "비율"
    }
  }
};
const TorchCompileModel$2 = {
  display_name: "모델 토치 컴파일",
  inputs: {
    backend: {
      name: "백엔드"
    },
    model: {
      name: "모델"
    }
  }
};
const TripleCLIPLoader$2 = {
  description: "[조합법]\n\nsd3: clip-l, clip-g, t5",
  display_name: "삼중 CLIP 로드",
  inputs: {
    clip_name1: {
      name: "CLIP 파일명1"
    },
    clip_name2: {
      name: "CLIP 파일명2"
    },
    clip_name3: {
      name: "CLIP 파일명3"
    }
  }
};
const UNETLoader$2 = {
  display_name: "확산 모델 로드",
  inputs: {
    unet_name: {
      name: "UNet 모델 파일명"
    },
    weight_dtype: {
      name: "가중치 데이터 유형"
    }
  }
};
const UNetCrossAttentionMultiply$2 = {
  display_name: "UNet 교차 어텐션 곱하기",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "모델"
    },
    out: {
      name: "out"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetSelfAttentionMultiply$2 = {
  display_name: "UNet 셀프 어텐션 곱하기",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "모델"
    },
    out: {
      name: "out"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetTemporalAttentionMultiply$2 = {
  display_name: "UNet 템포럴 어텐션 곱하기",
  inputs: {
    cross_structural: {
      name: "구조적 크로스"
    },
    cross_temporal: {
      name: "시간적 크로스"
    },
    model: {
      name: "모델"
    },
    self_structural: {
      name: "구조적 셀프"
    },
    self_temporal: {
      name: "시간적 셀프"
    }
  }
};
const UpscaleModelLoader$2 = {
  display_name: "업스케일 모델 로드",
  inputs: {
    model_name: {
      name: "모델 파일명"
    }
  }
};
const VAEDecode$2 = {
  description: "잠재 데이터를 픽셀 공간 이미지로 디코딩합니다.",
  display_name: "VAE 디코드",
  inputs: {
    samples: {
      name: "잠재 데이터",
      tooltip: "디코딩할 잠재입니다."
    },
    vae: {
      name: "vae",
      tooltip: "잠재 디코딩에 사용되는 VAE 모델입니다."
    }
  },
  outputs: {
    "0": {
      tooltip: "디코딩된 이미지입니다."
    }
  }
};
const VAEDecodeAudio$2 = {
  display_name: "오디오 VAE 디코드",
  inputs: {
    samples: {
      name: "잠재 오디오"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D$2 = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    num_chunks: {
      name: "num_chunks"
    },
    octree_resolution: {
      name: "옥트리 해상도"
    },
    samples: {
      name: "샘플"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeTiled$2 = {
  display_name: "VAE 디코드 (타일)",
  inputs: {
    overlap: {
      name: "겹침"
    },
    samples: {
      name: "잠재 데이터"
    },
    temporal_overlap: {
      name: "시간 겹침",
      tooltip: "비디오 VAE에만 사용됩니다: 겹치는 프레임의 양."
    },
    temporal_size: {
      name: "시간 크기",
      tooltip: "비디오 VAE에만 사용됩니다: 한 번에 디코딩할 프레임의 양."
    },
    tile_size: {
      name: "타일 크기"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncode$2 = {
  display_name: "VAE 인코드",
  inputs: {
    pixels: {
      name: "픽셀 이미지"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio$2 = {
  display_name: "오디오 VAE 인코드",
  inputs: {
    audio: {
      name: "오디오"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint$2 = {
  display_name: "VAE 인코드 (인페인팅용)",
  inputs: {
    grow_mask_by: {
      name: "마스크 확장"
    },
    mask: {
      name: "마스크"
    },
    pixels: {
      name: "픽셀"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeTiled$2 = {
  display_name: "VAE 인코드 (타일)",
  inputs: {
    overlap: {
      name: "겹침"
    },
    pixels: {
      name: "픽셀"
    },
    temporal_overlap: {
      name: "시간적 겹침",
      tooltip: "비디오 VAE에만 사용됩니다: 겹치는 프레임의 양."
    },
    temporal_size: {
      name: "시간적 크기",
      tooltip: "비디오 VAE에만 사용됩니다: 한 번에 인코딩할 프레임의 양."
    },
    tile_size: {
      name: "타일 크기"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAELoader$2 = {
  display_name: "VAE 로드",
  inputs: {
    vae_name: {
      name: "vae 파일명"
    }
  }
};
const VAESave$2 = {
  display_name: "VAE 저장",
  inputs: {
    filename_prefix: {
      name: "파일명 접두사"
    },
    vae: {
      name: "vae"
    }
  }
};
const VPScheduler$2 = {
  display_name: "VP 스케줄러",
  inputs: {
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    },
    steps: {
      name: "스텝수"
    }
  }
};
const VideoLinearCFGGuidance$2 = {
  display_name: "비디오 선형 CFG 가이드",
  inputs: {
    min_cfg: {
      name: "최소 cfg"
    },
    model: {
      name: "모델"
    }
  }
};
const VideoTriangleCFGGuidance$2 = {
  display_name: "비디오 삼각형 CFG 가이드",
  inputs: {
    min_cfg: {
      name: "최소 cfg"
    },
    model: {
      name: "모델"
    }
  }
};
const VoxelToMeshBasic$2 = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    threshold: {
      name: "임계값"
    },
    voxel: {
      name: "복셀"
    }
  }
};
const WanImageToVideo$2 = {
  display_name: "Wan 이미지를 비디오로",
  inputs: {
    batch_size: {
      name: "배치 크기"
    },
    clip_vision_output: {
      name: "클립 비전 출력"
    },
    height: {
      name: "높이"
    },
    length: {
      name: "길이"
    },
    negative: {
      name: "부정 조건"
    },
    positive: {
      name: "긍정 조건"
    },
    start_image: {
      name: "시작 이미지"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "너비"
    }
  },
  outputs: {
    "0": {
      name: "긍정 조건"
    },
    "1": {
      name: "부정 조건"
    },
    "2": {
      name: "잠재 비디오"
    }
  }
};
const WebcamCapture$2 = {
  display_name: "웹캠 캡처",
  inputs: {
    capture_on_queue: {
      name: "큐에서 캡처"
    },
    height: {
      name: "높이"
    },
    image: {
      name: "이미지"
    },
    "waiting for camera___": {},
    width: {
      name: "너비"
    }
  }
};
const unCLIPCheckpointLoader$2 = {
  display_name: "unCLIP 체크포인트 로드",
  inputs: {
    ckpt_name: {
      name: "체크포인트 파일명"
    }
  }
};
const unCLIPConditioning$2 = {
  display_name: "unCLIP 조건 설정",
  inputs: {
    clip_vision_output: {
      name: "clip_vision 출력"
    },
    conditioning: {
      name: "조건"
    },
    noise_augmentation: {
      name: "노이즈 증강"
    },
    strength: {
      name: "강도"
    }
  }
};
const koNodes = {
  AddNoise: AddNoise$2,
  AlignYourStepsScheduler: AlignYourStepsScheduler$2,
  BasicGuider: BasicGuider$2,
  BasicScheduler: BasicScheduler$2,
  BetaSamplingScheduler: BetaSamplingScheduler$2,
  CFGGuider: CFGGuider$2,
  CLIPAttentionMultiply: CLIPAttentionMultiply$2,
  CLIPLoader: CLIPLoader$2,
  CLIPMergeAdd: CLIPMergeAdd$2,
  CLIPMergeSimple: CLIPMergeSimple$2,
  CLIPMergeSubtract: CLIPMergeSubtract$2,
  CLIPSave: CLIPSave$2,
  CLIPSetLastLayer: CLIPSetLastLayer$2,
  CLIPTextEncode: CLIPTextEncode$2,
  CLIPTextEncodeControlnet: CLIPTextEncodeControlnet$2,
  CLIPTextEncodeFlux: CLIPTextEncodeFlux$2,
  CLIPTextEncodeHunyuanDiT: CLIPTextEncodeHunyuanDiT$2,
  CLIPTextEncodeLumina2: CLIPTextEncodeLumina2$2,
  CLIPTextEncodePixArtAlpha: CLIPTextEncodePixArtAlpha$2,
  CLIPTextEncodeSD3: CLIPTextEncodeSD3$2,
  CLIPTextEncodeSDXL: CLIPTextEncodeSDXL$2,
  CLIPTextEncodeSDXLRefiner: CLIPTextEncodeSDXLRefiner$2,
  CLIPVisionEncode: CLIPVisionEncode$2,
  CLIPVisionLoader: CLIPVisionLoader$2,
  Canny: Canny$2,
  CheckpointLoader: CheckpointLoader$2,
  CheckpointLoaderSimple: CheckpointLoaderSimple$2,
  CheckpointSave: CheckpointSave$2,
  CombineHooks2: CombineHooks2$2,
  CombineHooks4: CombineHooks4$2,
  CombineHooks8: CombineHooks8$2,
  ConditioningAverage: ConditioningAverage$2,
  ConditioningCombine: ConditioningCombine$2,
  ConditioningConcat: ConditioningConcat$2,
  ConditioningSetArea: ConditioningSetArea$2,
  ConditioningSetAreaPercentage: ConditioningSetAreaPercentage$2,
  ConditioningSetAreaPercentageVideo: ConditioningSetAreaPercentageVideo$2,
  ConditioningSetAreaStrength: ConditioningSetAreaStrength$2,
  ConditioningSetDefaultCombine: ConditioningSetDefaultCombine$2,
  ConditioningSetMask: ConditioningSetMask$2,
  ConditioningSetProperties: ConditioningSetProperties$2,
  ConditioningSetPropertiesAndCombine: ConditioningSetPropertiesAndCombine$2,
  ConditioningSetTimestepRange: ConditioningSetTimestepRange$2,
  ConditioningStableAudio: ConditioningStableAudio$2,
  ConditioningTimestepsRange: ConditioningTimestepsRange$2,
  ConditioningZeroOut: ConditioningZeroOut$2,
  ControlNetApply: ControlNetApply$2,
  ControlNetApplyAdvanced: ControlNetApplyAdvanced$2,
  ControlNetApplySD3: ControlNetApplySD3$2,
  ControlNetInpaintingAliMamaApply: ControlNetInpaintingAliMamaApply$2,
  ControlNetLoader: ControlNetLoader$2,
  CosmosImageToVideoLatent: CosmosImageToVideoLatent$2,
  CreateHookKeyframe: CreateHookKeyframe$2,
  CreateHookKeyframesFromFloats: CreateHookKeyframesFromFloats$2,
  CreateHookKeyframesInterpolated: CreateHookKeyframesInterpolated$2,
  CreateHookLora: CreateHookLora$2,
  CreateHookLoraModelOnly: CreateHookLoraModelOnly$2,
  CreateHookModelAsLora: CreateHookModelAsLora$2,
  CreateHookModelAsLoraModelOnly: CreateHookModelAsLoraModelOnly$2,
  CropMask: CropMask$2,
  DiffControlNetLoader: DiffControlNetLoader$2,
  DifferentialDiffusion: DifferentialDiffusion$2,
  DiffusersLoader: DiffusersLoader$2,
  DisableNoise: DisableNoise$2,
  DualCFGGuider: DualCFGGuider$2,
  DualCLIPLoader: DualCLIPLoader$2,
  EmptyCosmosLatentVideo: EmptyCosmosLatentVideo$2,
  EmptyHunyuanLatentVideo: EmptyHunyuanLatentVideo$2,
  EmptyImage: EmptyImage$2,
  EmptyLTXVLatentVideo: EmptyLTXVLatentVideo$2,
  EmptyLatentAudio: EmptyLatentAudio$2,
  EmptyLatentHunyuan3Dv2: EmptyLatentHunyuan3Dv2$2,
  EmptyLatentImage: EmptyLatentImage$2,
  EmptyMochiLatentVideo: EmptyMochiLatentVideo$2,
  EmptySD3LatentImage: EmptySD3LatentImage$2,
  ExponentialScheduler: ExponentialScheduler$2,
  FeatherMask: FeatherMask$2,
  FlipSigmas: FlipSigmas$2,
  FluxDisableGuidance: FluxDisableGuidance$2,
  FluxGuidance: FluxGuidance$2,
  FreeU: FreeU$2,
  FreeU_V2: FreeU_V2$2,
  GITSScheduler: GITSScheduler$2,
  GLIGENLoader: GLIGENLoader$2,
  GLIGENTextBoxApply: GLIGENTextBoxApply$2,
  GrowMask: GrowMask$2,
  Hunyuan3Dv2Conditioning: Hunyuan3Dv2Conditioning$2,
  Hunyuan3Dv2ConditioningMultiView: Hunyuan3Dv2ConditioningMultiView$2,
  HunyuanImageToVideo: HunyuanImageToVideo$2,
  HyperTile: HyperTile$2,
  HypernetworkLoader: HypernetworkLoader$2,
  ImageBatch: ImageBatch$2,
  ImageBlend: ImageBlend$2,
  ImageBlur: ImageBlur$2,
  ImageColorToMask: ImageColorToMask$2,
  ImageCompositeMasked: ImageCompositeMasked$2,
  ImageCrop: ImageCrop$2,
  ImageFromBatch: ImageFromBatch$2,
  ImageInvert: ImageInvert$2,
  ImageOnlyCheckpointLoader: ImageOnlyCheckpointLoader$2,
  ImageOnlyCheckpointSave: ImageOnlyCheckpointSave$2,
  ImagePadForOutpaint: ImagePadForOutpaint$2,
  ImageQuantize: ImageQuantize$2,
  ImageScale: ImageScale$2,
  ImageScaleBy: ImageScaleBy$2,
  ImageScaleToTotalPixels: ImageScaleToTotalPixels$2,
  ImageSharpen: ImageSharpen$2,
  ImageToMask: ImageToMask$2,
  ImageUpscaleWithModel: ImageUpscaleWithModel$2,
  InpaintModelConditioning: InpaintModelConditioning$2,
  InstructPixToPixConditioning: InstructPixToPixConditioning$2,
  InvertMask: InvertMask$2,
  JoinImageWithAlpha: JoinImageWithAlpha$2,
  KSampler: KSampler$2,
  KSamplerAdvanced: KSamplerAdvanced$2,
  KSamplerSelect: KSamplerSelect$2,
  KarrasScheduler: KarrasScheduler$2,
  LTXVAddGuide: LTXVAddGuide$2,
  LTXVConditioning: LTXVConditioning$2,
  LTXVCropGuides: LTXVCropGuides$2,
  LTXVImgToVideo: LTXVImgToVideo$2,
  LTXVPreprocess: LTXVPreprocess$2,
  LTXVScheduler: LTXVScheduler$2,
  LaplaceScheduler: LaplaceScheduler$2,
  LatentAdd: LatentAdd$2,
  LatentApplyOperation: LatentApplyOperation$2,
  LatentApplyOperationCFG: LatentApplyOperationCFG$2,
  LatentBatch: LatentBatch$2,
  LatentBatchSeedBehavior: LatentBatchSeedBehavior$2,
  LatentBlend: LatentBlend$2,
  LatentComposite: LatentComposite$2,
  LatentCompositeMasked: LatentCompositeMasked$2,
  LatentCrop: LatentCrop$2,
  LatentFlip: LatentFlip$2,
  LatentFromBatch: LatentFromBatch$2,
  LatentInterpolate: LatentInterpolate$2,
  LatentMultiply: LatentMultiply$2,
  LatentOperationSharpen: LatentOperationSharpen$2,
  LatentOperationTonemapReinhard: LatentOperationTonemapReinhard$2,
  LatentRotate: LatentRotate$2,
  LatentSubtract: LatentSubtract$2,
  LatentUpscale: LatentUpscale$2,
  LatentUpscaleBy: LatentUpscaleBy$2,
  Load3D: Load3D$2,
  Load3DAnimation: Load3DAnimation$2,
  LoadAudio: LoadAudio$2,
  LoadImage: LoadImage$2,
  LoadImageMask: LoadImageMask$2,
  LoadImageOutput: LoadImageOutput$2,
  LoadLatent: LoadLatent$2,
  LoraLoader: LoraLoader$2,
  LoraLoaderModelOnly: LoraLoaderModelOnly$2,
  LoraSave: LoraSave$2,
  Mahiro: Mahiro$2,
  MaskComposite: MaskComposite$2,
  MaskToImage: MaskToImage$2,
  ModelComputeDtype: ModelComputeDtype$2,
  ModelMergeAdd: ModelMergeAdd$2,
  ModelMergeAuraflow: ModelMergeAuraflow$2,
  ModelMergeBlocks: ModelMergeBlocks$2,
  ModelMergeCosmos14B: ModelMergeCosmos14B$2,
  ModelMergeCosmos7B: ModelMergeCosmos7B$2,
  ModelMergeFlux1: ModelMergeFlux1$2,
  ModelMergeLTXV: ModelMergeLTXV$2,
  ModelMergeMochiPreview: ModelMergeMochiPreview$2,
  ModelMergeSD1: ModelMergeSD1$2,
  ModelMergeSD2: ModelMergeSD2$2,
  ModelMergeSD35_Large: ModelMergeSD35_Large$2,
  ModelMergeSD3_2B: ModelMergeSD3_2B$2,
  ModelMergeSDXL: ModelMergeSDXL$2,
  ModelMergeSimple: ModelMergeSimple$2,
  ModelMergeSubtract: ModelMergeSubtract$2,
  ModelSamplingAuraFlow: ModelSamplingAuraFlow$2,
  ModelSamplingContinuousEDM: ModelSamplingContinuousEDM$2,
  ModelSamplingContinuousV: ModelSamplingContinuousV$2,
  ModelSamplingDiscrete: ModelSamplingDiscrete$2,
  ModelSamplingFlux: ModelSamplingFlux$2,
  ModelSamplingLTXV: ModelSamplingLTXV$2,
  ModelSamplingSD3: ModelSamplingSD3$2,
  ModelSamplingStableCascade: ModelSamplingStableCascade$2,
  ModelSave: ModelSave$2,
  Morphology: Morphology$2,
  PairConditioningCombine: PairConditioningCombine$2,
  PairConditioningSetDefaultCombine: PairConditioningSetDefaultCombine$2,
  PairConditioningSetProperties: PairConditioningSetProperties$2,
  PairConditioningSetPropertiesAndCombine: PairConditioningSetPropertiesAndCombine$2,
  PatchModelAddDownscale: PatchModelAddDownscale$2,
  PerpNeg: PerpNeg$2,
  PerpNegGuider: PerpNegGuider$2,
  PerturbedAttentionGuidance: PerturbedAttentionGuidance$2,
  PhotoMakerEncode: PhotoMakerEncode$2,
  PhotoMakerLoader: PhotoMakerLoader$2,
  PolyexponentialScheduler: PolyexponentialScheduler$2,
  PorterDuffImageComposite: PorterDuffImageComposite$2,
  Preview3D: Preview3D$2,
  Preview3DAnimation: Preview3DAnimation$2,
  PreviewAudio: PreviewAudio$2,
  PreviewImage: PreviewImage$2,
  RandomNoise: RandomNoise$2,
  RebatchImages: RebatchImages$2,
  RebatchLatents: RebatchLatents$2,
  RenormCFG: RenormCFG$2,
  RepeatImageBatch: RepeatImageBatch$2,
  RepeatLatentBatch: RepeatLatentBatch$2,
  RescaleCFG: RescaleCFG$2,
  SDTurboScheduler: SDTurboScheduler$2,
  SD_4XUpscale_Conditioning: SD_4XUpscale_Conditioning$2,
  SV3D_Conditioning: SV3D_Conditioning$2,
  SVD_img2vid_Conditioning: SVD_img2vid_Conditioning$2,
  SamplerCustom: SamplerCustom$2,
  SamplerCustomAdvanced: SamplerCustomAdvanced$2,
  SamplerDPMAdaptative: SamplerDPMAdaptative$2,
  SamplerDPMPP_2M_SDE: SamplerDPMPP_2M_SDE$2,
  SamplerDPMPP_2S_Ancestral: SamplerDPMPP_2S_Ancestral$2,
  SamplerDPMPP_3M_SDE: SamplerDPMPP_3M_SDE$2,
  SamplerDPMPP_SDE: SamplerDPMPP_SDE$2,
  SamplerEulerAncestral: SamplerEulerAncestral$2,
  SamplerEulerAncestralCFGPP: SamplerEulerAncestralCFGPP$2,
  SamplerEulerCFGpp: SamplerEulerCFGpp$2,
  SamplerLCMUpscale: SamplerLCMUpscale$2,
  SamplerLMS: SamplerLMS$2,
  SaveAnimatedPNG: SaveAnimatedPNG$2,
  SaveAnimatedWEBP: SaveAnimatedWEBP$2,
  SaveAudio: SaveAudio$2,
  SaveGLB: SaveGLB$2,
  SaveImage: SaveImage$2,
  SaveImageWebsocket: SaveImageWebsocket$2,
  SaveLatent: SaveLatent$2,
  SaveWEBM: SaveWEBM$2,
  SelfAttentionGuidance: SelfAttentionGuidance$2,
  SetClipHooks: SetClipHooks$2,
  SetFirstSigma: SetFirstSigma$2,
  SetHookKeyframes: SetHookKeyframes$2,
  SetLatentNoiseMask: SetLatentNoiseMask$2,
  SetUnionControlNetType: SetUnionControlNetType$2,
  SkipLayerGuidanceDiT: SkipLayerGuidanceDiT$2,
  SkipLayerGuidanceSD3: SkipLayerGuidanceSD3$2,
  SolidMask: SolidMask$2,
  SplitImageWithAlpha: SplitImageWithAlpha$2,
  SplitSigmas: SplitSigmas$2,
  SplitSigmasDenoise: SplitSigmasDenoise$2,
  StableCascade_EmptyLatentImage: StableCascade_EmptyLatentImage$2,
  StableCascade_StageB_Conditioning: StableCascade_StageB_Conditioning$2,
  StableCascade_StageC_VAEEncode: StableCascade_StageC_VAEEncode$2,
  StableCascade_SuperResolutionControlnet: StableCascade_SuperResolutionControlnet$2,
  StableZero123_Conditioning: StableZero123_Conditioning$2,
  StableZero123_Conditioning_Batched: StableZero123_Conditioning_Batched$2,
  StyleModelApply: StyleModelApply$2,
  StyleModelLoader: StyleModelLoader$2,
  TextEncodeHunyuanVideo_ImageToVideo: TextEncodeHunyuanVideo_ImageToVideo$2,
  ThresholdMask: ThresholdMask$2,
  TomePatchModel: TomePatchModel$2,
  TorchCompileModel: TorchCompileModel$2,
  TripleCLIPLoader: TripleCLIPLoader$2,
  UNETLoader: UNETLoader$2,
  UNetCrossAttentionMultiply: UNetCrossAttentionMultiply$2,
  UNetSelfAttentionMultiply: UNetSelfAttentionMultiply$2,
  UNetTemporalAttentionMultiply: UNetTemporalAttentionMultiply$2,
  UpscaleModelLoader: UpscaleModelLoader$2,
  VAEDecode: VAEDecode$2,
  VAEDecodeAudio: VAEDecodeAudio$2,
  VAEDecodeHunyuan3D: VAEDecodeHunyuan3D$2,
  VAEDecodeTiled: VAEDecodeTiled$2,
  VAEEncode: VAEEncode$2,
  VAEEncodeAudio: VAEEncodeAudio$2,
  VAEEncodeForInpaint: VAEEncodeForInpaint$2,
  VAEEncodeTiled: VAEEncodeTiled$2,
  VAELoader: VAELoader$2,
  VAESave: VAESave$2,
  VPScheduler: VPScheduler$2,
  VideoLinearCFGGuidance: VideoLinearCFGGuidance$2,
  VideoTriangleCFGGuidance: VideoTriangleCFGGuidance$2,
  VoxelToMeshBasic: VoxelToMeshBasic$2,
  WanImageToVideo: WanImageToVideo$2,
  WebcamCapture: WebcamCapture$2,
  unCLIPCheckpointLoader: unCLIPCheckpointLoader$2,
  unCLIPConditioning: unCLIPConditioning$2
};
const Comfy_Canvas_SelectionToolbox$2 = {
  name: "선택 도구 상자 표시"
};
const Comfy_ConfirmClear$2 = {
  name: "워크플로 비우기 시 확인 요구"
};
const Comfy_DOMClippingEnabled$2 = {
  name: "DOM 요소 클리핑 활성화 (활성화 시 성능 저하 가능)"
};
const Comfy_DevMode$2 = {
  name: "개발자 모드 옵션 활성화 (API 저장 등)"
};
const Comfy_DisableFloatRounding$2 = {
  name: "기본 부동 소수점 위젯 반올림 비활성화",
  tooltip: "(페이지 새로 고침 필요) 백엔드에서 노드에 의해 설정된 반올림이 있을 때 반올림을 비활성화할 수 없습니다."
};
const Comfy_DisableSliders$2 = {
  name: "노드 위젯 슬라이더 비활성화"
};
const Comfy_EditAttention_Delta$2 = {
  name: "Ctrl+위/아래 정밀도"
};
const Comfy_EnableTooltips$2 = {
  name: "툴팁 활성화"
};
const Comfy_EnableWorkflowViewRestore$2 = {
  name: "워크플로에서 캔버스 위치 및 확대/축소 수준 저장 및 복원"
};
const Comfy_FloatRoundingPrecision$2 = {
  name: "부동 소수점 위젯 반올림 소수 자리 수 [0 = 자동]",
  tooltip: "(페이지 새로 고침 필요)"
};
const Comfy_Graph_CanvasInfo$2 = {
  name: "왼쪽 하단 모서리에 캔버스 정보 표시 (fps 등)"
};
const Comfy_Graph_CanvasMenu$2 = {
  name: "그래프 캔버스 메뉴 표시"
};
const Comfy_Graph_CtrlShiftZoom$2 = {
  name: "빠른 확대/축소 단축키 활성화 (Ctrl + Shift + 드래그)"
};
const Comfy_Graph_LinkMarkers$2 = {
  name: "링크 중간점 마커",
  options: {
    Arrow: "화살표",
    Circle: "원",
    None: "없음"
  }
};
const Comfy_Graph_ZoomSpeed$2 = {
  name: "캔버스 확대/축소 속도"
};
const Comfy_GroupSelectedNodes_Padding$2 = {
  name: "선택된 노드 패딩"
};
const Comfy_Group_DoubleClickTitleToEdit$2 = {
  name: "그룹 제목을 두 번 클릭하여 편집"
};
const Comfy_LinkRelease_Action$2 = {
  name: "링크 해제 시 동작 (수정자 없음)",
  options: {
    "context menu": "컨텍스트 메뉴",
    "no action": "작업 없음",
    "search box": "검색 상자"
  }
};
const Comfy_LinkRelease_ActionShift$2 = {
  name: "링크 해제 시 동작 (Shift)",
  options: {
    "context menu": "컨텍스트 메뉴",
    "no action": "작업 없음",
    "search box": "검색 상자"
  }
};
const Comfy_LinkRenderMode$2 = {
  name: "링크 렌더 모드",
  options: {
    Hidden: "숨김",
    Linear: "선형",
    Spline: "스플라인",
    Straight: "직선"
  }
};
const Comfy_Locale$2 = {
  name: "언어"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed$2 = {
  name: "브러시 조정 속도 배수",
  tooltip: "조정할 때 브러시 크기와 경도가 얼마나 빨리 변하는지를 제어합니다. 값이 높을수록 변화가 더 빠릅니다."
};
const Comfy_MaskEditor_UseDominantAxis$2 = {
  name: "브러시 조정을 지배 축에 고정",
  tooltip: "활성화하면 브러시 조정이 이동하는 방향에 따라 크기 또는 경도에만 영향을 미칩니다."
};
const Comfy_MaskEditor_UseNewEditor$2 = {
  name: "새 마스크 편집기 사용",
  tooltip: "새 마스크 편집기 인터페이스로 전환"
};
const Comfy_ModelLibrary_AutoLoadAll$2 = {
  name: "모든 모델 폴더 자동 로드",
  tooltip: "참이면 모든 폴더가 모델 라이브러리를 열 때 즉시 로드됩니다 (로드하는 동안 지연이 발생할 수 있습니다). 거짓이면 루트 수준 모델 폴더는 클릭할 때만 로드됩니다."
};
const Comfy_ModelLibrary_NameFormat$2 = {
  name: "모델 라이브러리 트리 뷰에 표시할 이름",
  options: {
    filename: "파일 이름",
    title: "제목"
  },
  tooltip: '"파일 이름"을 선택하면 모델 목록에서 원시 파일 이름(디렉토리 또는 ".safetensors" 확장자 없이)의 단순화된 뷰가 렌더링됩니다. "제목"을 선택하면 구성 가능한 모델 메타데이터 제목이 표시됩니다.'
};
const Comfy_NodeBadge_NodeIdBadgeMode$2 = {
  name: "노드 ID 배지 모드",
  options: {
    None: "없음",
    "Show all": "모두 표시"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode$2 = {
  name: "노드 생명 주기 배지 모드",
  options: {
    None: "없음",
    "Show all": "모두 표시"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode$2 = {
  name: "노드 출처 배지 모드",
  options: {
    "Hide built-in": "내장 숨기기",
    None: "없음",
    "Show all": "모두 표시"
  }
};
const Comfy_NodeInputConversionSubmenus$2 = {
  name: "노드 컨텍스트 메뉴에서 입력/위젯 간 변환 항목을 하위 메뉴에 배치합니다."
};
const Comfy_NodeSearchBoxImpl$2 = {
  name: "노드 검색 상자 구현",
  options: {
    "default": "기본",
    "litegraph (legacy)": "litegraph (구버전)"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview$2 = {
  name: "노드 미리보기",
  tooltip: "기본 구현에만 적용됩니다."
};
const Comfy_NodeSearchBoxImpl_ShowCategory$2 = {
  name: "검색 결과에 노드 카테고리 표시",
  tooltip: "기본 구현에만 적용됩니다."
};
const Comfy_NodeSearchBoxImpl_ShowIdName$2 = {
  name: "검색 결과에 노드 ID 이름 표시",
  tooltip: "기본 구현에만 적용됩니다."
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency$2 = {
  name: "검색 결과에 노드 빈도 표시",
  tooltip: "기본 구현에만 적용됩니다."
};
const Comfy_NodeSuggestions_number$2 = {
  name: "노드 제안 수",
  tooltip: "라이트그래프 검색 상자/컨텍스트 메뉴 전용"
};
const Comfy_Node_AutoSnapLinkToSlot$2 = {
  name: "링크를 노드 슬롯에 자동 스냅",
  tooltip: "링크를 노드 위로 드래그할 때 링크가 노드의 유효한 입력 슬롯에 자동으로 스냅됩니다."
};
const Comfy_Node_BypassAllLinksOnDelete$2 = {
  name: "노드 삭제 시 모든 링크 유지",
  tooltip: "노드를 삭제할 때 모든 입력 및 출력 링크를 재연결하려고 시도합니다 (삭제된 노드를 우회)."
};
const Comfy_Node_DoubleClickTitleToEdit$2 = {
  name: "노드 제목을 두 번 클릭하여 편집"
};
const Comfy_Node_MiddleClickRerouteNode$2 = {
  name: "중간 클릭으로 새 경로재설정 노드 생성"
};
const Comfy_Node_Opacity$2 = {
  name: "노드 불투명도"
};
const Comfy_Node_ShowDeprecated$2 = {
  name: "검색에서 지원 중단된 노드 표시",
  tooltip: "지원 중단된 노드는 기본적으로 UI에서 숨겨지지만, 이를 사용하는 기존 워크플로에서는 여전히 기능합니다."
};
const Comfy_Node_ShowExperimental$2 = {
  name: "검색에서 실험적 노드 표시",
  tooltip: "실험적 노드는 UI에서 그렇게 표시되며, 향후 버전에서 상당한 변경이나 제거의 대상이 될 수 있습니다. 프로덕션 워크플로에서 주의하여 사용하십시오."
};
const Comfy_Node_SnapHighlightsNode$2 = {
  name: "스냅 하이라이트 노드",
  tooltip: "링크를 유효한 입력 슬롯이 있는 노드 위로 드래그할 때 노드를 강조 표시합니다."
};
const Comfy_Pointer_ClickBufferTime$2 = {
  name: "포인터 클릭 드리프트 지연",
  tooltip: "포인터 버튼을 누른 후, 포인터 움직임을 무시할 수 있는 최대 시간(밀리초)입니다.\n\n클릭하는 동안 포인터가 움직여 의도치 않게 객체가 밀리는 것을 방지합니다."
};
const Comfy_Pointer_ClickDrift$2 = {
  name: "포인터 클릭 드리프트 (최대 거리)",
  tooltip: "버튼을 누른 상태에서 포인터가 이 거리보다 더 많이 움직이면, 클릭이 아닌 드래그로 간주됩니다.\n\n클릭하는 동안 포인터가 움직여 의도치 않게 객체가 밀리는 것을 방지합니다."
};
const Comfy_Pointer_DoubleClickTime$2 = {
  name: "더블 클릭 간격 (최대)",
  tooltip: "더블 클릭의 두 클릭 사이의 최대 시간(밀리초)입니다. 이 값을 늘리면 가끔 더블 클릭이 인식되지 않는 문제를 해결할 수 있습니다."
};
const Comfy_PreviewFormat$2 = {
  name: "미리보기 이미지 형식",
  tooltip: "이미지 위젯에서 미리보기를 표시할 때 경량 이미지로 변환합니다. '이미지 포맷;품질' 예: webp, jpeg, webp;50 등."
};
const Comfy_PromptFilename$2 = {
  name: "워크플로 저장 시 파일 이름 프롬프트"
};
const Comfy_QueueButton_BatchCountLimit$2 = {
  name: "배치 수 제한",
  tooltip: "한 번의 버튼 클릭으로 실행 큐에 추가되는 최대 작업 수입니다."
};
const Comfy_Queue_MaxHistoryItems$2 = {
  name: "실행 큐 기록 갯수",
  tooltip: "실행 큐 기록에 표시되는 최대 작업 수입니다."
};
const Comfy_RerouteBeta$2 = {
  name: "경로재설정 베타 테스트 참여",
  tooltip: "새로운 기본 경로재설정을 활성화합니다.\n\n링크 라인에서 Alt를 누른 채 드래그하거나 링크 메뉴에서 경로재설정을 추가할 수 있습니다.\n\n이 옵션을 비활성화해도 경로재설정은 삭제되지 않고 숨겨집니다."
};
const Comfy_Sidebar_Location$2 = {
  name: "사이드바 위치",
  options: {
    left: "왼쪽",
    right: "오른쪽"
  }
};
const Comfy_Sidebar_Size$2 = {
  name: "사이드바 크기",
  options: {
    normal: "보통",
    small: "작음"
  }
};
const Comfy_SnapToGrid_GridSize$2 = {
  name: "그리드 크기에 스냅",
  tooltip: "Shift 키를 누른 상태에서 노드를 드래그하거나 크기를 조절하면 그리드에 맞춰 정렬됩니다. 이 설정은 그리드의 크기를 제어합니다."
};
const Comfy_TextareaWidget_FontSize$2 = {
  name: "텍스트 영역 위젯 글꼴 크기"
};
const Comfy_TextareaWidget_Spellcheck$2 = {
  name: "텍스트 영역 위젯 맞춤법 검사"
};
const Comfy_TreeExplorer_ItemPadding$2 = {
  name: "트리 탐색기 항목 패딩"
};
const Comfy_UseNewMenu$2 = {
  name: "새 메뉴 사용",
  options: {
    Bottom: "하단",
    Disabled: "비활성화",
    Top: "상단"
  }
};
const Comfy_Validation_NodeDefs$2 = {
  name: "노드 정의 유효성 검사 (느림)",
  tooltip: "노드 개발자에게 권장됩니다. 시작 시 모든 노드 정의를 유효성 검사합니다."
};
const Comfy_Validation_Workflows$2 = {
  name: "워크플로 유효성 검사"
};
const Comfy_WidgetControlMode$2 = {
  name: "위젯 제어 모드",
  options: {
    after: "다음",
    before: "이전"
  },
  tooltip: "위젯 값이 업데이트되는 시점을 제어합니다 (무작위화/증가/감소), 프롬프트가 큐에 추가되기 전 또는 후입니다."
};
const Comfy_Window_UnloadConfirmation$2 = {
  name: "창 닫을 때 확인 표시"
};
const Comfy_Workflow_ConfirmDelete$2 = {
  name: "워크플로 삭제 시 확인 표시"
};
const Comfy_Workflow_ShowMissingModelsWarning$2 = {
  name: "누락된 모델 경고 표시"
};
const Comfy_Workflow_ShowMissingNodesWarning$2 = {
  name: "누락된 노드 경고 표시"
};
const Comfy_Workflow_SortNodeIdOnSave$2 = {
  name: "워크플로 저장 시 노드 ID 정렬"
};
const Comfy_Workflow_WorkflowTabsPosition$2 = {
  name: "열린 워크플로 위치",
  options: {
    Sidebar: "사이드바",
    Topbar: "상단바",
    "Topbar (2nd-row)": "상단바 (2번째 행)"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold$2 = {
  name: "저품질 렌더링 줌 임계값",
  tooltip: "줌 아웃시 저품질 도형 렌더링"
};
const LiteGraph_Canvas_MaximumFps$2 = {
  name: "최대 FPS",
  tooltip: "캔버스가 렌더링할 수 있는 최대 프레임 수입니다. 부드럽게 동작하도록 GPU 사용률을 제한 합니다. 0이면 화면 주사율로 작동 합니다. 기본값: 0"
};
const LiteGraph_ContextMenu_Scaling$2 = {
  name: "확대시 노드 콤보 위젯 메뉴 (목록) 스케일링"
};
const LiteGraph_Node_TooltipDelay$2 = {
  name: "툴팁 지연"
};
const pysssss_SnapToGrid$2 = {
  name: "항상 그리드에 스냅"
};
const koSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "자동 업데이트 확인"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "익명 사용 통계 보내기"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "PyPI 설치 미러",
    tooltip: "기본 pip 설치 미러"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Python 설치 미러",
    tooltip: "관리되는 Python 설치파일은 Astral python-build-standalone 프로젝트에서 다운로드됩니다. 이 변수는 Python 설치파일의 다른 출처를 사용하기 위해 미러 URL로 설정할 수 있습니다. 예를 들어, 제공된 URL은 https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gz에서 https://github.com/astral-sh/python-build-standalone/releases/download 를 대체합니다. 배포판은 file:// URL 스키마를 사용하여 로컬 디렉토리에서 읽을 수 있습니다."
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "torch 설치 미러",
    tooltip: "pytorch를 위한 pip 설치 미러"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "창 스타일",
    options: {
      custom: "사용자 정의",
      "default": "기본"
    },
    tooltip: "시스템 제목 표시 줄을 숨기려면 사용자 정의 옵션을 선택하세요"
  },
  Comfy_Canvas_SelectionToolbox: Comfy_Canvas_SelectionToolbox$2,
  Comfy_ConfirmClear: Comfy_ConfirmClear$2,
  Comfy_DOMClippingEnabled: Comfy_DOMClippingEnabled$2,
  Comfy_DevMode: Comfy_DevMode$2,
  Comfy_DisableFloatRounding: Comfy_DisableFloatRounding$2,
  Comfy_DisableSliders: Comfy_DisableSliders$2,
  Comfy_EditAttention_Delta: Comfy_EditAttention_Delta$2,
  Comfy_EnableTooltips: Comfy_EnableTooltips$2,
  Comfy_EnableWorkflowViewRestore: Comfy_EnableWorkflowViewRestore$2,
  Comfy_FloatRoundingPrecision: Comfy_FloatRoundingPrecision$2,
  Comfy_Graph_CanvasInfo: Comfy_Graph_CanvasInfo$2,
  Comfy_Graph_CanvasMenu: Comfy_Graph_CanvasMenu$2,
  Comfy_Graph_CtrlShiftZoom: Comfy_Graph_CtrlShiftZoom$2,
  Comfy_Graph_LinkMarkers: Comfy_Graph_LinkMarkers$2,
  Comfy_Graph_ZoomSpeed: Comfy_Graph_ZoomSpeed$2,
  Comfy_GroupSelectedNodes_Padding: Comfy_GroupSelectedNodes_Padding$2,
  Comfy_Group_DoubleClickTitleToEdit: Comfy_Group_DoubleClickTitleToEdit$2,
  Comfy_LinkRelease_Action: Comfy_LinkRelease_Action$2,
  Comfy_LinkRelease_ActionShift: Comfy_LinkRelease_ActionShift$2,
  Comfy_LinkRenderMode: Comfy_LinkRenderMode$2,
  Comfy_Locale: Comfy_Locale$2,
  Comfy_MaskEditor_BrushAdjustmentSpeed: Comfy_MaskEditor_BrushAdjustmentSpeed$2,
  Comfy_MaskEditor_UseDominantAxis: Comfy_MaskEditor_UseDominantAxis$2,
  Comfy_MaskEditor_UseNewEditor: Comfy_MaskEditor_UseNewEditor$2,
  Comfy_ModelLibrary_AutoLoadAll: Comfy_ModelLibrary_AutoLoadAll$2,
  Comfy_ModelLibrary_NameFormat: Comfy_ModelLibrary_NameFormat$2,
  Comfy_NodeBadge_NodeIdBadgeMode: Comfy_NodeBadge_NodeIdBadgeMode$2,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode: Comfy_NodeBadge_NodeLifeCycleBadgeMode$2,
  Comfy_NodeBadge_NodeSourceBadgeMode: Comfy_NodeBadge_NodeSourceBadgeMode$2,
  Comfy_NodeInputConversionSubmenus: Comfy_NodeInputConversionSubmenus$2,
  Comfy_NodeSearchBoxImpl: Comfy_NodeSearchBoxImpl$2,
  Comfy_NodeSearchBoxImpl_NodePreview: Comfy_NodeSearchBoxImpl_NodePreview$2,
  Comfy_NodeSearchBoxImpl_ShowCategory: Comfy_NodeSearchBoxImpl_ShowCategory$2,
  Comfy_NodeSearchBoxImpl_ShowIdName: Comfy_NodeSearchBoxImpl_ShowIdName$2,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency: Comfy_NodeSearchBoxImpl_ShowNodeFrequency$2,
  Comfy_NodeSuggestions_number: Comfy_NodeSuggestions_number$2,
  Comfy_Node_AutoSnapLinkToSlot: Comfy_Node_AutoSnapLinkToSlot$2,
  Comfy_Node_BypassAllLinksOnDelete: Comfy_Node_BypassAllLinksOnDelete$2,
  Comfy_Node_DoubleClickTitleToEdit: Comfy_Node_DoubleClickTitleToEdit$2,
  Comfy_Node_MiddleClickRerouteNode: Comfy_Node_MiddleClickRerouteNode$2,
  Comfy_Node_Opacity: Comfy_Node_Opacity$2,
  Comfy_Node_ShowDeprecated: Comfy_Node_ShowDeprecated$2,
  Comfy_Node_ShowExperimental: Comfy_Node_ShowExperimental$2,
  Comfy_Node_SnapHighlightsNode: Comfy_Node_SnapHighlightsNode$2,
  Comfy_Pointer_ClickBufferTime: Comfy_Pointer_ClickBufferTime$2,
  Comfy_Pointer_ClickDrift: Comfy_Pointer_ClickDrift$2,
  Comfy_Pointer_DoubleClickTime: Comfy_Pointer_DoubleClickTime$2,
  Comfy_PreviewFormat: Comfy_PreviewFormat$2,
  Comfy_PromptFilename: Comfy_PromptFilename$2,
  Comfy_QueueButton_BatchCountLimit: Comfy_QueueButton_BatchCountLimit$2,
  Comfy_Queue_MaxHistoryItems: Comfy_Queue_MaxHistoryItems$2,
  Comfy_RerouteBeta: Comfy_RerouteBeta$2,
  Comfy_Sidebar_Location: Comfy_Sidebar_Location$2,
  Comfy_Sidebar_Size: Comfy_Sidebar_Size$2,
  Comfy_SnapToGrid_GridSize: Comfy_SnapToGrid_GridSize$2,
  Comfy_TextareaWidget_FontSize: Comfy_TextareaWidget_FontSize$2,
  Comfy_TextareaWidget_Spellcheck: Comfy_TextareaWidget_Spellcheck$2,
  Comfy_TreeExplorer_ItemPadding: Comfy_TreeExplorer_ItemPadding$2,
  Comfy_UseNewMenu: Comfy_UseNewMenu$2,
  Comfy_Validation_NodeDefs: Comfy_Validation_NodeDefs$2,
  Comfy_Validation_Workflows: Comfy_Validation_Workflows$2,
  Comfy_WidgetControlMode: Comfy_WidgetControlMode$2,
  Comfy_Window_UnloadConfirmation: Comfy_Window_UnloadConfirmation$2,
  Comfy_Workflow_ConfirmDelete: Comfy_Workflow_ConfirmDelete$2,
  Comfy_Workflow_ShowMissingModelsWarning: Comfy_Workflow_ShowMissingModelsWarning$2,
  Comfy_Workflow_ShowMissingNodesWarning: Comfy_Workflow_ShowMissingNodesWarning$2,
  Comfy_Workflow_SortNodeIdOnSave: Comfy_Workflow_SortNodeIdOnSave$2,
  Comfy_Workflow_WorkflowTabsPosition: Comfy_Workflow_WorkflowTabsPosition$2,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold: LiteGraph_Canvas_LowQualityRenderingZoomThreshold$2,
  LiteGraph_Canvas_MaximumFps: LiteGraph_Canvas_MaximumFps$2,
  LiteGraph_ContextMenu_Scaling: LiteGraph_ContextMenu_Scaling$2,
  LiteGraph_Node_TooltipDelay: LiteGraph_Node_TooltipDelay$2,
  pysssss_SnapToGrid: pysssss_SnapToGrid$2
};
const Comfy_BrowseTemplates$1 = {
  label: "Просмотр шаблонов"
};
const Comfy_Canvas_DeleteSelectedItems$1 = {
  label: "Удалить выбранные элементы"
};
const Comfy_Canvas_FitView$1 = {
  label: "Подогнать вид к выбранным нодам"
};
const Comfy_Canvas_ResetView$1 = {
  label: "Сбросить вид"
};
const Comfy_Canvas_ToggleLinkVisibility$1 = {
  label: "Переключить видимость ссылки"
};
const Comfy_Canvas_ToggleLock$1 = {
  label: "Переключить блокировку холста"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass$1 = {
  label: "Обход/Необход выбранных нод"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse$1 = {
  label: "Свернуть/Развернуть выбранные ноды"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute$1 = {
  label: "Отключить/Включить звук выбранных нод"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin$1 = {
  label: "Закрепить/Открепить выбранные ноды"
};
const Comfy_Canvas_ToggleSelected_Pin$1 = {
  label: "Закрепить/Открепить выбранных нод"
};
const Comfy_Canvas_ZoomIn$1 = {
  label: "Увеличить"
};
const Comfy_Canvas_ZoomOut$1 = {
  label: "Уменьшить"
};
const Comfy_ClearPendingTasks$1 = {
  label: "Очистить ожидающие задачи"
};
const Comfy_ClearWorkflow$1 = {
  label: "Очистить рабочий процесс"
};
const Comfy_DuplicateWorkflow$1 = {
  label: "Дублировать текущий рабочий процесс"
};
const Comfy_ExportWorkflow$1 = {
  label: "Экспорт рабочего процесса"
};
const Comfy_ExportWorkflowAPI$1 = {
  label: "Экспорт рабочего процесса (формат API)"
};
const Comfy_Feedback$1 = {
  label: "Обратная связь"
};
const Comfy_Graph_FitGroupToContents$1 = {
  label: "Подогнать группу к содержимому"
};
const Comfy_Graph_GroupSelectedNodes$1 = {
  label: "Группировать выбранные ноды"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode$1 = {
  label: "Преобразовать выбранные ноды в групповую ноду"
};
const Comfy_GroupNode_ManageGroupNodes$1 = {
  label: "Управление групповыми нодами"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes$1 = {
  label: "Разгруппировать выбранные групповые ноды"
};
const Comfy_Help_AboutComfyUI$1 = {
  label: "Открыть «О ComfyUI»"
};
const Comfy_Help_OpenComfyOrgDiscord$1 = {
  label: "Открыть Comfy-Org Discord"
};
const Comfy_Help_OpenComfyUIDocs$1 = {
  label: "Открыть документацию ComfyUI"
};
const Comfy_Help_OpenComfyUIForum$1 = {
  label: "Открыть форум Comfy-Org"
};
const Comfy_Help_OpenComfyUIIssues$1 = {
  label: "Открыть ComfyUI  Issues"
};
const Comfy_Interrupt$1 = {
  label: "Прервать"
};
const Comfy_LoadDefaultWorkflow$1 = {
  label: "Загрузить стандартный рабочий процесс"
};
const Comfy_Manager_CustomNodesManager$1 = {
  label: "Менеджер Пользовательских Узлов"
};
const Comfy_Manager_ToggleManagerProgressDialog$1 = {
  label: "Переключить диалоговое окно прогресса"
};
const Comfy_NewBlankWorkflow$1 = {
  label: "Новый пустой рабочий процесс"
};
const Comfy_OpenClipspace$1 = {
  label: "Клипспейс"
};
const Comfy_OpenWorkflow$1 = {
  label: "Открыть рабочий процесс"
};
const Comfy_QueuePrompt$1 = {
  label: "Очередь запросов"
};
const Comfy_QueuePromptFront$1 = {
  label: "Очередь запросов (передняя)"
};
const Comfy_Redo$1 = {
  label: "Повторить"
};
const Comfy_RefreshNodeDefinitions$1 = {
  label: "Обновить определения нод"
};
const Comfy_SaveWorkflow$1 = {
  label: "Сохранить рабочий процесс"
};
const Comfy_SaveWorkflowAs$1 = {
  label: "Сохранить рабочий процесс как"
};
const Comfy_ShowSettingsDialog$1 = {
  label: "Показать диалог настроек"
};
const Comfy_ToggleTheme$1 = {
  label: "Переключить тему (Тёмная/Светлая)"
};
const Comfy_Undo$1 = {
  label: "Отменить"
};
const Workspace_CloseWorkflow$1 = {
  label: "Закрыть текущий рабочий процесс"
};
const Workspace_NextOpenedWorkflow$1 = {
  label: "Следующий открытый рабочий процесс"
};
const Workspace_PreviousOpenedWorkflow$1 = {
  label: "Предыдущий открытый рабочий процесс"
};
const Workspace_SearchBox_Toggle$1 = {
  label: "Переключить поисковое окно"
};
const Workspace_ToggleBottomPanel$1 = {
  label: "Переключить нижнюю панель"
};
const Workspace_ToggleFocusMode$1 = {
  label: "Переключить режим фокуса"
};
const Workspace_ToggleSidebarTab_queue$1 = {
  label: "Переключить боковую панель очереди",
  tooltip: "Очередь"
};
const Workspace_ToggleSidebarTab_workflows$1 = {
  label: "Переключить боковую панель рабочих процессов",
  tooltip: "Рабочие процессы"
};
const ruCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "Открыть папку пользовательских нод"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "Открыть папку входных данных"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "Открыть папку логов"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "Открыть extra_model_paths.yaml"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "Открыть папку моделей"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "Открыть папку результатов"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "Открыть инструменты разработчика"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "Руководство пользователя для рабочего стола"
  },
  "Comfy-Desktop_Quit": {
    label: "Выйти"
  },
  "Comfy-Desktop_Reinstall": {
    label: "Переустановить"
  },
  "Comfy-Desktop_Restart": {
    label: "Перезагрузить"
  },
  Comfy_BrowseTemplates: Comfy_BrowseTemplates$1,
  Comfy_Canvas_DeleteSelectedItems: Comfy_Canvas_DeleteSelectedItems$1,
  Comfy_Canvas_FitView: Comfy_Canvas_FitView$1,
  Comfy_Canvas_ResetView: Comfy_Canvas_ResetView$1,
  Comfy_Canvas_ToggleLinkVisibility: Comfy_Canvas_ToggleLinkVisibility$1,
  Comfy_Canvas_ToggleLock: Comfy_Canvas_ToggleLock$1,
  Comfy_Canvas_ToggleSelectedNodes_Bypass: Comfy_Canvas_ToggleSelectedNodes_Bypass$1,
  Comfy_Canvas_ToggleSelectedNodes_Collapse: Comfy_Canvas_ToggleSelectedNodes_Collapse$1,
  Comfy_Canvas_ToggleSelectedNodes_Mute: Comfy_Canvas_ToggleSelectedNodes_Mute$1,
  Comfy_Canvas_ToggleSelectedNodes_Pin: Comfy_Canvas_ToggleSelectedNodes_Pin$1,
  Comfy_Canvas_ToggleSelected_Pin: Comfy_Canvas_ToggleSelected_Pin$1,
  Comfy_Canvas_ZoomIn: Comfy_Canvas_ZoomIn$1,
  Comfy_Canvas_ZoomOut: Comfy_Canvas_ZoomOut$1,
  Comfy_ClearPendingTasks: Comfy_ClearPendingTasks$1,
  Comfy_ClearWorkflow: Comfy_ClearWorkflow$1,
  Comfy_DuplicateWorkflow: Comfy_DuplicateWorkflow$1,
  Comfy_ExportWorkflow: Comfy_ExportWorkflow$1,
  Comfy_ExportWorkflowAPI: Comfy_ExportWorkflowAPI$1,
  Comfy_Feedback: Comfy_Feedback$1,
  Comfy_Graph_FitGroupToContents: Comfy_Graph_FitGroupToContents$1,
  Comfy_Graph_GroupSelectedNodes: Comfy_Graph_GroupSelectedNodes$1,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode: Comfy_GroupNode_ConvertSelectedNodesToGroupNode$1,
  Comfy_GroupNode_ManageGroupNodes: Comfy_GroupNode_ManageGroupNodes$1,
  Comfy_GroupNode_UngroupSelectedGroupNodes: Comfy_GroupNode_UngroupSelectedGroupNodes$1,
  Comfy_Help_AboutComfyUI: Comfy_Help_AboutComfyUI$1,
  Comfy_Help_OpenComfyOrgDiscord: Comfy_Help_OpenComfyOrgDiscord$1,
  Comfy_Help_OpenComfyUIDocs: Comfy_Help_OpenComfyUIDocs$1,
  Comfy_Help_OpenComfyUIForum: Comfy_Help_OpenComfyUIForum$1,
  Comfy_Help_OpenComfyUIIssues: Comfy_Help_OpenComfyUIIssues$1,
  Comfy_Interrupt: Comfy_Interrupt$1,
  Comfy_LoadDefaultWorkflow: Comfy_LoadDefaultWorkflow$1,
  Comfy_Manager_CustomNodesManager: Comfy_Manager_CustomNodesManager$1,
  Comfy_Manager_ToggleManagerProgressDialog: Comfy_Manager_ToggleManagerProgressDialog$1,
  Comfy_NewBlankWorkflow: Comfy_NewBlankWorkflow$1,
  Comfy_OpenClipspace: Comfy_OpenClipspace$1,
  Comfy_OpenWorkflow: Comfy_OpenWorkflow$1,
  Comfy_QueuePrompt: Comfy_QueuePrompt$1,
  Comfy_QueuePromptFront: Comfy_QueuePromptFront$1,
  Comfy_Redo: Comfy_Redo$1,
  Comfy_RefreshNodeDefinitions: Comfy_RefreshNodeDefinitions$1,
  Comfy_SaveWorkflow: Comfy_SaveWorkflow$1,
  Comfy_SaveWorkflowAs: Comfy_SaveWorkflowAs$1,
  Comfy_ShowSettingsDialog: Comfy_ShowSettingsDialog$1,
  Comfy_ToggleTheme: Comfy_ToggleTheme$1,
  Comfy_Undo: Comfy_Undo$1,
  Workspace_CloseWorkflow: Workspace_CloseWorkflow$1,
  Workspace_NextOpenedWorkflow: Workspace_NextOpenedWorkflow$1,
  Workspace_PreviousOpenedWorkflow: Workspace_PreviousOpenedWorkflow$1,
  Workspace_SearchBox_Toggle: Workspace_SearchBox_Toggle$1,
  Workspace_ToggleBottomPanel: Workspace_ToggleBottomPanel$1,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "Переключить нижнюю панель терминала"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "Переключить нижнюю панель логов"
  },
  Workspace_ToggleFocusMode: Workspace_ToggleFocusMode$1,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "Переключить боковую панель библиотеки моделей",
    tooltip: "Библиотека моделей"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "Переключить боковую панель библиотеки нод",
    tooltip: "Библиотека нод"
  },
  Workspace_ToggleSidebarTab_queue: Workspace_ToggleSidebarTab_queue$1,
  Workspace_ToggleSidebarTab_workflows: Workspace_ToggleSidebarTab_workflows$1
};
const clipboard$1 = {
  errorMessage: "Не удалось скопировать в буфер обмена",
  errorNotSupported: "API буфера обмена не поддерживается в вашем браузере",
  successMessage: "Скопировано в буфер обмена"
};
const color$1 = {
  black: "Черный",
  blue: "Синий",
  brown: "Коричневый",
  custom: "Пользовательский",
  cyan: "Голубой",
  "default": "По умолчанию",
  green: "Зелёный",
  noColor: "Без цвета",
  pale_blue: "Бледно-синий",
  pink: "Розовый",
  purple: "Фиолетовый",
  red: "Красный",
  yellow: "Жёлтый"
};
const contextMenu$1 = {
  " to input": " во вход",
  " to widget": " в виджет",
  "Add Group": "Добавить группу",
  "Add Group For Selected Nodes": "Добавить группу для выбранных узлов",
  "Add Node": "Добавить узел",
  Bypass: "Обход",
  Clone: "Клонировать",
  Collapse: "Свернуть",
  Colors: "Цвета",
  "Convert ": "Преобразовать ",
  "Convert Input to Widget": "Преобразовать вход в виджет",
  "Convert Widget to Input": "Преобразовать виджет во вход",
  "Convert to Group Node": "Преобразовать в групповой узел",
  "Copy (Clipspace)": "Копировать (Clipspace)",
  Expand: "Развернуть",
  Inputs: "Входы",
  Manage: "Управлять",
  "Manage Group Nodes": "Управление групповыми узлами",
  Mode: "Режим",
  "Node Templates": "Шаблоны узлов",
  Outputs: "Выходы",
  Pin: "Закрепить",
  Properties: "Свойства",
  "Properties Panel": "Панель свойств",
  Remove: "Удалить",
  Resize: "Изменить размер",
  "Save Selected as Template": "Сохранить выбранное как шаблон",
  Search: "Поиск",
  Shapes: "Формы",
  Title: "Заголовок",
  Unpin: "Открепить"
};
const dataTypes$1 = {
  AUDIO: "АУДИО",
  BOOLEAN: "БУЛЕВО",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP_VISION",
  CLIP_VISION_OUTPUT: "CLIP_VISION_OUTPUT",
  COMBO: "КОМБО",
  CONDITIONING: "КОНДИЦИОНИРОВАНИЕ",
  CONTROL_NET: "CONTROL_NET",
  FLOAT: "ПЛАВАЮЩИЙ",
  FLOATS: "ПЛАВАЮЩИЕ",
  GLIGEN: "GLIGEN",
  GUIDER: "ГИД",
  HOOKS: "ХУКИ",
  HOOK_KEYFRAMES: "КЛЮЧЕВЫЕ_КАДРЫ_ХУКА",
  IMAGE: "ИЗОБРАЖЕНИЕ",
  INT: "ЦЕЛОЕ",
  LATENT: "ЛАТЕНТНЫЙ",
  LATENT_OPERATION: "ЛАТЕНТНАЯ_ОПЕРАЦИЯ",
  LOAD_3D: "ЗАГРУЗИТЬ_3D",
  LOAD_3D_ANIMATION: "ЗАГРУЗИТЬ_3D_АНИМАЦИЮ",
  MASK: "МАСКА",
  MESH: "СЕТКА",
  MODEL: "МОДЕЛЬ",
  NOISE: "ШУМ",
  PHOTOMAKER: "PHOTOMAKER",
  SAMPLER: "СЭМПЛЕР",
  SIGMAS: "СИГМЫ",
  STRING: "СТРОКА",
  STYLE_MODEL: "МОДЕЛЬ_СТИЛЯ",
  TIMESTEPS_RANGE: "ДИАПАЗОН_ВРЕМЕННЫХ_ШАГОВ",
  UPSCALE_MODEL: "МОДЕЛЬ_АПСКЕЙЛА",
  VAE: "VAE",
  VOXEL: "ВОКСЕЛ",
  WEBCAM: "ВЕБ-КАМЕРА"
};
const desktopMenu$1 = {
  confirmQuit: "Открыты несохраненные рабочие процессы; все несохраненные изменения будут потеряны. Проигнорировать это и выйти?",
  confirmReinstall: "Это очистит ваш файл extra_models_config.yaml и начнёт установку заново. Вы уверены?",
  quit: "Выйти",
  reinstall: "Переустановить"
};
const desktopUpdate$1 = {
  description: "ComfyUI Desktop устанавливает новые зависимости. Это может занять несколько минут.",
  terminalDefaultMessage: "Любой вывод консоли из обновления будет отображаться здесь.",
  title: "Обновление ComfyUI Desktop"
};
const downloadGit$1 = {
  gitWebsite: "Скачать git",
  instructions: "Пожалуйста, скачайте и установите последнюю версию для вашей операционной системы. Кнопка «Скачать git» ниже открывает страницу загрузок git-scm.com.",
  message: "Не удалось найти git. Рабочая копия git необходима для нормальной работы.",
  skip: "Пропустить",
  title: "Скачать git",
  warning: "Если вы уверены, что вам не нужно устанавливать git, или произошла ошибка, вы можете нажать «Пропустить», чтобы обойти эту проверку. Попытка запустить ComfyUI без рабочей копии git в настоящее время не поддерживается."
};
const electronFileDownload$1 = {
  cancel: "Отменить загрузку",
  cancelled: "Отменено",
  inProgress: "В процессе",
  pause: "Приостановить загрузку",
  paused: "Приостановлено",
  resume: "Возобновить загрузку"
};
const g$1 = {
  about: "О программе",
  add: "Добавить",
  all: "Все",
  apply: "Применить",
  back: "Назад",
  cancel: "Отмена",
  capture: "захват",
  category: "Категория",
  choose_file_to_upload: "выберите файл для загрузки",
  close: "Закрыть",
  color: "Цвет",
  comingSoon: "Скоро будет",
  command: "Команда",
  community: "Сообщество",
  completed: "Завершено",
  confirm: "Подтвердить",
  "continue": "Продолжить",
  control_after_generate: "управление после генерации",
  control_before_generate: "управление до генерации",
  copyToClipboard: "Скопировать в буфер обмена",
  currentUser: "Текущий пользователь",
  customize: "Настроить",
  customizeFolder: "Настроить папку",
  "delete": "Удалить",
  deprecated: "Устарело",
  description: "Описание",
  devices: "Устройства",
  disableAll: "Отключить все",
  download: "Скачать",
  empty: "Пусто",
  enableAll: "Включить все",
  enabled: "Включено",
  error: "Ошибка",
  experimental: "БЕТА",
  "export": "Экспорт",
  extensionName: "Название расширения",
  feedback: "Обратная связь",
  filter: "Фильтр",
  findIssues: "Найти проблемы",
  firstTimeUIMessage: 'Вы впервые используете новый интерфейс. Выберите "Меню > Использовать новое меню > Отключено", чтобы восстановить старый интерфейс.',
  goToNode: "Перейти к ноде",
  icon: "Иконка",
  imageFailedToLoad: "Не удалось загрузить изображение",
  "import": "Импорт",
  inProgress: "В процессе",
  insert: "Вставить",
  install: "Установить",
  installed: "Установлено",
  installing: "Установка",
  keybinding: "Привязка клавиш",
  loadAllFolders: "Загрузить все папки",
  loadWorkflow: "Загрузить рабочий процесс",
  loading: "Загрузка",
  logs: "Логи",
  missing: "Отсутствует",
  name: "Имя",
  newFolder: "Новая папка",
  next: "Далее",
  no: "Нет",
  noResultsFound: "Результатов не найдено",
  noTasksFound: "Задачи не найдены",
  noTasksFoundMessage: "В очереди нет задач.",
  noWorkflowsFound: "Рабочие процессы не найдены.",
  nodes: "Узлы",
  ok: "ОК",
  openNewIssue: "Открыть новую проблему",
  overwrite: "Перезаписать",
  reconnected: "Переподключено",
  reconnecting: "Переподключение",
  refresh: "Обновить",
  reloadToApplyChanges: "Перезагрузите, чтобы применить изменения",
  rename: "Переименовать",
  reportIssue: "Отправить отчёт",
  reportIssueTooltip: "Отправить отчёт об ошибке в Comfy Org",
  reportSent: "Отчёт отправлен",
  reset: "Сбросить",
  resetKeybindingsTooltip: "Сбросить сочетания клавиш по умолчанию",
  restart: "Перезапустить",
  resultsCount: "Найдено {count} результатов",
  save: "Сохранить",
  saving: "Сохранение",
  searchExtensions: "Поиск расширений",
  searchFailedMessage: "Мы не смогли найти настройки, соответствующие вашему запросу. Попробуйте изменить поисковые термины.",
  searchKeybindings: "Поиск сочетаний клавиш",
  searchModels: "Поиск моделей",
  searchNodes: "Поиск нод",
  searchSettings: "Поиск настроек",
  searchWorkflows: "Поиск рабочих процессов",
  settings: "Настройки",
  showReport: "Показать отчёт",
  sort: "Сортировать",
  status: "Статус",
  success: "Успех",
  systemInfo: "Информация о системе",
  terminal: "Терминал",
  updated: "Обновлено",
  upload: "Загрузить",
  videoFailedToLoad: "Не удалось загрузить видео",
  workflow: "Рабочий процесс"
};
const graphCanvasMenu$1 = {
  fitView: "Подгонять под выделенные",
  panMode: "Режим панорамирования",
  resetView: "Сбросить вид",
  selectMode: "Выбрать режим",
  toggleLinkVisibility: "Переключить видимость ссылок",
  zoomIn: "Увеличить",
  zoomOut: "Уменьшить"
};
const groupNode$1 = {
  create: "Создать ноду группы",
  enterName: "Введите название"
};
const icon$1 = {
  bookmark: "Закладка",
  box: "Коробка",
  briefcase: "Портфель",
  "exclamation-triangle": "Предупреждение",
  file: "Файл",
  folder: "Папка",
  heart: "Сердце",
  inbox: "Входящие",
  star: "Звезда"
};
const install$1 = {
  appDataLocationTooltip: "Директория данных приложения ComfyUI. Хранит:\n- Логи\n- Конфигурации сервера",
  appPathLocationTooltip: "Директория активов приложения ComfyUI. Хранит код и активы ComfyUI",
  cannotWrite: "Невозможно записать в выбранный путь",
  chooseInstallationLocation: "Выберите место установки",
  customNodes: "Пользовательские ноды",
  customNodesDescription: "Переустановите пользовательские ноды из существующих установок ComfyUI.",
  desktopAppSettings: "Настройки десктопного приложения",
  desktopAppSettingsDescription: "Настройте, как ComfyUI ведёт себя на вашем рабочем столе. Вы можете изменить эти настройки позже.",
  desktopSettings: "Настройки рабочего стола",
  failedToSelectDirectory: "Не удалось выбрать директорию",
  gpu: "GPU",
  gpuSelection: {
    cpuMode: "Режим CPU",
    cpuModeDescription: "Режим CPU предназначен только для разработчиков и крайне редких случаев.",
    cpuModeDescription2: "Если вы не полностью уверены, что вам это нужно, пожалуйста, проигнорируйте эту галочку и выберите ваш GPU выше.",
    customComfyNeedsPython: "ComfyUI не будет работать, пока python не будет настроен",
    customInstallRequirements: "Установите все требования и зависимости (например, custom torch)",
    customManualVenv: "Вручную настроить python venv",
    customMayNotWork: "Это полностью не поддерживается и может просто не работать",
    customSkipsPython: "Этот вариант пропускает обычную настройку python.",
    enableCpuMode: "Включить режим CPU",
    mpsDescription: "Поддерживаются Apple Metal Performance Shaders с использованием pytorch nightly.",
    nvidiaDescription: "Устройства NVIDIA напрямую поддерживаются с использованием сборок pytorch CUDA.",
    selectGpu: "Выберите GPU",
    selectGpuDescription: "Выберите тип GPU, который у вас есть"
  },
  helpImprove: "Пожалуйста, помогите улучшить ComfyUI",
  installLocation: "Место установки",
  installLocationDescription: "Выберите директорию для пользовательских данных ComfyUI. В выбранном месте будет установлена среда Python. Пожалуйста, убедитесь, что на выбранном диске достаточно места (~15 ГБ).",
  installLocationTooltip: "Директория пользовательских данных ComfyUI. Хранит:\n- Среда Python\n- Модели\n- Пользовательские ноды\n",
  insufficientFreeSpace: "Недостаточно места — минимально необходимое свободное место",
  isOneDrive: "Установка в OneDrive может вызвать проблемы. Настоятельно рекомендуем устанавливать в месте, не связанном с OneDrive.",
  manualConfiguration: {
    createVenv: "Вам потребуется создать виртуальное окружение в следующем каталоге",
    requirements: "Требования",
    restartWhenFinished: "После завершения настройки виртуального окружения, пожалуйста, перезапустите ComfyUI.",
    title: "Ручная Конфигурация",
    virtualEnvironmentPath: "Путь виртуального окружения"
  },
  metricsDisabled: "Метрики отключены",
  metricsEnabled: "Метрики включены",
  migrateFromExistingInstallation: "Миграция из существующей установки",
  migration: "Миграция",
  migrationOptional: "Миграция является необязательной. Если у вас нет существующей установки, вы можете пропустить этот шаг.",
  migrationSourcePathDescription: "Если у вас уже есть установленный ComfyUI, мы можем скопировать/связать ваши существующие пользовательские файлы и модели с новой установкой. Ваша существующая установка ComfyUI не будет затронута.",
  moreInfo: "Для получения дополнительной информации, пожалуйста, прочтите нашу",
  nonDefaultDrive: "Пожалуйста, установите ComfyUI на системный диск (например, C:\\). Диски с другими файловыми системами могут вызвать непредсказуемые проблемы. Модели и другие файлы можно хранить на других дисках после установки.",
  parentMissing: "Путь не существует — сначала создайте родительский каталог",
  pathExists: "Директория уже существует — пожалуйста, убедитесь, что вы сделали резервное копирование всех данных",
  pathValidationFailed: "Не удалось проверить путь",
  privacyPolicy: "политику конфиденциальности",
  selectItemsToMigrate: "Выберите элементы для миграции",
  settings: {
    allowMetrics: "Метрики использования",
    allowMetricsDescription: "Помогите улучшить ComfyUI, отправляя анонимные метрики использования. Личная информация или содержание рабочего процесса не будут собираться.",
    autoUpdate: "Автоматические обновления",
    autoUpdateDescription: "Автоматически загружать и устанавливать обновления, когда они становятся доступными. Вы всегда будете уведомлены перед установкой обновлений.",
    checkingMirrors: "Проверка доступа к зеркалам python по сети...",
    dataCollectionDialog: {
      collect: {
        errorReports: "Сообщение об ошибке и трассировка стека",
        systemInfo: "Аппаратное обеспечение, тип ОС и версия приложения",
        userJourneyEvents: "События пользовательского пути"
      },
      doNotCollect: {
        customNodeConfigurations: "Пользовательские конфигурации нод",
        fileSystemInformation: "Информация о файловой системе",
        personalInformation: "Личная информация",
        workflowContents: "Содержание рабочего процесса"
      },
      title: "О сборе данных",
      viewFullPolicy: "Просмотреть политику полностью",
      whatWeCollect: "Что мы собираем:",
      whatWeDoNotCollect: "Что мы не собираем:"
    },
    errorUpdatingConsent: "Ошибка обновления согласия",
    errorUpdatingConsentDetail: "Не удалось обновить настройки согласия на метрики",
    learnMoreAboutData: "Узнать больше о сборе данных",
    mirrorSettings: "Настройки зеркала",
    mirrorsReachable: "Сетевой доступ к зеркалам python хороший",
    mirrorsUnreachable: "Сетевой доступ к некоторым зеркалам python плохой",
    pypiMirrorPlaceholder: "Введите URL-зеркало PyPI",
    pythonMirrorPlaceholder: "Введите URL-зеркало Python"
  },
  systemLocations: "Системные места",
  unhandledError: "Неизвестная ошибка",
  updateConsent: "Вы ранее согласились на отчётность об ошибках. Теперь мы отслеживаем метрики событий, чтобы помочь выявить ошибки и улучшить приложение. Личная идентифицируемая информация не собирается."
};
const issueReport$1 = {
  contactFollowUp: "Свяжитесь со мной для уточнения",
  feedbackTitle: "Помогите нам улучшить ComfyUI, оставив отзыв",
  helpFix: "Помочь исправить это",
  notifyResolve: "Уведомить меня, когда проблема будет решена",
  provideAdditionalDetails: "Предоставьте дополнительные сведения (необязательно)",
  provideEmail: "Укажите вашу электронную почту (необязательно)",
  rating: "Рейтинг",
  stackTrace: "Трассировка стека",
  submitErrorReport: "Отправить отчёт об ошибке (необязательно)",
  systemStats: "Статистика системы",
  validation: {
    invalidEmail: "Пожалуйста, введите действительный адрес электронной почты",
    maxLength: "Сообщение слишком длинное"
  }
};
const load3d$1 = {
  backgroundColor: "Цвет фона",
  camera: "Камера",
  edgeThreshold: "Пороговое значение края",
  "export": "Экспорт",
  exportModel: "Экспорт модели",
  exportingModel: "Экспорт модели...",
  fov: "Угол обзора",
  light: "Свет",
  lightIntensity: "Интенсивность света",
  loadingModel: "Загрузка 3D модели...",
  materialMode: "Режим Материала",
  model: "Модель",
  previewOutput: "Предварительный просмотр",
  removeBackgroundImage: "Удалить фоновое изображение",
  scene: "Сцена",
  showGrid: "Показать сетку",
  switchCamera: "Переключить камеру",
  switchingMaterialMode: "Переключение режима материала...",
  upDirection: "Направление Вверх",
  uploadBackgroundImage: "Загрузить фоновое изображение"
};
const maintenance$1 = {
  None: "Нет",
  OK: "OK",
  Skipped: "Пропущено",
  allOk: "Проблем не обнаружено.",
  confirmTitle: "Вы уверены?",
  consoleLogs: "Консольные журналы",
  detected: "Обнаружено",
  error: {
    cannotContinue: "Невозможно продолжить - остались ошибки",
    defaultDescription: "Произошла ошибка при выполнении задачи по обслуживанию.",
    taskFailed: "Не удалось выполнить задачу.",
    toastTitle: "Ошибка задачи"
  },
  refreshing: "Обновление",
  showManual: "Показать задачи по обслуживанию",
  status: "Статус",
  terminalDefaultMessage: "Когда вы запускаете команду для устранения неполадок, любой вывод будет отображаться здесь.",
  title: "Обслуживание"
};
const manager$1 = {
  createdBy: "Создано",
  dependencies: "Зависимости",
  discoverCommunityContent: "Откройте для себя пакеты узлов, расширения и многое другое, созданные сообществом...",
  downloads: "Загрузки",
  errorConnecting: "Ошибка подключения к реестру Comfy Node.",
  filter: {
    disabled: "Отключено",
    enabled: "Включено",
    nodePack: "Пакет Узлов"
  },
  inWorkflow: "В рабочем процессе",
  infoPanelEmpty: "Нажмите на элемент, чтобы увидеть информацию",
  installSelected: "Установить выбранное",
  lastUpdated: "Последнее обновление",
  latestVersion: "Последняя",
  license: "Лицензия",
  loadingVersions: "Загрузка версий...",
  nightlyVersion: "Ночная",
  noDescription: "Описание отсутствует",
  noResultsFound: "По вашему запросу ничего не найдено.",
  nodePack: "Пакет Узлов",
  packsSelected: "Выбрано пакетов",
  repository: "Репозиторий",
  restartToApplyChanges: "Чтобы применить изменения, пожалуйста, перезапустите ComfyUI",
  searchPlaceholder: "Поиск",
  selectVersion: "Выберите версию",
  sort: {
    downloads: "Самые популярные",
    rating: "Рейтинг"
  },
  status: {
    active: "Активный",
    banned: "Заблокировано",
    deleted: "Удалено",
    flagged: "Отмечено",
    pending: "В ожидании",
    unknown: "Неизвестно"
  },
  title: "Менеджер Пользовательских Узлов",
  totalNodes: "Всего Узлов",
  tryAgainLater: "Пожалуйста, попробуйте позже.",
  tryDifferentSearch: "Пожалуйста, попробуйте изменить запрос.",
  uninstall: "Удалить",
  uninstallSelected: "Удалить выбранное",
  uninstalling: "Удаление",
  update: "Обновить",
  version: "Версия"
};
const maskEditor$1 = {
  "Apply to Whole Image": "Применить ко всему изображению",
  "Brush Settings": "Настройки кисти",
  "Brush Shape": "Форма кисти",
  Clear: "Очистить",
  "Color Select Settings": "Настройки выбора цвета",
  "Fill Opacity": "Прозрачность заливки",
  Hardness: "Жесткость",
  "Image Layer": "Слой изображения",
  Invert: "Инвертировать",
  Layers: "Слои",
  "Live Preview": "Предварительный просмотр",
  "Mask Layer": "Слой маски",
  "Mask Opacity": "Прозрачность маски",
  "Mask Tolerance": "Толерантность маски",
  Method: "Метод",
  Opacity: "Прозрачность",
  "Paint Bucket Settings": "Настройки заливки",
  "Reset to Default": "Сбросить до стандартных",
  "Selection Opacity": "Прозрачность выбора",
  "Smoothing Precision": "Точность сглаживания",
  "Stop at mask": "Остановиться на маске",
  Thickness: "Толщина",
  Tolerance: "Толерантность"
};
const menu$1 = {
  autoQueue: "Автоочередь",
  batchCount: "Количество пакетов",
  batchCountTooltip: "Количество раз, когда генерация рабочего процесса должна быть помещена в очередь",
  clear: "Очистить рабочий процесс",
  clipspace: "Открыть Clipspace",
  disabled: "Отключено",
  disabledTooltip: "Рабочий процесс не будет автоматически помещён в очередь",
  execute: "Выполнить",
  hideMenu: "Скрыть меню",
  instant: "Мгновенно",
  instantTooltip: "Рабочий процесс будет помещён в очередь сразу же после завершения генерации",
  interrupt: "Отменить текущее выполнение",
  onChange: "При изменении",
  onChangeTooltip: "Рабочий процесс будет поставлен в очередь после внесения изменений",
  refresh: "Обновить определения нод",
  resetView: "Сбросить вид холста",
  run: "Запустить",
  runWorkflow: "Запустить рабочий процесс (Shift для очереди в начале)",
  runWorkflowFront: "Запустить рабочий процесс (Очередь в начале)",
  showMenu: "Показать меню",
  toggleBottomPanel: "Переключить нижнюю панель"
};
const menuLabels$1 = {
  "About ComfyUI": "О ComfyUI",
  "Browse Templates": "Просмотреть шаблоны",
  "Bypass/Unbypass Selected Nodes": "Обойти/восстановить выбранные ноды",
  "Canvas Toggle Link Visibility": "Переключение видимости ссылки на холст",
  "Canvas Toggle Lock": "Переключение блокировки холста",
  "Clear Pending Tasks": "Очистить ожидающие задачи",
  "Clear Workflow": "Очистить рабочий процесс",
  Clipspace: "Клиппространство",
  "Close Current Workflow": "Закрыть текущий рабочий процесс",
  "Collapse/Expand Selected Nodes": "Свернуть/развернуть выбранные ноды",
  "Comfy-Org Discord": "Discord Comfy-Org",
  "ComfyUI Docs": "Документация ComfyUI",
  "ComfyUI Forum": "Форум ComfyUI",
  "ComfyUI Issues": "Проблемы ComfyUI",
  "Convert selected nodes to group node": "Преобразовать выбранные ноды в групповую ноду",
  "Custom Nodes Manager": "Менеджер Пользовательских Узлов",
  "Delete Selected Items": "Удалить выбранные элементы",
  "Desktop User Guide": "Руководство пользователя для настольных ПК",
  "Duplicate Current Workflow": "Дублировать текущий рабочий процесс",
  Edit: "Редактировать",
  Export: "Экспортировать",
  "Export (API)": "Экспорт (API)",
  "Fit Group To Contents": "Подогнать группу под содержимое",
  "Fit view to selected nodes": "Подогнать вид под выбранные ноды",
  "Give Feedback": "Оставить отзыв",
  "Group Selected Nodes": "Сгруппировать выбранные ноды",
  Help: "Помощь",
  Interrupt: "Прервать",
  "Load Default Workflow": "Загрузить стандартный рабочий процесс",
  "Manage group nodes": "Управление групповыми нодами",
  "Mute/Unmute Selected Nodes": "Отключить/включить звук для выбранных нод",
  New: "Новый",
  "Next Opened Workflow": "Следующий открытый рабочий процесс",
  Open: "Открыть",
  "Open Custom Nodes Folder": "Открыть папку пользовательских нод",
  "Open DevTools": "Открыть инструменты разработчика",
  "Open Inputs Folder": "Открыть папку входных данных",
  "Open Logs Folder": "Открыть папку журналов",
  "Open Models Folder": "Открыть папку моделей",
  "Open Outputs Folder": "Открыть папку выходных данных",
  "Open extra_model_paths_yaml": "Открыть extra_model_paths.yaml",
  "Pin/Unpin Selected Items": "Закрепить/открепить выбранные элементы",
  "Pin/Unpin Selected Nodes": "Закрепить/открепить выбранные ноды",
  "Previous Opened Workflow": "Предыдущий открытый рабочий процесс",
  "Queue Prompt": "Запрос в очереди",
  "Queue Prompt (Front)": "Запрос в очереди (спереди)",
  Quit: "Выйти",
  Redo: "Повторить",
  "Refresh Node Definitions": "Обновить определения нод",
  Reinstall: "Переустановить",
  "Reset View": "Сбросить вид",
  Restart: "Перезапустить",
  Save: "Сохранить",
  "Save As": "Сохранить как",
  "Show Settings Dialog": "Показать диалог настроек",
  "Toggle Bottom Panel": "Переключить нижнюю панель",
  "Toggle Focus Mode": "Переключить режим фокуса",
  "Toggle Logs Bottom Panel": "Переключение нижней панели журналов",
  "Toggle Model Library Sidebar": "Переключение боковой панели библиотеки моделей",
  "Toggle Node Library Sidebar": "Переключение боковой панели библиотеки нод",
  "Toggle Progress Dialog": "Переключить диалоговое окно прогресса",
  "Toggle Queue Sidebar": "Переключение боковой панели очереди",
  "Toggle Search Box": "Переключить поисковую панель",
  "Toggle Terminal Bottom Panel": "Переключение нижней панели терминала",
  "Toggle Theme (Dark/Light)": "Переключение темы (Тёмная/Светлая)",
  "Toggle Workflows Sidebar": "Переключение боковой панели рабочих процессов",
  Undo: "Отменить",
  "Ungroup selected group nodes": "Разгруппировать выбранные групповые ноды",
  Workflow: "Рабочий процесс",
  "Zoom In": "Увеличить",
  "Zoom Out": "Уменьшить"
};
const missingModelsDialog$1 = {
  doNotAskAgain: "Больше не показывать это",
  missingModels: "Отсутствующие модели",
  missingModelsMessage: "При загрузке графа следующие модели не были найдены"
};
const nodeCategories$1 = {
  "3d": "3d",
  "3d_models": "3d_модели",
  _for_testing: "_для_тестирования",
  advanced: "расширенный",
  animation: "анимация",
  api: "api",
  attention_experiments: "эксперименты_внимания",
  audio: "аудио",
  batch: "пакет",
  clip: "clip",
  combine: "объединить",
  compositing: "композиционирование",
  "cond pair": "условие_пара",
  "cond single": "условие_одиночное",
  conditioning: "условие",
  controlnet: "controlnet",
  create: "создать",
  custom_sampling: "пользовательский_семплинг",
  debug: "отладка",
  deprecated: "устаревший",
  flux: "flux",
  gligen: "gligen",
  guidance: "направление",
  guiders: "направляющие",
  hooks: "хуки",
  image: "изображение",
  inpaint: "восстановление",
  instructpix2pix: "instructpix2pix",
  latent: "латентный",
  loaders: "загрузчики",
  ltxv: "ltxv",
  mask: "маска",
  model: "модель",
  model_merging: "слияние_моделей",
  model_patches: "патчи_моделей",
  model_specific: "специфичная_модель",
  noise: "шум",
  operations: "операции",
  photomaker: "photomaker",
  postprocessing: "постобработка",
  preprocessors: "предобработчики",
  samplers: "семплеры",
  sampling: "выборка",
  schedulers: "schedulers",
  scheduling: "scheduling",
  sd3: "sd3",
  sigmas: "сигмы",
  stable_cascade: "стабильная_каскадная",
  style_model: "модель_стиля",
  transform: "преобразование",
  unet: "unet",
  upscale_diffusion: "диффузии_апскейла",
  upscaling: "апскейл",
  video: "видео",
  video_models: "видеомодели"
};
const nodeTemplates$1 = {
  enterName: "Введите название",
  saveAsTemplate: "Сохранить как шаблон"
};
const notSupported$1 = {
  "continue": "Продолжить",
  continueTooltip: "Я уверен, что моё устройство поддерживается",
  learnMore: "Узнать больше",
  message: "Поддерживаются только следующие устройства:",
  reportIssue: "Сообщить о проблеме",
  supportedDevices: {
    macos: "MacOS (M1 или новее)",
    windows: "Windows (Nvidia GPU с поддержкой CUDA)"
  },
  title: "Ваше устройство не поддерживается"
};
const serverConfig$1 = {
  modifiedConfigs: "Вы изменили следующие конфигурации сервера. Перезапустите, чтобы применить изменения.",
  restart: "Перезапустить",
  revertChanges: "Отменить изменения"
};
const serverConfigCategories$1 = {
  Attention: "Внимание",
  CUDA: "CUDA",
  Cache: "Кэш",
  Directories: "Каталоги",
  General: "Общее",
  Inference: "Вывод",
  Memory: "Память",
  Network: "Сеть",
  Preview: "Предпросмотр"
};
const serverConfigItems$1 = {
  "cache-classic": {
    name: "Использовать классическую систему кэширования"
  },
  "cache-lru": {
    name: "Использовать LRU кэширование с максимальным количеством N кэшированных результатов нод.",
    tooltip: "Может использовать больше ОЗУ/ВРП."
  },
  "cpu-vae": {
    name: "Запуск VAE на CPU"
  },
  "cross-attention-method": {
    name: "Метод перекрёстного внимания"
  },
  "cuda-device": {
    name: "Индекс устройства CUDA для использования"
  },
  "cuda-malloc": {
    name: "Использовать CUDA malloc для выделения памяти"
  },
  "default-hashing-function": {
    name: "Функция хеширования по умолчанию для файлов моделей"
  },
  deterministic: {
    name: "Заставить pytorch использовать более медленные детерминированные алгоритмы, когда это возможно.",
    tooltip: "Обратите внимание, что это может не сделать изображения детерминированными во всех случаях."
  },
  directml: {
    name: "Индекс устройства DirectML"
  },
  "disable-all-custom-nodes": {
    name: "Отключить загрузку всех пользовательских нод."
  },
  "disable-ipex-optimize": {
    name: "Отключить оптимизацию IPEX"
  },
  "disable-metadata": {
    name: "Отключить сохранение метаданных подсказок в файлах."
  },
  "disable-smart-memory": {
    name: "Отключить управление умной памятью",
    tooltip: "Принудить ComfyUI агрессивно выгружать в обычную оперативную память вместо того, чтобы держать модели в VRAM, когда это возможно."
  },
  "disable-xformers": {
    name: "Отключить оптимизацию xFormers"
  },
  "dont-print-server": {
    name: "Не показывать вывод сервера в консоль."
  },
  "dont-upcast-attention": {
    name: "Предотвратить повышение внимания"
  },
  "enable-cors-header": {
    name: 'Включить CORS заголовок: Используйте "*" для всех источников или укажите домен'
  },
  fast: {
    name: "Включить некоторые непроверенные и потенциально ухудшающие качество оптимизации."
  },
  "force-channels-last": {
    name: "Принудительное использование формата памяти с последними каналами"
  },
  "force-upcast-attention": {
    name: "Принудительное повышение внимания"
  },
  "global-precision": {
    name: "Глобальная точность с плавающей запятой",
    tooltip: "Глобальная точность с плавающей запятой"
  },
  "input-directory": {
    name: "Входной каталог"
  },
  listen: {
    name: "Хост: IP-адрес для прослушивания"
  },
  "log-level": {
    name: "Уровень подробности логирования"
  },
  "max-upload-size": {
    name: "Максимальный размер загрузки (МБ)"
  },
  "output-directory": {
    name: "Выходной каталог"
  },
  port: {
    name: "Порт: Порт для прослушивания"
  },
  "preview-method": {
    name: "Метод, используемый для латентных превью"
  },
  "preview-size": {
    name: "Размер превью изображений"
  },
  "reserve-vram": {
    name: "Резервируемая VRAM (ГБ)",
    tooltip: "Установите количество VRAM в ГБ, которое вы хотите зарезервировать для использования вашей ОС/другими программами. По умолчанию резервируется определённое количество в зависимости от вашей ОС."
  },
  "text-encoder-precision": {
    name: "Точность текстового кодировщика",
    tooltip: "Точность текстового кодировщика"
  },
  "tls-certfile": {
    name: "TLS сертификат: Путь к TLS сертификату для HTTPS"
  },
  "tls-keyfile": {
    name: "TLS ключевой файл: Путь к TLS ключевому файлу для HTTPS"
  },
  "unet-precision": {
    name: "Точность UNET",
    tooltip: "Точность UNET"
  },
  "vae-precision": {
    name: "Точность VAE",
    tooltip: "Точность VAE"
  },
  "vram-management": {
    name: "Режим управления VRAM"
  }
};
const serverStart$1 = {
  openLogs: "Открыть логи",
  process: {
    error: "Не удалось запустить ComfyUI Desktop",
    "initial-state": "Загрузка…",
    "python-setup": "Настройка окружения Python…",
    ready: "Завершение…",
    "starting-server": "Запуск сервера ComfyUI…"
  },
  reportIssue: "Сообщить о проблеме",
  showTerminal: "Показать терминал",
  troubleshoot: "Устранение неполадок"
};
const settingsCategories$1 = {
  About: "О программе",
  Appearance: "Внешний вид",
  BrushAdjustment: "Настройка кисти",
  Canvas: "Холст",
  ColorPalette: "Цветовая палитра",
  Comfy: "Comfy",
  "Comfy-Desktop": "Десктопный Comfy",
  ContextMenu: "Контекстное меню",
  CustomColorPalettes: "Пользовательские цветовые палитры",
  DevMode: "Режим разработчика",
  EditTokenWeight: "Редактировать вес токена",
  Extension: "Расширение",
  General: "Общие",
  Graph: "Граф",
  Group: "Группа",
  Keybinding: "Сочетание клавиш",
  Link: "Ссылка",
  LinkRelease: "Освобождение ссылки",
  LiteGraph: "Lite Graph",
  Locale: "Локализация",
  "Mask Editor": "Редактор масок",
  Menu: "Меню",
  ModelLibrary: "Библиотека моделей",
  NewEditor: "Новый редактор",
  Node: "Нода",
  "Node Search Box": "Поисковая строка нод",
  "Node Widget": "Виджет ноды",
  NodeInputConversionSubmenus: "Подменю преобразования ввода ноды",
  NodeLibrary: "Библиотека нод",
  Pointer: "Указатель",
  Queue: "Очередь",
  QueueButton: "Кнопка очереди",
  RerouteBeta: "Бета-версия перенаправления",
  Server: "Сервер",
  "Server-Config": "Настройки сервера",
  Settings: "Настройки",
  Sidebar: "Боковая панель",
  "Tree Explorer": "Дерево проводника",
  UV: "UV",
  Validation: "Валидация",
  Window: "Окно",
  Workflow: "Рабочий процесс"
};
const sideToolbar$1 = {
  browseTemplates: "Просмотреть примеры шаблонов",
  downloads: "Загрузки",
  logout: "Выйти",
  modelLibrary: "Библиотека моделей",
  newBlankWorkflow: "Создайте новый пустой рабочий процесс",
  nodeLibrary: "Библиотека нод",
  nodeLibraryTab: {
    sortOrder: "Порядок сортировки"
  },
  openWorkflow: "Открыть рабочий процесс в локальной файловой системе",
  queue: "Очередь",
  queueTab: {
    backToAllTasks: "Вернуться ко всем задачам",
    clearPendingTasks: "Очистить отложенные задачи",
    containImagePreview: "Предпросмотр заливающего изображения",
    coverImagePreview: "Предпросмотр подходящего изображения",
    filter: "Фильтровать выводы",
    filters: {
      hideCached: "Скрыть кэшированные",
      hideCanceled: "Скрыть отмененные"
    },
    showFlatList: "Показать плоский список"
  },
  themeToggle: "Переключить тему",
  workflowTab: {
    confirmDelete: "Вы уверены, что хотите удалить этот рабочий процесс?",
    confirmDeleteTitle: "Удалить рабочий процесс?",
    confirmOverwrite: "Файл ниже уже существует. Вы хотите его перезаписать?",
    confirmOverwriteTitle: "Перезаписать существующий файл?",
    deleteFailed: "Попытка удалить рабочий процесс не удалась.",
    deleteFailedTitle: "Не удалось удалить",
    deleted: "Рабочий процесс удалён",
    dirtyClose: "Файлы ниже были изменены. Вы хотите сохранить их перед закрытием?",
    dirtyCloseHint: "Удерживайте Shift, чтобы закрыть без подсказки",
    dirtyCloseTitle: "Сохранить изменения?",
    workflowTreeType: {
      bookmarks: "Закладки",
      browse: "Просмотреть",
      open: "Открыть"
    }
  },
  workflows: "Рабочие процессы"
};
const tabMenu$1 = {
  addToBookmarks: "Добавить в закладки",
  closeOtherTabs: "Закрыть другие вкладки",
  closeTab: "Закрыть вкладку",
  closeTabsToLeft: "Закрыть вкладки слева",
  closeTabsToRight: "Закрыть вкладки справа",
  duplicateTab: "Дублировать вкладку",
  removeFromBookmarks: "Удалить из закладок"
};
const templateWorkflows$1 = {
  category: {
    "3D": "3D",
    "Area Composition": "Композиция области",
    Audio: "Аудио",
    Basics: "Основы",
    "ComfyUI Examples": "Примеры ComfyUI",
    ControlNet: "ControlNet",
    "Custom Nodes": "Пользовательские узлы",
    Flux: "Flux",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    Upscaling: "Увеличение разрешения",
    Video: "Видео"
  },
  template: {
    "3D": {
      "hunyuan-3d-multiview-elf": "Hunyuan3D Многовидовой",
      "hunyuan-3d-turbo": "Hunyuan3D Турбо",
      "hunyuan3d-non-multiview-train": "Hunyuan3D",
      stable_zero123_example: "Stable Zero123"
    },
    "Area Composition": {
      area_composition: "Композиция области",
      area_composition_reversed: "Обратная композиция области",
      area_composition_square_area_for_subject: "Композиция области квадратной области для субъекта"
    },
    Audio: {
      stable_audio_example: "Stable Audio"
    },
    Basics: {
      "default": "Генерация изображений",
      embedding_example: "Встраивание",
      gligen_textbox_example: "Gligen Textbox",
      image2image: "Изображение в изображение",
      inpain_model_outpainting: "Inpaint Model Outpainting",
      inpaint_example: "Inpaint",
      lora: "Lora",
      lora_multiple: "Lora Multiple"
    },
    ControlNet: {
      "2_pass_pose_worship": "2 Pass Pose Worship",
      controlnet_example: "ControlNet",
      depth_controlnet: "Depth ControlNet",
      depth_t2i_adapter: "Depth T2I Adapter",
      mixing_controlnets: "Mixing ControlNets"
    },
    Flux: {
      flux_canny_model_example: "Flux Canny Model",
      flux_depth_lora_example: "Flux Depth Lora",
      flux_dev_checkpoint_example: "Flux Dev",
      flux_fill_inpaint_example: "Flux Inpaint",
      flux_fill_outpaint_example: "Flux Outpaint",
      flux_redux_model_example: "Flux Redux Model",
      flux_schnell: "Flux Schnell"
    },
    SD3_5: {
      sd3_5_large_blur: "SD3.5 Большое размытие",
      sd3_5_large_canny_controlnet_example: "SD3.5 Большой Canny ControlNet",
      sd3_5_large_depth: "SD3.5 Большая глубина",
      sd3_5_simple_example: "SD3.5 Простой"
    },
    SDXL: {
      sdxl_refiner_prompt_example: "SDXL Refiner Prompt",
      sdxl_revision_text_prompts: "SDXL Revision Text Prompts",
      sdxl_revision_zero_positive: "SDXL Revision Zero Positive",
      sdxl_simple_example: "SDXL Simple",
      sdxlturbo_example: "SDXL Turbo"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_esrgan_workflow: "HiresFix ESRGAN Workflow",
      hiresfix_latent_workflow: "HiresFix Latent Workflow",
      latent_upscale_different_prompt_model: "Latent Upscale Different Prompt Model"
    },
    Video: {
      hunyuan_video_text_to_video: "Hunyuan Video Text to Video",
      image_to_video: "Изображение в видео",
      image_to_video_wan: "Wan 2.1 Изображение в Видео",
      ltxv_image_to_video: "LTXV Image to Video",
      ltxv_text_to_video: "LTXV Text to Video",
      mochi_text_to_video_example: "Mochi Text to Video",
      text_to_video_wan: "Wan 2.1 Текст в Видео",
      txt_to_image_to_video: "Текст в изображение в видео"
    }
  },
  title: "Начните с шаблона"
};
const userSelect$1 = {
  enterUsername: "Введите имя пользователя",
  existingUser: "Существующий пользователь",
  newUser: "Новый пользователь",
  next: "Далее",
  selectUser: "Выберите пользователя"
};
const welcome$1 = {
  getStarted: "Начать",
  title: "Добро пожаловать в ComfyUI"
};
const workflowService$1 = {
  enterFilename: "Введите название файла",
  exportWorkflow: "Экспорт рабочего процесса",
  saveWorkflow: "Сохранить рабочий процесс"
};
const ru = {
  clipboard: clipboard$1,
  color: color$1,
  contextMenu: contextMenu$1,
  dataTypes: dataTypes$1,
  desktopMenu: desktopMenu$1,
  desktopUpdate: desktopUpdate$1,
  downloadGit: downloadGit$1,
  electronFileDownload: electronFileDownload$1,
  g: g$1,
  graphCanvasMenu: graphCanvasMenu$1,
  groupNode: groupNode$1,
  icon: icon$1,
  install: install$1,
  issueReport: issueReport$1,
  load3d: load3d$1,
  maintenance: maintenance$1,
  manager: manager$1,
  maskEditor: maskEditor$1,
  menu: menu$1,
  menuLabels: menuLabels$1,
  missingModelsDialog: missingModelsDialog$1,
  nodeCategories: nodeCategories$1,
  nodeTemplates: nodeTemplates$1,
  notSupported: notSupported$1,
  serverConfig: serverConfig$1,
  serverConfigCategories: serverConfigCategories$1,
  serverConfigItems: serverConfigItems$1,
  serverStart: serverStart$1,
  settingsCategories: settingsCategories$1,
  sideToolbar: sideToolbar$1,
  tabMenu: tabMenu$1,
  templateWorkflows: templateWorkflows$1,
  userSelect: userSelect$1,
  welcome: welcome$1,
  workflowService: workflowService$1
};
const AddNoise$1 = {
  display_name: "Добавить шум",
  inputs: {
    latent_image: {
      name: "латентное_изображение"
    },
    model: {
      name: "модель"
    },
    noise: {
      name: "шум"
    },
    sigmas: {
      name: "сигмы"
    }
  }
};
const AlignYourStepsScheduler$1 = {
  display_name: "Scheduler выравнивания шагов",
  inputs: {
    denoise: {
      name: "шумоподавление"
    },
    model_type: {
      name: "тип_модели"
    },
    steps: {
      name: "шаги"
    }
  }
};
const BasicGuider$1 = {
  display_name: "Основной гид",
  inputs: {
    conditioning: {
      name: "кондиционирование"
    },
    model: {
      name: "модель"
    }
  }
};
const BasicScheduler$1 = {
  display_name: "Основной scheduler",
  inputs: {
    denoise: {
      name: "шумоподавление"
    },
    model: {
      name: "модель"
    },
    scheduler: {
      name: "scheduler"
    },
    steps: {
      name: "шаги"
    }
  }
};
const BetaSamplingScheduler$1 = {
  display_name: "Scheduler выборки Бета",
  inputs: {
    alpha: {
      name: "альфа"
    },
    beta: {
      name: "бета"
    },
    model: {
      name: "модель"
    },
    steps: {
      name: "шаги"
    }
  }
};
const CFGGuider$1 = {
  display_name: "CFG Гид",
  inputs: {
    cfg: {
      name: "cfg"
    },
    model: {
      name: "модель"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    }
  }
};
const CLIPAttentionMultiply$1 = {
  display_name: "Умножение внимания CLIP",
  inputs: {
    clip: {
      name: "clip"
    },
    k: {
      name: "k"
    },
    out: {
      name: "выход"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const CLIPLoader$1 = {
  description: "[Рецепты]\n\nstable_diffusion: clip-l\nstable_cascade: clip-g\nsd3: t5 / clip-g / clip-l\nstable_audio: t5\nmochi: t5\ncosmos: old t5 xxl",
  display_name: "Загрузить CLIP",
  inputs: {
    clip_name: {
      name: "название_clip"
    },
    device: {
      name: "устройство"
    },
    type: {
      name: "тип"
    }
  }
};
const CLIPMergeAdd$1 = {
  display_name: "Сложение CLIP",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    }
  }
};
const CLIPMergeSimple$1 = {
  display_name: "Простое слияние CLIP",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    ratio: {
      name: "соотношение"
    }
  }
};
const CLIPMergeSubtract$1 = {
  display_name: "Вычитание CLIP",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    multiplier: {
      name: "множитель"
    }
  }
};
const CLIPSave$1 = {
  display_name: "Сохранить CLIP",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    }
  }
};
const CLIPSetLastLayer$1 = {
  display_name: "Установить последний слой CLIP",
  inputs: {
    clip: {
      name: "clip"
    },
    stop_at_clip_layer: {
      name: "остановиться_на_clip_слое"
    }
  }
};
const CLIPTextEncode$1 = {
  description: "Кодирует текстовый запрос с помощью модели CLIP в вектор, который можно использовать для управления моделью диффузии для генерации конкретных изображений.",
  display_name: "Кодирование текста CLIP (Запрос)",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "Модель CLIP, используемая для кодирования текста."
    },
    text: {
      name: "текст",
      tooltip: "Текст для кодирования."
    }
  },
  outputs: {
    "0": {
      tooltip: "Условие, содержащее встроенный текст, используемое для управления моделью диффузии."
    }
  }
};
const CLIPTextEncodeControlnet$1 = {
  display_name: "Кодирование текста CLIP для Controlnet",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning: {
      name: "кондиционирование"
    },
    text: {
      name: "текст"
    }
  }
};
const CLIPTextEncodeFlux$1 = {
  display_name: "Кодирование текста CLIP Flux",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip_l"
    },
    guidance: {
      name: "руководство"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeHunyuanDiT$1 = {
  display_name: "Кодирование текста CLIP HunyuanDiT",
  inputs: {
    bert: {
      name: "bert"
    },
    clip: {
      name: "clip"
    },
    mt5xl: {
      name: "mt5xl"
    }
  }
};
const CLIPTextEncodeLumina2$1 = {
  description: "Кодирует системный запрос и запрос пользователя с помощью модели CLIP во встраиваемый элемент, который можно использовать для направления модели диффузии на генерацию конкретных изображений.",
  display_name: "CLIP Text Encode для Lumina2",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "Модель CLIP, используемая для кодирования текста."
    },
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2 предоставляет два типа системных запросов: Высший: Вы - помощник, разработанный для генерации высококачественных изображений с наивысшей степенью соответствия текста и изображения на основе текстовых запросов или запросов пользователя. Соответствие: Вы - помощник, разработанный для генерации высококачественных изображений с наивысшей степенью соответствия текста и изображения на основе текстовых запросов."
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "Текст для кодирования."
    }
  },
  outputs: {
    "0": {
      tooltip: "Условие, содержащее встроенный текст, используемый для направления модели диффузии."
    }
  }
};
const CLIPTextEncodePixArtAlpha$1 = {
  description: "Кодирует текст и устанавливает условие разрешения для PixArt Alpha. Не применяется к PixArt Sigma.",
  display_name: "CLIPTextEncodePixArtAlpha",
  inputs: {
    clip: {
      name: "clip"
    },
    height: {
      name: "высота"
    },
    text: {
      name: "текст"
    },
    width: {
      name: "ширина"
    }
  }
};
const CLIPTextEncodeSD3$1 = {
  display_name: "Кодирование текста CLIP SD3",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_g: {
      name: "clip_g"
    },
    clip_l: {
      name: "clip_l"
    },
    empty_padding: {
      name: "пустое_заполнение"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeSDXL$1 = {
  display_name: "Кодирование текста CLIP SDXL",
  inputs: {
    clip: {
      name: "clip"
    },
    crop_h: {
      name: "обрезка_высоты"
    },
    crop_w: {
      name: "обрезка_ширины"
    },
    height: {
      name: "высота"
    },
    target_height: {
      name: "целевая_высота"
    },
    target_width: {
      name: "целевая_ширина"
    },
    text_g: {
      name: "текст_g"
    },
    text_l: {
      name: "текст_l"
    },
    width: {
      name: "ширина"
    }
  }
};
const CLIPTextEncodeSDXLRefiner$1 = {
  display_name: "Кодирование текста CLIP SDXL Refinement",
  inputs: {
    ascore: {
      name: "ascore"
    },
    clip: {
      name: "clip"
    },
    height: {
      name: "высота"
    },
    text: {
      name: "текст"
    },
    width: {
      name: "ширина"
    }
  }
};
const CLIPVisionEncode$1 = {
  display_name: "Кодирование видения CLIP",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    crop: {
      name: "обрезка"
    },
    image: {
      name: "изображение"
    }
  }
};
const CLIPVisionLoader$1 = {
  display_name: "Загрузить видение CLIP",
  inputs: {
    clip_name: {
      name: "название_clip"
    }
  }
};
const Canny$1 = {
  display_name: "Canny",
  inputs: {
    high_threshold: {
      name: "верхний_порог"
    },
    image: {
      name: "изображение"
    },
    low_threshold: {
      name: "нижний_порог"
    }
  }
};
const CheckpointLoader$1 = {
  display_name: "Загрузить сheckpoint с конфигурацией (УСТАРЕЛО)",
  inputs: {
    ckpt_name: {
      name: "название_точки_проверки"
    },
    config_name: {
      name: "название_конфигурации"
    }
  }
};
const CheckpointLoaderSimple$1 = {
  description: "Загружает сheckpoint-модели диффузии, модели диффузии используются для удаления шума из латентов.",
  display_name: "Загрузить сheckpoint",
  inputs: {
    ckpt_name: {
      name: "название_точки_проверки",
      tooltip: "Название сheckpoint (модели) для загрузки."
    }
  },
  outputs: {
    "0": {
      tooltip: "Модель, используемая для шумоподавления латентов."
    },
    "1": {
      tooltip: "Модель CLIP, используемая для кодирования текстовых подсказок."
    },
    "2": {
      tooltip: "Модель VAE, используемая для кодирования и декодирования изображений из и в латентное пространство."
    }
  }
};
const CheckpointSave$1 = {
  display_name: "Сохранить сheckpoint",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    model: {
      name: "модель"
    },
    vae: {
      name: "vae"
    }
  }
};
const CombineHooks2$1 = {
  display_name: "Объединить хуки [2]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    }
  }
};
const CombineHooks4$1 = {
  display_name: "Объединить хуки [4]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    }
  }
};
const CombineHooks8$1 = {
  display_name: "Объединить хуки [8]",
  inputs: {
    hooks_A: {
      name: "hooks_A"
    },
    hooks_B: {
      name: "hooks_B"
    },
    hooks_C: {
      name: "hooks_C"
    },
    hooks_D: {
      name: "hooks_D"
    },
    hooks_E: {
      name: "hooks_E"
    },
    hooks_F: {
      name: "hooks_F"
    },
    hooks_G: {
      name: "hooks_G"
    },
    hooks_H: {
      name: "hooks_H"
    }
  }
};
const ConditioningAverage$1 = {
  display_name: "Среднее кондиционирование",
  inputs: {
    conditioning_from: {
      name: "условие_от"
    },
    conditioning_to: {
      name: "условие_к"
    },
    conditioning_to_strength: {
      name: "сила_условия_к"
    }
  }
};
const ConditioningCombine$1 = {
  display_name: "Кондиционирование (Объединение)",
  inputs: {
    conditioning_1: {
      name: "условие_1"
    },
    conditioning_2: {
      name: "условие_2"
    }
  }
};
const ConditioningConcat$1 = {
  display_name: "Кондиционирование (Конкатенация)",
  inputs: {
    conditioning_from: {
      name: "условие_от"
    },
    conditioning_to: {
      name: "условие_к"
    }
  }
};
const ConditioningSetArea$1 = {
  display_name: "Кондиционирование (Установить область)",
  inputs: {
    conditioning: {
      name: "условие"
    },
    height: {
      name: "высота"
    },
    strength: {
      name: "сила"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentage$1 = {
  display_name: "Кондиционирование (Установить область с процентом)",
  inputs: {
    conditioning: {
      name: "условие"
    },
    height: {
      name: "высота"
    },
    strength: {
      name: "сила"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentageVideo$1 = {
  display_name: "УсловныйНаборПроцентПлощадиВидео",
  inputs: {
    conditioning: {
      name: "условие"
    },
    height: {
      name: "высота"
    },
    strength: {
      name: "сила"
    },
    temporal: {
      name: "временной"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    }
  }
};
const ConditioningSetAreaStrength$1 = {
  display_name: "Сила установки области кондиционирования",
  inputs: {
    conditioning: {
      name: "условие"
    },
    strength: {
      name: "сила"
    }
  }
};
const ConditioningSetDefaultCombine$1 = {
  display_name: "Установить значение по умолчанию для объединения кондиционирования",
  inputs: {
    cond: {
      name: "условие"
    },
    cond_DEFAULT: {
      name: "условие_ПО_УМОЛЧАНИЮ"
    },
    hooks: {
      name: "hooks"
    }
  }
};
const ConditioningSetMask$1 = {
  display_name: "Кондиционирование (Установить маску)",
  inputs: {
    conditioning: {
      name: "условие"
    },
    mask: {
      name: "маска"
    },
    set_cond_area: {
      name: "установить_область_условия"
    },
    strength: {
      name: "сила"
    }
  }
};
const ConditioningSetProperties$1 = {
  display_name: "Установить свойства кондиционирования",
  inputs: {
    cond_NEW: {
      name: "новое_условие"
    },
    hooks: {
      name: "хуки"
    },
    mask: {
      name: "маска"
    },
    set_cond_area: {
      name: "установить_область_условия"
    },
    strength: {
      name: "сила"
    },
    timesteps: {
      name: "временные_шаги"
    }
  }
};
const ConditioningSetPropertiesAndCombine$1 = {
  display_name: "Установить свойства кондиционирования и объединить",
  inputs: {
    cond: {
      name: "условие"
    },
    cond_NEW: {
      name: "новое_условие"
    },
    hooks: {
      name: "хуки"
    },
    mask: {
      name: "маска"
    },
    set_cond_area: {
      name: "установить_область_условия"
    },
    strength: {
      name: "сила"
    },
    timesteps: {
      name: "временные_шаги"
    }
  }
};
const ConditioningSetTimestepRange$1 = {
  display_name: "Установить диапазон временных шагов кондиционирования",
  inputs: {
    conditioning: {
      name: "условие"
    },
    end: {
      name: "конец"
    },
    start: {
      name: "начало"
    }
  }
};
const ConditioningStableAudio$1 = {
  display_name: "ConditioningStableAudio",
  inputs: {
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    seconds_start: {
      name: "секунды_начала"
    },
    seconds_total: {
      name: "всего_секунд"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const ConditioningTimestepsRange$1 = {
  display_name: "Диапазон временных шагов",
  inputs: {
    end_percent: {
      name: "процент_конца"
    },
    start_percent: {
      name: "процент_начала"
    }
  },
  outputs: {
    "1": {
      name: "ДО_ДИАПАЗОНА"
    },
    "2": {
      name: "ПОСЛЕ_ДИАПАЗОНА"
    }
  }
};
const ConditioningZeroOut$1 = {
  display_name: "Обнуление кондиционирования",
  inputs: {
    conditioning: {
      name: "условие"
    }
  }
};
const ControlNetApply$1 = {
  display_name: "Применить ControlNet (УСТАРЕЛО)",
  inputs: {
    conditioning: {
      name: "условие"
    },
    control_net: {
      name: "control_net"
    },
    image: {
      name: "изображение"
    },
    strength: {
      name: "сила"
    }
  }
};
const ControlNetApplyAdvanced$1 = {
  display_name: "Применить ControlNet",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "процент_конца"
    },
    image: {
      name: "изображение"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    start_percent: {
      name: "процент_начала"
    },
    strength: {
      name: "сила"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const ControlNetApplySD3$1 = {
  display_name: "Применить ControlNet с VAE",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "процент_конца"
    },
    image: {
      name: "изображение"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    start_percent: {
      name: "процент_начала"
    },
    strength: {
      name: "сила"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const ControlNetInpaintingAliMamaApply$1 = {
  display_name: "Применить ControlNet для инпейнтинга AliMama",
  inputs: {
    control_net: {
      name: "control_net"
    },
    end_percent: {
      name: "процент_конца"
    },
    image: {
      name: "изображение"
    },
    mask: {
      name: "маска"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    start_percent: {
      name: "процент_начала"
    },
    strength: {
      name: "сила"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const ControlNetLoader$1 = {
  display_name: "Загрузить модель ControlNet",
  inputs: {
    control_net_name: {
      name: "название_control_net"
    }
  }
};
const CosmosImageToVideoLatent$1 = {
  display_name: "CosmosImageToVideoLatent",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    end_image: {
      name: "конечное_изображение"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    start_image: {
      name: "начальное_изображение"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  }
};
const CreateHookKeyframe$1 = {
  display_name: "Создать ключевой кадр хука",
  inputs: {
    prev_hook_kf: {
      name: "предыдущий_hook_kf"
    },
    start_percent: {
      name: "процент_начала"
    },
    strength_mult: {
      name: "множитель_силы"
    }
  },
  outputs: {
    "0": {
      name: "КЛЮЧЕВОЙ_КАДР"
    }
  }
};
const CreateHookKeyframesFromFloats$1 = {
  display_name: "Создать ключевые кадры хука из чисел с плавающей запятой",
  inputs: {
    end_percent: {
      name: "процент_конца"
    },
    floats_strength: {
      name: "сила_в_виде_чисел"
    },
    prev_hook_kf: {
      name: "предыдущий_hook_kf"
    },
    print_keyframes: {
      name: "печать_ключевых_кадров"
    },
    start_percent: {
      name: "процент_начала"
    }
  },
  outputs: {
    "0": {
      name: "КЛЮЧЕВОЙ_КАДР"
    }
  }
};
const CreateHookKeyframesInterpolated$1 = {
  display_name: "Создать интерполированные ключевые кадры хука",
  inputs: {
    end_percent: {
      name: "конечный_процент"
    },
    interpolation: {
      name: "интерполяция"
    },
    keyframes_count: {
      name: "количество_ключевых_кадров"
    },
    prev_hook_kf: {
      name: "предыдущий_хук_kf"
    },
    print_keyframes: {
      name: "печать_ключевых_кадров"
    },
    start_percent: {
      name: "начальный_процент"
    },
    strength_end: {
      name: "конечная_сила"
    },
    strength_start: {
      name: "начальная_сила"
    }
  },
  outputs: {
    "0": {
      name: "КЛЮЧЕВОЙ_КАДР"
    }
  }
};
const CreateHookLora$1 = {
  display_name: "Создать хук LoRA",
  inputs: {
    lora_name: {
      name: "название_lora"
    },
    prev_hooks: {
      name: "предыдущие_хуки"
    },
    strength_clip: {
      name: "сила_клипа"
    },
    strength_model: {
      name: "сила_модели"
    }
  }
};
const CreateHookLoraModelOnly$1 = {
  display_name: "Создать хук LoRA (Только модель)",
  inputs: {
    lora_name: {
      name: "название_lora"
    },
    prev_hooks: {
      name: "предыдущие_хуки"
    },
    strength_model: {
      name: "сила_модели"
    }
  }
};
const CreateHookModelAsLora$1 = {
  display_name: "Создать хук модели как LoRA",
  inputs: {
    ckpt_name: {
      name: "название_ckpt"
    },
    prev_hooks: {
      name: "предыдущие_хуки"
    },
    strength_clip: {
      name: "сила_клипа"
    },
    strength_model: {
      name: "сила_модели"
    }
  }
};
const CreateHookModelAsLoraModelOnly$1 = {
  display_name: "Создать хук модели как LoRA (Только модель)",
  inputs: {
    ckpt_name: {
      name: "название_ckpt"
    },
    prev_hooks: {
      name: "предыдущие_хуки"
    },
    strength_model: {
      name: "сила_модели"
    }
  }
};
const CropMask$1 = {
  display_name: "Обрезать маску",
  inputs: {
    height: {
      name: "высота"
    },
    mask: {
      name: "маска"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const DiffControlNetLoader$1 = {
  display_name: "Загрузить модель ControlNet (дифф)",
  inputs: {
    control_net_name: {
      name: "название_control_net"
    },
    model: {
      name: "модель"
    }
  }
};
const DifferentialDiffusion$1 = {
  display_name: "Дифференциальная диффузия",
  inputs: {
    model: {
      name: "модель"
    }
  }
};
const DiffusersLoader$1 = {
  display_name: "Загрузчик диффузоров",
  inputs: {
    model_path: {
      name: "путь_модели"
    }
  }
};
const DisableNoise$1 = {
  display_name: "Отключить шум"
};
const DualCFGGuider$1 = {
  display_name: "Двойной CFG Гид",
  inputs: {
    cfg_cond2_negative: {
      name: "cfg_cond2_negative"
    },
    cfg_conds: {
      name: "cfg_conds"
    },
    cond1: {
      name: "cond1"
    },
    cond2: {
      name: "cond2"
    },
    model: {
      name: "модель"
    },
    negative: {
      name: "отрицательный"
    }
  }
};
const DualCLIPLoader$1 = {
  description: "[Рецепты]\n\nsdxl: clip-l, clip-g\nsd3: clip-l, clip-g / clip-l, t5 / clip-g, t5\nflux: clip-l, t5",
  display_name: "Двойной загрузчик CLIP",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    device: {
      name: "устройство"
    },
    type: {
      name: "тип"
    }
  }
};
const EmptyCosmosLatentVideo$1 = {
  display_name: "EmptyCosmosLatentVideo",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    width: {
      name: "ширина"
    }
  }
};
const EmptyHunyuanLatentVideo$1 = {
  display_name: "Пустой HunyuanLatentVideo",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    width: {
      name: "ширина"
    }
  }
};
const EmptyImage$1 = {
  display_name: "Пустое изображение",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    color: {
      name: "цвет"
    },
    height: {
      name: "высота"
    },
    width: {
      name: "ширина"
    }
  }
};
const EmptyLTXVLatentVideo$1 = {
  display_name: "Пустой LTXVLatentVideo",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    width: {
      name: "ширина"
    }
  }
};
const EmptyLatentAudio$1 = {
  display_name: "Пустой LatentAudio",
  inputs: {
    batch_size: {
      name: "размер_пакета",
      tooltip: "Количество латентных изображений в партии."
    },
    seconds: {
      name: "секунды"
    }
  }
};
const EmptyLatentHunyuan3Dv2$1 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    batch_size: {
      name: "размер_пакета",
      tooltip: "Количество скрытых изображений в пакете."
    },
    resolution: {
      name: "разрешение"
    }
  }
};
const EmptyLatentImage$1 = {
  description: "Создаёт новую партию пустых латентных изображений для удаления шума через выборку.",
  display_name: "Пустое латентное изображение",
  inputs: {
    batch_size: {
      name: "размер_пакета",
      tooltip: "Количество латентных изображений в партии."
    },
    height: {
      name: "высота",
      tooltip: "Высота латентных изображений в пикселях."
    },
    width: {
      name: "ширина",
      tooltip: "Ширина латентных изображений в пикселях."
    }
  },
  outputs: {
    "0": {
      tooltip: "Пустая партия латентных изображений."
    }
  }
};
const EmptyMochiLatentVideo$1 = {
  display_name: "Пустой MochiLatentVideo",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    width: {
      name: "ширина"
    }
  }
};
const EmptySD3LatentImage$1 = {
  display_name: "Пустой SD3LatentImage",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    width: {
      name: "ширина"
    }
  }
};
const ExponentialScheduler$1 = {
  display_name: "Экспоненциальный scheduler",
  inputs: {
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "шаги"
    }
  }
};
const FeatherMask$1 = {
  display_name: "Пернатая маска",
  inputs: {
    bottom: {
      name: "снизу"
    },
    left: {
      name: "слева"
    },
    mask: {
      name: "маска"
    },
    right: {
      name: "справа"
    },
    top: {
      name: "сверху"
    }
  }
};
const FlipSigmas$1 = {
  display_name: "Перевернуть сигмы",
  inputs: {
    sigmas: {
      name: "sigmas"
    }
  }
};
const FluxDisableGuidance$1 = {
  description: "Этот узел полностью отключает встраиваемое руководство на Flux и подобных моделях Flux",
  display_name: "FluxDisableGuidance",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const FluxGuidance$1 = {
  display_name: "Направление Flux",
  inputs: {
    conditioning: {
      name: "условие"
    },
    guidance: {
      name: "руководство"
    }
  }
};
const FreeU$1 = {
  display_name: "FreeU",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "модель"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2$1 = {
  display_name: "FreeU_V2",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "модель"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler$1 = {
  display_name: "GITSScheduler",
  inputs: {
    coeff: {
      name: "коэфф"
    },
    denoise: {
      name: "шумоподавление"
    },
    steps: {
      name: "шаги"
    }
  }
};
const GLIGENLoader$1 = {
  display_name: "Загрузчик GLIGEN",
  inputs: {
    gligen_name: {
      name: "название_gligen"
    }
  }
};
const GLIGENTextBoxApply$1 = {
  display_name: "Применить текстовое поле GLIGEN",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning_to: {
      name: "условие_для"
    },
    gligen_textbox_model: {
      name: "модель_текстового_поля_gligen"
    },
    height: {
      name: "высота"
    },
    text: {
      name: "текст"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask$1 = {
  display_name: "Увеличить маску",
  inputs: {
    expand: {
      name: "расширить"
    },
    mask: {
      name: "маска"
    },
    tapered_corners: {
      name: "заостренные_углы"
    }
  }
};
const Hunyuan3Dv2Conditioning$1 = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "выход_clip_vision"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView$1 = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    back: {
      name: "сзади"
    },
    front: {
      name: "фронт"
    },
    left: {
      name: "слева"
    },
    right: {
      name: "справа"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const HunyuanImageToVideo$1 = {
  display_name: "HunyuanImageToVideo",
  inputs: {
    batch_size: {
      name: "размер пакета"
    },
    guidance_type: {
      name: "тип руководства"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    positive: {
      name: "положительный"
    },
    start_image: {
      name: "начальное изображение"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "скрытое пространство"
    }
  }
};
const HyperTile$1 = {
  display_name: "Гиперплитка",
  inputs: {
    max_depth: {
      name: "максимальная_глубина"
    },
    model: {
      name: "модель"
    },
    scale_depth: {
      name: "масштаб_глубины"
    },
    swap_size: {
      name: "размер_замены"
    },
    tile_size: {
      name: "размер_плитки"
    }
  }
};
const HypernetworkLoader$1 = {
  display_name: "Загрузчик hypernetwork",
  inputs: {
    hypernetwork_name: {
      name: "название_hypernetwork"
    },
    model: {
      name: "модель"
    },
    strength: {
      name: "сила"
    }
  }
};
const ImageBatch$1 = {
  display_name: "Партия изображений",
  inputs: {
    image1: {
      name: "изображение1"
    },
    image2: {
      name: "изображение2"
    }
  }
};
const ImageBlend$1 = {
  display_name: "Смешивание изображений",
  inputs: {
    blend_factor: {
      name: "фактор_смешивания"
    },
    blend_mode: {
      name: "режим_смешивания"
    },
    image1: {
      name: "изображение1"
    },
    image2: {
      name: "изображение2"
    }
  }
};
const ImageBlur$1 = {
  display_name: "Размытие изображения",
  inputs: {
    blur_radius: {
      name: "радиус_размытия"
    },
    image: {
      name: "изображение"
    },
    sigma: {
      name: "сигма"
    }
  }
};
const ImageColorToMask$1 = {
  display_name: "Цвет изображения в маску",
  inputs: {
    color: {
      name: "цвет"
    },
    image: {
      name: "изображение"
    }
  }
};
const ImageCompositeMasked$1 = {
  display_name: "Составное изображение с маской",
  inputs: {
    destination: {
      name: "назначение"
    },
    mask: {
      name: "маска"
    },
    resize_source: {
      name: "изменить_размер_источника"
    },
    source: {
      name: "источник"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageCrop$1 = {
  display_name: "Обрезка изображения",
  inputs: {
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch$1 = {
  display_name: "Изображение из партии",
  inputs: {
    batch_index: {
      name: "индекс_пакета"
    },
    image: {
      name: "изображение"
    },
    length: {
      name: "длина"
    }
  }
};
const ImageInvert$1 = {
  display_name: "Инвертировать изображение",
  inputs: {
    image: {
      name: "изображение"
    }
  }
};
const ImageOnlyCheckpointLoader$1 = {
  display_name: "Загрузчик checkpoint только для изображения (модель img2vid)",
  inputs: {
    ckpt_name: {
      name: "название_ckpt"
    }
  }
};
const ImageOnlyCheckpointSave$1 = {
  display_name: "Сохранить только checkpoint изображения",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    model: {
      name: "модель"
    },
    vae: {
      name: "vae"
    }
  }
};
const ImagePadForOutpaint$1 = {
  display_name: "Добавить поля к изображению для выкрашивания",
  inputs: {
    bottom: {
      name: "снизу"
    },
    feathering: {
      name: "смягчение"
    },
    image: {
      name: "изображение"
    },
    left: {
      name: "слева"
    },
    right: {
      name: "справа"
    },
    top: {
      name: "сверху"
    }
  }
};
const ImageQuantize$1 = {
  display_name: "Квантизация изображения",
  inputs: {
    colors: {
      name: "цвета"
    },
    dither: {
      name: "дизеринг"
    },
    image: {
      name: "изображение"
    }
  }
};
const ImageScale$1 = {
  display_name: "Масштабировать изображение",
  inputs: {
    crop: {
      name: "обрезка"
    },
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    upscale_method: {
      name: "метод_увеличения"
    },
    width: {
      name: "ширина"
    }
  }
};
const ImageScaleBy$1 = {
  display_name: "Масштабировать изображение на",
  inputs: {
    image: {
      name: "изображение"
    },
    scale_by: {
      name: "увеличить_на"
    },
    upscale_method: {
      name: "метод_апскейла"
    }
  }
};
const ImageScaleToTotalPixels$1 = {
  display_name: "Масштабировать изображение до общего количества пикселей",
  inputs: {
    image: {
      name: "изображение"
    },
    megapixels: {
      name: "мегапиксели"
    },
    upscale_method: {
      name: "метод_апскейла"
    }
  }
};
const ImageSharpen$1 = {
  display_name: "Резкость изображения",
  inputs: {
    alpha: {
      name: "альфа"
    },
    image: {
      name: "изображение"
    },
    sharpen_radius: {
      name: "радиус_резкости"
    },
    sigma: {
      name: "сигма"
    }
  }
};
const ImageToMask$1 = {
  display_name: "Преобразовать изображение в маску",
  inputs: {
    channel: {
      name: "канал"
    },
    image: {
      name: "изображение"
    }
  }
};
const ImageUpscaleWithModel$1 = {
  display_name: "Апскейл изображения (с использованием модели)",
  inputs: {
    image: {
      name: "изображение"
    },
    upscale_model: {
      name: "модель_апскейла"
    }
  }
};
const InpaintModelConditioning$1 = {
  display_name: "Кондиционирование модели инпейнтинга",
  inputs: {
    mask: {
      name: "маска"
    },
    negative: {
      name: "отрицательный"
    },
    noise_mask: {
      name: "шумовая_маска",
      tooltip: "Добавьте маску шума к латентному изображению, чтобы выборка происходила только в пределах маски. Это может улучшить результаты или полностью испортить их в зависимости от модели."
    },
    pixels: {
      name: "пиксели"
    },
    positive: {
      name: "положительный"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const InstructPixToPixConditioning$1 = {
  display_name: "Кондиционирование PixToPix",
  inputs: {
    negative: {
      name: "отрицательный"
    },
    pixels: {
      name: "пиксели"
    },
    positive: {
      name: "положительный"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const InvertMask$1 = {
  display_name: "Инвертировать маску",
  inputs: {
    mask: {
      name: "маска"
    }
  }
};
const JoinImageWithAlpha$1 = {
  display_name: "Объединить изображение с альфа-каналом",
  inputs: {
    alpha: {
      name: "альфа"
    },
    image: {
      name: "изображение"
    }
  }
};
const KSampler$1 = {
  description: "Использует предоставленную модель, положительное и отрицательное кондиционирование для удаления шума из латентного изображения.",
  display_name: "KSampler",
  inputs: {
    cfg: {
      name: "cfg",
      tooltip: "Масштаб без классификатора балансирует креативность и соблюдение запроса. Более высокие значения приводят к изображениям, более точно соответствующим запросу, однако слишком высокие значения негативно скажутся на качестве."
    },
    control_after_generate: {
      name: "control after generate"
    },
    denoise: {
      name: "шумоподавление",
      tooltip: "Количество уменьшения шума, более низкие значения сохранят структуру начального изображения, позволяя выборку изображений."
    },
    latent_image: {
      name: "латентное_изображение",
      tooltip: "Латентное изображение для уменьшения шума."
    },
    model: {
      name: "модель",
      tooltip: "Модель, используемая для уменьшения шума входного латентного изображения."
    },
    negative: {
      name: "отрицательный",
      tooltip: "Условие, описывающее атрибуты, которые вы хотите исключить из изображения."
    },
    positive: {
      name: "положительный",
      tooltip: "Условие, описывающее атрибуты, которые вы хотите включить в изображение."
    },
    sampler_name: {
      name: "название_сэмплера",
      tooltip: "Алгоритм, используемый при выборке, это может повлиять на качество, скорость и стиль сгенерированного вывода."
    },
    scheduler: {
      name: "scheduler",
      tooltip: "Scheduler контролирует, как шум постепенно удаляется для формирования изображения."
    },
    seed: {
      name: "сид",
      tooltip: "Случайный сид, используемый для создания шума."
    },
    steps: {
      name: "шаги",
      tooltip: "Количество шагов, используемых в процессе уменьшения шума."
    }
  },
  outputs: {
    "0": {
      tooltip: "шумоподавленный латент."
    }
  }
};
const KSamplerAdvanced$1 = {
  display_name: "KSampler (Расширенный)",
  inputs: {
    add_noise: {
      name: "добавить_шум"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "control after generate"
    },
    end_at_step: {
      name: "закончить_на_шаге"
    },
    latent_image: {
      name: "латентное_изображение"
    },
    model: {
      name: "модель"
    },
    negative: {
      name: "отрицательный"
    },
    noise_seed: {
      name: "сид_шума"
    },
    positive: {
      name: "положительный"
    },
    return_with_leftover_noise: {
      name: "вернуться_с_оставшимся_шумом"
    },
    sampler_name: {
      name: "название_сэмплера"
    },
    scheduler: {
      name: "scheduler"
    },
    start_at_step: {
      name: "начать_с_шага"
    },
    steps: {
      name: "шаги"
    }
  }
};
const KSamplerSelect$1 = {
  display_name: "Выбор KSampler",
  inputs: {
    sampler_name: {
      name: "название_сэмплера"
    }
  }
};
const KarrasScheduler$1 = {
  display_name: "Scheduler Карраса",
  inputs: {
    rho: {
      name: "ро"
    },
    sigma_max: {
      name: "максимальное_сигма"
    },
    sigma_min: {
      name: "минимальное_сигма"
    },
    steps: {
      name: "шаги"
    }
  }
};
const LTXVAddGuide$1 = {
  display_name: "LTXVAddGuide",
  inputs: {
    frame_idx: {
      name: "индекс кадра",
      tooltip: "Индекс кадра для начала условия. Для однокадровых изображений или видео с 1-8 кадрами любое значение frame_idx приемлемо. Для видео с 9+ кадрами, frame_idx должен быть кратен 8, в противном случае он будет округлен вниз до ближайшего кратного 8. Отрицательные значения считаются с конца видео."
    },
    image: {
      name: "изображение",
      tooltip: "Изображение или видео для условия скрытого видео. Должно быть 8*n + 1 кадров. Если видео не 8*n + 1 кадров, оно будет обрезано до ближайших 8*n + 1 кадров."
    },
    latent: {
      name: "скрытое пространство"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    strength: {
      name: "сила"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "скрытое пространство"
    }
  }
};
const LTXVConditioning$1 = {
  display_name: "Кондиционирование LTXV",
  inputs: {
    frame_rate: {
      name: "частота_кадров"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const LTXVCropGuides$1 = {
  display_name: "LTXVCropGuides",
  inputs: {
    latent: {
      name: "скрытое пространство"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "скрытое пространство"
    }
  }
};
const LTXVImgToVideo$1 = {
  display_name: "LTXVImgToVideo",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    length: {
      name: "длина"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const LTXVPreprocess$1 = {
  display_name: "LTXVPreprocess",
  inputs: {
    image: {
      name: "изображение"
    },
    img_compression: {
      name: "сжатие изображения",
      tooltip: "Степень сжатия, применяемая к изображению."
    }
  },
  outputs: {
    "0": {
      name: "выходное изображение"
    }
  }
};
const LTXVScheduler$1 = {
  display_name: "Scheduler LTXV",
  inputs: {
    base_shift: {
      name: "базовое_смещение"
    },
    latent: {
      name: "скрытый"
    },
    max_shift: {
      name: "максимальное_смещение"
    },
    steps: {
      name: "шаги"
    },
    stretch: {
      name: "растяжение",
      tooltip: "Растянуть сигмы, чтобы они находились в диапазоне [terminal, 1]."
    },
    terminal: {
      name: "терминал",
      tooltip: "Конечное значение сигм после растяжения."
    }
  }
};
const LaplaceScheduler$1 = {
  display_name: "Scheduler Лапласа",
  inputs: {
    beta: {
      name: "бета"
    },
    mu: {
      name: "мю"
    },
    sigma_max: {
      name: "максимальное_сигма"
    },
    sigma_min: {
      name: "минимальное_сигма"
    },
    steps: {
      name: "шаги"
    }
  }
};
const LatentAdd$1 = {
  display_name: "Добавить латент",
  inputs: {
    samples1: {
      name: "образцы1"
    },
    samples2: {
      name: "образцы2"
    }
  }
};
const LatentApplyOperation$1 = {
  display_name: "Применить операцию к латенту",
  inputs: {
    operation: {
      name: "операция"
    },
    samples: {
      name: "образцы"
    }
  }
};
const LatentApplyOperationCFG$1 = {
  display_name: "Применить операцию к латенту CFG",
  inputs: {
    model: {
      name: "модель"
    },
    operation: {
      name: "операция"
    }
  }
};
const LatentBatch$1 = {
  display_name: "Партия латентов",
  inputs: {
    samples1: {
      name: "образцы1"
    },
    samples2: {
      name: "образцы2"
    }
  }
};
const LatentBatchSeedBehavior$1 = {
  display_name: "Поведение сида партии латентов",
  inputs: {
    samples: {
      name: "образцы"
    },
    seed_behavior: {
      name: "поведение_сида"
    }
  }
};
const LatentBlend$1 = {
  display_name: "Смешивание латентов",
  inputs: {
    blend_factor: {
      name: "фактор_смешивания"
    },
    samples1: {
      name: "образцы1"
    },
    samples2: {
      name: "образцы2"
    }
  }
};
const LatentComposite$1 = {
  display_name: "Составной латент",
  inputs: {
    feather: {
      name: "перо"
    },
    samples_from: {
      name: "образцы_из"
    },
    samples_to: {
      name: "образцы_для"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCompositeMasked$1 = {
  display_name: "Составной латент с маской",
  inputs: {
    destination: {
      name: "назначение"
    },
    mask: {
      name: "маска"
    },
    resize_source: {
      name: "изменить_размер_источника"
    },
    source: {
      name: "источник"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCrop$1 = {
  display_name: "Обрезка латента",
  inputs: {
    height: {
      name: "высота"
    },
    samples: {
      name: "образцы"
    },
    width: {
      name: "ширина"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip$1 = {
  display_name: "Перевернуть латент",
  inputs: {
    flip_method: {
      name: "метод_отражения"
    },
    samples: {
      name: "образцы"
    }
  }
};
const LatentFromBatch$1 = {
  display_name: "Латент из партии",
  inputs: {
    batch_index: {
      name: "индекс_пакета"
    },
    length: {
      name: "длина"
    },
    samples: {
      name: "образцы"
    }
  }
};
const LatentInterpolate$1 = {
  display_name: "Интерполяция латента",
  inputs: {
    ratio: {
      name: "соотношение"
    },
    samples1: {
      name: "образцы1"
    },
    samples2: {
      name: "образцы2"
    }
  }
};
const LatentMultiply$1 = {
  display_name: "Умножить латент",
  inputs: {
    multiplier: {
      name: "множитель"
    },
    samples: {
      name: "образцы"
    }
  }
};
const LatentOperationSharpen$1 = {
  display_name: "Операция латента: резкость",
  inputs: {
    alpha: {
      name: "альфа"
    },
    sharpen_radius: {
      name: "радиус_резкости"
    },
    sigma: {
      name: "сигма"
    }
  }
};
const LatentOperationTonemapReinhard$1 = {
  display_name: "Операция латента: тональная карта Рейнхарда",
  inputs: {
    multiplier: {
      name: "множитель"
    }
  }
};
const LatentRotate$1 = {
  display_name: "Повернуть латент",
  inputs: {
    rotation: {
      name: "вращение"
    },
    samples: {
      name: "образцы"
    }
  }
};
const LatentSubtract$1 = {
  display_name: "Вычесть латент",
  inputs: {
    samples1: {
      name: "образцы1"
    },
    samples2: {
      name: "образцы2"
    }
  }
};
const LatentUpscale$1 = {
  display_name: "Увеличить латент",
  inputs: {
    crop: {
      name: "обрезка"
    },
    height: {
      name: "высота"
    },
    samples: {
      name: "образцы"
    },
    upscale_method: {
      name: "метод_апскейла"
    },
    width: {
      name: "ширина"
    }
  }
};
const LatentUpscaleBy$1 = {
  display_name: "Увеличить латент на",
  inputs: {
    samples: {
      name: "образцы"
    },
    scale_by: {
      name: "масштабировать_по"
    },
    upscale_method: {
      name: "метод_апскейла"
    }
  }
};
const Load3D$1 = {
  display_name: "Загрузить 3D",
  inputs: {
    clear: {},
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    model_file: {
      name: "файл_модели"
    },
    "upload 3d model": {},
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "изображение"
    },
    "1": {
      name: "маска"
    },
    "2": {
      name: "путь_сетки"
    }
  }
};
const Load3DAnimation$1 = {
  display_name: "Загрузить 3D — Анимация",
  inputs: {
    clear: {},
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    model_file: {
      name: "файл_модели"
    },
    "upload 3d model": {},
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "изображение"
    },
    "1": {
      name: "маска"
    },
    "2": {
      name: "путь_сетки"
    }
  }
};
const LoadAudio$1 = {
  display_name: "Загрузить аудио",
  inputs: {
    audio: {
      name: "аудио"
    },
    audioUI: {
      name: "audioUI"
    },
    upload: {
      name: "выберите файл для загрузки"
    }
  }
};
const LoadImage$1 = {
  display_name: "Загрузить изображение",
  inputs: {
    image: {
      name: "изображение"
    },
    upload: {
      name: "выберите файл для загрузки"
    }
  }
};
const LoadImageMask$1 = {
  display_name: "Загрузить изображение (как маску)",
  inputs: {
    channel: {
      name: "канал"
    },
    image: {
      name: "изображение"
    },
    upload: {
      name: "выберите файл для загрузки"
    }
  }
};
const LoadImageOutput$1 = {
  description: "Загрузите изображение из папки вывода. При нажатии кнопки обновления, узел обновит список изображений и автоматически выберет первое изображение, что позволяет легко итерировать.",
  display_name: "Загрузить изображение (из выходных данных)",
  inputs: {
    image: {
      name: "изображение"
    },
    refresh: {},
    upload: {
      name: "выберите файл для загрузки"
    }
  }
};
const LoadLatent$1 = {
  display_name: "Загрузить латент",
  inputs: {
    latent: {
      name: "скрытый"
    }
  }
};
const LoraLoader$1 = {
  description: "LoRA используются для изменения моделей диффузии и CLIP, изменяя способ, которым латенты удаляются от шума, например, применяя стили. Несколько нод LoRA могут быть связаны вместе.",
  display_name: "Загрузить LoRA",
  inputs: {
    clip: {
      name: "клип",
      tooltip: "Модель CLIP, к которой будет применена LoRA."
    },
    lora_name: {
      name: "название_lora",
      tooltip: "Название LoRA."
    },
    model: {
      name: "модель",
      tooltip: "Диффузионная модель, к которой будет применена LoRA."
    },
    strength_clip: {
      name: "сила_клипа",
      tooltip: "Насколько сильно модифицировать модель CLIP. Это значение может быть отрицательным."
    },
    strength_model: {
      name: "сила_модели",
      tooltip: "Насколько сильно модифицировать диффузионную модель. Это значение может быть отрицательным."
    }
  },
  outputs: {
    "0": {
      tooltip: "Модифицированная модель диффузии."
    },
    "1": {
      tooltip: "Модифицированная модель CLIP."
    }
  }
};
const LoraLoaderModelOnly$1 = {
  description: "LoRA используются для изменения моделей диффузии и CLIP, изменяя способ, которым латенты удаляются от шума, например, применяя стили. Несколько нод LoRA могут быть связаны вместе.",
  display_name: "Загрузчик LoRA (Только модель)",
  inputs: {
    lora_name: {
      name: "название_lora"
    },
    model: {
      name: "модель"
    },
    strength_model: {
      name: "сила_модели"
    }
  },
  outputs: {
    "0": {
      tooltip: "Модифицированная модель диффузии."
    }
  }
};
const LoraSave$1 = {
  display_name: "Извлечь и сохранить LoRA",
  inputs: {
    bias_diff: {
      name: "разница_смещения"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    lora_type: {
      name: "тип_lora"
    },
    model_diff: {
      name: "разница_модели",
      tooltip: "Вывод ModelSubtract, который будет преобразован в lora."
    },
    rank: {
      name: "ранг"
    },
    text_encoder_diff: {
      name: "разница_текстового_кодировщика",
      tooltip: "Вывод CLIPSubtract, который будет преобразован в lora."
    }
  }
};
const Mahiro$1 = {
  description: "Измените руководство, чтобы оно больше масштабировалось в «направлении» положительной подсказки, а не разницы между отрицательной подсказкой.",
  display_name: "Mahiro настолько мила, что заслуживает лучшей функции руководства!! (。・ω・。)",
  inputs: {
    model: {
      name: "модель"
    }
  },
  outputs: {
    "0": {
      name: "исправленная_модель"
    }
  }
};
const MaskComposite$1 = {
  display_name: "Составная маска",
  inputs: {
    destination: {
      name: "назначение"
    },
    operation: {
      name: "операция"
    },
    source: {
      name: "источник"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const MaskToImage$1 = {
  display_name: "Преобразовать маску в изображение",
  inputs: {
    mask: {
      name: "маска"
    }
  }
};
const ModelComputeDtype$1 = {
  display_name: "ModelComputeDtype",
  inputs: {
    dtype: {
      name: "dtype"
    },
    model: {
      name: "модель"
    }
  }
};
const ModelMergeAdd$1 = {
  display_name: "Слияние моделей",
  inputs: {
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    }
  }
};
const ModelMergeAuraflow$1 = {
  display_name: "Слияние моделей Auraflow",
  inputs: {
    cond_seq_linear_: {
      name: "cond_seq_linear."
    },
    double_layers_0_: {
      name: "double_layers.0."
    },
    double_layers_1_: {
      name: "double_layers.1."
    },
    double_layers_2_: {
      name: "double_layers.2."
    },
    double_layers_3_: {
      name: "double_layers.3."
    },
    final_linear_: {
      name: "final_linear."
    },
    init_x_linear_: {
      name: "init_x_linear."
    },
    modF_: {
      name: "modF."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    positional_encoding: {
      name: "позиционное кодирование"
    },
    register_tokens: {
      name: "регистрация токенов"
    },
    single_layers_0_: {
      name: "single_layers.0."
    },
    single_layers_10_: {
      name: "single_layers.10."
    },
    single_layers_11_: {
      name: "single_layers.11."
    },
    single_layers_12_: {
      name: "single_layers.12."
    },
    single_layers_13_: {
      name: "single_layers.13."
    },
    single_layers_14_: {
      name: "single_layers.14."
    },
    single_layers_15_: {
      name: "single_layers.15."
    },
    single_layers_16_: {
      name: "single_layers.16."
    },
    single_layers_17_: {
      name: "single_layers.17."
    },
    single_layers_18_: {
      name: "single_layers.18."
    },
    single_layers_19_: {
      name: "single_layers.19."
    },
    single_layers_1_: {
      name: "single_layers.1."
    },
    single_layers_20_: {
      name: "single_layers.20."
    },
    single_layers_21_: {
      name: "single_layers.21."
    },
    single_layers_22_: {
      name: "single_layers.22."
    },
    single_layers_23_: {
      name: "single_layers.23."
    },
    single_layers_24_: {
      name: "single_layers.24."
    },
    single_layers_25_: {
      name: "single_layers.25."
    },
    single_layers_26_: {
      name: "single_layers.26."
    },
    single_layers_27_: {
      name: "single_layers.27."
    },
    single_layers_28_: {
      name: "single_layers.28."
    },
    single_layers_29_: {
      name: "single_layers.29."
    },
    single_layers_2_: {
      name: "single_layers.2."
    },
    single_layers_30_: {
      name: "single_layers.30."
    },
    single_layers_31_: {
      name: "single_layers.31."
    },
    single_layers_3_: {
      name: "single_layers.3."
    },
    single_layers_4_: {
      name: "single_layers.4."
    },
    single_layers_5_: {
      name: "single_layers.5."
    },
    single_layers_6_: {
      name: "single_layers.6."
    },
    single_layers_7_: {
      name: "single_layers.7."
    },
    single_layers_8_: {
      name: "single_layers.8."
    },
    single_layers_9_: {
      name: "single_layers.9."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeBlocks$1 = {
  display_name: "Слияние блоков моделей",
  inputs: {
    input: {
      name: "вход"
    },
    middle: {
      name: "середина"
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    out: {
      name: "выход"
    }
  }
};
const ModelMergeCosmos14B$1 = {
  display_name: "ModelMergeCosmos14B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeCosmos7B$1 = {
  display_name: "ModelMergeCosmos7B",
  inputs: {
    affline_norm_: {
      name: "affline_norm."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "extra_pos_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "model1"
    },
    model2: {
      name: "model2"
    },
    pos_embedder_: {
      name: "pos_embedder."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    }
  }
};
const ModelMergeFlux1$1 = {
  display_name: "Слияние моделей Flux1",
  inputs: {
    double_blocks_0_: {
      name: "double_blocks.0."
    },
    double_blocks_10_: {
      name: "double_blocks.10."
    },
    double_blocks_11_: {
      name: "double_blocks.11."
    },
    double_blocks_12_: {
      name: "double_blocks.12."
    },
    double_blocks_13_: {
      name: "double_blocks.13."
    },
    double_blocks_14_: {
      name: "double_blocks.14."
    },
    double_blocks_15_: {
      name: "double_blocks.15."
    },
    double_blocks_16_: {
      name: "double_blocks.16."
    },
    double_blocks_17_: {
      name: "double_blocks.17."
    },
    double_blocks_18_: {
      name: "double_blocks.18."
    },
    double_blocks_1_: {
      name: "double_blocks.1."
    },
    double_blocks_2_: {
      name: "double_blocks.2."
    },
    double_blocks_3_: {
      name: "double_blocks.3."
    },
    double_blocks_4_: {
      name: "double_blocks.4."
    },
    double_blocks_5_: {
      name: "double_blocks.5."
    },
    double_blocks_6_: {
      name: "double_blocks.6."
    },
    double_blocks_7_: {
      name: "double_blocks.7."
    },
    double_blocks_8_: {
      name: "double_blocks.8."
    },
    double_blocks_9_: {
      name: "double_blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    guidance_in: {
      name: "guidance_in"
    },
    img_in_: {
      name: "img_in."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    single_blocks_0_: {
      name: "single_blocks.0."
    },
    single_blocks_10_: {
      name: "single_blocks.10."
    },
    single_blocks_11_: {
      name: "single_blocks.11."
    },
    single_blocks_12_: {
      name: "single_blocks.12."
    },
    single_blocks_13_: {
      name: "single_blocks.13."
    },
    single_blocks_14_: {
      name: "single_blocks.14."
    },
    single_blocks_15_: {
      name: "single_blocks.15."
    },
    single_blocks_16_: {
      name: "single_blocks.16."
    },
    single_blocks_17_: {
      name: "single_blocks.17."
    },
    single_blocks_18_: {
      name: "single_blocks.18."
    },
    single_blocks_19_: {
      name: "single_blocks.19."
    },
    single_blocks_1_: {
      name: "single_blocks.1."
    },
    single_blocks_20_: {
      name: "single_blocks.20."
    },
    single_blocks_21_: {
      name: "single_blocks.21."
    },
    single_blocks_22_: {
      name: "single_blocks.22."
    },
    single_blocks_23_: {
      name: "single_blocks.23."
    },
    single_blocks_24_: {
      name: "single_blocks.24."
    },
    single_blocks_25_: {
      name: "single_blocks.25."
    },
    single_blocks_26_: {
      name: "single_blocks.26."
    },
    single_blocks_27_: {
      name: "single_blocks.27."
    },
    single_blocks_28_: {
      name: "single_blocks.28."
    },
    single_blocks_29_: {
      name: "single_blocks.29."
    },
    single_blocks_2_: {
      name: "single_blocks.2."
    },
    single_blocks_30_: {
      name: "single_blocks.30."
    },
    single_blocks_31_: {
      name: "single_blocks.31."
    },
    single_blocks_32_: {
      name: "single_blocks.32."
    },
    single_blocks_33_: {
      name: "single_blocks.33."
    },
    single_blocks_34_: {
      name: "single_blocks.34."
    },
    single_blocks_35_: {
      name: "single_blocks.35."
    },
    single_blocks_36_: {
      name: "single_blocks.36."
    },
    single_blocks_37_: {
      name: "single_blocks.37."
    },
    single_blocks_3_: {
      name: "single_blocks.3."
    },
    single_blocks_4_: {
      name: "single_blocks.4."
    },
    single_blocks_5_: {
      name: "single_blocks.5."
    },
    single_blocks_6_: {
      name: "single_blocks.6."
    },
    single_blocks_7_: {
      name: "single_blocks.7."
    },
    single_blocks_8_: {
      name: "single_blocks.8."
    },
    single_blocks_9_: {
      name: "single_blocks.9."
    },
    time_in_: {
      name: "time_in."
    },
    txt_in_: {
      name: "txt_in."
    },
    vector_in_: {
      name: "vector_in."
    }
  }
};
const ModelMergeLTXV$1 = {
  display_name: "Слияние моделей LTXV",
  inputs: {
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "caption_projection."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    proj_out_: {
      name: "proj_out."
    },
    scale_shift_table: {
      name: "scale_shift_table"
    },
    transformer_blocks_0_: {
      name: "transformer_blocks.0."
    },
    transformer_blocks_10_: {
      name: "transformer_blocks.10."
    },
    transformer_blocks_11_: {
      name: "transformer_blocks.11."
    },
    transformer_blocks_12_: {
      name: "transformer_blocks.12."
    },
    transformer_blocks_13_: {
      name: "transformer_blocks.13."
    },
    transformer_blocks_14_: {
      name: "transformer_blocks.14."
    },
    transformer_blocks_15_: {
      name: "transformer_blocks.15."
    },
    transformer_blocks_16_: {
      name: "transformer_blocks.16."
    },
    transformer_blocks_17_: {
      name: "transformer_blocks.17."
    },
    transformer_blocks_18_: {
      name: "transformer_blocks.18."
    },
    transformer_blocks_19_: {
      name: "transformer_blocks.19."
    },
    transformer_blocks_1_: {
      name: "transformer_blocks.1."
    },
    transformer_blocks_20_: {
      name: "transformer_blocks.20."
    },
    transformer_blocks_21_: {
      name: "transformer_blocks.21."
    },
    transformer_blocks_22_: {
      name: "transformer_blocks.22."
    },
    transformer_blocks_23_: {
      name: "transformer_blocks.23."
    },
    transformer_blocks_24_: {
      name: "transformer_blocks.24."
    },
    transformer_blocks_25_: {
      name: "transformer_blocks.25."
    },
    transformer_blocks_26_: {
      name: "transformer_blocks.26."
    },
    transformer_blocks_27_: {
      name: "transformer_blocks.27."
    },
    transformer_blocks_2_: {
      name: "transformer_blocks.2."
    },
    transformer_blocks_3_: {
      name: "transformer_blocks.3."
    },
    transformer_blocks_4_: {
      name: "transformer_blocks.4."
    },
    transformer_blocks_5_: {
      name: "transformer_blocks.5."
    },
    transformer_blocks_6_: {
      name: "transformer_blocks.6."
    },
    transformer_blocks_7_: {
      name: "transformer_blocks.7."
    },
    transformer_blocks_8_: {
      name: "transformer_blocks.8."
    },
    transformer_blocks_9_: {
      name: "transformer_blocks.9."
    }
  }
};
const ModelMergeMochiPreview$1 = {
  display_name: "Предварительный просмотр слияния моделей Mochi",
  inputs: {
    blocks_0_: {
      name: "blocks.0."
    },
    blocks_10_: {
      name: "blocks.10."
    },
    blocks_11_: {
      name: "blocks.11."
    },
    blocks_12_: {
      name: "blocks.12."
    },
    blocks_13_: {
      name: "blocks.13."
    },
    blocks_14_: {
      name: "blocks.14."
    },
    blocks_15_: {
      name: "blocks.15."
    },
    blocks_16_: {
      name: "blocks.16."
    },
    blocks_17_: {
      name: "blocks.17."
    },
    blocks_18_: {
      name: "blocks.18."
    },
    blocks_19_: {
      name: "blocks.19."
    },
    blocks_1_: {
      name: "blocks.1."
    },
    blocks_20_: {
      name: "blocks.20."
    },
    blocks_21_: {
      name: "blocks.21."
    },
    blocks_22_: {
      name: "blocks.22."
    },
    blocks_23_: {
      name: "blocks.23."
    },
    blocks_24_: {
      name: "blocks.24."
    },
    blocks_25_: {
      name: "blocks.25."
    },
    blocks_26_: {
      name: "blocks.26."
    },
    blocks_27_: {
      name: "blocks.27."
    },
    blocks_28_: {
      name: "blocks.28."
    },
    blocks_29_: {
      name: "blocks.29."
    },
    blocks_2_: {
      name: "blocks.2."
    },
    blocks_30_: {
      name: "blocks.30."
    },
    blocks_31_: {
      name: "blocks.31."
    },
    blocks_32_: {
      name: "blocks.32."
    },
    blocks_33_: {
      name: "blocks.33."
    },
    blocks_34_: {
      name: "blocks.34."
    },
    blocks_35_: {
      name: "blocks.35."
    },
    blocks_36_: {
      name: "blocks.36."
    },
    blocks_37_: {
      name: "blocks.37."
    },
    blocks_38_: {
      name: "blocks.38."
    },
    blocks_39_: {
      name: "blocks.39."
    },
    blocks_3_: {
      name: "blocks.3."
    },
    blocks_40_: {
      name: "blocks.40."
    },
    blocks_41_: {
      name: "blocks.41."
    },
    blocks_42_: {
      name: "blocks.42."
    },
    blocks_43_: {
      name: "blocks.43."
    },
    blocks_44_: {
      name: "blocks.44."
    },
    blocks_45_: {
      name: "blocks.45."
    },
    blocks_46_: {
      name: "blocks.46."
    },
    blocks_47_: {
      name: "blocks.47."
    },
    blocks_4_: {
      name: "blocks.4."
    },
    blocks_5_: {
      name: "blocks.5."
    },
    blocks_6_: {
      name: "blocks.6."
    },
    blocks_7_: {
      name: "blocks.7."
    },
    blocks_8_: {
      name: "blocks.8."
    },
    blocks_9_: {
      name: "blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    pos_frequencies_: {
      name: "pos_frequencies."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeSD1$1 = {
  display_name: "Слияние моделей SD1",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD2$1 = {
  display_name: "Слияние моделей SD2",
  inputs: {
    input_blocks_0_: {
      name: "input_blocks.0."
    },
    input_blocks_10_: {
      name: "input_blocks.10."
    },
    input_blocks_11_: {
      name: "input_blocks.11."
    },
    input_blocks_1_: {
      name: "input_blocks.1."
    },
    input_blocks_2_: {
      name: "input_blocks.2."
    },
    input_blocks_3_: {
      name: "input_blocks.3."
    },
    input_blocks_4_: {
      name: "input_blocks.4."
    },
    input_blocks_5_: {
      name: "input_blocks.5."
    },
    input_blocks_6_: {
      name: "input_blocks.6."
    },
    input_blocks_7_: {
      name: "input_blocks.7."
    },
    input_blocks_8_: {
      name: "input_blocks.8."
    },
    input_blocks_9_: {
      name: "input_blocks.9."
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0_: {
      name: "middle_block.0."
    },
    middle_block_1_: {
      name: "middle_block.1."
    },
    middle_block_2_: {
      name: "middle_block.2."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0_: {
      name: "output_blocks.0."
    },
    output_blocks_10_: {
      name: "output_blocks.10."
    },
    output_blocks_11_: {
      name: "output_blocks.11."
    },
    output_blocks_1_: {
      name: "output_blocks.1."
    },
    output_blocks_2_: {
      name: "output_blocks.2."
    },
    output_blocks_3_: {
      name: "output_blocks.3."
    },
    output_blocks_4_: {
      name: "output_blocks.4."
    },
    output_blocks_5_: {
      name: "output_blocks.5."
    },
    output_blocks_6_: {
      name: "output_blocks.6."
    },
    output_blocks_7_: {
      name: "output_blocks.7."
    },
    output_blocks_8_: {
      name: "output_blocks.8."
    },
    output_blocks_9_: {
      name: "output_blocks.9."
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSD35_Large$1 = {
  display_name: "Слияние моделей SD35_Large",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_24_: {
      name: "joint_blocks.24."
    },
    joint_blocks_25_: {
      name: "joint_blocks.25."
    },
    joint_blocks_26_: {
      name: "joint_blocks.26."
    },
    joint_blocks_27_: {
      name: "joint_blocks.27."
    },
    joint_blocks_28_: {
      name: "joint_blocks.28."
    },
    joint_blocks_29_: {
      name: "joint_blocks.29."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_30_: {
      name: "joint_blocks.30."
    },
    joint_blocks_31_: {
      name: "joint_blocks.31."
    },
    joint_blocks_32_: {
      name: "joint_blocks.32."
    },
    joint_blocks_33_: {
      name: "joint_blocks.33."
    },
    joint_blocks_34_: {
      name: "joint_blocks.34."
    },
    joint_blocks_35_: {
      name: "joint_blocks.35."
    },
    joint_blocks_36_: {
      name: "joint_blocks.36."
    },
    joint_blocks_37_: {
      name: "joint_blocks.37."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSD3_2B$1 = {
  display_name: "Слияние моделей SD3_2B",
  inputs: {
    context_embedder_: {
      name: "context_embedder."
    },
    final_layer_: {
      name: "final_layer."
    },
    joint_blocks_0_: {
      name: "joint_blocks.0."
    },
    joint_blocks_10_: {
      name: "joint_blocks.10."
    },
    joint_blocks_11_: {
      name: "joint_blocks.11."
    },
    joint_blocks_12_: {
      name: "joint_blocks.12."
    },
    joint_blocks_13_: {
      name: "joint_blocks.13."
    },
    joint_blocks_14_: {
      name: "joint_blocks.14."
    },
    joint_blocks_15_: {
      name: "joint_blocks.15."
    },
    joint_blocks_16_: {
      name: "joint_blocks.16."
    },
    joint_blocks_17_: {
      name: "joint_blocks.17."
    },
    joint_blocks_18_: {
      name: "joint_blocks.18."
    },
    joint_blocks_19_: {
      name: "joint_blocks.19."
    },
    joint_blocks_1_: {
      name: "joint_blocks.1."
    },
    joint_blocks_20_: {
      name: "joint_blocks.20."
    },
    joint_blocks_21_: {
      name: "joint_blocks.21."
    },
    joint_blocks_22_: {
      name: "joint_blocks.22."
    },
    joint_blocks_23_: {
      name: "joint_blocks.23."
    },
    joint_blocks_2_: {
      name: "joint_blocks.2."
    },
    joint_blocks_3_: {
      name: "joint_blocks.3."
    },
    joint_blocks_4_: {
      name: "joint_blocks.4."
    },
    joint_blocks_5_: {
      name: "joint_blocks.5."
    },
    joint_blocks_6_: {
      name: "joint_blocks.6."
    },
    joint_blocks_7_: {
      name: "joint_blocks.7."
    },
    joint_blocks_8_: {
      name: "joint_blocks.8."
    },
    joint_blocks_9_: {
      name: "joint_blocks.9."
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    pos_embed_: {
      name: "pos_embed."
    },
    t_embedder_: {
      name: "t_embedder."
    },
    x_embedder_: {
      name: "x_embedder."
    },
    y_embedder_: {
      name: "y_embedder."
    }
  }
};
const ModelMergeSDXL$1 = {
  display_name: "Слияние моделей SDXL",
  inputs: {
    input_blocks_0: {
      name: "input_blocks.0"
    },
    input_blocks_1: {
      name: "input_blocks.1"
    },
    input_blocks_2: {
      name: "input_blocks.2"
    },
    input_blocks_3: {
      name: "input_blocks.3"
    },
    input_blocks_4: {
      name: "input_blocks.4"
    },
    input_blocks_5: {
      name: "input_blocks.5"
    },
    input_blocks_6: {
      name: "input_blocks.6"
    },
    input_blocks_7: {
      name: "input_blocks.7"
    },
    input_blocks_8: {
      name: "input_blocks.8"
    },
    label_emb_: {
      name: "label_emb."
    },
    middle_block_0: {
      name: "middle_block.0"
    },
    middle_block_1: {
      name: "middle_block.1"
    },
    middle_block_2: {
      name: "middle_block.2"
    },
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    out_: {
      name: "out."
    },
    output_blocks_0: {
      name: "output_blocks.0"
    },
    output_blocks_1: {
      name: "output_blocks.1"
    },
    output_blocks_2: {
      name: "output_blocks.2"
    },
    output_blocks_3: {
      name: "output_blocks.3"
    },
    output_blocks_4: {
      name: "output_blocks.4"
    },
    output_blocks_5: {
      name: "output_blocks.5"
    },
    output_blocks_6: {
      name: "output_blocks.6"
    },
    output_blocks_7: {
      name: "output_blocks.7"
    },
    output_blocks_8: {
      name: "output_blocks.8"
    },
    time_embed_: {
      name: "time_embed."
    }
  }
};
const ModelMergeSimple$1 = {
  display_name: "Простое слияние моделей",
  inputs: {
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    ratio: {
      name: "соотношение"
    }
  }
};
const ModelMergeSubtract$1 = {
  display_name: "Вычитание моделей",
  inputs: {
    model1: {
      name: "модель1"
    },
    model2: {
      name: "модель2"
    },
    multiplier: {
      name: "множитель"
    }
  }
};
const ModelSamplingAuraFlow$1 = {
  display_name: "Выборка модели AuraFlow",
  inputs: {
    model: {
      name: "модель"
    },
    shift: {
      name: "сдвиг"
    }
  }
};
const ModelSamplingContinuousEDM$1 = {
  display_name: "Выборка модели Continuous EDM",
  inputs: {
    model: {
      name: "модель"
    },
    sampling: {
      name: "выборка"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingContinuousV$1 = {
  display_name: "Выборка модели Continuous V",
  inputs: {
    model: {
      name: "модель"
    },
    sampling: {
      name: "выборка"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    }
  }
};
const ModelSamplingDiscrete$1 = {
  display_name: "Дискретная выборка модели",
  inputs: {
    model: {
      name: "модель"
    },
    sampling: {
      name: "выборка"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux$1 = {
  display_name: "Выборка модели Flux",
  inputs: {
    base_shift: {
      name: "базовый_сдвиг"
    },
    height: {
      name: "высота"
    },
    max_shift: {
      name: "макс_сдвиг"
    },
    model: {
      name: "модель"
    },
    width: {
      name: "ширина"
    }
  }
};
const ModelSamplingLTXV$1 = {
  display_name: "Выборка модели LTXV",
  inputs: {
    base_shift: {
      name: "базовый_сдвиг"
    },
    latent: {
      name: "скрытый"
    },
    max_shift: {
      name: "макс_сдвиг"
    },
    model: {
      name: "модель"
    }
  }
};
const ModelSamplingSD3$1 = {
  display_name: "Выборка модели SD3",
  inputs: {
    model: {
      name: "модель"
    },
    shift: {
      name: "сдвиг"
    }
  }
};
const ModelSamplingStableCascade$1 = {
  display_name: "Выборка модели Stable Cascade",
  inputs: {
    model: {
      name: "модель"
    },
    shift: {
      name: "сдвиг"
    }
  }
};
const ModelSave$1 = {
  display_name: "Сохранить модель",
  inputs: {
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    model: {
      name: "модель"
    }
  }
};
const Morphology$1 = {
  display_name: "Морфология изображения",
  inputs: {
    image: {
      name: "изображение"
    },
    kernel_size: {
      name: "размер_ядра"
    },
    operation: {
      name: "операция"
    }
  }
};
const PairConditioningCombine$1 = {
  display_name: "Объединение пар кондиционирования",
  inputs: {
    negative_A: {
      name: "отрицательный_A"
    },
    negative_B: {
      name: "отрицательный_B"
    },
    positive_A: {
      name: "положительный_A"
    },
    positive_B: {
      name: "положительный_B"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const PairConditioningSetDefaultCombine$1 = {
  display_name: "Установить значение по умолчанию для объединения пар кондиционирования",
  inputs: {
    hooks: {
      name: "хуки"
    },
    negative: {
      name: "отрицательный"
    },
    negative_DEFAULT: {
      name: "отрицательный_ПО_УМОЛЧАНИЮ"
    },
    positive: {
      name: "положительный"
    },
    positive_DEFAULT: {
      name: "положительный_ПО_УМОЛЧАНИЮ"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const PairConditioningSetProperties$1 = {
  display_name: "Установить свойства пар кондиционирования",
  inputs: {
    hooks: {
      name: "хуки"
    },
    mask: {
      name: "маска"
    },
    negative_NEW: {
      name: "отрицательный_НОВЫЙ"
    },
    positive_NEW: {
      name: "положительный_НОВЫЙ"
    },
    set_cond_area: {
      name: "установить_область_условия"
    },
    strength: {
      name: "сила"
    },
    timesteps: {
      name: "временные_шаги"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const PairConditioningSetPropertiesAndCombine$1 = {
  display_name: "Установить свойства пар кондиционирования и объединить",
  inputs: {
    hooks: {
      name: "хуки"
    },
    mask: {
      name: "маска"
    },
    negative: {
      name: "отрицательный"
    },
    negative_NEW: {
      name: "отрицательный_НОВЫЙ"
    },
    positive: {
      name: "положительный"
    },
    positive_NEW: {
      name: "положительный_НОВЫЙ"
    },
    set_cond_area: {
      name: "установить_область_условия"
    },
    strength: {
      name: "сила"
    },
    timesteps: {
      name: "временные_шаги"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    }
  }
};
const PatchModelAddDownscale$1 = {
  display_name: "Добавить уменьшение модели патча (Kohya Deep Shrink)",
  inputs: {
    block_number: {
      name: "номер_блока"
    },
    downscale_after_skip: {
      name: "уменьшение_после_пропуска"
    },
    downscale_factor: {
      name: "коэффициент_уменьшения"
    },
    downscale_method: {
      name: "метод_уменьшения"
    },
    end_percent: {
      name: "конечный_процент"
    },
    model: {
      name: "модель"
    },
    start_percent: {
      name: "начальный_процент"
    },
    upscale_method: {
      name: "метод_увеличения"
    }
  }
};
const PerpNeg$1 = {
  display_name: "PerpNeg (УСТАРЕЛО из-за PerpNegGuider)",
  inputs: {
    empty_conditioning: {
      name: "пустое_условие"
    },
    model: {
      name: "модель"
    },
    neg_scale: {
      name: "масштаб_отриц"
    }
  }
};
const PerpNegGuider$1 = {
  display_name: "PerpNegGuider",
  inputs: {
    cfg: {
      name: "cfg"
    },
    empty_conditioning: {
      name: "пустое_условие"
    },
    model: {
      name: "модель"
    },
    neg_scale: {
      name: "масштаб_отриц"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    }
  }
};
const PerturbedAttentionGuidance$1 = {
  display_name: "Направление с учётом возмущений",
  inputs: {
    model: {
      name: "модель"
    },
    scale: {
      name: "масштаб"
    }
  }
};
const PhotoMakerEncode$1 = {
  display_name: "Кодирование PhotoMaker",
  inputs: {
    clip: {
      name: "clip"
    },
    image: {
      name: "изображение"
    },
    photomaker: {
      name: "photomaker"
    },
    text: {
      name: "текст"
    }
  }
};
const PhotoMakerLoader$1 = {
  display_name: "Загрузчик PhotoMaker",
  inputs: {
    photomaker_model_name: {
      name: "название_модели_photomaker"
    }
  }
};
const PolyexponentialScheduler$1 = {
  display_name: "Полиэкспоненциальный scheduler",
  inputs: {
    rho: {
      name: "ро"
    },
    sigma_max: {
      name: "макс_сигма"
    },
    sigma_min: {
      name: "мин_сигма"
    },
    steps: {
      name: "шаги"
    }
  }
};
const PorterDuffImageComposite$1 = {
  display_name: "Составное изображение Портера-Даффа",
  inputs: {
    destination: {
      name: "назначение"
    },
    destination_alpha: {
      name: "альфа_назначения"
    },
    mode: {
      name: "режим"
    },
    source: {
      name: "источник"
    },
    source_alpha: {
      name: "альфа_источника"
    }
  }
};
const Preview3D$1 = {
  display_name: "Предварительный просмотр 3D",
  inputs: {
    image: {
      name: "изображение"
    },
    model_file: {
      name: "файл_модели"
    }
  }
};
const Preview3DAnimation$1 = {
  display_name: "Предварительный просмотр 3D - Анимация",
  inputs: {
    image: {
      name: "изображение"
    },
    model_file: {
      name: "файл_модели"
    }
  }
};
const PreviewAudio$1 = {
  display_name: "Предварительное прослушивание аудио",
  inputs: {
    audio: {
      name: "аудио"
    },
    audioUI: {
      name: "audioUI"
    }
  }
};
const PreviewImage$1 = {
  description: "Сохраняет входные изображения в вашу директорию вывода ComfyUI.",
  display_name: "Предварительный просмотр изображения",
  inputs: {
    images: {
      name: "изображения"
    }
  }
};
const RandomNoise$1 = {
  display_name: "Случайный шум",
  inputs: {
    control_after_generate: {
      name: "контроль_после_генерации"
    },
    noise_seed: {
      name: "сид_шума"
    }
  }
};
const RebatchImages$1 = {
  display_name: "Перепаковать изображения",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    images: {
      name: "изображения"
    }
  }
};
const RebatchLatents$1 = {
  display_name: "Перепаковать латенты",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    latents: {
      name: "латенты"
    }
  }
};
const RenormCFG$1 = {
  display_name: "RenormCFG",
  inputs: {
    cfg_trunc: {
      name: "cfg_trunc"
    },
    model: {
      name: "модель"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch$1 = {
  display_name: "Повторить партию изображений",
  inputs: {
    amount: {
      name: "количество"
    },
    image: {
      name: "изображение"
    }
  }
};
const RepeatLatentBatch$1 = {
  display_name: "Повторить партию латентов",
  inputs: {
    amount: {
      name: "количество"
    },
    samples: {
      name: "образцы"
    }
  }
};
const RescaleCFG$1 = {
  display_name: "Масштабировать CFG",
  inputs: {
    model: {
      name: "модель"
    },
    multiplier: {
      name: "множитель"
    }
  }
};
const SDTurboScheduler$1 = {
  display_name: "Scheduler SDTurbo",
  inputs: {
    denoise: {
      name: "шумоподавление"
    },
    model: {
      name: "модель"
    },
    steps: {
      name: "шаги"
    }
  }
};
const SD_4XUpscale_Conditioning$1 = {
  display_name: "SD_4XUpscale_Conditioning",
  inputs: {
    images: {
      name: "изображения"
    },
    negative: {
      name: "отрицательный"
    },
    noise_augmentation: {
      name: "шумовое_увеличение"
    },
    positive: {
      name: "положительный"
    },
    scale_ratio: {
      name: "коэффициент_масштабирования"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const SV3D_Conditioning$1 = {
  display_name: "SV3D_Кондиционирование",
  inputs: {
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "высота"
    },
    height: {
      name: "высота"
    },
    init_image: {
      name: "начальное_изображение"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "кадры_видео"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const SVD_img2vid_Conditioning$1 = {
  display_name: "SVD_img2vid_Кондиционирование",
  inputs: {
    augmentation_level: {
      name: "уровень_аугментации"
    },
    clip_vision: {
      name: "clip_vision"
    },
    fps: {
      name: "fps"
    },
    height: {
      name: "высота"
    },
    init_image: {
      name: "init_image"
    },
    motion_bucket_id: {
      name: "id_корзины_движения"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "кадры_видео"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const SamplerCustom$1 = {
  display_name: "Пользовательский выборщик",
  inputs: {
    add_noise: {
      name: "добавить_шум"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "контроль после генерации"
    },
    latent_image: {
      name: "латентное_изображение"
    },
    model: {
      name: "модель"
    },
    negative: {
      name: "отрицательный"
    },
    noise_seed: {
      name: "сид_шума"
    },
    positive: {
      name: "положительный"
    },
    sampler: {
      name: "сэмплер"
    },
    sigmas: {
      name: "сигмы"
    }
  },
  outputs: {
    "0": {
      name: "выход"
    },
    "1": {
      name: "очищенный_выход"
    }
  }
};
const SamplerCustomAdvanced$1 = {
  display_name: "Пользовательский сэмплер (Расширенный)",
  inputs: {
    guider: {
      name: "гид"
    },
    latent_image: {
      name: "латентное_изображение"
    },
    noise: {
      name: "шум"
    },
    sampler: {
      name: "сэмплер"
    },
    sigmas: {
      name: "сигмы"
    }
  },
  outputs: {
    "0": {
      name: "выход"
    },
    "1": {
      name: "очищенный_выход"
    }
  }
};
const SamplerDPMAdaptative$1 = {
  display_name: "Адаптивный сэмплер DPM",
  inputs: {
    accept_safety: {
      name: "accept_safety"
    },
    atol: {
      name: "atol"
    },
    dcoeff: {
      name: "dcoeff"
    },
    eta: {
      name: "eta"
    },
    h_init: {
      name: "h_init"
    },
    icoeff: {
      name: "icoeff"
    },
    order: {
      name: "порядок"
    },
    pcoeff: {
      name: "pcoeff"
    },
    rtol: {
      name: "rtol"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_2M_SDE$1 = {
  display_name: "Сэмплер DPMPP_2M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "устройство_шума"
    },
    s_noise: {
      name: "s_noise"
    },
    solver_type: {
      name: "тип_решателя"
    }
  }
};
const SamplerDPMPP_2S_Ancestral$1 = {
  display_name: "Сэмплер DPMPP_2S_Ancestral",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_3M_SDE$1 = {
  display_name: "Сэмплер DPMPP_3M_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "устройство_шума"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_SDE$1 = {
  display_name: "Сэмплер DPMPP_SDE",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "устройство_шума"
    },
    r: {
      name: "r"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestral$1 = {
  display_name: "Сэмплер Эйлера (Анастр.)",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestralCFGPP$1 = {
  display_name: "Сэмплер Эйлера (Анастр.) CFG++",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerCFGpp$1 = {
  display_name: "Сэмплер Эйлера CFG++",
  inputs: {
    version: {
      name: "версия"
    }
  }
};
const SamplerLCMUpscale$1 = {
  display_name: "Сэмплер LCM Upscale",
  inputs: {
    scale_ratio: {
      name: "коэффициент_масштабирования"
    },
    scale_steps: {
      name: "шаги_масштабирования"
    },
    upscale_method: {
      name: "метод_масштабирования"
    }
  }
};
const SamplerLMS$1 = {
  display_name: "Сэмплер LMS",
  inputs: {
    order: {
      name: "порядок"
    }
  }
};
const SaveAnimatedPNG$1 = {
  display_name: "Сохранить анимированный PNG",
  inputs: {
    compress_level: {
      name: "уровень_сжатия"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "изображения"
    }
  }
};
const SaveAnimatedWEBP$1 = {
  display_name: "Сохранить анимированный WEBP",
  inputs: {
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "изображения"
    },
    lossless: {
      name: "без_потерь"
    },
    method: {
      name: "метод"
    },
    quality: {
      name: "качество"
    }
  }
};
const SaveAudio$1 = {
  display_name: "Сохранить аудио",
  inputs: {
    audio: {
      name: "аудио"
    },
    audioUI: {
      name: "audioUI"
    },
    filename_prefix: {
      name: "префикс_названия_файла"
    }
  }
};
const SaveGLB$1 = {
  display_name: "SaveGLB",
  inputs: {
    filename_prefix: {
      name: "префикс_имени_файла"
    },
    image: {
      name: "изображение"
    },
    mesh: {
      name: "сетка"
    }
  }
};
const SaveImage$1 = {
  description: "Сохраняет входные изображения в вашу директорию вывода ComfyUI.",
  display_name: "Сохранить изображение",
  inputs: {
    filename_prefix: {
      name: "префикс_названия_файла",
      tooltip: "Префикс для файла, который нужно сохранить. Это может включать информацию о форматировании, такую как %date:yyyy-MM-dd% или %Empty Latent Image.width%, чтобы включить значения из нод."
    },
    images: {
      name: "изображения",
      tooltip: "Изображения_для_сохранения."
    }
  }
};
const SaveImageWebsocket$1 = {
  display_name: "Сохранить изображение через веб-сокет",
  inputs: {
    images: {
      name: "изображения"
    }
  }
};
const SaveLatent$1 = {
  display_name: "Сохранить латент",
  inputs: {
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    samples: {
      name: "образцы"
    }
  }
};
const SaveWEBM$1 = {
  display_name: "SaveWEBM",
  inputs: {
    codec: {
      name: "кодек"
    },
    crf: {
      name: "crf",
      tooltip: "Большее значение crf означает нижнее качество с меньшим размером файла, меньшее значение crf означает высшее качество большего размера файла."
    },
    filename_prefix: {
      name: "префикс_имени_файла"
    },
    fps: {
      name: "fps"
    },
    images: {
      name: "изображения"
    }
  }
};
const SelfAttentionGuidance$1 = {
  display_name: "Направление самовнимания",
  inputs: {
    blur_sigma: {
      name: "сигма_размытия"
    },
    model: {
      name: "модель"
    },
    scale: {
      name: "масштаб"
    }
  }
};
const SetClipHooks$1 = {
  display_name: "Установить хуки CLIP",
  inputs: {
    apply_to_conds: {
      name: "применить_к_условиям"
    },
    clip: {
      name: "клип"
    },
    hooks: {
      name: "хуки"
    },
    schedule_clip: {
      name: "schedule_clip"
    }
  }
};
const SetFirstSigma$1 = {
  display_name: "SetFirstSigma",
  inputs: {
    sigma: {
      name: "сигма"
    },
    sigmas: {
      name: "сигмы"
    }
  }
};
const SetHookKeyframes$1 = {
  display_name: "Установить ключевые кадры хука",
  inputs: {
    hook_kf: {
      name: "ключевые_кадры_хука"
    },
    hooks: {
      name: "хуки"
    }
  }
};
const SetLatentNoiseMask$1 = {
  display_name: "Установить маску шума латента",
  inputs: {
    mask: {
      name: "маска"
    },
    samples: {
      name: "образцы"
    }
  }
};
const SetUnionControlNetType$1 = {
  display_name: "Установить тип объединенного ControlNet",
  inputs: {
    control_net: {
      name: "control_net"
    },
    type: {
      name: "тип"
    }
  }
};
const SkipLayerGuidanceDiT$1 = {
  description: "Универсальная версия ноды SkipLayerGuidance, которую можно использовать на любой модели DiT.",
  display_name: "Пропустить руководство по слоям DiT",
  inputs: {
    double_layers: {
      name: "двойные_слои"
    },
    end_percent: {
      name: "конечный_процент"
    },
    model: {
      name: "модель"
    },
    rescaling_scale: {
      name: "масштаб_перемасштабирования"
    },
    scale: {
      name: "масштаб"
    },
    single_layers: {
      name: "одиночные_слои"
    },
    start_percent: {
      name: "начальный_процент"
    }
  }
};
const SkipLayerGuidanceSD3$1 = {
  description: "Универсальная версия ноды SkipLayerGuidance, которую можно использовать на любой модели DiT.",
  display_name: "Пропустить руководство по слоям SD3",
  inputs: {
    end_percent: {
      name: "конечный_процент"
    },
    layers: {
      name: "слои"
    },
    model: {
      name: "модель"
    },
    scale: {
      name: "масштаб"
    },
    start_percent: {
      name: "начальный_процент"
    }
  }
};
const SolidMask$1 = {
  display_name: "Сплошная маска",
  inputs: {
    height: {
      name: "высота"
    },
    value: {
      name: "значение"
    },
    width: {
      name: "ширина"
    }
  }
};
const SplitImageWithAlpha$1 = {
  display_name: "Разделить изображение с альфа-каналом",
  inputs: {
    image: {
      name: "изображение"
    }
  }
};
const SplitSigmas$1 = {
  display_name: "Разделить сигмы",
  inputs: {
    sigmas: {
      name: "сигмы"
    },
    step: {
      name: "шаг"
    }
  },
  outputs: {
    "0": {
      name: "высокие_сигмы"
    },
    "1": {
      name: "низкие_сигмы"
    }
  }
};
const SplitSigmasDenoise$1 = {
  display_name: "Разделить сигмы для удаления шума",
  inputs: {
    denoise: {
      name: "шумоподавление"
    },
    sigmas: {
      name: "сигмы"
    }
  },
  outputs: {
    "0": {
      name: "высокие_сигмы"
    },
    "1": {
      name: "низкие_сигмы"
    }
  }
};
const StableCascade_EmptyLatentImage$1 = {
  display_name: "StableCascade_Пустое латентное изображение",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    compression: {
      name: "сжатие"
    },
    height: {
      name: "высота"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "этап_c"
    },
    "1": {
      name: "этап_b"
    }
  }
};
const StableCascade_StageB_Conditioning$1 = {
  display_name: "StableCascade_Этап B_Кондиционирование",
  inputs: {
    conditioning: {
      name: "кондиционирование"
    },
    stage_c: {
      name: "стадия_c"
    }
  }
};
const StableCascade_StageC_VAEEncode$1 = {
  display_name: "StableCascade_Этап C_VAE Кодирование",
  inputs: {
    compression: {
      name: "сжатие"
    },
    image: {
      name: "изображение"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "этап_c"
    },
    "1": {
      name: "этап_b"
    }
  }
};
const StableCascade_SuperResolutionControlnet$1 = {
  display_name: "StableCascade_Суперразрешение Controlnet",
  inputs: {
    image: {
      name: "изображение"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "вход_controlnet"
    },
    "1": {
      name: "этап_c"
    },
    "2": {
      name: "этап_b"
    }
  }
};
const StableZero123_Conditioning$1 = {
  display_name: "StableZero123_Кондиционирование",
  inputs: {
    azimuth: {
      name: "азимут"
    },
    batch_size: {
      name: "размер_пакета"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "высота"
    },
    height: {
      name: "высота"
    },
    init_image: {
      name: "начальное_изображение"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const StableZero123_Conditioning_Batched$1 = {
  display_name: "StableZero123_Кондиционирование_Пакетное",
  inputs: {
    azimuth: {
      name: "азимут"
    },
    azimuth_batch_increment: {
      name: "инкремент_азимута_пакета"
    },
    batch_size: {
      name: "размер_пакета"
    },
    clip_vision: {
      name: "clip_vision"
    },
    elevation: {
      name: "высота"
    },
    elevation_batch_increment: {
      name: "инкремент_высоты_пакета"
    },
    height: {
      name: "высота"
    },
    init_image: {
      name: "начальное_изображение"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "латентный"
    }
  }
};
const StyleModelApply$1 = {
  display_name: "Применить модель стиля",
  inputs: {
    clip_vision_output: {
      name: "выход_clip_vision"
    },
    conditioning: {
      name: "кондиционирование"
    },
    strength: {
      name: "сила"
    },
    strength_type: {
      name: "тип_силы"
    },
    style_model: {
      name: "модель_стиля"
    }
  }
};
const StyleModelLoader$1 = {
  display_name: "Загрузить модель стиля",
  inputs: {
    style_model_name: {
      name: "название_модели_стиля"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo$1 = {
  display_name: "TextEncodeHunyuanVideo_ImageToVideo",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_vision_output: {
      name: "выход clip_vision"
    },
    image_interleave: {
      name: "перемежение изображения",
      tooltip: "Насколько сильно изображение влияет на текстовую подсказку. Чем выше число, тем больше влияние от текстовой подсказки."
    },
    prompt: {
      name: "подсказка"
    }
  }
};
const ThresholdMask$1 = {
  display_name: "Пороговая маска",
  inputs: {
    mask: {
      name: "маска"
    },
    value: {
      name: "значение"
    }
  }
};
const TomePatchModel$1 = {
  display_name: "Модель патча Tome",
  inputs: {
    model: {
      name: "модель"
    },
    ratio: {
      name: "соотношение"
    }
  }
};
const TorchCompileModel$1 = {
  display_name: "Скомпилировать модель Torch",
  inputs: {
    backend: {
      name: "бэкенд"
    },
    model: {
      name: "модель"
    }
  }
};
const TripleCLIPLoader$1 = {
  description: "[Рецепты]\n\nsd3: clip-l, clip-g, t5",
  display_name: "Тройной загрузчик CLIP",
  inputs: {
    clip_name1: {
      name: "clip_name1"
    },
    clip_name2: {
      name: "clip_name2"
    },
    clip_name3: {
      name: "clip_name3"
    }
  }
};
const UNETLoader$1 = {
  display_name: "Загрузить модель диффузии",
  inputs: {
    unet_name: {
      name: "название_unet"
    },
    weight_dtype: {
      name: "тип_данных_веса"
    }
  }
};
const UNetCrossAttentionMultiply$1 = {
  display_name: "Умножение перекрёстного внимания UNet",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "модель"
    },
    out: {
      name: "выход"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetSelfAttentionMultiply$1 = {
  display_name: "Умножение самовнимания UNet",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "модель"
    },
    out: {
      name: "выход"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetTemporalAttentionMultiply$1 = {
  display_name: "Умножение временного внимания UNet",
  inputs: {
    cross_structural: {
      name: "кросс-структурный"
    },
    cross_temporal: {
      name: "кросс-временной"
    },
    model: {
      name: "модель"
    },
    self_structural: {
      name: "самоструктурный"
    },
    self_temporal: {
      name: "самовременный"
    }
  }
};
const UpscaleModelLoader$1 = {
  display_name: "Загрузить модель апскейла",
  inputs: {
    model_name: {
      name: "название_модели"
    }
  }
};
const VAEDecode$1 = {
  description: "Декодирует латентные изображения обратно в изображения в пиксельном пространстве.",
  display_name: "Декодировать VAE",
  inputs: {
    samples: {
      name: "образцы",
      tooltip: "Латентное изображение для декодирования."
    },
    vae: {
      name: "vae",
      tooltip: "Модель VAE, используемая для декодирования латентного изображения."
    }
  },
  outputs: {
    "0": {
      tooltip: "Декодированное изображение."
    }
  }
};
const VAEDecodeAudio$1 = {
  display_name: "Декодировать аудио VAE",
  inputs: {
    samples: {
      name: "образцы"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D$1 = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    num_chunks: {
      name: "количество_частей"
    },
    octree_resolution: {
      name: "разрешение_октодерева"
    },
    samples: {
      name: "образцы"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeTiled$1 = {
  display_name: "Декодировать VAE (плитками)",
  inputs: {
    overlap: {
      name: "перекрытие"
    },
    samples: {
      name: "образцы"
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "Используется только для видео VAE: количество кадров для перекрытия."
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "Используется только для видео VAE: количество кадров для декодирования за раз."
    },
    tile_size: {
      name: "размер_плитки"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncode$1 = {
  display_name: "Кодировать VAE",
  inputs: {
    pixels: {
      name: "пиксели"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio$1 = {
  display_name: "Кодировать аудио VAE",
  inputs: {
    audio: {
      name: "аудио"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint$1 = {
  display_name: "Кодировать VAE (для инпейнтинга)",
  inputs: {
    grow_mask_by: {
      name: "увеличить_маску_на"
    },
    mask: {
      name: "маска"
    },
    pixels: {
      name: "пиксели"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeTiled$1 = {
  display_name: "Кодировать VAE (плитками)",
  inputs: {
    overlap: {
      name: "перекрытие"
    },
    pixels: {
      name: "пиксели"
    },
    temporal_overlap: {
      name: "temporal_overlap",
      tooltip: "Используется только для видео VAEs: количество кадров для перекрытия."
    },
    temporal_size: {
      name: "temporal_size",
      tooltip: "Используется только для видео VAEs: количество кадров для кодирования за один раз."
    },
    tile_size: {
      name: "размер_плитки"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAELoader$1 = {
  display_name: "Загрузить VAE",
  inputs: {
    vae_name: {
      name: "название_vae"
    }
  }
};
const VAESave$1 = {
  display_name: "Сохранить VAE",
  inputs: {
    filename_prefix: {
      name: "префикс_названия_файла"
    },
    vae: {
      name: "vae"
    }
  }
};
const VPScheduler$1 = {
  display_name: "VPScheduler",
  inputs: {
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    },
    steps: {
      name: "шаги"
    }
  }
};
const VideoLinearCFGGuidance$1 = {
  display_name: "Направление Video Linear CFG",
  inputs: {
    min_cfg: {
      name: "мин_cfg"
    },
    model: {
      name: "модель"
    }
  }
};
const VideoTriangleCFGGuidance$1 = {
  display_name: "Направление Video Triangle CFG",
  inputs: {
    min_cfg: {
      name: "мин_cfg"
    },
    model: {
      name: "модель"
    }
  }
};
const VoxelToMeshBasic$1 = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    threshold: {
      name: "порог"
    },
    voxel: {
      name: "воксель"
    }
  }
};
const WanImageToVideo$1 = {
  display_name: "WanИзображениеВВидео",
  inputs: {
    batch_size: {
      name: "размер_пакета"
    },
    clip_vision_output: {
      name: "clip_vision_output"
    },
    height: {
      name: "высота"
    },
    length: {
      name: "длина"
    },
    negative: {
      name: "отрицательный"
    },
    positive: {
      name: "положительный"
    },
    start_image: {
      name: "начальное_изображение"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "ширина"
    }
  },
  outputs: {
    "0": {
      name: "положительный"
    },
    "1": {
      name: "отрицательный"
    },
    "2": {
      name: "latent"
    }
  }
};
const WebcamCapture$1 = {
  display_name: "Захват с веб-камеры",
  inputs: {
    capture_on_queue: {
      name: "захват_в_очереди"
    },
    height: {
      name: "высота"
    },
    image: {
      name: "изображение"
    },
    "waiting for camera___": {},
    width: {
      name: "ширина"
    }
  }
};
const unCLIPCheckpointLoader$1 = {
  display_name: "Загрузчик контрольной точки unCLIP",
  inputs: {
    ckpt_name: {
      name: "название_ckpt"
    }
  }
};
const unCLIPConditioning$1 = {
  display_name: "unCLIP кондиционирование",
  inputs: {
    clip_vision_output: {
      name: "выход_clip_vision"
    },
    conditioning: {
      name: "условие"
    },
    noise_augmentation: {
      name: "аугментация_шума"
    },
    strength: {
      name: "сила"
    }
  }
};
const ruNodes = {
  AddNoise: AddNoise$1,
  AlignYourStepsScheduler: AlignYourStepsScheduler$1,
  BasicGuider: BasicGuider$1,
  BasicScheduler: BasicScheduler$1,
  BetaSamplingScheduler: BetaSamplingScheduler$1,
  CFGGuider: CFGGuider$1,
  CLIPAttentionMultiply: CLIPAttentionMultiply$1,
  CLIPLoader: CLIPLoader$1,
  CLIPMergeAdd: CLIPMergeAdd$1,
  CLIPMergeSimple: CLIPMergeSimple$1,
  CLIPMergeSubtract: CLIPMergeSubtract$1,
  CLIPSave: CLIPSave$1,
  CLIPSetLastLayer: CLIPSetLastLayer$1,
  CLIPTextEncode: CLIPTextEncode$1,
  CLIPTextEncodeControlnet: CLIPTextEncodeControlnet$1,
  CLIPTextEncodeFlux: CLIPTextEncodeFlux$1,
  CLIPTextEncodeHunyuanDiT: CLIPTextEncodeHunyuanDiT$1,
  CLIPTextEncodeLumina2: CLIPTextEncodeLumina2$1,
  CLIPTextEncodePixArtAlpha: CLIPTextEncodePixArtAlpha$1,
  CLIPTextEncodeSD3: CLIPTextEncodeSD3$1,
  CLIPTextEncodeSDXL: CLIPTextEncodeSDXL$1,
  CLIPTextEncodeSDXLRefiner: CLIPTextEncodeSDXLRefiner$1,
  CLIPVisionEncode: CLIPVisionEncode$1,
  CLIPVisionLoader: CLIPVisionLoader$1,
  Canny: Canny$1,
  CheckpointLoader: CheckpointLoader$1,
  CheckpointLoaderSimple: CheckpointLoaderSimple$1,
  CheckpointSave: CheckpointSave$1,
  CombineHooks2: CombineHooks2$1,
  CombineHooks4: CombineHooks4$1,
  CombineHooks8: CombineHooks8$1,
  ConditioningAverage: ConditioningAverage$1,
  ConditioningCombine: ConditioningCombine$1,
  ConditioningConcat: ConditioningConcat$1,
  ConditioningSetArea: ConditioningSetArea$1,
  ConditioningSetAreaPercentage: ConditioningSetAreaPercentage$1,
  ConditioningSetAreaPercentageVideo: ConditioningSetAreaPercentageVideo$1,
  ConditioningSetAreaStrength: ConditioningSetAreaStrength$1,
  ConditioningSetDefaultCombine: ConditioningSetDefaultCombine$1,
  ConditioningSetMask: ConditioningSetMask$1,
  ConditioningSetProperties: ConditioningSetProperties$1,
  ConditioningSetPropertiesAndCombine: ConditioningSetPropertiesAndCombine$1,
  ConditioningSetTimestepRange: ConditioningSetTimestepRange$1,
  ConditioningStableAudio: ConditioningStableAudio$1,
  ConditioningTimestepsRange: ConditioningTimestepsRange$1,
  ConditioningZeroOut: ConditioningZeroOut$1,
  ControlNetApply: ControlNetApply$1,
  ControlNetApplyAdvanced: ControlNetApplyAdvanced$1,
  ControlNetApplySD3: ControlNetApplySD3$1,
  ControlNetInpaintingAliMamaApply: ControlNetInpaintingAliMamaApply$1,
  ControlNetLoader: ControlNetLoader$1,
  CosmosImageToVideoLatent: CosmosImageToVideoLatent$1,
  CreateHookKeyframe: CreateHookKeyframe$1,
  CreateHookKeyframesFromFloats: CreateHookKeyframesFromFloats$1,
  CreateHookKeyframesInterpolated: CreateHookKeyframesInterpolated$1,
  CreateHookLora: CreateHookLora$1,
  CreateHookLoraModelOnly: CreateHookLoraModelOnly$1,
  CreateHookModelAsLora: CreateHookModelAsLora$1,
  CreateHookModelAsLoraModelOnly: CreateHookModelAsLoraModelOnly$1,
  CropMask: CropMask$1,
  DiffControlNetLoader: DiffControlNetLoader$1,
  DifferentialDiffusion: DifferentialDiffusion$1,
  DiffusersLoader: DiffusersLoader$1,
  DisableNoise: DisableNoise$1,
  DualCFGGuider: DualCFGGuider$1,
  DualCLIPLoader: DualCLIPLoader$1,
  EmptyCosmosLatentVideo: EmptyCosmosLatentVideo$1,
  EmptyHunyuanLatentVideo: EmptyHunyuanLatentVideo$1,
  EmptyImage: EmptyImage$1,
  EmptyLTXVLatentVideo: EmptyLTXVLatentVideo$1,
  EmptyLatentAudio: EmptyLatentAudio$1,
  EmptyLatentHunyuan3Dv2: EmptyLatentHunyuan3Dv2$1,
  EmptyLatentImage: EmptyLatentImage$1,
  EmptyMochiLatentVideo: EmptyMochiLatentVideo$1,
  EmptySD3LatentImage: EmptySD3LatentImage$1,
  ExponentialScheduler: ExponentialScheduler$1,
  FeatherMask: FeatherMask$1,
  FlipSigmas: FlipSigmas$1,
  FluxDisableGuidance: FluxDisableGuidance$1,
  FluxGuidance: FluxGuidance$1,
  FreeU: FreeU$1,
  FreeU_V2: FreeU_V2$1,
  GITSScheduler: GITSScheduler$1,
  GLIGENLoader: GLIGENLoader$1,
  GLIGENTextBoxApply: GLIGENTextBoxApply$1,
  GrowMask: GrowMask$1,
  Hunyuan3Dv2Conditioning: Hunyuan3Dv2Conditioning$1,
  Hunyuan3Dv2ConditioningMultiView: Hunyuan3Dv2ConditioningMultiView$1,
  HunyuanImageToVideo: HunyuanImageToVideo$1,
  HyperTile: HyperTile$1,
  HypernetworkLoader: HypernetworkLoader$1,
  ImageBatch: ImageBatch$1,
  ImageBlend: ImageBlend$1,
  ImageBlur: ImageBlur$1,
  ImageColorToMask: ImageColorToMask$1,
  ImageCompositeMasked: ImageCompositeMasked$1,
  ImageCrop: ImageCrop$1,
  ImageFromBatch: ImageFromBatch$1,
  ImageInvert: ImageInvert$1,
  ImageOnlyCheckpointLoader: ImageOnlyCheckpointLoader$1,
  ImageOnlyCheckpointSave: ImageOnlyCheckpointSave$1,
  ImagePadForOutpaint: ImagePadForOutpaint$1,
  ImageQuantize: ImageQuantize$1,
  ImageScale: ImageScale$1,
  ImageScaleBy: ImageScaleBy$1,
  ImageScaleToTotalPixels: ImageScaleToTotalPixels$1,
  ImageSharpen: ImageSharpen$1,
  ImageToMask: ImageToMask$1,
  ImageUpscaleWithModel: ImageUpscaleWithModel$1,
  InpaintModelConditioning: InpaintModelConditioning$1,
  InstructPixToPixConditioning: InstructPixToPixConditioning$1,
  InvertMask: InvertMask$1,
  JoinImageWithAlpha: JoinImageWithAlpha$1,
  KSampler: KSampler$1,
  KSamplerAdvanced: KSamplerAdvanced$1,
  KSamplerSelect: KSamplerSelect$1,
  KarrasScheduler: KarrasScheduler$1,
  LTXVAddGuide: LTXVAddGuide$1,
  LTXVConditioning: LTXVConditioning$1,
  LTXVCropGuides: LTXVCropGuides$1,
  LTXVImgToVideo: LTXVImgToVideo$1,
  LTXVPreprocess: LTXVPreprocess$1,
  LTXVScheduler: LTXVScheduler$1,
  LaplaceScheduler: LaplaceScheduler$1,
  LatentAdd: LatentAdd$1,
  LatentApplyOperation: LatentApplyOperation$1,
  LatentApplyOperationCFG: LatentApplyOperationCFG$1,
  LatentBatch: LatentBatch$1,
  LatentBatchSeedBehavior: LatentBatchSeedBehavior$1,
  LatentBlend: LatentBlend$1,
  LatentComposite: LatentComposite$1,
  LatentCompositeMasked: LatentCompositeMasked$1,
  LatentCrop: LatentCrop$1,
  LatentFlip: LatentFlip$1,
  LatentFromBatch: LatentFromBatch$1,
  LatentInterpolate: LatentInterpolate$1,
  LatentMultiply: LatentMultiply$1,
  LatentOperationSharpen: LatentOperationSharpen$1,
  LatentOperationTonemapReinhard: LatentOperationTonemapReinhard$1,
  LatentRotate: LatentRotate$1,
  LatentSubtract: LatentSubtract$1,
  LatentUpscale: LatentUpscale$1,
  LatentUpscaleBy: LatentUpscaleBy$1,
  Load3D: Load3D$1,
  Load3DAnimation: Load3DAnimation$1,
  LoadAudio: LoadAudio$1,
  LoadImage: LoadImage$1,
  LoadImageMask: LoadImageMask$1,
  LoadImageOutput: LoadImageOutput$1,
  LoadLatent: LoadLatent$1,
  LoraLoader: LoraLoader$1,
  LoraLoaderModelOnly: LoraLoaderModelOnly$1,
  LoraSave: LoraSave$1,
  Mahiro: Mahiro$1,
  MaskComposite: MaskComposite$1,
  MaskToImage: MaskToImage$1,
  ModelComputeDtype: ModelComputeDtype$1,
  ModelMergeAdd: ModelMergeAdd$1,
  ModelMergeAuraflow: ModelMergeAuraflow$1,
  ModelMergeBlocks: ModelMergeBlocks$1,
  ModelMergeCosmos14B: ModelMergeCosmos14B$1,
  ModelMergeCosmos7B: ModelMergeCosmos7B$1,
  ModelMergeFlux1: ModelMergeFlux1$1,
  ModelMergeLTXV: ModelMergeLTXV$1,
  ModelMergeMochiPreview: ModelMergeMochiPreview$1,
  ModelMergeSD1: ModelMergeSD1$1,
  ModelMergeSD2: ModelMergeSD2$1,
  ModelMergeSD35_Large: ModelMergeSD35_Large$1,
  ModelMergeSD3_2B: ModelMergeSD3_2B$1,
  ModelMergeSDXL: ModelMergeSDXL$1,
  ModelMergeSimple: ModelMergeSimple$1,
  ModelMergeSubtract: ModelMergeSubtract$1,
  ModelSamplingAuraFlow: ModelSamplingAuraFlow$1,
  ModelSamplingContinuousEDM: ModelSamplingContinuousEDM$1,
  ModelSamplingContinuousV: ModelSamplingContinuousV$1,
  ModelSamplingDiscrete: ModelSamplingDiscrete$1,
  ModelSamplingFlux: ModelSamplingFlux$1,
  ModelSamplingLTXV: ModelSamplingLTXV$1,
  ModelSamplingSD3: ModelSamplingSD3$1,
  ModelSamplingStableCascade: ModelSamplingStableCascade$1,
  ModelSave: ModelSave$1,
  Morphology: Morphology$1,
  PairConditioningCombine: PairConditioningCombine$1,
  PairConditioningSetDefaultCombine: PairConditioningSetDefaultCombine$1,
  PairConditioningSetProperties: PairConditioningSetProperties$1,
  PairConditioningSetPropertiesAndCombine: PairConditioningSetPropertiesAndCombine$1,
  PatchModelAddDownscale: PatchModelAddDownscale$1,
  PerpNeg: PerpNeg$1,
  PerpNegGuider: PerpNegGuider$1,
  PerturbedAttentionGuidance: PerturbedAttentionGuidance$1,
  PhotoMakerEncode: PhotoMakerEncode$1,
  PhotoMakerLoader: PhotoMakerLoader$1,
  PolyexponentialScheduler: PolyexponentialScheduler$1,
  PorterDuffImageComposite: PorterDuffImageComposite$1,
  Preview3D: Preview3D$1,
  Preview3DAnimation: Preview3DAnimation$1,
  PreviewAudio: PreviewAudio$1,
  PreviewImage: PreviewImage$1,
  RandomNoise: RandomNoise$1,
  RebatchImages: RebatchImages$1,
  RebatchLatents: RebatchLatents$1,
  RenormCFG: RenormCFG$1,
  RepeatImageBatch: RepeatImageBatch$1,
  RepeatLatentBatch: RepeatLatentBatch$1,
  RescaleCFG: RescaleCFG$1,
  SDTurboScheduler: SDTurboScheduler$1,
  SD_4XUpscale_Conditioning: SD_4XUpscale_Conditioning$1,
  SV3D_Conditioning: SV3D_Conditioning$1,
  SVD_img2vid_Conditioning: SVD_img2vid_Conditioning$1,
  SamplerCustom: SamplerCustom$1,
  SamplerCustomAdvanced: SamplerCustomAdvanced$1,
  SamplerDPMAdaptative: SamplerDPMAdaptative$1,
  SamplerDPMPP_2M_SDE: SamplerDPMPP_2M_SDE$1,
  SamplerDPMPP_2S_Ancestral: SamplerDPMPP_2S_Ancestral$1,
  SamplerDPMPP_3M_SDE: SamplerDPMPP_3M_SDE$1,
  SamplerDPMPP_SDE: SamplerDPMPP_SDE$1,
  SamplerEulerAncestral: SamplerEulerAncestral$1,
  SamplerEulerAncestralCFGPP: SamplerEulerAncestralCFGPP$1,
  SamplerEulerCFGpp: SamplerEulerCFGpp$1,
  SamplerLCMUpscale: SamplerLCMUpscale$1,
  SamplerLMS: SamplerLMS$1,
  SaveAnimatedPNG: SaveAnimatedPNG$1,
  SaveAnimatedWEBP: SaveAnimatedWEBP$1,
  SaveAudio: SaveAudio$1,
  SaveGLB: SaveGLB$1,
  SaveImage: SaveImage$1,
  SaveImageWebsocket: SaveImageWebsocket$1,
  SaveLatent: SaveLatent$1,
  SaveWEBM: SaveWEBM$1,
  SelfAttentionGuidance: SelfAttentionGuidance$1,
  SetClipHooks: SetClipHooks$1,
  SetFirstSigma: SetFirstSigma$1,
  SetHookKeyframes: SetHookKeyframes$1,
  SetLatentNoiseMask: SetLatentNoiseMask$1,
  SetUnionControlNetType: SetUnionControlNetType$1,
  SkipLayerGuidanceDiT: SkipLayerGuidanceDiT$1,
  SkipLayerGuidanceSD3: SkipLayerGuidanceSD3$1,
  SolidMask: SolidMask$1,
  SplitImageWithAlpha: SplitImageWithAlpha$1,
  SplitSigmas: SplitSigmas$1,
  SplitSigmasDenoise: SplitSigmasDenoise$1,
  StableCascade_EmptyLatentImage: StableCascade_EmptyLatentImage$1,
  StableCascade_StageB_Conditioning: StableCascade_StageB_Conditioning$1,
  StableCascade_StageC_VAEEncode: StableCascade_StageC_VAEEncode$1,
  StableCascade_SuperResolutionControlnet: StableCascade_SuperResolutionControlnet$1,
  StableZero123_Conditioning: StableZero123_Conditioning$1,
  StableZero123_Conditioning_Batched: StableZero123_Conditioning_Batched$1,
  StyleModelApply: StyleModelApply$1,
  StyleModelLoader: StyleModelLoader$1,
  TextEncodeHunyuanVideo_ImageToVideo: TextEncodeHunyuanVideo_ImageToVideo$1,
  ThresholdMask: ThresholdMask$1,
  TomePatchModel: TomePatchModel$1,
  TorchCompileModel: TorchCompileModel$1,
  TripleCLIPLoader: TripleCLIPLoader$1,
  UNETLoader: UNETLoader$1,
  UNetCrossAttentionMultiply: UNetCrossAttentionMultiply$1,
  UNetSelfAttentionMultiply: UNetSelfAttentionMultiply$1,
  UNetTemporalAttentionMultiply: UNetTemporalAttentionMultiply$1,
  UpscaleModelLoader: UpscaleModelLoader$1,
  VAEDecode: VAEDecode$1,
  VAEDecodeAudio: VAEDecodeAudio$1,
  VAEDecodeHunyuan3D: VAEDecodeHunyuan3D$1,
  VAEDecodeTiled: VAEDecodeTiled$1,
  VAEEncode: VAEEncode$1,
  VAEEncodeAudio: VAEEncodeAudio$1,
  VAEEncodeForInpaint: VAEEncodeForInpaint$1,
  VAEEncodeTiled: VAEEncodeTiled$1,
  VAELoader: VAELoader$1,
  VAESave: VAESave$1,
  VPScheduler: VPScheduler$1,
  VideoLinearCFGGuidance: VideoLinearCFGGuidance$1,
  VideoTriangleCFGGuidance: VideoTriangleCFGGuidance$1,
  VoxelToMeshBasic: VoxelToMeshBasic$1,
  WanImageToVideo: WanImageToVideo$1,
  WebcamCapture: WebcamCapture$1,
  unCLIPCheckpointLoader: unCLIPCheckpointLoader$1,
  unCLIPConditioning: unCLIPConditioning$1
};
const Comfy_Canvas_SelectionToolbox$1 = {
  name: "Показать панель инструментов выбора"
};
const Comfy_ConfirmClear$1 = {
  name: "Требовать подтверждение при очистке рабочего процесса"
};
const Comfy_DOMClippingEnabled$1 = {
  name: "Включить обрезку элементов DOM (включение может снизить производительность)"
};
const Comfy_DevMode$1 = {
  name: "Включить параметры режима разработчика (сохранение API и т. д.)"
};
const Comfy_DisableFloatRounding$1 = {
  name: "Отключить округление по умолчанию для плавающих виджетов.",
  tooltip: "(требуется перезагрузка страницы) Невозможно отключить округление, если оно установлено узлом на сервере."
};
const Comfy_DisableSliders$1 = {
  name: "Отключить ползунки виджетов нод"
};
const Comfy_EditAttention_Delta$1 = {
  name: "Точность Ctrl+вверх/вниз"
};
const Comfy_EnableTooltips$1 = {
  name: "Включить подсказки"
};
const Comfy_EnableWorkflowViewRestore$1 = {
  name: "Сохранять и восстанавливать положение и уровень масштабирования холста в рабочих процессах"
};
const Comfy_FloatRoundingPrecision$1 = {
  name: "Количество знаков после запятой для округления плавающего виджета [0 = авто].",
  tooltip: "(требуется перезагрузка страницы)"
};
const Comfy_Graph_CanvasInfo$1 = {
  name: "Показать информацию о холсте в нижнем левом углу (fps и т.д.)"
};
const Comfy_Graph_CanvasMenu$1 = {
  name: "Показать меню холста графа"
};
const Comfy_Graph_CtrlShiftZoom$1 = {
  name: "Включить быстрый зум с помощью сочетания клавиш (Ctrl + Shift + Колёсико мыши)"
};
const Comfy_Graph_LinkMarkers$1 = {
  name: "Маркер середины ссылки",
  options: {
    Arrow: "Стрелка",
    Circle: "Круг",
    None: "Нет"
  }
};
const Comfy_Graph_ZoomSpeed$1 = {
  name: "Скорость зума холста"
};
const Comfy_GroupSelectedNodes_Padding$1 = {
  name: "Отступ для выбранных нод группы"
};
const Comfy_Group_DoubleClickTitleToEdit$1 = {
  name: "Дважды щёлкните по заголовку группы, чтобы редактировать"
};
const Comfy_LinkRelease_Action$1 = {
  name: "Действие при отпускании ссылки (без модификатора)",
  options: {
    "context menu": "контекстное меню",
    "no action": "без действия",
    "search box": "поисковая строка"
  }
};
const Comfy_LinkRelease_ActionShift$1 = {
  name: "Действие при отпускании ссылки (Shift)",
  options: {
    "context menu": "контекстное меню",
    "no action": "без действия",
    "search box": "поисковая строка"
  }
};
const Comfy_LinkRenderMode$1 = {
  name: "Режим рендеринга ссылки",
  options: {
    Hidden: "Скрытый",
    Linear: "Линейный",
    Spline: "Сплайн",
    Straight: "Прямой"
  }
};
const Comfy_Locale$1 = {
  name: "Язык"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed$1 = {
  name: "Множитель скорости регулировки кисти",
  tooltip: "Управляет тем, как быстро изменяются размер и жёсткость кисти при регулировке. Более высокие значения означают более быстрые изменения."
};
const Comfy_MaskEditor_UseDominantAxis$1 = {
  name: "Закрепить регулировку кисти по доминирующей оси",
  tooltip: "При включении регулировки кисти будет влиять только на размер или жёсткость в зависимости от того, в каком направлении вы двигаетесь больше"
};
const Comfy_MaskEditor_UseNewEditor$1 = {
  name: "Использовать новый редактор масок",
  tooltip: "Переключиться на новый интерфейс редактора масок"
};
const Comfy_ModelLibrary_AutoLoadAll$1 = {
  name: "Автоматически загружать все папки моделей",
  tooltip: "Если true, все папки будут загружены, как только вы откроете библиотеку моделей (это может вызвать задержки при загрузке). Если false, корневые папки моделей будут загружены только после нажатия на них."
};
const Comfy_ModelLibrary_NameFormat$1 = {
  name: "Какое название отображать в древовидном представлении библиотеки моделей",
  options: {
    filename: "название файла",
    title: "название"
  },
  tooltip: 'Выберите "название файла", чтобы отобразить упрощённый вид сырого названия файла (без директории или расширения ".safetensors") в списке моделей. Выберите "название", чтобы отобразить настраиваемое название метаданных модели.'
};
const Comfy_NodeBadge_NodeIdBadgeMode$1 = {
  name: "Режим значка ID ноды",
  options: {
    None: "Нет",
    "Show all": "Показать все"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode$1 = {
  name: "Режим значка жизненного цикла ноды",
  options: {
    None: "Нет",
    "Show all": "Показать все"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode$1 = {
  name: "Режим значка источника ноды",
  options: {
    "Hide built-in": "Скрыть встроенные",
    None: "Нет",
    "Show all": "Показать все"
  }
};
const Comfy_NodeInputConversionSubmenus$1 = {
  name: "В контекстном меню ноды разместите элементы, которые конвертируют между вводом/виджетом в подменю."
};
const Comfy_NodeSearchBoxImpl$1 = {
  name: "Реализация поискового поля нод",
  options: {
    "default": "по умолчанию",
    "litegraph (legacy)": "litegraph (устаревший)"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview$1 = {
  name: "Предварительный просмотр ноды",
  tooltip: "Применяется только к стандартной реализации"
};
const Comfy_NodeSearchBoxImpl_ShowCategory$1 = {
  name: "Показать категорию ноды в результатах поиска",
  tooltip: "Применяется только к стандартной реализации"
};
const Comfy_NodeSearchBoxImpl_ShowIdName$1 = {
  name: "Показать название ID ноды в результатах поиска",
  tooltip: "Применяется только к стандартной реализации"
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency$1 = {
  name: "Показать частоту ноды в результатах поиска",
  tooltip: "Применяется только к стандартной реализации"
};
const Comfy_NodeSuggestions_number$1 = {
  name: "Количество предложенных нод",
  tooltip: "Только для поля поиска litegraph/контекстного меню"
};
const Comfy_Node_AutoSnapLinkToSlot$1 = {
  name: "Автоматически привязывать ссылку к слоту ноды",
  tooltip: "При перетаскивании ссылки над нодой ссылка автоматически привязывается к подходящему входному слоту ноды"
};
const Comfy_Node_BypassAllLinksOnDelete$1 = {
  name: "Сохранить все ссылки при удалении нод",
  tooltip: "При удалении ноды попытаться переподключить все её входные и выходные ссылки (обходя удалённую ноду)"
};
const Comfy_Node_DoubleClickTitleToEdit$1 = {
  name: "Дважды щёлкните по заголовку ноды, чтобы редактировать"
};
const Comfy_Node_MiddleClickRerouteNode$1 = {
  name: "Средний щелчок создаёт новую ноду перенаправления"
};
const Comfy_Node_Opacity$1 = {
  name: "Непрозрачность ноды"
};
const Comfy_Node_ShowDeprecated$1 = {
  name: "Показать устаревшие ноды в поиске",
  tooltip: "Устаревшие ноды по умолчанию скрыты в интерфейсе, но остаются функциональными в существующих рабочих процессах, которые их используют."
};
const Comfy_Node_ShowExperimental$1 = {
  name: "Показать экспериментальные ноды в поиске",
  tooltip: "Экспериментальные ноды помечены как таковые в интерфейсе и могут подвергаться значительным изменениям или удалению в будущих версиях. Используйте с осторожностью в производственных рабочих процессах"
};
const Comfy_Node_SnapHighlightsNode$1 = {
  name: "Подсветка ноды при привязке",
  tooltip: "При перетаскивании ссылки над нодой с подходящим входным слотом, нода подсвечивается"
};
const Comfy_Pointer_ClickBufferTime$1 = {
  name: "Задержка дрейфа щелчка указателя",
  tooltip: "После нажатия кнопки указателя, это максимальное время (в миллисекундах), в течение которого движение указателя может быть проигнорировано.\n\nПомогает предотвратить непреднамеренное смещение объектов, если указатель перемещается во время щелчка."
};
const Comfy_Pointer_ClickDrift$1 = {
  name: "Дрейф щелчка указателя (максимальное расстояние)",
  tooltip: "Если указатель перемещается более чем на это расстояние, удерживая кнопку, это считается перетаскиванием (а не щелчком).\n\nПомогает предотвратить непреднамеренное смещение объектов, если указатель перемещается во время щелчка."
};
const Comfy_Pointer_DoubleClickTime$1 = {
  name: "Интервал двойного щелчка (максимум)",
  tooltip: "Максимальное время в миллисекундах между двумя щелчками двойного щелчка. Увеличение этого значения может помочь, если двойные щелчки иногда не регистрируются."
};
const Comfy_PreviewFormat$1 = {
  name: "Формат изображения предварительного просмотра",
  tooltip: "При отображении предварительного просмотра в виджете изображения, преобразуйте его в легковесное изображение, например, webp, jpeg, webp;50 и т.д."
};
const Comfy_PromptFilename$1 = {
  name: "Запрос названия файла при сохранении рабочего процесса"
};
const Comfy_QueueButton_BatchCountLimit$1 = {
  name: "Ограничение количества партий",
  tooltip: "Максимальное количество задач, добавляемых в очередь за одно нажатие кнопки"
};
const Comfy_Queue_MaxHistoryItems$1 = {
  name: "Размер истории очереди",
  tooltip: "Максимальное количество задач, отображаемых в истории очереди."
};
const Comfy_RerouteBeta$1 = {
  name: "Участвовать в бета-тестировании перенаправления",
  tooltip: "Включает новые нативные перенаправления.\n\nПеренаправления можно добавлять, удерживая alt и перетаскивая от линии ссылки или в меню ссылки.\n\nОтключение этой опции не разрушительно — перенаправления скрыты."
};
const Comfy_Sidebar_Location$1 = {
  name: "Расположение боковой панели",
  options: {
    left: "слева",
    right: "справа"
  }
};
const Comfy_Sidebar_Size$1 = {
  name: "Размер боковой панели",
  options: {
    normal: "нормальный",
    small: "маленький"
  }
};
const Comfy_SnapToGrid_GridSize$1 = {
  name: "Размер сетки привязки",
  tooltip: "При перетаскивании и изменении размера нод, удерживая shift, они будут выровнены по сетке, это контролирует размер этой сетки."
};
const Comfy_TextareaWidget_FontSize$1 = {
  name: "Размер шрифта виджета текстовой области"
};
const Comfy_TextareaWidget_Spellcheck$1 = {
  name: "Проверка орфографии виджета текстовой области"
};
const Comfy_TreeExplorer_ItemPadding$1 = {
  name: "Отступ элемента в проводнике дерева"
};
const Comfy_UseNewMenu$1 = {
  name: "Использовать новое меню",
  options: {
    Bottom: "Внизу",
    Disabled: "Отключено",
    Top: "Вверху"
  }
};
const Comfy_Validation_NodeDefs$1 = {
  name: "Проверка определений нод (медленно)",
  tooltip: "Рекомендуется для разработчиков нод. Это проверит все определения нод при запуске."
};
const Comfy_Validation_Workflows$1 = {
  name: "Проверка рабочих процессов"
};
const Comfy_WidgetControlMode$1 = {
  name: "Режим управления виджетом",
  options: {
    after: "после",
    before: "до"
  },
  tooltip: "Управляет тем, когда обновляются значения виджета (случайные/увеличение/уменьшение), либо до того, как запрос будет поставлен в очередь, либо после."
};
const Comfy_Window_UnloadConfirmation$1 = {
  name: "Показать подтверждение при закрытии окна"
};
const Comfy_Workflow_ConfirmDelete$1 = {
  name: "Показать подтверждение при удалении рабочих процессов"
};
const Comfy_Workflow_ShowMissingModelsWarning$1 = {
  name: "Показать предупреждение об отсутствующих моделях"
};
const Comfy_Workflow_ShowMissingNodesWarning$1 = {
  name: "Показать предупреждение об отсутствующих нодах"
};
const Comfy_Workflow_SortNodeIdOnSave$1 = {
  name: "Сортировать ID нод при сохранении рабочего процесса"
};
const Comfy_Workflow_WorkflowTabsPosition$1 = {
  name: "Положение открытых рабочих процессов",
  options: {
    Sidebar: "Боковая панель",
    Topbar: "Верхняя панель",
    "Topbar (2nd-row)": "Топбар (2-й ряд)"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold$1 = {
  name: "Порог масштабирования для рендеринга низкого качества",
  tooltip: "Рендеринг фигур низкого качества при уменьшении масштаба"
};
const LiteGraph_Canvas_MaximumFps$1 = {
  name: "Максимум FPS",
  tooltip: "Максимальное количество кадров в секунду, которое холст может рендерить. Ограничивает использование GPU за счёт плавности. Если 0, используется частота обновления экрана. По умолчанию: 0"
};
const LiteGraph_ContextMenu_Scaling$1 = {
  name: "Масштабирование комбинированных виджетов меню узлов (списков) при увеличении"
};
const LiteGraph_Node_TooltipDelay$1 = {
  name: "Задержка всплывающей подсказки"
};
const pysssss_SnapToGrid$1 = {
  name: "Всегда привязываться к сетке"
};
const ruSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "Автоматически проверять обновления"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "Отправлять анонимную статистику использования"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "Pypi Установить Зеркало",
    tooltip: "Зеркало установки pip по умолчанию"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Зеркало для установки Python",
    tooltip: "Управляемые установки Python загружаются из проекта Astral python-build-standalone. Эта переменная может быть установлена на URL-адрес зеркала для использования другого источника для установок Python. Предоставленный URL заменит https://github.com/astral-sh/python-build-standalone/releases/download в, например, https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gz. Дистрибутивы могут быть прочитаны из локального каталога, используя схему URL file://."
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "Установочное Зеркало Torch",
    tooltip: "Зеркало для установки pip для pytorch"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "Стиль окна",
    options: {
      custom: "пользовательский",
      "default": "по умолчанию"
    },
    tooltip: "Выберите пользовательский вариант, чтобы скрыть системную строку заголовка"
  },
  Comfy_Canvas_SelectionToolbox: Comfy_Canvas_SelectionToolbox$1,
  Comfy_ConfirmClear: Comfy_ConfirmClear$1,
  Comfy_DOMClippingEnabled: Comfy_DOMClippingEnabled$1,
  Comfy_DevMode: Comfy_DevMode$1,
  Comfy_DisableFloatRounding: Comfy_DisableFloatRounding$1,
  Comfy_DisableSliders: Comfy_DisableSliders$1,
  Comfy_EditAttention_Delta: Comfy_EditAttention_Delta$1,
  Comfy_EnableTooltips: Comfy_EnableTooltips$1,
  Comfy_EnableWorkflowViewRestore: Comfy_EnableWorkflowViewRestore$1,
  Comfy_FloatRoundingPrecision: Comfy_FloatRoundingPrecision$1,
  Comfy_Graph_CanvasInfo: Comfy_Graph_CanvasInfo$1,
  Comfy_Graph_CanvasMenu: Comfy_Graph_CanvasMenu$1,
  Comfy_Graph_CtrlShiftZoom: Comfy_Graph_CtrlShiftZoom$1,
  Comfy_Graph_LinkMarkers: Comfy_Graph_LinkMarkers$1,
  Comfy_Graph_ZoomSpeed: Comfy_Graph_ZoomSpeed$1,
  Comfy_GroupSelectedNodes_Padding: Comfy_GroupSelectedNodes_Padding$1,
  Comfy_Group_DoubleClickTitleToEdit: Comfy_Group_DoubleClickTitleToEdit$1,
  Comfy_LinkRelease_Action: Comfy_LinkRelease_Action$1,
  Comfy_LinkRelease_ActionShift: Comfy_LinkRelease_ActionShift$1,
  Comfy_LinkRenderMode: Comfy_LinkRenderMode$1,
  Comfy_Locale: Comfy_Locale$1,
  Comfy_MaskEditor_BrushAdjustmentSpeed: Comfy_MaskEditor_BrushAdjustmentSpeed$1,
  Comfy_MaskEditor_UseDominantAxis: Comfy_MaskEditor_UseDominantAxis$1,
  Comfy_MaskEditor_UseNewEditor: Comfy_MaskEditor_UseNewEditor$1,
  Comfy_ModelLibrary_AutoLoadAll: Comfy_ModelLibrary_AutoLoadAll$1,
  Comfy_ModelLibrary_NameFormat: Comfy_ModelLibrary_NameFormat$1,
  Comfy_NodeBadge_NodeIdBadgeMode: Comfy_NodeBadge_NodeIdBadgeMode$1,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode: Comfy_NodeBadge_NodeLifeCycleBadgeMode$1,
  Comfy_NodeBadge_NodeSourceBadgeMode: Comfy_NodeBadge_NodeSourceBadgeMode$1,
  Comfy_NodeInputConversionSubmenus: Comfy_NodeInputConversionSubmenus$1,
  Comfy_NodeSearchBoxImpl: Comfy_NodeSearchBoxImpl$1,
  Comfy_NodeSearchBoxImpl_NodePreview: Comfy_NodeSearchBoxImpl_NodePreview$1,
  Comfy_NodeSearchBoxImpl_ShowCategory: Comfy_NodeSearchBoxImpl_ShowCategory$1,
  Comfy_NodeSearchBoxImpl_ShowIdName: Comfy_NodeSearchBoxImpl_ShowIdName$1,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency: Comfy_NodeSearchBoxImpl_ShowNodeFrequency$1,
  Comfy_NodeSuggestions_number: Comfy_NodeSuggestions_number$1,
  Comfy_Node_AutoSnapLinkToSlot: Comfy_Node_AutoSnapLinkToSlot$1,
  Comfy_Node_BypassAllLinksOnDelete: Comfy_Node_BypassAllLinksOnDelete$1,
  Comfy_Node_DoubleClickTitleToEdit: Comfy_Node_DoubleClickTitleToEdit$1,
  Comfy_Node_MiddleClickRerouteNode: Comfy_Node_MiddleClickRerouteNode$1,
  Comfy_Node_Opacity: Comfy_Node_Opacity$1,
  Comfy_Node_ShowDeprecated: Comfy_Node_ShowDeprecated$1,
  Comfy_Node_ShowExperimental: Comfy_Node_ShowExperimental$1,
  Comfy_Node_SnapHighlightsNode: Comfy_Node_SnapHighlightsNode$1,
  Comfy_Pointer_ClickBufferTime: Comfy_Pointer_ClickBufferTime$1,
  Comfy_Pointer_ClickDrift: Comfy_Pointer_ClickDrift$1,
  Comfy_Pointer_DoubleClickTime: Comfy_Pointer_DoubleClickTime$1,
  Comfy_PreviewFormat: Comfy_PreviewFormat$1,
  Comfy_PromptFilename: Comfy_PromptFilename$1,
  Comfy_QueueButton_BatchCountLimit: Comfy_QueueButton_BatchCountLimit$1,
  Comfy_Queue_MaxHistoryItems: Comfy_Queue_MaxHistoryItems$1,
  Comfy_RerouteBeta: Comfy_RerouteBeta$1,
  Comfy_Sidebar_Location: Comfy_Sidebar_Location$1,
  Comfy_Sidebar_Size: Comfy_Sidebar_Size$1,
  Comfy_SnapToGrid_GridSize: Comfy_SnapToGrid_GridSize$1,
  Comfy_TextareaWidget_FontSize: Comfy_TextareaWidget_FontSize$1,
  Comfy_TextareaWidget_Spellcheck: Comfy_TextareaWidget_Spellcheck$1,
  Comfy_TreeExplorer_ItemPadding: Comfy_TreeExplorer_ItemPadding$1,
  Comfy_UseNewMenu: Comfy_UseNewMenu$1,
  Comfy_Validation_NodeDefs: Comfy_Validation_NodeDefs$1,
  Comfy_Validation_Workflows: Comfy_Validation_Workflows$1,
  Comfy_WidgetControlMode: Comfy_WidgetControlMode$1,
  Comfy_Window_UnloadConfirmation: Comfy_Window_UnloadConfirmation$1,
  Comfy_Workflow_ConfirmDelete: Comfy_Workflow_ConfirmDelete$1,
  Comfy_Workflow_ShowMissingModelsWarning: Comfy_Workflow_ShowMissingModelsWarning$1,
  Comfy_Workflow_ShowMissingNodesWarning: Comfy_Workflow_ShowMissingNodesWarning$1,
  Comfy_Workflow_SortNodeIdOnSave: Comfy_Workflow_SortNodeIdOnSave$1,
  Comfy_Workflow_WorkflowTabsPosition: Comfy_Workflow_WorkflowTabsPosition$1,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold: LiteGraph_Canvas_LowQualityRenderingZoomThreshold$1,
  LiteGraph_Canvas_MaximumFps: LiteGraph_Canvas_MaximumFps$1,
  LiteGraph_ContextMenu_Scaling: LiteGraph_ContextMenu_Scaling$1,
  LiteGraph_Node_TooltipDelay: LiteGraph_Node_TooltipDelay$1,
  pysssss_SnapToGrid: pysssss_SnapToGrid$1
};
const Comfy_BrowseTemplates = {
  label: "浏览模板"
};
const Comfy_Canvas_DeleteSelectedItems = {
  label: "删除选定的项目"
};
const Comfy_Canvas_FitView = {
  label: "适应视图到选中节点"
};
const Comfy_Canvas_ResetView = {
  label: "重置视图"
};
const Comfy_Canvas_ToggleLinkVisibility = {
  label: "切换链接可见性"
};
const Comfy_Canvas_ToggleLock = {
  label: "锁定视图"
};
const Comfy_Canvas_ToggleSelectedNodes_Bypass = {
  label: "忽略/取消忽略选中节点"
};
const Comfy_Canvas_ToggleSelectedNodes_Collapse = {
  label: "折叠/展开选中节点"
};
const Comfy_Canvas_ToggleSelectedNodes_Mute = {
  label: "静音/取消静音选中节点"
};
const Comfy_Canvas_ToggleSelectedNodes_Pin = {
  label: "固定/取消固定选中节点"
};
const Comfy_Canvas_ToggleSelected_Pin = {
  label: "固定/取消固定选中项"
};
const Comfy_Canvas_ZoomIn = {
  label: "放大"
};
const Comfy_Canvas_ZoomOut = {
  label: "缩小"
};
const Comfy_ClearPendingTasks = {
  label: "清除待处理任务"
};
const Comfy_ClearWorkflow = {
  label: "清除工作流"
};
const Comfy_DuplicateWorkflow = {
  label: "复制当前工作流"
};
const Comfy_ExportWorkflow = {
  label: "导出工作流"
};
const Comfy_ExportWorkflowAPI = {
  label: "导出工作流（API格式）"
};
const Comfy_Feedback = {
  label: "反馈"
};
const Comfy_Graph_FitGroupToContents = {
  label: "适应节点框到内容"
};
const Comfy_Graph_GroupSelectedNodes = {
  label: "添加框到选中节点"
};
const Comfy_GroupNode_ConvertSelectedNodesToGroupNode = {
  label: "将选中节点转换为组节点"
};
const Comfy_GroupNode_ManageGroupNodes = {
  label: "管理组节点"
};
const Comfy_GroupNode_UngroupSelectedGroupNodes = {
  label: "解散选中组节点"
};
const Comfy_Help_AboutComfyUI = {
  label: "打开关于ComfyUI"
};
const Comfy_Help_OpenComfyOrgDiscord = {
  label: "打开Comfy-Org Discord"
};
const Comfy_Help_OpenComfyUIDocs = {
  label: "打开ComfyUI文档"
};
const Comfy_Help_OpenComfyUIForum = {
  label: "打开 Comfy-Org 论坛"
};
const Comfy_Help_OpenComfyUIIssues = {
  label: "打开ComfyUI问题"
};
const Comfy_Interrupt = {
  label: "中断"
};
const Comfy_LoadDefaultWorkflow = {
  label: "加载默认工作流"
};
const Comfy_Manager_CustomNodesManager = {
  label: "自定义节点管理器"
};
const Comfy_Manager_ToggleManagerProgressDialog = {
  label: "切换进度对话框"
};
const Comfy_NewBlankWorkflow = {
  label: "新建空白工作流"
};
const Comfy_OpenClipspace = {
  label: "打开剪贴板"
};
const Comfy_OpenWorkflow = {
  label: "打开工作流"
};
const Comfy_QueuePrompt = {
  label: "执行提示词"
};
const Comfy_QueuePromptFront = {
  label: "执行提示词（前端）"
};
const Comfy_Redo = {
  label: "重做"
};
const Comfy_RefreshNodeDefinitions = {
  label: "刷新节点定义"
};
const Comfy_SaveWorkflow = {
  label: "保存工作流"
};
const Comfy_SaveWorkflowAs = {
  label: "另存工作流"
};
const Comfy_ShowSettingsDialog = {
  label: "显示设置对话框"
};
const Comfy_ToggleTheme = {
  label: "切换主题"
};
const Comfy_Undo = {
  label: "撤销"
};
const Workspace_CloseWorkflow = {
  label: "关闭当前工作流"
};
const Workspace_NextOpenedWorkflow = {
  label: "下一个打开的工作流"
};
const Workspace_PreviousOpenedWorkflow = {
  label: "上一个打开的工作流"
};
const Workspace_SearchBox_Toggle = {
  label: "切换搜索框"
};
const Workspace_ToggleBottomPanel = {
  label: "切换底部面板"
};
const Workspace_ToggleFocusMode = {
  label: "切换焦点模式"
};
const Workspace_ToggleSidebarTab_queue = {
  label: "切换执行队列侧边栏",
  tooltip: "执行队列"
};
const Workspace_ToggleSidebarTab_workflows = {
  label: "切换工作流侧边栏",
  tooltip: "工作流"
};
const zhCommands = {
  "Comfy-Desktop_Folders_OpenCustomNodesFolder": {
    label: "打开自定义节点文件夹"
  },
  "Comfy-Desktop_Folders_OpenInputsFolder": {
    label: "打开输入文件夹"
  },
  "Comfy-Desktop_Folders_OpenLogsFolder": {
    label: "打开日志文件夹"
  },
  "Comfy-Desktop_Folders_OpenModelConfig": {
    label: "打开 extra_model_paths.yaml"
  },
  "Comfy-Desktop_Folders_OpenModelsFolder": {
    label: "打开模型文件夹"
  },
  "Comfy-Desktop_Folders_OpenOutputsFolder": {
    label: "打开输出文件夹"
  },
  "Comfy-Desktop_OpenDevTools": {
    label: "打开开发者工具"
  },
  "Comfy-Desktop_OpenUserGuide": {
    label: "桌面用户指南"
  },
  "Comfy-Desktop_Quit": {
    label: "退出"
  },
  "Comfy-Desktop_Reinstall": {
    label: "重新安装"
  },
  "Comfy-Desktop_Restart": {
    label: "重启"
  },
  Comfy_BrowseTemplates,
  Comfy_Canvas_DeleteSelectedItems,
  Comfy_Canvas_FitView,
  Comfy_Canvas_ResetView,
  Comfy_Canvas_ToggleLinkVisibility,
  Comfy_Canvas_ToggleLock,
  Comfy_Canvas_ToggleSelectedNodes_Bypass,
  Comfy_Canvas_ToggleSelectedNodes_Collapse,
  Comfy_Canvas_ToggleSelectedNodes_Mute,
  Comfy_Canvas_ToggleSelectedNodes_Pin,
  Comfy_Canvas_ToggleSelected_Pin,
  Comfy_Canvas_ZoomIn,
  Comfy_Canvas_ZoomOut,
  Comfy_ClearPendingTasks,
  Comfy_ClearWorkflow,
  Comfy_DuplicateWorkflow,
  Comfy_ExportWorkflow,
  Comfy_ExportWorkflowAPI,
  Comfy_Feedback,
  Comfy_Graph_FitGroupToContents,
  Comfy_Graph_GroupSelectedNodes,
  Comfy_GroupNode_ConvertSelectedNodesToGroupNode,
  Comfy_GroupNode_ManageGroupNodes,
  Comfy_GroupNode_UngroupSelectedGroupNodes,
  Comfy_Help_AboutComfyUI,
  Comfy_Help_OpenComfyOrgDiscord,
  Comfy_Help_OpenComfyUIDocs,
  Comfy_Help_OpenComfyUIForum,
  Comfy_Help_OpenComfyUIIssues,
  Comfy_Interrupt,
  Comfy_LoadDefaultWorkflow,
  Comfy_Manager_CustomNodesManager,
  Comfy_Manager_ToggleManagerProgressDialog,
  Comfy_NewBlankWorkflow,
  Comfy_OpenClipspace,
  Comfy_OpenWorkflow,
  Comfy_QueuePrompt,
  Comfy_QueuePromptFront,
  Comfy_Redo,
  Comfy_RefreshNodeDefinitions,
  Comfy_SaveWorkflow,
  Comfy_SaveWorkflowAs,
  Comfy_ShowSettingsDialog,
  Comfy_ToggleTheme,
  Comfy_Undo,
  Workspace_CloseWorkflow,
  Workspace_NextOpenedWorkflow,
  Workspace_PreviousOpenedWorkflow,
  Workspace_SearchBox_Toggle,
  Workspace_ToggleBottomPanel,
  "Workspace_ToggleBottomPanelTab_command-terminal": {
    label: "切换终端底部面板"
  },
  "Workspace_ToggleBottomPanelTab_logs-terminal": {
    label: "切换日志底部面板"
  },
  Workspace_ToggleFocusMode,
  "Workspace_ToggleSidebarTab_model-library": {
    label: "切换模型库侧边栏",
    tooltip: "模型库"
  },
  "Workspace_ToggleSidebarTab_node-library": {
    label: "切换节点库侧边栏",
    tooltip: "节点库"
  },
  Workspace_ToggleSidebarTab_queue,
  Workspace_ToggleSidebarTab_workflows
};
const clipboard = {
  errorMessage: "复制到剪贴板失败",
  errorNotSupported: "您的浏览器不支持剪贴板API",
  successMessage: "已复制到剪贴板"
};
const color = {
  black: "黑色",
  blue: "蓝色",
  brown: "棕色",
  custom: "自定义",
  cyan: "青色",
  "default": "默认",
  green: "绿色",
  noColor: "无色",
  pale_blue: "淡蓝色",
  pink: "粉色",
  purple: "紫色",
  red: "红色",
  yellow: "黄色"
};
const contextMenu = {
  " to input": " 为输入",
  " to widget": " 为控件",
  "Add Group": "添加组",
  "Add Group For Selected Nodes": "为选定节点添加组",
  "Add Node": "添加节点",
  Bypass: "绕过",
  Clone: "克隆",
  Collapse: "折叠",
  Colors: "颜色",
  "Convert ": "转换 ",
  "Convert Input to Widget": "将输入转换为控件",
  "Convert Widget to Input": "将控件转换为输入",
  "Convert to Group Node": "转换为组节点",
  "Copy (Clipspace)": "复制 (Clipspace)",
  Expand: "展开",
  Inputs: "输入",
  Manage: "管理",
  "Manage Group Nodes": "管理组节点",
  Mode: "模式",
  "Node Templates": "节点模板",
  Outputs: "输出",
  Pin: "固定",
  Properties: "属性",
  "Properties Panel": "属性面板",
  Remove: "删除",
  Resize: "调整大小",
  "Save Selected as Template": "将选定节点另存为模板",
  Search: "搜索",
  Shapes: "形状",
  Title: "标题",
  Unpin: "取消固定"
};
const dataTypes = {
  AUDIO: "音频",
  BOOLEAN: "布尔",
  CLIP: "CLIP",
  CLIP_VISION: "CLIP视觉",
  CLIP_VISION_OUTPUT: "CLIP视觉输出",
  COMBO: "组合",
  CONDITIONING: "条件",
  CONTROL_NET: "ControlNet",
  FLOAT: "浮点",
  FLOATS: "浮点组",
  GLIGEN: "GLIGEN",
  GUIDER: "引导器",
  HOOKS: "约束",
  HOOK_KEYFRAMES: "约束关键帧",
  IMAGE: "图像",
  INT: "整数",
  LATENT: "Latent",
  LATENT_OPERATION: "Latent操作",
  LOAD_3D: "加载3D",
  LOAD_3D_ANIMATION: "加载3D动画",
  MASK: "遮罩",
  MESH: "网格",
  MODEL: "模型",
  NOISE: "噪波",
  PHOTOMAKER: "PhotoMaker",
  SAMPLER: "采样器",
  SIGMAS: "Sigmas",
  STRING: "字符串",
  STYLE_MODEL: "风格模型",
  TIMESTEPS_RANGE: "时间间隔范围",
  UPSCALE_MODEL: "放大模型",
  VAE: "VAE",
  VOXEL: "体素",
  WEBCAM: "摄像头"
};
const desktopMenu = {
  confirmQuit: "有未保存的工作流程开启；任何未保存的更改都将丢失。忽略此警告并退出？",
  confirmReinstall: "这将清除您的 extra_models_config.yaml 文件，并重新开始安装。您确定吗？",
  quit: "退出",
  reinstall: "重新安装"
};
const desktopUpdate = {
  description: "ComfyUI桌面正在安装新的依赖项。这可能需要几分钟的时间。",
  terminalDefaultMessage: "更新过程中的任何控制台输出都将在这里显示。",
  title: "正在更新ComfyUI桌面"
};
const downloadGit = {
  gitWebsite: "下载 git",
  instructions: "请下载并安装适合您操作系统的最新版本。下面的下载 git 按钮将打开 git-scm.com 下载页面。",
  message: "无法找到 git。正常操作需要一个可用的 git 副本。",
  skip: "跳过",
  title: "下载 git",
  warning: "如果您确定不需要安装 git，或者已经安装了 git，您可以点击跳过以绕过此检查。当前不支持在没有可用 git 副本的情况下运行 ComfyUI。"
};
const electronFileDownload = {
  cancel: "取消下载",
  cancelled: "已取消",
  inProgress: "进行中",
  pause: "暂停下载",
  paused: "已暂停",
  resume: "恢复下载"
};
const g = {
  about: "关于",
  add: "添加",
  all: "全部",
  apply: "应用",
  back: "返回",
  cancel: "取消",
  capture: "捕获",
  category: "类别",
  choose_file_to_upload: "选择要上传的文件",
  close: "关闭",
  color: "颜色",
  comingSoon: "即将推出",
  command: "指令",
  community: "社区",
  completed: "已完成",
  confirm: "确认",
  "continue": "继续",
  control_after_generate: "生成后控制",
  control_before_generate: "生成前控制",
  copyToClipboard: "复制到剪贴板",
  currentUser: "当前用户",
  customize: "自定义",
  customizeFolder: "自定义文件夹",
  "delete": "删除",
  deprecated: "已弃用",
  description: "描述",
  devices: "设备",
  disableAll: "禁用全部",
  download: "下载",
  empty: "空",
  enableAll: "启用全部",
  enabled: "已启用",
  error: "错误",
  experimental: "测试版",
  "export": "导出",
  extensionName: "扩展名称",
  feedback: "反馈",
  filter: "过滤",
  findIssues: "查找问题",
  firstTimeUIMessage: '这是您第一次使用新界面。选择 "菜单 > 使用新菜单 > 禁用" 来恢复旧界面。',
  goToNode: "转到节点",
  icon: "图标",
  imageFailedToLoad: "图像加载失败",
  "import": "导入",
  inProgress: "进行中",
  insert: "插入",
  install: "安装",
  installed: "已安装",
  installing: "正在安装",
  keybinding: "按键绑定",
  loadAllFolders: "加载所有文件夹",
  loadWorkflow: "加载工作流",
  loading: "加载中",
  logs: "日志",
  missing: "缺失",
  name: "名称",
  newFolder: "新文件夹",
  next: "下一个",
  no: "否",
  noResultsFound: "未找到结果",
  noTasksFound: "未找到任务",
  noTasksFoundMessage: "队列中没有任务。",
  noWorkflowsFound: "未找到工作流。",
  nodes: "节点",
  ok: "确定",
  openNewIssue: "打开新问题",
  overwrite: "覆盖",
  reconnected: "已重新连接",
  reconnecting: "重新连接中",
  refresh: "刷新",
  reloadToApplyChanges: "重新加载以应用更改",
  rename: "重命名",
  reportIssue: "发送报告",
  reportIssueTooltip: "向 Comfy Org 提交错误报告",
  reportSent: "报告已提交",
  reset: "重置",
  resetKeybindingsTooltip: "将快捷键重置为默认",
  restart: "重新启动",
  resultsCount: "找到 {count} 个结果",
  save: "保存",
  saving: "正在保存",
  searchExtensions: "搜索扩展",
  searchFailedMessage: "我们找不到任何与您的搜索匹配的设置。请尝试调整您的搜索词。",
  searchKeybindings: "搜索快捷键",
  searchModels: "搜索模型",
  searchNodes: "搜索节点",
  searchSettings: "搜索设置",
  searchWorkflows: "搜索工作流",
  settings: "设置",
  showReport: "显示报告",
  sort: "排序",
  status: "状态",
  success: "成功",
  systemInfo: "系统信息",
  terminal: "终端",
  updated: "已更新",
  upload: "上传",
  videoFailedToLoad: "视频加载失败",
  workflow: "工作流"
};
const graphCanvasMenu = {
  fitView: "适应视图",
  panMode: "平移模式",
  resetView: "重置视图",
  selectMode: "选择模式",
  toggleLinkVisibility: "切换连线可见性",
  zoomIn: "放大",
  zoomOut: "缩小"
};
const groupNode = {
  create: "创建组节点",
  enterName: "输入名称"
};
const icon = {
  bookmark: "书签",
  box: "盒子",
  briefcase: "公文包",
  "exclamation-triangle": "警告",
  file: "文件",
  folder: "文件夹",
  heart: "心",
  inbox: "收件箱",
  star: "星星"
};
const install = {
  appDataLocationTooltip: "ComfyUI 的应用数据目录。存储：\n- 日志\n- 服务器配置",
  appPathLocationTooltip: "ComfyUI 的应用资产目录。存储 ComfyUI 代码和资产",
  cannotWrite: "无法写入所选路径。",
  chooseInstallationLocation: "选择安装位置",
  customNodes: "自定义节点",
  customNodesDescription: "引用现有 ComfyUI 安装的自定义节点文件并安装其依赖项。",
  desktopAppSettings: "桌面应用设置",
  desktopAppSettingsDescription: "配置 ComfyUI 在桌面上的行为。您可以稍后更改这些设置。",
  desktopSettings: "桌面设置",
  failedToSelectDirectory: "选择目录失败",
  gpu: "GPU",
  gpuSelection: {
    cpuMode: "CPU 模式",
    cpuModeDescription: "CPU 模式仅适用于开发者和极少数特殊情况。",
    cpuModeDescription2: "如果你不完全确定你需要这个，忽略该选项并在上面选择你的 GPU。",
    customComfyNeedsPython: "在 python 完成设置前，ComfyUI 将无法工作",
    customInstallRequirements: "安装所有需求和依赖项（例如：自定义 torch）",
    customManualVenv: "手动配置 python 虚拟环境",
    customMayNotWork: "完全不支持，可能无法工作",
    customSkipsPython: "此选项跳过正常的 python 设置。",
    enableCpuMode: "启用 CPU 模式",
    mpsDescription: "Apple Metal Performance Shaders 使用 pytorch nightly 支持。",
    nvidiaDescription: "NVIDIA 设备直接支持使用 pytorch CUDA 构建。",
    selectGpu: "选择 GPU",
    selectGpuDescription: "选择你拥有的 GPU 类型"
  },
  helpImprove: "请帮助我们改进ComfyUI",
  installLocation: "安装位置",
  installLocationDescription: "选择 ComfyUI 用户数据的存放目录。将安装一个 Python 环境到所选位置。请确保所选磁盘有足够的空间（约 15GB）。",
  installLocationTooltip: "ComfyUI 的用户数据目录。存储：\n- Python 环境\n- 模型\n- 自定义节点\n",
  insufficientFreeSpace: "空间不足 - 最小可用空间",
  isOneDrive: "在OneDrive中安装可能会导致问题。强烈建议在非OneDrive位置安装。",
  manualConfiguration: {
    createVenv: "您需要在以下目录中创建虚拟环境",
    requirements: "依赖项",
    restartWhenFinished: "配置虚拟环境完成后，请重新启动ComfyUI。",
    title: "手动配置",
    virtualEnvironmentPath: "虚拟环境路径"
  },
  metricsDisabled: "禁用度量",
  metricsEnabled: "启用度量",
  migrateFromExistingInstallation: "从现有安装迁移",
  migration: "迁移",
  migrationOptional: "迁移是可选的。如果您之前没有安装过 ComfyUI，可以跳过此步骤。",
  migrationSourcePathDescription: "如果您已有现有的ComfyUI安装，我们可以复制/链接您现有的用户文件和模型到新的安装。您现有的ComfyUI安装将不会受到影响。",
  moreInfo: "有关更多信息，请阅读我们的",
  nonDefaultDrive: "请在您的系统驱动器上安装ComfyUI（例如C:\\）。具有不同文件系统的驱动器可能会导致不可预测的问题。安装后，模型和其他文件可以存储在其他驱动器上。",
  parentMissing: "路径不存在 - 请先创建包含该路径的目录",
  pathExists: "目录已存在 - 请确保您已备份全部数据",
  pathValidationFailed: "路径验证失败",
  privacyPolicy: "隐私政策",
  selectItemsToMigrate: "选择要迁移的项目",
  settings: {
    allowMetrics: "使用情况指标",
    allowMetricsDescription: "通过发送匿名使用情况指标来帮助改进ComfyUI。不会收集任何个人信息或工作流内容。",
    autoUpdate: "自动更新",
    autoUpdateDescription: "更新可用时自动更新。您将在安装更新之前收到通知。",
    checkingMirrors: "正在检查到Python镜像的网络访问...",
    dataCollectionDialog: {
      collect: {
        errorReports: "错误报告和堆栈跟踪",
        systemInfo: "硬件，操作系统类型和应用版本",
        userJourneyEvents: "用户旅程事件"
      },
      doNotCollect: {
        customNodeConfigurations: "自定义节点配置",
        fileSystemInformation: "文件系统信息",
        personalInformation: "个人信息",
        workflowContents: "工作流内容"
      },
      title: "关于数据收集",
      viewFullPolicy: "查看完整政策",
      whatWeCollect: "我们收集的内容：",
      whatWeDoNotCollect: "我们不收集的内容："
    },
    errorUpdatingConsent: "更新同意错误",
    errorUpdatingConsentDetail: "无法更新度量同意设置",
    learnMoreAboutData: "了解更多关于数据收集的信息",
    mirrorSettings: "镜像设置",
    mirrorsReachable: "到Python镜像的网络访问良好",
    mirrorsUnreachable: "对某些python镜像的网络访问不佳",
    pypiMirrorPlaceholder: "输入PyPI镜像URL",
    pythonMirrorPlaceholder: "输入Python镜像URL"
  },
  systemLocations: "系统位置",
  unhandledError: "未知错误",
  updateConsent: "您之前选择了报告崩溃。我们现在正在跟踪基于事件的度量，以帮助识别错误并改进应用程序。我们不收集任何个人可识别信息。"
};
const issueReport = {
  contactFollowUp: "跟进联系我",
  feedbackTitle: "通过提供反馈帮助我们改进ComfyUI",
  helpFix: "帮助修复这个",
  notifyResolve: "解决时通知我",
  provideAdditionalDetails: "提供额外的详细信息（可选）",
  provideEmail: "提供您的电子邮件（可选）",
  rating: "评分",
  stackTrace: "堆栈跟踪",
  submitErrorReport: "提交错误报告（可选）",
  systemStats: "系统状态",
  validation: {
    invalidEmail: "请输入有效的电子邮件地址",
    maxLength: "消息过长"
  }
};
const load3d = {
  backgroundColor: "背景颜色",
  camera: "相机",
  edgeThreshold: "边缘阈值",
  "export": "导出",
  exportModel: "导出模型",
  exportingModel: "正在导出模型...",
  fov: "视场",
  light: "灯光",
  lightIntensity: "光照强度",
  loadingModel: "正在加载3D模型...",
  materialMode: "材料模式",
  model: "模型",
  previewOutput: "预览输出",
  removeBackgroundImage: "移除背景图片",
  scene: "场景",
  showGrid: "显示网格",
  switchCamera: "切换摄像头",
  switchingMaterialMode: "切换材质模式中...",
  upDirection: "向上方向",
  uploadBackgroundImage: "上传背景图片"
};
const maintenance = {
  None: "无",
  OK: "确定",
  Skipped: "跳过",
  allOk: "未检测到任何问题。",
  confirmTitle: "你确定吗？",
  consoleLogs: "控制台日志",
  detected: "检测到",
  error: {
    cannotContinue: "无法继续 - 仍有错误",
    defaultDescription: "运行维护任务时发生错误。",
    taskFailed: "任务运行失败。",
    toastTitle: "任务错误"
  },
  refreshing: "刷新中",
  showManual: "显示维护任务",
  status: "状态",
  terminalDefaultMessage: "当你运行一个故障排除命令时，任何输出都会在这里显示。",
  title: "维护"
};
const manager = {
  createdBy: "创建者",
  dependencies: "依赖关系",
  discoverCommunityContent: "发现社区制作的节点包，扩展等等...",
  downloads: "下载",
  errorConnecting: "连接到Comfy节点注册表时出错。",
  filter: {
    disabled: "已禁用",
    enabled: "已启用",
    nodePack: "节点包"
  },
  inWorkflow: "在工作流中",
  infoPanelEmpty: "点击一个项目查看信息",
  installSelected: "安装选定",
  lastUpdated: "最后更新",
  latestVersion: "最新",
  license: "许可证",
  loadingVersions: "正在加载版本...",
  nightlyVersion: "每夜",
  noDescription: "无可用描述",
  noResultsFound: "未找到符合您搜索的结果。",
  nodePack: "节点包",
  packsSelected: "选定的包",
  repository: "仓库",
  restartToApplyChanges: "要应用更改，请重新启动ComfyUI",
  searchPlaceholder: "搜索",
  selectVersion: "选择版本",
  sort: {
    downloads: "最受欢迎",
    rating: "评级"
  },
  status: {
    active: "活跃",
    banned: "已禁止",
    deleted: "已删除",
    flagged: "已标记",
    pending: "待定",
    unknown: "未知"
  },
  title: "自定义节点管理器",
  totalNodes: "节点总数",
  tryAgainLater: "请稍后再试。",
  tryDifferentSearch: "请尝试不同的搜索查询。",
  uninstall: "卸载",
  uninstallSelected: "卸载所选",
  uninstalling: "正在卸载",
  update: "更新",
  version: "版本"
};
const maskEditor = {
  "Apply to Whole Image": "应用到整个图像",
  "Brush Settings": "笔刷设置",
  "Brush Shape": "笔刷形状",
  Clear: "清空",
  "Color Select Settings": "颜色选择设置",
  "Fill Opacity": "填充不透明度",
  Hardness: "硬度",
  "Image Layer": "图像图层",
  Invert: "反转",
  Layers: "图层",
  "Live Preview": "实时预览",
  "Mask Layer": "遮罩图层",
  "Mask Opacity": "遮罩不透明度",
  "Mask Tolerance": "遮罩容差",
  Method: "方法",
  Opacity: "不透明度",
  "Paint Bucket Settings": "油漆桶设置",
  "Reset to Default": "恢复默认",
  "Selection Opacity": "选区不透明度",
  "Smoothing Precision": "平滑精度",
  "Stop at mask": "在遮罩处停止",
  Thickness: "粗细",
  Tolerance: "容差"
};
const menu = {
  autoQueue: "自动执行",
  batchCount: "批次数量",
  batchCountTooltip: "工作流生成次数",
  clear: "清空工作流",
  clipspace: "打开剪贴板",
  disabled: "禁用",
  disabledTooltip: "工作流将不会自动执行",
  execute: "执行",
  hideMenu: "隐藏菜单",
  instant: "实时",
  instantTooltip: "工作流将会在生成完成后立即执行",
  interrupt: "取消当前任务",
  onChange: "更改时",
  onChangeTooltip: "一旦进行更改，工作流将添加到执行队列",
  refresh: "刷新节点",
  resetView: "重置视图",
  run: "运行",
  runWorkflow: "运行工作流程（Shift排在前面）",
  runWorkflowFront: "运行工作流程（排在前面）",
  showMenu: "显示菜单",
  toggleBottomPanel: "底部面板"
};
const menuLabels = {
  "About ComfyUI": "关于ComfyUI",
  "Browse Templates": "浏览模板",
  "Bypass/Unbypass Selected Nodes": "忽略/取消忽略选定节点",
  "Canvas Toggle Link Visibility": "切换连线可见性",
  "Canvas Toggle Lock": "切换视图锁定",
  "Clear Pending Tasks": "清除待处理任务",
  "Clear Workflow": "清除工作流",
  Clipspace: "剪贴空间",
  "Close Current Workflow": "关闭当前工作流",
  "Collapse/Expand Selected Nodes": "折叠/展开选定节点",
  "Comfy-Org Discord": "Comfy-Org Discord",
  "ComfyUI Docs": "ComfyUI 文档",
  "ComfyUI Forum": "ComfyUI 论坛",
  "ComfyUI Issues": "ComfyUI 问题",
  "Convert selected nodes to group node": "将选中节点转换为组节点",
  "Custom Nodes Manager": "自定义节点管理器",
  "Delete Selected Items": "删除选定的项目",
  "Desktop User Guide": "桌面端用户指南",
  "Duplicate Current Workflow": "复制当前工作流",
  Edit: "编辑",
  Export: "导出",
  "Export (API)": "导出 (API)",
  "Fit Group To Contents": "适应组内容",
  "Fit view to selected nodes": "适应视图到选中节点",
  "Give Feedback": "提供反馈",
  "Group Selected Nodes": "将选中节点转换为组节点",
  Help: "帮助",
  Interrupt: "中断",
  "Load Default Workflow": "加载默认工作流",
  "Manage group nodes": "管理组节点",
  "Mute/Unmute Selected Nodes": "静音/取消静音选定节点",
  New: "新建",
  "Next Opened Workflow": "下一个打开的工作流",
  Open: "打开",
  "Open Custom Nodes Folder": "打开自定义节点文件夹",
  "Open DevTools": "打开开发者工具",
  "Open Inputs Folder": "打开输入文件夹",
  "Open Logs Folder": "打开日志文件夹",
  "Open Models Folder": "打开模型文件夹",
  "Open Outputs Folder": "打开输出文件夹",
  "Open extra_model_paths_yaml": "打开 extra_model_paths.yaml",
  "Pin/Unpin Selected Items": "固定/取消固定选定项目",
  "Pin/Unpin Selected Nodes": "固定/取消固定选定节点",
  "Previous Opened Workflow": "上一个打开的工作流",
  "Queue Prompt": "执行提示词",
  "Queue Prompt (Front)": "执行提示词 (优先执行)",
  Quit: "退出",
  Redo: "重做",
  "Refresh Node Definitions": "刷新节点定义",
  Reinstall: "重新安装",
  "Reset View": "重置视图",
  Restart: "重启",
  Save: "保存",
  "Save As": "另存为",
  "Show Settings Dialog": "显示设置对话框",
  "Toggle Bottom Panel": "切换底部面板",
  "Toggle Focus Mode": "切换专注模式",
  "Toggle Logs Bottom Panel": "切换日志底部面板",
  "Toggle Model Library Sidebar": "切换模型库侧边栏",
  "Toggle Node Library Sidebar": "切换节点库侧边栏",
  "Toggle Progress Dialog": "切换进度对话框",
  "Toggle Queue Sidebar": "切换队列侧边栏",
  "Toggle Search Box": "切换搜索框",
  "Toggle Terminal Bottom Panel": "切换终端底部面板",
  "Toggle Theme (Dark/Light)": "切换主题（暗/亮）",
  "Toggle Workflows Sidebar": "切换工作流侧边栏",
  Undo: "撤销",
  "Ungroup selected group nodes": "解散选中组节点",
  Workflow: "工作流",
  "Zoom In": "放大画面",
  "Zoom Out": "缩小画面"
};
const missingModelsDialog = {
  doNotAskAgain: "不再显示此消息",
  missingModels: "缺少模型",
  missingModelsMessage: "加载图表时，未找到以下模型"
};
const nodeCategories = {
  "3d": "3d",
  "3d_models": "3D模型",
  _for_testing: "_用于测试",
  advanced: "高级",
  animation: "动画",
  api: "API",
  attention_experiments: "注意力实验",
  audio: "音频",
  batch: "批处理",
  clip: "CLIP",
  combine: "组合",
  compositing: "合成",
  "cond pair": "条件对",
  "cond single": "条件单",
  conditioning: "条件",
  controlnet: "ControlNet",
  create: "创建",
  custom_sampling: "自定义采样",
  debug: "调试",
  deprecated: "已弃用",
  flux: "Flux",
  gligen: "GLIGEN",
  guidance: "引导",
  guiders: "引导器",
  hooks: "约束",
  image: "图像",
  inpaint: "局部重绘",
  instructpix2pix: "InstructPix2Pix",
  latent: "Latent",
  loaders: "加载器",
  ltxv: "LTXV",
  mask: "遮罩",
  model: "模型",
  model_merging: "模型合并",
  model_patches: "模型微调",
  model_specific: "模型特定",
  noise: "噪波",
  operations: "操作",
  photomaker: "PhotoMaker",
  postprocessing: "后处理",
  preprocessors: "预处理器",
  samplers: "采样器",
  sampling: "采样",
  schedulers: "调度器",
  scheduling: "调度",
  sd3: "SD3",
  sigmas: "Sigmas",
  stable_cascade: "StableCascade",
  style_model: "风格模型",
  transform: "变换",
  unet: "U-Net",
  upscale_diffusion: "放大扩散",
  upscaling: "放大",
  video: "视频",
  video_models: "视频模型"
};
const nodeTemplates = {
  enterName: "输入名称",
  saveAsTemplate: "另存为模板"
};
const notSupported = {
  "continue": "继续",
  continueTooltip: "我确定我的设备是受支持的",
  learnMore: "了解更多",
  message: "仅支持以下设备：",
  reportIssue: "报告问题",
  supportedDevices: {
    macos: "MacOS (M1 或更高版本)",
    windows: "Windows (支持 CUDA 的 Nvidia GPU)"
  },
  title: "您的设备不受支持"
};
const serverConfig = {
  modifiedConfigs: "您已修改以下服务器配置。重启以应用更改。",
  restart: "重启",
  revertChanges: "撤销更改"
};
const serverConfigCategories = {
  Attention: "注意力",
  CUDA: "CUDA",
  Cache: "缓存",
  Directories: "目录",
  General: "常规",
  Inference: "推理",
  Memory: "内存",
  Network: "网络",
  Preview: "预览"
};
const serverConfigItems = {
  "cache-classic": {
    name: "使用经典缓存系统"
  },
  "cache-lru": {
    name: "使用 LRU 缓存，最多缓存 N 个节点结果。",
    tooltip: "可能会使用更多的 RAM/VRAM。"
  },
  "cpu-vae": {
    name: "在 CPU 上运行 VAE"
  },
  "cross-attention-method": {
    name: "交叉注意力方法"
  },
  "cuda-device": {
    name: "要使用的 CUDA 设备索引"
  },
  "cuda-malloc": {
    name: "使用 CUDA malloc 进行内存分配"
  },
  "default-hashing-function": {
    name: "模型文件的默认哈希函数"
  },
  deterministic: {
    name: "使 pytorch 在可以时使用较慢的确定性算法。",
    tooltip: "请注意，这可能不会在所有情况下使图像具有确定性。"
  },
  directml: {
    name: "DirectML 设备索引"
  },
  "disable-all-custom-nodes": {
    name: "禁用加载所有自定义节点。"
  },
  "disable-ipex-optimize": {
    name: "禁用 IPEX 优化"
  },
  "disable-metadata": {
    name: "禁用在文件中保存提示元数据。"
  },
  "disable-smart-memory": {
    name: "禁用智能内存管理",
    tooltip: "强制 ComfyUI 在可以时将模型从 VRAM 移出到常规 RAM。"
  },
  "disable-xformers": {
    name: "禁用 xFormers 优化"
  },
  "dont-print-server": {
    name: "不将服务器输出打印到控制台。"
  },
  "dont-upcast-attention": {
    name: "不使用 upcast-attention"
  },
  "enable-cors-header": {
    name: '启用 CORS header：使用 "*" 代表所有来源或指定域名'
  },
  fast: {
    name: "启用一些未经测试且可能降低质量的优化。"
  },
  "force-channels-last": {
    name: "强制使用 channels-last 内存格式"
  },
  "force-upcast-attention": {
    name: "强制 upcast-attention"
  },
  "global-precision": {
    name: "全局浮点精度",
    tooltip: "全局浮点精度"
  },
  "input-directory": {
    name: "输入目录"
  },
  listen: {
    name: "主机：要监听的IP地址"
  },
  "log-level": {
    name: "日志详细级别"
  },
  "max-upload-size": {
    name: "最大上传大小 (MB)"
  },
  "output-directory": {
    name: "输出目录"
  },
  port: {
    name: "端口：要监听的端口"
  },
  "preview-method": {
    name: "用于潜空间预览的方法"
  },
  "preview-size": {
    name: "预览图像的大小"
  },
  "reserve-vram": {
    name: "保留 VRAM (GB)",
    tooltip: "设置您希望为操作系统/其他软件保留的 VRAM （GB）。默认会根据系统类型保留一定数量。"
  },
  "text-encoder-precision": {
    name: "文本编码器精度",
    tooltip: "文本编码器精度"
  },
  "tls-certfile": {
    name: "TLS 证书文件：HTTPS 的 TLS 证书文件路径"
  },
  "tls-keyfile": {
    name: "TLS 密钥文件：HTTPS 的 TLS 密钥文件路径"
  },
  "unet-precision": {
    name: "UNET 精度",
    tooltip: "UNET 精度"
  },
  "vae-precision": {
    name: "VAE 精度",
    tooltip: "VAE 精度"
  },
  "vram-management": {
    name: "VRAM 管理模式"
  }
};
const serverStart = {
  openLogs: "打开日志",
  process: {
    error: "无法启动 ComfyUI 桌面版",
    "initial-state": "加载中...",
    "python-setup": "正在设置 Python 环境...",
    ready: "完成中...",
    "starting-server": "正在启动 ComfyUI 服务器..."
  },
  reportIssue: "报告问题",
  showTerminal: "显示终端",
  troubleshoot: "故障排除"
};
const settingsCategories = {
  About: "关于",
  Appearance: "外观",
  BrushAdjustment: "画笔调整",
  Canvas: "画布",
  ColorPalette: "色彩主题",
  Comfy: "Comfy",
  "Comfy-Desktop": "Comfy桌面版",
  ContextMenu: "上下文菜单",
  CustomColorPalettes: "自定义色彩主题",
  DevMode: "开发模式",
  EditTokenWeight: "编辑令牌权重",
  Extension: "扩展",
  General: "常规",
  Graph: "画面",
  Group: "组节点",
  Keybinding: "快捷键",
  Link: "连线",
  LinkRelease: "释放链接",
  LiteGraph: "画面",
  Locale: "区域设置",
  "Mask Editor": "遮罩编辑器",
  Menu: "菜单",
  ModelLibrary: "模型库",
  NewEditor: "新编辑器",
  Node: "节点",
  "Node Search Box": "节点搜索框",
  "Node Widget": "节点组件",
  NodeInputConversionSubmenus: "节点输入转换子菜单",
  NodeLibrary: "节点库",
  Pointer: "指针",
  Queue: "队列",
  QueueButton: "执行按钮",
  RerouteBeta: "转接点 Beta",
  Server: "服务器",
  "Server-Config": "服务器配置",
  Settings: "设置",
  Sidebar: "侧边栏",
  "Tree Explorer": "树形浏览器",
  UV: "UV",
  Validation: "验证",
  Window: "窗口",
  Workflow: "工作流"
};
const sideToolbar = {
  browseTemplates: "浏览示例模板",
  downloads: "下载",
  logout: "登出",
  modelLibrary: "模型库",
  newBlankWorkflow: "创建空白工作流",
  nodeLibrary: "节点库",
  nodeLibraryTab: {
    sortOrder: "排序顺序"
  },
  openWorkflow: "在本地文件系统中打开工作流",
  queue: "队列",
  queueTab: {
    backToAllTasks: "返回",
    clearPendingTasks: "清除待处理任务",
    containImagePreview: "填充图像预览",
    coverImagePreview: "适应图像预览",
    filter: "过滤输出",
    filters: {
      hideCached: "隐藏缓存",
      hideCanceled: "隐藏已取消"
    },
    showFlatList: "平铺结果"
  },
  themeToggle: "主题切换",
  workflowTab: {
    confirmDelete: "您确定要删除此工作流吗？",
    confirmDeleteTitle: "删除工作流？",
    confirmOverwrite: "下面的文件已经存在。您想要覆盖它吗？",
    confirmOverwriteTitle: "覆盖现有文件？",
    deleteFailed: "尝试删除工作流失败。",
    deleteFailedTitle: "删除失败",
    deleted: "工作流已删除",
    dirtyClose: "以下文件已被更改。您想在关闭之前保存它们吗？",
    dirtyCloseHint: "按住 Shift 关闭而不提示",
    dirtyCloseTitle: "保存更改？",
    workflowTreeType: {
      bookmarks: "书签",
      browse: "浏览",
      open: "打开"
    }
  },
  workflows: "工作流"
};
const tabMenu = {
  addToBookmarks: "添加到书签",
  closeOtherTabs: "关闭其他标签",
  closeTab: "关闭标签",
  closeTabsToLeft: "关闭左侧标签",
  closeTabsToRight: "关闭右侧标签",
  duplicateTab: "复制标签",
  removeFromBookmarks: "从书签中移除"
};
const templateWorkflows = {
  category: {
    "3D": "3D",
    "Area Composition": "区域组成",
    Audio: "音频",
    Basics: "基础",
    "ComfyUI Examples": "ComfyUI示例",
    ControlNet: "ControlNet",
    "Custom Nodes": "自定义节点",
    Flux: "Flux",
    SD3_5: "SD3.5",
    SDXL: "SDXL",
    Upscaling: "放大",
    Video: "视频"
  },
  template: {
    "3D": {
      "hunyuan-3d-multiview-elf": "Hunyuan3D多视图",
      "hunyuan-3d-turbo": "Hunyuan3D Turbo",
      "hunyuan3d-non-multiview-train": "Hunyuan3D",
      stable_zero123_example: "稳定Zero123"
    },
    "Area Composition": {
      area_composition: "区域构成",
      area_composition_reversed: "反向区域构成",
      area_composition_square_area_for_subject: "主题的方形区域构成"
    },
    Audio: {
      stable_audio_example: "稳定音频"
    },
    Basics: {
      "default": "图像生成",
      embedding_example: "嵌入",
      gligen_textbox_example: "Gligen文本框",
      image2image: "图像到图像",
      inpain_model_outpainting: "Inpaint模型Outpainting",
      inpaint_example: "Inpaint",
      lora: "Lora",
      lora_multiple: "Lora多个"
    },
    ControlNet: {
      "2_pass_pose_worship": "2通道姿势崇拜",
      controlnet_example: "ControlNet",
      depth_controlnet: "深度ControlNet",
      depth_t2i_adapter: "深度T2I适配器",
      mixing_controlnets: "混合ControlNets"
    },
    Flux: {
      flux_canny_model_example: "Flux Canny Model",
      flux_depth_lora_example: "Flux Depth Lora",
      flux_dev_checkpoint_example: "Flux Dev的检查点示例",
      flux_fill_inpaint_example: "Flux Inpaint",
      flux_fill_outpaint_example: "Flux Outpaint",
      flux_redux_model_example: "Flux Redux Model",
      flux_schnell: "Flux Schnell"
    },
    SD3_5: {
      sd3_5_large_blur: "SD3.5 Large 模糊",
      sd3_5_large_canny_controlnet_example: "SD3.5 Large Canny 控制网",
      sd3_5_large_depth: "SD3.5 Large 深度",
      sd3_5_simple_example: "SD3.5 简易示例"
    },
    SDXL: {
      sdxl_refiner_prompt_example: "SDXL Refiner提示",
      sdxl_revision_text_prompts: "SDXL修订文本提示",
      sdxl_revision_zero_positive: "SDXL修订零正",
      sdxl_simple_example: "SDXL简单",
      sdxlturbo_example: "SDXL Turbo"
    },
    Upscaling: {
      esrgan_example: "ESRGAN",
      hiresfix_esrgan_workflow: "HiresFix ESRGAN工作流",
      hiresfix_latent_workflow: "HiresFix潜在工作流",
      latent_upscale_different_prompt_model: "潜在升级不同提示模型"
    },
    Video: {
      hunyuan_video_text_to_video: "Hunyuan视频文本到视频",
      image_to_video: "图像到视频",
      image_to_video_wan: "Wan 2.1 图像到视频",
      ltxv_image_to_video: "LTXV图像到视频",
      ltxv_text_to_video: "LTXV文本到视频",
      mochi_text_to_video_example: "Mochi文本到视频",
      text_to_video_wan: "Wan 2.1 文字到视频",
      txt_to_image_to_video: "文本到图像到视频"
    }
  },
  title: "从模板开始"
};
const userSelect = {
  enterUsername: "输入用户名",
  existingUser: "用户已存在",
  newUser: "新用户",
  next: "下一步",
  selectUser: "选择用户"
};
const welcome = {
  getStarted: "开始使用",
  title: "欢迎使用 ComfyUI"
};
const workflowService = {
  enterFilename: "输入文件名",
  exportWorkflow: "导出工作流",
  saveWorkflow: "保存工作流"
};
const zh = {
  clipboard,
  color,
  contextMenu,
  dataTypes,
  desktopMenu,
  desktopUpdate,
  downloadGit,
  electronFileDownload,
  g,
  graphCanvasMenu,
  groupNode,
  icon,
  install,
  issueReport,
  load3d,
  maintenance,
  manager,
  maskEditor,
  menu,
  menuLabels,
  missingModelsDialog,
  nodeCategories,
  nodeTemplates,
  notSupported,
  serverConfig,
  serverConfigCategories,
  serverConfigItems,
  serverStart,
  settingsCategories,
  sideToolbar,
  tabMenu,
  templateWorkflows,
  userSelect,
  welcome,
  workflowService
};
const AddNoise = {
  display_name: "添加噪波",
  inputs: {
    latent_image: {
      name: "Latent"
    },
    model: {
      name: "模型"
    },
    noise: {
      name: "噪波"
    },
    sigmas: {
      name: "Sigmas"
    }
  }
};
const AlignYourStepsScheduler = {
  display_name: "AlignYourSteps调度器",
  inputs: {
    denoise: {
      name: "降噪"
    },
    model_type: {
      name: "模型类型"
    },
    steps: {
      name: "步数"
    }
  }
};
const BasicGuider = {
  display_name: "基本引导器",
  inputs: {
    conditioning: {
      name: "条件"
    },
    model: {
      name: "模型"
    }
  }
};
const BasicScheduler = {
  display_name: "基本调度器",
  inputs: {
    denoise: {
      name: "降噪"
    },
    model: {
      name: "模型"
    },
    scheduler: {
      name: "调度器"
    },
    steps: {
      name: "步数"
    }
  }
};
const BetaSamplingScheduler = {
  display_name: "Beta采样调度器",
  inputs: {
    alpha: {
      name: "阿尔法"
    },
    beta: {
      name: "贝塔"
    },
    model: {
      name: "模型"
    },
    steps: {
      name: "步数"
    }
  }
};
const CFGGuider = {
  display_name: "CFG引导器",
  inputs: {
    cfg: {
      name: "CFG"
    },
    model: {
      name: "模型"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    }
  }
};
const CLIPAttentionMultiply = {
  display_name: "CLIP注意力相乘",
  inputs: {
    clip: {
      name: "clip"
    },
    k: {
      name: "k"
    },
    out: {
      name: "输出"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const CLIPLoader = {
  description: "[配方]\n\nStable Diffusion：clip-l\nStable Cascade：clip-g\nSD3：t5 / clip-g / clip-l\nStable Audio：t5\nMochi：t5\ncosmos：old t5 xxl",
  display_name: "加载CLIP",
  inputs: {
    clip_name: {
      name: "CLIP名称"
    },
    device: {
      name: "设备"
    },
    type: {
      name: "类型"
    }
  }
};
const CLIPMergeAdd = {
  display_name: "CLIP相加",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    }
  }
};
const CLIPMergeSimple = {
  display_name: "CLIP融合简易",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    ratio: {
      name: "比例"
    }
  }
};
const CLIPMergeSubtract = {
  display_name: "CLIP相减",
  inputs: {
    clip1: {
      name: "clip1"
    },
    clip2: {
      name: "clip2"
    },
    multiplier: {
      name: "乘数"
    }
  }
};
const CLIPSave = {
  display_name: "CLIP保存",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "文件名前缀"
    }
  }
};
const CLIPSetLastLayer = {
  display_name: "设置CLIP最后一层",
  inputs: {
    clip: {
      name: "clip"
    },
    stop_at_clip_layer: {
      name: "停止在CLIP层"
    }
  }
};
const CLIPTextEncode = {
  description: "使用 CLIP 模型将文本编码成嵌入组（embedding），用于引导扩散模型生成图像。",
  display_name: "CLIP文本编码",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "用于编码文本的 CLIP 模型。"
    },
    text: {
      name: "文本",
      tooltip: "要编码的文本。"
    }
  },
  outputs: {
    "0": {
      tooltip: "包含嵌入文本的条件，用于引导扩散模型。"
    }
  }
};
const CLIPTextEncodeControlnet = {
  display_name: "CLIP文本编码ControlNet",
  inputs: {
    clip: {
      name: "clip"
    },
    conditioning: {
      name: "条件"
    },
    text: {
      name: "文本"
    }
  }
};
const CLIPTextEncodeFlux = {
  display_name: "CLIP文本编码Flux",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_l: {
      name: "clip_l"
    },
    guidance: {
      name: "引导"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeHunyuanDiT = {
  display_name: "CLIP文本编码混元DiT",
  inputs: {
    bert: {
      name: "bert"
    },
    clip: {
      name: "clip"
    },
    mt5xl: {
      name: "mt5xl"
    }
  }
};
const CLIPTextEncodeLumina2 = {
  description: "使用CLIP模型将系统提示和用户提示编码成可以用来引导扩散模型生成特定图像的嵌入。",
  display_name: "Lumina2的CLIP文本编码",
  inputs: {
    clip: {
      name: "clip",
      tooltip: "用于编码文本的CLIP模型。"
    },
    system_prompt: {
      name: "system_prompt",
      tooltip: "Lumina2提供两种类型的系统提示：优越：你是一个设计来根据文本提示或用户提示生成优越图像的助手，这些图像具有基于文本提示的优越度的图像-文本对齐。对齐：你是一个设计来根据文本提示生成高质量图像的助手，这些图像具有基于文本提示的最高度的图像-文本对齐。"
    },
    user_prompt: {
      name: "user_prompt",
      tooltip: "需要编码的文本。"
    }
  },
  outputs: {
    "0": {
      tooltip: "包含用于引导扩散模型的嵌入文本的条件。"
    }
  }
};
const CLIPTextEncodePixArtAlpha = {
  description: "编码文本并设置PixArt Alpha的分辨率条件。不适用于PixArt Sigma。",
  display_name: "CLIPTextEncodePixArtAlpha",
  inputs: {
    clip: {
      name: "剪辑"
    },
    height: {
      name: "高度"
    },
    text: {
      name: "文本"
    },
    width: {
      name: "宽度"
    }
  }
};
const CLIPTextEncodeSD3 = {
  display_name: "CLIP文本编码SD3",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_g: {
      name: "clip_g"
    },
    clip_l: {
      name: "clip_l"
    },
    empty_padding: {
      name: "空白填充"
    },
    t5xxl: {
      name: "t5xxl"
    }
  }
};
const CLIPTextEncodeSDXL = {
  display_name: "CLIP文本编码SDXL",
  inputs: {
    clip: {
      name: "clip"
    },
    crop_h: {
      name: "裁剪高"
    },
    crop_w: {
      name: "裁剪宽"
    },
    height: {
      name: "高度"
    },
    target_height: {
      name: "目标高度"
    },
    target_width: {
      name: "目标宽度"
    },
    text_g: {
      name: "文本_g"
    },
    text_l: {
      name: "文本_l"
    },
    width: {
      name: "宽度"
    }
  }
};
const CLIPTextEncodeSDXLRefiner = {
  display_name: "CLIP文本编码SDXL精炼器",
  inputs: {
    ascore: {
      name: "美学分数"
    },
    clip: {
      name: "clip"
    },
    height: {
      name: "高度"
    },
    text: {
      name: "文本"
    },
    width: {
      name: "宽度"
    }
  }
};
const CLIPVisionEncode = {
  display_name: "CLIP视觉编码",
  inputs: {
    clip_vision: {
      name: "clip视觉"
    },
    crop: {
      name: "裁剪"
    },
    image: {
      name: "图像"
    }
  }
};
const CLIPVisionLoader = {
  display_name: "加载CLIP视觉",
  inputs: {
    clip_name: {
      name: "clip名称"
    }
  }
};
const Canny = {
  display_name: "Canny边缘检测",
  inputs: {
    high_threshold: {
      name: "高阈值"
    },
    image: {
      name: "图像"
    },
    low_threshold: {
      name: "低阈值"
    }
  }
};
const CheckpointLoader = {
  display_name: "Ckeckpoint加载器（已弃用）",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称"
    },
    config_name: {
      name: "配置名称"
    }
  }
};
const CheckpointLoaderSimple = {
  description: "加载扩散模型 Checkpoint，用于去除 Latent 噪波。",
  display_name: "Checkpoint加载器（简易）",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称",
      tooltip: "要加载的Checkpoint模型的名称。"
    }
  },
  outputs: {
    "0": {
      tooltip: "用于去除 Latent 噪波的模型。"
    },
    "1": {
      tooltip: "用于编码文本提示的 CLIP 模型。"
    },
    "2": {
      tooltip: "用于将图像编码和解码到 Latent 的 VAE 模型。"
    }
  }
};
const CheckpointSave = {
  display_name: "保存Checkpoint",
  inputs: {
    clip: {
      name: "clip"
    },
    filename_prefix: {
      name: "文件名前缀"
    },
    model: {
      name: "模型"
    },
    vae: {
      name: "vae"
    }
  }
};
const CombineHooks2 = {
  display_name: "组合约束 [2]",
  inputs: {
    hooks_A: {
      name: "约束_A"
    },
    hooks_B: {
      name: "约束_B"
    }
  }
};
const CombineHooks4 = {
  display_name: "组合约束 [4]",
  inputs: {
    hooks_A: {
      name: "约束_A"
    },
    hooks_B: {
      name: "约束_B"
    },
    hooks_C: {
      name: "约束_C"
    },
    hooks_D: {
      name: "约束_D"
    }
  }
};
const CombineHooks8 = {
  display_name: "组合约束 [8]",
  inputs: {
    hooks_A: {
      name: "约束_A"
    },
    hooks_B: {
      name: "约束_B"
    },
    hooks_C: {
      name: "约束_C"
    },
    hooks_D: {
      name: "约束_D"
    },
    hooks_E: {
      name: "约束_E"
    },
    hooks_F: {
      name: "约束_F"
    },
    hooks_G: {
      name: "约束_G"
    },
    hooks_H: {
      name: "约束_H"
    }
  }
};
const ConditioningAverage = {
  display_name: "条件平均",
  inputs: {
    conditioning_from: {
      name: "条件从"
    },
    conditioning_to: {
      name: "条件到"
    },
    conditioning_to_strength: {
      name: "条件到强度"
    }
  }
};
const ConditioningCombine = {
  display_name: "条件合并",
  inputs: {
    conditioning_1: {
      name: "条件_1"
    },
    conditioning_2: {
      name: "条件_2"
    }
  }
};
const ConditioningConcat = {
  display_name: "条件连接",
  inputs: {
    conditioning_from: {
      name: "条件从"
    },
    conditioning_to: {
      name: "条件到"
    }
  }
};
const ConditioningSetArea = {
  display_name: "条件采样区域",
  inputs: {
    conditioning: {
      name: "条件"
    },
    height: {
      name: "高度"
    },
    strength: {
      name: "强度"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentage = {
  display_name: "条件采样区域（系数）",
  inputs: {
    conditioning: {
      name: "条件化"
    },
    height: {
      name: "高度"
    },
    strength: {
      name: "强度"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ConditioningSetAreaPercentageVideo = {
  display_name: "调节设置区域百分比视频",
  inputs: {
    conditioning: {
      name: "调节"
    },
    height: {
      name: "高度"
    },
    strength: {
      name: "强度"
    },
    temporal: {
      name: "时间"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    },
    z: {
      name: "z"
    }
  }
};
const ConditioningSetAreaStrength = {
  display_name: "条件采样区域强度",
  inputs: {
    conditioning: {
      name: "条件化"
    },
    strength: {
      name: "强度"
    }
  }
};
const ConditioningSetDefaultCombine = {
  display_name: "条件设置默认合并",
  inputs: {
    cond: {
      name: "条件"
    },
    cond_DEFAULT: {
      name: "默认条件"
    },
    hooks: {
      name: "约束"
    }
  }
};
const ConditioningSetMask = {
  display_name: "条件遮罩",
  inputs: {
    conditioning: {
      name: "条件化"
    },
    mask: {
      name: "遮罩"
    },
    set_cond_area: {
      name: "设置条件区域"
    },
    strength: {
      name: "强度"
    }
  }
};
const ConditioningSetProperties = {
  display_name: "条件设置属性",
  inputs: {
    cond_NEW: {
      name: "新条件"
    },
    hooks: {
      name: "约束"
    },
    mask: {
      name: "遮罩"
    },
    set_cond_area: {
      name: "设置条件区域"
    },
    strength: {
      name: "强度"
    },
    timesteps: {
      name: "间隔"
    }
  }
};
const ConditioningSetPropertiesAndCombine = {
  display_name: "条件设置属性合并",
  inputs: {
    cond: {
      name: "条件"
    },
    cond_NEW: {
      name: "新条件"
    },
    hooks: {
      name: "约束"
    },
    mask: {
      name: "遮罩"
    },
    set_cond_area: {
      name: "设置条件区域"
    },
    strength: {
      name: "强度"
    },
    timesteps: {
      name: "间隔"
    }
  }
};
const ConditioningSetTimestepRange = {
  display_name: "设置条件时间",
  inputs: {
    conditioning: {
      name: "条件"
    },
    end: {
      name: "结束"
    },
    start: {
      name: "开始"
    }
  }
};
const ConditioningStableAudio = {
  display_name: "StableAudio条件",
  inputs: {
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    },
    seconds_start: {
      name: "开始秒数"
    },
    seconds_total: {
      name: "总秒数"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const ConditioningTimestepsRange = {
  display_name: "条件间隔范围",
  inputs: {
    end_percent: {
      name: "结束百分比"
    },
    start_percent: {
      name: "开始百分比"
    }
  },
  outputs: {
    "1": {
      name: "范围前"
    },
    "2": {
      name: "范围后"
    }
  }
};
const ConditioningZeroOut = {
  display_name: "条件零化",
  inputs: {
    conditioning: {
      name: "条件"
    }
  }
};
const ControlNetApply = {
  display_name: "应用ControlNet（旧版）",
  inputs: {
    conditioning: {
      name: "条件"
    },
    control_net: {
      name: "ControlNet"
    },
    image: {
      name: "图像"
    },
    strength: {
      name: "强度"
    }
  }
};
const ControlNetApplyAdvanced = {
  display_name: "应用ControlNet（旧版高级）",
  inputs: {
    control_net: {
      name: "ControlNet"
    },
    end_percent: {
      name: "结束百分比"
    },
    image: {
      name: "图像"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    },
    start_percent: {
      name: "开始百分比"
    },
    strength: {
      name: "强度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const ControlNetApplySD3 = {
  display_name: "应用ControlNet",
  inputs: {
    control_net: {
      name: "ControlNet"
    },
    end_percent: {
      name: "结束百分比"
    },
    image: {
      name: "图像"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    },
    start_percent: {
      name: "开始百分比"
    },
    strength: {
      name: "强度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const ControlNetInpaintingAliMamaApply = {
  display_name: "应用ControlNet（阿里妈妈局部重绘）",
  inputs: {
    control_net: {
      name: "ControlNet"
    },
    end_percent: {
      name: "结束百分比"
    },
    image: {
      name: "图像"
    },
    mask: {
      name: "遮罩"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    },
    start_percent: {
      name: "开始百分比"
    },
    strength: {
      name: "强度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const ControlNetLoader = {
  display_name: "加载ControlNet模型",
  inputs: {
    control_net_name: {
      name: "ControlNet名称"
    }
  }
};
const CosmosImageToVideoLatent = {
  display_name: "Cosmos图像到视频潜在",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    end_image: {
      name: "结束图像"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    start_image: {
      name: "开始图像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  }
};
const CreateHookKeyframe = {
  display_name: "创建约束关键帧",
  inputs: {
    prev_hook_kf: {
      name: "前一个约束关键帧"
    },
    start_percent: {
      name: "开始百分比"
    },
    strength_mult: {
      name: "强度倍数"
    }
  },
  outputs: {
    "0": {
      name: "约束关键帧"
    }
  }
};
const CreateHookKeyframesFromFloats = {
  display_name: "从浮点数创建约束关键帧",
  inputs: {
    end_percent: {
      name: "结束百分比"
    },
    floats_strength: {
      name: "浮点强度"
    },
    prev_hook_kf: {
      name: "前一个约束关键帧"
    },
    print_keyframes: {
      name: "打印关键帧"
    },
    start_percent: {
      name: "开始百分比"
    }
  },
  outputs: {
    "0": {
      name: "约束关键帧"
    }
  }
};
const CreateHookKeyframesInterpolated = {
  display_name: "创建约束关键帧插值",
  inputs: {
    end_percent: {
      name: "结束百分比"
    },
    interpolation: {
      name: "插值"
    },
    keyframes_count: {
      name: "关键帧数量"
    },
    prev_hook_kf: {
      name: "前一个约束关键帧"
    },
    print_keyframes: {
      name: "打印关键帧"
    },
    start_percent: {
      name: "开始百分比"
    },
    strength_end: {
      name: "结束强度"
    },
    strength_start: {
      name: "开始强度"
    }
  },
  outputs: {
    "0": {
      name: "约束关键帧"
    }
  }
};
const CreateHookLora = {
  display_name: "创建约束LoRA",
  inputs: {
    lora_name: {
      name: "LoRA名称"
    },
    prev_hooks: {
      name: "前一个约束"
    },
    strength_clip: {
      name: "CLIP强度"
    },
    strength_model: {
      name: "模型强度"
    }
  }
};
const CreateHookLoraModelOnly = {
  display_name: "创建约束LoRA（仅模型）",
  inputs: {
    lora_name: {
      name: "LoRA名称"
    },
    prev_hooks: {
      name: "前一个约束"
    },
    strength_model: {
      name: "模型强度"
    }
  }
};
const CreateHookModelAsLora = {
  display_name: "创建约束模型为LoRA",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称"
    },
    prev_hooks: {
      name: "前一个约束"
    },
    strength_clip: {
      name: "CLIP强度"
    },
    strength_model: {
      name: "模型强度"
    }
  }
};
const CreateHookModelAsLoraModelOnly = {
  display_name: "创建约束模型为LoRA（仅模型）",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称"
    },
    prev_hooks: {
      name: "前一个约束"
    },
    strength_model: {
      name: "模型强度"
    }
  }
};
const CropMask = {
  display_name: "裁剪遮罩",
  inputs: {
    height: {
      name: "高度"
    },
    mask: {
      name: "遮罩"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const DiffControlNetLoader = {
  display_name: "加载ControlNet模型（diff）",
  inputs: {
    control_net_name: {
      name: "ControlNet名称"
    },
    model: {
      name: "模型"
    }
  }
};
const DifferentialDiffusion = {
  display_name: "差异扩散DifferentialDiffusion",
  inputs: {
    model: {
      name: "模型"
    }
  }
};
const DiffusersLoader = {
  display_name: "Diffusers加载器",
  inputs: {
    model_path: {
      name: "模型路径"
    }
  }
};
const DisableNoise = {
  display_name: "禁用噪波"
};
const DualCFGGuider = {
  display_name: "双CFG引导器",
  inputs: {
    cfg_cond2_negative: {
      name: "cfg_条件2_负面"
    },
    cfg_conds: {
      name: "cfg_条件1"
    },
    cond1: {
      name: "条件1"
    },
    cond2: {
      name: "条件2"
    },
    model: {
      name: "模型"
    },
    negative: {
      name: "负面条件"
    }
  }
};
const DualCLIPLoader = {
  description: "[配方]\n\nSDXL：clip-l，clip-g\nSD3：clip-l，clip-g / clip-l，t5 / clip-g，t5\nFlux：clip-l，t5",
  display_name: "双CLIP加载器",
  inputs: {
    clip_name1: {
      name: "CLIP名称1"
    },
    clip_name2: {
      name: "CLIP名称2"
    },
    device: {
      name: "设备"
    },
    type: {
      name: "类型"
    }
  }
};
const EmptyCosmosLatentVideo = {
  display_name: "空的Cosmos潜在视频",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    width: {
      name: "宽度"
    }
  }
};
const EmptyHunyuanLatentVideo = {
  display_name: "空Latent视频（混元）",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    width: {
      name: "宽度"
    }
  }
};
const EmptyImage = {
  display_name: "空图像",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    color: {
      name: "颜色"
    },
    height: {
      name: "高度"
    },
    width: {
      name: "宽度"
    }
  }
};
const EmptyLTXVLatentVideo = {
  display_name: "空Latent视频（LTXV）",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    width: {
      name: "宽度"
    }
  }
};
const EmptyLatentAudio = {
  display_name: "空Latent音频",
  inputs: {
    batch_size: {
      name: "批量大小",
      tooltip: "批次中的Latent数量。"
    },
    seconds: {
      name: "秒"
    }
  }
};
const EmptyLatentHunyuan3Dv2 = {
  display_name: "EmptyLatentHunyuan3Dv2",
  inputs: {
    batch_size: {
      name: "批量大小",
      tooltip: "批量中的潜在图像数量。"
    },
    resolution: {
      name: "分辨率"
    }
  }
};
const EmptyLatentImage = {
  description: "创建一批新的空Latent图像，以通过采样进行降噪。",
  display_name: "空Latent图像",
  inputs: {
    batch_size: {
      name: "批量大小",
      tooltip: "批次中的Latent数量。"
    },
    height: {
      name: "高度",
      tooltip: "Latent图像的高度（像素）。"
    },
    width: {
      name: "宽度",
      tooltip: "Latent图像的宽度（像素）。"
    }
  },
  outputs: {
    "0": {
      tooltip: "空Latent图像批次。"
    }
  }
};
const EmptyMochiLatentVideo = {
  display_name: "空Latent视频（Mochi）",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    width: {
      name: "宽度"
    }
  }
};
const EmptySD3LatentImage = {
  display_name: "空Latent图像（SD3）",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    width: {
      name: "宽度"
    }
  }
};
const ExponentialScheduler = {
  display_name: "Exponential调度器",
  inputs: {
    sigma_max: {
      name: "最大Sigma"
    },
    sigma_min: {
      name: "最新Sigma"
    },
    steps: {
      name: "步数"
    }
  }
};
const FeatherMask = {
  display_name: "羽化遮罩",
  inputs: {
    bottom: {
      name: "底"
    },
    left: {
      name: "左"
    },
    mask: {
      name: "遮罩"
    },
    right: {
      name: "右"
    },
    top: {
      name: "顶"
    }
  }
};
const FlipSigmas = {
  display_name: "翻转Sigma",
  inputs: {
    sigmas: {
      name: "sigmas"
    }
  }
};
const FluxDisableGuidance = {
  description: "此节点完全禁用Flux和类似Flux模型上的指导嵌入",
  display_name: "Flux禁用指导",
  inputs: {
    conditioning: {
      name: "conditioning"
    }
  }
};
const FluxGuidance = {
  display_name: "Flux引导",
  inputs: {
    conditioning: {
      name: "条件"
    },
    guidance: {
      name: "引导"
    }
  }
};
const FreeU = {
  display_name: "FreeU",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "模型"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const FreeU_V2 = {
  display_name: "FreeU_V2",
  inputs: {
    b1: {
      name: "b1"
    },
    b2: {
      name: "b2"
    },
    model: {
      name: "模型"
    },
    s1: {
      name: "s1"
    },
    s2: {
      name: "s2"
    }
  }
};
const GITSScheduler = {
  display_name: "GITS调度器",
  inputs: {
    coeff: {
      name: "系数"
    },
    denoise: {
      name: "降噪"
    },
    steps: {
      name: "步数"
    }
  }
};
const GLIGENLoader = {
  display_name: "GLIGEN加载器",
  inputs: {
    gligen_name: {
      name: "gligen名称"
    }
  }
};
const GLIGENTextBoxApply = {
  display_name: "GLIGEN文本框应用",
  inputs: {
    clip: {
      name: "CLIPCLIP"
    },
    conditioning_to: {
      name: "条件到"
    },
    gligen_textbox_model: {
      name: "GLIGEN文本框模型"
    },
    height: {
      name: "高度"
    },
    text: {
      name: "文本"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const GrowMask = {
  display_name: "扩展遮罩",
  inputs: {
    expand: {
      name: "扩展"
    },
    mask: {
      name: "遮罩"
    },
    tapered_corners: {
      name: "倒角"
    }
  }
};
const Hunyuan3Dv2Conditioning = {
  display_name: "Hunyuan3Dv2Conditioning",
  inputs: {
    clip_vision_output: {
      name: "clip视觉输出"
    }
  },
  outputs: {
    "0": {
      name: "正向"
    },
    "1": {
      name: "反向"
    }
  }
};
const Hunyuan3Dv2ConditioningMultiView = {
  display_name: "Hunyuan3Dv2ConditioningMultiView",
  inputs: {
    back: {
      name: "后"
    },
    front: {
      name: "前"
    },
    left: {
      name: "左"
    },
    right: {
      name: "右"
    }
  },
  outputs: {
    "0": {
      name: "正向"
    },
    "1": {
      name: "反向"
    }
  }
};
const HunyuanImageToVideo = {
  display_name: "Hunyuan图像到视频",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    guidance_type: {
      name: "指导类型"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    positive: {
      name: "正向"
    },
    start_image: {
      name: "起始图像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正向"
    },
    "1": {
      name: "潜在空间"
    }
  }
};
const HyperTile = {
  display_name: "超分块HyperTile",
  inputs: {
    max_depth: {
      name: "最大深度"
    },
    model: {
      name: "模型"
    },
    scale_depth: {
      name: "规模深度"
    },
    swap_size: {
      name: "分割尺寸"
    },
    tile_size: {
      name: "分块尺寸"
    }
  }
};
const HypernetworkLoader = {
  display_name: "超网络加载器",
  inputs: {
    hypernetwork_name: {
      name: "HyperNetwork名称"
    },
    model: {
      name: "模型"
    },
    strength: {
      name: "强度"
    }
  }
};
const ImageBatch = {
  display_name: "组合图像批次",
  inputs: {
    image1: {
      name: "图像1"
    },
    image2: {
      name: "图像2"
    }
  }
};
const ImageBlend = {
  display_name: "混合图像",
  inputs: {
    blend_factor: {
      name: "系数"
    },
    blend_mode: {
      name: "混合模式"
    },
    image1: {
      name: "图像1"
    },
    image2: {
      name: "图像2"
    }
  }
};
const ImageBlur = {
  display_name: "模糊图像",
  inputs: {
    blur_radius: {
      name: "模糊半径"
    },
    image: {
      name: "图像"
    },
    sigma: {
      name: "西格玛"
    }
  }
};
const ImageColorToMask = {
  display_name: "图像颜色到遮罩",
  inputs: {
    color: {
      name: "颜色"
    },
    image: {
      name: "图像"
    }
  }
};
const ImageCompositeMasked = {
  display_name: "合成图像（遮罩）",
  inputs: {
    destination: {
      name: "目标图像"
    },
    mask: {
      name: "遮罩"
    },
    resize_source: {
      name: "缩放来源图像"
    },
    source: {
      name: "来源图像"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageCrop = {
  display_name: "裁剪图像",
  inputs: {
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const ImageFromBatch = {
  display_name: "从批次获取图像",
  inputs: {
    batch_index: {
      name: "批次索引"
    },
    image: {
      name: "图像"
    },
    length: {
      name: "长度"
    }
  }
};
const ImageInvert = {
  display_name: "反转图像",
  inputs: {
    image: {
      name: "图像"
    }
  }
};
const ImageOnlyCheckpointLoader = {
  display_name: "Checkpoint加载器（仅图像）",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称"
    }
  }
};
const ImageOnlyCheckpointSave = {
  display_name: "保存Checkpoint（仅图像）",
  inputs: {
    clip_vision: {
      name: "clip视觉"
    },
    filename_prefix: {
      name: "文件名前缀"
    },
    model: {
      name: "模型"
    },
    vae: {
      name: "vae"
    }
  }
};
const ImagePadForOutpaint = {
  display_name: "外补画板",
  inputs: {
    bottom: {
      name: "下"
    },
    feathering: {
      name: "羽化"
    },
    image: {
      name: "图像"
    },
    left: {
      name: "左"
    },
    right: {
      name: "右"
    },
    top: {
      name: "上"
    }
  }
};
const ImageQuantize = {
  display_name: "量化图像",
  inputs: {
    colors: {
      name: "颜色"
    },
    dither: {
      name: "抖动"
    },
    image: {
      name: "图像"
    }
  }
};
const ImageScale = {
  display_name: "缩放图像",
  inputs: {
    crop: {
      name: "裁剪"
    },
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    upscale_method: {
      name: "缩放算法"
    },
    width: {
      name: "宽度"
    }
  }
};
const ImageScaleBy = {
  display_name: "缩放图像（比例）",
  inputs: {
    image: {
      name: "图像"
    },
    scale_by: {
      name: "缩放系数"
    },
    upscale_method: {
      name: "缩放算法"
    }
  }
};
const ImageScaleToTotalPixels = {
  display_name: "缩放图像（像素）",
  inputs: {
    image: {
      name: "图像"
    },
    megapixels: {
      name: "像素数量"
    },
    upscale_method: {
      name: "缩放算法"
    }
  }
};
const ImageSharpen = {
  display_name: "锐化图像",
  inputs: {
    alpha: {
      name: "alpha"
    },
    image: {
      name: "图像"
    },
    sharpen_radius: {
      name: "锐化半径"
    },
    sigma: {
      name: "Sigma"
    }
  }
};
const ImageToMask = {
  display_name: "图像转换为遮罩",
  inputs: {
    channel: {
      name: "通道"
    },
    image: {
      name: "图像"
    }
  }
};
const ImageUpscaleWithModel = {
  display_name: "使用模型放大图像",
  inputs: {
    image: {
      name: "图像"
    },
    upscale_model: {
      name: "放大模型"
    }
  }
};
const InpaintModelConditioning = {
  display_name: "内补模型条件",
  inputs: {
    mask: {
      name: "遮罩"
    },
    negative: {
      name: "负面条件"
    },
    noise_mask: {
      name: "噪波遮罩",
      tooltip: "向Latent图像添加遮罩，采样仅在遮罩内进行。根据模型的不同，可能会改善结果或完全破坏效果。"
    },
    pixels: {
      name: "像素"
    },
    positive: {
      name: "正面条件"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const InstructPixToPixConditioning = {
  display_name: "InstructPixToPix条件",
  inputs: {
    negative: {
      name: "负面条件"
    },
    pixels: {
      name: "像素"
    },
    positive: {
      name: "正面条件"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const InvertMask = {
  display_name: "反转遮罩",
  inputs: {
    mask: {
      name: "遮罩"
    }
  }
};
const JoinImageWithAlpha = {
  display_name: "合并图像Alpha",
  inputs: {
    alpha: {
      name: "阿尔法"
    },
    image: {
      name: "图像"
    }
  }
};
const KSampler = {
  description: "使用提供的模型、正面条件和负面条件条件降噪Latent图像。",
  display_name: "K采样器",
  inputs: {
    cfg: {
      name: "cfg",
      tooltip: "用于平衡随机性和提示词服从性。提高该值会使结果更加符合提示词，但过高会导致图像质量下降。"
    },
    control_after_generate: {
      name: "生成后的控制"
    },
    denoise: {
      name: "降噪",
      tooltip: "降噪的强度，降低该值会保留原图的大部分内容从而实现图生图。"
    },
    latent_image: {
      name: "Latent图像",
      tooltip: "要降噪的 Latent 图像。"
    },
    model: {
      name: "模型",
      tooltip: "用于降噪输入 Latent 图像的模型。"
    },
    negative: {
      name: "负面条件",
      tooltip: "描述不包含在图像中的内容的条件。"
    },
    positive: {
      name: "正面条件",
      tooltip: "描述包含在图像中的内容的条件。"
    },
    sampler_name: {
      name: "采样器名称",
      tooltip: "采样算法，会影响结果质量、生成速度、风格样式。"
    },
    scheduler: {
      name: "调度器",
      tooltip: "控制逐渐移除噪波的方法。"
    },
    seed: {
      name: "种子",
      tooltip: "生成噪波的随机种。"
    },
    steps: {
      name: "步数",
      tooltip: "降噪的步数。"
    }
  },
  outputs: {
    "0": {
      tooltip: "降噪后的 Latent。"
    }
  }
};
const KSamplerAdvanced = {
  display_name: "K采样器（高级）",
  inputs: {
    add_noise: {
      name: "添加噪波"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "生成后的控制"
    },
    end_at_step: {
      name: "结束步数"
    },
    latent_image: {
      name: "Latent图像"
    },
    model: {
      name: "模型"
    },
    negative: {
      name: "负面条件"
    },
    noise_seed: {
      name: "随机种"
    },
    positive: {
      name: "正面条件"
    },
    return_with_leftover_noise: {
      name: "返回剩余噪波"
    },
    sampler_name: {
      name: "采样器名称"
    },
    scheduler: {
      name: "调度器"
    },
    start_at_step: {
      name: "开始步数"
    },
    steps: {
      name: "步数"
    }
  }
};
const KSamplerSelect = {
  display_name: "K采样器选择",
  inputs: {
    sampler_name: {
      name: "采样器名称"
    }
  }
};
const KarrasScheduler = {
  display_name: "Karras调度器",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "步数"
    }
  }
};
const LTXVAddGuide = {
  display_name: "LTXV添加指导",
  inputs: {
    frame_idx: {
      name: "帧索引",
      tooltip: "开始调节的帧索引。对于单帧图像或1-8帧的视频，任何帧索引值都可以接受。对于9+帧的视频，帧索引必须能被8整除，否则它将被向下取整到最接近的8的倍数。负值从视频的末尾开始计算。"
    },
    image: {
      name: "图像",
      tooltip: "用于调节潜在视频的图像或视频。必须是8*n + 1帧。如果视频不是8*n + 1帧，它将被裁剪到最接近的8*n + 1帧。"
    },
    latent: {
      name: "潜在空间"
    },
    negative: {
      name: "负向"
    },
    positive: {
      name: "正向"
    },
    strength: {
      name: "强度"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "正向"
    },
    "1": {
      name: "负向"
    },
    "2": {
      name: "潜在空间"
    }
  }
};
const LTXVConditioning = {
  display_name: "LTXV条件",
  inputs: {
    frame_rate: {
      name: "帧率"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const LTXVCropGuides = {
  display_name: "LTXV裁剪指导",
  inputs: {
    latent: {
      name: "潜在空间"
    },
    negative: {
      name: "负向"
    },
    positive: {
      name: "正向"
    }
  },
  outputs: {
    "0": {
      name: "正向"
    },
    "1": {
      name: "负向"
    },
    "2": {
      name: "潜在空间"
    }
  }
};
const LTXVImgToVideo = {
  display_name: "LTXV图像到视频",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    length: {
      name: "长度"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const LTXVPreprocess = {
  display_name: "LTXV预处理",
  inputs: {
    image: {
      name: "图像"
    },
    img_compression: {
      name: "图像压缩",
      tooltip: "应用于图像的压缩量。"
    }
  },
  outputs: {
    "0": {
      name: "输出图像"
    }
  }
};
const LTXVScheduler = {
  display_name: "LTXV调度器",
  inputs: {
    base_shift: {
      name: "基础移位"
    },
    latent: {
      name: "Latent"
    },
    max_shift: {
      name: "最大移位"
    },
    steps: {
      name: "步数"
    },
    stretch: {
      name: "拉伸",
      tooltip: "将 sigma 拉伸到范围 [终值, 1]。"
    },
    terminal: {
      name: "终值",
      tooltip: "拉伸后 sigma 的终值。"
    }
  }
};
const LaplaceScheduler = {
  display_name: "Laplace调度器",
  inputs: {
    beta: {
      name: "beta"
    },
    mu: {
      name: "mu"
    },
    sigma_max: {
      name: "sigma_max"
    },
    sigma_min: {
      name: "sigma_min"
    },
    steps: {
      name: "步数"
    }
  }
};
const LatentAdd = {
  display_name: "Latent相加",
  inputs: {
    samples1: {
      name: "Latent1"
    },
    samples2: {
      name: "Latent2"
    }
  }
};
const LatentApplyOperation = {
  display_name: "Latent应用操作",
  inputs: {
    operation: {
      name: "操作"
    },
    samples: {
      name: "Latent"
    }
  }
};
const LatentApplyOperationCFG = {
  display_name: "Latent应用操作CFG",
  inputs: {
    model: {
      name: "模型"
    },
    operation: {
      name: "操作"
    }
  }
};
const LatentBatch = {
  display_name: "组合Latent批次",
  inputs: {
    samples1: {
      name: "Latent1"
    },
    samples2: {
      name: "Latent2"
    }
  }
};
const LatentBatchSeedBehavior = {
  display_name: "Latent批处理随机种行为",
  inputs: {
    samples: {
      name: "Latent"
    },
    seed_behavior: {
      name: "随机种行为"
    }
  }
};
const LatentBlend = {
  display_name: "混合Latent",
  inputs: {
    blend_factor: {
      name: "系数"
    },
    samples1: {
      name: "Latent1"
    },
    samples2: {
      name: "Latent2"
    }
  }
};
const LatentComposite = {
  display_name: "合成Latent",
  inputs: {
    feather: {
      name: "羽化"
    },
    samples_from: {
      name: "Latent从"
    },
    samples_to: {
      name: "Latent到"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCompositeMasked = {
  display_name: "合成Latent遮罩",
  inputs: {
    destination: {
      name: "目标Latent"
    },
    mask: {
      name: "遮罩"
    },
    resize_source: {
      name: "调整来源大小"
    },
    source: {
      name: "来源Latent"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentCrop = {
  display_name: "裁剪Latent",
  inputs: {
    height: {
      name: "高度"
    },
    samples: {
      name: "Latent"
    },
    width: {
      name: "宽度"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const LatentFlip = {
  display_name: "翻转Latent",
  inputs: {
    flip_method: {
      name: "翻转方法"
    },
    samples: {
      name: "Latent"
    }
  }
};
const LatentFromBatch = {
  display_name: "从批次获取Latent",
  inputs: {
    batch_index: {
      name: "批次索引"
    },
    length: {
      name: "长度"
    },
    samples: {
      name: "Latent"
    }
  }
};
const LatentInterpolate = {
  display_name: "Latent插值",
  inputs: {
    ratio: {
      name: "比率"
    },
    samples1: {
      name: "Latent1"
    },
    samples2: {
      name: "Latent2"
    }
  }
};
const LatentMultiply = {
  display_name: "Latent相乘",
  inputs: {
    multiplier: {
      name: "乘数"
    },
    samples: {
      name: "Latent"
    }
  }
};
const LatentOperationSharpen = {
  display_name: "Latent操作锐化",
  inputs: {
    alpha: {
      name: "阿尔法"
    },
    sharpen_radius: {
      name: "锐化半径"
    },
    sigma: {
      name: "西格玛"
    }
  }
};
const LatentOperationTonemapReinhard = {
  display_name: "Latent操作色调映射Reinhard",
  inputs: {
    multiplier: {
      name: "乘数"
    }
  }
};
const LatentRotate = {
  display_name: "旋转Latent",
  inputs: {
    rotation: {
      name: "旋转"
    },
    samples: {
      name: "Latent"
    }
  }
};
const LatentSubtract = {
  display_name: "Latent相减",
  inputs: {
    samples1: {
      name: "Latent1"
    },
    samples2: {
      name: "Latent2"
    }
  }
};
const LatentUpscale = {
  display_name: "缩放Latent",
  inputs: {
    crop: {
      name: "裁剪"
    },
    height: {
      name: "高度"
    },
    samples: {
      name: "Latent"
    },
    upscale_method: {
      name: "缩放算法"
    },
    width: {
      name: "宽度"
    }
  }
};
const LatentUpscaleBy = {
  display_name: "缩放Latent（比例）",
  inputs: {
    samples: {
      name: "Latent"
    },
    scale_by: {
      name: "缩放比例"
    },
    upscale_method: {
      name: "缩放算法"
    }
  }
};
const Load3D = {
  display_name: "加载3D",
  inputs: {
    clear: {},
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    model_file: {
      name: "模型文件"
    },
    "upload 3d model": {},
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "图像"
    },
    "1": {
      name: "遮罩"
    },
    "2": {
      name: "网格路径"
    }
  }
};
const Load3DAnimation = {
  display_name: "加载3D动画",
  inputs: {
    clear: {},
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    model_file: {
      name: "模型文件"
    },
    "upload 3d model": {},
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "图像"
    },
    "1": {
      name: "遮罩"
    },
    "2": {
      name: "网格路径"
    }
  }
};
const LoadAudio = {
  display_name: "加载音频",
  inputs: {
    audio: {
      name: "音频"
    },
    audioUI: {
      name: "音频UI"
    },
    upload: {
      name: "选择文件上传"
    }
  }
};
const LoadImage = {
  display_name: "加载图像",
  inputs: {
    image: {
      name: "图像"
    },
    upload: {
      name: "选择文件上传"
    }
  }
};
const LoadImageMask = {
  display_name: "加载图像（作为遮罩）",
  inputs: {
    channel: {
      name: "通道"
    },
    image: {
      name: "图像"
    },
    upload: {
      name: "选择文件上传"
    }
  }
};
const LoadImageOutput = {
  description: "从输出文件夹加载图像。当点击刷新按钮时，节点将更新图像列表并自动选择第一张图像，便于轻松迭代。",
  display_name: "加载图像（来自输出）",
  inputs: {
    image: {
      name: "图像"
    },
    refresh: {},
    upload: {
      name: "选择文件上传"
    }
  }
};
const LoadLatent = {
  display_name: "加载Latent",
  inputs: {
    latent: {
      name: "Latent"
    }
  }
};
const LoraLoader = {
  description: "LoRA用于修改扩散和CLIP模型，改变Latent图像的降噪方式，例如应用风格。多个LoRA节点可以链接在一起。",
  display_name: "加载LoRA",
  inputs: {
    clip: {
      name: "CLIPCLIP",
      tooltip: "LoRA 将应用于的 CLIP 模型。"
    },
    lora_name: {
      name: "LoRA名称",
      tooltip: "LoRA 的名称。"
    },
    model: {
      name: "模型",
      tooltip: "LoRA 将应用于的扩散模型。"
    },
    strength_clip: {
      name: "CLIP强度",
      tooltip: "修改 CLIP 模型的强度。此值可以为负。"
    },
    strength_model: {
      name: "模型强度",
      tooltip: "修改扩散模型的强度。此值可以为负。"
    }
  },
  outputs: {
    "0": {
      tooltip: "修改后的扩散模型。"
    },
    "1": {
      tooltip: "修改后的CLIP模型。"
    }
  }
};
const LoraLoaderModelOnly = {
  description: "LoRA用于修改扩散和CLIP模型，改变Latent图像的降噪方式，例如应用风格。多个LoRA节点可以链接在一起。",
  display_name: "LoRA加载器（仅模型）",
  inputs: {
    lora_name: {
      name: "LoRA名称"
    },
    model: {
      name: "模型"
    },
    strength_model: {
      name: "模型强度"
    }
  },
  outputs: {
    "0": {
      tooltip: "修改后的扩散模型。"
    }
  }
};
const LoraSave = {
  display_name: "保存LoRA",
  inputs: {
    bias_diff: {
      name: "偏差差异"
    },
    filename_prefix: {
      name: "文件名前缀"
    },
    lora_type: {
      name: "lora类型"
    },
    model_diff: {
      name: "模型差异",
      tooltip: "要转换为 LoRA 的模型差异输出。"
    },
    rank: {
      name: "排名"
    },
    text_encoder_diff: {
      name: "文本编码器差异",
      tooltip: "要转换为 LoRA 的CLIP差异输出。"
    }
  }
};
const Mahiro = {
  description: "修改引导以更多地侧重于正面条件提示的'方向'，而不是负面条件提示之间的差异。",
  display_name: "真寻太可爱了，她应该有个更好的引导功能！！(。・ω・。)",
  inputs: {
    model: {
      name: "模型"
    }
  },
  outputs: {
    "0": {
      name: "修补后的模型"
    }
  }
};
const MaskComposite = {
  display_name: "合成遮罩",
  inputs: {
    destination: {
      name: "目标"
    },
    operation: {
      name: "操作"
    },
    source: {
      name: "源"
    },
    x: {
      name: "x"
    },
    y: {
      name: "y"
    }
  }
};
const MaskToImage = {
  display_name: "遮罩转换为图像",
  inputs: {
    mask: {
      name: "遮罩"
    }
  }
};
const ModelComputeDtype = {
  display_name: "模型计算Dtype",
  inputs: {
    dtype: {
      name: "dtype"
    },
    model: {
      name: "模型"
    }
  }
};
const ModelMergeAdd = {
  display_name: "模型相加",
  inputs: {
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    }
  }
};
const ModelMergeAuraflow = {
  display_name: "模型融合（Auraflow ）",
  inputs: {
    cond_seq_linear_: {
      name: "条件序列线性."
    },
    double_layers_0_: {
      name: "双层.0."
    },
    double_layers_1_: {
      name: "双层.1."
    },
    double_layers_2_: {
      name: "双层.2."
    },
    double_layers_3_: {
      name: "双层.3."
    },
    final_linear_: {
      name: "最终线性."
    },
    init_x_linear_: {
      name: "初始x线性."
    },
    modF_: {
      name: "modF."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    positional_encoding: {
      name: "位置编码"
    },
    register_tokens: {
      name: "注册令牌"
    },
    single_layers_0_: {
      name: "单层.0."
    },
    single_layers_10_: {
      name: "单层.10."
    },
    single_layers_11_: {
      name: "单层.11."
    },
    single_layers_12_: {
      name: "单层.12."
    },
    single_layers_13_: {
      name: "单层.13."
    },
    single_layers_14_: {
      name: "单层.14."
    },
    single_layers_15_: {
      name: "单层.15."
    },
    single_layers_16_: {
      name: "单层.16."
    },
    single_layers_17_: {
      name: "单层.17."
    },
    single_layers_18_: {
      name: "单层.18."
    },
    single_layers_19_: {
      name: "单层.19."
    },
    single_layers_1_: {
      name: "单层.1."
    },
    single_layers_20_: {
      name: "单层.20."
    },
    single_layers_21_: {
      name: "单层.21."
    },
    single_layers_22_: {
      name: "单层.22."
    },
    single_layers_23_: {
      name: "单层.23."
    },
    single_layers_24_: {
      name: "单层.24."
    },
    single_layers_25_: {
      name: "单层.25."
    },
    single_layers_26_: {
      name: "单层.26."
    },
    single_layers_27_: {
      name: "单层.27."
    },
    single_layers_28_: {
      name: "单层.28."
    },
    single_layers_29_: {
      name: "单层.29."
    },
    single_layers_2_: {
      name: "单层.2."
    },
    single_layers_30_: {
      name: "单层.30."
    },
    single_layers_31_: {
      name: "单层.31."
    },
    single_layers_3_: {
      name: "单层.3."
    },
    single_layers_4_: {
      name: "单层.4."
    },
    single_layers_5_: {
      name: "单层.5."
    },
    single_layers_6_: {
      name: "单层.6."
    },
    single_layers_7_: {
      name: "单层.7."
    },
    single_layers_8_: {
      name: "单层.8."
    },
    single_layers_9_: {
      name: "单层.9."
    },
    t_embedder_: {
      name: "t嵌入器."
    }
  }
};
const ModelMergeBlocks = {
  display_name: "模型融合（分块）",
  inputs: {
    input: {
      name: "输入"
    },
    middle: {
      name: "中间"
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    out: {
      name: "输出"
    }
  }
};
const ModelMergeCosmos14B = {
  display_name: "ModelMergeCosmos14B",
  inputs: {
    affline_norm_: {
      name: "仿射规范化."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block28_: {
      name: "blocks.block28."
    },
    blocks_block29_: {
      name: "blocks.block29."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block30_: {
      name: "blocks.block30."
    },
    blocks_block31_: {
      name: "blocks.block31."
    },
    blocks_block32_: {
      name: "blocks.block32."
    },
    blocks_block33_: {
      name: "blocks.block33."
    },
    blocks_block34_: {
      name: "blocks.block34."
    },
    blocks_block35_: {
      name: "blocks.block35."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "额外位置嵌入器."
    },
    final_layer_: {
      name: "最终层."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    pos_embedder_: {
      name: "位置嵌入器."
    },
    t_embedder_: {
      name: "t嵌入器."
    },
    x_embedder_: {
      name: "x嵌入器."
    }
  }
};
const ModelMergeCosmos7B = {
  display_name: "ModelMergeCosmos7B",
  inputs: {
    affline_norm_: {
      name: "仿射规范化."
    },
    blocks_block0_: {
      name: "blocks.block0."
    },
    blocks_block10_: {
      name: "blocks.block10."
    },
    blocks_block11_: {
      name: "blocks.block11."
    },
    blocks_block12_: {
      name: "blocks.block12."
    },
    blocks_block13_: {
      name: "blocks.block13."
    },
    blocks_block14_: {
      name: "blocks.block14."
    },
    blocks_block15_: {
      name: "blocks.block15."
    },
    blocks_block16_: {
      name: "blocks.block16."
    },
    blocks_block17_: {
      name: "blocks.block17."
    },
    blocks_block18_: {
      name: "blocks.block18."
    },
    blocks_block19_: {
      name: "blocks.block19."
    },
    blocks_block1_: {
      name: "blocks.block1."
    },
    blocks_block20_: {
      name: "blocks.block20."
    },
    blocks_block21_: {
      name: "blocks.block21."
    },
    blocks_block22_: {
      name: "blocks.block22."
    },
    blocks_block23_: {
      name: "blocks.block23."
    },
    blocks_block24_: {
      name: "blocks.block24."
    },
    blocks_block25_: {
      name: "blocks.block25."
    },
    blocks_block26_: {
      name: "blocks.block26."
    },
    blocks_block27_: {
      name: "blocks.block27."
    },
    blocks_block2_: {
      name: "blocks.block2."
    },
    blocks_block3_: {
      name: "blocks.block3."
    },
    blocks_block4_: {
      name: "blocks.block4."
    },
    blocks_block5_: {
      name: "blocks.block5."
    },
    blocks_block6_: {
      name: "blocks.block6."
    },
    blocks_block7_: {
      name: "blocks.block7."
    },
    blocks_block8_: {
      name: "blocks.block8."
    },
    blocks_block9_: {
      name: "blocks.block9."
    },
    extra_pos_embedder_: {
      name: "额外位置嵌入器."
    },
    final_layer_: {
      name: "最终层."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    pos_embedder_: {
      name: "位置嵌入器."
    },
    t_embedder_: {
      name: "t嵌入器."
    },
    x_embedder_: {
      name: "x嵌入器."
    }
  }
};
const ModelMergeFlux1 = {
  display_name: "模型融合（Flux1）",
  inputs: {
    double_blocks_0_: {
      name: "双块.0."
    },
    double_blocks_10_: {
      name: "双块.10."
    },
    double_blocks_11_: {
      name: "双块.11."
    },
    double_blocks_12_: {
      name: "双块.12."
    },
    double_blocks_13_: {
      name: "双块.13."
    },
    double_blocks_14_: {
      name: "双块.14."
    },
    double_blocks_15_: {
      name: "双块.15."
    },
    double_blocks_16_: {
      name: "双块.16."
    },
    double_blocks_17_: {
      name: "双块.17."
    },
    double_blocks_18_: {
      name: "双块.18."
    },
    double_blocks_1_: {
      name: "双块.1."
    },
    double_blocks_2_: {
      name: "双块.2."
    },
    double_blocks_3_: {
      name: "双块.3."
    },
    double_blocks_4_: {
      name: "双块.4."
    },
    double_blocks_5_: {
      name: "双块.5."
    },
    double_blocks_6_: {
      name: "双块.6."
    },
    double_blocks_7_: {
      name: "双块.7."
    },
    double_blocks_8_: {
      name: "双块.8."
    },
    double_blocks_9_: {
      name: "双块.9."
    },
    final_layer_: {
      name: "最终层."
    },
    guidance_in: {
      name: "输入引导"
    },
    img_in_: {
      name: "输入图像."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    single_blocks_0_: {
      name: "单块.0."
    },
    single_blocks_10_: {
      name: "单块.10."
    },
    single_blocks_11_: {
      name: "单块.11."
    },
    single_blocks_12_: {
      name: "单块.12."
    },
    single_blocks_13_: {
      name: "单块.13."
    },
    single_blocks_14_: {
      name: "单块.14."
    },
    single_blocks_15_: {
      name: "单块.15."
    },
    single_blocks_16_: {
      name: "单块.16."
    },
    single_blocks_17_: {
      name: "单块.17."
    },
    single_blocks_18_: {
      name: "单块.18."
    },
    single_blocks_19_: {
      name: "单块.19."
    },
    single_blocks_1_: {
      name: "单块.1."
    },
    single_blocks_20_: {
      name: "单块.20."
    },
    single_blocks_21_: {
      name: "单块.21."
    },
    single_blocks_22_: {
      name: "单块.22."
    },
    single_blocks_23_: {
      name: "单块.23."
    },
    single_blocks_24_: {
      name: "单块.24."
    },
    single_blocks_25_: {
      name: "单块.25."
    },
    single_blocks_26_: {
      name: "单块.26."
    },
    single_blocks_27_: {
      name: "单块.27."
    },
    single_blocks_28_: {
      name: "单块.28."
    },
    single_blocks_29_: {
      name: "单块.29."
    },
    single_blocks_2_: {
      name: "单块.2."
    },
    single_blocks_30_: {
      name: "单块.30."
    },
    single_blocks_31_: {
      name: "单块.31."
    },
    single_blocks_32_: {
      name: "单块.32."
    },
    single_blocks_33_: {
      name: "单块.33."
    },
    single_blocks_34_: {
      name: "单块.34."
    },
    single_blocks_35_: {
      name: "单块.35."
    },
    single_blocks_36_: {
      name: "单块.36."
    },
    single_blocks_37_: {
      name: "单块.37."
    },
    single_blocks_3_: {
      name: "单块.3."
    },
    single_blocks_4_: {
      name: "单块.4."
    },
    single_blocks_5_: {
      name: "单块.5."
    },
    single_blocks_6_: {
      name: "单块.6."
    },
    single_blocks_7_: {
      name: "单块.7."
    },
    single_blocks_8_: {
      name: "单块.8."
    },
    single_blocks_9_: {
      name: "单块.9."
    },
    time_in_: {
      name: "输入时间."
    },
    txt_in_: {
      name: "输入文本."
    },
    vector_in_: {
      name: "输入向量."
    }
  }
};
const ModelMergeLTXV = {
  display_name: "模型融合（LTXV）",
  inputs: {
    adaln_single_: {
      name: "adaln_single."
    },
    caption_projection_: {
      name: "caption_projection."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    patchify_proj_: {
      name: "patchify_proj."
    },
    proj_out_: {
      name: "proj_out."
    },
    scale_shift_table: {
      name: "scale_shift_table"
    },
    transformer_blocks_0_: {
      name: "transformer_blocks.0."
    },
    transformer_blocks_10_: {
      name: "transformer_blocks.10."
    },
    transformer_blocks_11_: {
      name: "transformer_blocks.11."
    },
    transformer_blocks_12_: {
      name: "transformer_blocks.12."
    },
    transformer_blocks_13_: {
      name: "transformer_blocks.13."
    },
    transformer_blocks_14_: {
      name: "transformer_blocks.14."
    },
    transformer_blocks_15_: {
      name: "transformer_blocks.15."
    },
    transformer_blocks_16_: {
      name: "transformer_blocks.16."
    },
    transformer_blocks_17_: {
      name: "transformer_blocks.17."
    },
    transformer_blocks_18_: {
      name: "transformer_blocks.18."
    },
    transformer_blocks_19_: {
      name: "transformer_blocks.19."
    },
    transformer_blocks_1_: {
      name: "transformer_blocks.1."
    },
    transformer_blocks_20_: {
      name: "transformer_blocks.20."
    },
    transformer_blocks_21_: {
      name: "transformer_blocks.21."
    },
    transformer_blocks_22_: {
      name: "transformer_blocks.22."
    },
    transformer_blocks_23_: {
      name: "transformer_blocks.23."
    },
    transformer_blocks_24_: {
      name: "transformer_blocks.24."
    },
    transformer_blocks_25_: {
      name: "transformer_blocks.25."
    },
    transformer_blocks_26_: {
      name: "transformer_blocks.26."
    },
    transformer_blocks_27_: {
      name: "transformer_blocks.27."
    },
    transformer_blocks_2_: {
      name: "transformer_blocks.2."
    },
    transformer_blocks_3_: {
      name: "transformer_blocks.3."
    },
    transformer_blocks_4_: {
      name: "transformer_blocks.4."
    },
    transformer_blocks_5_: {
      name: "transformer_blocks.5."
    },
    transformer_blocks_6_: {
      name: "transformer_blocks.6."
    },
    transformer_blocks_7_: {
      name: "transformer_blocks.7."
    },
    transformer_blocks_8_: {
      name: "transformer_blocks.8."
    },
    transformer_blocks_9_: {
      name: "transformer_blocks.9."
    }
  }
};
const ModelMergeMochiPreview = {
  display_name: "模型融合（Mochi预览）",
  inputs: {
    blocks_0_: {
      name: "blocks.0."
    },
    blocks_10_: {
      name: "blocks.10."
    },
    blocks_11_: {
      name: "blocks.11."
    },
    blocks_12_: {
      name: "blocks.12."
    },
    blocks_13_: {
      name: "blocks.13."
    },
    blocks_14_: {
      name: "blocks.14."
    },
    blocks_15_: {
      name: "blocks.15."
    },
    blocks_16_: {
      name: "blocks.16."
    },
    blocks_17_: {
      name: "blocks.17."
    },
    blocks_18_: {
      name: "blocks.18."
    },
    blocks_19_: {
      name: "blocks.19."
    },
    blocks_1_: {
      name: "blocks.1."
    },
    blocks_20_: {
      name: "blocks.20."
    },
    blocks_21_: {
      name: "blocks.21."
    },
    blocks_22_: {
      name: "blocks.22."
    },
    blocks_23_: {
      name: "blocks.23."
    },
    blocks_24_: {
      name: "blocks.24."
    },
    blocks_25_: {
      name: "blocks.25."
    },
    blocks_26_: {
      name: "blocks.26."
    },
    blocks_27_: {
      name: "blocks.27."
    },
    blocks_28_: {
      name: "blocks.28."
    },
    blocks_29_: {
      name: "blocks.29."
    },
    blocks_2_: {
      name: "blocks.2."
    },
    blocks_30_: {
      name: "blocks.30."
    },
    blocks_31_: {
      name: "blocks.31."
    },
    blocks_32_: {
      name: "blocks.32."
    },
    blocks_33_: {
      name: "blocks.33."
    },
    blocks_34_: {
      name: "blocks.34."
    },
    blocks_35_: {
      name: "blocks.35."
    },
    blocks_36_: {
      name: "blocks.36."
    },
    blocks_37_: {
      name: "blocks.37."
    },
    blocks_38_: {
      name: "blocks.38."
    },
    blocks_39_: {
      name: "blocks.39."
    },
    blocks_3_: {
      name: "blocks.3."
    },
    blocks_40_: {
      name: "blocks.40."
    },
    blocks_41_: {
      name: "blocks.41."
    },
    blocks_42_: {
      name: "blocks.42."
    },
    blocks_43_: {
      name: "blocks.43."
    },
    blocks_44_: {
      name: "blocks.44."
    },
    blocks_45_: {
      name: "blocks.45."
    },
    blocks_46_: {
      name: "blocks.46."
    },
    blocks_47_: {
      name: "blocks.47."
    },
    blocks_4_: {
      name: "blocks.4."
    },
    blocks_5_: {
      name: "blocks.5."
    },
    blocks_6_: {
      name: "blocks.6."
    },
    blocks_7_: {
      name: "blocks.7."
    },
    blocks_8_: {
      name: "blocks.8."
    },
    blocks_9_: {
      name: "blocks.9."
    },
    final_layer_: {
      name: "final_layer."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    pos_frequencies_: {
      name: "pos_frequencies."
    },
    t5_y_embedder_: {
      name: "t5_y_embedder."
    },
    t5_yproj_: {
      name: "t5_yproj."
    },
    t_embedder_: {
      name: "t_embedder."
    }
  }
};
const ModelMergeSD1 = {
  display_name: "模型融合（SD1）",
  inputs: {
    input_blocks_0_: {
      name: "输入块.0."
    },
    input_blocks_10_: {
      name: "输入块.10."
    },
    input_blocks_11_: {
      name: "输入块.11."
    },
    input_blocks_1_: {
      name: "输入块.1."
    },
    input_blocks_2_: {
      name: "输入块.2."
    },
    input_blocks_3_: {
      name: "输入块.3."
    },
    input_blocks_4_: {
      name: "输入块.4."
    },
    input_blocks_5_: {
      name: "输入块.5."
    },
    input_blocks_6_: {
      name: "输入块.6."
    },
    input_blocks_7_: {
      name: "输入块.7."
    },
    input_blocks_8_: {
      name: "输入块.8."
    },
    input_blocks_9_: {
      name: "输入块.9."
    },
    label_emb_: {
      name: "标签嵌入."
    },
    middle_block_0_: {
      name: "中间块.0."
    },
    middle_block_1_: {
      name: "中间块.1."
    },
    middle_block_2_: {
      name: "中间块.2."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    out_: {
      name: "出."
    },
    output_blocks_0_: {
      name: "输出块.0."
    },
    output_blocks_10_: {
      name: "输出块.10."
    },
    output_blocks_11_: {
      name: "输出块.11."
    },
    output_blocks_1_: {
      name: "输出块.1."
    },
    output_blocks_2_: {
      name: "输出块.2."
    },
    output_blocks_3_: {
      name: "输出块.3."
    },
    output_blocks_4_: {
      name: "输出块.4."
    },
    output_blocks_5_: {
      name: "输出块.5."
    },
    output_blocks_6_: {
      name: "输出块.6."
    },
    output_blocks_7_: {
      name: "输出块.7."
    },
    output_blocks_8_: {
      name: "输出块.8."
    },
    output_blocks_9_: {
      name: "输出块.9."
    },
    time_embed_: {
      name: "时间嵌入."
    }
  }
};
const ModelMergeSD2 = {
  display_name: "模型融合（SD2）",
  inputs: {
    input_blocks_0_: {
      name: "输入块.0."
    },
    input_blocks_10_: {
      name: "输入块.10."
    },
    input_blocks_11_: {
      name: "输入块.11."
    },
    input_blocks_1_: {
      name: "输入块.1."
    },
    input_blocks_2_: {
      name: "输入块.2."
    },
    input_blocks_3_: {
      name: "输入块.3."
    },
    input_blocks_4_: {
      name: "输入块.4."
    },
    input_blocks_5_: {
      name: "输入块.5."
    },
    input_blocks_6_: {
      name: "输入块.6."
    },
    input_blocks_7_: {
      name: "输入块.7."
    },
    input_blocks_8_: {
      name: "输入块.8."
    },
    input_blocks_9_: {
      name: "输入块.9."
    },
    label_emb_: {
      name: "标签嵌入."
    },
    middle_block_0_: {
      name: "中间块.0."
    },
    middle_block_1_: {
      name: "中间块.1."
    },
    middle_block_2_: {
      name: "中间块.2."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    out_: {
      name: "出."
    },
    output_blocks_0_: {
      name: "输出块.0."
    },
    output_blocks_10_: {
      name: "输出块.10."
    },
    output_blocks_11_: {
      name: "输出块.11."
    },
    output_blocks_1_: {
      name: "输出块.1."
    },
    output_blocks_2_: {
      name: "输出块.2."
    },
    output_blocks_3_: {
      name: "输出块.3."
    },
    output_blocks_4_: {
      name: "输出块.4."
    },
    output_blocks_5_: {
      name: "输出块.5."
    },
    output_blocks_6_: {
      name: "输出块.6."
    },
    output_blocks_7_: {
      name: "输出块.7."
    },
    output_blocks_8_: {
      name: "输出块.8."
    },
    output_blocks_9_: {
      name: "输出块.9."
    },
    time_embed_: {
      name: "时间嵌入."
    }
  }
};
const ModelMergeSD35_Large = {
  display_name: "模型融合（SD35_大）",
  inputs: {
    context_embedder_: {
      name: "上下文嵌入器."
    },
    final_layer_: {
      name: "最终层."
    },
    joint_blocks_0_: {
      name: "联合块.0."
    },
    joint_blocks_10_: {
      name: "联合块.10."
    },
    joint_blocks_11_: {
      name: "联合块.11."
    },
    joint_blocks_12_: {
      name: "联合块.12."
    },
    joint_blocks_13_: {
      name: "联合块.13."
    },
    joint_blocks_14_: {
      name: "联合块.14."
    },
    joint_blocks_15_: {
      name: "联合块.15."
    },
    joint_blocks_16_: {
      name: "联合块.16."
    },
    joint_blocks_17_: {
      name: "联合块.17."
    },
    joint_blocks_18_: {
      name: "联合块.18."
    },
    joint_blocks_19_: {
      name: "联合块.19."
    },
    joint_blocks_1_: {
      name: "联合块.1."
    },
    joint_blocks_20_: {
      name: "联合块.20."
    },
    joint_blocks_21_: {
      name: "联合块.21."
    },
    joint_blocks_22_: {
      name: "联合块.22."
    },
    joint_blocks_23_: {
      name: "联合块.23."
    },
    joint_blocks_24_: {
      name: "联合块.24."
    },
    joint_blocks_25_: {
      name: "联合块.25."
    },
    joint_blocks_26_: {
      name: "联合块.26."
    },
    joint_blocks_27_: {
      name: "联合块.27."
    },
    joint_blocks_28_: {
      name: "联合块.28."
    },
    joint_blocks_29_: {
      name: "联合块.29."
    },
    joint_blocks_2_: {
      name: "联合块.2."
    },
    joint_blocks_30_: {
      name: "联合块.30."
    },
    joint_blocks_31_: {
      name: "联合块.31."
    },
    joint_blocks_32_: {
      name: "联合块.32."
    },
    joint_blocks_33_: {
      name: "联合块.33."
    },
    joint_blocks_34_: {
      name: "联合块.34."
    },
    joint_blocks_35_: {
      name: "联合块.35."
    },
    joint_blocks_36_: {
      name: "联合块.36."
    },
    joint_blocks_37_: {
      name: "联合块.37."
    },
    joint_blocks_3_: {
      name: "联合块.3."
    },
    joint_blocks_4_: {
      name: "联合块.4."
    },
    joint_blocks_5_: {
      name: "联合块.5."
    },
    joint_blocks_6_: {
      name: "联合块.6."
    },
    joint_blocks_7_: {
      name: "联合块.7."
    },
    joint_blocks_8_: {
      name: "联合块.8."
    },
    joint_blocks_9_: {
      name: "联合块.9."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    pos_embed_: {
      name: "位置嵌入."
    },
    t_embedder_: {
      name: "t嵌入器."
    },
    x_embedder_: {
      name: "x嵌入器."
    },
    y_embedder_: {
      name: "y嵌入器."
    }
  }
};
const ModelMergeSD3_2B = {
  display_name: "模型融合（SD3_2B）",
  inputs: {
    context_embedder_: {
      name: "上下文嵌入器."
    },
    final_layer_: {
      name: "最终层."
    },
    joint_blocks_0_: {
      name: "联合块.0."
    },
    joint_blocks_10_: {
      name: "联合块.10."
    },
    joint_blocks_11_: {
      name: "联合块.11."
    },
    joint_blocks_12_: {
      name: "联合块.12."
    },
    joint_blocks_13_: {
      name: "联合块.13."
    },
    joint_blocks_14_: {
      name: "联合块.14."
    },
    joint_blocks_15_: {
      name: "联合块.15."
    },
    joint_blocks_16_: {
      name: "联合块.16."
    },
    joint_blocks_17_: {
      name: "联合块.17."
    },
    joint_blocks_18_: {
      name: "联合块.18."
    },
    joint_blocks_19_: {
      name: "联合块.19."
    },
    joint_blocks_1_: {
      name: "联合块.1."
    },
    joint_blocks_20_: {
      name: "联合块.20."
    },
    joint_blocks_21_: {
      name: "联合块.21."
    },
    joint_blocks_22_: {
      name: "联合块.22."
    },
    joint_blocks_23_: {
      name: "联合块.23."
    },
    joint_blocks_2_: {
      name: "联合块.2."
    },
    joint_blocks_3_: {
      name: "联合块.3."
    },
    joint_blocks_4_: {
      name: "联合块.4."
    },
    joint_blocks_5_: {
      name: "联合块.5."
    },
    joint_blocks_6_: {
      name: "联合块.6."
    },
    joint_blocks_7_: {
      name: "联合块.7."
    },
    joint_blocks_8_: {
      name: "联合块.8."
    },
    joint_blocks_9_: {
      name: "联合块.9."
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    pos_embed_: {
      name: "位置嵌入."
    },
    t_embedder_: {
      name: "t嵌入器."
    },
    x_embedder_: {
      name: "x嵌入器."
    },
    y_embedder_: {
      name: "y嵌入器."
    }
  }
};
const ModelMergeSDXL = {
  display_name: "模型融合（SDXL）",
  inputs: {
    input_blocks_0: {
      name: "输入块.0"
    },
    input_blocks_1: {
      name: "输入块.1"
    },
    input_blocks_2: {
      name: "输入块.2"
    },
    input_blocks_3: {
      name: "输入块.3"
    },
    input_blocks_4: {
      name: "输入块.4"
    },
    input_blocks_5: {
      name: "输入块.5"
    },
    input_blocks_6: {
      name: "输入块.6"
    },
    input_blocks_7: {
      name: "输入块.7"
    },
    input_blocks_8: {
      name: "输入块.8"
    },
    label_emb_: {
      name: "标签嵌入."
    },
    middle_block_0: {
      name: "中间块.0"
    },
    middle_block_1: {
      name: "中间块.1"
    },
    middle_block_2: {
      name: "中间块.2"
    },
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    out_: {
      name: "输出."
    },
    output_blocks_0: {
      name: "输出块.0"
    },
    output_blocks_1: {
      name: "输出块.1"
    },
    output_blocks_2: {
      name: "输出块.2"
    },
    output_blocks_3: {
      name: "输出块.3"
    },
    output_blocks_4: {
      name: "输出块.4"
    },
    output_blocks_5: {
      name: "输出块.5"
    },
    output_blocks_6: {
      name: "输出块.6"
    },
    output_blocks_7: {
      name: "输出块.7"
    },
    output_blocks_8: {
      name: "输出块.8"
    },
    time_embed_: {
      name: "时间嵌入."
    }
  }
};
const ModelMergeSimple = {
  display_name: "模型融合（简易）",
  inputs: {
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    ratio: {
      name: "比例"
    }
  }
};
const ModelMergeSubtract = {
  display_name: "模型相减",
  inputs: {
    model1: {
      name: "模型1"
    },
    model2: {
      name: "模型2"
    },
    multiplier: {
      name: "乘数"
    }
  }
};
const ModelSamplingAuraFlow = {
  display_name: "采样算法（AuraFlow）",
  inputs: {
    model: {
      name: "模型"
    },
    shift: {
      name: "移位"
    }
  }
};
const ModelSamplingContinuousEDM = {
  display_name: "采样算法（连续EDM）",
  inputs: {
    model: {
      name: "模型"
    },
    sampling: {
      name: "采样"
    },
    sigma_max: {
      name: "最大西格玛"
    },
    sigma_min: {
      name: "最小西格玛"
    }
  }
};
const ModelSamplingContinuousV = {
  display_name: "采样算法（连续V）",
  inputs: {
    model: {
      name: "模型"
    },
    sampling: {
      name: "采样"
    },
    sigma_max: {
      name: "最大西格玛"
    },
    sigma_min: {
      name: "最小西格玛"
    }
  }
};
const ModelSamplingDiscrete = {
  display_name: "采样算法（离散）",
  inputs: {
    model: {
      name: "模型"
    },
    sampling: {
      name: "采样"
    },
    zsnr: {
      name: "zsnr"
    }
  }
};
const ModelSamplingFlux = {
  display_name: "采样算法（Flux）",
  inputs: {
    base_shift: {
      name: "基础移位"
    },
    height: {
      name: "高度"
    },
    max_shift: {
      name: "最大移位"
    },
    model: {
      name: "模型"
    },
    width: {
      name: "宽度"
    }
  }
};
const ModelSamplingLTXV = {
  display_name: "采样算法（LTXV）",
  inputs: {
    base_shift: {
      name: "基础移位"
    },
    latent: {
      name: "Latent"
    },
    max_shift: {
      name: "最大移位"
    },
    model: {
      name: "模型"
    }
  }
};
const ModelSamplingSD3 = {
  display_name: "采样算法（SD3）",
  inputs: {
    model: {
      name: "模型"
    },
    shift: {
      name: "移位"
    }
  }
};
const ModelSamplingStableCascade = {
  display_name: "采样算法（Stable Cascade）",
  inputs: {
    model: {
      name: "模型"
    },
    shift: {
      name: "移位"
    }
  }
};
const ModelSave = {
  display_name: "保存模型",
  inputs: {
    filename_prefix: {
      name: "文件名前缀"
    },
    model: {
      name: "模型"
    }
  }
};
const Morphology = {
  display_name: "图像形态学",
  inputs: {
    image: {
      name: "图像"
    },
    kernel_size: {
      name: "核心大小"
    },
    operation: {
      name: "操作"
    }
  }
};
const PairConditioningCombine = {
  display_name: "条件对合并",
  inputs: {
    negative_A: {
      name: "负面条件_A"
    },
    negative_B: {
      name: "负面条件_B"
    },
    positive_A: {
      name: "正面条件_A"
    },
    positive_B: {
      name: "正面条件_B"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const PairConditioningSetDefaultCombine = {
  display_name: "条件对设置默认合并",
  inputs: {
    hooks: {
      name: "约束"
    },
    negative: {
      name: "负面条件"
    },
    negative_DEFAULT: {
      name: "默认负面条件"
    },
    positive: {
      name: "正面条件"
    },
    positive_DEFAULT: {
      name: "默认正面条件"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const PairConditioningSetProperties = {
  display_name: "条件对设置属性",
  inputs: {
    hooks: {
      name: "约束"
    },
    mask: {
      name: "遮罩"
    },
    negative_NEW: {
      name: "新负面条件"
    },
    positive_NEW: {
      name: "新正面条件"
    },
    set_cond_area: {
      name: "设置条件区域"
    },
    strength: {
      name: "强度"
    },
    timesteps: {
      name: "间隔"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const PairConditioningSetPropertiesAndCombine = {
  display_name: "条件对设置属性合并",
  inputs: {
    hooks: {
      name: "约束"
    },
    mask: {
      name: "遮罩"
    },
    negative: {
      name: "负面条件"
    },
    negative_NEW: {
      name: "新负面条件"
    },
    positive: {
      name: "正面条件"
    },
    positive_NEW: {
      name: "新正面条件"
    },
    set_cond_area: {
      name: "设置条件区域"
    },
    strength: {
      name: "强度"
    },
    timesteps: {
      name: "间隔"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    }
  }
};
const PatchModelAddDownscale = {
  display_name: "收缩模型UNET（Kohya Deep Shrink）",
  inputs: {
    block_number: {
      name: "层编号"
    },
    downscale_after_skip: {
      name: "跳过后收缩"
    },
    downscale_factor: {
      name: "收缩系数"
    },
    downscale_method: {
      name: "收缩算法"
    },
    end_percent: {
      name: "结束百分比"
    },
    model: {
      name: "模型"
    },
    start_percent: {
      name: "开始百分比"
    },
    upscale_method: {
      name: "放大方法"
    }
  }
};
const PerpNeg = {
  display_name: "Perp-Neg（已弃用，使用PerpNegGuider）",
  inputs: {
    empty_conditioning: {
      name: "空条件"
    },
    model: {
      name: "模型"
    },
    neg_scale: {
      name: "负面缩放"
    }
  }
};
const PerpNegGuider = {
  display_name: "PerpNeg引导器",
  inputs: {
    cfg: {
      name: "cfg"
    },
    empty_conditioning: {
      name: "空条件"
    },
    model: {
      name: "模型"
    },
    neg_scale: {
      name: "负面缩放"
    },
    negative: {
      name: "负面条件"
    },
    positive: {
      name: "正面条件"
    }
  }
};
const PerturbedAttentionGuidance = {
  display_name: "PAG注意力引导",
  inputs: {
    model: {
      name: "模型"
    },
    scale: {
      name: "规模"
    }
  }
};
const PhotoMakerEncode = {
  display_name: "PhotoMaker编码",
  inputs: {
    clip: {
      name: "clip"
    },
    image: {
      name: "图像"
    },
    photomaker: {
      name: "photomaker"
    },
    text: {
      name: "文本"
    }
  }
};
const PhotoMakerLoader = {
  display_name: "PhotoMaker加载器",
  inputs: {
    photomaker_model_name: {
      name: "photomaker模型名称"
    }
  }
};
const PolyexponentialScheduler = {
  display_name: "Polyexponential调度器",
  inputs: {
    rho: {
      name: "rho"
    },
    sigma_max: {
      name: "sigma最大值"
    },
    sigma_min: {
      name: "sigma最小值"
    },
    steps: {
      name: "步数"
    }
  }
};
const PorterDuffImageComposite = {
  display_name: "Porter-Duff图像合成",
  inputs: {
    destination: {
      name: "目标图像"
    },
    destination_alpha: {
      name: "目标图像alpha"
    },
    mode: {
      name: "模式"
    },
    source: {
      name: "来源图像"
    },
    source_alpha: {
      name: "来源图像alpha"
    }
  }
};
const Preview3D = {
  display_name: "预览3D",
  inputs: {
    image: {
      name: "图像"
    },
    model_file: {
      name: "模型文件"
    }
  }
};
const Preview3DAnimation = {
  display_name: "预览3D - 动画",
  inputs: {
    image: {
      name: "图像"
    },
    model_file: {
      name: "模型文件"
    }
  }
};
const PreviewAudio = {
  display_name: "预览音频",
  inputs: {
    audio: {
      name: "音频"
    },
    audioUI: {
      name: "音频UI"
    }
  }
};
const PreviewImage = {
  description: "将输入图像保存到您的ComfyUI临时目录。",
  display_name: "预览图像",
  inputs: {
    images: {
      name: "图像"
    }
  }
};
const RandomNoise = {
  display_name: "随机噪波",
  inputs: {
    control_after_generate: {
      name: "生成后控制"
    },
    noise_seed: {
      name: "噪波随机种"
    }
  }
};
const RebatchImages = {
  display_name: "重设图像批次",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    images: {
      name: "图像"
    }
  }
};
const RebatchLatents = {
  display_name: "重设Latent批次",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    latents: {
      name: "Latent因素"
    }
  }
};
const RenormCFG = {
  display_name: "RenormCFG",
  inputs: {
    cfg_trunc: {
      name: "cfg_trunc"
    },
    model: {
      name: "模型"
    },
    renorm_cfg: {
      name: "renorm_cfg"
    }
  }
};
const RepeatImageBatch = {
  display_name: "复制图像批次",
  inputs: {
    amount: {
      name: "数量"
    },
    image: {
      name: "图像"
    }
  }
};
const RepeatLatentBatch = {
  display_name: "复制Latent批次",
  inputs: {
    amount: {
      name: "数量"
    },
    samples: {
      name: "Latent"
    }
  }
};
const RescaleCFG = {
  display_name: "缩放CFG",
  inputs: {
    model: {
      name: "模型"
    },
    multiplier: {
      name: "乘数"
    }
  }
};
const SDTurboScheduler = {
  display_name: "SDTurbo调度器",
  inputs: {
    denoise: {
      name: "降噪"
    },
    model: {
      name: "模型"
    },
    steps: {
      name: "步数"
    }
  }
};
const SD_4XUpscale_Conditioning = {
  display_name: "SD_4X放大条件",
  inputs: {
    images: {
      name: "图片"
    },
    negative: {
      name: "负面条件"
    },
    noise_augmentation: {
      name: "噪波增强"
    },
    positive: {
      name: "正面条件"
    },
    scale_ratio: {
      name: "缩放比例"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const SV3D_Conditioning = {
  display_name: "SV3D条件",
  inputs: {
    clip_vision: {
      name: "clip视觉"
    },
    elevation: {
      name: "俯仰角"
    },
    height: {
      name: "高度"
    },
    init_image: {
      name: "初始图像"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "帧数"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const SVD_img2vid_Conditioning = {
  display_name: "SVD_img2vid条件",
  inputs: {
    augmentation_level: {
      name: "增强"
    },
    clip_vision: {
      name: "clip视觉"
    },
    fps: {
      name: "帧率"
    },
    height: {
      name: "高度"
    },
    init_image: {
      name: "初始图像"
    },
    motion_bucket_id: {
      name: "动态bucketID"
    },
    vae: {
      name: "vae"
    },
    video_frames: {
      name: "帧数"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const SamplerCustom = {
  display_name: "自定义采样器",
  inputs: {
    add_noise: {
      name: "添加噪波"
    },
    cfg: {
      name: "cfg"
    },
    control_after_generate: {
      name: "生成后的控制"
    },
    latent_image: {
      name: "Latent"
    },
    model: {
      name: "模型"
    },
    negative: {
      name: "负面条件"
    },
    noise_seed: {
      name: "噪波种子"
    },
    positive: {
      name: "正面条件"
    },
    sampler: {
      name: "采样器"
    },
    sigmas: {
      name: "Sigmas"
    }
  },
  outputs: {
    "0": {
      name: "Latent"
    },
    "1": {
      name: "降噪Latent"
    }
  }
};
const SamplerCustomAdvanced = {
  display_name: "自定义采样器（高级）",
  inputs: {
    guider: {
      name: "引导器"
    },
    latent_image: {
      name: "Latent图像"
    },
    noise: {
      name: "噪波"
    },
    sampler: {
      name: "采样器"
    },
    sigmas: {
      name: "西格玛"
    }
  },
  outputs: {
    "0": {
      name: "Latent"
    },
    "1": {
      name: "降噪Latent"
    }
  }
};
const SamplerDPMAdaptative = {
  display_name: "DPMAdaptative采样器",
  inputs: {
    accept_safety: {
      name: "accept_safety"
    },
    atol: {
      name: "atol"
    },
    dcoeff: {
      name: "dcoeff"
    },
    eta: {
      name: "eta"
    },
    h_init: {
      name: "h_init"
    },
    icoeff: {
      name: "icoeff"
    },
    order: {
      name: "order"
    },
    pcoeff: {
      name: "pcoeff"
    },
    rtol: {
      name: "rtol"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_2M_SDE = {
  display_name: "DPMPP_2M_SDE采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "噪波设备"
    },
    s_noise: {
      name: "s_noise"
    },
    solver_type: {
      name: "求解器类型"
    }
  }
};
const SamplerDPMPP_2S_Ancestral = {
  display_name: "DPMPP_2S_Ancestral采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_3M_SDE = {
  display_name: "DPMPP_3M_SDE采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "噪波设备"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerDPMPP_SDE = {
  display_name: "DPMPP_SDE采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    noise_device: {
      name: "噪波设备"
    },
    r: {
      name: "r"
    },
    s_noise: {
      name: "s_noise"
    }
  }
};
const SamplerEulerAncestral = {
  display_name: "EulerAncestral采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s噪波"
    }
  }
};
const SamplerEulerAncestralCFGPP = {
  display_name: "EulerAncestralCFG++采样器",
  inputs: {
    eta: {
      name: "eta"
    },
    s_noise: {
      name: "s噪波"
    }
  }
};
const SamplerEulerCFGpp = {
  display_name: "EuleCFG++采样器",
  inputs: {
    version: {
      name: "版本"
    }
  }
};
const SamplerLCMUpscale = {
  display_name: "LCM缩放采样器",
  inputs: {
    scale_ratio: {
      name: "缩放比例"
    },
    scale_steps: {
      name: "缩放步数"
    },
    upscale_method: {
      name: "缩放方法"
    }
  }
};
const SamplerLMS = {
  display_name: "LMS采样器",
  inputs: {
    order: {
      name: "顺序"
    }
  }
};
const SaveAnimatedPNG = {
  display_name: "保存动画（APNG）",
  inputs: {
    compress_level: {
      name: "压缩级别"
    },
    filename_prefix: {
      name: "文件名前缀"
    },
    fps: {
      name: "帧率"
    },
    images: {
      name: "图片"
    }
  }
};
const SaveAnimatedWEBP = {
  display_name: "保存动画（WEBP）",
  inputs: {
    filename_prefix: {
      name: "文件名前缀"
    },
    fps: {
      name: "帧率"
    },
    images: {
      name: "图片"
    },
    lossless: {
      name: "无损"
    },
    method: {
      name: "方法"
    },
    quality: {
      name: "质量"
    }
  }
};
const SaveAudio = {
  display_name: "保存音频",
  inputs: {
    audio: {
      name: "音频"
    },
    audioUI: {
      name: "音频UI"
    },
    filename_prefix: {
      name: "文件名前缀"
    }
  }
};
const SaveGLB = {
  display_name: "SaveGLB",
  inputs: {
    filename_prefix: {
      name: "文件名前缀"
    },
    image: {
      name: "图像"
    },
    mesh: {
      name: "网格"
    }
  }
};
const SaveImage = {
  description: "将输入图像保存到您的ComfyUI输出目录。",
  display_name: "保存图像",
  inputs: {
    filename_prefix: {
      name: "文件名前缀",
      tooltip: "保存文件的文件名的前缀。可使用格式信息如 %date:yyyy-MM-dd% 或 %空Latent.width%，以包含来自工作流内的信息。"
    },
    images: {
      name: "图片",
      tooltip: "要保存的图像。"
    }
  }
};
const SaveImageWebsocket = {
  display_name: "保存图像（网络接口）",
  inputs: {
    images: {
      name: "图片"
    }
  }
};
const SaveLatent = {
  display_name: "保存Latent",
  inputs: {
    filename_prefix: {
      name: "文件名前缀"
    },
    samples: {
      name: "Latent"
    }
  }
};
const SaveWEBM = {
  display_name: "保存WEBM",
  inputs: {
    codec: {
      name: "编解码器"
    },
    crf: {
      name: "crf",
      tooltip: "更高的crf意味着更低的质量和更小的文件大小，更低的crf意味着更高的质量和更大的文件大小。"
    },
    filename_prefix: {
      name: "文件名前缀"
    },
    fps: {
      name: "帧率"
    },
    images: {
      name: "图像"
    }
  }
};
const SelfAttentionGuidance = {
  display_name: "SAG自注意力引导",
  inputs: {
    blur_sigma: {
      name: "模糊Sigma"
    },
    model: {
      name: "模型"
    },
    scale: {
      name: "缩放"
    }
  }
};
const SetClipHooks = {
  display_name: "设置CLIP约束",
  inputs: {
    apply_to_conds: {
      name: "应用于条件"
    },
    clip: {
      name: "clip"
    },
    hooks: {
      name: "约束"
    },
    schedule_clip: {
      name: "安排clip"
    }
  }
};
const SetFirstSigma = {
  display_name: "设置第一个Sigma",
  inputs: {
    sigma: {
      name: "sigma"
    },
    sigmas: {
      name: "sigmas"
    }
  }
};
const SetHookKeyframes = {
  display_name: "设置约束关键帧",
  inputs: {
    hook_kf: {
      name: "约束关键帧"
    },
    hooks: {
      name: "约束"
    }
  }
};
const SetLatentNoiseMask = {
  display_name: "设置Latent噪波遮罩",
  inputs: {
    mask: {
      name: "遮罩"
    },
    samples: {
      name: "Latent"
    }
  }
};
const SetUnionControlNetType = {
  display_name: "设置UnionControlNet类型",
  inputs: {
    control_net: {
      name: "ControlNet"
    },
    type: {
      name: "类型"
    }
  }
};
const SkipLayerGuidanceDiT = {
  description: "通用的跳过层引导节点，可用于每个DiT模型。",
  display_name: "跳过层引导（DiT）",
  inputs: {
    double_layers: {
      name: "双层"
    },
    end_percent: {
      name: "结束百分比"
    },
    model: {
      name: "模型"
    },
    rescaling_scale: {
      name: "重新缩放比例"
    },
    scale: {
      name: "缩放"
    },
    single_layers: {
      name: "单层"
    },
    start_percent: {
      name: "开始百分比"
    }
  }
};
const SkipLayerGuidanceSD3 = {
  description: "通用版本的跳过层引导节点，可用于每个DiT模型。",
  display_name: "跳过层引导（SD3）",
  inputs: {
    end_percent: {
      name: "结束百分比"
    },
    layers: {
      name: "层"
    },
    model: {
      name: "模型"
    },
    scale: {
      name: "缩放"
    },
    start_percent: {
      name: "开始百分比"
    }
  }
};
const SolidMask = {
  display_name: "纯块遮罩",
  inputs: {
    height: {
      name: "高度"
    },
    value: {
      name: "明度"
    },
    width: {
      name: "宽度"
    }
  }
};
const SplitImageWithAlpha = {
  display_name: "分离图像Alpha",
  inputs: {
    image: {
      name: "图片"
    }
  }
};
const SplitSigmas = {
  display_name: "分离Sigma",
  inputs: {
    sigmas: {
      name: "Sigmas"
    },
    step: {
      name: "步数"
    }
  },
  outputs: {
    "0": {
      name: "高方差"
    },
    "1": {
      name: "低方差"
    }
  }
};
const SplitSigmasDenoise = {
  display_name: "分离Sigma降噪",
  inputs: {
    denoise: {
      name: "降噪"
    },
    sigmas: {
      name: "Sigmas"
    }
  },
  outputs: {
    "0": {
      name: "高方差"
    },
    "1": {
      name: "低方差"
    }
  }
};
const StableCascade_EmptyLatentImage = {
  display_name: "空Latent图像（Stable Cascade）",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    compression: {
      name: "压缩"
    },
    height: {
      name: "高度"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "阶段C"
    },
    "1": {
      name: "阶段B"
    }
  }
};
const StableCascade_StageB_Conditioning = {
  display_name: "Stable Cascade_B阶段_条件",
  inputs: {
    conditioning: {
      name: "条件"
    },
    stage_c: {
      name: "阶段c"
    }
  }
};
const StableCascade_StageC_VAEEncode = {
  display_name: "Stable Cascade_C阶段_VAE编码",
  inputs: {
    compression: {
      name: "压缩"
    },
    image: {
      name: "图像"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "阶段C"
    },
    "1": {
      name: "阶段B"
    }
  }
};
const StableCascade_SuperResolutionControlnet = {
  display_name: "Stable Cascade_超分辨率ControlNet",
  inputs: {
    image: {
      name: "图像"
    },
    vae: {
      name: "vae"
    }
  },
  outputs: {
    "0": {
      name: "ControlNet"
    },
    "1": {
      name: "阶段C"
    },
    "2": {
      name: "阶段B"
    }
  }
};
const StableZero123_Conditioning = {
  display_name: "StableZero123条件",
  inputs: {
    azimuth: {
      name: "方位角"
    },
    batch_size: {
      name: "批量大小"
    },
    clip_vision: {
      name: "clip视觉"
    },
    elevation: {
      name: "俯仰角"
    },
    height: {
      name: "高度"
    },
    init_image: {
      name: "初始图像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const StableZero123_Conditioning_Batched = {
  display_name: "StableZero123条件_批处理",
  inputs: {
    azimuth: {
      name: "方位角"
    },
    azimuth_batch_increment: {
      name: "方位角增量"
    },
    batch_size: {
      name: "批量大小"
    },
    clip_vision: {
      name: "clip视觉"
    },
    elevation: {
      name: "俯仰角"
    },
    elevation_batch_increment: {
      name: "俯仰角增量"
    },
    height: {
      name: "高度"
    },
    init_image: {
      name: "初始图像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面条件"
    },
    "1": {
      name: "负面条件"
    },
    "2": {
      name: "Latent"
    }
  }
};
const StyleModelApply = {
  display_name: "应用风格模型",
  inputs: {
    clip_vision_output: {
      name: "clip视觉输出"
    },
    conditioning: {
      name: "条件"
    },
    strength: {
      name: "强度"
    },
    strength_type: {
      name: "强度类型"
    },
    style_model: {
      name: "风格模型"
    }
  }
};
const StyleModelLoader = {
  display_name: "加载风格模型",
  inputs: {
    style_model_name: {
      name: "风格模型名称"
    }
  }
};
const TextEncodeHunyuanVideo_ImageToVideo = {
  display_name: "文本编码Hunyuan视频_图像到视频",
  inputs: {
    clip: {
      name: "clip"
    },
    clip_vision_output: {
      name: "clip视觉输出"
    },
    image_interleave: {
      name: "图像交错",
      tooltip: "图像与文本提示的影响程度。数字越高，文本提示的影响越大。"
    },
    prompt: {
      name: "提示"
    }
  }
};
const ThresholdMask = {
  display_name: "遮罩阈值",
  inputs: {
    mask: {
      name: "遮罩"
    },
    value: {
      name: "值"
    }
  }
};
const TomePatchModel = {
  display_name: "Tome合并模型Token",
  inputs: {
    model: {
      name: "模型"
    },
    ratio: {
      name: "比率"
    }
  }
};
const TorchCompileModel = {
  display_name: "Torch编译模型",
  inputs: {
    backend: {
      name: "后端"
    },
    model: {
      name: "模型"
    }
  }
};
const TripleCLIPLoader = {
  description: "[配方]\n\nSD3：clip-l，clip-g，t5",
  display_name: "三重CLIP加载器",
  inputs: {
    clip_name1: {
      name: "CLIP名称1"
    },
    clip_name2: {
      name: "CLIP名称2"
    },
    clip_name3: {
      name: "CLIP名称3"
    }
  }
};
const UNETLoader = {
  display_name: "UNet加载器",
  inputs: {
    unet_name: {
      name: "UNet名称"
    },
    weight_dtype: {
      name: "数据类型"
    }
  }
};
const UNetCrossAttentionMultiply = {
  display_name: "UNet交叉注意力乘数",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "模型"
    },
    out: {
      name: "输出"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetSelfAttentionMultiply = {
  display_name: "UNet自注意力乘数",
  inputs: {
    k: {
      name: "k"
    },
    model: {
      name: "模型"
    },
    out: {
      name: "输出"
    },
    q: {
      name: "q"
    },
    v: {
      name: "v"
    }
  }
};
const UNetTemporalAttentionMultiply = {
  display_name: "UNet时间注意力乘数",
  inputs: {
    cross_structural: {
      name: "交叉结构"
    },
    cross_temporal: {
      name: "交叉时间"
    },
    model: {
      name: "模型"
    },
    self_structural: {
      name: "自我结构"
    },
    self_temporal: {
      name: "自我时间"
    }
  }
};
const UpscaleModelLoader = {
  display_name: "加载放大模型",
  inputs: {
    model_name: {
      name: "模型名称"
    }
  }
};
const VAEDecode = {
  description: "将 Latent 图像解码为像素空间的图像。",
  display_name: "VAE解码",
  inputs: {
    samples: {
      name: "Latent",
      tooltip: "要解码的 Latent 图像。"
    },
    vae: {
      name: "vae",
      tooltip: "用于解码 Latent 图像的 VAE 模型。"
    }
  },
  outputs: {
    "0": {
      tooltip: "解码后的图像。"
    }
  }
};
const VAEDecodeAudio = {
  display_name: "VAE解码（音频）",
  inputs: {
    samples: {
      name: "Latent"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeHunyuan3D = {
  display_name: "VAEDecodeHunyuan3D",
  inputs: {
    num_chunks: {
      name: "块数"
    },
    octree_resolution: {
      name: "八叉树分辨率"
    },
    samples: {
      name: "样本"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEDecodeTiled = {
  display_name: "VAE解码（分块）",
  inputs: {
    overlap: {
      name: "重叠"
    },
    samples: {
      name: "Latent"
    },
    temporal_overlap: {
      name: "时间重叠",
      tooltip: "仅用于视频VAE：重叠的帧数。"
    },
    temporal_size: {
      name: "时间尺寸",
      tooltip: "仅用于视频VAE：一次解码的帧数。"
    },
    tile_size: {
      name: "分块尺寸"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncode = {
  display_name: "VAE编码",
  inputs: {
    pixels: {
      name: "像素"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeAudio = {
  display_name: "VAE编码（音频）",
  inputs: {
    audio: {
      name: "音频"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeForInpaint = {
  display_name: "VAE编码（局部重绘）",
  inputs: {
    grow_mask_by: {
      name: "扩展遮罩"
    },
    mask: {
      name: "遮罩"
    },
    pixels: {
      name: "像素"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAEEncodeTiled = {
  display_name: "VAE编码分块）",
  inputs: {
    overlap: {
      name: "重叠"
    },
    pixels: {
      name: "像素"
    },
    temporal_overlap: {
      name: "时间重叠",
      tooltip: "仅用于视频VAE：重叠的帧数。"
    },
    temporal_size: {
      name: "时间尺寸",
      tooltip: "仅用于视频VAE：一次编码的帧数。"
    },
    tile_size: {
      name: "分块尺寸"
    },
    vae: {
      name: "vae"
    }
  }
};
const VAELoader = {
  display_name: "加载VAE",
  inputs: {
    vae_name: {
      name: "vae名称"
    }
  }
};
const VAESave = {
  display_name: "保存VAE",
  inputs: {
    filename_prefix: {
      name: "文件名前缀"
    },
    vae: {
      name: "vae"
    }
  }
};
const VPScheduler = {
  display_name: "VPS调度器",
  inputs: {
    beta_d: {
      name: "beta_d"
    },
    beta_min: {
      name: "beta_min"
    },
    eps_s: {
      name: "eps_s"
    },
    steps: {
      name: "步数"
    }
  }
};
const VideoLinearCFGGuidance = {
  display_name: "视频线性CFG引导",
  inputs: {
    min_cfg: {
      name: "最小配置"
    },
    model: {
      name: "模型"
    }
  }
};
const VideoTriangleCFGGuidance = {
  display_name: "视频三角形CFG引导",
  inputs: {
    min_cfg: {
      name: "最小配置"
    },
    model: {
      name: "模型"
    }
  }
};
const VoxelToMeshBasic = {
  display_name: "VoxelToMeshBasic",
  inputs: {
    threshold: {
      name: "阈值"
    },
    voxel: {
      name: "体素"
    }
  }
};
const WanImageToVideo = {
  display_name: "Wan图像到视频",
  inputs: {
    batch_size: {
      name: "批量大小"
    },
    clip_vision_output: {
      name: "clip视觉输出"
    },
    height: {
      name: "高度"
    },
    length: {
      name: "长度"
    },
    negative: {
      name: "负面"
    },
    positive: {
      name: "正面"
    },
    start_image: {
      name: "开始图像"
    },
    vae: {
      name: "vae"
    },
    width: {
      name: "宽度"
    }
  },
  outputs: {
    "0": {
      name: "正面"
    },
    "1": {
      name: "负面"
    },
    "2": {
      name: "潜在"
    }
  }
};
const WebcamCapture = {
  display_name: "网络摄像头捕获",
  inputs: {
    capture_on_queue: {
      name: "执行时捕获"
    },
    height: {
      name: "高度"
    },
    image: {
      name: "图像"
    },
    "waiting for camera___": {},
    width: {
      name: "宽度"
    }
  }
};
const unCLIPCheckpointLoader = {
  display_name: "unCLIPCheckpoint加载器",
  inputs: {
    ckpt_name: {
      name: "Checkpoint名称"
    }
  }
};
const unCLIPConditioning = {
  display_name: "unCLIP条件",
  inputs: {
    clip_vision_output: {
      name: "CLIP视觉输出"
    },
    conditioning: {
      name: "条件"
    },
    noise_augmentation: {
      name: "噪波增强"
    },
    strength: {
      name: "强度"
    }
  }
};
const zhNodes = {
  AddNoise,
  AlignYourStepsScheduler,
  BasicGuider,
  BasicScheduler,
  BetaSamplingScheduler,
  CFGGuider,
  CLIPAttentionMultiply,
  CLIPLoader,
  CLIPMergeAdd,
  CLIPMergeSimple,
  CLIPMergeSubtract,
  CLIPSave,
  CLIPSetLastLayer,
  CLIPTextEncode,
  CLIPTextEncodeControlnet,
  CLIPTextEncodeFlux,
  CLIPTextEncodeHunyuanDiT,
  CLIPTextEncodeLumina2,
  CLIPTextEncodePixArtAlpha,
  CLIPTextEncodeSD3,
  CLIPTextEncodeSDXL,
  CLIPTextEncodeSDXLRefiner,
  CLIPVisionEncode,
  CLIPVisionLoader,
  Canny,
  CheckpointLoader,
  CheckpointLoaderSimple,
  CheckpointSave,
  CombineHooks2,
  CombineHooks4,
  CombineHooks8,
  ConditioningAverage,
  ConditioningCombine,
  ConditioningConcat,
  ConditioningSetArea,
  ConditioningSetAreaPercentage,
  ConditioningSetAreaPercentageVideo,
  ConditioningSetAreaStrength,
  ConditioningSetDefaultCombine,
  ConditioningSetMask,
  ConditioningSetProperties,
  ConditioningSetPropertiesAndCombine,
  ConditioningSetTimestepRange,
  ConditioningStableAudio,
  ConditioningTimestepsRange,
  ConditioningZeroOut,
  ControlNetApply,
  ControlNetApplyAdvanced,
  ControlNetApplySD3,
  ControlNetInpaintingAliMamaApply,
  ControlNetLoader,
  CosmosImageToVideoLatent,
  CreateHookKeyframe,
  CreateHookKeyframesFromFloats,
  CreateHookKeyframesInterpolated,
  CreateHookLora,
  CreateHookLoraModelOnly,
  CreateHookModelAsLora,
  CreateHookModelAsLoraModelOnly,
  CropMask,
  DiffControlNetLoader,
  DifferentialDiffusion,
  DiffusersLoader,
  DisableNoise,
  DualCFGGuider,
  DualCLIPLoader,
  EmptyCosmosLatentVideo,
  EmptyHunyuanLatentVideo,
  EmptyImage,
  EmptyLTXVLatentVideo,
  EmptyLatentAudio,
  EmptyLatentHunyuan3Dv2,
  EmptyLatentImage,
  EmptyMochiLatentVideo,
  EmptySD3LatentImage,
  ExponentialScheduler,
  FeatherMask,
  FlipSigmas,
  FluxDisableGuidance,
  FluxGuidance,
  FreeU,
  FreeU_V2,
  GITSScheduler,
  GLIGENLoader,
  GLIGENTextBoxApply,
  GrowMask,
  Hunyuan3Dv2Conditioning,
  Hunyuan3Dv2ConditioningMultiView,
  HunyuanImageToVideo,
  HyperTile,
  HypernetworkLoader,
  ImageBatch,
  ImageBlend,
  ImageBlur,
  ImageColorToMask,
  ImageCompositeMasked,
  ImageCrop,
  ImageFromBatch,
  ImageInvert,
  ImageOnlyCheckpointLoader,
  ImageOnlyCheckpointSave,
  ImagePadForOutpaint,
  ImageQuantize,
  ImageScale,
  ImageScaleBy,
  ImageScaleToTotalPixels,
  ImageSharpen,
  ImageToMask,
  ImageUpscaleWithModel,
  InpaintModelConditioning,
  InstructPixToPixConditioning,
  InvertMask,
  JoinImageWithAlpha,
  KSampler,
  KSamplerAdvanced,
  KSamplerSelect,
  KarrasScheduler,
  LTXVAddGuide,
  LTXVConditioning,
  LTXVCropGuides,
  LTXVImgToVideo,
  LTXVPreprocess,
  LTXVScheduler,
  LaplaceScheduler,
  LatentAdd,
  LatentApplyOperation,
  LatentApplyOperationCFG,
  LatentBatch,
  LatentBatchSeedBehavior,
  LatentBlend,
  LatentComposite,
  LatentCompositeMasked,
  LatentCrop,
  LatentFlip,
  LatentFromBatch,
  LatentInterpolate,
  LatentMultiply,
  LatentOperationSharpen,
  LatentOperationTonemapReinhard,
  LatentRotate,
  LatentSubtract,
  LatentUpscale,
  LatentUpscaleBy,
  Load3D,
  Load3DAnimation,
  LoadAudio,
  LoadImage,
  LoadImageMask,
  LoadImageOutput,
  LoadLatent,
  LoraLoader,
  LoraLoaderModelOnly,
  LoraSave,
  Mahiro,
  MaskComposite,
  MaskToImage,
  ModelComputeDtype,
  ModelMergeAdd,
  ModelMergeAuraflow,
  ModelMergeBlocks,
  ModelMergeCosmos14B,
  ModelMergeCosmos7B,
  ModelMergeFlux1,
  ModelMergeLTXV,
  ModelMergeMochiPreview,
  ModelMergeSD1,
  ModelMergeSD2,
  ModelMergeSD35_Large,
  ModelMergeSD3_2B,
  ModelMergeSDXL,
  ModelMergeSimple,
  ModelMergeSubtract,
  ModelSamplingAuraFlow,
  ModelSamplingContinuousEDM,
  ModelSamplingContinuousV,
  ModelSamplingDiscrete,
  ModelSamplingFlux,
  ModelSamplingLTXV,
  ModelSamplingSD3,
  ModelSamplingStableCascade,
  ModelSave,
  Morphology,
  PairConditioningCombine,
  PairConditioningSetDefaultCombine,
  PairConditioningSetProperties,
  PairConditioningSetPropertiesAndCombine,
  PatchModelAddDownscale,
  PerpNeg,
  PerpNegGuider,
  PerturbedAttentionGuidance,
  PhotoMakerEncode,
  PhotoMakerLoader,
  PolyexponentialScheduler,
  PorterDuffImageComposite,
  Preview3D,
  Preview3DAnimation,
  PreviewAudio,
  PreviewImage,
  RandomNoise,
  RebatchImages,
  RebatchLatents,
  RenormCFG,
  RepeatImageBatch,
  RepeatLatentBatch,
  RescaleCFG,
  SDTurboScheduler,
  SD_4XUpscale_Conditioning,
  SV3D_Conditioning,
  SVD_img2vid_Conditioning,
  SamplerCustom,
  SamplerCustomAdvanced,
  SamplerDPMAdaptative,
  SamplerDPMPP_2M_SDE,
  SamplerDPMPP_2S_Ancestral,
  SamplerDPMPP_3M_SDE,
  SamplerDPMPP_SDE,
  SamplerEulerAncestral,
  SamplerEulerAncestralCFGPP,
  SamplerEulerCFGpp,
  SamplerLCMUpscale,
  SamplerLMS,
  SaveAnimatedPNG,
  SaveAnimatedWEBP,
  SaveAudio,
  SaveGLB,
  SaveImage,
  SaveImageWebsocket,
  SaveLatent,
  SaveWEBM,
  SelfAttentionGuidance,
  SetClipHooks,
  SetFirstSigma,
  SetHookKeyframes,
  SetLatentNoiseMask,
  SetUnionControlNetType,
  SkipLayerGuidanceDiT,
  SkipLayerGuidanceSD3,
  SolidMask,
  SplitImageWithAlpha,
  SplitSigmas,
  SplitSigmasDenoise,
  StableCascade_EmptyLatentImage,
  StableCascade_StageB_Conditioning,
  StableCascade_StageC_VAEEncode,
  StableCascade_SuperResolutionControlnet,
  StableZero123_Conditioning,
  StableZero123_Conditioning_Batched,
  StyleModelApply,
  StyleModelLoader,
  TextEncodeHunyuanVideo_ImageToVideo,
  ThresholdMask,
  TomePatchModel,
  TorchCompileModel,
  TripleCLIPLoader,
  UNETLoader,
  UNetCrossAttentionMultiply,
  UNetSelfAttentionMultiply,
  UNetTemporalAttentionMultiply,
  UpscaleModelLoader,
  VAEDecode,
  VAEDecodeAudio,
  VAEDecodeHunyuan3D,
  VAEDecodeTiled,
  VAEEncode,
  VAEEncodeAudio,
  VAEEncodeForInpaint,
  VAEEncodeTiled,
  VAELoader,
  VAESave,
  VPScheduler,
  VideoLinearCFGGuidance,
  VideoTriangleCFGGuidance,
  VoxelToMeshBasic,
  WanImageToVideo,
  WebcamCapture,
  unCLIPCheckpointLoader,
  unCLIPConditioning
};
const Comfy_Canvas_SelectionToolbox = {
  name: "显示选择工具箱"
};
const Comfy_ConfirmClear = {
  name: "清除工作流时需要确认"
};
const Comfy_DOMClippingEnabled = {
  name: "启用DOM元素裁剪（启用可能会降低性能）"
};
const Comfy_DevMode = {
  name: "启用开发模式选项（API保存等）"
};
const Comfy_DisableFloatRounding = {
  name: "禁用默认浮点组件四舍五入。",
  tooltip: "(需要重新加载页面) 当节点自身设置了四舍五入时，无法禁用该功能。"
};
const Comfy_DisableSliders = {
  name: "禁用节点组件滑块"
};
const Comfy_EditAttention_Delta = {
  name: "Ctrl+上/下 精度"
};
const Comfy_EnableTooltips = {
  name: "启用工具提示"
};
const Comfy_EnableWorkflowViewRestore = {
  name: "在工作流中保存和恢复视图位置及缩放"
};
const Comfy_FloatRoundingPrecision = {
  name: "浮点组件四舍五入的小数位数 [0 = 自动]。",
  tooltip: "(需要重新加载页面)"
};
const Comfy_Graph_CanvasInfo = {
  name: "在左下角显示画布信息（fps等）"
};
const Comfy_Graph_CanvasMenu = {
  name: "显示图形画布菜单"
};
const Comfy_Graph_CtrlShiftZoom = {
  name: "启用快速缩放快捷键（Ctrl + Shift + 拖动）"
};
const Comfy_Graph_LinkMarkers = {
  name: "连线中点标记",
  options: {
    Arrow: "箭头",
    Circle: "圆",
    None: "无"
  }
};
const Comfy_Graph_ZoomSpeed = {
  name: "画布缩放速度"
};
const Comfy_GroupSelectedNodes_Padding = {
  name: "选定节点的组内边距"
};
const Comfy_Group_DoubleClickTitleToEdit = {
  name: "双击组标题以编辑"
};
const Comfy_LinkRelease_Action = {
  name: "释放连线时的操作",
  options: {
    "context menu": "上下文菜单",
    "no action": "无操作",
    "search box": "搜索框"
  }
};
const Comfy_LinkRelease_ActionShift = {
  name: "释放连线时的操作（Shift）",
  options: {
    "context menu": "上下文菜单",
    "no action": "无操作",
    "search box": "搜索框"
  }
};
const Comfy_LinkRenderMode = {
  name: "连线渲染样式",
  options: {
    Hidden: "隐藏",
    Linear: "直线",
    Spline: "曲线",
    Straight: "直角线"
  }
};
const Comfy_Locale = {
  name: "语言"
};
const Comfy_MaskEditor_BrushAdjustmentSpeed = {
  name: "画笔调整速度倍增器",
  tooltip: "控制调整时画笔大小和硬度变化的速度。更高的值意味着更快的变化。"
};
const Comfy_MaskEditor_UseDominantAxis = {
  name: "将画笔调整锁定到主轴",
  tooltip: "启用后，画笔调整将仅根据您移动的方向影响大小或硬度。"
};
const Comfy_MaskEditor_UseNewEditor = {
  name: "使用新画笔编辑器",
  tooltip: "切换到新的画笔编辑器界面"
};
const Comfy_ModelLibrary_AutoLoadAll = {
  name: "自动加载所有模型文件夹",
  tooltip: "开启后，打开模型库会加载所有文件夹内的模型（可能导致卡顿）。关闭后，仅加载当前文件夹内的模型。"
};
const Comfy_ModelLibrary_NameFormat = {
  name: "在模型库树视图中显示的名称",
  options: {
    filename: "文件名",
    title: "标题"
  },
  tooltip: "选择“文件名”以在模型列表中显示原始文件名的简化视图（不带目录和“.safetensors”后缀名）。选择“标题”以显示可配置的模型元数据标题。"
};
const Comfy_NodeBadge_NodeIdBadgeMode = {
  name: "节点ID标签",
  options: {
    None: "无",
    "Show all": "显示全部"
  }
};
const Comfy_NodeBadge_NodeLifeCycleBadgeMode = {
  name: "节点制作周期标签",
  options: {
    None: "无",
    "Show all": "显示全部"
  }
};
const Comfy_NodeBadge_NodeSourceBadgeMode = {
  name: "节点源标签",
  options: {
    "Hide built-in": "仅第三方",
    None: "无",
    "Show all": "显示全部"
  }
};
const Comfy_NodeInputConversionSubmenus = {
  name: "在节点上下文菜单中，将输入/组件之间转换的条目放置在子菜单中。"
};
const Comfy_NodeSearchBoxImpl = {
  name: "节点搜索框",
  options: {
    "default": "默认",
    "litegraph (legacy)": "litegraph（旧版）"
  }
};
const Comfy_NodeSearchBoxImpl_NodePreview = {
  name: "显示节点预览",
  tooltip: "仅适用于默认框架"
};
const Comfy_NodeSearchBoxImpl_ShowCategory = {
  name: "显示节点类别",
  tooltip: "仅适用于默认框架"
};
const Comfy_NodeSearchBoxImpl_ShowIdName = {
  name: "显示节点ID名称",
  tooltip: "仅适用于默认框架"
};
const Comfy_NodeSearchBoxImpl_ShowNodeFrequency = {
  name: "显示节点频率",
  tooltip: "仅适用于默认框架"
};
const Comfy_NodeSuggestions_number = {
  name: "节点建议数量",
  tooltip: "仅适用于 litegraph"
};
const Comfy_Node_AutoSnapLinkToSlot = {
  name: "连线自动吸附到节点接口",
  tooltip: "在节点上拖动连线时，连线会自动吸附到节点的可用输入接口。"
};
const Comfy_Node_BypassAllLinksOnDelete = {
  name: "删除节点时保留连线",
  tooltip: "删除节点时，尝试重新连接其所有输入和输出连线（类似于忽略节点）。"
};
const Comfy_Node_DoubleClickTitleToEdit = {
  name: "双击节点标题以编辑"
};
const Comfy_Node_MiddleClickRerouteNode = {
  name: "中键单击创建新的转接点"
};
const Comfy_Node_Opacity = {
  name: "节点不透明度"
};
const Comfy_Node_ShowDeprecated = {
  name: "在搜索中显示已弃用的节点",
  tooltip: "弃用节点在UI中默认隐藏，但在工作流中仍然有效。"
};
const Comfy_Node_ShowExperimental = {
  name: "在搜索中显示实验性节点",
  tooltip: "实验节点在UI中标记为实验性，可能在未来版本中发生重大变化或被移除。在生产工作流中谨慎使用。"
};
const Comfy_Node_SnapHighlightsNode = {
  name: "吸附高亮节点",
  tooltip: "在拖动连线经过具有可用输入接口的节点时，高亮显示该节点。"
};
const Comfy_Pointer_ClickBufferTime = {
  name: "指针点击漂移延迟",
  tooltip: "按下指针按钮后，忽略指针移动的最大时间（毫秒）。\n\n有助于防止在点击时意外移动鼠标。"
};
const Comfy_Pointer_ClickDrift = {
  name: "指针点击漂移（距离）",
  tooltip: "如果指针在按住按钮时移动超过此距离，则视为拖动（而不是点击）。\n\n有助于防止在点击时意外移动鼠标"
};
const Comfy_Pointer_DoubleClickTime = {
  name: "双击间隔（最大）",
  tooltip: "双击的两次点击之间的最大时间（毫秒）。增加此值有助于解决双击有时未被识别的问题。"
};
const Comfy_PreviewFormat = {
  name: "预览图像格式",
  tooltip: "在图像组件中显示预览时，将其转换为轻量级图像，例如webp、jpeg、webp;50等。"
};
const Comfy_PromptFilename = {
  name: "保存工作流时提示文件名"
};
const Comfy_QueueButton_BatchCountLimit = {
  name: "批处理计数限制",
  tooltip: "单次添加到队列的最大任务数量"
};
const Comfy_Queue_MaxHistoryItems = {
  name: "队列历史大小",
  tooltip: "队列历史中显示的最大任务数量。"
};
const Comfy_RerouteBeta = {
  name: "选择加入转接点Beta",
  tooltip: "启用新的转接点。\n\n通过按住alt并划过连线来添加转接点，或在连线中点菜单中添加。\n\n禁用此选项不会造成破坏 - 转接点将被隐藏。"
};
const Comfy_Sidebar_Location = {
  name: "侧边栏位置",
  options: {
    left: "左侧",
    right: "右侧"
  }
};
const Comfy_Sidebar_Size = {
  name: "侧边栏大小",
  options: {
    normal: "正常",
    small: "小"
  }
};
const Comfy_SnapToGrid_GridSize = {
  name: "吸附网格大小",
  tooltip: "在按住shift拖动和调整节点大小时，节点将对齐到网格，该选项控制网格。"
};
const Comfy_TextareaWidget_FontSize = {
  name: "文本框组件字体大小"
};
const Comfy_TextareaWidget_Spellcheck = {
  name: "文本框组件拼写检查"
};
const Comfy_TreeExplorer_ItemPadding = {
  name: "树形浏览器项目内边距"
};
const Comfy_UseNewMenu = {
  name: "使用新菜单",
  options: {
    Bottom: "底部",
    Disabled: "禁用",
    Top: "顶部"
  }
};
const Comfy_Validation_NodeDefs = {
  name: "校验节点定义（慢）",
  tooltip: "推荐给节点开发者。开启后会在 ComfyUI 启动时校验全部节点定义。"
};
const Comfy_Validation_Workflows = {
  name: "校验工作流"
};
const Comfy_WidgetControlMode = {
  name: "组件控制模式",
  options: {
    after: "之后",
    before: "之前"
  },
  tooltip: "控制组件值的更新时机（随机/增加/减少），可以在执行工作流之前或之后。"
};
const Comfy_Window_UnloadConfirmation = {
  name: "关闭窗口时显示确认"
};
const Comfy_Workflow_ConfirmDelete = {
  name: "删除工作流时显示确认"
};
const Comfy_Workflow_ShowMissingModelsWarning = {
  name: "显示缺失模型警告"
};
const Comfy_Workflow_ShowMissingNodesWarning = {
  name: "显示缺失节点警告"
};
const Comfy_Workflow_SortNodeIdOnSave = {
  name: "保存节点ID到工作流"
};
const Comfy_Workflow_WorkflowTabsPosition = {
  name: "已打开工作流的位置",
  options: {
    Sidebar: "侧边栏",
    Topbar: "顶部栏",
    "Topbar (2nd-row)": "顶部栏 (第二行)"
  }
};
const LiteGraph_Canvas_LowQualityRenderingZoomThreshold = {
  name: "低质量渲染缩放阈值",
  tooltip: "在缩小时渲染低质量形状"
};
const LiteGraph_Canvas_MaximumFps = {
  name: "最大FPS",
  tooltip: "画布允许渲染的最大帧数。限制GPU使用以换取流畅度。如果为0，则使用屏幕刷新率。默认值：0"
};
const LiteGraph_ContextMenu_Scaling = {
  name: "放大时缩放节点组合部件菜单（列表）"
};
const LiteGraph_Node_TooltipDelay = {
  name: "工具提示延迟"
};
const pysssss_SnapToGrid = {
  name: "始终吸附到网格"
};
const zhSettings = {
  "Comfy-Desktop_AutoUpdate": {
    name: "自动检查更新"
  },
  "Comfy-Desktop_SendStatistics": {
    name: "发送匿名使用情况统计"
  },
  "Comfy-Desktop_UV_PypiInstallMirror": {
    name: "Pypi 安装镜像",
    tooltip: "默认 pip 安装镜像"
  },
  "Comfy-Desktop_UV_PythonInstallMirror": {
    name: "Python安装镜像",
    tooltip: "管理的Python安装包从Astral python-build-standalone项目下载。此变量可以设置为镜像URL，以使用不同的Python安装源。提供的URL将替换https://github.com/astral-sh/python-build-standalone/releases/download，例如，在https://github.com/astral-sh/python-build-standalone/releases/download/20240713/cpython-3.12.4%2B20240713-aarch64-apple-darwin-install_only.tar.gz中。可以通过使用file:// URL方案从本地目录读取分发包。"
  },
  "Comfy-Desktop_UV_TorchInstallMirror": {
    name: "Torch安装镜像",
    tooltip: "用于pytorch的Pip安装镜像"
  },
  "Comfy-Desktop_WindowStyle": {
    name: "窗口样式",
    options: {
      custom: "自定义",
      "default": "默认"
    },
    tooltip: "选择自定义选项以隐藏系统标题栏"
  },
  Comfy_Canvas_SelectionToolbox,
  Comfy_ConfirmClear,
  Comfy_DOMClippingEnabled,
  Comfy_DevMode,
  Comfy_DisableFloatRounding,
  Comfy_DisableSliders,
  Comfy_EditAttention_Delta,
  Comfy_EnableTooltips,
  Comfy_EnableWorkflowViewRestore,
  Comfy_FloatRoundingPrecision,
  Comfy_Graph_CanvasInfo,
  Comfy_Graph_CanvasMenu,
  Comfy_Graph_CtrlShiftZoom,
  Comfy_Graph_LinkMarkers,
  Comfy_Graph_ZoomSpeed,
  Comfy_GroupSelectedNodes_Padding,
  Comfy_Group_DoubleClickTitleToEdit,
  Comfy_LinkRelease_Action,
  Comfy_LinkRelease_ActionShift,
  Comfy_LinkRenderMode,
  Comfy_Locale,
  Comfy_MaskEditor_BrushAdjustmentSpeed,
  Comfy_MaskEditor_UseDominantAxis,
  Comfy_MaskEditor_UseNewEditor,
  Comfy_ModelLibrary_AutoLoadAll,
  Comfy_ModelLibrary_NameFormat,
  Comfy_NodeBadge_NodeIdBadgeMode,
  Comfy_NodeBadge_NodeLifeCycleBadgeMode,
  Comfy_NodeBadge_NodeSourceBadgeMode,
  Comfy_NodeInputConversionSubmenus,
  Comfy_NodeSearchBoxImpl,
  Comfy_NodeSearchBoxImpl_NodePreview,
  Comfy_NodeSearchBoxImpl_ShowCategory,
  Comfy_NodeSearchBoxImpl_ShowIdName,
  Comfy_NodeSearchBoxImpl_ShowNodeFrequency,
  Comfy_NodeSuggestions_number,
  Comfy_Node_AutoSnapLinkToSlot,
  Comfy_Node_BypassAllLinksOnDelete,
  Comfy_Node_DoubleClickTitleToEdit,
  Comfy_Node_MiddleClickRerouteNode,
  Comfy_Node_Opacity,
  Comfy_Node_ShowDeprecated,
  Comfy_Node_ShowExperimental,
  Comfy_Node_SnapHighlightsNode,
  Comfy_Pointer_ClickBufferTime,
  Comfy_Pointer_ClickDrift,
  Comfy_Pointer_DoubleClickTime,
  Comfy_PreviewFormat,
  Comfy_PromptFilename,
  Comfy_QueueButton_BatchCountLimit,
  Comfy_Queue_MaxHistoryItems,
  Comfy_RerouteBeta,
  Comfy_Sidebar_Location,
  Comfy_Sidebar_Size,
  Comfy_SnapToGrid_GridSize,
  Comfy_TextareaWidget_FontSize,
  Comfy_TextareaWidget_Spellcheck,
  Comfy_TreeExplorer_ItemPadding,
  Comfy_UseNewMenu,
  Comfy_Validation_NodeDefs,
  Comfy_Validation_Workflows,
  Comfy_WidgetControlMode,
  Comfy_Window_UnloadConfirmation,
  Comfy_Workflow_ConfirmDelete,
  Comfy_Workflow_ShowMissingModelsWarning,
  Comfy_Workflow_ShowMissingNodesWarning,
  Comfy_Workflow_SortNodeIdOnSave,
  Comfy_Workflow_WorkflowTabsPosition,
  LiteGraph_Canvas_LowQualityRenderingZoomThreshold,
  LiteGraph_Canvas_MaximumFps,
  LiteGraph_ContextMenu_Scaling,
  LiteGraph_Node_TooltipDelay,
  pysssss_SnapToGrid
};
function buildLocale(main, nodes, commands2, settings) {
  return {
    ...main,
    nodeDefs: nodes,
    commands: commands2,
    settings
  };
}
__name(buildLocale, "buildLocale");
const messages = {
  en: buildLocale(en, enNodes, enCommands, enSettings),
  zh: buildLocale(zh, zhNodes, zhCommands, zhSettings),
  ru: buildLocale(ru, ruNodes, ruCommands, ruSettings),
  ja: buildLocale(ja, jaNodes, jaCommands, jaSettings),
  ko: buildLocale(ko, koNodes, koCommands, koSettings),
  fr: buildLocale(fr, frNodes, frCommands, frSettings)
};
const i18n = createI18n({
  // Must set `false`, as Vue I18n Legacy API is for Vue 2
  legacy: false,
  locale: navigator.language.split("-")[0] || "en",
  fallbackLocale: "en",
  messages,
  // Ignore warnings for locale options as each option is in its own language.
  // e.g. "English", "中文", "Русский", "日本語", "한국어", "Français"
  missingWarn: /^(?!settings\.Comfy_Locale\.options\.).+/,
  fallbackWarn: /^(?!settings\.Comfy_Locale\.options\.).+/
});
const { t, te } = i18n.global;
function st(key, fallbackMessage) {
  return te(key) ? t(key) : fallbackMessage;
}
__name(st, "st");
const useToastStore = /* @__PURE__ */ defineStore("toast", () => {
  const messagesToAdd = ref([]);
  const messagesToRemove = ref([]);
  const removeAllRequested = ref(false);
  function add3(message3) {
    messagesToAdd.value = [...messagesToAdd.value, message3];
  }
  __name(add3, "add");
  function remove4(message3) {
    messagesToRemove.value = [...messagesToRemove.value, message3];
  }
  __name(remove4, "remove");
  function removeAll() {
    removeAllRequested.value = true;
  }
  __name(removeAll, "removeAll");
  function addAlert(message3) {
    add3({ severity: "warn", summary: "Alert", detail: message3 });
  }
  __name(addAlert, "addAlert");
  return {
    messagesToAdd,
    messagesToRemove,
    removeAllRequested,
    add: add3,
    remove: remove4,
    removeAll,
    addAlert
  };
});
function useErrorHandling() {
  const toast = useToastStore();
  const toastErrorHandler = /* @__PURE__ */ __name((error2) => {
    toast.add({
      severity: "error",
      summary: t("g.error"),
      detail: error2.message
    });
  }, "toastErrorHandler");
  const wrapWithErrorHandling = /* @__PURE__ */ __name((action, errorHandler2, finallyHandler) => (...args) => {
    try {
      return action(...args);
    } catch (e2) {
      ;
      (errorHandler2 ?? toastErrorHandler)(e2);
    } finally {
      finallyHandler?.();
    }
  }, "wrapWithErrorHandling");
  const wrapWithErrorHandlingAsync = /* @__PURE__ */ __name((action, errorHandler2, finallyHandler) => async (...args) => {
    try {
      return await action(...args);
    } catch (e2) {
      ;
      (errorHandler2 ?? toastErrorHandler)(e2);
    } finally {
      finallyHandler?.();
    }
  }, "wrapWithErrorHandlingAsync");
  return { wrapWithErrorHandling, wrapWithErrorHandlingAsync };
}
__name(useErrorHandling, "useErrorHandling");
const nodeSlotSchema = z.object({
  CLIP: z.string(),
  CLIP_VISION: z.string(),
  CLIP_VISION_OUTPUT: z.string(),
  CONDITIONING: z.string(),
  CONTROL_NET: z.string(),
  IMAGE: z.string(),
  LATENT: z.string(),
  MASK: z.string(),
  MODEL: z.string(),
  STYLE_MODEL: z.string(),
  VAE: z.string(),
  NOISE: z.string(),
  GUIDER: z.string(),
  SAMPLER: z.string(),
  SIGMAS: z.string(),
  TAESD: z.string()
});
const litegraphBaseSchema = z.object({
  BACKGROUND_IMAGE: z.string(),
  CLEAR_BACKGROUND_COLOR: z.string(),
  NODE_TITLE_COLOR: z.string(),
  NODE_SELECTED_TITLE_COLOR: z.string(),
  NODE_TEXT_SIZE: z.number(),
  NODE_TEXT_COLOR: z.string(),
  NODE_TEXT_HIGHLIGHT_COLOR: z.string(),
  NODE_SUBTEXT_SIZE: z.number(),
  NODE_DEFAULT_COLOR: z.string(),
  NODE_DEFAULT_BGCOLOR: z.string(),
  NODE_DEFAULT_BOXCOLOR: z.string(),
  NODE_DEFAULT_SHAPE: z.union([
    z.literal(LiteGraph.BOX_SHAPE),
    z.literal(LiteGraph.ROUND_SHAPE),
    z.literal(LiteGraph.CARD_SHAPE),
    // Legacy palettes have string field for NODE_DEFAULT_SHAPE.
    z.string()
  ]),
  NODE_BOX_OUTLINE_COLOR: z.string(),
  NODE_BYPASS_BGCOLOR: z.string(),
  NODE_ERROR_COLOUR: z.string(),
  DEFAULT_SHADOW_COLOR: z.string(),
  DEFAULT_GROUP_FONT: z.number(),
  WIDGET_BGCOLOR: z.string(),
  WIDGET_OUTLINE_COLOR: z.string(),
  WIDGET_TEXT_COLOR: z.string(),
  WIDGET_SECONDARY_TEXT_COLOR: z.string(),
  LINK_COLOR: z.string(),
  EVENT_LINK_COLOR: z.string(),
  CONNECTING_LINK_COLOR: z.string(),
  BADGE_FG_COLOR: z.string(),
  BADGE_BG_COLOR: z.string()
});
const comfyBaseSchema = z.object({
  ["fg-color"]: z.string(),
  ["bg-color"]: z.string(),
  ["bg-img"]: z.string().optional(),
  ["comfy-menu-bg"]: z.string(),
  ["comfy-menu-secondary-bg"]: z.string(),
  ["comfy-input-bg"]: z.string(),
  ["input-text"]: z.string(),
  ["descrip-text"]: z.string(),
  ["drag-text"]: z.string(),
  ["error-text"]: z.string(),
  ["border-color"]: z.string(),
  ["tr-even-bg-color"]: z.string(),
  ["tr-odd-bg-color"]: z.string(),
  ["content-bg"]: z.string(),
  ["content-fg"]: z.string(),
  ["content-hover-bg"]: z.string(),
  ["content-hover-fg"]: z.string(),
  ["bar-shadow"]: z.string()
});
const colorsSchema = z.object({
  node_slot: nodeSlotSchema,
  litegraph_base: litegraphBaseSchema,
  comfy_base: comfyBaseSchema
});
const partialColorsSchema = z.object({
  node_slot: nodeSlotSchema.partial(),
  litegraph_base: litegraphBaseSchema.partial(),
  comfy_base: comfyBaseSchema.partial()
});
const paletteSchema = z.object({
  id: z.string(),
  name: z.string(),
  colors: partialColorsSchema,
  light_theme: z.boolean().optional()
}).passthrough();
const completedPaletteSchema = z.object({
  id: z.string(),
  name: z.string(),
  colors: colorsSchema
}).passthrough();
const colorPalettesSchema = z.record(paletteSchema);
const zNodeId = z.union([z.number().int(), z.string()]);
const zNodeInputName = z.string();
const zSlotIndex = z.union([
  z.number().int(),
  z.string().transform((val) => parseInt(val)).refine((val) => !isNaN(val), {
    message: "Invalid number"
  })
]);
const zDataType = z.union([z.string(), z.array(z.string()), z.number()]);
const zVector2 = z.union([
  z.object({ 0: z.number(), 1: z.number() }).passthrough().transform((v2) => [v2[0], v2[1]]),
  z.tuple([z.number(), z.number()])
]);
const zModelFile = z.object({
  name: z.string(),
  url: z.string().url(),
  hash: z.string().optional(),
  hash_type: z.string().optional(),
  directory: z.string()
});
const zGraphState = z.object({
  lastGroupid: z.number().optional(),
  lastNodeId: z.number().optional(),
  lastLinkId: z.number().optional(),
  lastRerouteId: z.number().optional()
}).passthrough();
const zComfyLink = z.tuple([
  z.number(),
  // Link id
  zNodeId,
  // Node id of source node
  zSlotIndex,
  // Output slot# of source node
  zNodeId,
  // Node id of destination node
  zSlotIndex,
  // Input slot# of destination node
  zDataType
  // Data type
]);
const zComfyLinkExtension = z.object({
  id: z.number(),
  parentId: z.number()
}).passthrough();
const zComfyLinkObject = z.object({
  id: z.number(),
  origin_id: zNodeId,
  origin_slot: zSlotIndex,
  target_id: zNodeId,
  target_slot: zSlotIndex,
  type: zDataType,
  parentId: z.number().optional()
}).passthrough();
const zReroute = z.object({
  id: z.number(),
  parentId: z.number().optional(),
  pos: zVector2,
  linkIds: z.array(z.number()).nullish()
}).passthrough();
const zNodeOutput = z.object({
  name: z.string(),
  type: zDataType,
  links: z.array(z.number()).nullable().optional(),
  slot_index: zSlotIndex.optional()
}).passthrough();
const zNodeInput = z.object({
  name: zNodeInputName,
  type: zDataType,
  link: z.number().nullable().optional(),
  slot_index: zSlotIndex.optional()
}).passthrough();
const zFlags = z.object({
  collapsed: z.boolean().optional(),
  pinned: z.boolean().optional(),
  allow_interaction: z.boolean().optional(),
  horizontal: z.boolean().optional(),
  skip_repeated_outputs: z.boolean().optional()
}).passthrough();
const repoLikeIdPattern = /^[a-zA-Z0-9](?:[a-zA-Z0-9._-]*[a-zA-Z0-9])?$/;
const githubUsernamePattern = /^(?!-)(?!.*--)[a-zA-Z0-9-]+(?<!-)$/;
const gitHashPattern = /^[0-9a-f]{4,40}$/i;
const semverPattern = /^(0|[1-9]\d*)\.(0|[1-9]\d*)\.(0|[1-9]\d*)(?:-([\da-z-]+(?:\.[\da-z-]+)*))?(?:\+([\da-z-]+(?:\.[\da-z-]+)*))?$/;
const zRepoLikeId = z.string().min(1).max(100).regex(repoLikeIdPattern, {
  message: "ID can only contain ASCII letters, digits, '_', '-', and '.'"
}).refine((id4) => !/^[_\-.]|[_\-.]$/.test(id4), {
  message: "ID must not start or end with '_', '-', or '.'"
});
const zCnrId = zRepoLikeId;
const zGithubRepoName = zRepoLikeId;
const zGithubUsername = z.string().min(1).max(39).regex(githubUsernamePattern, "Invalid GitHub username/org");
const zAuxId = z.string().regex(/^[^/]+\/[^/]+$/, "Invalid format. Must be 'github-user/repo-name'").transform((id4) => id4.split("/")).refine(
  ([username, repo]) => zGithubUsername.safeParse(username).success && zGithubRepoName.safeParse(repo).success,
  "Invalid aux_id: Must be valid 'github-username/github-repo-name'"
).transform(([username, repo]) => `${username}/${repo}`);
const zSemVer = z.union([
  z.string().regex(semverPattern, "Invalid semantic version (x.y.z)"),
  z.literal("unknown")
]);
const zGitHash = z.string().regex(gitHashPattern, "Invalid Git commit hash");
const zVersion = z.union([zSemVer, zGitHash]);
const zProperties = z.object({
  ["Node name for S&R"]: z.string().optional(),
  cnr_id: zCnrId.optional(),
  aux_id: zAuxId.optional(),
  ver: zVersion.optional(),
  models: z.array(zModelFile).optional()
}).passthrough();
const zWidgetValues = z.union([z.array(z.any()), z.record(z.any())]);
const zComfyNode = z.object({
  id: zNodeId,
  type: z.string(),
  pos: zVector2,
  size: zVector2,
  flags: zFlags,
  order: z.number(),
  mode: z.number(),
  inputs: z.array(zNodeInput).optional(),
  outputs: z.array(zNodeOutput).optional(),
  properties: zProperties,
  widgets_values: zWidgetValues.optional(),
  color: z.string().optional(),
  bgcolor: z.string().optional()
}).passthrough();
const zGroup = z.object({
  title: z.string(),
  bounding: z.tuple([z.number(), z.number(), z.number(), z.number()]),
  color: z.string().optional(),
  font_size: z.number().optional(),
  locked: z.boolean().optional()
}).passthrough();
const zInfo = z.object({
  name: z.string(),
  author: z.string(),
  description: z.string(),
  version: z.string(),
  created: z.string(),
  modified: z.string(),
  software: z.string()
}).passthrough();
const zDS = z.object({
  scale: z.number(),
  offset: zVector2
}).passthrough();
const zConfig = z.object({
  links_ontop: z.boolean().optional(),
  align_to_grid: z.boolean().optional()
}).passthrough();
const zExtra = z.object({
  ds: zDS.optional(),
  info: zInfo.optional(),
  linkExtensions: z.array(zComfyLinkExtension).optional(),
  reroutes: z.array(zReroute).optional()
}).passthrough();
const zComfyWorkflow = z.object({
  id: z.string().uuid().optional(),
  revision: z.number().optional(),
  last_node_id: zNodeId,
  last_link_id: z.number(),
  nodes: z.array(zComfyNode),
  links: z.array(zComfyLink),
  floatingLinks: z.array(zComfyLinkObject).optional(),
  groups: z.array(zGroup).optional(),
  config: zConfig.optional().nullable(),
  extra: zExtra.optional().nullable(),
  version: z.number(),
  models: z.array(zModelFile).optional()
}).passthrough();
const zComfyWorkflow1 = z.object({
  id: z.string().uuid().optional(),
  revision: z.number().optional(),
  version: z.literal(1),
  config: zConfig.optional().nullable(),
  state: zGraphState,
  groups: z.array(zGroup).optional(),
  nodes: z.array(zComfyNode),
  links: z.array(zComfyLinkObject).optional(),
  floatingLinks: z.array(zComfyLinkObject).optional(),
  reroutes: z.array(zReroute).optional(),
  extra: zExtra.optional().nullable(),
  models: z.array(zModelFile).optional()
}).passthrough();
const zWorkflowVersion = z.object({
  version: z.number()
});
async function validateComfyWorkflow(data30, onError = console.warn) {
  const versionResult = zWorkflowVersion.safeParse(data30);
  let result;
  if (!versionResult.success) {
    const error22 = fromZodError(versionResult.error);
    onError(`Workflow does not contain a valid version.  Zod error:
${error22}`);
    return null;
  } else if (versionResult.data.version === 1) {
    result = await zComfyWorkflow1.safeParseAsync(data30);
  } else {
    result = await zComfyWorkflow.safeParseAsync(data30);
  }
  if (result.success) return result.data;
  const error2 = fromZodError(result.error);
  onError(`Invalid workflow against zod schema:
${error2}`);
  return null;
}
__name(validateComfyWorkflow, "validateComfyWorkflow");
const zNodeInputValue = z.union([
  // For widget values (can be any type)
  z.any(),
  // For node links [nodeId, slotIndex]
  z.tuple([zNodeId, zSlotIndex])
]);
const zNodeData = z.object({
  inputs: z.record(zNodeInputName, zNodeInputValue),
  class_type: z.string(),
  _meta: z.object({
    title: z.string()
  })
});
const zComfyApiWorkflow = z.record(zNodeId, zNodeData);
var ComfyMetadataTags = /* @__PURE__ */ ((ComfyMetadataTags2) => {
  ComfyMetadataTags2["PROMPT"] = "PROMPT";
  ComfyMetadataTags2["WORKFLOW"] = "WORKFLOW";
  return ComfyMetadataTags2;
})(ComfyMetadataTags || {});
var ASCII$1 = /* @__PURE__ */ ((ASCII2) => {
  ASCII2[ASCII2["GLTF"] = 1179937895] = "GLTF";
  ASCII2[ASCII2["JSON"] = 1313821514] = "JSON";
  return ASCII2;
})(ASCII$1 || {});
var GltfSizeBytes = /* @__PURE__ */ ((GltfSizeBytes2) => {
  GltfSizeBytes2[GltfSizeBytes2["HEADER"] = 12] = "HEADER";
  GltfSizeBytes2[GltfSizeBytes2["CHUNK_HEADER"] = 8] = "CHUNK_HEADER";
  return GltfSizeBytes2;
})(GltfSizeBytes || {});
const WEBM_SIGNATURE = [26, 69, 223, 163];
const MAX_READ_BYTES$1 = 2 * 1024 * 1024;
const EBML_ID = {
  SIMPLE_TAG: new Uint8Array([103, 200]),
  TAG_NAME: new Uint8Array([69, 163]),
  TAG_VALUE: new Uint8Array([68, 135])
};
const ASCII = {
  OPEN_BRACE: 123,
  NULL: 0,
  PRINTABLE_MIN: 32,
  PRINTABLE_MAX: 126
};
const MASK = {
  MSB: 128,
  ALL_BITS_SET: -1
};
const hasWebmSignature = /* @__PURE__ */ __name((data30) => WEBM_SIGNATURE.every((byte, index2) => data30[index2] === byte), "hasWebmSignature");
const readVint = /* @__PURE__ */ __name((data30, pos) => {
  if (pos >= data30.length) return null;
  const byte = data30[pos];
  if ((byte & MASK.MSB) === MASK.MSB) {
    return { value: byte & ~MASK.MSB, length: 1 };
  }
  const length = findFirstSetBitPosition(byte);
  if (length === 0 || pos + length > data30.length) {
    return null;
  }
  return {
    value: calculateVintValue(data30, pos, length),
    length
  };
}, "readVint");
const calculateVintValue = /* @__PURE__ */ __name((data30, pos, length) => {
  let value3 = data30[pos] & 255 >> length;
  for (let i2 = 1; i2 < length; i2++) {
    value3 = value3 << 8 | data30[pos + i2];
  }
  const allBitsSet = Math.pow(2, 7 * length) - 1;
  return value3 === allBitsSet ? MASK.ALL_BITS_SET : value3;
}, "calculateVintValue");
const findFirstSetBitPosition = /* @__PURE__ */ __name((byte) => {
  for (let mask3 = MASK.MSB, position3 = 1; mask3 !== 0; mask3 >>= 1, position3++) {
    if ((byte & mask3) !== 0) return position3;
  }
  return 0;
}, "findFirstSetBitPosition");
const matchesId = /* @__PURE__ */ __name((data30, pos, id4) => {
  if (pos + id4.length > data30.length) return false;
  for (let i2 = 0; i2 < id4.length; i2++) {
    if (data30[pos + i2] !== id4[i2]) return false;
  }
  return true;
}, "matchesId");
const findNextTag = /* @__PURE__ */ __name((data30, pos) => {
  if (!matchesId(data30, pos, EBML_ID.SIMPLE_TAG)) return null;
  const tagSize = readVint(data30, pos + 2);
  if (!tagSize || tagSize.value <= 0) return null;
  const tagEnd = pos + 2 + tagSize.length + tagSize.value;
  if (tagEnd > data30.length) return null;
  const contents = extractTagContents(data30, pos + 2 + tagSize.length, tagEnd);
  return { tagEnd, contents };
}, "findNextTag");
const extractTagContents = /* @__PURE__ */ __name((data30, start2, end) => {
  const nameInfo = findElementsInTag(data30, start2, end, EBML_ID.TAG_NAME);
  const valueInfo = findElementsInTag(data30, start2, end, EBML_ID.TAG_VALUE);
  if (!nameInfo || !valueInfo) return null;
  return {
    name: nameInfo,
    value: valueInfo
  };
}, "extractTagContents");
const findElementsInTag = /* @__PURE__ */ __name((data30, start2, end, id4) => {
  for (let pos = start2; pos < end - 1; ) {
    if (matchesId(data30, pos, id4)) {
      const size = readVint(data30, pos + 2);
      if (size && size.value > 0) {
        const elementPos = pos + 2 + size.length;
        return { pos: elementPos, len: size.value };
      }
    }
    pos++;
  }
  return null;
}, "findElementsInTag");
const processTagContents = /* @__PURE__ */ __name((data30, contents, meta) => {
  try {
    const name2 = extractEbmlTagName(data30, contents.name.pos, contents.name.len);
    if (!name2) return;
    const value3 = extractEbmlTagValue(
      data30,
      name2,
      contents.value.pos,
      contents.value.len
    );
    if (value3 !== null) {
      meta[name2.toLowerCase()] = value3;
    }
  } catch {
  }
}, "processTagContents");
const extractEbmlTagValue = /* @__PURE__ */ __name((data30, name2, pos, len) => {
  if (name2 === ComfyMetadataTags.PROMPT || name2 === ComfyMetadataTags.WORKFLOW) {
    return readJson(data30, pos, len);
  }
  return ebmlToString(data30, pos, len);
}, "extractEbmlTagValue");
const extractEbmlTagName = /* @__PURE__ */ __name((data30, start2, length) => {
  if (length <= 0) return null;
  const textRange2 = findReadableTextRange(data30, start2, length);
  if (!textRange2) return null;
  return new TextDecoder().decode(data30.subarray(textRange2.start, textRange2.end)).trim();
}, "extractEbmlTagName");
const findReadableTextRange = /* @__PURE__ */ __name((data30, start2, length) => {
  const isPrintableAscii = /* @__PURE__ */ __name((byte) => byte >= ASCII.PRINTABLE_MIN && byte <= ASCII.PRINTABLE_MAX, "isPrintableAscii");
  let textStart = start2;
  while (textStart < start2 + length && !isPrintableAscii(data30[textStart])) {
    textStart++;
  }
  if (textStart >= start2 + length) return null;
  let textEnd = textStart;
  while (textEnd < start2 + length && data30[textEnd] !== ASCII.NULL) {
    textEnd++;
  }
  return { start: textStart, end: textEnd };
}, "findReadableTextRange");
const readJson = /* @__PURE__ */ __name((data30, start2, length) => {
  if (length <= 0) return null;
  const nullTerminatorPos = findNullTerminator(data30, start2, length);
  const jsonStartPos = findJsonStart(data30, start2, nullTerminatorPos - start2);
  if (jsonStartPos === null) return null;
  const jsonText = decodeJsonText(data30, jsonStartPos, nullTerminatorPos);
  return parseJsonText(jsonText);
}, "readJson");
const decodeJsonText = /* @__PURE__ */ __name((data30, start2, end) => {
  return new TextDecoder().decode(data30.subarray(start2, end));
}, "decodeJsonText");
const parseJsonText = /* @__PURE__ */ __name((jsonText) => {
  const jsonEndPos = findJsonEnd(jsonText);
  if (jsonEndPos === null) return null;
  try {
    return JSON.parse(jsonText.substring(0, jsonEndPos));
  } catch {
    return null;
  }
}, "parseJsonText");
const findNullTerminator = /* @__PURE__ */ __name((data30, start2, maxLength) => {
  const end = Math.min(start2 + maxLength, data30.length);
  for (let pos = start2; pos < end; pos++) {
    if (data30[pos] === ASCII.NULL) return pos;
  }
  return end;
}, "findNullTerminator");
const findJsonStart = /* @__PURE__ */ __name((data30, start2, length) => {
  for (let pos = start2; pos < start2 + length; pos++) {
    if (data30[pos] === ASCII.OPEN_BRACE) return pos;
  }
  return null;
}, "findJsonStart");
const findJsonEnd = /* @__PURE__ */ __name((text2) => {
  let braceCount = 1;
  let pos = 1;
  while (braceCount > 0 && pos < text2.length) {
    if (text2[pos] === "{") braceCount++;
    if (text2[pos] === "}") braceCount--;
    pos++;
  }
  return braceCount === 0 ? pos : null;
}, "findJsonEnd");
const ebmlToString = /* @__PURE__ */ __name((data30, start2, length) => {
  if (length <= 0) return "";
  const endPos = findNullTerminator(data30, start2, length);
  return new TextDecoder().decode(data30.subarray(start2, endPos)).trim();
}, "ebmlToString");
const parseMetadata = /* @__PURE__ */ __name((data30) => {
  const meta = {};
  for (let pos = 0; pos < data30.length - 2; ) {
    const tagInfo = findNextTag(data30, pos);
    if (!tagInfo) {
      pos++;
      continue;
    }
    const { tagEnd, contents } = tagInfo;
    if (contents) {
      processTagContents(data30, contents, meta);
    }
    pos = tagEnd;
  }
  return meta;
}, "parseMetadata");
const handleFileLoad = /* @__PURE__ */ __name((event, resolve2) => {
  if (!event.target?.result) {
    resolve2({});
    return;
  }
  try {
    const data30 = new Uint8Array(event.target.result);
    if (data30.length < 4 || !hasWebmSignature(data30)) {
      resolve2({});
      return;
    }
    resolve2(parseMetadata(data30));
  } catch {
    resolve2({});
  }
}, "handleFileLoad");
function getFromWebmFile(file) {
  return new Promise((resolve2) => {
    const reader = new FileReader();
    reader.onload = (event) => handleFileLoad(event, resolve2);
    reader.onerror = () => resolve2({});
    reader.readAsArrayBuffer(file.slice(0, MAX_READ_BYTES$1));
  });
}
__name(getFromWebmFile, "getFromWebmFile");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.ebml = window.comfyAPI.ebml || {};
window.comfyAPI.ebml.getFromWebmFile = getFromWebmFile;
const MAX_READ_BYTES = 1 << 20;
const isJsonChunk = /* @__PURE__ */ __name((chunk) => !!chunk && chunk.chunkTypeIdentifier === ASCII$1.JSON, "isJsonChunk");
const isValidChunkRange = /* @__PURE__ */ __name((start2, length, bufferSize) => start2 + length <= bufferSize, "isValidChunkRange");
const byteArrayToString = /* @__PURE__ */ __name((bytes) => new TextDecoder().decode(bytes), "byteArrayToString");
const parseGltfBinaryHeader = /* @__PURE__ */ __name((dataView) => {
  if (dataView.byteLength < GltfSizeBytes.HEADER) return null;
  const magicNumber = dataView.getUint32(0, true);
  if (magicNumber !== ASCII$1.GLTF) return null;
  return {
    magicNumber,
    gltfFormatVersion: dataView.getUint32(4, true),
    totalLengthBytes: dataView.getUint32(8, true)
  };
}, "parseGltfBinaryHeader");
const parseChunkHeaderAtOffset = /* @__PURE__ */ __name((dataView, offset) => {
  if (offset + GltfSizeBytes.CHUNK_HEADER > dataView.byteLength) return null;
  return {
    chunkLengthBytes: dataView.getUint32(offset, true),
    chunkTypeIdentifier: dataView.getUint32(offset + 4, true)
  };
}, "parseChunkHeaderAtOffset");
const extractJsonChunk = /* @__PURE__ */ __name((buffer2) => {
  const dataView = new DataView(buffer2);
  const header3 = parseGltfBinaryHeader(dataView);
  if (!header3) return null;
  const chunkOffset = GltfSizeBytes.HEADER;
  const firstChunk = parseChunkHeaderAtOffset(dataView, chunkOffset);
  if (!firstChunk || !isJsonChunk(firstChunk)) return null;
  const jsonStart = chunkOffset + GltfSizeBytes.CHUNK_HEADER;
  const isValid2 = isValidChunkRange(
    jsonStart,
    firstChunk.chunkLengthBytes,
    dataView.byteLength
  );
  if (!isValid2) return null;
  return { start: jsonStart, length: firstChunk.chunkLengthBytes };
}, "extractJsonChunk");
const extractJsonChunkData = /* @__PURE__ */ __name((buffer2) => {
  const chunkLocation = extractJsonChunk(buffer2);
  if (!chunkLocation) return null;
  return new Uint8Array(buffer2, chunkLocation.start, chunkLocation.length);
}, "extractJsonChunkData");
const parseJson = /* @__PURE__ */ __name((text2) => {
  try {
    return JSON.parse(text2);
  } catch {
    return null;
  }
}, "parseJson");
const parseJsonBytes = /* @__PURE__ */ __name((bytes) => {
  const jsonString = byteArrayToString(bytes);
  return parseJson(jsonString);
}, "parseJsonBytes");
const parseMetadataValue = /* @__PURE__ */ __name((value3) => {
  if (typeof value3 !== "string")
    return value3;
  const parsed = parseJson(value3);
  if (!parsed) return void 0;
  return parsed;
}, "parseMetadataValue");
const extractComfyMetadata = /* @__PURE__ */ __name((jsonData) => {
  const metadata = {};
  if (!jsonData?.asset?.extras) return metadata;
  const { extras } = jsonData.asset;
  if (extras.workflow) {
    const parsedValue = parseMetadataValue(extras.workflow);
    if (parsedValue) {
      metadata[ComfyMetadataTags.WORKFLOW.toLowerCase()] = parsedValue;
    }
  }
  if (extras.prompt) {
    const parsedValue = parseMetadataValue(extras.prompt);
    if (parsedValue) {
      metadata[ComfyMetadataTags.PROMPT.toLowerCase()] = parsedValue;
    }
  }
  return metadata;
}, "extractComfyMetadata");
const processGltfFileBuffer = /* @__PURE__ */ __name((buffer2) => {
  const jsonChunk = extractJsonChunkData(buffer2);
  if (!jsonChunk) return {};
  const parsedJson = parseJsonBytes(jsonChunk);
  if (!parsedJson) return {};
  return extractComfyMetadata(parsedJson);
}, "processGltfFileBuffer");
function getGltfBinaryMetadata(file) {
  return new Promise((resolve2) => {
    if (!file) return Promise.resolve({});
    const bytesToRead = Math.min(file.size, MAX_READ_BYTES);
    const reader = new FileReader();
    reader.onload = (event) => {
      try {
        if (!event.target?.result) {
          resolve2({});
          return;
        }
        resolve2(processGltfFileBuffer(event.target.result));
      } catch {
        resolve2({});
      }
    };
    reader.onerror = () => resolve2({});
    reader.readAsArrayBuffer(file.slice(0, bytesToRead));
  });
}
__name(getGltfBinaryMetadata, "getGltfBinaryMetadata");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.gltf = window.comfyAPI.gltf || {};
window.comfyAPI.gltf.getGltfBinaryMetadata = getGltfBinaryMetadata;
var theme$A = /* @__PURE__ */ __name(function theme10(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-message {\n    border-radius: ".concat(dt2("message.border.radius"), ";\n    outline-width: ").concat(dt2("message.border.width"), ";\n    outline-style: solid;\n}\n\n.p-message-content {\n    display: flex;\n    align-items: center;\n    padding: ").concat(dt2("message.content.padding"), ";\n    gap: ").concat(dt2("message.content.gap"), ";\n    height: 100%;\n}\n\n.p-message-icon {\n    flex-shrink: 0;\n}\n\n.p-message-close-button {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    flex-shrink: 0;\n    margin-inline-start: auto;\n    overflow: hidden;\n    position: relative;\n    width: ").concat(dt2("message.close.button.width"), ";\n    height: ").concat(dt2("message.close.button.height"), ";\n    border-radius: ").concat(dt2("message.close.button.border.radius"), ";\n    background: transparent;\n    transition: background ").concat(dt2("message.transition.duration"), ", color ").concat(dt2("message.transition.duration"), ", outline-color ").concat(dt2("message.transition.duration"), ", box-shadow ").concat(dt2("message.transition.duration"), ", opacity 0.3s;\n    outline-color: transparent;\n    color: inherit;\n    padding: 0;\n    border: none;\n    cursor: pointer;\n    user-select: none;\n}\n\n.p-message-close-icon {\n    font-size: ").concat(dt2("message.close.icon.size"), ";\n    width: ").concat(dt2("message.close.icon.size"), ";\n    height: ").concat(dt2("message.close.icon.size"), ";\n}\n\n.p-message-close-button:focus-visible {\n    outline-width: ").concat(dt2("message.close.button.focus.ring.width"), ";\n    outline-style: ").concat(dt2("message.close.button.focus.ring.style"), ";\n    outline-offset: ").concat(dt2("message.close.button.focus.ring.offset"), ";\n}\n\n.p-message-info {\n    background: ").concat(dt2("message.info.background"), ";\n    outline-color: ").concat(dt2("message.info.border.color"), ";\n    color: ").concat(dt2("message.info.color"), ";\n    box-shadow: ").concat(dt2("message.info.shadow"), ";\n}\n\n.p-message-info .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.info.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.info.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-info .p-message-close-button:hover {\n    background: ").concat(dt2("message.info.close.button.hover.background"), ";\n}\n\n.p-message-info.p-message-outlined {\n    color: ").concat(dt2("message.info.outlined.color"), ";\n    outline-color: ").concat(dt2("message.info.outlined.border.color"), ";\n}\n\n.p-message-info.p-message-simple {\n    color: ").concat(dt2("message.info.simple.color"), ";\n}\n\n.p-message-success {\n    background: ").concat(dt2("message.success.background"), ";\n    outline-color: ").concat(dt2("message.success.border.color"), ";\n    color: ").concat(dt2("message.success.color"), ";\n    box-shadow: ").concat(dt2("message.success.shadow"), ";\n}\n\n.p-message-success .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.success.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.success.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-success .p-message-close-button:hover {\n    background: ").concat(dt2("message.success.close.button.hover.background"), ";\n}\n\n.p-message-success.p-message-outlined {\n    color: ").concat(dt2("message.success.outlined.color"), ";\n    outline-color: ").concat(dt2("message.success.outlined.border.color"), ";\n}\n\n.p-message-success.p-message-simple {\n    color: ").concat(dt2("message.success.simple.color"), ";\n}\n\n.p-message-warn {\n    background: ").concat(dt2("message.warn.background"), ";\n    outline-color: ").concat(dt2("message.warn.border.color"), ";\n    color: ").concat(dt2("message.warn.color"), ";\n    box-shadow: ").concat(dt2("message.warn.shadow"), ";\n}\n\n.p-message-warn .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.warn.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.warn.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-warn .p-message-close-button:hover {\n    background: ").concat(dt2("message.warn.close.button.hover.background"), ";\n}\n\n.p-message-warn.p-message-outlined {\n    color: ").concat(dt2("message.warn.outlined.color"), ";\n    outline-color: ").concat(dt2("message.warn.outlined.border.color"), ";\n}\n\n.p-message-warn.p-message-simple {\n    color: ").concat(dt2("message.warn.simple.color"), ";\n}\n\n.p-message-error {\n    background: ").concat(dt2("message.error.background"), ";\n    outline-color: ").concat(dt2("message.error.border.color"), ";\n    color: ").concat(dt2("message.error.color"), ";\n    box-shadow: ").concat(dt2("message.error.shadow"), ";\n}\n\n.p-message-error .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.error.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.error.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-error .p-message-close-button:hover {\n    background: ").concat(dt2("message.error.close.button.hover.background"), ";\n}\n\n.p-message-error.p-message-outlined {\n    color: ").concat(dt2("message.error.outlined.color"), ";\n    outline-color: ").concat(dt2("message.error.outlined.border.color"), ";\n}\n\n.p-message-error.p-message-simple {\n    color: ").concat(dt2("message.error.simple.color"), ";\n}\n\n.p-message-secondary {\n    background: ").concat(dt2("message.secondary.background"), ";\n    outline-color: ").concat(dt2("message.secondary.border.color"), ";\n    color: ").concat(dt2("message.secondary.color"), ";\n    box-shadow: ").concat(dt2("message.secondary.shadow"), ";\n}\n\n.p-message-secondary .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.secondary.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.secondary.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-secondary .p-message-close-button:hover {\n    background: ").concat(dt2("message.secondary.close.button.hover.background"), ";\n}\n\n.p-message-secondary.p-message-outlined {\n    color: ").concat(dt2("message.secondary.outlined.color"), ";\n    outline-color: ").concat(dt2("message.secondary.outlined.border.color"), ";\n}\n\n.p-message-secondary.p-message-simple {\n    color: ").concat(dt2("message.secondary.simple.color"), ";\n}\n\n.p-message-contrast {\n    background: ").concat(dt2("message.contrast.background"), ";\n    outline-color: ").concat(dt2("message.contrast.border.color"), ";\n    color: ").concat(dt2("message.contrast.color"), ";\n    box-shadow: ").concat(dt2("message.contrast.shadow"), ";\n}\n\n.p-message-contrast .p-message-close-button:focus-visible {\n    outline-color: ").concat(dt2("message.contrast.close.button.focus.ring.color"), ";\n    box-shadow: ").concat(dt2("message.contrast.close.button.focus.ring.shadow"), ";\n}\n\n.p-message-contrast .p-message-close-button:hover {\n    background: ").concat(dt2("message.contrast.close.button.hover.background"), ";\n}\n\n.p-message-contrast.p-message-outlined {\n    color: ").concat(dt2("message.contrast.outlined.color"), ";\n    outline-color: ").concat(dt2("message.contrast.outlined.border.color"), ";\n}\n\n.p-message-contrast.p-message-simple {\n    color: ").concat(dt2("message.contrast.simple.color"), ";\n}\n\n.p-message-text {\n    font-size: ").concat(dt2("message.text.font.size"), ";\n    font-weight: ").concat(dt2("message.text.font.weight"), ";\n}\n\n.p-message-icon {\n    font-size: ").concat(dt2("message.icon.size"), ";\n    width: ").concat(dt2("message.icon.size"), ";\n    height: ").concat(dt2("message.icon.size"), ";\n}\n\n.p-message-enter-from {\n    opacity: 0;\n}\n\n.p-message-enter-active {\n    transition: opacity 0.3s;\n}\n\n.p-message.p-message-leave-from {\n    max-height: 1000px;\n}\n\n.p-message.p-message-leave-to {\n    max-height: 0;\n    opacity: 0;\n    margin: 0;\n}\n\n.p-message-leave-active {\n    overflow: hidden;\n    transition: max-height 0.45s cubic-bezier(0, 1, 0, 1), opacity 0.3s, margin 0.3s;\n}\n\n.p-message-leave-active .p-message-close-button {\n    opacity: 0;\n}\n\n.p-message-sm .p-message-content {\n    padding: ").concat(dt2("message.content.sm.padding"), ";\n}\n\n.p-message-sm .p-message-text {\n    font-size: ").concat(dt2("message.text.sm.font.size"), ";\n}\n\n.p-message-sm .p-message-icon {\n    font-size: ").concat(dt2("message.icon.sm.size"), ";\n    width: ").concat(dt2("message.icon.sm.size"), ";\n    height: ").concat(dt2("message.icon.sm.size"), ";\n}\n\n.p-message-sm .p-message-close-icon {\n    font-size: ").concat(dt2("message.close.icon.sm.size"), ";\n    width: ").concat(dt2("message.close.icon.sm.size"), ";\n    height: ").concat(dt2("message.close.icon.sm.size"), ";\n}\n\n.p-message-lg .p-message-content {\n    padding: ").concat(dt2("message.content.lg.padding"), ";\n}\n\n.p-message-lg .p-message-text {\n    font-size: ").concat(dt2("message.text.lg.font.size"), ";\n}\n\n.p-message-lg .p-message-icon {\n    font-size: ").concat(dt2("message.icon.lg.size"), ";\n    width: ").concat(dt2("message.icon.lg.size"), ";\n    height: ").concat(dt2("message.icon.lg.size"), ";\n}\n\n.p-message-lg .p-message-close-icon {\n    font-size: ").concat(dt2("message.close.icon.lg.size"), ";\n    width: ").concat(dt2("message.close.icon.lg.size"), ";\n    height: ").concat(dt2("message.close.icon.lg.size"), ";\n}\n\n.p-message-outlined {\n    background: transparent;\n    outline-width: ").concat(dt2("message.outlined.border.width"), ";\n}\n\n.p-message-simple {\n    background: transparent;\n    outline-color: transparent;\n    box-shadow: none;\n}\n\n.p-message-simple .p-message-content {\n    padding: ").concat(dt2("message.simple.content.padding"), ";\n}\n\n.p-message-outlined .p-message-close-button:hover,\n.p-message-simple .p-message-close-button:hover {\n    background: transparent;\n}\n");
}, "theme");
var classes$G = {
  root: /* @__PURE__ */ __name(function root5(_ref2) {
    var props = _ref2.props;
    return ["p-message p-component p-message-" + props.severity, {
      "p-message-outlined": props.variant === "outlined",
      "p-message-simple": props.variant === "simple",
      "p-message-sm": props.size === "small",
      "p-message-lg": props.size === "large"
    }];
  }, "root"),
  content: "p-message-content",
  icon: "p-message-icon",
  text: "p-message-text",
  closeButton: "p-message-close-button",
  closeIcon: "p-message-close-icon"
};
var MessageStyle = BaseStyle$1.extend({
  name: "message",
  theme: theme$A,
  classes: classes$G
});
var script$1$G = {
  name: "BaseMessage",
  "extends": script$1b,
  props: {
    severity: {
      type: String,
      "default": "info"
    },
    closable: {
      type: Boolean,
      "default": false
    },
    life: {
      type: Number,
      "default": null
    },
    icon: {
      type: String,
      "default": void 0
    },
    closeIcon: {
      type: String,
      "default": void 0
    },
    closeButtonProps: {
      type: null,
      "default": null
    },
    size: {
      type: String,
      "default": null
    },
    variant: {
      type: String,
      "default": null
    }
  },
  style: MessageStyle,
  provide: /* @__PURE__ */ __name(function provide9() {
    return {
      $pcMessage: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$Z = {
  name: "Message",
  "extends": script$1$G,
  inheritAttrs: false,
  emits: ["close", "life-end"],
  timeout: null,
  data: /* @__PURE__ */ __name(function data5() {
    return {
      visible: true
    };
  }, "data"),
  mounted: /* @__PURE__ */ __name(function mounted6() {
    var _this = this;
    if (this.life) {
      setTimeout(function() {
        _this.visible = false;
        _this.$emit("life-end");
      }, this.life);
    }
  }, "mounted"),
  methods: {
    close: /* @__PURE__ */ __name(function close3(event) {
      this.visible = false;
      this.$emit("close", event);
    }, "close")
  },
  computed: {
    closeAriaLabel: /* @__PURE__ */ __name(function closeAriaLabel2() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.close : void 0;
    }, "closeAriaLabel")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    TimesIcon: script$15
  }
};
function _typeof$i(o2) {
  "@babel/helpers - typeof";
  return _typeof$i = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$i(o2);
}
__name(_typeof$i, "_typeof$i");
function ownKeys$k(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$k, "ownKeys$k");
function _objectSpread$k(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$k(Object(t2), true).forEach(function(r3) {
      _defineProperty$k(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$k(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$k, "_objectSpread$k");
function _defineProperty$k(e2, r2, t2) {
  return (r2 = _toPropertyKey$h(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$k, "_defineProperty$k");
function _toPropertyKey$h(t2) {
  var i2 = _toPrimitive$h(t2, "string");
  return "symbol" == _typeof$i(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$h, "_toPropertyKey$h");
function _toPrimitive$h(t2, r2) {
  if ("object" != _typeof$i(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$i(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$h, "_toPrimitive$h");
var _hoisted_1$1L = ["aria-label"];
function render$W(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_TimesIcon = resolveComponent("TimesIcon");
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createBlock(Transition, mergeProps$2({
    name: "p-message",
    appear: ""
  }, _ctx.ptmi("transition")), {
    "default": withCtx(function() {
      return [withDirectives(createBaseVNode("div", mergeProps$2({
        "class": _ctx.cx("root"),
        role: "alert",
        "aria-live": "assertive",
        "aria-atomic": "true"
      }, _ctx.ptm("root")), [_ctx.$slots.container ? renderSlot(_ctx.$slots, "container", {
        key: 0,
        closeCallback: $options.close
      }) : (openBlock(), createElementBlock("div", mergeProps$2({
        key: 1,
        "class": _ctx.cx("content")
      }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "icon", {
        "class": normalizeClass(_ctx.cx("icon"))
      }, function() {
        return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.icon ? "span" : null), mergeProps$2({
          "class": [_ctx.cx("icon"), _ctx.icon]
        }, _ctx.ptm("icon")), null, 16, ["class"]))];
      }), _ctx.$slots["default"] ? (openBlock(), createElementBlock("div", mergeProps$2({
        key: 0,
        "class": _ctx.cx("text")
      }, _ctx.ptm("text")), [renderSlot(_ctx.$slots, "default")], 16)) : createCommentVNode("", true), _ctx.closable ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
        key: 1,
        "class": _ctx.cx("closeButton"),
        "aria-label": $options.closeAriaLabel,
        type: "button",
        onClick: _cache[0] || (_cache[0] = function($event) {
          return $options.close($event);
        })
      }, _objectSpread$k(_objectSpread$k({}, _ctx.closeButtonProps), _ctx.ptm("closeButton"))), [renderSlot(_ctx.$slots, "closeicon", {}, function() {
        return [_ctx.closeIcon ? (openBlock(), createElementBlock("i", mergeProps$2({
          key: 0,
          "class": [_ctx.cx("closeIcon"), _ctx.closeIcon]
        }, _ctx.ptm("closeIcon")), null, 16)) : (openBlock(), createBlock(_component_TimesIcon, mergeProps$2({
          key: 1,
          "class": [_ctx.cx("closeIcon"), _ctx.closeIcon]
        }, _ctx.ptm("closeIcon")), null, 16, ["class"]))];
      })], 16, _hoisted_1$1L)), [[_directive_ripple]]) : createCommentVNode("", true)], 16))], 16), [[vShow, $data.visible]])];
    }),
    _: 3
  }, 16);
}
__name(render$W, "render$W");
script$Z.render = render$W;
const _hoisted_1$1K = { class: "prompt-dialog-content flex flex-col gap-6 m-2 mt-4" };
const _hoisted_2$1f = {
  key: 0,
  class: "pl-4 m-0 flex flex-col gap-2"
};
const _hoisted_3$S = { class: "flex gap-4 justify-end" };
const _sfc_main$1E = /* @__PURE__ */ defineComponent({
  __name: "ConfirmationDialogContent",
  props: {
    message: {},
    type: {},
    onConfirm: { type: Function },
    itemList: {},
    hint: {}
  },
  setup(__props) {
    const props = __props;
    const onCancel = /* @__PURE__ */ __name(() => useDialogStore().closeDialog(), "onCancel");
    const onDeny = /* @__PURE__ */ __name(() => {
      props.onConfirm(false);
      useDialogStore().closeDialog();
    }, "onDeny");
    const onConfirm = /* @__PURE__ */ __name(() => {
      props.onConfirm(true);
      useDialogStore().closeDialog();
    }, "onConfirm");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("section", _hoisted_1$1K, [
        createBaseVNode("span", null, toDisplayString$1(_ctx.message), 1),
        _ctx.itemList?.length ? (openBlock(), createElementBlock("ul", _hoisted_2$1f, [
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.itemList, (item3) => {
            return openBlock(), createElementBlock("li", { key: item3 }, toDisplayString$1(item3), 1);
          }), 128))
        ])) : createCommentVNode("", true),
        _ctx.hint ? (openBlock(), createBlock(unref(script$Z), {
          key: 1,
          icon: "pi pi-info-circle",
          severity: "secondary",
          size: "small",
          variant: "simple"
        }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString$1(_ctx.hint), 1)
          ]),
          _: 1
        })) : createCommentVNode("", true),
        createBaseVNode("div", _hoisted_3$S, [
          createVNode(unref(script$10), {
            label: _ctx.$t("g.cancel"),
            icon: "pi pi-undo",
            severity: "secondary",
            onClick: onCancel,
            autofocus: ""
          }, null, 8, ["label"]),
          _ctx.type === "default" ? (openBlock(), createBlock(unref(script$10), {
            key: 0,
            label: _ctx.$t("g.confirm"),
            severity: "primary",
            onClick: onConfirm,
            icon: "pi pi-check"
          }, null, 8, ["label"])) : _ctx.type === "delete" ? (openBlock(), createBlock(unref(script$10), {
            key: 1,
            label: _ctx.$t("g.delete"),
            severity: "danger",
            onClick: onConfirm,
            icon: "pi pi-trash"
          }, null, 8, ["label"])) : _ctx.type === "overwrite" ? (openBlock(), createBlock(unref(script$10), {
            key: 2,
            label: _ctx.$t("g.overwrite"),
            severity: "warn",
            onClick: onConfirm,
            icon: "pi pi-save"
          }, null, 8, ["label"])) : _ctx.type === "dirtyClose" ? (openBlock(), createElementBlock(Fragment$1, { key: 3 }, [
            createVNode(unref(script$10), {
              label: _ctx.$t("g.no"),
              severity: "secondary",
              onClick: onDeny,
              icon: "pi pi-times"
            }, null, 8, ["label"]),
            createVNode(unref(script$10), {
              label: _ctx.$t("g.save"),
              onClick: onConfirm,
              icon: "pi pi-save"
            }, null, 8, ["label"])
          ], 64)) : _ctx.type === "reinstall" ? (openBlock(), createBlock(unref(script$10), {
            key: 4,
            label: _ctx.$t("desktopMenu.reinstall"),
            severity: "warn",
            onClick: onConfirm,
            icon: "pi pi-eraser"
          }, null, 8, ["label"])) : (openBlock(), createBlock(unref(script$10), {
            key: 5,
            label: _ctx.$t("g.close"),
            severity: "primary",
            onClick: onCancel,
            icon: "pi pi-times"
          }, null, 8, ["label"]))
        ])
      ]);
    };
  }
});
const ConfirmationDialogContent = /* @__PURE__ */ _export_sfc(_sfc_main$1E, [["__scopeId", "data-v-4f1e3bbe"]]);
var theme$z = /* @__PURE__ */ __name(function theme11(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-divider-horizontal {\n    display: flex;\n    width: 100%;\n    position: relative;\n    align-items: center;\n    margin: ".concat(dt2("divider.horizontal.margin"), ";\n    padding: ").concat(dt2("divider.horizontal.padding"), ';\n}\n\n.p-divider-horizontal:before {\n    position: absolute;\n    display: block;\n    inset-block-start: 50%;\n    inset-inline-start: 0;\n    width: 100%;\n    content: "";\n    border-block-start: 1px solid ').concat(dt2("divider.border.color"), ";\n}\n\n.p-divider-horizontal .p-divider-content {\n    padding: ").concat(dt2("divider.horizontal.content.padding"), ";\n}\n\n.p-divider-vertical {\n    min-height: 100%;\n    display: flex;\n    position: relative;\n    justify-content: center;\n    margin: ").concat(dt2("divider.vertical.margin"), ";\n    padding: ").concat(dt2("divider.vertical.padding"), ';\n}\n\n.p-divider-vertical:before {\n    position: absolute;\n    display: block;\n    inset-block-start: 0;\n    inset-inline-start: 50%;\n    height: 100%;\n    content: "";\n    border-inline-start: 1px solid ').concat(dt2("divider.border.color"), ";\n}\n\n.p-divider.p-divider-vertical .p-divider-content {\n    padding: ").concat(dt2("divider.vertical.content.padding"), ";\n}\n\n.p-divider-content {\n    z-index: 1;\n    background: ").concat(dt2("divider.content.background"), ";\n    color: ").concat(dt2("divider.content.color"), ";\n}\n\n.p-divider-solid.p-divider-horizontal:before {\n    border-block-start-style: solid;\n}\n\n.p-divider-solid.p-divider-vertical:before {\n    border-inline-start-style: solid;\n}\n\n.p-divider-dashed.p-divider-horizontal:before {\n    border-block-start-style: dashed;\n}\n\n.p-divider-dashed.p-divider-vertical:before {\n    border-inline-start-style: dashed;\n}\n\n.p-divider-dotted.p-divider-horizontal:before {\n    border-block-start-style: dotted;\n}\n\n.p-divider-dotted.p-divider-vertical:before {\n    border-inline-start-style: dotted;\n}\n\n.p-divider-left:dir(rtl),\n.p-divider-right:dir(rtl) {\n    flex-direction: row-reverse;\n}\n");
}, "theme");
var inlineStyles$6 = {
  root: /* @__PURE__ */ __name(function root6(_ref2) {
    var props = _ref2.props;
    return {
      justifyContent: props.layout === "horizontal" ? props.align === "center" || props.align === null ? "center" : props.align === "left" ? "flex-start" : props.align === "right" ? "flex-end" : null : null,
      alignItems: props.layout === "vertical" ? props.align === "center" || props.align === null ? "center" : props.align === "top" ? "flex-start" : props.align === "bottom" ? "flex-end" : null : null
    };
  }, "root")
};
var classes$F = {
  root: /* @__PURE__ */ __name(function root7(_ref3) {
    var props = _ref3.props;
    return ["p-divider p-component", "p-divider-" + props.layout, "p-divider-" + props.type, {
      "p-divider-left": props.layout === "horizontal" && (!props.align || props.align === "left")
    }, {
      "p-divider-center": props.layout === "horizontal" && props.align === "center"
    }, {
      "p-divider-right": props.layout === "horizontal" && props.align === "right"
    }, {
      "p-divider-top": props.layout === "vertical" && props.align === "top"
    }, {
      "p-divider-center": props.layout === "vertical" && (!props.align || props.align === "center")
    }, {
      "p-divider-bottom": props.layout === "vertical" && props.align === "bottom"
    }];
  }, "root"),
  content: "p-divider-content"
};
var DividerStyle = BaseStyle$1.extend({
  name: "divider",
  theme: theme$z,
  classes: classes$F,
  inlineStyles: inlineStyles$6
});
var script$1$F = {
  name: "BaseDivider",
  "extends": script$1b,
  props: {
    align: {
      type: String,
      "default": null
    },
    layout: {
      type: String,
      "default": "horizontal"
    },
    type: {
      type: String,
      "default": "solid"
    }
  },
  style: DividerStyle,
  provide: /* @__PURE__ */ __name(function provide10() {
    return {
      $pcDivider: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$Y = {
  name: "Divider",
  "extends": script$1$F,
  inheritAttrs: false
};
var _hoisted_1$1J = ["aria-orientation"];
function render$V(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    style: _ctx.sx("root"),
    role: "separator",
    "aria-orientation": _ctx.layout
  }, _ctx.ptmi("root")), [_ctx.$slots["default"] ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("content")
  }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "default")], 16)) : createCommentVNode("", true)], 16, _hoisted_1$1J);
}
__name(render$V, "render$V");
script$Y.render = render$V;
var theme$y = /* @__PURE__ */ __name(function theme12(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-scrollpanel-content-container {\n    overflow: hidden;\n    width: 100%;\n    height: 100%;\n    position: relative;\n    z-index: 1;\n    float: left;\n}\n\n.p-scrollpanel-content {\n    height: calc(100% + calc(2 * ".concat(dt2("scrollpanel.bar.size"), "));\n    width: calc(100% + calc(2 * ").concat(dt2("scrollpanel.bar.size"), "));\n    padding-inline: 0 calc(2 * ").concat(dt2("scrollpanel.bar.size"), ");\n    padding-block: 0 calc(2 * ").concat(dt2("scrollpanel.bar.size"), ");\n    position: relative;\n    overflow: auto;\n    box-sizing: border-box;\n    scrollbar-width: none;\n}\n\n.p-scrollpanel-content::-webkit-scrollbar {\n    display: none;\n}\n\n.p-scrollpanel-bar {\n    position: relative;\n    border-radius: ").concat(dt2("scrollpanel.bar.border.radius"), ";\n    z-index: 2;\n    cursor: pointer;\n    opacity: 0;\n    outline-color: transparent;\n    background: ").concat(dt2("scrollpanel.bar.background"), ";\n    border: 0 none;\n    transition: outline-color ").concat(dt2("scrollpanel.transition.duration"), ", opacity ").concat(dt2("scrollpanel.transition.duration"), ";\n}\n\n.p-scrollpanel-bar:focus-visible {\n    box-shadow: ").concat(dt2("scrollpanel.bar.focus.ring.shadow"), ";\n    outline: ").concat(dt2("scrollpanel.barfocus.ring.width"), " ").concat(dt2("scrollpanel.bar.focus.ring.style"), " ").concat(dt2("scrollpanel.bar.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("scrollpanel.barfocus.ring.offset"), ";\n}\n\n.p-scrollpanel-bar-y {\n    width: ").concat(dt2("scrollpanel.bar.size"), ";\n    inset-block-start: 0;\n}\n\n.p-scrollpanel-bar-x {\n    height: ").concat(dt2("scrollpanel.bar.size"), ";\n    inset-block-end: 0;\n}\n\n.p-scrollpanel-hidden {\n    visibility: hidden;\n}\n\n.p-scrollpanel:hover .p-scrollpanel-bar,\n.p-scrollpanel:active .p-scrollpanel-bar {\n    opacity: 1;\n}\n\n.p-scrollpanel-grabbed {\n    user-select: none;\n}\n");
}, "theme");
var classes$E = {
  root: "p-scrollpanel p-component",
  contentContainer: "p-scrollpanel-content-container",
  content: "p-scrollpanel-content",
  barX: "p-scrollpanel-bar p-scrollpanel-bar-x",
  barY: "p-scrollpanel-bar p-scrollpanel-bar-y"
};
var ScrollPanelStyle = BaseStyle$1.extend({
  name: "scrollpanel",
  theme: theme$y,
  classes: classes$E
});
var script$1$E = {
  name: "BaseScrollPanel",
  "extends": script$1b,
  props: {
    step: {
      type: Number,
      "default": 5
    }
  },
  style: ScrollPanelStyle,
  provide: /* @__PURE__ */ __name(function provide11() {
    return {
      $pcScrollPanel: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$X = {
  name: "ScrollPanel",
  "extends": script$1$E,
  inheritAttrs: false,
  initialized: false,
  documentResizeListener: null,
  documentMouseMoveListener: null,
  documentMouseUpListener: null,
  frame: null,
  scrollXRatio: null,
  scrollYRatio: null,
  isXBarClicked: false,
  isYBarClicked: false,
  lastPageX: null,
  lastPageY: null,
  timer: null,
  outsideClickListener: null,
  data: /* @__PURE__ */ __name(function data6() {
    return {
      id: this.$attrs.id,
      orientation: "vertical",
      lastScrollTop: 0,
      lastScrollLeft: 0
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId2(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId")
  },
  mounted: /* @__PURE__ */ __name(function mounted7() {
    this.id = this.id || UniqueComponentId();
    if (this.$el.offsetParent) {
      this.initialize();
    }
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated5() {
    if (!this.initialized && this.$el.offsetParent) {
      this.initialize();
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount3() {
    this.unbindDocumentResizeListener();
    if (this.frame) {
      window.cancelAnimationFrame(this.frame);
    }
  }, "beforeUnmount"),
  methods: {
    initialize: /* @__PURE__ */ __name(function initialize() {
      this.moveBar();
      this.bindDocumentResizeListener();
      this.calculateContainerHeight();
    }, "initialize"),
    calculateContainerHeight: /* @__PURE__ */ __name(function calculateContainerHeight() {
      var containerStyles = getComputedStyle(this.$el), xBarStyles = getComputedStyle(this.$refs.xBar), pureContainerHeight = getHeight$1(this.$el) - parseInt(xBarStyles["height"], 10);
      if (containerStyles["max-height"] !== "none" && pureContainerHeight === 0) {
        if (this.$refs.content.offsetHeight + parseInt(xBarStyles["height"], 10) > parseInt(containerStyles["max-height"], 10)) {
          this.$el.style.height = containerStyles["max-height"];
        } else {
          this.$el.style.height = this.$refs.content.offsetHeight + parseFloat(containerStyles.paddingTop) + parseFloat(containerStyles.paddingBottom) + parseFloat(containerStyles.borderTopWidth) + parseFloat(containerStyles.borderBottomWidth) + "px";
        }
      }
    }, "calculateContainerHeight"),
    moveBar: /* @__PURE__ */ __name(function moveBar() {
      var _this = this;
      if (this.$refs.content) {
        var totalWidth = this.$refs.content.scrollWidth;
        var ownWidth = this.$refs.content.clientWidth;
        var bottom = (this.$el.clientHeight - this.$refs.xBar.clientHeight) * -1;
        this.scrollXRatio = ownWidth / totalWidth;
        var totalHeight = this.$refs.content.scrollHeight;
        var ownHeight = this.$refs.content.clientHeight;
        var right = (this.$el.clientWidth - this.$refs.yBar.clientWidth) * -1;
        this.scrollYRatio = ownHeight / totalHeight;
        this.frame = this.requestAnimationFrame(function() {
          if (_this.$refs.xBar) {
            if (_this.scrollXRatio >= 1) {
              _this.$refs.xBar.setAttribute("data-p-scrollpanel-hidden", "true");
              !_this.isUnstyled && addClass$1(_this.$refs.xBar, "p-scrollpanel-hidden");
            } else {
              _this.$refs.xBar.setAttribute("data-p-scrollpanel-hidden", "false");
              !_this.isUnstyled && removeClass$1(_this.$refs.xBar, "p-scrollpanel-hidden");
              _this.$refs.xBar.style.cssText = "width:" + Math.max(_this.scrollXRatio * 100, 10) + "%; inset-inline-start:" + Math.abs(_this.$refs.content.scrollLeft) / totalWidth * 100 + "%;bottom:" + bottom + "px;";
            }
          }
          if (_this.$refs.yBar) {
            if (_this.scrollYRatio >= 1) {
              _this.$refs.yBar.setAttribute("data-p-scrollpanel-hidden", "true");
              !_this.isUnstyled && addClass$1(_this.$refs.yBar, "p-scrollpanel-hidden");
            } else {
              _this.$refs.yBar.setAttribute("data-p-scrollpanel-hidden", "false");
              !_this.isUnstyled && removeClass$1(_this.$refs.yBar, "p-scrollpanel-hidden");
              _this.$refs.yBar.style.cssText = "height:" + Math.max(_this.scrollYRatio * 100, 10) + "%; top: calc(" + _this.$refs.content.scrollTop / totalHeight * 100 + "% - " + _this.$refs.xBar.clientHeight + "px); inset-inline-end:" + right + "px;";
            }
          }
        });
      }
    }, "moveBar"),
    onYBarMouseDown: /* @__PURE__ */ __name(function onYBarMouseDown(e2) {
      this.isYBarClicked = true;
      this.$refs.yBar.focus();
      this.lastPageY = e2.pageY;
      this.$refs.yBar.setAttribute("data-p-scrollpanel-grabbed", "true");
      !this.isUnstyled && addClass$1(this.$refs.yBar, "p-scrollpanel-grabbed");
      document.body.setAttribute("data-p-scrollpanel-grabbed", "true");
      !this.isUnstyled && addClass$1(document.body, "p-scrollpanel-grabbed");
      this.bindDocumentMouseListeners();
      e2.preventDefault();
    }, "onYBarMouseDown"),
    onXBarMouseDown: /* @__PURE__ */ __name(function onXBarMouseDown(e2) {
      this.isXBarClicked = true;
      this.$refs.xBar.focus();
      this.lastPageX = e2.pageX;
      this.$refs.yBar.setAttribute("data-p-scrollpanel-grabbed", "false");
      !this.isUnstyled && addClass$1(this.$refs.xBar, "p-scrollpanel-grabbed");
      document.body.setAttribute("data-p-scrollpanel-grabbed", "false");
      !this.isUnstyled && addClass$1(document.body, "p-scrollpanel-grabbed");
      this.bindDocumentMouseListeners();
      e2.preventDefault();
    }, "onXBarMouseDown"),
    onScroll: /* @__PURE__ */ __name(function onScroll(event) {
      if (this.lastScrollLeft !== event.target.scrollLeft) {
        this.lastScrollLeft = event.target.scrollLeft;
        this.orientation = "horizontal";
      } else if (this.lastScrollTop !== event.target.scrollTop) {
        this.lastScrollTop = event.target.scrollTop;
        this.orientation = "vertical";
      }
      this.moveBar();
    }, "onScroll"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown3(event) {
      if (this.orientation === "vertical") {
        switch (event.code) {
          case "ArrowDown": {
            this.setTimer("scrollTop", this.step);
            event.preventDefault();
            break;
          }
          case "ArrowUp": {
            this.setTimer("scrollTop", this.step * -1);
            event.preventDefault();
            break;
          }
          case "ArrowLeft":
          case "ArrowRight": {
            event.preventDefault();
            break;
          }
        }
      } else if (this.orientation === "horizontal") {
        switch (event.code) {
          case "ArrowRight": {
            this.setTimer("scrollLeft", this.step);
            event.preventDefault();
            break;
          }
          case "ArrowLeft": {
            this.setTimer("scrollLeft", this.step * -1);
            event.preventDefault();
            break;
          }
          case "ArrowDown":
          case "ArrowUp": {
            event.preventDefault();
            break;
          }
        }
      }
    }, "onKeyDown"),
    onKeyUp: /* @__PURE__ */ __name(function onKeyUp2() {
      this.clearTimer();
    }, "onKeyUp"),
    repeat: /* @__PURE__ */ __name(function repeat2(bar, step2) {
      this.$refs.content[bar] += step2;
      this.moveBar();
    }, "repeat"),
    setTimer: /* @__PURE__ */ __name(function setTimer(bar, step2) {
      var _this2 = this;
      this.clearTimer();
      this.timer = setTimeout(function() {
        _this2.repeat(bar, step2);
      }, 40);
    }, "setTimer"),
    clearTimer: /* @__PURE__ */ __name(function clearTimer() {
      if (this.timer) {
        clearTimeout(this.timer);
      }
    }, "clearTimer"),
    onDocumentMouseMove: /* @__PURE__ */ __name(function onDocumentMouseMove(e2) {
      if (this.isXBarClicked) {
        this.onMouseMoveForXBar(e2);
      } else if (this.isYBarClicked) {
        this.onMouseMoveForYBar(e2);
      } else {
        this.onMouseMoveForXBar(e2);
        this.onMouseMoveForYBar(e2);
      }
    }, "onDocumentMouseMove"),
    onMouseMoveForXBar: /* @__PURE__ */ __name(function onMouseMoveForXBar(e2) {
      var _this3 = this;
      var deltaX = e2.pageX - this.lastPageX;
      this.lastPageX = e2.pageX;
      this.frame = this.requestAnimationFrame(function() {
        _this3.$refs.content.scrollLeft += deltaX / _this3.scrollXRatio;
      });
    }, "onMouseMoveForXBar"),
    onMouseMoveForYBar: /* @__PURE__ */ __name(function onMouseMoveForYBar(e2) {
      var _this4 = this;
      var deltaY = e2.pageY - this.lastPageY;
      this.lastPageY = e2.pageY;
      this.frame = this.requestAnimationFrame(function() {
        _this4.$refs.content.scrollTop += deltaY / _this4.scrollYRatio;
      });
    }, "onMouseMoveForYBar"),
    onFocus: /* @__PURE__ */ __name(function onFocus2(event) {
      if (this.$refs.xBar.isSameNode(event.target)) {
        this.orientation = "horizontal";
      } else if (this.$refs.yBar.isSameNode(event.target)) {
        this.orientation = "vertical";
      }
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur2() {
      if (this.orientation === "horizontal") {
        this.orientation = "vertical";
      }
    }, "onBlur"),
    onDocumentMouseUp: /* @__PURE__ */ __name(function onDocumentMouseUp() {
      this.$refs.yBar.setAttribute("data-p-scrollpanel-grabbed", "false");
      !this.isUnstyled && removeClass$1(this.$refs.yBar, "p-scrollpanel-grabbed");
      this.$refs.xBar.setAttribute("data-p-scrollpanel-grabbed", "false");
      !this.isUnstyled && removeClass$1(this.$refs.xBar, "p-scrollpanel-grabbed");
      document.body.setAttribute("data-p-scrollpanel-grabbed", "false");
      !this.isUnstyled && removeClass$1(document.body, "p-scrollpanel-grabbed");
      this.unbindDocumentMouseListeners();
      this.isXBarClicked = false;
      this.isYBarClicked = false;
    }, "onDocumentMouseUp"),
    requestAnimationFrame: /* @__PURE__ */ __name(function requestAnimationFrame2(f2) {
      var frame = window.requestAnimationFrame || this.timeoutFrame;
      return frame(f2);
    }, "requestAnimationFrame"),
    refresh: /* @__PURE__ */ __name(function refresh() {
      this.moveBar();
    }, "refresh"),
    scrollTop: /* @__PURE__ */ __name(function scrollTop(_scrollTop) {
      var scrollableHeight = this.$refs.content.scrollHeight - this.$refs.content.clientHeight;
      _scrollTop = _scrollTop > scrollableHeight ? scrollableHeight : _scrollTop > 0 ? _scrollTop : 0;
      this.$refs.content.scrollTop = _scrollTop;
    }, "scrollTop"),
    timeoutFrame: /* @__PURE__ */ __name(function timeoutFrame(fn) {
      setTimeout(fn, 0);
    }, "timeoutFrame"),
    bindDocumentMouseListeners: /* @__PURE__ */ __name(function bindDocumentMouseListeners() {
      var _this5 = this;
      if (!this.documentMouseMoveListener) {
        this.documentMouseMoveListener = function(e2) {
          _this5.onDocumentMouseMove(e2);
        };
        document.addEventListener("mousemove", this.documentMouseMoveListener);
      }
      if (!this.documentMouseUpListener) {
        this.documentMouseUpListener = function(e2) {
          _this5.onDocumentMouseUp(e2);
        };
        document.addEventListener("mouseup", this.documentMouseUpListener);
      }
    }, "bindDocumentMouseListeners"),
    unbindDocumentMouseListeners: /* @__PURE__ */ __name(function unbindDocumentMouseListeners() {
      if (this.documentMouseMoveListener) {
        document.removeEventListener("mousemove", this.documentMouseMoveListener);
        this.documentMouseMoveListener = null;
      }
      if (this.documentMouseUpListener) {
        document.removeEventListener("mouseup", this.documentMouseUpListener);
        this.documentMouseUpListener = null;
      }
    }, "unbindDocumentMouseListeners"),
    bindDocumentResizeListener: /* @__PURE__ */ __name(function bindDocumentResizeListener() {
      var _this6 = this;
      if (!this.documentResizeListener) {
        this.documentResizeListener = function() {
          _this6.moveBar();
        };
        window.addEventListener("resize", this.documentResizeListener);
      }
    }, "bindDocumentResizeListener"),
    unbindDocumentResizeListener: /* @__PURE__ */ __name(function unbindDocumentResizeListener() {
      if (this.documentResizeListener) {
        window.removeEventListener("resize", this.documentResizeListener);
        this.documentResizeListener = null;
      }
    }, "unbindDocumentResizeListener")
  },
  computed: {
    contentId: /* @__PURE__ */ __name(function contentId() {
      return this.id + "_content";
    }, "contentId")
  }
};
var _hoisted_1$1I = ["id"];
var _hoisted_2$1e = ["aria-controls", "aria-valuenow"];
var _hoisted_3$R = ["aria-controls", "aria-valuenow"];
function render$U(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("contentContainer")
  }, _ctx.ptm("contentContainer")), [createBaseVNode("div", mergeProps$2({
    ref: "content",
    id: $options.contentId,
    "class": _ctx.cx("content"),
    onScroll: _cache[0] || (_cache[0] = function() {
      return $options.onScroll && $options.onScroll.apply($options, arguments);
    }),
    onMouseenter: _cache[1] || (_cache[1] = function() {
      return $options.moveBar && $options.moveBar.apply($options, arguments);
    })
  }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "default")], 16, _hoisted_1$1I)], 16), createBaseVNode("div", mergeProps$2({
    ref: "xBar",
    "class": _ctx.cx("barx"),
    tabindex: "0",
    role: "scrollbar",
    "aria-orientation": "horizontal",
    "aria-controls": $options.contentId,
    "aria-valuenow": $data.lastScrollLeft,
    onMousedown: _cache[2] || (_cache[2] = function() {
      return $options.onXBarMouseDown && $options.onXBarMouseDown.apply($options, arguments);
    }),
    onKeydown: _cache[3] || (_cache[3] = function($event) {
      return $options.onKeyDown($event);
    }),
    onKeyup: _cache[4] || (_cache[4] = function() {
      return $options.onKeyUp && $options.onKeyUp.apply($options, arguments);
    }),
    onFocus: _cache[5] || (_cache[5] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[6] || (_cache[6] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    })
  }, _ctx.ptm("barx"), {
    "data-pc-group-section": "bar"
  }), null, 16, _hoisted_2$1e), createBaseVNode("div", mergeProps$2({
    ref: "yBar",
    "class": _ctx.cx("bary"),
    tabindex: "0",
    role: "scrollbar",
    "aria-orientation": "vertical",
    "aria-controls": $options.contentId,
    "aria-valuenow": $data.lastScrollTop,
    onMousedown: _cache[7] || (_cache[7] = function() {
      return $options.onYBarMouseDown && $options.onYBarMouseDown.apply($options, arguments);
    }),
    onKeydown: _cache[8] || (_cache[8] = function($event) {
      return $options.onKeyDown($event);
    }),
    onKeyup: _cache[9] || (_cache[9] = function() {
      return $options.onKeyUp && $options.onKeyUp.apply($options, arguments);
    }),
    onFocus: _cache[10] || (_cache[10] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    })
  }, _ctx.ptm("bary"), {
    "data-pc-group-section": "bar"
  }), null, 16, _hoisted_3$R)], 16);
}
__name(render$U, "render$U");
script$X.render = render$U;
var theme$x = /* @__PURE__ */ __name(function theme13(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-card {\n    background: ".concat(dt2("card.background"), ";\n    color: ").concat(dt2("card.color"), ";\n    box-shadow: ").concat(dt2("card.shadow"), ";\n    border-radius: ").concat(dt2("card.border.radius"), ";\n    display: flex;\n    flex-direction: column;\n}\n\n.p-card-caption {\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("card.caption.gap"), ";\n}\n\n.p-card-body {\n    padding: ").concat(dt2("card.body.padding"), ";\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("card.body.gap"), ";\n}\n\n.p-card-title {\n    font-size: ").concat(dt2("card.title.font.size"), ";\n    font-weight: ").concat(dt2("card.title.font.weight"), ";\n}\n\n.p-card-subtitle {\n    color: ").concat(dt2("card.subtitle.color"), ";\n}\n");
}, "theme");
var classes$D = {
  root: "p-card p-component",
  header: "p-card-header",
  body: "p-card-body",
  caption: "p-card-caption",
  title: "p-card-title",
  subtitle: "p-card-subtitle",
  content: "p-card-content",
  footer: "p-card-footer"
};
var CardStyle = BaseStyle$1.extend({
  name: "card",
  theme: theme$x,
  classes: classes$D
});
var script$1$D = {
  name: "BaseCard",
  "extends": script$1b,
  style: CardStyle,
  provide: /* @__PURE__ */ __name(function provide12() {
    return {
      $pcCard: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$W = {
  name: "Card",
  "extends": script$1$D,
  inheritAttrs: false
};
function render$T(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [_ctx.$slots.header ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("header")
  }, _ctx.ptm("header")), [renderSlot(_ctx.$slots, "header")], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("body")
  }, _ctx.ptm("body")), [_ctx.$slots.title || _ctx.$slots.subtitle ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("caption")
  }, _ctx.ptm("caption")), [_ctx.$slots.title ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("title")
  }, _ctx.ptm("title")), [renderSlot(_ctx.$slots, "title")], 16)) : createCommentVNode("", true), _ctx.$slots.subtitle ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": _ctx.cx("subtitle")
  }, _ctx.ptm("subtitle")), [renderSlot(_ctx.$slots, "subtitle")], 16)) : createCommentVNode("", true)], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("content")
  }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "content")], 16), _ctx.$slots.footer ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": _ctx.cx("footer")
  }, _ctx.ptm("footer")), [renderSlot(_ctx.$slots, "footer")], 16)) : createCommentVNode("", true)], 16)], 16);
}
__name(render$T, "render$T");
script$W.render = render$T;
const _hoisted_1$1H = { class: "flex flex-col items-center" };
const _hoisted_2$1d = { class: "whitespace-pre-line text-center" };
const _sfc_main$1D = /* @__PURE__ */ defineComponent({
  __name: "NoResultsPlaceholder",
  props: {
    class: {},
    icon: {},
    title: {},
    message: {},
    buttonLabel: {}
  },
  emits: ["action"],
  setup(__props) {
    const props = __props;
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["no-results-placeholder p-8 h-full", props.class])
      }, [
        createVNode(unref(script$W), null, {
          content: withCtx(() => [
            createBaseVNode("div", _hoisted_1$1H, [
              createBaseVNode("i", {
                class: normalizeClass(_ctx.icon),
                style: { "font-size": "3rem", "margin-bottom": "1rem" }
              }, null, 2),
              createBaseVNode("h3", null, toDisplayString$1(_ctx.title), 1),
              createBaseVNode("p", _hoisted_2$1d, toDisplayString$1(_ctx.message), 1),
              _ctx.buttonLabel ? (openBlock(), createBlock(unref(script$10), {
                key: 0,
                label: _ctx.buttonLabel,
                onClick: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("action")),
                class: "p-button-text"
              }, null, 8, ["label"])) : createCommentVNode("", true)
            ])
          ]),
          _: 1
        })
      ], 2);
    };
  }
});
const NoResultsPlaceholder = /* @__PURE__ */ _export_sfc(_sfc_main$1D, [["__scopeId", "data-v-f2b77816"]]);
const _sfc_main$1C = /* @__PURE__ */ defineComponent({
  __name: "FindIssueButton",
  props: {
    errorMessage: {},
    repoOwner: {},
    repoName: {}
  },
  setup(__props) {
    const props = __props;
    const queryString = computed(() => props.errorMessage + " is:issue");
    const openGitHubIssues = /* @__PURE__ */ __name(() => {
      const query = encodeURIComponent(queryString.value);
      const url = `https://github.com/${props.repoOwner}/${props.repoName}/issues?q=${query}`;
      window.open(url, "_blank");
    }, "openGitHubIssues");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$10), {
        onClick: openGitHubIssues,
        label: _ctx.$t("g.findIssues"),
        severity: "secondary",
        icon: "pi pi-github"
      }, null, 8, ["label"]);
    };
  }
});
function useCopyToClipboard() {
  const { copy: copy2, isSupported: isSupported2 } = useClipboard();
  const toast = useToast();
  const copyToClipboard = /* @__PURE__ */ __name(async (text2) => {
    if (isSupported2) {
      try {
        await copy2(text2);
        toast.add({
          severity: "success",
          summary: t("g.success"),
          detail: t("clipboard.successMessage"),
          life: 3e3
        });
      } catch (err) {
        toast.add({
          severity: "error",
          summary: t("g.error"),
          detail: t("clipboard.errorMessage")
        });
      }
    } else {
      toast.add({
        severity: "error",
        summary: t("g.error"),
        detail: t("clipboard.errorNotSupported")
      });
    }
  }, "copyToClipboard");
  return {
    copyToClipboard
  };
}
__name(useCopyToClipboard, "useCopyToClipboard");
function classNames(...args) {
  if (args) {
    let classes2 = [];
    for (let i2 = 0; i2 < args.length; i2++) {
      let className = args[i2];
      if (!className) {
        continue;
      }
      const type = typeof className;
      if (type === "string" || type === "number") {
        classes2.push(className);
      } else if (type === "object") {
        const _classes = Array.isArray(className) ? [classNames(...className)] : Object.entries(className).map(([key, value3]) => value3 ? key : void 0);
        classes2 = _classes.length ? classes2.concat(_classes.filter((c2) => !!c2)) : classes2;
      }
    }
    return classes2.join(" ").trim();
  }
  return void 0;
}
__name(classNames, "classNames");
function hasClass(element, className) {
  if (element) {
    if (element.classList) return element.classList.contains(className);
    else return new RegExp("(^| )" + className + "( |$)", "gi").test(element.className);
  }
  return false;
}
__name(hasClass, "hasClass");
function addClass(element, className) {
  if (element && className) {
    const fn = /* @__PURE__ */ __name((_className) => {
      if (!hasClass(element, _className)) {
        if (element.classList) element.classList.add(_className);
        else element.className += " " + _className;
      }
    }, "fn");
    [className].flat().filter(Boolean).forEach((_classNames) => _classNames.split(" ").forEach(fn));
  }
}
__name(addClass, "addClass");
function calculateBodyScrollbarWidth() {
  return window.innerWidth - document.documentElement.offsetWidth;
}
__name(calculateBodyScrollbarWidth, "calculateBodyScrollbarWidth");
function getCSSVariableByRegex(variableRegex) {
  for (const sheet of document == null ? void 0 : document.styleSheets) {
    try {
      for (const rule of sheet == null ? void 0 : sheet.cssRules) {
        for (const property of rule == null ? void 0 : rule.style) {
          if (variableRegex.test(property)) {
            return { name: property, value: rule.style.getPropertyValue(property).trim() };
          }
        }
      }
    } catch (e2) {
    }
  }
  return null;
}
__name(getCSSVariableByRegex, "getCSSVariableByRegex");
function blockBodyScroll(className = "p-overflow-hidden") {
  const variableData = getCSSVariableByRegex(/-scrollbar-width$/);
  (variableData == null ? void 0 : variableData.name) && document.body.style.setProperty(variableData.name, calculateBodyScrollbarWidth() + "px");
  addClass(document.body, className);
}
__name(blockBodyScroll, "blockBodyScroll");
function saveAs(file) {
  if (file) {
    let link2 = document.createElement("a");
    if (link2.download !== void 0) {
      const { name: name2, src } = file;
      link2.setAttribute("href", src);
      link2.setAttribute("download", name2);
      link2.style.display = "none";
      document.body.appendChild(link2);
      link2.click();
      document.body.removeChild(link2);
      return true;
    }
  }
  return false;
}
__name(saveAs, "saveAs");
function exportCSV(csv, filename) {
  let blob = new Blob([csv], {
    type: "application/csv;charset=utf-8;"
  });
  if (window.navigator.msSaveOrOpenBlob) {
    navigator.msSaveOrOpenBlob(blob, filename + ".csv");
  } else {
    const isDownloaded = saveAs({ name: filename + ".csv", src: URL.createObjectURL(blob) });
    if (!isDownloaded) {
      csv = "data:text/csv;charset=utf-8," + csv;
      window.open(encodeURI(csv));
    }
  }
}
__name(exportCSV, "exportCSV");
function removeClass(element, className) {
  if (element && className) {
    const fn = /* @__PURE__ */ __name((_className) => {
      if (element.classList) element.classList.remove(_className);
      else element.className = element.className.replace(new RegExp("(^|\\b)" + _className.split(" ").join("|") + "(\\b|$)", "gi"), " ");
    }, "fn");
    [className].flat().filter(Boolean).forEach((_classNames) => _classNames.split(" ").forEach(fn));
  }
}
__name(removeClass, "removeClass");
function unblockBodyScroll(className = "p-overflow-hidden") {
  const variableData = getCSSVariableByRegex(/-scrollbar-width$/);
  (variableData == null ? void 0 : variableData.name) && document.body.style.removeProperty(variableData.name);
  removeClass(document.body, className);
}
__name(unblockBodyScroll, "unblockBodyScroll");
function getHiddenElementDimensions(element) {
  let dimensions = { width: 0, height: 0 };
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    dimensions.width = element.offsetWidth;
    dimensions.height = element.offsetHeight;
    element.style.display = "none";
    element.style.visibility = "visible";
  }
  return dimensions;
}
__name(getHiddenElementDimensions, "getHiddenElementDimensions");
function getViewport() {
  let win = window, d2 = document, e2 = d2.documentElement, g2 = d2.getElementsByTagName("body")[0], w2 = win.innerWidth || e2.clientWidth || g2.clientWidth, h2 = win.innerHeight || e2.clientHeight || g2.clientHeight;
  return { width: w2, height: h2 };
}
__name(getViewport, "getViewport");
function getWindowScrollLeft() {
  let doc2 = document.documentElement;
  return (window.pageXOffset || doc2.scrollLeft) - (doc2.clientLeft || 0);
}
__name(getWindowScrollLeft, "getWindowScrollLeft");
function getWindowScrollTop() {
  let doc2 = document.documentElement;
  return (window.pageYOffset || doc2.scrollTop) - (doc2.clientTop || 0);
}
__name(getWindowScrollTop, "getWindowScrollTop");
function absolutePosition(element, target2, gutter = true) {
  var _a2, _b, _c, _d;
  if (element) {
    const elementDimensions = element.offsetParent ? { width: element.offsetWidth, height: element.offsetHeight } : getHiddenElementDimensions(element);
    const elementOuterHeight = elementDimensions.height;
    const elementOuterWidth = elementDimensions.width;
    const targetOuterHeight = target2.offsetHeight;
    const targetOuterWidth = target2.offsetWidth;
    const targetOffset = target2.getBoundingClientRect();
    const windowScrollTop = getWindowScrollTop();
    const windowScrollLeft = getWindowScrollLeft();
    const viewport = getViewport();
    let top, left, origin2 = "top";
    if (targetOffset.top + targetOuterHeight + elementOuterHeight > viewport.height) {
      top = targetOffset.top + windowScrollTop - elementOuterHeight;
      origin2 = "bottom";
      if (top < 0) {
        top = windowScrollTop;
      }
    } else {
      top = targetOuterHeight + targetOffset.top + windowScrollTop;
    }
    if (targetOffset.left + elementOuterWidth > viewport.width) left = Math.max(0, targetOffset.left + windowScrollLeft + targetOuterWidth - elementOuterWidth);
    else left = targetOffset.left + windowScrollLeft;
    element.style.top = top + "px";
    element.style.left = left + "px";
    element.style.transformOrigin = origin2;
    gutter && (element.style.marginTop = origin2 === "bottom" ? `calc(${(_b = (_a2 = getCSSVariableByRegex(/-anchor-gutter$/)) == null ? void 0 : _a2.value) != null ? _b : "2px"} * -1)` : (_d = (_c = getCSSVariableByRegex(/-anchor-gutter$/)) == null ? void 0 : _c.value) != null ? _d : "");
  }
}
__name(absolutePosition, "absolutePosition");
function addStyle(element, style2) {
  if (element) {
    if (typeof style2 === "string") {
      element.style.cssText = style2;
    } else {
      Object.entries(style2 || {}).forEach(([key, value3]) => element.style[key] = value3);
    }
  }
}
__name(addStyle, "addStyle");
function getOuterWidth(element, margin) {
  if (element instanceof HTMLElement) {
    let width2 = element.offsetWidth;
    if (margin) {
      let style2 = getComputedStyle(element);
      width2 += parseFloat(style2.marginLeft) + parseFloat(style2.marginRight);
    }
    return width2;
  }
  return 0;
}
__name(getOuterWidth, "getOuterWidth");
function relativePosition(element, target2, gutter = true) {
  var _a2, _b, _c, _d;
  if (element) {
    const elementDimensions = element.offsetParent ? { width: element.offsetWidth, height: element.offsetHeight } : getHiddenElementDimensions(element);
    const targetHeight = target2.offsetHeight;
    const targetOffset = target2.getBoundingClientRect();
    const viewport = getViewport();
    let top, left, origin2 = "top";
    if (targetOffset.top + targetHeight + elementDimensions.height > viewport.height) {
      top = -1 * elementDimensions.height;
      origin2 = "bottom";
      if (targetOffset.top + top < 0) {
        top = -1 * targetOffset.top;
      }
    } else {
      top = targetHeight;
    }
    if (elementDimensions.width > viewport.width) {
      left = targetOffset.left * -1;
    } else if (targetOffset.left + elementDimensions.width > viewport.width) {
      left = (targetOffset.left + elementDimensions.width - viewport.width) * -1;
    } else {
      left = 0;
    }
    element.style.top = top + "px";
    element.style.left = left + "px";
    element.style.transformOrigin = origin2;
    gutter && (element.style.marginTop = origin2 === "bottom" ? `calc(${(_b = (_a2 = getCSSVariableByRegex(/-anchor-gutter$/)) == null ? void 0 : _a2.value) != null ? _b : "2px"} * -1)` : (_d = (_c = getCSSVariableByRegex(/-anchor-gutter$/)) == null ? void 0 : _c.value) != null ? _d : "");
  }
}
__name(relativePosition, "relativePosition");
function alignOverlay(overlay, target2, appendTo2, calculateMinWidth = true) {
  if (overlay && target2) {
    if (appendTo2 === "self") {
      relativePosition(overlay, target2);
    } else {
      calculateMinWidth && (overlay.style.minWidth = getOuterWidth(target2) + "px");
      absolutePosition(overlay, target2);
    }
  }
}
__name(alignOverlay, "alignOverlay");
function isElement(element) {
  return typeof HTMLElement === "object" ? element instanceof HTMLElement : element && typeof element === "object" && element !== null && element.nodeType === 1 && typeof element.nodeName === "string";
}
__name(isElement, "isElement");
function toElement(element) {
  let target2 = element;
  if (element && typeof element === "object") {
    if (element.hasOwnProperty("current")) {
      target2 = element.current;
    } else if (element.hasOwnProperty("el")) {
      if (element.el.hasOwnProperty("nativeElement")) {
        target2 = element.el.nativeElement;
      } else {
        target2 = element.el;
      }
    }
  }
  return isElement(target2) ? target2 : void 0;
}
__name(toElement, "toElement");
function appendChild(element, child) {
  const target2 = toElement(element);
  if (target2) target2.appendChild(child);
  else throw new Error("Cannot append " + child + " to " + element);
}
__name(appendChild, "appendChild");
var calculatedScrollbarHeight = void 0;
function calculateScrollbarHeight(element) {
  if (element) {
    let style2 = getComputedStyle(element);
    return element.offsetHeight - element.clientHeight - parseFloat(style2.borderTopWidth) - parseFloat(style2.borderBottomWidth);
  } else {
    if (calculatedScrollbarHeight != null) return calculatedScrollbarHeight;
    let scrollDiv = document.createElement("div");
    addStyle(scrollDiv, {
      width: "100px",
      height: "100px",
      overflow: "scroll",
      position: "absolute",
      top: "-9999px"
    });
    document.body.appendChild(scrollDiv);
    let scrollbarHeight = scrollDiv.offsetHeight - scrollDiv.clientHeight;
    document.body.removeChild(scrollDiv);
    calculatedScrollbarHeight = scrollbarHeight;
    return scrollbarHeight;
  }
}
__name(calculateScrollbarHeight, "calculateScrollbarHeight");
var calculatedScrollbarWidth = void 0;
function calculateScrollbarWidth(element) {
  if (element) {
    let style2 = getComputedStyle(element);
    return element.offsetWidth - element.clientWidth - parseFloat(style2.borderLeftWidth) - parseFloat(style2.borderRightWidth);
  } else {
    if (calculatedScrollbarWidth != null) return calculatedScrollbarWidth;
    let scrollDiv = document.createElement("div");
    addStyle(scrollDiv, {
      width: "100px",
      height: "100px",
      overflow: "scroll",
      position: "absolute",
      top: "-9999px"
    });
    document.body.appendChild(scrollDiv);
    let scrollbarWidth = scrollDiv.offsetWidth - scrollDiv.clientWidth;
    document.body.removeChild(scrollDiv);
    calculatedScrollbarWidth = scrollbarWidth;
    return scrollbarWidth;
  }
}
__name(calculateScrollbarWidth, "calculateScrollbarWidth");
function clearSelection() {
  if (window.getSelection) {
    const selection = window.getSelection() || {};
    if (selection.empty) {
      selection.empty();
    } else if (selection.removeAllRanges && selection.rangeCount > 0 && selection.getRangeAt(0).getClientRects().length > 0) {
      selection.removeAllRanges();
    }
  }
}
__name(clearSelection, "clearSelection");
function setAttributes(element, attributes = {}) {
  if (isElement(element)) {
    const computedStyles = /* @__PURE__ */ __name((rule, value3) => {
      var _a2, _b;
      const styles = ((_a2 = element == null ? void 0 : element.$attrs) == null ? void 0 : _a2[rule]) ? [(_b = element == null ? void 0 : element.$attrs) == null ? void 0 : _b[rule]] : [];
      return [value3].flat().reduce((cv, v2) => {
        if (v2 !== null && v2 !== void 0) {
          const type = typeof v2;
          if (type === "string" || type === "number") {
            cv.push(v2);
          } else if (type === "object") {
            const _cv = Array.isArray(v2) ? computedStyles(rule, v2) : Object.entries(v2).map(([_k, _v]) => rule === "style" && (!!_v || _v === 0) ? `${_k.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase()}:${_v}` : !!_v ? _k : void 0);
            cv = _cv.length ? cv.concat(_cv.filter((c2) => !!c2)) : cv;
          }
        }
        return cv;
      }, styles);
    }, "computedStyles");
    Object.entries(attributes).forEach(([key, value3]) => {
      if (value3 !== void 0 && value3 !== null) {
        const matchedEvent = key.match(/^on(.+)/);
        if (matchedEvent) {
          element.addEventListener(matchedEvent[1].toLowerCase(), value3);
        } else if (key === "p-bind" || key === "pBind") {
          setAttributes(element, value3);
        } else {
          value3 = key === "class" ? [...new Set(computedStyles("class", value3))].join(" ").trim() : key === "style" ? computedStyles("style", value3).join(";").trim() : value3;
          (element.$attrs = element.$attrs || {}) && (element.$attrs[key] = value3);
          element.setAttribute(key, value3);
        }
      }
    });
  }
}
__name(setAttributes, "setAttributes");
function createElement(type, attributes = {}, ...children) {
  if (type) {
    const element = document.createElement(type);
    setAttributes(element, attributes);
    element.append(...children);
    return element;
  }
  return void 0;
}
__name(createElement, "createElement");
function createStyleAsString(css4, options5 = {}) {
  return css4 ? `'<style ${Object.entries(options5).reduce((s2, [k2, v2]) => s2 + `${k2}="${v2}"`, " ")}>${css4}</style>'` : "";
}
__name(createStyleAsString, "createStyleAsString");
function createStyleTag$1(attributes = {}, container) {
  let element = document.createElement("style");
  setAttributes(element, attributes);
  if (!container) {
    container = document.head;
  }
  container.appendChild(element);
  return element;
}
__name(createStyleTag$1, "createStyleTag$1");
function fadeIn(element, duration) {
  if (element) {
    element.style.opacity = "0";
    let last = +/* @__PURE__ */ new Date();
    let opacity = "0";
    let tick = /* @__PURE__ */ __name(function() {
      opacity = `${+element.style.opacity + ((/* @__PURE__ */ new Date()).getTime() - last) / duration}`;
      element.style.opacity = opacity;
      last = +/* @__PURE__ */ new Date();
      if (+opacity < 1) {
        !!window.requestAnimationFrame && requestAnimationFrame(tick) || setTimeout(tick, 16);
      }
    }, "tick");
    tick();
  }
}
__name(fadeIn, "fadeIn");
function fadeOut(element, duration) {
  if (element) {
    let opacity = 1, interval = 50, gap = interval / duration;
    let fading = setInterval(() => {
      opacity -= gap;
      if (opacity <= 0) {
        opacity = 0;
        clearInterval(fading);
      }
      element.style.opacity = opacity.toString();
    }, interval);
  }
}
__name(fadeOut, "fadeOut");
function find$1(element, selector) {
  return isElement(element) ? Array.from(element.querySelectorAll(selector)) : [];
}
__name(find$1, "find$1");
function findSingle(element, selector) {
  return isElement(element) ? element.matches(selector) ? element : element.querySelector(selector) : null;
}
__name(findSingle, "findSingle");
function focus$1(element, options5) {
  element && document.activeElement !== element && element.focus(options5);
}
__name(focus$1, "focus$1");
function getAttribute(element, name2) {
  if (isElement(element)) {
    const value3 = element.getAttribute(name2);
    if (!isNaN(value3)) {
      return +value3;
    }
    if (value3 === "true" || value3 === "false") {
      return value3 === "true";
    }
    return value3;
  }
  return void 0;
}
__name(getAttribute, "getAttribute");
function resolveUserAgent() {
  let ua = navigator.userAgent.toLowerCase();
  let match2 = /(chrome)[ ]([\w.]+)/.exec(ua) || /(webkit)[ ]([\w.]+)/.exec(ua) || /(opera)(?:.*version|)[ ]([\w.]+)/.exec(ua) || /(msie) ([\w.]+)/.exec(ua) || ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) || [];
  return {
    browser: match2[1] || "",
    version: match2[2] || "0"
  };
}
__name(resolveUserAgent, "resolveUserAgent");
var browser = null;
function getBrowser() {
  if (!browser) {
    browser = {};
    let matched = resolveUserAgent();
    if (matched.browser) {
      browser[matched.browser] = true;
      browser["version"] = matched.version;
    }
    if (browser["chrome"]) {
      browser["webkit"] = true;
    } else if (browser["webkit"]) {
      browser["safari"] = true;
    }
  }
  return browser;
}
__name(getBrowser, "getBrowser");
function getBrowserLanguage() {
  return navigator.languages && navigator.languages.length && navigator.languages[0] || navigator.language || "en";
}
__name(getBrowserLanguage, "getBrowserLanguage");
function getCSSProperty(element, property, inline3) {
  var _a2;
  if (element && property) {
    return inline3 ? (_a2 = element == null ? void 0 : element.style) == null ? void 0 : _a2.getPropertyValue(property) : getComputedStyle(element).getPropertyValue(property);
  }
  return null;
}
__name(getCSSProperty, "getCSSProperty");
function getCursorOffset(element, prevText, nextText, currentText) {
  if (element) {
    let style2 = getComputedStyle(element);
    let ghostDiv = document.createElement("div");
    ghostDiv.style.position = "absolute";
    ghostDiv.style.top = "0px";
    ghostDiv.style.left = "0px";
    ghostDiv.style.visibility = "hidden";
    ghostDiv.style.pointerEvents = "none";
    ghostDiv.style.overflow = style2.overflow;
    ghostDiv.style.width = style2.width;
    ghostDiv.style.height = style2.height;
    ghostDiv.style.padding = style2.padding;
    ghostDiv.style.border = style2.border;
    ghostDiv.style.overflowWrap = style2.overflowWrap;
    ghostDiv.style.whiteSpace = style2.whiteSpace;
    ghostDiv.style.lineHeight = style2.lineHeight;
    ghostDiv.innerHTML = prevText.replace(/\r\n|\r|\n/g, "<br />");
    let ghostSpan = document.createElement("span");
    ghostSpan.textContent = currentText;
    ghostDiv.appendChild(ghostSpan);
    let text2 = document.createTextNode(nextText);
    ghostDiv.appendChild(text2);
    document.body.appendChild(ghostDiv);
    const { offsetLeft, offsetTop, clientHeight } = ghostSpan;
    document.body.removeChild(ghostDiv);
    return {
      left: Math.abs(offsetLeft - element.scrollLeft),
      top: Math.abs(offsetTop - element.scrollTop) + clientHeight
    };
  }
  return {
    top: "auto",
    left: "auto"
  };
}
__name(getCursorOffset, "getCursorOffset");
function getFocusableElements(element, selector = "") {
  let focusableElements = find$1(
    element,
    `button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector}`
  );
  let visibleFocusableElements = [];
  for (let focusableElement of focusableElements) {
    if (getComputedStyle(focusableElement).display != "none" && getComputedStyle(focusableElement).visibility != "hidden") visibleFocusableElements.push(focusableElement);
  }
  return visibleFocusableElements;
}
__name(getFocusableElements, "getFocusableElements");
function getFirstFocusableElement(element, selector) {
  const focusableElements = getFocusableElements(element, selector);
  return focusableElements.length > 0 ? focusableElements[0] : null;
}
__name(getFirstFocusableElement, "getFirstFocusableElement");
function getHeight(element) {
  if (element) {
    let height = element.offsetHeight;
    let style2 = getComputedStyle(element);
    height -= parseFloat(style2.paddingTop) + parseFloat(style2.paddingBottom) + parseFloat(style2.borderTopWidth) + parseFloat(style2.borderBottomWidth);
    return height;
  }
  return 0;
}
__name(getHeight, "getHeight");
function getHiddenElementOuterHeight(element) {
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    let elementHeight = element.offsetHeight;
    element.style.display = "none";
    element.style.visibility = "visible";
    return elementHeight;
  }
  return 0;
}
__name(getHiddenElementOuterHeight, "getHiddenElementOuterHeight");
function getHiddenElementOuterWidth(element) {
  if (element) {
    element.style.visibility = "hidden";
    element.style.display = "block";
    let elementWidth = element.offsetWidth;
    element.style.display = "none";
    element.style.visibility = "visible";
    return elementWidth;
  }
  return 0;
}
__name(getHiddenElementOuterWidth, "getHiddenElementOuterWidth");
function getParentNode(element) {
  if (element) {
    let parent = element.parentNode;
    if (parent && parent instanceof ShadowRoot && parent.host) {
      parent = parent.host;
    }
    return parent;
  }
  return null;
}
__name(getParentNode, "getParentNode");
function getIndex(element) {
  var _a2;
  if (element) {
    let children = (_a2 = getParentNode(element)) == null ? void 0 : _a2.childNodes;
    let num = 0;
    if (children) {
      for (let i2 = 0; i2 < children.length; i2++) {
        if (children[i2] === element) return num;
        if (children[i2].nodeType === 1) num++;
      }
    }
  }
  return -1;
}
__name(getIndex, "getIndex");
function getInnerWidth(element) {
  if (element) {
    let width2 = element.offsetWidth;
    let style2 = getComputedStyle(element);
    width2 -= parseFloat(style2.borderLeft) + parseFloat(style2.borderRight);
    return width2;
  }
  return 0;
}
__name(getInnerWidth, "getInnerWidth");
function getLastFocusableElement(element, selector) {
  const focusableElements = getFocusableElements(element, selector);
  return focusableElements.length > 0 ? focusableElements[focusableElements.length - 1] : null;
}
__name(getLastFocusableElement, "getLastFocusableElement");
function getNextElementSibling(element, selector) {
  let nextElement = element.nextElementSibling;
  while (nextElement) {
    if (nextElement.matches(selector)) {
      return nextElement;
    } else {
      nextElement = nextElement.nextElementSibling;
    }
  }
  return null;
}
__name(getNextElementSibling, "getNextElementSibling");
function getNextFocusableElement(container, element, selector) {
  const focusableElements = getFocusableElements(container, selector);
  const index2 = focusableElements.length > 0 ? focusableElements.findIndex((el) => el === element) : -1;
  const nextIndex = index2 > -1 && focusableElements.length >= index2 + 1 ? index2 + 1 : -1;
  return nextIndex > -1 ? focusableElements[nextIndex] : null;
}
__name(getNextFocusableElement, "getNextFocusableElement");
function getOffset(element) {
  if (element) {
    let rect = element.getBoundingClientRect();
    return {
      top: rect.top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0),
      left: rect.left + (window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft || 0)
    };
  }
  return {
    top: "auto",
    left: "auto"
  };
}
__name(getOffset, "getOffset");
function getOuterHeight(element, margin) {
  if (element) {
    let height = element.offsetHeight;
    if (margin) {
      let style2 = getComputedStyle(element);
      height += parseFloat(style2.marginTop) + parseFloat(style2.marginBottom);
    }
    return height;
  }
  return 0;
}
__name(getOuterHeight, "getOuterHeight");
function getParents(element, parents = []) {
  const parent = getParentNode(element);
  return parent === null ? parents : getParents(parent, parents.concat([parent]));
}
__name(getParents, "getParents");
function getPreviousElementSibling(element, selector) {
  let previousElement = element.previousElementSibling;
  while (previousElement) {
    if (previousElement.matches(selector)) {
      return previousElement;
    } else {
      previousElement = previousElement.previousElementSibling;
    }
  }
  return null;
}
__name(getPreviousElementSibling, "getPreviousElementSibling");
function getScrollableParents(element) {
  let scrollableParents = [];
  if (element) {
    let parents = getParents(element);
    const overflowRegex = /(auto|scroll)/;
    const overflowCheck = /* @__PURE__ */ __name((node3) => {
      try {
        let styleDeclaration = window["getComputedStyle"](node3, null);
        return overflowRegex.test(styleDeclaration.getPropertyValue("overflow")) || overflowRegex.test(styleDeclaration.getPropertyValue("overflowX")) || overflowRegex.test(styleDeclaration.getPropertyValue("overflowY"));
      } catch (err) {
        return false;
      }
    }, "overflowCheck");
    for (let parent of parents) {
      let scrollSelectors = parent.nodeType === 1 && parent.dataset["scrollselectors"];
      if (scrollSelectors) {
        let selectors = scrollSelectors.split(",");
        for (let selector of selectors) {
          let el = findSingle(parent, selector);
          if (el && overflowCheck(el)) {
            scrollableParents.push(el);
          }
        }
      }
      if (parent.nodeType !== 9 && overflowCheck(parent)) {
        scrollableParents.push(parent);
      }
    }
  }
  return scrollableParents;
}
__name(getScrollableParents, "getScrollableParents");
function getSelection$1() {
  if (window.getSelection) return window.getSelection().toString();
  else if (document.getSelection) return document.getSelection().toString();
  return void 0;
}
__name(getSelection$1, "getSelection$1");
function isExist(element) {
  return !!(element !== null && typeof element !== "undefined" && element.nodeName && getParentNode(element));
}
__name(isExist, "isExist");
function getTargetElement(target2, currentElement) {
  var _a2;
  if (!target2) return void 0;
  switch (target2) {
    case "document":
      return document;
    case "window":
      return window;
    case "body":
      return document.body;
    case "@next":
      return currentElement == null ? void 0 : currentElement.nextElementSibling;
    case "@prev":
      return currentElement == null ? void 0 : currentElement.previousElementSibling;
    case "@parent":
      return currentElement == null ? void 0 : currentElement.parentElement;
    case "@grandparent":
      return (_a2 = currentElement == null ? void 0 : currentElement.parentElement) == null ? void 0 : _a2.parentElement;
    default:
      if (typeof target2 === "string") {
        return document.querySelector(target2);
      }
      const isFunction2 = /* @__PURE__ */ __name((obj) => !!(obj && obj.constructor && obj.call && obj.apply), "isFunction");
      const element = toElement(isFunction2(target2) ? target2() : target2);
      return (element == null ? void 0 : element.nodeType) === 9 || isExist(element) ? element : void 0;
  }
}
__name(getTargetElement, "getTargetElement");
function getUserAgent() {
  return navigator.userAgent;
}
__name(getUserAgent, "getUserAgent");
function getWidth(element) {
  if (element) {
    let width2 = element.offsetWidth;
    let style2 = getComputedStyle(element);
    width2 -= parseFloat(style2.paddingLeft) + parseFloat(style2.paddingRight) + parseFloat(style2.borderLeftWidth) + parseFloat(style2.borderRightWidth);
    return width2;
  }
  return 0;
}
__name(getWidth, "getWidth");
function hasCSSAnimation(element) {
  if (element) {
    const style2 = getComputedStyle(element);
    const animationDuration = parseFloat(style2.getPropertyValue("animation-duration") || "0");
    return animationDuration > 0;
  }
  return false;
}
__name(hasCSSAnimation, "hasCSSAnimation");
function hasCSSTransition(element) {
  if (element) {
    const style2 = getComputedStyle(element);
    const transitionDuration = parseFloat(style2.getPropertyValue("transition-duration") || "0");
    return transitionDuration > 0;
  }
  return false;
}
__name(hasCSSTransition, "hasCSSTransition");
function invokeElementMethod(element, methodName, args) {
  element[methodName].apply(element, args);
}
__name(invokeElementMethod, "invokeElementMethod");
function isAndroid$2() {
  return /(android)/i.test(navigator.userAgent);
}
__name(isAndroid$2, "isAndroid$2");
function isAttributeEquals(element, name2, value3) {
  return isElement(element) ? getAttribute(element, name2) === value3 : false;
}
__name(isAttributeEquals, "isAttributeEquals");
function isAttributeNotEquals(element, name2, value3) {
  return !isAttributeEquals(element, name2, value3);
}
__name(isAttributeNotEquals, "isAttributeNotEquals");
function isClickable(element) {
  if (element) {
    const targetNode = element.nodeName;
    const parentNode2 = element.parentElement && element.parentElement.nodeName;
    return targetNode === "INPUT" || targetNode === "TEXTAREA" || targetNode === "BUTTON" || targetNode === "A" || parentNode2 === "INPUT" || parentNode2 === "TEXTAREA" || parentNode2 === "BUTTON" || parentNode2 === "A" || !!element.closest(".p-button, .p-checkbox, .p-radiobutton");
  }
  return false;
}
__name(isClickable, "isClickable");
function isClient() {
  return !!(typeof window !== "undefined" && window.document && window.document.createElement);
}
__name(isClient, "isClient");
function isFocusableElement(element, selector = "") {
  return isElement(element) ? element.matches(`button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector},
            [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])${selector}`) : false;
}
__name(isFocusableElement, "isFocusableElement");
function isVisible(element) {
  return !!(element && element.offsetParent != null);
}
__name(isVisible, "isVisible");
function isHidden(element) {
  return !isVisible(element);
}
__name(isHidden, "isHidden");
function isIOS() {
  return /iPad|iPhone|iPod/.test(navigator.userAgent) && !window["MSStream"];
}
__name(isIOS, "isIOS");
function isRTL(element) {
  return element ? getComputedStyle(element).direction === "rtl" : false;
}
__name(isRTL, "isRTL");
function isServer() {
  return !isClient();
}
__name(isServer, "isServer");
function isTouchDevice() {
  return "ontouchstart" in window || navigator.maxTouchPoints > 0 || navigator.msMaxTouchPoints > 0;
}
__name(isTouchDevice, "isTouchDevice");
function nestedPosition(element, level) {
  var _a2, _b;
  if (element) {
    const parentItem = element.parentElement;
    const elementOffset = getOffset(parentItem);
    const viewport = getViewport();
    const sublistWidth = element.offsetParent ? element.offsetWidth : getHiddenElementOuterWidth(element);
    const sublistHeight = element.offsetParent ? element.offsetHeight : getHiddenElementOuterHeight(element);
    const itemOuterWidth = getOuterWidth((_a2 = parentItem == null ? void 0 : parentItem.children) == null ? void 0 : _a2[0]);
    const itemOuterHeight = getOuterHeight((_b = parentItem == null ? void 0 : parentItem.children) == null ? void 0 : _b[0]);
    let left = "";
    let top = "";
    if (elementOffset.left + itemOuterWidth + sublistWidth > viewport.width - calculateScrollbarWidth()) {
      if (elementOffset.left < sublistWidth) {
        if (level % 2 === 1) {
          left = elementOffset.left ? "-" + elementOffset.left + "px" : "100%";
        } else if (level % 2 === 0) {
          left = viewport.width - sublistWidth - calculateScrollbarWidth() + "px";
        }
      } else {
        left = "-100%";
      }
    } else {
      left = "100%";
    }
    if (element.getBoundingClientRect().top + itemOuterHeight + sublistHeight > viewport.height) {
      top = `-${sublistHeight - itemOuterHeight}px`;
    } else {
      top = "0px";
    }
    element.style.top = top;
    element.style.left = left;
  }
}
__name(nestedPosition, "nestedPosition");
function remove(element) {
  var _a2;
  if (element) {
    if (!("remove" in Element.prototype)) (_a2 = element.parentNode) == null ? void 0 : _a2.removeChild(element);
    else element.remove();
  }
}
__name(remove, "remove");
function removeChild(element, child) {
  const target2 = toElement(element);
  if (target2) target2.removeChild(child);
  else throw new Error("Cannot remove " + child + " from " + element);
}
__name(removeChild, "removeChild");
function removeStyleTag(element) {
  var _a2;
  if (isExist(element)) {
    try {
      (_a2 = element.parentNode) == null ? void 0 : _a2.removeChild(element);
    } catch (error2) {
    }
    return null;
  }
  return element;
}
__name(removeStyleTag, "removeStyleTag");
function scrollInView(container, item3) {
  let borderTopValue = getComputedStyle(container).getPropertyValue("borderTopWidth");
  let borderTop = borderTopValue ? parseFloat(borderTopValue) : 0;
  let paddingTopValue = getComputedStyle(container).getPropertyValue("paddingTop");
  let paddingTop = paddingTopValue ? parseFloat(paddingTopValue) : 0;
  let containerRect = container.getBoundingClientRect();
  let itemRect = item3.getBoundingClientRect();
  let offset = itemRect.top + document.body.scrollTop - (containerRect.top + document.body.scrollTop) - borderTop - paddingTop;
  let scroll = container.scrollTop;
  let elementHeight = container.clientHeight;
  let itemHeight = getOuterHeight(item3);
  if (offset < 0) {
    container.scrollTop = scroll + offset;
  } else if (offset + itemHeight > elementHeight) {
    container.scrollTop = scroll + offset - elementHeight + itemHeight;
  }
}
__name(scrollInView, "scrollInView");
function setAttribute(element, attribute2 = "", value3) {
  if (isElement(element) && value3 !== null && value3 !== void 0) {
    element.setAttribute(attribute2, value3);
  }
}
__name(setAttribute, "setAttribute");
function setCSSProperty(element, property, value3 = null, priority) {
  var _a2;
  property && ((_a2 = element == null ? void 0 : element.style) == null ? void 0 : _a2.setProperty(property, value3, priority));
}
__name(setCSSProperty, "setCSSProperty");
function EventBus() {
  const allHandlers = /* @__PURE__ */ new Map();
  return {
    on(type, handler14) {
      let handlers2 = allHandlers.get(type);
      if (!handlers2) handlers2 = [handler14];
      else handlers2.push(handler14);
      allHandlers.set(type, handlers2);
      return this;
    },
    off(type, handler14) {
      let handlers2 = allHandlers.get(type);
      if (handlers2) {
        handlers2.splice(handlers2.indexOf(handler14) >>> 0, 1);
      }
      return this;
    },
    emit(type, evt) {
      let handlers2 = allHandlers.get(type);
      if (handlers2) {
        handlers2.slice().map((handler14) => {
          handler14(evt);
        });
      }
    },
    clear() {
      allHandlers.clear();
    }
  };
}
__name(EventBus, "EventBus");
var __defProp$4 = Object.defineProperty;
var __getOwnPropSymbols$3 = Object.getOwnPropertySymbols;
var __hasOwnProp$3 = Object.prototype.hasOwnProperty;
var __propIsEnum$3 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$4 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$4(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$4");
var __spreadValues$3 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$3.call(b2, prop2))
      __defNormalProp$4(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$3)
    for (var prop2 of __getOwnPropSymbols$3(b2)) {
      if (__propIsEnum$3.call(b2, prop2))
        __defNormalProp$4(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$3");
function isFunction$8(value3) {
  return !!(value3 && value3.constructor && value3.call && value3.apply);
}
__name(isFunction$8, "isFunction$8");
function mergeProps(...props) {
  return props == null ? void 0 : props.reduce((merged, ps = {}) => {
    for (const key in ps) {
      const value3 = ps[key];
      if (key === "style") {
        merged["style"] = __spreadValues$3(__spreadValues$3({}, merged["style"]), ps["style"]);
      } else if (key === "class") {
        merged["class"] = [merged["class"], ps["class"]].join(" ").trim() || void 0;
      } else if (key === "className") {
        merged["className"] = [merged["className"], ps["className"]].join(" ").trim() || void 0;
      } else if (isFunction$8(value3)) {
        const fn = merged[key];
        merged[key] = fn ? (...args) => {
          fn(...args);
          value3(...args);
        } : value3;
      } else {
        merged[key] = value3;
      }
    }
    return merged;
  }, {});
}
__name(mergeProps, "mergeProps");
var __defProp$3 = Object.defineProperty;
var __getOwnPropSymbols$2 = Object.getOwnPropertySymbols;
var __hasOwnProp$2 = Object.prototype.hasOwnProperty;
var __propIsEnum$2 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$3 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$3(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$3");
var __spreadValues$2 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$2.call(b2, prop2))
      __defNormalProp$3(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$2)
    for (var prop2 of __getOwnPropSymbols$2(b2)) {
      if (__propIsEnum$2.call(b2, prop2))
        __defNormalProp$3(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$2");
function isEmpty$2(value3) {
  return value3 === null || value3 === void 0 || value3 === "" || Array.isArray(value3) && value3.length === 0 || !(value3 instanceof Date) && typeof value3 === "object" && Object.keys(value3).length === 0;
}
__name(isEmpty$2, "isEmpty$2");
function compare$2(value1, value22, comparator, order = 1) {
  let result = -1;
  const emptyValue1 = isEmpty$2(value1);
  const emptyValue2 = isEmpty$2(value22);
  if (emptyValue1 && emptyValue2) result = 0;
  else if (emptyValue1) result = order;
  else if (emptyValue2) result = -order;
  else if (typeof value1 === "string" && typeof value22 === "string") result = comparator(value1, value22);
  else result = value1 < value22 ? -1 : value1 > value22 ? 1 : 0;
  return result;
}
__name(compare$2, "compare$2");
function _deepEquals$1(obj1, obj2, visited = /* @__PURE__ */ new WeakSet()) {
  if (obj1 === obj2) return true;
  if (!obj1 || !obj2 || typeof obj1 !== "object" || typeof obj2 !== "object") return false;
  if (visited.has(obj1) || visited.has(obj2)) return false;
  visited.add(obj1).add(obj2);
  let arrObj1 = Array.isArray(obj1), arrObj2 = Array.isArray(obj2), i2, length, key;
  if (arrObj1 && arrObj2) {
    length = obj1.length;
    if (length != obj2.length) return false;
    for (i2 = length; i2-- !== 0; ) if (!_deepEquals$1(obj1[i2], obj2[i2], visited)) return false;
    return true;
  }
  if (arrObj1 != arrObj2) return false;
  let dateObj1 = obj1 instanceof Date, dateObj2 = obj2 instanceof Date;
  if (dateObj1 != dateObj2) return false;
  if (dateObj1 && dateObj2) return obj1.getTime() == obj2.getTime();
  let regexpObj1 = obj1 instanceof RegExp, regexpObj2 = obj2 instanceof RegExp;
  if (regexpObj1 != regexpObj2) return false;
  if (regexpObj1 && regexpObj2) return obj1.toString() == obj2.toString();
  let keys2 = Object.keys(obj1);
  length = keys2.length;
  if (length !== Object.keys(obj2).length) return false;
  for (i2 = length; i2-- !== 0; ) if (!Object.prototype.hasOwnProperty.call(obj2, keys2[i2])) return false;
  for (i2 = length; i2-- !== 0; ) {
    key = keys2[i2];
    if (!_deepEquals$1(obj1[key], obj2[key], visited)) return false;
  }
  return true;
}
__name(_deepEquals$1, "_deepEquals$1");
function deepEquals$1(obj1, obj2) {
  return _deepEquals$1(obj1, obj2);
}
__name(deepEquals$1, "deepEquals$1");
function isFunction$7(value3) {
  return !!(value3 && value3.constructor && value3.call && value3.apply);
}
__name(isFunction$7, "isFunction$7");
function isNotEmpty$1(value3) {
  return !isEmpty$2(value3);
}
__name(isNotEmpty$1, "isNotEmpty$1");
function resolveFieldData$1(data30, field2) {
  if (!data30 || !field2) {
    return null;
  }
  try {
    const value3 = data30[field2];
    if (isNotEmpty$1(value3)) return value3;
  } catch (e2) {
  }
  if (Object.keys(data30).length) {
    if (isFunction$7(field2)) {
      return field2(data30);
    } else if (field2.indexOf(".") === -1) {
      return data30[field2];
    } else {
      let fields = field2.split(".");
      let value3 = data30;
      for (let i2 = 0, len = fields.length; i2 < len; ++i2) {
        if (value3 == null) {
          return null;
        }
        value3 = value3[fields[i2]];
      }
      return value3;
    }
  }
  return null;
}
__name(resolveFieldData$1, "resolveFieldData$1");
function equals$1(obj1, obj2, field2) {
  if (field2) return resolveFieldData$1(obj1, field2) === resolveFieldData$1(obj2, field2);
  else return deepEquals$1(obj1, obj2);
}
__name(equals$1, "equals$1");
function contains$1(value3, list2) {
  if (value3 != null && list2 && list2.length) {
    for (let val of list2) {
      if (equals$1(value3, val)) return true;
    }
  }
  return false;
}
__name(contains$1, "contains$1");
function filter$1(value3, fields, filterValue) {
  let filteredItems = [];
  if (value3) {
    for (let item3 of value3) {
      for (let field2 of fields) {
        if (String(resolveFieldData$1(item3, field2)).toLowerCase().indexOf(filterValue.toLowerCase()) > -1) {
          filteredItems.push(item3);
          break;
        }
      }
    }
  }
  return filteredItems;
}
__name(filter$1, "filter$1");
function findIndexInList$1(value3, list2) {
  let index2 = -1;
  if (list2) {
    for (let i2 = 0; i2 < list2.length; i2++) {
      if (list2[i2] === value3) {
        index2 = i2;
        break;
      }
    }
  }
  return index2;
}
__name(findIndexInList$1, "findIndexInList$1");
function findLast$1(arr, callback) {
  let item3;
  if (isNotEmpty$1(arr)) {
    try {
      item3 = arr.findLast(callback);
    } catch (e2) {
      item3 = [...arr].reverse().find(callback);
    }
  }
  return item3;
}
__name(findLast$1, "findLast$1");
function findLastIndex$1(arr, callback) {
  let index2 = -1;
  if (isNotEmpty$1(arr)) {
    try {
      index2 = arr.findLastIndex(callback);
    } catch (e2) {
      index2 = arr.lastIndexOf([...arr].reverse().find(callback));
    }
  }
  return index2;
}
__name(findLastIndex$1, "findLastIndex$1");
function isObject$a(value3, empty2 = true) {
  return value3 instanceof Object && value3.constructor === Object && (empty2 || Object.keys(value3).length !== 0);
}
__name(isObject$a, "isObject$a");
function resolve$1(obj, ...params) {
  return isFunction$7(obj) ? obj(...params) : obj;
}
__name(resolve$1, "resolve$1");
function isString$5(value3, empty2 = true) {
  return typeof value3 === "string" && (empty2 || value3 !== "");
}
__name(isString$5, "isString$5");
function toFlatCase$1(str) {
  return isString$5(str) ? str.replace(/(-|_)/g, "").toLowerCase() : str;
}
__name(toFlatCase$1, "toFlatCase$1");
function getKeyValue$1(obj, key = "", params = {}) {
  const fKeys = toFlatCase$1(key).split(".");
  const fKey = fKeys.shift();
  return fKey ? isObject$a(obj) ? getKeyValue$1(resolve$1(obj[Object.keys(obj).find((k2) => toFlatCase$1(k2) === fKey) || ""], params), fKeys.join("."), params) : void 0 : resolve$1(obj, params);
}
__name(getKeyValue$1, "getKeyValue$1");
function insertIntoOrderedArray$1(item3, index2, arr, sourceArr) {
  if (arr.length > 0) {
    let injected = false;
    for (let i2 = 0; i2 < arr.length; i2++) {
      let currentItemIndex = findIndexInList$1(arr[i2], sourceArr);
      if (currentItemIndex > index2) {
        arr.splice(i2, 0, item3);
        injected = true;
        break;
      }
    }
    if (!injected) {
      arr.push(item3);
    }
  } else {
    arr.push(item3);
  }
}
__name(insertIntoOrderedArray$1, "insertIntoOrderedArray$1");
function isArray$7(value3, empty2 = true) {
  return Array.isArray(value3) && (empty2 || value3.length !== 0);
}
__name(isArray$7, "isArray$7");
function isDate$1(value3) {
  return value3 instanceof Date && value3.constructor === Date;
}
__name(isDate$1, "isDate$1");
function isLetter$2(char) {
  return /^[a-zA-Z\u00C0-\u017F]$/.test(char);
}
__name(isLetter$2, "isLetter$2");
function isNumber$4(value3) {
  return isNotEmpty$1(value3) && !isNaN(value3);
}
__name(isNumber$4, "isNumber$4");
function isPrintableCharacter$1(char = "") {
  return isNotEmpty$1(char) && char.length === 1 && !!char.match(/\S| /);
}
__name(isPrintableCharacter$1, "isPrintableCharacter$1");
function isScalar$1(value3) {
  return value3 != null && (typeof value3 === "string" || typeof value3 === "number" || typeof value3 === "bigint" || typeof value3 === "boolean");
}
__name(isScalar$1, "isScalar$1");
function localeComparator$1() {
  return new Intl.Collator(void 0, { numeric: true }).compare;
}
__name(localeComparator$1, "localeComparator$1");
function matchRegex$1(str, regex2) {
  if (regex2) {
    const match2 = regex2.test(str);
    regex2.lastIndex = 0;
    return match2;
  }
  return false;
}
__name(matchRegex$1, "matchRegex$1");
function mergeKeys$1(...args) {
  const _mergeKeys = /* @__PURE__ */ __name((target2 = {}, source = {}) => {
    const mergedObj = __spreadValues$2({}, target2);
    Object.keys(source).forEach((key) => {
      if (isObject$a(source[key]) && key in target2 && isObject$a(target2[key])) {
        mergedObj[key] = _mergeKeys(target2[key], source[key]);
      } else {
        mergedObj[key] = source[key];
      }
    });
    return mergedObj;
  }, "_mergeKeys");
  return args.reduce((acc, obj, i2) => i2 === 0 ? obj : _mergeKeys(acc, obj), {});
}
__name(mergeKeys$1, "mergeKeys$1");
function minifyCSS$1(css4) {
  return css4 ? css4.replace(/\/\*(?:(?!\*\/)[\s\S])*\*\/|[\r\n\t]+/g, "").replace(/ {2,}/g, " ").replace(/ ([{:}]) /g, "$1").replace(/([;,]) /g, "$1").replace(/ !/g, "!").replace(/: /g, ":") : css4;
}
__name(minifyCSS$1, "minifyCSS$1");
function nestedKeys$1(obj = {}, parentKey = "") {
  return Object.entries(obj).reduce((o2, [key, value3]) => {
    const currentKey = parentKey ? `${parentKey}.${key}` : key;
    isObject$a(value3) ? o2 = o2.concat(nestedKeys$1(value3, currentKey)) : o2.push(currentKey);
    return o2;
  }, []);
}
__name(nestedKeys$1, "nestedKeys$1");
function omit$1(obj, ...keys2) {
  if (!isObject$a(obj)) return obj;
  const copy2 = __spreadValues$2({}, obj);
  keys2 == null ? void 0 : keys2.flat().forEach((key) => delete copy2[key]);
  return copy2;
}
__name(omit$1, "omit$1");
function removeAccents$1(str) {
  const accentCheckRegex = /[\xC0-\xFF\u0100-\u017E]/;
  if (str && accentCheckRegex.test(str)) {
    const accentsMap = {
      A: /[\xC0-\xC5\u0100\u0102\u0104]/g,
      AE: /[\xC6]/g,
      C: /[\xC7\u0106\u0108\u010A\u010C]/g,
      D: /[\xD0\u010E\u0110]/g,
      E: /[\xC8-\xCB\u0112\u0114\u0116\u0118\u011A]/g,
      G: /[\u011C\u011E\u0120\u0122]/g,
      H: /[\u0124\u0126]/g,
      I: /[\xCC-\xCF\u0128\u012A\u012C\u012E\u0130]/g,
      IJ: /[\u0132]/g,
      J: /[\u0134]/g,
      K: /[\u0136]/g,
      L: /[\u0139\u013B\u013D\u013F\u0141]/g,
      N: /[\xD1\u0143\u0145\u0147\u014A]/g,
      O: /[\xD2-\xD6\xD8\u014C\u014E\u0150]/g,
      OE: /[\u0152]/g,
      R: /[\u0154\u0156\u0158]/g,
      S: /[\u015A\u015C\u015E\u0160]/g,
      T: /[\u0162\u0164\u0166]/g,
      U: /[\xD9-\xDC\u0168\u016A\u016C\u016E\u0170\u0172]/g,
      W: /[\u0174]/g,
      Y: /[\xDD\u0176\u0178]/g,
      Z: /[\u0179\u017B\u017D]/g,
      a: /[\xE0-\xE5\u0101\u0103\u0105]/g,
      ae: /[\xE6]/g,
      c: /[\xE7\u0107\u0109\u010B\u010D]/g,
      d: /[\u010F\u0111]/g,
      e: /[\xE8-\xEB\u0113\u0115\u0117\u0119\u011B]/g,
      g: /[\u011D\u011F\u0121\u0123]/g,
      i: /[\xEC-\xEF\u0129\u012B\u012D\u012F\u0131]/g,
      ij: /[\u0133]/g,
      j: /[\u0135]/g,
      k: /[\u0137,\u0138]/g,
      l: /[\u013A\u013C\u013E\u0140\u0142]/g,
      n: /[\xF1\u0144\u0146\u0148\u014B]/g,
      p: /[\xFE]/g,
      o: /[\xF2-\xF6\xF8\u014D\u014F\u0151]/g,
      oe: /[\u0153]/g,
      r: /[\u0155\u0157\u0159]/g,
      s: /[\u015B\u015D\u015F\u0161]/g,
      t: /[\u0163\u0165\u0167]/g,
      u: /[\xF9-\xFC\u0169\u016B\u016D\u016F\u0171\u0173]/g,
      w: /[\u0175]/g,
      y: /[\xFD\xFF\u0177]/g,
      z: /[\u017A\u017C\u017E]/g
    };
    for (let key in accentsMap) {
      str = str.replace(accentsMap[key], key);
    }
  }
  return str;
}
__name(removeAccents$1, "removeAccents$1");
function reorderArray$1(value3, from2, to) {
  if (value3 && from2 !== to) {
    if (to >= value3.length) {
      to %= value3.length;
      from2 %= value3.length;
    }
    value3.splice(to, 0, value3.splice(from2, 1)[0]);
  }
}
__name(reorderArray$1, "reorderArray$1");
function sort$1(value1, value22, order = 1, comparator, nullSortOrder = 1) {
  const result = compare$2(value1, value22, comparator, order);
  let finalSortOrder = order;
  if (isEmpty$2(value1) || isEmpty$2(value22)) {
    finalSortOrder = nullSortOrder === 1 ? order : nullSortOrder;
  }
  return finalSortOrder * result;
}
__name(sort$1, "sort$1");
function stringify$1(value3, indent = 2, currentIndent = 0) {
  const currentIndentStr = " ".repeat(currentIndent);
  const nextIndentStr = " ".repeat(currentIndent + indent);
  if (isArray$7(value3)) {
    return "[" + value3.map((v2) => stringify$1(v2, indent, currentIndent + indent)).join(", ") + "]";
  } else if (isDate$1(value3)) {
    return value3.toISOString();
  } else if (isFunction$7(value3)) {
    return value3.toString();
  } else if (isObject$a(value3)) {
    return "{\n" + Object.entries(value3).map(([k2, v2]) => `${nextIndentStr}${k2}: ${stringify$1(v2, indent, currentIndent + indent)}`).join(",\n") + `
${currentIndentStr}}`;
  } else {
    return JSON.stringify(value3);
  }
}
__name(stringify$1, "stringify$1");
function toCapitalCase$1(str) {
  return isString$5(str, false) ? str[0].toUpperCase() + str.slice(1) : str;
}
__name(toCapitalCase$1, "toCapitalCase$1");
function toKebabCase$1(str) {
  return isString$5(str) ? str.replace(/(_)/g, "-").replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "-" + c2.toLowerCase()).toLowerCase() : str;
}
__name(toKebabCase$1, "toKebabCase$1");
function toTokenKey$2(str) {
  return isString$5(str) ? str.replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "." + c2.toLowerCase()).toLowerCase() : str;
}
__name(toTokenKey$2, "toTokenKey$2");
function toValue$2(value3) {
  if (value3 && typeof value3 === "object") {
    if (value3.hasOwnProperty("current")) {
      return value3.current;
    } else if (value3.hasOwnProperty("value")) {
      return value3.value;
    }
  }
  return resolve$1(value3);
}
__name(toValue$2, "toValue$2");
var lastIds = {};
function uuid(prefix2 = "pui_id_") {
  if (!lastIds.hasOwnProperty(prefix2)) {
    lastIds[prefix2] = 0;
  }
  lastIds[prefix2]++;
  return `${prefix2}${lastIds[prefix2]}`;
}
__name(uuid, "uuid");
function handler() {
  let zIndexes = [];
  const generateZIndex = /* @__PURE__ */ __name((key, autoZIndex, baseZIndex = 999) => {
    const lastZIndex = getLastZIndex(key, autoZIndex, baseZIndex);
    const newZIndex = lastZIndex.value + (lastZIndex.key === key ? 0 : baseZIndex) + 1;
    zIndexes.push({ key, value: newZIndex });
    return newZIndex;
  }, "generateZIndex");
  const revertZIndex = /* @__PURE__ */ __name((zIndex) => {
    zIndexes = zIndexes.filter((obj) => obj.value !== zIndex);
  }, "revertZIndex");
  const getCurrentZIndex = /* @__PURE__ */ __name((key, autoZIndex) => {
    return getLastZIndex(key, autoZIndex).value;
  }, "getCurrentZIndex");
  const getLastZIndex = /* @__PURE__ */ __name((key, autoZIndex, baseZIndex = 0) => {
    return [...zIndexes].reverse().find((obj) => autoZIndex ? true : obj.key === key) || { key, value: baseZIndex };
  }, "getLastZIndex");
  const getZIndex = /* @__PURE__ */ __name((element) => {
    return element ? parseInt(element.style.zIndex, 10) || 0 : 0;
  }, "getZIndex");
  return {
    get: getZIndex,
    set: /* @__PURE__ */ __name((key, element, baseZIndex) => {
      if (element) {
        element.style.zIndex = String(generateZIndex(key, true, baseZIndex));
      }
    }, "set"),
    clear: /* @__PURE__ */ __name((element) => {
      if (element) {
        revertZIndex(getZIndex(element));
        element.style.zIndex = "";
      }
    }, "clear"),
    getCurrent: /* @__PURE__ */ __name((key) => getCurrentZIndex(key, true), "getCurrent")
  };
}
__name(handler, "handler");
var ZIndex = handler();
function _typeof$h(o2) {
  "@babel/helpers - typeof";
  return _typeof$h = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$h(o2);
}
__name(_typeof$h, "_typeof$h");
function _slicedToArray$4(r2, e2) {
  return _arrayWithHoles$4(r2) || _iterableToArrayLimit$4(r2, e2) || _unsupportedIterableToArray$h(r2, e2) || _nonIterableRest$4();
}
__name(_slicedToArray$4, "_slicedToArray$4");
function _nonIterableRest$4() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$4, "_nonIterableRest$4");
function _unsupportedIterableToArray$h(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$h(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$h(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$h, "_unsupportedIterableToArray$h");
function _arrayLikeToArray$h(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$h, "_arrayLikeToArray$h");
function _iterableToArrayLimit$4(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$4, "_iterableToArrayLimit$4");
function _arrayWithHoles$4(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$4, "_arrayWithHoles$4");
function ownKeys$j(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$j, "ownKeys$j");
function _objectSpread$j(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$j(Object(t2), true).forEach(function(r3) {
      _defineProperty$j(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$j(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$j, "_objectSpread$j");
function _defineProperty$j(e2, r2, t2) {
  return (r2 = _toPropertyKey$g(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$j, "_defineProperty$j");
function _toPropertyKey$g(t2) {
  var i2 = _toPrimitive$g(t2, "string");
  return "symbol" == _typeof$h(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$g, "_toPropertyKey$g");
function _toPrimitive$g(t2, r2) {
  if ("object" != _typeof$h(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$h(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$g, "_toPrimitive$g");
function _regeneratorRuntime() {
  /*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/facebook/regenerator/blob/main/LICENSE */
  _regeneratorRuntime = /* @__PURE__ */ __name(function _regeneratorRuntime2() {
    return e2;
  }, "_regeneratorRuntime");
  var t2, e2 = {}, r2 = Object.prototype, n2 = r2.hasOwnProperty, o2 = Object.defineProperty || function(t3, e3, r3) {
    t3[e3] = r3.value;
  }, i2 = "function" == typeof Symbol ? Symbol : {}, a2 = i2.iterator || "@@iterator", c2 = i2.asyncIterator || "@@asyncIterator", u2 = i2.toStringTag || "@@toStringTag";
  function define(t3, e3, r3) {
    return Object.defineProperty(t3, e3, { value: r3, enumerable: true, configurable: true, writable: true }), t3[e3];
  }
  __name(define, "define");
  try {
    define({}, "");
  } catch (t3) {
    define = /* @__PURE__ */ __name(function define2(t4, e3, r3) {
      return t4[e3] = r3;
    }, "define");
  }
  function wrap2(t3, e3, r3, n3) {
    var i3 = e3 && e3.prototype instanceof Generator ? e3 : Generator, a3 = Object.create(i3.prototype), c3 = new Context2(n3 || []);
    return o2(a3, "_invoke", { value: makeInvokeMethod(t3, r3, c3) }), a3;
  }
  __name(wrap2, "wrap");
  function tryCatch(t3, e3, r3) {
    try {
      return { type: "normal", arg: t3.call(e3, r3) };
    } catch (t4) {
      return { type: "throw", arg: t4 };
    }
  }
  __name(tryCatch, "tryCatch");
  e2.wrap = wrap2;
  var h2 = "suspendedStart", l2 = "suspendedYield", f2 = "executing", s2 = "completed", y2 = {};
  function Generator() {
  }
  __name(Generator, "Generator");
  function GeneratorFunction() {
  }
  __name(GeneratorFunction, "GeneratorFunction");
  function GeneratorFunctionPrototype() {
  }
  __name(GeneratorFunctionPrototype, "GeneratorFunctionPrototype");
  var p2 = {};
  define(p2, a2, function() {
    return this;
  });
  var d2 = Object.getPrototypeOf, v2 = d2 && d2(d2(values([])));
  v2 && v2 !== r2 && n2.call(v2, a2) && (p2 = v2);
  var g2 = GeneratorFunctionPrototype.prototype = Generator.prototype = Object.create(p2);
  function defineIteratorMethods(t3) {
    ["next", "throw", "return"].forEach(function(e3) {
      define(t3, e3, function(t4) {
        return this._invoke(e3, t4);
      });
    });
  }
  __name(defineIteratorMethods, "defineIteratorMethods");
  function AsyncIterator(t3, e3) {
    function invoke2(r4, o3, i3, a3) {
      var c3 = tryCatch(t3[r4], t3, o3);
      if ("throw" !== c3.type) {
        var u3 = c3.arg, h3 = u3.value;
        return h3 && "object" == _typeof$h(h3) && n2.call(h3, "__await") ? e3.resolve(h3.__await).then(function(t4) {
          invoke2("next", t4, i3, a3);
        }, function(t4) {
          invoke2("throw", t4, i3, a3);
        }) : e3.resolve(h3).then(function(t4) {
          u3.value = t4, i3(u3);
        }, function(t4) {
          return invoke2("throw", t4, i3, a3);
        });
      }
      a3(c3.arg);
    }
    __name(invoke2, "invoke");
    var r3;
    o2(this, "_invoke", { value: /* @__PURE__ */ __name(function value3(t4, n3) {
      function callInvokeWithMethodAndArg() {
        return new e3(function(e4, r4) {
          invoke2(t4, n3, e4, r4);
        });
      }
      __name(callInvokeWithMethodAndArg, "callInvokeWithMethodAndArg");
      return r3 = r3 ? r3.then(callInvokeWithMethodAndArg, callInvokeWithMethodAndArg) : callInvokeWithMethodAndArg();
    }, "value") });
  }
  __name(AsyncIterator, "AsyncIterator");
  function makeInvokeMethod(e3, r3, n3) {
    var o3 = h2;
    return function(i3, a3) {
      if (o3 === f2) throw Error("Generator is already running");
      if (o3 === s2) {
        if ("throw" === i3) throw a3;
        return { value: t2, done: true };
      }
      for (n3.method = i3, n3.arg = a3; ; ) {
        var c3 = n3.delegate;
        if (c3) {
          var u3 = maybeInvokeDelegate(c3, n3);
          if (u3) {
            if (u3 === y2) continue;
            return u3;
          }
        }
        if ("next" === n3.method) n3.sent = n3._sent = n3.arg;
        else if ("throw" === n3.method) {
          if (o3 === h2) throw o3 = s2, n3.arg;
          n3.dispatchException(n3.arg);
        } else "return" === n3.method && n3.abrupt("return", n3.arg);
        o3 = f2;
        var p3 = tryCatch(e3, r3, n3);
        if ("normal" === p3.type) {
          if (o3 = n3.done ? s2 : l2, p3.arg === y2) continue;
          return { value: p3.arg, done: n3.done };
        }
        "throw" === p3.type && (o3 = s2, n3.method = "throw", n3.arg = p3.arg);
      }
    };
  }
  __name(makeInvokeMethod, "makeInvokeMethod");
  function maybeInvokeDelegate(e3, r3) {
    var n3 = r3.method, o3 = e3.iterator[n3];
    if (o3 === t2) return r3.delegate = null, "throw" === n3 && e3.iterator["return"] && (r3.method = "return", r3.arg = t2, maybeInvokeDelegate(e3, r3), "throw" === r3.method) || "return" !== n3 && (r3.method = "throw", r3.arg = new TypeError("The iterator does not provide a '" + n3 + "' method")), y2;
    var i3 = tryCatch(o3, e3.iterator, r3.arg);
    if ("throw" === i3.type) return r3.method = "throw", r3.arg = i3.arg, r3.delegate = null, y2;
    var a3 = i3.arg;
    return a3 ? a3.done ? (r3[e3.resultName] = a3.value, r3.next = e3.nextLoc, "return" !== r3.method && (r3.method = "next", r3.arg = t2), r3.delegate = null, y2) : a3 : (r3.method = "throw", r3.arg = new TypeError("iterator result is not an object"), r3.delegate = null, y2);
  }
  __name(maybeInvokeDelegate, "maybeInvokeDelegate");
  function pushTryEntry(t3) {
    var e3 = { tryLoc: t3[0] };
    1 in t3 && (e3.catchLoc = t3[1]), 2 in t3 && (e3.finallyLoc = t3[2], e3.afterLoc = t3[3]), this.tryEntries.push(e3);
  }
  __name(pushTryEntry, "pushTryEntry");
  function resetTryEntry(t3) {
    var e3 = t3.completion || {};
    e3.type = "normal", delete e3.arg, t3.completion = e3;
  }
  __name(resetTryEntry, "resetTryEntry");
  function Context2(t3) {
    this.tryEntries = [{ tryLoc: "root" }], t3.forEach(pushTryEntry, this), this.reset(true);
  }
  __name(Context2, "Context");
  function values(e3) {
    if (e3 || "" === e3) {
      var r3 = e3[a2];
      if (r3) return r3.call(e3);
      if ("function" == typeof e3.next) return e3;
      if (!isNaN(e3.length)) {
        var o3 = -1, i3 = /* @__PURE__ */ __name(function next2() {
          for (; ++o3 < e3.length; ) if (n2.call(e3, o3)) return next2.value = e3[o3], next2.done = false, next2;
          return next2.value = t2, next2.done = true, next2;
        }, "next");
        return i3.next = i3;
      }
    }
    throw new TypeError(_typeof$h(e3) + " is not iterable");
  }
  __name(values, "values");
  return GeneratorFunction.prototype = GeneratorFunctionPrototype, o2(g2, "constructor", { value: GeneratorFunctionPrototype, configurable: true }), o2(GeneratorFunctionPrototype, "constructor", { value: GeneratorFunction, configurable: true }), GeneratorFunction.displayName = define(GeneratorFunctionPrototype, u2, "GeneratorFunction"), e2.isGeneratorFunction = function(t3) {
    var e3 = "function" == typeof t3 && t3.constructor;
    return !!e3 && (e3 === GeneratorFunction || "GeneratorFunction" === (e3.displayName || e3.name));
  }, e2.mark = function(t3) {
    return Object.setPrototypeOf ? Object.setPrototypeOf(t3, GeneratorFunctionPrototype) : (t3.__proto__ = GeneratorFunctionPrototype, define(t3, u2, "GeneratorFunction")), t3.prototype = Object.create(g2), t3;
  }, e2.awrap = function(t3) {
    return { __await: t3 };
  }, defineIteratorMethods(AsyncIterator.prototype), define(AsyncIterator.prototype, c2, function() {
    return this;
  }), e2.AsyncIterator = AsyncIterator, e2.async = function(t3, r3, n3, o3, i3) {
    void 0 === i3 && (i3 = Promise);
    var a3 = new AsyncIterator(wrap2(t3, r3, n3, o3), i3);
    return e2.isGeneratorFunction(r3) ? a3 : a3.next().then(function(t4) {
      return t4.done ? t4.value : a3.next();
    });
  }, defineIteratorMethods(g2), define(g2, u2, "Generator"), define(g2, a2, function() {
    return this;
  }), define(g2, "toString", function() {
    return "[object Generator]";
  }), e2.keys = function(t3) {
    var e3 = Object(t3), r3 = [];
    for (var n3 in e3) r3.push(n3);
    return r3.reverse(), /* @__PURE__ */ __name(function next2() {
      for (; r3.length; ) {
        var t4 = r3.pop();
        if (t4 in e3) return next2.value = t4, next2.done = false, next2;
      }
      return next2.done = true, next2;
    }, "next");
  }, e2.values = values, Context2.prototype = { constructor: Context2, reset: /* @__PURE__ */ __name(function reset2(e3) {
    if (this.prev = 0, this.next = 0, this.sent = this._sent = t2, this.done = false, this.delegate = null, this.method = "next", this.arg = t2, this.tryEntries.forEach(resetTryEntry), !e3) for (var r3 in this) "t" === r3.charAt(0) && n2.call(this, r3) && !isNaN(+r3.slice(1)) && (this[r3] = t2);
  }, "reset"), stop: /* @__PURE__ */ __name(function stop2() {
    this.done = true;
    var t3 = this.tryEntries[0].completion;
    if ("throw" === t3.type) throw t3.arg;
    return this.rval;
  }, "stop"), dispatchException: /* @__PURE__ */ __name(function dispatchException(e3) {
    if (this.done) throw e3;
    var r3 = this;
    function handle(n3, o4) {
      return a3.type = "throw", a3.arg = e3, r3.next = n3, o4 && (r3.method = "next", r3.arg = t2), !!o4;
    }
    __name(handle, "handle");
    for (var o3 = this.tryEntries.length - 1; o3 >= 0; --o3) {
      var i3 = this.tryEntries[o3], a3 = i3.completion;
      if ("root" === i3.tryLoc) return handle("end");
      if (i3.tryLoc <= this.prev) {
        var c3 = n2.call(i3, "catchLoc"), u3 = n2.call(i3, "finallyLoc");
        if (c3 && u3) {
          if (this.prev < i3.catchLoc) return handle(i3.catchLoc, true);
          if (this.prev < i3.finallyLoc) return handle(i3.finallyLoc);
        } else if (c3) {
          if (this.prev < i3.catchLoc) return handle(i3.catchLoc, true);
        } else {
          if (!u3) throw Error("try statement without catch or finally");
          if (this.prev < i3.finallyLoc) return handle(i3.finallyLoc);
        }
      }
    }
  }, "dispatchException"), abrupt: /* @__PURE__ */ __name(function abrupt(t3, e3) {
    for (var r3 = this.tryEntries.length - 1; r3 >= 0; --r3) {
      var o3 = this.tryEntries[r3];
      if (o3.tryLoc <= this.prev && n2.call(o3, "finallyLoc") && this.prev < o3.finallyLoc) {
        var i3 = o3;
        break;
      }
    }
    i3 && ("break" === t3 || "continue" === t3) && i3.tryLoc <= e3 && e3 <= i3.finallyLoc && (i3 = null);
    var a3 = i3 ? i3.completion : {};
    return a3.type = t3, a3.arg = e3, i3 ? (this.method = "next", this.next = i3.finallyLoc, y2) : this.complete(a3);
  }, "abrupt"), complete: /* @__PURE__ */ __name(function complete(t3, e3) {
    if ("throw" === t3.type) throw t3.arg;
    return "break" === t3.type || "continue" === t3.type ? this.next = t3.arg : "return" === t3.type ? (this.rval = this.arg = t3.arg, this.method = "return", this.next = "end") : "normal" === t3.type && e3 && (this.next = e3), y2;
  }, "complete"), finish: /* @__PURE__ */ __name(function finish(t3) {
    for (var e3 = this.tryEntries.length - 1; e3 >= 0; --e3) {
      var r3 = this.tryEntries[e3];
      if (r3.finallyLoc === t3) return this.complete(r3.completion, r3.afterLoc), resetTryEntry(r3), y2;
    }
  }, "finish"), "catch": /* @__PURE__ */ __name(function _catch(t3) {
    for (var e3 = this.tryEntries.length - 1; e3 >= 0; --e3) {
      var r3 = this.tryEntries[e3];
      if (r3.tryLoc === t3) {
        var n3 = r3.completion;
        if ("throw" === n3.type) {
          var o3 = n3.arg;
          resetTryEntry(r3);
        }
        return o3;
      }
    }
    throw Error("illegal catch attempt");
  }, "_catch"), delegateYield: /* @__PURE__ */ __name(function delegateYield(e3, r3, n3) {
    return this.delegate = { iterator: values(e3), resultName: r3, nextLoc: n3 }, "next" === this.method && (this.arg = t2), y2;
  }, "delegateYield") }, e2;
}
__name(_regeneratorRuntime, "_regeneratorRuntime");
function asyncGeneratorStep(n2, t2, e2, r2, o2, a2, c2) {
  try {
    var i2 = n2[a2](c2), u2 = i2.value;
  } catch (n3) {
    return void e2(n3);
  }
  i2.done ? t2(u2) : Promise.resolve(u2).then(r2, o2);
}
__name(asyncGeneratorStep, "asyncGeneratorStep");
function _asyncToGenerator(n2) {
  return function() {
    var t2 = this, e2 = arguments;
    return new Promise(function(r2, o2) {
      var a2 = n2.apply(t2, e2);
      function _next(n3) {
        asyncGeneratorStep(a2, r2, o2, _next, _throw, "next", n3);
      }
      __name(_next, "_next");
      function _throw(n3) {
        asyncGeneratorStep(a2, r2, o2, _next, _throw, "throw", n3);
      }
      __name(_throw, "_throw");
      _next(void 0);
    });
  };
}
__name(_asyncToGenerator, "_asyncToGenerator");
function tryOnMounted$1(fn) {
  var sync = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
  if (getCurrentInstance()) onMounted(fn);
  else if (sync) fn();
  else nextTick(fn);
}
__name(tryOnMounted$1, "tryOnMounted$1");
var useForm = /* @__PURE__ */ __name(function useForm2() {
  var options5 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
  var states = reactive({});
  var fields = reactive({});
  var valid = computed(function() {
    return Object.values(states).every(function(field2) {
      return !field2.invalid;
    });
  });
  var getInitialState = /* @__PURE__ */ __name(function getInitialState2(field2, initialValue) {
    var _options$initialValue;
    return {
      value: initialValue !== null && initialValue !== void 0 ? initialValue : (_options$initialValue = options5.initialValues) === null || _options$initialValue === void 0 ? void 0 : _options$initialValue[field2],
      touched: false,
      dirty: false,
      pristine: true,
      valid: true,
      invalid: false,
      error: null,
      errors: []
    };
  }, "getInitialState");
  var isFieldValidate = /* @__PURE__ */ __name(function isFieldValidate2(field2, validateOn2) {
    var value3 = resolve$1(validateOn2, field2);
    return value3 === true || isArray$7(value3) && value3.includes(field2);
  }, "isFieldValidate");
  var validateOn = /* @__PURE__ */ function() {
    var _ref = _asyncToGenerator(/* @__PURE__ */ _regeneratorRuntime().mark(/* @__PURE__ */ __name(function _callee(option5, defaultValue2) {
      var _options$option;
      var results, fieldArr;
      return _regeneratorRuntime().wrap(/* @__PURE__ */ __name(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            results = {};
            if (!isArray$7(options5[option5])) {
              _context.next = 7;
              break;
            }
            _context.next = 4;
            return validate(options5[option5]);
          case 4:
            results = _context.sent;
            _context.next = 12;
            break;
          case 7:
            _context.t0 = (_options$option = options5[option5]) !== null && _options$option !== void 0 ? _options$option : defaultValue2;
            if (!_context.t0) {
              _context.next = 12;
              break;
            }
            _context.next = 11;
            return validate();
          case 11:
            results = _context.sent;
          case 12:
            fieldArr = Object.keys(fields).filter(function(field2) {
              var _fields$field;
              return (_fields$field = fields[field2]) === null || _fields$field === void 0 || (_fields$field = _fields$field.options) === null || _fields$field === void 0 ? void 0 : _fields$field[option5];
            }) || [];
            _context.t1 = isNotEmpty$1(fieldArr);
            if (!_context.t1) {
              _context.next = 18;
              break;
            }
            _context.next = 17;
            return validate(fieldArr);
          case 17:
            results = _context.sent;
          case 18:
            return _context.abrupt("return", results);
          case 19:
          case "end":
            return _context.stop();
        }
      }, "_callee$"), _callee);
    }, "_callee")));
    return /* @__PURE__ */ __name(function validateOn2(_x, _x2) {
      return _ref.apply(this, arguments);
    }, "validateOn");
  }();
  var validateFieldOn = /* @__PURE__ */ __name(function validateFieldOn2(field2, fieldOptions, option5, defaultValue2) {
    var _fieldOptions$option, _options$option2;
    ((_fieldOptions$option = fieldOptions === null || fieldOptions === void 0 ? void 0 : fieldOptions[option5]) !== null && _fieldOptions$option !== void 0 ? _fieldOptions$option : isFieldValidate(field2, (_options$option2 = options5[option5]) !== null && _options$option2 !== void 0 ? _options$option2 : defaultValue2)) && validate(field2);
  }, "validateFieldOn");
  var defineField = /* @__PURE__ */ __name(function defineField2(field2, fieldOptions) {
    var _resolve;
    states[field2] || (states[field2] = getInitialState(field2, fieldOptions === null || fieldOptions === void 0 ? void 0 : fieldOptions.initialValue));
    var props = mergeProps$2((_resolve = resolve$1(fieldOptions, states[field2])) === null || _resolve === void 0 ? void 0 : _resolve.props, resolve$1(fieldOptions === null || fieldOptions === void 0 ? void 0 : fieldOptions.props, states[field2]), {
      name: field2,
      onBlur: /* @__PURE__ */ __name(function onBlur12() {
        states[field2].touched = true;
        validateFieldOn(field2, fieldOptions, "validateOnBlur");
      }, "onBlur"),
      onInput: /* @__PURE__ */ __name(function onInput4(event) {
        states[field2].value = event.hasOwnProperty("value") ? event.value : event.target.value;
      }, "onInput"),
      onChange: /* @__PURE__ */ __name(function onChange6(event) {
        states[field2].value = event.hasOwnProperty("value") ? event.value : event.target.type === "checkbox" || event.target.type === "radio" ? event.target.checked : event.target.value;
      }, "onChange"),
      onInvalid: /* @__PURE__ */ __name(function onInvalid(errors2) {
        var _errors$;
        states[field2].invalid = true;
        states[field2].errors = errors2;
        states[field2].error = (_errors$ = errors2 === null || errors2 === void 0 ? void 0 : errors2[0]) !== null && _errors$ !== void 0 ? _errors$ : null;
      }, "onInvalid")
    });
    fields[field2] = {
      props,
      states: states[field2],
      options: fieldOptions
    };
    watch(function() {
      return states[field2].value;
    }, function(newValue2, oldValue) {
      if (states[field2].pristine) {
        states[field2].pristine = false;
      }
      if (newValue2 !== oldValue) {
        states[field2].dirty = true;
      }
      validateFieldOn(field2, fieldOptions, "validateOnValueUpdate", true);
    });
    return [states[field2], props];
  }, "defineField");
  var handleSubmit = /* @__PURE__ */ __name(function handleSubmit2(callback) {
    return /* @__PURE__ */ function() {
      var _ref2 = _asyncToGenerator(/* @__PURE__ */ _regeneratorRuntime().mark(/* @__PURE__ */ __name(function _callee2(event) {
        var results;
        return _regeneratorRuntime().wrap(/* @__PURE__ */ __name(function _callee2$(_context2) {
          while (1) switch (_context2.prev = _context2.next) {
            case 0:
              _context2.next = 2;
              return validateOn("validateOnSubmit", true);
            case 2:
              results = _context2.sent;
              return _context2.abrupt("return", callback(_objectSpread$j({
                originalEvent: event,
                valid: toValue$4(valid),
                states: toValue$4(states),
                reset: reset2
              }, results)));
            case 4:
            case "end":
              return _context2.stop();
          }
        }, "_callee2$"), _callee2);
      }, "_callee2")));
      return function(_x3) {
        return _ref2.apply(this, arguments);
      };
    }();
  }, "handleSubmit");
  var validate = /* @__PURE__ */ function() {
    var _ref3 = _asyncToGenerator(/* @__PURE__ */ _regeneratorRuntime().mark(/* @__PURE__ */ __name(function _callee3(field2) {
      var _yield$options$resolv, _options$resolver, _result, _result$errors;
      var resolverOptions, result, flattenFields, _i, _Object$entries, _Object$entries$_i, fieldName, fieldInst, _fieldInst$options, _result$errors$fieldN, _errors$2, fieldResolver, _yield$fieldResolver, fieldValue, fieldResult, errors2;
      return _regeneratorRuntime().wrap(/* @__PURE__ */ __name(function _callee3$(_context3) {
        while (1) switch (_context3.prev = _context3.next) {
          case 0:
            resolverOptions = Object.entries(states).reduce(function(acc, _ref4) {
              var _ref5 = _slicedToArray$4(_ref4, 2), key = _ref5[0], val = _ref5[1];
              acc.names.push(key);
              acc.values[key] = val.value;
              return acc;
            }, {
              names: [],
              values: {}
            });
            _context3.next = 3;
            return (_options$resolver = options5.resolver) === null || _options$resolver === void 0 ? void 0 : _options$resolver.call(options5, resolverOptions);
          case 3:
            _context3.t1 = _yield$options$resolv = _context3.sent;
            _context3.t0 = _context3.t1 !== null;
            if (!_context3.t0) {
              _context3.next = 7;
              break;
            }
            _context3.t0 = _yield$options$resolv !== void 0;
          case 7:
            if (!_context3.t0) {
              _context3.next = 11;
              break;
            }
            _context3.t2 = _yield$options$resolv;
            _context3.next = 12;
            break;
          case 11:
            _context3.t2 = {};
          case 12:
            result = _context3.t2;
            (_result$errors = (_result = result).errors) !== null && _result$errors !== void 0 ? _result$errors : _result.errors = {};
            flattenFields = [field2].flat();
            _i = 0, _Object$entries = Object.entries(fields);
          case 16:
            if (!(_i < _Object$entries.length)) {
              _context3.next = 44;
              break;
            }
            _Object$entries$_i = _slicedToArray$4(_Object$entries[_i], 2), fieldName = _Object$entries$_i[0], fieldInst = _Object$entries$_i[1];
            if (!(flattenFields.includes(fieldName) || !field2)) {
              _context3.next = 41;
              break;
            }
            fieldResolver = (_fieldInst$options = fieldInst.options) === null || _fieldInst$options === void 0 ? void 0 : _fieldInst$options.resolver;
            if (!fieldResolver) {
              _context3.next = 36;
              break;
            }
            fieldValue = fieldInst.states.value;
            _context3.next = 24;
            return fieldResolver({
              values: fieldValue,
              value: fieldValue,
              name: fieldName
            });
          case 24:
            _context3.t4 = _yield$fieldResolver = _context3.sent;
            _context3.t3 = _context3.t4 !== null;
            if (!_context3.t3) {
              _context3.next = 28;
              break;
            }
            _context3.t3 = _yield$fieldResolver !== void 0;
          case 28:
            if (!_context3.t3) {
              _context3.next = 32;
              break;
            }
            _context3.t5 = _yield$fieldResolver;
            _context3.next = 33;
            break;
          case 32:
            _context3.t5 = {};
          case 33:
            fieldResult = _context3.t5;
            isArray$7(fieldResult.errors) && (fieldResult.errors = _defineProperty$j({}, fieldName, fieldResult.errors));
            result = mergeKeys$1(result, fieldResult);
          case 36:
            errors2 = (_result$errors$fieldN = result.errors[fieldName]) !== null && _result$errors$fieldN !== void 0 ? _result$errors$fieldN : [];
            states[fieldName].invalid = errors2.length > 0;
            states[fieldName].valid = !states[fieldName].invalid;
            states[fieldName].errors = errors2;
            states[fieldName].error = (_errors$2 = errors2 === null || errors2 === void 0 ? void 0 : errors2[0]) !== null && _errors$2 !== void 0 ? _errors$2 : null;
          case 41:
            _i++;
            _context3.next = 16;
            break;
          case 44:
            return _context3.abrupt("return", result);
          case 45:
          case "end":
            return _context3.stop();
        }
      }, "_callee3$"), _callee3);
    }, "_callee3")));
    return /* @__PURE__ */ __name(function validate2(_x4) {
      return _ref3.apply(this, arguments);
    }, "validate");
  }();
  var reset2 = /* @__PURE__ */ __name(function reset3() {
    Object.keys(states).forEach(function(field2) {
      var _fields$field2;
      return fields[field2].states = states[field2] = getInitialState(field2, (_fields$field2 = fields[field2]) === null || _fields$field2 === void 0 || (_fields$field2 = _fields$field2.options) === null || _fields$field2 === void 0 ? void 0 : _fields$field2.initialValue);
    });
  }, "reset");
  var validateOnMounted = /* @__PURE__ */ __name(function validateOnMounted2() {
    validateOn("validateOnMount");
  }, "validateOnMounted");
  tryOnMounted$1(validateOnMounted);
  return {
    defineField,
    handleSubmit,
    validate,
    reset: reset2,
    valid,
    states,
    fields
  };
}, "useForm");
var __defProp$2 = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$1 = Object.getOwnPropertySymbols;
var __hasOwnProp$1 = Object.prototype.hasOwnProperty;
var __propIsEnum$1 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$2 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$2(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$2");
var __spreadValues$1 = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp$1.call(b2, prop2))
      __defNormalProp$2(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols$1)
    for (var prop2 of __getOwnPropSymbols$1(b2)) {
      if (__propIsEnum$1.call(b2, prop2))
        __defNormalProp$2(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues$1");
var __spreadProps = /* @__PURE__ */ __name((a2, b2) => __defProps(a2, __getOwnPropDescs(b2)), "__spreadProps");
var __objRest = /* @__PURE__ */ __name((source, exclude) => {
  var target2 = {};
  for (var prop2 in source)
    if (__hasOwnProp$1.call(source, prop2) && exclude.indexOf(prop2) < 0)
      target2[prop2] = source[prop2];
  if (source != null && __getOwnPropSymbols$1)
    for (var prop2 of __getOwnPropSymbols$1(source)) {
      if (exclude.indexOf(prop2) < 0 && __propIsEnum$1.call(source, prop2))
        target2[prop2] = source[prop2];
    }
  return target2;
}, "__objRest");
function definePreset(...presets) {
  return mergeKeys$1(...presets);
}
__name(definePreset, "definePreset");
var ThemeService = EventBus();
var service_default = ThemeService;
function toTokenKey$1(str) {
  return isString$5(str) ? str.replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "." + c2.toLowerCase()).toLowerCase() : str;
}
__name(toTokenKey$1, "toTokenKey$1");
function merge(value1, value22) {
  if (isArray$7(value1)) {
    value1.push(...value22 || []);
  } else if (isObject$a(value1)) {
    Object.assign(value1, value22);
  }
}
__name(merge, "merge");
function toValue$1(value3) {
  return isObject$a(value3) && value3.hasOwnProperty("value") && value3.hasOwnProperty("type") ? value3.value : value3;
}
__name(toValue$1, "toValue$1");
function toUnit(value3, variable = "") {
  const excludedProperties = ["opacity", "z-index", "line-height", "font-weight", "flex", "flex-grow", "flex-shrink", "order"];
  if (!excludedProperties.some((property) => variable.endsWith(property))) {
    const val = `${value3}`.trim();
    const valArr = val.split(" ");
    return valArr.map((v2) => isNumber$4(v2) ? `${v2}px` : v2).join(" ");
  }
  return value3;
}
__name(toUnit, "toUnit");
function toNormalizePrefix(prefix2) {
  return prefix2.replaceAll(/ /g, "").replace(/[^\w]/g, "-");
}
__name(toNormalizePrefix, "toNormalizePrefix");
function toNormalizeVariable(prefix2 = "", variable = "") {
  return toNormalizePrefix(`${isString$5(prefix2, false) && isString$5(variable, false) ? `${prefix2}-` : prefix2}${variable}`);
}
__name(toNormalizeVariable, "toNormalizeVariable");
function getVariableName(prefix2 = "", variable = "") {
  return `--${toNormalizeVariable(prefix2, variable)}`;
}
__name(getVariableName, "getVariableName");
function hasOddBraces(str = "") {
  const openBraces = (str.match(/{/g) || []).length;
  const closeBraces = (str.match(/}/g) || []).length;
  return (openBraces + closeBraces) % 2 !== 0;
}
__name(hasOddBraces, "hasOddBraces");
function getVariableValue(value3, variable = "", prefix2 = "", excludedKeyRegexes = [], fallback) {
  if (isString$5(value3)) {
    const regex2 = /{([^}]*)}/g;
    const val = value3.trim();
    if (hasOddBraces(val)) {
      return void 0;
    } else if (matchRegex$1(val, regex2)) {
      const _val = val.replaceAll(regex2, (v2) => {
        const path = v2.replace(/{|}/g, "");
        const keys2 = path.split(".").filter((_v) => !excludedKeyRegexes.some((_r) => matchRegex$1(_v, _r)));
        return `var(${getVariableName(prefix2, toKebabCase$1(keys2.join("-")))}${isNotEmpty$1(fallback) ? `, ${fallback}` : ""})`;
      });
      const calculationRegex = /(\d+\s+[\+\-\*\/]\s+\d+)/g;
      const cleanedVarRegex = /var\([^)]+\)/g;
      return matchRegex$1(_val.replace(cleanedVarRegex, "0"), calculationRegex) ? `calc(${_val})` : _val;
    }
    return val;
  } else if (isNumber$4(value3)) {
    return value3;
  }
  return void 0;
}
__name(getVariableValue, "getVariableValue");
function getComputedValue(obj = {}, value3) {
  if (isString$5(value3)) {
    const regex2 = /{([^}]*)}/g;
    const val = value3.trim();
    return matchRegex$1(val, regex2) ? val.replaceAll(regex2, (v2) => getKeyValue$1(obj, v2.replace(/{|}/g, ""))) : val;
  } else if (isNumber$4(value3)) {
    return value3;
  }
  return void 0;
}
__name(getComputedValue, "getComputedValue");
function setProperty(properties, key, value3) {
  if (isString$5(key, false)) {
    properties.push(`${key}:${value3};`);
  }
}
__name(setProperty, "setProperty");
function getRule(selector, properties) {
  if (selector) {
    return `${selector}{${properties}}`;
  }
  return "";
}
__name(getRule, "getRule");
function normalizeColor(color2) {
  if (color2.length === 4) {
    return `#${color2[1]}${color2[1]}${color2[2]}${color2[2]}${color2[3]}${color2[3]}`;
  }
  return color2;
}
__name(normalizeColor, "normalizeColor");
function hexToRgb$1(hex) {
  var bigint = parseInt(hex.substring(1), 16);
  var r2 = bigint >> 16 & 255;
  var g2 = bigint >> 8 & 255;
  var b2 = bigint & 255;
  return { r: r2, g: g2, b: b2 };
}
__name(hexToRgb$1, "hexToRgb$1");
function rgbToHex(r2, g2, b2) {
  return `#${r2.toString(16).padStart(2, "0")}${g2.toString(16).padStart(2, "0")}${b2.toString(16).padStart(2, "0")}`;
}
__name(rgbToHex, "rgbToHex");
var mix_default = /* @__PURE__ */ __name((color1, color2, weight) => {
  color1 = normalizeColor(color1);
  color2 = normalizeColor(color2);
  var p2 = weight / 100;
  var w2 = p2 * 2 - 1;
  var w1 = (w2 + 1) / 2;
  var w22 = 1 - w1;
  var rgb1 = hexToRgb$1(color1);
  var rgb2 = hexToRgb$1(color2);
  var r2 = Math.round(rgb1.r * w1 + rgb2.r * w22);
  var g2 = Math.round(rgb1.g * w1 + rgb2.g * w22);
  var b2 = Math.round(rgb1.b * w1 + rgb2.b * w22);
  return rgbToHex(r2, g2, b2);
}, "mix_default");
var shade_default = /* @__PURE__ */ __name((color2, percent) => mix_default("#000000", color2, percent), "shade_default");
var tint_default = /* @__PURE__ */ __name((color2, percent) => mix_default("#ffffff", color2, percent), "tint_default");
var scales = [50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 950];
var palette_default = /* @__PURE__ */ __name((color2) => {
  if (/{([^}]*)}/g.test(color2)) {
    const token = color2.replace(/{|}/g, "");
    return scales.reduce((acc, scale) => (acc[scale] = `{${token}.${scale}}`, acc), {});
  }
  return typeof color2 === "string" ? scales.reduce((acc, scale, i2) => (acc[scale] = i2 <= 5 ? tint_default(color2, (5 - i2) * 19) : shade_default(color2, (i2 - 5) * 15), acc), {}) : color2;
}, "palette_default");
var $dt = /* @__PURE__ */ __name((tokenPath) => {
  var _a2;
  const theme47 = config_default.getTheme();
  const variable = dtwt(theme47, tokenPath, void 0, "variable");
  const name2 = (_a2 = variable == null ? void 0 : variable.match(/--[\w-]+/g)) == null ? void 0 : _a2[0];
  const value3 = dtwt(theme47, tokenPath, void 0, "value");
  return {
    name: name2,
    variable,
    value: value3
  };
}, "$dt");
var dt = /* @__PURE__ */ __name((...args) => {
  return dtwt(config_default.getTheme(), ...args);
}, "dt");
var dtwt = /* @__PURE__ */ __name((theme47 = {}, tokenPath, fallback, type) => {
  if (tokenPath) {
    const { variable: VARIABLE, options: OPTIONS } = config_default.defaults || {};
    const { prefix: prefix2, transform: transform2 } = (theme47 == null ? void 0 : theme47.options) || OPTIONS || {};
    const regex2 = /{([^}]*)}/g;
    const token = matchRegex$1(tokenPath, regex2) ? tokenPath : `{${tokenPath}}`;
    const isStrictTransform = type === "value" || isEmpty$2(type) && transform2 === "strict";
    return isStrictTransform ? config_default.getTokenValue(tokenPath) : getVariableValue(token, void 0, prefix2, [VARIABLE.excludedKeyRegex], fallback);
  }
  return "";
}, "dtwt");
function css$2(style2) {
  return resolve$1(style2, { dt });
}
__name(css$2, "css$2");
var $t = /* @__PURE__ */ __name((theme47 = {}) => {
  let { preset: _preset, options: _options } = theme47;
  return {
    preset(value3) {
      _preset = _preset ? mergeKeys$1(_preset, value3) : value3;
      return this;
    },
    options(value3) {
      _options = _options ? __spreadValues$1(__spreadValues$1({}, _options), value3) : value3;
      return this;
    },
    // features
    primaryPalette(primary) {
      const { semantic } = _preset || {};
      _preset = __spreadProps(__spreadValues$1({}, _preset), { semantic: __spreadProps(__spreadValues$1({}, semantic), { primary }) });
      return this;
    },
    surfacePalette(surface) {
      var _a2, _b;
      const { semantic } = _preset || {};
      const lightSurface = (surface == null ? void 0 : surface.hasOwnProperty("light")) ? surface == null ? void 0 : surface.light : surface;
      const darkSurface = (surface == null ? void 0 : surface.hasOwnProperty("dark")) ? surface == null ? void 0 : surface.dark : surface;
      const newColorScheme = {
        colorScheme: {
          light: __spreadValues$1(__spreadValues$1({}, (_a2 = semantic == null ? void 0 : semantic.colorScheme) == null ? void 0 : _a2.light), !!lightSurface && { surface: lightSurface }),
          dark: __spreadValues$1(__spreadValues$1({}, (_b = semantic == null ? void 0 : semantic.colorScheme) == null ? void 0 : _b.dark), !!darkSurface && { surface: darkSurface })
        }
      };
      _preset = __spreadProps(__spreadValues$1({}, _preset), { semantic: __spreadValues$1(__spreadValues$1({}, semantic), newColorScheme) });
      return this;
    },
    // actions
    define({ useDefaultPreset = false, useDefaultOptions = false } = {}) {
      return {
        preset: useDefaultPreset ? config_default.getPreset() : _preset,
        options: useDefaultOptions ? config_default.getOptions() : _options
      };
    },
    update({ mergePresets = true, mergeOptions: mergeOptions2 = true } = {}) {
      const newTheme = {
        preset: mergePresets ? mergeKeys$1(config_default.getPreset(), _preset) : _preset,
        options: mergeOptions2 ? __spreadValues$1(__spreadValues$1({}, config_default.getOptions()), _options) : _options
      };
      config_default.setTheme(newTheme);
      return newTheme;
    },
    use(options5) {
      const newTheme = this.define(options5);
      config_default.setTheme(newTheme);
      return newTheme;
    }
  };
}, "$t");
function toVariables_default(theme47, options5 = {}) {
  const VARIABLE = config_default.defaults.variable;
  const { prefix: prefix2 = VARIABLE.prefix, selector = VARIABLE.selector, excludedKeyRegex = VARIABLE.excludedKeyRegex } = options5;
  const _toVariables = /* @__PURE__ */ __name((_theme, _prefix = "") => {
    return Object.entries(_theme).reduce(
      (acc, [key, value3]) => {
        const px = matchRegex$1(key, excludedKeyRegex) ? toNormalizeVariable(_prefix) : toNormalizeVariable(_prefix, toKebabCase$1(key));
        const v2 = toValue$1(value3);
        if (isObject$a(v2)) {
          const { variables: variables2, tokens: tokens2 } = _toVariables(v2, px);
          merge(acc["tokens"], tokens2);
          merge(acc["variables"], variables2);
        } else {
          acc["tokens"].push((prefix2 ? px.replace(`${prefix2}-`, "") : px).replaceAll("-", "."));
          setProperty(acc["variables"], getVariableName(px), getVariableValue(v2, px, prefix2, [excludedKeyRegex]));
        }
        return acc;
      },
      { variables: [], tokens: [] }
    );
  }, "_toVariables");
  const { variables, tokens } = _toVariables(theme47, prefix2);
  return {
    value: variables,
    tokens,
    declarations: variables.join(""),
    css: getRule(selector, variables.join(""))
  };
}
__name(toVariables_default, "toVariables_default");
var themeUtils_default = {
  regex: {
    rules: {
      class: {
        pattern: /^\.([a-zA-Z][\w-]*)$/,
        resolve(value3) {
          return { type: "class", selector: value3, matched: this.pattern.test(value3.trim()) };
        }
      },
      attr: {
        pattern: /^\[(.*)\]$/,
        resolve(value3) {
          return { type: "attr", selector: `:root${value3}`, matched: this.pattern.test(value3.trim()) };
        }
      },
      media: {
        pattern: /^@media (.*)$/,
        resolve(value3) {
          return { type: "media", selector: `${value3}{:root{[CSS]}}`, matched: this.pattern.test(value3.trim()) };
        }
      },
      system: {
        pattern: /^system$/,
        resolve(value3) {
          return { type: "system", selector: "@media (prefers-color-scheme: dark){:root{[CSS]}}", matched: this.pattern.test(value3.trim()) };
        }
      },
      custom: {
        resolve(value3) {
          return { type: "custom", selector: value3, matched: true };
        }
      }
    },
    resolve(value3) {
      const rules = Object.keys(this.rules).filter((k2) => k2 !== "custom").map((r2) => this.rules[r2]);
      return [value3].flat().map((v2) => {
        var _a2;
        return (_a2 = rules.map((r2) => r2.resolve(v2)).find((rr) => rr.matched)) != null ? _a2 : this.rules.custom.resolve(v2);
      });
    }
  },
  _toVariables(theme47, options5) {
    return toVariables_default(theme47, { prefix: options5 == null ? void 0 : options5.prefix });
  },
  getCommon({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _e, _f, _g, _h, _i, _j, _k;
    const { preset, options: options5 } = theme47;
    let primitive_css, primitive_tokens, semantic_css, semantic_tokens, global_css, global_tokens, style2;
    if (isNotEmpty$1(preset) && options5.transform !== "strict") {
      const { primitive, semantic, extend: extend5 } = preset;
      const _a2 = semantic || {}, { colorScheme } = _a2, sRest = __objRest(_a2, ["colorScheme"]);
      const _b = extend5 || {}, { colorScheme: eColorScheme } = _b, eRest = __objRest(_b, ["colorScheme"]);
      const _c = colorScheme || {}, { dark: dark2 } = _c, csRest = __objRest(_c, ["dark"]);
      const _d = eColorScheme || {}, { dark: eDark } = _d, ecsRest = __objRest(_d, ["dark"]);
      const prim_var = isNotEmpty$1(primitive) ? this._toVariables({ primitive }, options5) : {};
      const sRest_var = isNotEmpty$1(sRest) ? this._toVariables({ semantic: sRest }, options5) : {};
      const csRest_var = isNotEmpty$1(csRest) ? this._toVariables({ light: csRest }, options5) : {};
      const csDark_var = isNotEmpty$1(dark2) ? this._toVariables({ dark: dark2 }, options5) : {};
      const eRest_var = isNotEmpty$1(eRest) ? this._toVariables({ semantic: eRest }, options5) : {};
      const ecsRest_var = isNotEmpty$1(ecsRest) ? this._toVariables({ light: ecsRest }, options5) : {};
      const ecsDark_var = isNotEmpty$1(eDark) ? this._toVariables({ dark: eDark }, options5) : {};
      const [prim_css, prim_tokens] = [(_e = prim_var.declarations) != null ? _e : "", prim_var.tokens];
      const [sRest_css, sRest_tokens] = [(_f = sRest_var.declarations) != null ? _f : "", sRest_var.tokens || []];
      const [csRest_css, csRest_tokens] = [(_g = csRest_var.declarations) != null ? _g : "", csRest_var.tokens || []];
      const [csDark_css, csDark_tokens] = [(_h = csDark_var.declarations) != null ? _h : "", csDark_var.tokens || []];
      const [eRest_css, eRest_tokens] = [(_i = eRest_var.declarations) != null ? _i : "", eRest_var.tokens || []];
      const [ecsRest_css, ecsRest_tokens] = [(_j = ecsRest_var.declarations) != null ? _j : "", ecsRest_var.tokens || []];
      const [ecsDark_css, ecsDark_tokens] = [(_k = ecsDark_var.declarations) != null ? _k : "", ecsDark_var.tokens || []];
      primitive_css = this.transformCSS(name2, prim_css, "light", "variable", options5, set3, defaults2);
      primitive_tokens = prim_tokens;
      const semantic_light_css = this.transformCSS(name2, `${sRest_css}${csRest_css}`, "light", "variable", options5, set3, defaults2);
      const semantic_dark_css = this.transformCSS(name2, `${csDark_css}`, "dark", "variable", options5, set3, defaults2);
      semantic_css = `${semantic_light_css}${semantic_dark_css}`;
      semantic_tokens = [.../* @__PURE__ */ new Set([...sRest_tokens, ...csRest_tokens, ...csDark_tokens])];
      const global_light_css = this.transformCSS(name2, `${eRest_css}${ecsRest_css}color-scheme:light`, "light", "variable", options5, set3, defaults2);
      const global_dark_css = this.transformCSS(name2, `${ecsDark_css}color-scheme:dark`, "dark", "variable", options5, set3, defaults2);
      global_css = `${global_light_css}${global_dark_css}`;
      global_tokens = [.../* @__PURE__ */ new Set([...eRest_tokens, ...ecsRest_tokens, ...ecsDark_tokens])];
      style2 = resolve$1(preset.css, { dt });
    }
    return {
      primitive: {
        css: primitive_css,
        tokens: primitive_tokens
      },
      semantic: {
        css: semantic_css,
        tokens: semantic_tokens
      },
      global: {
        css: global_css,
        tokens: global_tokens
      },
      style: style2
    };
  },
  getPreset({ name: name2 = "", preset = {}, options: options5, params, set: set3, defaults: defaults2, selector }) {
    var _e, _f, _g;
    let p_css, p_tokens, p_style;
    if (isNotEmpty$1(preset) && options5.transform !== "strict") {
      const _name = name2.replace("-directive", "");
      const _a2 = preset, { colorScheme, extend: extend5, css: css22 } = _a2, vRest = __objRest(_a2, ["colorScheme", "extend", "css"]);
      const _b = extend5 || {}, { colorScheme: eColorScheme } = _b, evRest = __objRest(_b, ["colorScheme"]);
      const _c = colorScheme || {}, { dark: dark2 } = _c, csRest = __objRest(_c, ["dark"]);
      const _d = eColorScheme || {}, { dark: ecsDark } = _d, ecsRest = __objRest(_d, ["dark"]);
      const vRest_var = isNotEmpty$1(vRest) ? this._toVariables({ [_name]: __spreadValues$1(__spreadValues$1({}, vRest), evRest) }, options5) : {};
      const csRest_var = isNotEmpty$1(csRest) ? this._toVariables({ [_name]: __spreadValues$1(__spreadValues$1({}, csRest), ecsRest) }, options5) : {};
      const csDark_var = isNotEmpty$1(dark2) ? this._toVariables({ [_name]: __spreadValues$1(__spreadValues$1({}, dark2), ecsDark) }, options5) : {};
      const [vRest_css, vRest_tokens] = [(_e = vRest_var.declarations) != null ? _e : "", vRest_var.tokens || []];
      const [csRest_css, csRest_tokens] = [(_f = csRest_var.declarations) != null ? _f : "", csRest_var.tokens || []];
      const [csDark_css, csDark_tokens] = [(_g = csDark_var.declarations) != null ? _g : "", csDark_var.tokens || []];
      const light_variable_css = this.transformCSS(_name, `${vRest_css}${csRest_css}`, "light", "variable", options5, set3, defaults2, selector);
      const dark_variable_css = this.transformCSS(_name, csDark_css, "dark", "variable", options5, set3, defaults2, selector);
      p_css = `${light_variable_css}${dark_variable_css}`;
      p_tokens = [.../* @__PURE__ */ new Set([...vRest_tokens, ...csRest_tokens, ...csDark_tokens])];
      p_style = resolve$1(css22, { dt });
    }
    return {
      css: p_css,
      tokens: p_tokens,
      style: p_style
    };
  },
  getPresetC({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _a2;
    const { preset, options: options5 } = theme47;
    const cPreset = (_a2 = preset == null ? void 0 : preset.components) == null ? void 0 : _a2[name2];
    return this.getPreset({ name: name2, preset: cPreset, options: options5, params, set: set3, defaults: defaults2 });
  },
  getPresetD({ name: name2 = "", theme: theme47 = {}, params, set: set3, defaults: defaults2 }) {
    var _a2;
    const dName = name2.replace("-directive", "");
    const { preset, options: options5 } = theme47;
    const dPreset = (_a2 = preset == null ? void 0 : preset.directives) == null ? void 0 : _a2[dName];
    return this.getPreset({ name: dName, preset: dPreset, options: options5, params, set: set3, defaults: defaults2 });
  },
  applyDarkColorScheme(options5) {
    return !(options5.darkModeSelector === "none" || options5.darkModeSelector === false);
  },
  getColorSchemeOption(options5, defaults2) {
    var _a2;
    return this.applyDarkColorScheme(options5) ? this.regex.resolve(options5.darkModeSelector === true ? defaults2.options.darkModeSelector : (_a2 = options5.darkModeSelector) != null ? _a2 : defaults2.options.darkModeSelector) : [];
  },
  getLayerOrder(name2, options5 = {}, params, defaults2) {
    const { cssLayer } = options5;
    if (cssLayer) {
      const order = resolve$1(cssLayer.order || "primeui", params);
      return `@layer ${order}`;
    }
    return "";
  },
  getCommonStyleSheet({ name: name2 = "", theme: theme47 = {}, params, props = {}, set: set3, defaults: defaults2 }) {
    const common = this.getCommon({ name: name2, theme: theme47, params, set: set3, defaults: defaults2 });
    const _props = Object.entries(props).reduce((acc, [k2, v2]) => acc.push(`${k2}="${v2}"`) && acc, []).join(" ");
    return Object.entries(common || {}).reduce((acc, [key, value3]) => {
      if (value3 == null ? void 0 : value3.css) {
        const _css = minifyCSS$1(value3 == null ? void 0 : value3.css);
        const id4 = `${key}-variables`;
        acc.push(`<style type="text/css" data-primevue-style-id="${id4}" ${_props}>${_css}</style>`);
      }
      return acc;
    }, []).join("");
  },
  getStyleSheet({ name: name2 = "", theme: theme47 = {}, params, props = {}, set: set3, defaults: defaults2 }) {
    var _a2;
    const options5 = { name: name2, theme: theme47, params, set: set3, defaults: defaults2 };
    const preset_css = (_a2 = name2.includes("-directive") ? this.getPresetD(options5) : this.getPresetC(options5)) == null ? void 0 : _a2.css;
    const _props = Object.entries(props).reduce((acc, [k2, v2]) => acc.push(`${k2}="${v2}"`) && acc, []).join(" ");
    return preset_css ? `<style type="text/css" data-primevue-style-id="${name2}-variables" ${_props}>${minifyCSS$1(preset_css)}</style>` : "";
  },
  createTokens(obj = {}, defaults2, parentKey = "", parentPath = "", tokens = {}) {
    Object.entries(obj).forEach(([key, value3]) => {
      const currentKey = matchRegex$1(key, defaults2.variable.excludedKeyRegex) ? parentKey : parentKey ? `${parentKey}.${toTokenKey$2(key)}` : toTokenKey$2(key);
      const currentPath = parentPath ? `${parentPath}.${key}` : key;
      if (isObject$a(value3)) {
        this.createTokens(value3, defaults2, currentKey, currentPath, tokens);
      } else {
        tokens[currentKey] || (tokens[currentKey] = {
          paths: [],
          computed(colorScheme, tokenPathMap = {}) {
            var _a2, _b;
            if (this.paths.length === 1) {
              return (_a2 = this.paths[0]) == null ? void 0 : _a2.computed(this.paths[0].scheme, tokenPathMap["binding"]);
            } else if (colorScheme && colorScheme !== "none") {
              return (_b = this.paths.find((p2) => p2.scheme === colorScheme)) == null ? void 0 : _b.computed(colorScheme, tokenPathMap["binding"]);
            }
            return this.paths.map((p2) => p2.computed(p2.scheme, tokenPathMap[p2.scheme]));
          }
        });
        tokens[currentKey].paths.push({
          path: currentPath,
          value: value3,
          scheme: currentPath.includes("colorScheme.light") ? "light" : currentPath.includes("colorScheme.dark") ? "dark" : "none",
          computed(colorScheme, tokenPathMap = {}) {
            const regex2 = /{([^}]*)}/g;
            let computedValue = value3;
            tokenPathMap["name"] = this.path;
            tokenPathMap["binding"] || (tokenPathMap["binding"] = {});
            if (matchRegex$1(value3, regex2)) {
              const val = value3.trim();
              const _val = val.replaceAll(regex2, (v2) => {
                var _a2;
                const path = v2.replace(/{|}/g, "");
                const computed2 = (_a2 = tokens[path]) == null ? void 0 : _a2.computed(colorScheme, tokenPathMap);
                return isArray$7(computed2) && computed2.length === 2 ? `light-dark(${computed2[0].value},${computed2[1].value})` : computed2 == null ? void 0 : computed2.value;
              });
              const calculationRegex = /(\d+\w*\s+[\+\-\*\/]\s+\d+\w*)/g;
              const cleanedVarRegex = /var\([^)]+\)/g;
              computedValue = matchRegex$1(_val.replace(cleanedVarRegex, "0"), calculationRegex) ? `calc(${_val})` : _val;
            }
            isEmpty$2(tokenPathMap["binding"]) && delete tokenPathMap["binding"];
            return {
              colorScheme,
              path: this.path,
              paths: tokenPathMap,
              value: computedValue.includes("undefined") ? void 0 : computedValue
            };
          }
        });
      }
    });
    return tokens;
  },
  getTokenValue(tokens, path, defaults2) {
    var _a2;
    const normalizePath2 = /* @__PURE__ */ __name((str) => {
      const strArr = str.split(".");
      return strArr.filter((s2) => !matchRegex$1(s2.toLowerCase(), defaults2.variable.excludedKeyRegex)).join(".");
    }, "normalizePath");
    const token = normalizePath2(path);
    const colorScheme = path.includes("colorScheme.light") ? "light" : path.includes("colorScheme.dark") ? "dark" : void 0;
    const computedValues = [(_a2 = tokens[token]) == null ? void 0 : _a2.computed(colorScheme)].flat().filter((computed2) => computed2);
    return computedValues.length === 1 ? computedValues[0].value : computedValues.reduce((acc = {}, computed2) => {
      const _a22 = computed2, { colorScheme: cs } = _a22, rest = __objRest(_a22, ["colorScheme"]);
      acc[cs] = rest;
      return acc;
    }, void 0);
  },
  getSelectorRule(selector1, selector2, type, css22) {
    return type === "class" || type === "attr" ? getRule(isNotEmpty$1(selector2) ? `${selector1}${selector2},${selector1} ${selector2}` : selector1, css22) : getRule(selector1, isNotEmpty$1(selector2) ? getRule(selector2, css22) : css22);
  },
  transformCSS(name2, css22, mode2, type, options5 = {}, set3, defaults2, selector) {
    if (isNotEmpty$1(css22)) {
      const { cssLayer } = options5;
      if (type !== "style") {
        const colorSchemeOption = this.getColorSchemeOption(options5, defaults2);
        css22 = mode2 === "dark" ? colorSchemeOption.reduce((acc, { type: type2, selector: _selector }) => {
          if (isNotEmpty$1(_selector)) {
            acc += _selector.includes("[CSS]") ? _selector.replace("[CSS]", css22) : this.getSelectorRule(_selector, selector, type2, css22);
          }
          return acc;
        }, "") : getRule(selector != null ? selector : ":root", css22);
      }
      if (cssLayer) {
        const layerOptions = {
          name: "primeui",
          order: "primeui"
        };
        isObject$a(cssLayer) && (layerOptions.name = resolve$1(cssLayer.name, { name: name2, type }));
        if (isNotEmpty$1(layerOptions.name)) {
          css22 = getRule(`@layer ${layerOptions.name}`, css22);
          set3 == null ? void 0 : set3.layerNames(layerOptions.name);
        }
      }
      return css22;
    }
    return "";
  }
};
var config_default = {
  defaults: {
    variable: {
      prefix: "p",
      selector: ":root",
      excludedKeyRegex: /^(primitive|semantic|components|directives|variables|colorscheme|light|dark|common|root|states|extend|css)$/gi
    },
    options: {
      prefix: "p",
      darkModeSelector: "system",
      cssLayer: false
    }
  },
  _theme: void 0,
  _layerNames: /* @__PURE__ */ new Set(),
  _loadedStyleNames: /* @__PURE__ */ new Set(),
  _loadingStyles: /* @__PURE__ */ new Set(),
  _tokens: {},
  update(newValues = {}) {
    const { theme: theme47 } = newValues;
    if (theme47) {
      this._theme = __spreadProps(__spreadValues$1({}, theme47), {
        options: __spreadValues$1(__spreadValues$1({}, this.defaults.options), theme47.options)
      });
      this._tokens = themeUtils_default.createTokens(this.preset, this.defaults);
      this.clearLoadedStyleNames();
    }
  },
  get theme() {
    return this._theme;
  },
  get preset() {
    var _a2;
    return ((_a2 = this.theme) == null ? void 0 : _a2.preset) || {};
  },
  get options() {
    var _a2;
    return ((_a2 = this.theme) == null ? void 0 : _a2.options) || {};
  },
  get tokens() {
    return this._tokens;
  },
  getTheme() {
    return this.theme;
  },
  setTheme(newValue2) {
    this.update({ theme: newValue2 });
    service_default.emit("theme:change", newValue2);
  },
  getPreset() {
    return this.preset;
  },
  setPreset(newValue2) {
    this._theme = __spreadProps(__spreadValues$1({}, this.theme), { preset: newValue2 });
    this._tokens = themeUtils_default.createTokens(newValue2, this.defaults);
    this.clearLoadedStyleNames();
    service_default.emit("preset:change", newValue2);
    service_default.emit("theme:change", this.theme);
  },
  getOptions() {
    return this.options;
  },
  setOptions(newValue2) {
    this._theme = __spreadProps(__spreadValues$1({}, this.theme), { options: newValue2 });
    this.clearLoadedStyleNames();
    service_default.emit("options:change", newValue2);
    service_default.emit("theme:change", this.theme);
  },
  getLayerNames() {
    return [...this._layerNames];
  },
  setLayerNames(layerName) {
    this._layerNames.add(layerName);
  },
  getLoadedStyleNames() {
    return this._loadedStyleNames;
  },
  isStyleNameLoaded(name2) {
    return this._loadedStyleNames.has(name2);
  },
  setLoadedStyleName(name2) {
    this._loadedStyleNames.add(name2);
  },
  deleteLoadedStyleName(name2) {
    this._loadedStyleNames.delete(name2);
  },
  clearLoadedStyleNames() {
    this._loadedStyleNames.clear();
  },
  getTokenValue(tokenPath) {
    return themeUtils_default.getTokenValue(this.tokens, tokenPath, this.defaults);
  },
  getCommon(name2 = "", params) {
    return themeUtils_default.getCommon({ name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  getComponent(name2 = "", params) {
    const options5 = { name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default.getPresetC(options5);
  },
  getDirective(name2 = "", params) {
    const options5 = { name: name2, theme: this.theme, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default.getPresetD(options5);
  },
  getCustomPreset(name2 = "", preset, selector, params) {
    const options5 = { name: name2, preset, options: this.options, selector, params, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } };
    return themeUtils_default.getPreset(options5);
  },
  getLayerOrderCSS(name2 = "") {
    return themeUtils_default.getLayerOrder(name2, this.options, { names: this.getLayerNames() }, this.defaults);
  },
  transformCSS(name2 = "", css22, type = "style", mode2) {
    return themeUtils_default.transformCSS(name2, css22, mode2, type, this.options, { layerNames: this.setLayerNames.bind(this) }, this.defaults);
  },
  getCommonStyleSheet(name2 = "", params, props = {}) {
    return themeUtils_default.getCommonStyleSheet({ name: name2, theme: this.theme, params, props, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  getStyleSheet(name2, params, props = {}) {
    return themeUtils_default.getStyleSheet({ name: name2, theme: this.theme, params, props, defaults: this.defaults, set: { layerNames: this.setLayerNames.bind(this) } });
  },
  onStyleMounted(name2) {
    this._loadingStyles.add(name2);
  },
  onStyleUpdated(name2) {
    this._loadingStyles.add(name2);
  },
  onStyleLoaded(event, { name: name2 }) {
    if (this._loadingStyles.size) {
      this._loadingStyles.delete(name2);
      service_default.emit(`theme:${name2}:load`, event);
      !this._loadingStyles.size && service_default.emit("theme:load");
    }
  }
};
function updatePreset(...presets) {
  const newPreset = mergeKeys$1(config_default.getPreset(), ...presets);
  config_default.setPreset(newPreset);
  return newPreset;
}
__name(updatePreset, "updatePreset");
function updatePrimaryPalette(primary) {
  return $t().primaryPalette(primary).update().preset;
}
__name(updatePrimaryPalette, "updatePrimaryPalette");
function updateSurfacePalette(palette) {
  return $t().surfacePalette(palette).update().preset;
}
__name(updateSurfacePalette, "updateSurfacePalette");
function usePreset(...presets) {
  const newPreset = mergeKeys$1(...presets);
  config_default.setPreset(newPreset);
  return newPreset;
}
__name(usePreset, "usePreset");
function useTheme(theme47) {
  return $t(theme47).update({ mergePresets: false });
}
__name(useTheme, "useTheme");
var Base = {
  _loadedStyleNames: /* @__PURE__ */ new Set(),
  getLoadedStyleNames: /* @__PURE__ */ __name(function getLoadedStyleNames2() {
    return this._loadedStyleNames;
  }, "getLoadedStyleNames"),
  isStyleNameLoaded: /* @__PURE__ */ __name(function isStyleNameLoaded2(name2) {
    return this._loadedStyleNames.has(name2);
  }, "isStyleNameLoaded"),
  setLoadedStyleName: /* @__PURE__ */ __name(function setLoadedStyleName2(name2) {
    this._loadedStyleNames.add(name2);
  }, "setLoadedStyleName"),
  deleteLoadedStyleName: /* @__PURE__ */ __name(function deleteLoadedStyleName2(name2) {
    this._loadedStyleNames["delete"](name2);
  }, "deleteLoadedStyleName"),
  clearLoadedStyleNames: /* @__PURE__ */ __name(function clearLoadedStyleNames2() {
    this._loadedStyleNames.clear();
  }, "clearLoadedStyleNames")
};
function _typeof$g(o2) {
  "@babel/helpers - typeof";
  return _typeof$g = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$g(o2);
}
__name(_typeof$g, "_typeof$g");
function ownKeys$i(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$i, "ownKeys$i");
function _objectSpread$i(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$i(Object(t2), true).forEach(function(r3) {
      _defineProperty$i(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$i(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$i, "_objectSpread$i");
function _defineProperty$i(e2, r2, t2) {
  return (r2 = _toPropertyKey$f(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$i, "_defineProperty$i");
function _toPropertyKey$f(t2) {
  var i2 = _toPrimitive$f(t2, "string");
  return "symbol" == _typeof$g(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$f, "_toPropertyKey$f");
function _toPrimitive$f(t2, r2) {
  if ("object" != _typeof$g(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$g(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$f, "_toPrimitive$f");
function tryOnMounted(fn) {
  var sync = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
  if (getCurrentInstance()) onMounted(fn);
  else if (sync) fn();
  else nextTick(fn);
}
__name(tryOnMounted, "tryOnMounted");
var _id = 0;
function useStyle(css4) {
  var options5 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
  var isLoaded = ref(false);
  var cssRef = ref(css4);
  var styleRef = ref(null);
  var defaultDocument2 = isClient() ? window.document : void 0;
  var _options$document = options5.document, document2 = _options$document === void 0 ? defaultDocument2 : _options$document, _options$immediate = options5.immediate, immediate = _options$immediate === void 0 ? true : _options$immediate, _options$manual = options5.manual, manual = _options$manual === void 0 ? false : _options$manual, _options$name = options5.name, name2 = _options$name === void 0 ? "style_".concat(++_id) : _options$name, _options$id = options5.id, id4 = _options$id === void 0 ? void 0 : _options$id, _options$media = options5.media, media = _options$media === void 0 ? void 0 : _options$media, _options$nonce = options5.nonce, nonce = _options$nonce === void 0 ? void 0 : _options$nonce, _options$first = options5.first, first2 = _options$first === void 0 ? false : _options$first, _options$onMounted = options5.onMounted, onStyleMounted = _options$onMounted === void 0 ? void 0 : _options$onMounted, _options$onUpdated = options5.onUpdated, onStyleUpdated = _options$onUpdated === void 0 ? void 0 : _options$onUpdated, _options$onLoad = options5.onLoad, onStyleLoaded = _options$onLoad === void 0 ? void 0 : _options$onLoad, _options$props = options5.props, props = _options$props === void 0 ? {} : _options$props;
  var stop2 = /* @__PURE__ */ __name(function stop3() {
  }, "stop");
  var load3 = /* @__PURE__ */ __name(function load4(_css) {
    var _props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (!document2) return;
    var _styleProps = _objectSpread$i(_objectSpread$i({}, props), _props);
    var _name = _styleProps.name || name2, _id2 = _styleProps.id || id4, _nonce = _styleProps.nonce || nonce;
    styleRef.value = document2.querySelector('style[data-primevue-style-id="'.concat(_name, '"]')) || document2.getElementById(_id2) || document2.createElement("style");
    if (!styleRef.value.isConnected) {
      cssRef.value = _css || css4;
      setAttributes(styleRef.value, {
        type: "text/css",
        id: _id2,
        media,
        nonce: _nonce
      });
      first2 ? document2.head.prepend(styleRef.value) : document2.head.appendChild(styleRef.value);
      setAttribute(styleRef.value, "data-primevue-style-id", _name);
      setAttributes(styleRef.value, _styleProps);
      styleRef.value.onload = function(event) {
        return onStyleLoaded === null || onStyleLoaded === void 0 ? void 0 : onStyleLoaded(event, {
          name: _name
        });
      };
      onStyleMounted === null || onStyleMounted === void 0 || onStyleMounted(_name);
    }
    if (isLoaded.value) return;
    stop2 = watch(cssRef, function(value3) {
      styleRef.value.textContent = value3;
      onStyleUpdated === null || onStyleUpdated === void 0 || onStyleUpdated(_name);
    }, {
      immediate: true
    });
    isLoaded.value = true;
  }, "load");
  var unload = /* @__PURE__ */ __name(function unload2() {
    if (!document2 || !isLoaded.value) return;
    stop2();
    isExist(styleRef.value) && document2.head.removeChild(styleRef.value);
    isLoaded.value = false;
  }, "unload");
  if (immediate && !manual) tryOnMounted(load3);
  return {
    id: id4,
    name: name2,
    el: styleRef,
    css: cssRef,
    unload,
    load: load3,
    isLoaded: readonly(isLoaded)
  };
}
__name(useStyle, "useStyle");
function _typeof$f(o2) {
  "@babel/helpers - typeof";
  return _typeof$f = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$f(o2);
}
__name(_typeof$f, "_typeof$f");
function _slicedToArray$3(r2, e2) {
  return _arrayWithHoles$3(r2) || _iterableToArrayLimit$3(r2, e2) || _unsupportedIterableToArray$g(r2, e2) || _nonIterableRest$3();
}
__name(_slicedToArray$3, "_slicedToArray$3");
function _nonIterableRest$3() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$3, "_nonIterableRest$3");
function _unsupportedIterableToArray$g(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$g(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$g(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$g, "_unsupportedIterableToArray$g");
function _arrayLikeToArray$g(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$g, "_arrayLikeToArray$g");
function _iterableToArrayLimit$3(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$3, "_iterableToArrayLimit$3");
function _arrayWithHoles$3(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$3, "_arrayWithHoles$3");
function ownKeys$h(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$h, "ownKeys$h");
function _objectSpread$h(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$h(Object(t2), true).forEach(function(r3) {
      _defineProperty$h(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$h(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$h, "_objectSpread$h");
function _defineProperty$h(e2, r2, t2) {
  return (r2 = _toPropertyKey$e(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$h, "_defineProperty$h");
function _toPropertyKey$e(t2) {
  var i2 = _toPrimitive$e(t2, "string");
  return "symbol" == _typeof$f(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$e, "_toPropertyKey$e");
function _toPrimitive$e(t2, r2) {
  if ("object" != _typeof$f(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$f(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$e, "_toPrimitive$e");
var theme$w = /* @__PURE__ */ __name(function theme14(_ref) {
  var dt2 = _ref.dt;
  return "\n*,\n::before,\n::after {\n    box-sizing: border-box;\n}\n\n/* Non vue overlay animations */\n.p-connected-overlay {\n    opacity: 0;\n    transform: scaleY(0.8);\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1),\n        opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-connected-overlay-visible {\n    opacity: 1;\n    transform: scaleY(1);\n}\n\n.p-connected-overlay-hidden {\n    opacity: 0;\n    transform: scaleY(1);\n    transition: opacity 0.1s linear;\n}\n\n/* Vue based overlay animations */\n.p-connected-overlay-enter-from {\n    opacity: 0;\n    transform: scaleY(0.8);\n}\n\n.p-connected-overlay-leave-to {\n    opacity: 0;\n}\n\n.p-connected-overlay-enter-active {\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1),\n        opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-connected-overlay-leave-active {\n    transition: opacity 0.1s linear;\n}\n\n/* Toggleable Content */\n.p-toggleable-content-enter-from,\n.p-toggleable-content-leave-to {\n    max-height: 0;\n}\n\n.p-toggleable-content-enter-to,\n.p-toggleable-content-leave-from {\n    max-height: 1000px;\n}\n\n.p-toggleable-content-leave-active {\n    overflow: hidden;\n    transition: max-height 0.45s cubic-bezier(0, 1, 0, 1);\n}\n\n.p-toggleable-content-enter-active {\n    overflow: hidden;\n    transition: max-height 1s ease-in-out;\n}\n\n.p-disabled,\n.p-disabled * {\n    cursor: default;\n    pointer-events: none;\n    user-select: none;\n}\n\n.p-disabled,\n.p-component:disabled {\n    opacity: ".concat(dt2("disabled.opacity"), ";\n}\n\n.pi {\n    font-size: ").concat(dt2("icon.size"), ";\n}\n\n.p-icon {\n    width: ").concat(dt2("icon.size"), ";\n    height: ").concat(dt2("icon.size"), ";\n}\n\n.p-overlay-mask {\n    background: ").concat(dt2("mask.background"), ";\n    color: ").concat(dt2("mask.color"), ";\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n}\n\n.p-overlay-mask-enter {\n    animation: p-overlay-mask-enter-animation ").concat(dt2("mask.transition.duration"), " forwards;\n}\n\n.p-overlay-mask-leave {\n    animation: p-overlay-mask-leave-animation ").concat(dt2("mask.transition.duration"), " forwards;\n}\n\n@keyframes p-overlay-mask-enter-animation {\n    from {\n        background: transparent;\n    }\n    to {\n        background: ").concat(dt2("mask.background"), ";\n    }\n}\n@keyframes p-overlay-mask-leave-animation {\n    from {\n        background: ").concat(dt2("mask.background"), ";\n    }\n    to {\n        background: transparent;\n    }\n}\n");
}, "theme");
var css$1 = /* @__PURE__ */ __name(function css3(_ref2) {
  var dt2 = _ref2.dt;
  return "\n.p-hidden-accessible {\n    border: 0;\n    clip: rect(0 0 0 0);\n    height: 1px;\n    margin: -1px;\n    overflow: hidden;\n    padding: 0;\n    position: absolute;\n    width: 1px;\n}\n\n.p-hidden-accessible input,\n.p-hidden-accessible select {\n    transform: scale(0);\n}\n\n.p-overflow-hidden {\n    overflow: hidden;\n    padding-right: ".concat(dt2("scrollbar.width"), ";\n}\n");
}, "css");
var classes$C = {};
var inlineStyles$5 = {};
var BaseStyle = {
  name: "base",
  css: css$1,
  theme: theme$w,
  classes: classes$C,
  inlineStyles: inlineStyles$5,
  load: /* @__PURE__ */ __name(function load2(style2) {
    var options5 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var transform2 = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : function(cs) {
      return cs;
    };
    var computedStyle = transform2(resolve$1(style2, {
      dt
    }));
    return isNotEmpty$1(computedStyle) ? useStyle(minifyCSS$1(computedStyle), _objectSpread$h({
      name: this.name
    }, options5)) : {};
  }, "load"),
  loadCSS: /* @__PURE__ */ __name(function loadCSS2() {
    var options5 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    return this.load(this.css, options5);
  }, "loadCSS"),
  loadTheme: /* @__PURE__ */ __name(function loadTheme2() {
    var _this = this;
    var options5 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    var style2 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    return this.load(this.theme, options5, function() {
      var computedStyle = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      return config_default.transformCSS(options5.name || _this.name, "".concat(computedStyle).concat(style2));
    });
  }, "loadTheme"),
  getCommonTheme: /* @__PURE__ */ __name(function getCommonTheme2(params) {
    return config_default.getCommon(this.name, params);
  }, "getCommonTheme"),
  getComponentTheme: /* @__PURE__ */ __name(function getComponentTheme2(params) {
    return config_default.getComponent(this.name, params);
  }, "getComponentTheme"),
  getDirectiveTheme: /* @__PURE__ */ __name(function getDirectiveTheme2(params) {
    return config_default.getDirective(this.name, params);
  }, "getDirectiveTheme"),
  getPresetTheme: /* @__PURE__ */ __name(function getPresetTheme2(preset, selector, params) {
    return config_default.getCustomPreset(this.name, preset, selector, params);
  }, "getPresetTheme"),
  getLayerOrderThemeCSS: /* @__PURE__ */ __name(function getLayerOrderThemeCSS2() {
    return config_default.getLayerOrderCSS(this.name);
  }, "getLayerOrderThemeCSS"),
  getStyleSheet: /* @__PURE__ */ __name(function getStyleSheet2() {
    var extendedCSS = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (this.css) {
      var _css = resolve$1(this.css, {
        dt
      }) || "";
      var _style = minifyCSS$1("".concat(_css).concat(extendedCSS));
      var _props = Object.entries(props).reduce(function(acc, _ref3) {
        var _ref4 = _slicedToArray$3(_ref3, 2), k2 = _ref4[0], v2 = _ref4[1];
        return acc.push("".concat(k2, '="').concat(v2, '"')) && acc;
      }, []).join(" ");
      return isNotEmpty$1(_style) ? '<style type="text/css" data-primevue-style-id="'.concat(this.name, '" ').concat(_props, ">").concat(_style, "</style>") : "";
    }
    return "";
  }, "getStyleSheet"),
  getCommonThemeStyleSheet: /* @__PURE__ */ __name(function getCommonThemeStyleSheet2(params) {
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    return config_default.getCommonStyleSheet(this.name, params, props);
  }, "getCommonThemeStyleSheet"),
  getThemeStyleSheet: /* @__PURE__ */ __name(function getThemeStyleSheet2(params) {
    var props = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    var css4 = [config_default.getStyleSheet(this.name, params, props)];
    if (this.theme) {
      var name2 = this.name === "base" ? "global-style" : "".concat(this.name, "-style");
      var _css = resolve$1(this.theme, {
        dt
      });
      var _style = minifyCSS$1(config_default.transformCSS(name2, _css));
      var _props = Object.entries(props).reduce(function(acc, _ref5) {
        var _ref6 = _slicedToArray$3(_ref5, 2), k2 = _ref6[0], v2 = _ref6[1];
        return acc.push("".concat(k2, '="').concat(v2, '"')) && acc;
      }, []).join(" ");
      isNotEmpty$1(_style) && css4.push('<style type="text/css" data-primevue-style-id="'.concat(name2, '" ').concat(_props, ">").concat(_style, "</style>"));
    }
    return css4.join("");
  }, "getThemeStyleSheet"),
  extend: /* @__PURE__ */ __name(function extend4(style2) {
    return _objectSpread$h(_objectSpread$h({}, this), {}, {
      css: void 0,
      theme: void 0
    }, style2);
  }, "extend")
};
var BaseComponentStyle = BaseStyle.extend({
  name: "common"
});
function _typeof$e(o2) {
  "@babel/helpers - typeof";
  return _typeof$e = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$e(o2);
}
__name(_typeof$e, "_typeof$e");
function _toArray(r2) {
  return _arrayWithHoles$2(r2) || _iterableToArray$c(r2) || _unsupportedIterableToArray$f(r2) || _nonIterableRest$2();
}
__name(_toArray, "_toArray");
function _iterableToArray$c(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$c, "_iterableToArray$c");
function _slicedToArray$2(r2, e2) {
  return _arrayWithHoles$2(r2) || _iterableToArrayLimit$2(r2, e2) || _unsupportedIterableToArray$f(r2, e2) || _nonIterableRest$2();
}
__name(_slicedToArray$2, "_slicedToArray$2");
function _nonIterableRest$2() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$2, "_nonIterableRest$2");
function _unsupportedIterableToArray$f(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$f(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$f(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$f, "_unsupportedIterableToArray$f");
function _arrayLikeToArray$f(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$f, "_arrayLikeToArray$f");
function _iterableToArrayLimit$2(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) {
        if (Object(t2) !== t2) return;
        f2 = false;
      } else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$2, "_iterableToArrayLimit$2");
function _arrayWithHoles$2(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$2, "_arrayWithHoles$2");
function ownKeys$g(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$g, "ownKeys$g");
function _objectSpread$g(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$g(Object(t2), true).forEach(function(r3) {
      _defineProperty$g(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$g(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$g, "_objectSpread$g");
function _defineProperty$g(e2, r2, t2) {
  return (r2 = _toPropertyKey$d(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$g, "_defineProperty$g");
function _toPropertyKey$d(t2) {
  var i2 = _toPrimitive$d(t2, "string");
  return "symbol" == _typeof$e(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$d, "_toPropertyKey$d");
function _toPrimitive$d(t2, r2) {
  if ("object" != _typeof$e(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$e(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$d, "_toPrimitive$d");
var script$V = {
  name: "BaseComponent",
  props: {
    pt: {
      type: Object,
      "default": void 0
    },
    ptOptions: {
      type: Object,
      "default": void 0
    },
    unstyled: {
      type: Boolean,
      "default": void 0
    },
    dt: {
      type: Object,
      "default": void 0
    }
  },
  inject: {
    $parentInstance: {
      "default": void 0
    }
  },
  watch: {
    isUnstyled: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler7(newValue2) {
        if (!newValue2) {
          this._loadCoreStyles();
          this._themeChangeListener(this._loadCoreStyles);
        }
      }, "handler")
    },
    dt: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler8(newValue2) {
        var _this = this;
        if (newValue2) {
          this._loadScopedThemeStyles(newValue2);
          this._themeChangeListener(function() {
            return _this._loadScopedThemeStyles(newValue2);
          });
        } else {
          this._unloadScopedThemeStyles();
        }
      }, "handler")
    }
  },
  scopedStyleEl: void 0,
  rootEl: void 0,
  $attrSelector: void 0,
  beforeCreate: /* @__PURE__ */ __name(function beforeCreate2() {
    var _this$pt, _this$pt2, _this$pt3, _ref, _ref$onBeforeCreate, _this$$primevueConfig, _this$$primevue, _this$$primevue2, _this$$primevue3, _ref2, _ref2$onBeforeCreate;
    var _usept = (_this$pt = this.pt) === null || _this$pt === void 0 ? void 0 : _this$pt["_usept"];
    var originalValue = _usept ? (_this$pt2 = this.pt) === null || _this$pt2 === void 0 || (_this$pt2 = _this$pt2.originalValue) === null || _this$pt2 === void 0 ? void 0 : _this$pt2[this.$.type.name] : void 0;
    var value3 = _usept ? (_this$pt3 = this.pt) === null || _this$pt3 === void 0 || (_this$pt3 = _this$pt3.value) === null || _this$pt3 === void 0 ? void 0 : _this$pt3[this.$.type.name] : this.pt;
    (_ref = value3 || originalValue) === null || _ref === void 0 || (_ref = _ref.hooks) === null || _ref === void 0 || (_ref$onBeforeCreate = _ref["onBeforeCreate"]) === null || _ref$onBeforeCreate === void 0 || _ref$onBeforeCreate.call(_ref);
    var _useptInConfig = (_this$$primevueConfig = this.$primevueConfig) === null || _this$$primevueConfig === void 0 || (_this$$primevueConfig = _this$$primevueConfig.pt) === null || _this$$primevueConfig === void 0 ? void 0 : _this$$primevueConfig["_usept"];
    var originalValueInConfig = _useptInConfig ? (_this$$primevue = this.$primevue) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.config) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.pt) === null || _this$$primevue === void 0 ? void 0 : _this$$primevue.originalValue : void 0;
    var valueInConfig = _useptInConfig ? (_this$$primevue2 = this.$primevue) === null || _this$$primevue2 === void 0 || (_this$$primevue2 = _this$$primevue2.config) === null || _this$$primevue2 === void 0 || (_this$$primevue2 = _this$$primevue2.pt) === null || _this$$primevue2 === void 0 ? void 0 : _this$$primevue2.value : (_this$$primevue3 = this.$primevue) === null || _this$$primevue3 === void 0 || (_this$$primevue3 = _this$$primevue3.config) === null || _this$$primevue3 === void 0 ? void 0 : _this$$primevue3.pt;
    (_ref2 = valueInConfig || originalValueInConfig) === null || _ref2 === void 0 || (_ref2 = _ref2[this.$.type.name]) === null || _ref2 === void 0 || (_ref2 = _ref2.hooks) === null || _ref2 === void 0 || (_ref2$onBeforeCreate = _ref2["onBeforeCreate"]) === null || _ref2$onBeforeCreate === void 0 || _ref2$onBeforeCreate.call(_ref2);
    this.$attrSelector = uuid("pc");
  }, "beforeCreate"),
  created: /* @__PURE__ */ __name(function created2() {
    this._hook("onCreated");
  }, "created"),
  beforeMount: /* @__PURE__ */ __name(function beforeMount3() {
    this.rootEl = findSingle(this.$el, '[data-pc-name="'.concat(toFlatCase$1(this.$.type.name), '"]'));
    if (this.rootEl) {
      this.$attrSelector && !this.rootEl.hasAttribute(this.$attrSelector) && this.rootEl.setAttribute(this.$attrSelector, "");
      this.rootEl.$pc = _objectSpread$g({
        name: this.$.type.name,
        attrSelector: this.$attrSelector
      }, this.$params);
    }
    this._loadStyles();
    this._hook("onBeforeMount");
  }, "beforeMount"),
  mounted: /* @__PURE__ */ __name(function mounted8() {
    this._hook("onMounted");
  }, "mounted"),
  beforeUpdate: /* @__PURE__ */ __name(function beforeUpdate2() {
    this._hook("onBeforeUpdate");
  }, "beforeUpdate"),
  updated: /* @__PURE__ */ __name(function updated6() {
    this._hook("onUpdated");
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount4() {
    this._hook("onBeforeUnmount");
  }, "beforeUnmount"),
  unmounted: /* @__PURE__ */ __name(function unmounted5() {
    this._unloadScopedThemeStyles();
    this._hook("onUnmounted");
  }, "unmounted"),
  methods: {
    _hook: /* @__PURE__ */ __name(function _hook3(hookName) {
      if (!this.$options.hostName) {
        var selfHook = this._usePT(this._getPT(this.pt, this.$.type.name), this._getOptionValue, "hooks.".concat(hookName));
        var defaultHook = this._useDefaultPT(this._getOptionValue, "hooks.".concat(hookName));
        selfHook === null || selfHook === void 0 || selfHook();
        defaultHook === null || defaultHook === void 0 || defaultHook();
      }
    }, "_hook"),
    _mergeProps: /* @__PURE__ */ __name(function _mergeProps3(fn) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key2 = 1; _key2 < _len; _key2++) {
        args[_key2 - 1] = arguments[_key2];
      }
      return isFunction$7(fn) ? fn.apply(void 0, args) : mergeProps$2.apply(void 0, args);
    }, "_mergeProps"),
    _loadStyles: /* @__PURE__ */ __name(function _loadStyles3() {
      var _this2 = this;
      var _load = /* @__PURE__ */ __name(function _load2() {
        if (!Base.isStyleNameLoaded("base")) {
          BaseStyle.loadCSS(_this2.$styleOptions);
          _this2._loadGlobalStyles();
          Base.setLoadedStyleName("base");
        }
        _this2._loadThemeStyles();
      }, "_load");
      _load();
      this._themeChangeListener(_load);
    }, "_loadStyles"),
    _loadCoreStyles: /* @__PURE__ */ __name(function _loadCoreStyles3() {
      var _this$$style, _this$$style2;
      if (!Base.isStyleNameLoaded((_this$$style = this.$style) === null || _this$$style === void 0 ? void 0 : _this$$style.name) && (_this$$style2 = this.$style) !== null && _this$$style2 !== void 0 && _this$$style2.name) {
        BaseComponentStyle.loadCSS(this.$styleOptions);
        this.$options.style && this.$style.loadCSS(this.$styleOptions);
        Base.setLoadedStyleName(this.$style.name);
      }
    }, "_loadCoreStyles"),
    _loadGlobalStyles: /* @__PURE__ */ __name(function _loadGlobalStyles2() {
      var globalCSS = this._useGlobalPT(this._getOptionValue, "global.css", this.$params);
      isNotEmpty$1(globalCSS) && BaseStyle.load(globalCSS, _objectSpread$g({
        name: "global"
      }, this.$styleOptions));
    }, "_loadGlobalStyles"),
    _loadThemeStyles: /* @__PURE__ */ __name(function _loadThemeStyles3() {
      var _this$$style4, _this$$style5;
      if (this.isUnstyled || this.$theme === "none") return;
      if (!config_default.isStyleNameLoaded("common")) {
        var _this$$style3, _this$$style3$getComm;
        var _ref3 = ((_this$$style3 = this.$style) === null || _this$$style3 === void 0 || (_this$$style3$getComm = _this$$style3.getCommonTheme) === null || _this$$style3$getComm === void 0 ? void 0 : _this$$style3$getComm.call(_this$$style3)) || {}, primitive = _ref3.primitive, semantic = _ref3.semantic, global2 = _ref3.global, style2 = _ref3.style;
        BaseStyle.load(primitive === null || primitive === void 0 ? void 0 : primitive.css, _objectSpread$g({
          name: "primitive-variables"
        }, this.$styleOptions));
        BaseStyle.load(semantic === null || semantic === void 0 ? void 0 : semantic.css, _objectSpread$g({
          name: "semantic-variables"
        }, this.$styleOptions));
        BaseStyle.load(global2 === null || global2 === void 0 ? void 0 : global2.css, _objectSpread$g({
          name: "global-variables"
        }, this.$styleOptions));
        BaseStyle.loadTheme(_objectSpread$g({
          name: "global-style"
        }, this.$styleOptions), style2);
        config_default.setLoadedStyleName("common");
      }
      if (!config_default.isStyleNameLoaded((_this$$style4 = this.$style) === null || _this$$style4 === void 0 ? void 0 : _this$$style4.name) && (_this$$style5 = this.$style) !== null && _this$$style5 !== void 0 && _this$$style5.name) {
        var _this$$style6, _this$$style6$getComp, _this$$style7, _this$$style8;
        var _ref4 = ((_this$$style6 = this.$style) === null || _this$$style6 === void 0 || (_this$$style6$getComp = _this$$style6.getComponentTheme) === null || _this$$style6$getComp === void 0 ? void 0 : _this$$style6$getComp.call(_this$$style6)) || {}, css4 = _ref4.css, _style = _ref4.style;
        (_this$$style7 = this.$style) === null || _this$$style7 === void 0 || _this$$style7.load(css4, _objectSpread$g({
          name: "".concat(this.$style.name, "-variables")
        }, this.$styleOptions));
        (_this$$style8 = this.$style) === null || _this$$style8 === void 0 || _this$$style8.loadTheme(_objectSpread$g({
          name: "".concat(this.$style.name, "-style")
        }, this.$styleOptions), _style);
        config_default.setLoadedStyleName(this.$style.name);
      }
      if (!config_default.isStyleNameLoaded("layer-order")) {
        var _this$$style9, _this$$style9$getLaye;
        var layerOrder = (_this$$style9 = this.$style) === null || _this$$style9 === void 0 || (_this$$style9$getLaye = _this$$style9.getLayerOrderThemeCSS) === null || _this$$style9$getLaye === void 0 ? void 0 : _this$$style9$getLaye.call(_this$$style9);
        BaseStyle.load(layerOrder, _objectSpread$g({
          name: "layer-order",
          first: true
        }, this.$styleOptions));
        config_default.setLoadedStyleName("layer-order");
      }
    }, "_loadThemeStyles"),
    _loadScopedThemeStyles: /* @__PURE__ */ __name(function _loadScopedThemeStyles3(preset) {
      var _this$$style10, _this$$style10$getPre, _this$$style11;
      var _ref5 = ((_this$$style10 = this.$style) === null || _this$$style10 === void 0 || (_this$$style10$getPre = _this$$style10.getPresetTheme) === null || _this$$style10$getPre === void 0 ? void 0 : _this$$style10$getPre.call(_this$$style10, preset, "[".concat(this.$attrSelector, "]"))) || {}, css4 = _ref5.css;
      var scopedStyle = (_this$$style11 = this.$style) === null || _this$$style11 === void 0 ? void 0 : _this$$style11.load(css4, _objectSpread$g({
        name: "".concat(this.$attrSelector, "-").concat(this.$style.name)
      }, this.$styleOptions));
      this.scopedStyleEl = scopedStyle.el;
    }, "_loadScopedThemeStyles"),
    _unloadScopedThemeStyles: /* @__PURE__ */ __name(function _unloadScopedThemeStyles2() {
      var _this$scopedStyleEl;
      (_this$scopedStyleEl = this.scopedStyleEl) === null || _this$scopedStyleEl === void 0 || (_this$scopedStyleEl = _this$scopedStyleEl.value) === null || _this$scopedStyleEl === void 0 || _this$scopedStyleEl.remove();
    }, "_unloadScopedThemeStyles"),
    _themeChangeListener: /* @__PURE__ */ __name(function _themeChangeListener3() {
      var callback = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : function() {
      };
      Base.clearLoadedStyleNames();
      service_default.on("theme:change", callback);
    }, "_themeChangeListener"),
    _getHostInstance: /* @__PURE__ */ __name(function _getHostInstance2(instance) {
      return instance ? this.$options.hostName ? instance.$.type.name === this.$options.hostName ? instance : this._getHostInstance(instance.$parentInstance) : instance.$parentInstance : void 0;
    }, "_getHostInstance"),
    _getPropValue: /* @__PURE__ */ __name(function _getPropValue2(name2) {
      var _this$_getHostInstanc;
      return this[name2] || ((_this$_getHostInstanc = this._getHostInstance(this)) === null || _this$_getHostInstanc === void 0 ? void 0 : _this$_getHostInstanc[name2]);
    }, "_getPropValue"),
    _getOptionValue: /* @__PURE__ */ __name(function _getOptionValue2(options5) {
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      return getKeyValue$1(options5, key, params);
    }, "_getOptionValue"),
    _getPTValue: /* @__PURE__ */ __name(function _getPTValue3() {
      var _this$$primevueConfig2;
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      var searchInDefaultPT = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : true;
      var searchOut = /./g.test(key) && !!params[key.split(".")[0]];
      var _ref6 = this._getPropValue("ptOptions") || ((_this$$primevueConfig2 = this.$primevueConfig) === null || _this$$primevueConfig2 === void 0 ? void 0 : _this$$primevueConfig2.ptOptions) || {}, _ref6$mergeSections = _ref6.mergeSections, mergeSections = _ref6$mergeSections === void 0 ? true : _ref6$mergeSections, _ref6$mergeProps = _ref6.mergeProps, useMergeProps = _ref6$mergeProps === void 0 ? false : _ref6$mergeProps;
      var global2 = searchInDefaultPT ? searchOut ? this._useGlobalPT(this._getPTClassValue, key, params) : this._useDefaultPT(this._getPTClassValue, key, params) : void 0;
      var self2 = searchOut ? void 0 : this._getPTSelf(obj, this._getPTClassValue, key, _objectSpread$g(_objectSpread$g({}, params), {}, {
        global: global2 || {}
      }));
      var datasets = this._getPTDatasets(key);
      return mergeSections || !mergeSections && self2 ? useMergeProps ? this._mergeProps(useMergeProps, global2, self2, datasets) : _objectSpread$g(_objectSpread$g(_objectSpread$g({}, global2), self2), datasets) : _objectSpread$g(_objectSpread$g({}, self2), datasets);
    }, "_getPTValue"),
    _getPTSelf: /* @__PURE__ */ __name(function _getPTSelf2() {
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key3 = 1; _key3 < _len2; _key3++) {
        args[_key3 - 1] = arguments[_key3];
      }
      return mergeProps$2(
        this._usePT.apply(this, [this._getPT(obj, this.$name)].concat(args)),
        // Exp; <component :pt="{}"
        this._usePT.apply(this, [this.$_attrsPT].concat(args))
        // Exp; <component :pt:[passthrough_key]:[attribute]="{value}" or <component :pt:[passthrough_key]="() =>{value}"
      );
    }, "_getPTSelf"),
    _getPTDatasets: /* @__PURE__ */ __name(function _getPTDatasets3() {
      var _this$pt4, _this$pt5;
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var datasetPrefix = "data-pc-";
      var isExtended = key === "root" && isNotEmpty$1((_this$pt4 = this.pt) === null || _this$pt4 === void 0 ? void 0 : _this$pt4["data-pc-section"]);
      return key !== "transition" && _objectSpread$g(_objectSpread$g({}, key === "root" && _objectSpread$g(_objectSpread$g(_defineProperty$g({}, "".concat(datasetPrefix, "name"), toFlatCase$1(isExtended ? (_this$pt5 = this.pt) === null || _this$pt5 === void 0 ? void 0 : _this$pt5["data-pc-section"] : this.$.type.name)), isExtended && _defineProperty$g({}, "".concat(datasetPrefix, "extend"), toFlatCase$1(this.$.type.name))), isClient() && _defineProperty$g({}, "".concat(this.$attrSelector), ""))), {}, _defineProperty$g({}, "".concat(datasetPrefix, "section"), toFlatCase$1(key)));
    }, "_getPTDatasets"),
    _getPTClassValue: /* @__PURE__ */ __name(function _getPTClassValue2() {
      var value3 = this._getOptionValue.apply(this, arguments);
      return isString$5(value3) || isArray$7(value3) ? {
        "class": value3
      } : value3;
    }, "_getPTClassValue"),
    _getPT: /* @__PURE__ */ __name(function _getPT3(pt) {
      var _this3 = this;
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var callback = arguments.length > 2 ? arguments[2] : void 0;
      var getValue2 = /* @__PURE__ */ __name(function getValue3(value3) {
        var _ref9;
        var checkSameKey = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
        var computedValue = callback ? callback(value3) : value3;
        var _key = toFlatCase$1(key);
        var _cKey = toFlatCase$1(_this3.$name);
        return (_ref9 = checkSameKey ? _key !== _cKey ? computedValue === null || computedValue === void 0 ? void 0 : computedValue[_key] : void 0 : computedValue === null || computedValue === void 0 ? void 0 : computedValue[_key]) !== null && _ref9 !== void 0 ? _ref9 : computedValue;
      }, "getValue");
      return pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept") ? {
        _usept: pt["_usept"],
        originalValue: getValue2(pt.originalValue),
        value: getValue2(pt.value)
      } : getValue2(pt, true);
    }, "_getPT"),
    _usePT: /* @__PURE__ */ __name(function _usePT3(pt, callback, key, params) {
      var fn = /* @__PURE__ */ __name(function fn2(value4) {
        return callback(value4, key, params);
      }, "fn");
      if (pt !== null && pt !== void 0 && pt.hasOwnProperty("_usept")) {
        var _this$$primevueConfig3;
        var _ref10 = pt["_usept"] || ((_this$$primevueConfig3 = this.$primevueConfig) === null || _this$$primevueConfig3 === void 0 ? void 0 : _this$$primevueConfig3.ptOptions) || {}, _ref10$mergeSections = _ref10.mergeSections, mergeSections = _ref10$mergeSections === void 0 ? true : _ref10$mergeSections, _ref10$mergeProps = _ref10.mergeProps, useMergeProps = _ref10$mergeProps === void 0 ? false : _ref10$mergeProps;
        var originalValue = fn(pt.originalValue);
        var value3 = fn(pt.value);
        if (originalValue === void 0 && value3 === void 0) return void 0;
        else if (isString$5(value3)) return value3;
        else if (isString$5(originalValue)) return originalValue;
        return mergeSections || !mergeSections && value3 ? useMergeProps ? this._mergeProps(useMergeProps, originalValue, value3) : _objectSpread$g(_objectSpread$g({}, originalValue), value3) : value3;
      }
      return fn(pt);
    }, "_usePT"),
    _useGlobalPT: /* @__PURE__ */ __name(function _useGlobalPT2(callback, key, params) {
      return this._usePT(this.globalPT, callback, key, params);
    }, "_useGlobalPT"),
    _useDefaultPT: /* @__PURE__ */ __name(function _useDefaultPT3(callback, key, params) {
      return this._usePT(this.defaultPT, callback, key, params);
    }, "_useDefaultPT"),
    ptm: /* @__PURE__ */ __name(function ptm2() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return this._getPTValue(this.pt, key, _objectSpread$g(_objectSpread$g({}, this.$params), params));
    }, "ptm"),
    ptmi: /* @__PURE__ */ __name(function ptmi2() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return mergeProps$2(this.$_attrsWithoutPT, this.ptm(key, params));
    }, "ptmi"),
    ptmo: /* @__PURE__ */ __name(function ptmo2() {
      var obj = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
      var key = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      return this._getPTValue(obj, key, _objectSpread$g({
        instance: this
      }, params), false);
    }, "ptmo"),
    cx: /* @__PURE__ */ __name(function cx2() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var params = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return !this.isUnstyled ? this._getOptionValue(this.$style.classes, key, _objectSpread$g(_objectSpread$g({}, this.$params), params)) : void 0;
    }, "cx"),
    sx: /* @__PURE__ */ __name(function sx2() {
      var key = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
      var when = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : true;
      var params = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      if (when) {
        var self2 = this._getOptionValue(this.$style.inlineStyles, key, _objectSpread$g(_objectSpread$g({}, this.$params), params));
        var base2 = this._getOptionValue(BaseComponentStyle.inlineStyles, key, _objectSpread$g(_objectSpread$g({}, this.$params), params));
        return [base2, self2];
      }
      return void 0;
    }, "sx")
  },
  computed: {
    globalPT: /* @__PURE__ */ __name(function globalPT2() {
      var _this$$primevueConfig4, _this4 = this;
      return this._getPT((_this$$primevueConfig4 = this.$primevueConfig) === null || _this$$primevueConfig4 === void 0 ? void 0 : _this$$primevueConfig4.pt, void 0, function(value3) {
        return resolve$1(value3, {
          instance: _this4
        });
      });
    }, "globalPT"),
    defaultPT: /* @__PURE__ */ __name(function defaultPT2() {
      var _this$$primevueConfig5, _this5 = this;
      return this._getPT((_this$$primevueConfig5 = this.$primevueConfig) === null || _this$$primevueConfig5 === void 0 ? void 0 : _this$$primevueConfig5.pt, void 0, function(value3) {
        return _this5._getOptionValue(value3, _this5.$name, _objectSpread$g({}, _this5.$params)) || resolve$1(value3, _objectSpread$g({}, _this5.$params));
      });
    }, "defaultPT"),
    isUnstyled: /* @__PURE__ */ __name(function isUnstyled2() {
      var _this$$primevueConfig6;
      return this.unstyled !== void 0 ? this.unstyled : (_this$$primevueConfig6 = this.$primevueConfig) === null || _this$$primevueConfig6 === void 0 ? void 0 : _this$$primevueConfig6.unstyled;
    }, "isUnstyled"),
    $inProps: /* @__PURE__ */ __name(function $inProps2() {
      var _this$$$vnode;
      var nodePropKeys = Object.keys(((_this$$$vnode = this.$.vnode) === null || _this$$$vnode === void 0 ? void 0 : _this$$$vnode.props) || {});
      return Object.fromEntries(Object.entries(this.$props).filter(function(_ref11) {
        var _ref12 = _slicedToArray$2(_ref11, 1), k2 = _ref12[0];
        return nodePropKeys === null || nodePropKeys === void 0 ? void 0 : nodePropKeys.includes(k2);
      }));
    }, "$inProps"),
    $theme: /* @__PURE__ */ __name(function $theme2() {
      var _this$$primevueConfig7;
      return (_this$$primevueConfig7 = this.$primevueConfig) === null || _this$$primevueConfig7 === void 0 ? void 0 : _this$$primevueConfig7.theme;
    }, "$theme"),
    $style: /* @__PURE__ */ __name(function $style2() {
      return _objectSpread$g(_objectSpread$g({
        classes: void 0,
        inlineStyles: void 0,
        load: /* @__PURE__ */ __name(function load3() {
        }, "load"),
        loadCSS: /* @__PURE__ */ __name(function loadCSS3() {
        }, "loadCSS"),
        loadTheme: /* @__PURE__ */ __name(function loadTheme3() {
        }, "loadTheme")
      }, (this._getHostInstance(this) || {}).$style), this.$options.style);
    }, "$style"),
    $styleOptions: /* @__PURE__ */ __name(function $styleOptions2() {
      var _this$$primevueConfig8;
      return {
        nonce: (_this$$primevueConfig8 = this.$primevueConfig) === null || _this$$primevueConfig8 === void 0 || (_this$$primevueConfig8 = _this$$primevueConfig8.csp) === null || _this$$primevueConfig8 === void 0 ? void 0 : _this$$primevueConfig8.nonce
      };
    }, "$styleOptions"),
    $primevueConfig: /* @__PURE__ */ __name(function $primevueConfig2() {
      var _this$$primevue4;
      return (_this$$primevue4 = this.$primevue) === null || _this$$primevue4 === void 0 ? void 0 : _this$$primevue4.config;
    }, "$primevueConfig"),
    $name: /* @__PURE__ */ __name(function $name2() {
      return this.$options.hostName || this.$.type.name;
    }, "$name"),
    $params: /* @__PURE__ */ __name(function $params2() {
      var parentInstance = this._getHostInstance(this) || this.$parent;
      return {
        instance: this,
        props: this.$props,
        state: this.$data,
        attrs: this.$attrs,
        parent: {
          instance: parentInstance,
          props: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$props,
          state: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$data,
          attrs: parentInstance === null || parentInstance === void 0 ? void 0 : parentInstance.$attrs
        }
      };
    }, "$params"),
    $_attrsPT: /* @__PURE__ */ __name(function $_attrsPT2() {
      return Object.entries(this.$attrs || {}).filter(function(_ref13) {
        var _ref14 = _slicedToArray$2(_ref13, 1), key = _ref14[0];
        return key === null || key === void 0 ? void 0 : key.startsWith("pt:");
      }).reduce(function(result, _ref15) {
        var _ref16 = _slicedToArray$2(_ref15, 2), key = _ref16[0], value3 = _ref16[1];
        var _key$split = key.split(":"), _key$split2 = _toArray(_key$split), rest = _key$split2.slice(1);
        rest === null || rest === void 0 || rest.reduce(function(currentObj, nestedKey, index2, array) {
          !currentObj[nestedKey] && (currentObj[nestedKey] = index2 === array.length - 1 ? value3 : {});
          return currentObj[nestedKey];
        }, result);
        return result;
      }, {});
    }, "$_attrsPT"),
    $_attrsWithoutPT: /* @__PURE__ */ __name(function $_attrsWithoutPT2() {
      return Object.entries(this.$attrs || {}).filter(function(_ref17) {
        var _ref18 = _slicedToArray$2(_ref17, 1), key = _ref18[0];
        return !(key !== null && key !== void 0 && key.startsWith("pt:"));
      }).reduce(function(acc, _ref19) {
        var _ref20 = _slicedToArray$2(_ref19, 2), key = _ref20[0], value3 = _ref20[1];
        acc[key] = value3;
        return acc;
      }, {});
    }, "$_attrsWithoutPT")
  }
};
var classes$B = {
  root: "p-form p-component"
};
var FormStyle = BaseStyle.extend({
  name: "form",
  classes: classes$B
});
var script$1$C = {
  name: "BaseForm",
  "extends": script$V,
  style: FormStyle,
  props: {
    resolver: {
      type: Function,
      "default": null
    },
    initialValues: {
      type: Object,
      "default": null
    },
    validateOnValueUpdate: {
      type: [Boolean, Array],
      "default": true
    },
    validateOnBlur: {
      type: [Boolean, Array],
      "default": false
    },
    validateOnMount: {
      type: [Boolean, Array],
      "default": false
    },
    validateOnSubmit: {
      type: [Boolean, Array],
      "default": true
    }
  },
  provide: /* @__PURE__ */ __name(function provide13() {
    return {
      $pcForm: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$d(o2) {
  "@babel/helpers - typeof";
  return _typeof$d = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$d(o2);
}
__name(_typeof$d, "_typeof$d");
function ownKeys$f(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$f, "ownKeys$f");
function _objectSpread$f(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$f(Object(t2), true).forEach(function(r3) {
      _defineProperty$f(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$f(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$f, "_objectSpread$f");
function _defineProperty$f(e2, r2, t2) {
  return (r2 = _toPropertyKey$c(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$f, "_defineProperty$f");
function _toPropertyKey$c(t2) {
  var i2 = _toPrimitive$c(t2, "string");
  return "symbol" == _typeof$d(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$c, "_toPropertyKey$c");
function _toPrimitive$c(t2, r2) {
  if ("object" != _typeof$d(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$d(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$c, "_toPrimitive$c");
function _slicedToArray$1(r2, e2) {
  return _arrayWithHoles$1(r2) || _iterableToArrayLimit$1(r2, e2) || _unsupportedIterableToArray$e(r2, e2) || _nonIterableRest$1();
}
__name(_slicedToArray$1, "_slicedToArray$1");
function _nonIterableRest$1() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest$1, "_nonIterableRest$1");
function _unsupportedIterableToArray$e(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$e(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$e(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$e, "_unsupportedIterableToArray$e");
function _arrayLikeToArray$e(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$e, "_arrayLikeToArray$e");
function _iterableToArrayLimit$1(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) ;
      else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit$1, "_iterableToArrayLimit$1");
function _arrayWithHoles$1(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles$1, "_arrayWithHoles$1");
var script$U = {
  name: "Form",
  "extends": script$1$C,
  inheritAttrs: false,
  emits: ["submit"],
  setup: /* @__PURE__ */ __name(function setup2(props, _ref) {
    var emit2 = _ref.emit;
    var $form = useForm(props);
    var register3 = /* @__PURE__ */ __name(function register4(field2, options5) {
      var _$form$defineField = $form.defineField(field2, options5), _$form$defineField2 = _slicedToArray$1(_$form$defineField, 2), fieldProps = _$form$defineField2[1];
      return fieldProps;
    }, "register");
    var onSubmit = $form.handleSubmit(function(e2) {
      emit2("submit", e2);
    });
    return _objectSpread$f({
      register: register3,
      onSubmit
    }, omit$1($form, ["handleSubmit"]));
  }, "setup")
};
function render$S(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("form", mergeProps$2({
    onSubmit: _cache[0] || (_cache[0] = withModifiers(function() {
      return $setup.onSubmit && $setup.onSubmit.apply($setup, arguments);
    }, ["prevent"])),
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default", mergeProps$2({
    register: $setup.register,
    valid: _ctx.valid,
    reset: _ctx.reset
  }, _ctx.states))], 16);
}
__name(render$S, "render$S");
script$U.render = render$S;
var classes$A = {
  root: "p-formfield p-component"
};
var FormFieldStyle = BaseStyle.extend({
  name: "formfield",
  classes: classes$A
});
var script$1$B = {
  name: "BaseFormField",
  "extends": script$V,
  style: FormFieldStyle,
  props: {
    name: {
      type: String,
      "default": void 0
    },
    resolver: {
      type: Function,
      "default": void 0
    },
    initialValue: {
      type: null,
      "default": void 0
    },
    validateOnValueUpdate: {
      type: Boolean,
      "default": void 0
    },
    validateOnBlur: {
      type: Boolean,
      "default": void 0
    },
    validateOnMount: {
      type: Boolean,
      "default": void 0
    },
    validateOnSubmit: {
      type: Boolean,
      "default": void 0
    },
    as: {
      type: [String, Object],
      "default": "DIV"
    },
    asChild: {
      type: Boolean,
      "default": false
    }
  },
  provide: /* @__PURE__ */ __name(function provide14() {
    return {
      $pcFormField: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$c(o2) {
  "@babel/helpers - typeof";
  return _typeof$c = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$c(o2);
}
__name(_typeof$c, "_typeof$c");
function ownKeys$e(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$e, "ownKeys$e");
function _objectSpread$e(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$e(Object(t2), true).forEach(function(r3) {
      _defineProperty$e(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$e(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$e, "_objectSpread$e");
function _defineProperty$e(e2, r2, t2) {
  return (r2 = _toPropertyKey$b(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$e, "_defineProperty$e");
function _toPropertyKey$b(t2) {
  var i2 = _toPrimitive$b(t2, "string");
  return "symbol" == _typeof$c(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$b, "_toPropertyKey$b");
function _toPrimitive$b(t2, r2) {
  if ("object" != _typeof$c(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$c(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$b, "_toPrimitive$b");
var script$T = {
  name: "FormField",
  "extends": script$1$B,
  inheritAttrs: false,
  inject: {
    $pcForm: {
      "default": void 0
    }
  },
  watch: {
    formControl: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler9(newValue2) {
        var _this$$pcForm, _this$$pcForm$registe;
        (_this$$pcForm = this.$pcForm) === null || _this$$pcForm === void 0 || (_this$$pcForm$registe = _this$$pcForm.register) === null || _this$$pcForm$registe === void 0 || _this$$pcForm$registe.call(_this$$pcForm, this.name, newValue2);
      }, "handler")
    }
  },
  computed: {
    formControl: /* @__PURE__ */ __name(function formControl() {
      return {
        name: this.name,
        resolver: this.resolver,
        initialValue: this.initialValue,
        validateOnValueUpdate: this.validateOnValueUpdate,
        validateOnBlur: this.validateOnBlur,
        validateOnMount: this.validateOnMount,
        validateOnSubmit: this.validateOnSubmit
      };
    }, "formControl"),
    field: /* @__PURE__ */ __name(function field() {
      var _this$$pcForm2;
      return ((_this$$pcForm2 = this.$pcForm) === null || _this$$pcForm2 === void 0 || (_this$$pcForm2 = _this$$pcForm2.fields) === null || _this$$pcForm2 === void 0 ? void 0 : _this$$pcForm2[this.name]) || {};
    }, "field"),
    fieldAttrs: /* @__PURE__ */ __name(function fieldAttrs() {
      return _objectSpread$e(_objectSpread$e({}, this.field.props), this.field.states);
    }, "fieldAttrs")
  }
};
function render$R(_ctx, _cache, $props, $setup, $data, $options) {
  return !_ctx.asChild ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.as), mergeProps$2({
    key: 0,
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), {
    "default": withCtx(function() {
      return [renderSlot(_ctx.$slots, "default", mergeProps$2({
        props: $options.field.props
      }, $options.fieldAttrs))];
    }),
    _: 3
  }, 16, ["class"])) : renderSlot(_ctx.$slots, "default", mergeProps$2({
    key: 1,
    "class": _ctx.cx("root"),
    props: $options.field.props
  }, $options.fieldAttrs));
}
__name(render$R, "render$R");
script$T.render = render$R;
var __defProp$1 = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp$1 = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp$1(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp$1");
var __spreadValues = /* @__PURE__ */ __name((a2, b2) => {
  for (var prop2 in b2 || (b2 = {}))
    if (__hasOwnProp.call(b2, prop2))
      __defNormalProp$1(a2, prop2, b2[prop2]);
  if (__getOwnPropSymbols)
    for (var prop2 of __getOwnPropSymbols(b2)) {
      if (__propIsEnum.call(b2, prop2))
        __defNormalProp$1(a2, prop2, b2[prop2]);
    }
  return a2;
}, "__spreadValues");
function isEmpty$1(value3) {
  return value3 === null || value3 === void 0 || value3 === "" || Array.isArray(value3) && value3.length === 0 || !(value3 instanceof Date) && typeof value3 === "object" && Object.keys(value3).length === 0;
}
__name(isEmpty$1, "isEmpty$1");
function compare$1(value1, value22, comparator, order = 1) {
  let result = -1;
  const emptyValue1 = isEmpty$1(value1);
  const emptyValue2 = isEmpty$1(value22);
  if (emptyValue1 && emptyValue2) result = 0;
  else if (emptyValue1) result = order;
  else if (emptyValue2) result = -order;
  else if (typeof value1 === "string" && typeof value22 === "string") result = comparator(value1, value22);
  else result = value1 < value22 ? -1 : value1 > value22 ? 1 : 0;
  return result;
}
__name(compare$1, "compare$1");
function _deepEquals(obj1, obj2, visited = /* @__PURE__ */ new WeakSet()) {
  if (obj1 === obj2) return true;
  if (!obj1 || !obj2 || typeof obj1 !== "object" || typeof obj2 !== "object") return false;
  if (visited.has(obj1) || visited.has(obj2)) return false;
  visited.add(obj1).add(obj2);
  let arrObj1 = Array.isArray(obj1), arrObj2 = Array.isArray(obj2), i2, length, key;
  if (arrObj1 && arrObj2) {
    length = obj1.length;
    if (length != obj2.length) return false;
    for (i2 = length; i2-- !== 0; ) if (!_deepEquals(obj1[i2], obj2[i2], visited)) return false;
    return true;
  }
  if (arrObj1 != arrObj2) return false;
  let dateObj1 = obj1 instanceof Date, dateObj2 = obj2 instanceof Date;
  if (dateObj1 != dateObj2) return false;
  if (dateObj1 && dateObj2) return obj1.getTime() == obj2.getTime();
  let regexpObj1 = obj1 instanceof RegExp, regexpObj2 = obj2 instanceof RegExp;
  if (regexpObj1 != regexpObj2) return false;
  if (regexpObj1 && regexpObj2) return obj1.toString() == obj2.toString();
  let keys2 = Object.keys(obj1);
  length = keys2.length;
  if (length !== Object.keys(obj2).length) return false;
  for (i2 = length; i2-- !== 0; ) if (!Object.prototype.hasOwnProperty.call(obj2, keys2[i2])) return false;
  for (i2 = length; i2-- !== 0; ) {
    key = keys2[i2];
    if (!_deepEquals(obj1[key], obj2[key], visited)) return false;
  }
  return true;
}
__name(_deepEquals, "_deepEquals");
function deepEquals(obj1, obj2) {
  return _deepEquals(obj1, obj2);
}
__name(deepEquals, "deepEquals");
function isFunction$6(value3) {
  return !!(value3 && value3.constructor && value3.call && value3.apply);
}
__name(isFunction$6, "isFunction$6");
function isNotEmpty(value3) {
  return !isEmpty$1(value3);
}
__name(isNotEmpty, "isNotEmpty");
function resolveFieldData(data30, field2) {
  if (!data30 || !field2) {
    return null;
  }
  try {
    const value3 = data30[field2];
    if (isNotEmpty(value3)) return value3;
  } catch (e2) {
  }
  if (Object.keys(data30).length) {
    if (isFunction$6(field2)) {
      return field2(data30);
    } else if (field2.indexOf(".") === -1) {
      return data30[field2];
    } else {
      let fields = field2.split(".");
      let value3 = data30;
      for (let i2 = 0, len = fields.length; i2 < len; ++i2) {
        if (value3 == null) {
          return null;
        }
        value3 = value3[fields[i2]];
      }
      return value3;
    }
  }
  return null;
}
__name(resolveFieldData, "resolveFieldData");
function equals(obj1, obj2, field2) {
  if (field2) return resolveFieldData(obj1, field2) === resolveFieldData(obj2, field2);
  else return deepEquals(obj1, obj2);
}
__name(equals, "equals");
function contains(value3, list2) {
  if (value3 != null && list2 && list2.length) {
    for (let val of list2) {
      if (equals(value3, val)) return true;
    }
  }
  return false;
}
__name(contains, "contains");
function filter(value3, fields, filterValue) {
  let filteredItems = [];
  if (value3) {
    for (let item3 of value3) {
      for (let field2 of fields) {
        if (String(resolveFieldData(item3, field2)).toLowerCase().indexOf(filterValue.toLowerCase()) > -1) {
          filteredItems.push(item3);
          break;
        }
      }
    }
  }
  return filteredItems;
}
__name(filter, "filter");
function findIndexInList(value3, list2) {
  let index2 = -1;
  if (list2) {
    for (let i2 = 0; i2 < list2.length; i2++) {
      if (list2[i2] === value3) {
        index2 = i2;
        break;
      }
    }
  }
  return index2;
}
__name(findIndexInList, "findIndexInList");
function findLast(arr, callback) {
  let item3;
  if (isNotEmpty(arr)) {
    try {
      item3 = arr.findLast(callback);
    } catch (e2) {
      item3 = [...arr].reverse().find(callback);
    }
  }
  return item3;
}
__name(findLast, "findLast");
function findLastIndex(arr, callback) {
  let index2 = -1;
  if (isNotEmpty(arr)) {
    try {
      index2 = arr.findLastIndex(callback);
    } catch (e2) {
      index2 = arr.lastIndexOf([...arr].reverse().find(callback));
    }
  }
  return index2;
}
__name(findLastIndex, "findLastIndex");
function isObject$9(value3, empty2 = true) {
  return value3 instanceof Object && value3.constructor === Object && (empty2 || Object.keys(value3).length !== 0);
}
__name(isObject$9, "isObject$9");
function resolve(obj, ...params) {
  return isFunction$6(obj) ? obj(...params) : obj;
}
__name(resolve, "resolve");
function isString$4(value3, empty2 = true) {
  return typeof value3 === "string" && (empty2 || value3 !== "");
}
__name(isString$4, "isString$4");
function toFlatCase(str) {
  return isString$4(str) ? str.replace(/(-|_)/g, "").toLowerCase() : str;
}
__name(toFlatCase, "toFlatCase");
function getKeyValue(obj, key = "", params = {}) {
  const fKeys = toFlatCase(key).split(".");
  const fKey = fKeys.shift();
  return fKey ? isObject$9(obj) ? getKeyValue(resolve(obj[Object.keys(obj).find((k2) => toFlatCase(k2) === fKey) || ""], params), fKeys.join("."), params) : void 0 : resolve(obj, params);
}
__name(getKeyValue, "getKeyValue");
function insertIntoOrderedArray(item3, index2, arr, sourceArr) {
  if (arr.length > 0) {
    let injected = false;
    for (let i2 = 0; i2 < arr.length; i2++) {
      let currentItemIndex = findIndexInList(arr[i2], sourceArr);
      if (currentItemIndex > index2) {
        arr.splice(i2, 0, item3);
        injected = true;
        break;
      }
    }
    if (!injected) {
      arr.push(item3);
    }
  } else {
    arr.push(item3);
  }
}
__name(insertIntoOrderedArray, "insertIntoOrderedArray");
function isArray$6(value3, empty2 = true) {
  return Array.isArray(value3) && (empty2 || value3.length !== 0);
}
__name(isArray$6, "isArray$6");
function isDate(value3) {
  return value3 instanceof Date && value3.constructor === Date;
}
__name(isDate, "isDate");
function isLetter$1(char) {
  return /^[a-zA-Z\u00C0-\u017F]$/.test(char);
}
__name(isLetter$1, "isLetter$1");
function isNumber$3(value3) {
  return isNotEmpty(value3) && !isNaN(value3);
}
__name(isNumber$3, "isNumber$3");
function isPrintableCharacter(char = "") {
  return isNotEmpty(char) && char.length === 1 && !!char.match(/\S| /);
}
__name(isPrintableCharacter, "isPrintableCharacter");
function isScalar(value3) {
  return value3 != null && (typeof value3 === "string" || typeof value3 === "number" || typeof value3 === "bigint" || typeof value3 === "boolean");
}
__name(isScalar, "isScalar");
function localeComparator() {
  return new Intl.Collator(void 0, { numeric: true }).compare;
}
__name(localeComparator, "localeComparator");
function matchRegex(str, regex2) {
  if (regex2) {
    const match2 = regex2.test(str);
    regex2.lastIndex = 0;
    return match2;
  }
  return false;
}
__name(matchRegex, "matchRegex");
function mergeKeys(...args) {
  const _mergeKeys = /* @__PURE__ */ __name((target2 = {}, source = {}) => {
    const mergedObj = __spreadValues({}, target2);
    Object.keys(source).forEach((key) => {
      if (isObject$9(source[key]) && key in target2 && isObject$9(target2[key])) {
        mergedObj[key] = _mergeKeys(target2[key], source[key]);
      } else {
        mergedObj[key] = source[key];
      }
    });
    return mergedObj;
  }, "_mergeKeys");
  return args.reduce((acc, obj, i2) => i2 === 0 ? obj : _mergeKeys(acc, obj), {});
}
__name(mergeKeys, "mergeKeys");
function minifyCSS(css4) {
  return css4 ? css4.replace(/\/\*(?:(?!\*\/)[\s\S])*\*\/|[\r\n\t]+/g, "").replace(/ {2,}/g, " ").replace(/ ([{:}]) /g, "$1").replace(/([;,]) /g, "$1").replace(/ !/g, "!").replace(/: /g, ":") : css4;
}
__name(minifyCSS, "minifyCSS");
function nestedKeys(obj = {}, parentKey = "") {
  return Object.entries(obj).reduce((o2, [key, value3]) => {
    const currentKey = parentKey ? `${parentKey}.${key}` : key;
    isObject$9(value3) ? o2 = o2.concat(nestedKeys(value3, currentKey)) : o2.push(currentKey);
    return o2;
  }, []);
}
__name(nestedKeys, "nestedKeys");
function omit(obj, ...keys2) {
  if (!isObject$9(obj)) return obj;
  const copy2 = __spreadValues({}, obj);
  keys2 == null ? void 0 : keys2.flat().forEach((key) => delete copy2[key]);
  return copy2;
}
__name(omit, "omit");
function removeAccents(str) {
  const accentCheckRegex = /[\xC0-\xFF\u0100-\u017E]/;
  if (str && accentCheckRegex.test(str)) {
    const accentsMap = {
      A: /[\xC0-\xC5\u0100\u0102\u0104]/g,
      AE: /[\xC6]/g,
      C: /[\xC7\u0106\u0108\u010A\u010C]/g,
      D: /[\xD0\u010E\u0110]/g,
      E: /[\xC8-\xCB\u0112\u0114\u0116\u0118\u011A]/g,
      G: /[\u011C\u011E\u0120\u0122]/g,
      H: /[\u0124\u0126]/g,
      I: /[\xCC-\xCF\u0128\u012A\u012C\u012E\u0130]/g,
      IJ: /[\u0132]/g,
      J: /[\u0134]/g,
      K: /[\u0136]/g,
      L: /[\u0139\u013B\u013D\u013F\u0141]/g,
      N: /[\xD1\u0143\u0145\u0147\u014A]/g,
      O: /[\xD2-\xD6\xD8\u014C\u014E\u0150]/g,
      OE: /[\u0152]/g,
      R: /[\u0154\u0156\u0158]/g,
      S: /[\u015A\u015C\u015E\u0160]/g,
      T: /[\u0162\u0164\u0166]/g,
      U: /[\xD9-\xDC\u0168\u016A\u016C\u016E\u0170\u0172]/g,
      W: /[\u0174]/g,
      Y: /[\xDD\u0176\u0178]/g,
      Z: /[\u0179\u017B\u017D]/g,
      a: /[\xE0-\xE5\u0101\u0103\u0105]/g,
      ae: /[\xE6]/g,
      c: /[\xE7\u0107\u0109\u010B\u010D]/g,
      d: /[\u010F\u0111]/g,
      e: /[\xE8-\xEB\u0113\u0115\u0117\u0119\u011B]/g,
      g: /[\u011D\u011F\u0121\u0123]/g,
      i: /[\xEC-\xEF\u0129\u012B\u012D\u012F\u0131]/g,
      ij: /[\u0133]/g,
      j: /[\u0135]/g,
      k: /[\u0137,\u0138]/g,
      l: /[\u013A\u013C\u013E\u0140\u0142]/g,
      n: /[\xF1\u0144\u0146\u0148\u014B]/g,
      p: /[\xFE]/g,
      o: /[\xF2-\xF6\xF8\u014D\u014F\u0151]/g,
      oe: /[\u0153]/g,
      r: /[\u0155\u0157\u0159]/g,
      s: /[\u015B\u015D\u015F\u0161]/g,
      t: /[\u0163\u0165\u0167]/g,
      u: /[\xF9-\xFC\u0169\u016B\u016D\u016F\u0171\u0173]/g,
      w: /[\u0175]/g,
      y: /[\xFD\xFF\u0177]/g,
      z: /[\u017A\u017C\u017E]/g
    };
    for (let key in accentsMap) {
      str = str.replace(accentsMap[key], key);
    }
  }
  return str;
}
__name(removeAccents, "removeAccents");
function reorderArray(value3, from2, to) {
  if (value3 && from2 !== to) {
    if (to >= value3.length) {
      to %= value3.length;
      from2 %= value3.length;
    }
    value3.splice(to, 0, value3.splice(from2, 1)[0]);
  }
}
__name(reorderArray, "reorderArray");
function sort(value1, value22, order = 1, comparator, nullSortOrder = 1) {
  const result = compare$1(value1, value22, comparator, order);
  let finalSortOrder = order;
  if (isEmpty$1(value1) || isEmpty$1(value22)) {
    finalSortOrder = nullSortOrder === 1 ? order : nullSortOrder;
  }
  return finalSortOrder * result;
}
__name(sort, "sort");
function stringify(value3, indent = 2, currentIndent = 0) {
  const currentIndentStr = " ".repeat(currentIndent);
  const nextIndentStr = " ".repeat(currentIndent + indent);
  if (isArray$6(value3)) {
    return "[" + value3.map((v2) => stringify(v2, indent, currentIndent + indent)).join(", ") + "]";
  } else if (isDate(value3)) {
    return value3.toISOString();
  } else if (isFunction$6(value3)) {
    return value3.toString();
  } else if (isObject$9(value3)) {
    return "{\n" + Object.entries(value3).map(([k2, v2]) => `${nextIndentStr}${k2}: ${stringify(v2, indent, currentIndent + indent)}`).join(",\n") + `
${currentIndentStr}}`;
  } else {
    return JSON.stringify(value3);
  }
}
__name(stringify, "stringify");
function toCapitalCase(str) {
  return isString$4(str, false) ? str[0].toUpperCase() + str.slice(1) : str;
}
__name(toCapitalCase, "toCapitalCase");
function toKebabCase(str) {
  return isString$4(str) ? str.replace(/(_)/g, "-").replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "-" + c2.toLowerCase()).toLowerCase() : str;
}
__name(toKebabCase, "toKebabCase");
function toTokenKey(str) {
  return isString$4(str) ? str.replace(/[A-Z]/g, (c2, i2) => i2 === 0 ? c2 : "." + c2.toLowerCase()).toLowerCase() : str;
}
__name(toTokenKey, "toTokenKey");
function toValue(value3) {
  if (value3 && typeof value3 === "object") {
    if (value3.hasOwnProperty("current")) {
      return value3.current;
    } else if (value3.hasOwnProperty("value")) {
      return value3.value;
    }
  }
  return resolve(value3);
}
__name(toValue, "toValue");
var toValues = /* @__PURE__ */ __name((value3, name2) => {
  if (isObject$9(value3) && value3.hasOwnProperty(name2)) {
    return value3;
  }
  return name2 ? { [name2]: value3 } : value3;
}, "toValues");
var zodResolver = /* @__PURE__ */ __name((schema2, schemaOptions, resolverOptions) => async ({ values, name: name2 }) => {
  const { sync = false, raw = false } = resolverOptions || {};
  try {
    const result = await schema2[sync ? "parse" : "parseAsync"](values, schemaOptions);
    return {
      values: toValues(raw ? values : result, name2),
      errors: {}
    };
  } catch (e2) {
    if (Array.isArray(e2?.errors)) {
      return {
        values: toValues(raw ? values : void 0, name2),
        errors: e2.errors.reduce((acc, error2) => {
          const pathKey = isNotEmpty(error2.path) ? error2.path[0] : name2;
          if (pathKey) {
            acc[pathKey] ||= [];
            acc[pathKey].push(error2);
          }
          return acc;
        }, {})
      };
    }
    throw e2;
  }
}, "zodResolver");
function listCacheClear$1() {
  this.__data__ = [];
  this.size = 0;
}
__name(listCacheClear$1, "listCacheClear$1");
var _listCacheClear = listCacheClear$1;
const _listCacheClear$1 = /* @__PURE__ */ getDefaultExportFromCjs(_listCacheClear);
function eq$2(value3, other) {
  return value3 === other || value3 !== value3 && other !== other;
}
__name(eq$2, "eq$2");
var eq_1 = eq$2;
const eq$3 = /* @__PURE__ */ getDefaultExportFromCjs(eq_1);
var eq$1 = eq_1;
function assocIndexOf$4(array, key) {
  var length = array.length;
  while (length--) {
    if (eq$1(array[length][0], key)) {
      return length;
    }
  }
  return -1;
}
__name(assocIndexOf$4, "assocIndexOf$4");
var _assocIndexOf = assocIndexOf$4;
const _assocIndexOf$1 = /* @__PURE__ */ getDefaultExportFromCjs(_assocIndexOf);
var assocIndexOf$3 = _assocIndexOf;
var arrayProto = Array.prototype;
var splice = arrayProto.splice;
function listCacheDelete$1(key) {
  var data30 = this.__data__, index2 = assocIndexOf$3(data30, key);
  if (index2 < 0) {
    return false;
  }
  var lastIndex = data30.length - 1;
  if (index2 == lastIndex) {
    data30.pop();
  } else {
    splice.call(data30, index2, 1);
  }
  --this.size;
  return true;
}
__name(listCacheDelete$1, "listCacheDelete$1");
var _listCacheDelete = listCacheDelete$1;
const _listCacheDelete$1 = /* @__PURE__ */ getDefaultExportFromCjs(_listCacheDelete);
var assocIndexOf$2 = _assocIndexOf;
function listCacheGet$1(key) {
  var data30 = this.__data__, index2 = assocIndexOf$2(data30, key);
  return index2 < 0 ? void 0 : data30[index2][1];
}
__name(listCacheGet$1, "listCacheGet$1");
var _listCacheGet = listCacheGet$1;
const _listCacheGet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_listCacheGet);
var assocIndexOf$1 = _assocIndexOf;
function listCacheHas$1(key) {
  return assocIndexOf$1(this.__data__, key) > -1;
}
__name(listCacheHas$1, "listCacheHas$1");
var _listCacheHas = listCacheHas$1;
const _listCacheHas$1 = /* @__PURE__ */ getDefaultExportFromCjs(_listCacheHas);
var assocIndexOf = _assocIndexOf;
function listCacheSet$1(key, value3) {
  var data30 = this.__data__, index2 = assocIndexOf(data30, key);
  if (index2 < 0) {
    ++this.size;
    data30.push([key, value3]);
  } else {
    data30[index2][1] = value3;
  }
  return this;
}
__name(listCacheSet$1, "listCacheSet$1");
var _listCacheSet = listCacheSet$1;
const _listCacheSet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_listCacheSet);
var listCacheClear = _listCacheClear, listCacheDelete = _listCacheDelete, listCacheGet = _listCacheGet, listCacheHas = _listCacheHas, listCacheSet = _listCacheSet;
function ListCache$4(entries) {
  var index2 = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index2 < length) {
    var entry = entries[index2];
    this.set(entry[0], entry[1]);
  }
}
__name(ListCache$4, "ListCache$4");
ListCache$4.prototype.clear = listCacheClear;
ListCache$4.prototype["delete"] = listCacheDelete;
ListCache$4.prototype.get = listCacheGet;
ListCache$4.prototype.has = listCacheHas;
ListCache$4.prototype.set = listCacheSet;
var _ListCache = ListCache$4;
const _ListCache$1 = /* @__PURE__ */ getDefaultExportFromCjs(_ListCache);
var ListCache$3 = _ListCache;
function stackClear$1() {
  this.__data__ = new ListCache$3();
  this.size = 0;
}
__name(stackClear$1, "stackClear$1");
var _stackClear = stackClear$1;
const _stackClear$1 = /* @__PURE__ */ getDefaultExportFromCjs(_stackClear);
function stackDelete$1(key) {
  var data30 = this.__data__, result = data30["delete"](key);
  this.size = data30.size;
  return result;
}
__name(stackDelete$1, "stackDelete$1");
var _stackDelete = stackDelete$1;
const _stackDelete$1 = /* @__PURE__ */ getDefaultExportFromCjs(_stackDelete);
function stackGet$1(key) {
  return this.__data__.get(key);
}
__name(stackGet$1, "stackGet$1");
var _stackGet = stackGet$1;
const _stackGet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_stackGet);
function stackHas$1(key) {
  return this.__data__.has(key);
}
__name(stackHas$1, "stackHas$1");
var _stackHas = stackHas$1;
const _stackHas$1 = /* @__PURE__ */ getDefaultExportFromCjs(_stackHas);
var freeGlobal$1 = typeof commonjsGlobal == "object" && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;
var _freeGlobal = freeGlobal$1;
const _freeGlobal$1 = /* @__PURE__ */ getDefaultExportFromCjs(_freeGlobal);
var freeGlobal = _freeGlobal;
var freeSelf = typeof self == "object" && self && self.Object === Object && self;
var root$8 = freeGlobal || freeSelf || Function("return this")();
var _root = root$8;
const _root$1 = /* @__PURE__ */ getDefaultExportFromCjs(_root);
var root$7 = _root;
var Symbol$4 = root$7.Symbol;
var _Symbol = Symbol$4;
const _Symbol$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Symbol);
var Symbol$3 = _Symbol;
var objectProto$c = Object.prototype;
var hasOwnProperty$9 = objectProto$c.hasOwnProperty;
var nativeObjectToString$1 = objectProto$c.toString;
var symToStringTag$1 = Symbol$3 ? Symbol$3.toStringTag : void 0;
function getRawTag$1(value3) {
  var isOwn = hasOwnProperty$9.call(value3, symToStringTag$1), tag = value3[symToStringTag$1];
  try {
    value3[symToStringTag$1] = void 0;
    var unmasked = true;
  } catch (e2) {
  }
  var result = nativeObjectToString$1.call(value3);
  if (unmasked) {
    if (isOwn) {
      value3[symToStringTag$1] = tag;
    } else {
      delete value3[symToStringTag$1];
    }
  }
  return result;
}
__name(getRawTag$1, "getRawTag$1");
var _getRawTag = getRawTag$1;
const _getRawTag$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getRawTag);
var objectProto$b = Object.prototype;
var nativeObjectToString = objectProto$b.toString;
function objectToString$1(value3) {
  return nativeObjectToString.call(value3);
}
__name(objectToString$1, "objectToString$1");
var _objectToString = objectToString$1;
const _objectToString$1 = /* @__PURE__ */ getDefaultExportFromCjs(_objectToString);
var Symbol$2 = _Symbol, getRawTag = _getRawTag, objectToString = _objectToString;
var nullTag = "[object Null]", undefinedTag = "[object Undefined]";
var symToStringTag = Symbol$2 ? Symbol$2.toStringTag : void 0;
function baseGetTag$4(value3) {
  if (value3 == null) {
    return value3 === void 0 ? undefinedTag : nullTag;
  }
  return symToStringTag && symToStringTag in Object(value3) ? getRawTag(value3) : objectToString(value3);
}
__name(baseGetTag$4, "baseGetTag$4");
var _baseGetTag = baseGetTag$4;
const _baseGetTag$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseGetTag);
function isObject$7(value3) {
  var type = typeof value3;
  return value3 != null && (type == "object" || type == "function");
}
__name(isObject$7, "isObject$7");
var isObject_1 = isObject$7;
const isObject$8 = /* @__PURE__ */ getDefaultExportFromCjs(isObject_1);
var baseGetTag$3 = _baseGetTag, isObject$6 = isObject_1;
var asyncTag = "[object AsyncFunction]", funcTag$2 = "[object Function]", genTag$1 = "[object GeneratorFunction]", proxyTag = "[object Proxy]";
function isFunction$4(value3) {
  if (!isObject$6(value3)) {
    return false;
  }
  var tag = baseGetTag$3(value3);
  return tag == funcTag$2 || tag == genTag$1 || tag == asyncTag || tag == proxyTag;
}
__name(isFunction$4, "isFunction$4");
var isFunction_1 = isFunction$4;
const isFunction$5 = /* @__PURE__ */ getDefaultExportFromCjs(isFunction_1);
var root$6 = _root;
var coreJsData$1 = root$6["__core-js_shared__"];
var _coreJsData = coreJsData$1;
const _coreJsData$1 = /* @__PURE__ */ getDefaultExportFromCjs(_coreJsData);
var coreJsData = _coreJsData;
var maskSrcKey = function() {
  var uid2 = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || "");
  return uid2 ? "Symbol(src)_1." + uid2 : "";
}();
function isMasked$1(func) {
  return !!maskSrcKey && maskSrcKey in func;
}
__name(isMasked$1, "isMasked$1");
var _isMasked = isMasked$1;
const _isMasked$1 = /* @__PURE__ */ getDefaultExportFromCjs(_isMasked);
var funcProto$1 = Function.prototype;
var funcToString$1 = funcProto$1.toString;
function toSource$2(func) {
  if (func != null) {
    try {
      return funcToString$1.call(func);
    } catch (e2) {
    }
    try {
      return func + "";
    } catch (e2) {
    }
  }
  return "";
}
__name(toSource$2, "toSource$2");
var _toSource = toSource$2;
const _toSource$1 = /* @__PURE__ */ getDefaultExportFromCjs(_toSource);
var isFunction$3 = isFunction_1, isMasked = _isMasked, isObject$5 = isObject_1, toSource$1 = _toSource;
var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;
var reIsHostCtor = /^\[object .+?Constructor\]$/;
var funcProto = Function.prototype, objectProto$a = Object.prototype;
var funcToString = funcProto.toString;
var hasOwnProperty$8 = objectProto$a.hasOwnProperty;
var reIsNative = RegExp(
  "^" + funcToString.call(hasOwnProperty$8).replace(reRegExpChar, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
);
function baseIsNative$1(value3) {
  if (!isObject$5(value3) || isMasked(value3)) {
    return false;
  }
  var pattern = isFunction$3(value3) ? reIsNative : reIsHostCtor;
  return pattern.test(toSource$1(value3));
}
__name(baseIsNative$1, "baseIsNative$1");
var _baseIsNative = baseIsNative$1;
const _baseIsNative$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseIsNative);
function getValue$1(object, key) {
  return object == null ? void 0 : object[key];
}
__name(getValue$1, "getValue$1");
var _getValue = getValue$1;
const _getValue$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getValue);
var baseIsNative = _baseIsNative, getValue = _getValue;
function getNative$7(object, key) {
  var value3 = getValue(object, key);
  return baseIsNative(value3) ? value3 : void 0;
}
__name(getNative$7, "getNative$7");
var _getNative = getNative$7;
const _getNative$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getNative);
var getNative$6 = _getNative, root$5 = _root;
var Map$4 = getNative$6(root$5, "Map");
var _Map = Map$4;
const _Map$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Map);
var getNative$5 = _getNative;
var nativeCreate$4 = getNative$5(Object, "create");
var _nativeCreate = nativeCreate$4;
const _nativeCreate$1 = /* @__PURE__ */ getDefaultExportFromCjs(_nativeCreate);
var nativeCreate$3 = _nativeCreate;
function hashClear$1() {
  this.__data__ = nativeCreate$3 ? nativeCreate$3(null) : {};
  this.size = 0;
}
__name(hashClear$1, "hashClear$1");
var _hashClear = hashClear$1;
const _hashClear$1 = /* @__PURE__ */ getDefaultExportFromCjs(_hashClear);
function hashDelete$1(key) {
  var result = this.has(key) && delete this.__data__[key];
  this.size -= result ? 1 : 0;
  return result;
}
__name(hashDelete$1, "hashDelete$1");
var _hashDelete = hashDelete$1;
const _hashDelete$1 = /* @__PURE__ */ getDefaultExportFromCjs(_hashDelete);
var nativeCreate$2 = _nativeCreate;
var HASH_UNDEFINED$1 = "__lodash_hash_undefined__";
var objectProto$9 = Object.prototype;
var hasOwnProperty$7 = objectProto$9.hasOwnProperty;
function hashGet$1(key) {
  var data30 = this.__data__;
  if (nativeCreate$2) {
    var result = data30[key];
    return result === HASH_UNDEFINED$1 ? void 0 : result;
  }
  return hasOwnProperty$7.call(data30, key) ? data30[key] : void 0;
}
__name(hashGet$1, "hashGet$1");
var _hashGet = hashGet$1;
const _hashGet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_hashGet);
var nativeCreate$1 = _nativeCreate;
var objectProto$8 = Object.prototype;
var hasOwnProperty$6 = objectProto$8.hasOwnProperty;
function hashHas$1(key) {
  var data30 = this.__data__;
  return nativeCreate$1 ? data30[key] !== void 0 : hasOwnProperty$6.call(data30, key);
}
__name(hashHas$1, "hashHas$1");
var _hashHas = hashHas$1;
const _hashHas$1 = /* @__PURE__ */ getDefaultExportFromCjs(_hashHas);
var nativeCreate = _nativeCreate;
var HASH_UNDEFINED = "__lodash_hash_undefined__";
function hashSet$1(key, value3) {
  var data30 = this.__data__;
  this.size += this.has(key) ? 0 : 1;
  data30[key] = nativeCreate && value3 === void 0 ? HASH_UNDEFINED : value3;
  return this;
}
__name(hashSet$1, "hashSet$1");
var _hashSet = hashSet$1;
const _hashSet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_hashSet);
var hashClear = _hashClear, hashDelete = _hashDelete, hashGet = _hashGet, hashHas = _hashHas, hashSet = _hashSet;
function Hash$1(entries) {
  var index2 = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index2 < length) {
    var entry = entries[index2];
    this.set(entry[0], entry[1]);
  }
}
__name(Hash$1, "Hash$1");
Hash$1.prototype.clear = hashClear;
Hash$1.prototype["delete"] = hashDelete;
Hash$1.prototype.get = hashGet;
Hash$1.prototype.has = hashHas;
Hash$1.prototype.set = hashSet;
var _Hash = Hash$1;
const _Hash$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Hash);
var Hash = _Hash, ListCache$2 = _ListCache, Map$3 = _Map;
function mapCacheClear$1() {
  this.size = 0;
  this.__data__ = {
    "hash": new Hash(),
    "map": new (Map$3 || ListCache$2)(),
    "string": new Hash()
  };
}
__name(mapCacheClear$1, "mapCacheClear$1");
var _mapCacheClear = mapCacheClear$1;
const _mapCacheClear$1 = /* @__PURE__ */ getDefaultExportFromCjs(_mapCacheClear);
function isKeyable$1(value3) {
  var type = typeof value3;
  return type == "string" || type == "number" || type == "symbol" || type == "boolean" ? value3 !== "__proto__" : value3 === null;
}
__name(isKeyable$1, "isKeyable$1");
var _isKeyable = isKeyable$1;
const _isKeyable$1 = /* @__PURE__ */ getDefaultExportFromCjs(_isKeyable);
var isKeyable = _isKeyable;
function getMapData$4(map3, key) {
  var data30 = map3.__data__;
  return isKeyable(key) ? data30[typeof key == "string" ? "string" : "hash"] : data30.map;
}
__name(getMapData$4, "getMapData$4");
var _getMapData = getMapData$4;
const _getMapData$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getMapData);
var getMapData$3 = _getMapData;
function mapCacheDelete$1(key) {
  var result = getMapData$3(this, key)["delete"](key);
  this.size -= result ? 1 : 0;
  return result;
}
__name(mapCacheDelete$1, "mapCacheDelete$1");
var _mapCacheDelete = mapCacheDelete$1;
const _mapCacheDelete$1 = /* @__PURE__ */ getDefaultExportFromCjs(_mapCacheDelete);
var getMapData$2 = _getMapData;
function mapCacheGet$1(key) {
  return getMapData$2(this, key).get(key);
}
__name(mapCacheGet$1, "mapCacheGet$1");
var _mapCacheGet = mapCacheGet$1;
const _mapCacheGet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_mapCacheGet);
var getMapData$1 = _getMapData;
function mapCacheHas$1(key) {
  return getMapData$1(this, key).has(key);
}
__name(mapCacheHas$1, "mapCacheHas$1");
var _mapCacheHas = mapCacheHas$1;
const _mapCacheHas$1 = /* @__PURE__ */ getDefaultExportFromCjs(_mapCacheHas);
var getMapData = _getMapData;
function mapCacheSet$1(key, value3) {
  var data30 = getMapData(this, key), size = data30.size;
  data30.set(key, value3);
  this.size += data30.size == size ? 0 : 1;
  return this;
}
__name(mapCacheSet$1, "mapCacheSet$1");
var _mapCacheSet = mapCacheSet$1;
const _mapCacheSet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_mapCacheSet);
var mapCacheClear = _mapCacheClear, mapCacheDelete = _mapCacheDelete, mapCacheGet = _mapCacheGet, mapCacheHas = _mapCacheHas, mapCacheSet = _mapCacheSet;
function MapCache$1(entries) {
  var index2 = -1, length = entries == null ? 0 : entries.length;
  this.clear();
  while (++index2 < length) {
    var entry = entries[index2];
    this.set(entry[0], entry[1]);
  }
}
__name(MapCache$1, "MapCache$1");
MapCache$1.prototype.clear = mapCacheClear;
MapCache$1.prototype["delete"] = mapCacheDelete;
MapCache$1.prototype.get = mapCacheGet;
MapCache$1.prototype.has = mapCacheHas;
MapCache$1.prototype.set = mapCacheSet;
var _MapCache = MapCache$1;
const _MapCache$1 = /* @__PURE__ */ getDefaultExportFromCjs(_MapCache);
var ListCache$1 = _ListCache, Map$2 = _Map, MapCache = _MapCache;
var LARGE_ARRAY_SIZE = 200;
function stackSet$1(key, value3) {
  var data30 = this.__data__;
  if (data30 instanceof ListCache$1) {
    var pairs = data30.__data__;
    if (!Map$2 || pairs.length < LARGE_ARRAY_SIZE - 1) {
      pairs.push([key, value3]);
      this.size = ++data30.size;
      return this;
    }
    data30 = this.__data__ = new MapCache(pairs);
  }
  data30.set(key, value3);
  this.size = data30.size;
  return this;
}
__name(stackSet$1, "stackSet$1");
var _stackSet = stackSet$1;
const _stackSet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_stackSet);
var ListCache = _ListCache, stackClear = _stackClear, stackDelete = _stackDelete, stackGet = _stackGet, stackHas = _stackHas, stackSet = _stackSet;
function Stack$1(entries) {
  var data30 = this.__data__ = new ListCache(entries);
  this.size = data30.size;
}
__name(Stack$1, "Stack$1");
Stack$1.prototype.clear = stackClear;
Stack$1.prototype["delete"] = stackDelete;
Stack$1.prototype.get = stackGet;
Stack$1.prototype.has = stackHas;
Stack$1.prototype.set = stackSet;
var _Stack = Stack$1;
const _Stack$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Stack);
function arrayEach$1(array, iteratee) {
  var index2 = -1, length = array == null ? 0 : array.length;
  while (++index2 < length) {
    if (iteratee(array[index2], index2, array) === false) {
      break;
    }
  }
  return array;
}
__name(arrayEach$1, "arrayEach$1");
var _arrayEach = arrayEach$1;
const _arrayEach$1 = /* @__PURE__ */ getDefaultExportFromCjs(_arrayEach);
var getNative$4 = _getNative;
var defineProperty$1 = function() {
  try {
    var func = getNative$4(Object, "defineProperty");
    func({}, "", {});
    return func;
  } catch (e2) {
  }
}();
var _defineProperty$c = defineProperty$1;
const _defineProperty$d = /* @__PURE__ */ getDefaultExportFromCjs(_defineProperty$c);
var defineProperty = _defineProperty$c;
function baseAssignValue$2(object, key, value3) {
  if (key == "__proto__" && defineProperty) {
    defineProperty(object, key, {
      "configurable": true,
      "enumerable": true,
      "value": value3,
      "writable": true
    });
  } else {
    object[key] = value3;
  }
}
__name(baseAssignValue$2, "baseAssignValue$2");
var _baseAssignValue = baseAssignValue$2;
const _baseAssignValue$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseAssignValue);
var baseAssignValue$1 = _baseAssignValue, eq = eq_1;
var objectProto$7 = Object.prototype;
var hasOwnProperty$5 = objectProto$7.hasOwnProperty;
function assignValue$2(object, key, value3) {
  var objValue = object[key];
  if (!(hasOwnProperty$5.call(object, key) && eq(objValue, value3)) || value3 === void 0 && !(key in object)) {
    baseAssignValue$1(object, key, value3);
  }
}
__name(assignValue$2, "assignValue$2");
var _assignValue = assignValue$2;
const _assignValue$1 = /* @__PURE__ */ getDefaultExportFromCjs(_assignValue);
var assignValue$1 = _assignValue, baseAssignValue = _baseAssignValue;
function copyObject$4(source, props, object, customizer) {
  var isNew = !object;
  object || (object = {});
  var index2 = -1, length = props.length;
  while (++index2 < length) {
    var key = props[index2];
    var newValue2 = customizer ? customizer(object[key], source[key], key, object, source) : void 0;
    if (newValue2 === void 0) {
      newValue2 = source[key];
    }
    if (isNew) {
      baseAssignValue(object, key, newValue2);
    } else {
      assignValue$1(object, key, newValue2);
    }
  }
  return object;
}
__name(copyObject$4, "copyObject$4");
var _copyObject = copyObject$4;
const _copyObject$1 = /* @__PURE__ */ getDefaultExportFromCjs(_copyObject);
function baseTimes$1(n2, iteratee) {
  var index2 = -1, result = Array(n2);
  while (++index2 < n2) {
    result[index2] = iteratee(index2);
  }
  return result;
}
__name(baseTimes$1, "baseTimes$1");
var _baseTimes = baseTimes$1;
const _baseTimes$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseTimes);
function isObjectLike$6(value3) {
  return value3 != null && typeof value3 == "object";
}
__name(isObjectLike$6, "isObjectLike$6");
var isObjectLike_1 = isObjectLike$6;
const isObjectLike$7 = /* @__PURE__ */ getDefaultExportFromCjs(isObjectLike_1);
var baseGetTag$2 = _baseGetTag, isObjectLike$5 = isObjectLike_1;
var argsTag$2 = "[object Arguments]";
function baseIsArguments$1(value3) {
  return isObjectLike$5(value3) && baseGetTag$2(value3) == argsTag$2;
}
__name(baseIsArguments$1, "baseIsArguments$1");
var _baseIsArguments = baseIsArguments$1;
const _baseIsArguments$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseIsArguments);
var baseIsArguments = _baseIsArguments, isObjectLike$4 = isObjectLike_1;
var objectProto$6 = Object.prototype;
var hasOwnProperty$4 = objectProto$6.hasOwnProperty;
var propertyIsEnumerable$1 = objectProto$6.propertyIsEnumerable;
var isArguments$1 = baseIsArguments(/* @__PURE__ */ function() {
  return arguments;
}()) ? baseIsArguments : function(value3) {
  return isObjectLike$4(value3) && hasOwnProperty$4.call(value3, "callee") && !propertyIsEnumerable$1.call(value3, "callee");
};
var isArguments_1 = isArguments$1;
const isArguments$2 = /* @__PURE__ */ getDefaultExportFromCjs(isArguments_1);
var isArray$4 = Array.isArray;
var isArray_1 = isArray$4;
const isArray$5 = /* @__PURE__ */ getDefaultExportFromCjs(isArray_1);
var isBuffer$3 = { exports: {} };
function stubFalse() {
  return false;
}
__name(stubFalse, "stubFalse");
var stubFalse_1 = stubFalse;
const stubFalse$1 = /* @__PURE__ */ getDefaultExportFromCjs(stubFalse_1);
var isBuffer_1 = isBuffer$3.exports;
(function(module2, exports) {
  var root34 = _root, stubFalse2 = stubFalse_1;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module2 && !module2.nodeType && module2;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var Buffer2 = moduleExports ? root34.Buffer : void 0;
  var nativeIsBuffer = Buffer2 ? Buffer2.isBuffer : void 0;
  var isBuffer2 = nativeIsBuffer || stubFalse2;
  module2.exports = isBuffer2;
})(isBuffer$3, isBuffer$3.exports);
var isBufferExports = isBuffer$3.exports;
const isBuffer$2 = /* @__PURE__ */ getDefaultExportFromCjs(isBufferExports);
var MAX_SAFE_INTEGER$1 = 9007199254740991;
var reIsUint = /^(?:0|[1-9]\d*)$/;
function isIndex$1(value3, length) {
  var type = typeof value3;
  length = length == null ? MAX_SAFE_INTEGER$1 : length;
  return !!length && (type == "number" || type != "symbol" && reIsUint.test(value3)) && (value3 > -1 && value3 % 1 == 0 && value3 < length);
}
__name(isIndex$1, "isIndex$1");
var _isIndex = isIndex$1;
const _isIndex$1 = /* @__PURE__ */ getDefaultExportFromCjs(_isIndex);
var MAX_SAFE_INTEGER = 9007199254740991;
function isLength$2(value3) {
  return typeof value3 == "number" && value3 > -1 && value3 % 1 == 0 && value3 <= MAX_SAFE_INTEGER;
}
__name(isLength$2, "isLength$2");
var isLength_1 = isLength$2;
const isLength$3 = /* @__PURE__ */ getDefaultExportFromCjs(isLength_1);
var baseGetTag$1 = _baseGetTag, isLength$1 = isLength_1, isObjectLike$3 = isObjectLike_1;
var argsTag$1 = "[object Arguments]", arrayTag$1 = "[object Array]", boolTag$2 = "[object Boolean]", dateTag$2 = "[object Date]", errorTag$1 = "[object Error]", funcTag$1 = "[object Function]", mapTag$4 = "[object Map]", numberTag$2 = "[object Number]", objectTag$2 = "[object Object]", regexpTag$2 = "[object RegExp]", setTag$4 = "[object Set]", stringTag$2 = "[object String]", weakMapTag$2 = "[object WeakMap]";
var arrayBufferTag$2 = "[object ArrayBuffer]", dataViewTag$3 = "[object DataView]", float32Tag$2 = "[object Float32Array]", float64Tag$2 = "[object Float64Array]", int8Tag$2 = "[object Int8Array]", int16Tag$2 = "[object Int16Array]", int32Tag$2 = "[object Int32Array]", uint8Tag$2 = "[object Uint8Array]", uint8ClampedTag$2 = "[object Uint8ClampedArray]", uint16Tag$2 = "[object Uint16Array]", uint32Tag$2 = "[object Uint32Array]";
var typedArrayTags = {};
typedArrayTags[float32Tag$2] = typedArrayTags[float64Tag$2] = typedArrayTags[int8Tag$2] = typedArrayTags[int16Tag$2] = typedArrayTags[int32Tag$2] = typedArrayTags[uint8Tag$2] = typedArrayTags[uint8ClampedTag$2] = typedArrayTags[uint16Tag$2] = typedArrayTags[uint32Tag$2] = true;
typedArrayTags[argsTag$1] = typedArrayTags[arrayTag$1] = typedArrayTags[arrayBufferTag$2] = typedArrayTags[boolTag$2] = typedArrayTags[dataViewTag$3] = typedArrayTags[dateTag$2] = typedArrayTags[errorTag$1] = typedArrayTags[funcTag$1] = typedArrayTags[mapTag$4] = typedArrayTags[numberTag$2] = typedArrayTags[objectTag$2] = typedArrayTags[regexpTag$2] = typedArrayTags[setTag$4] = typedArrayTags[stringTag$2] = typedArrayTags[weakMapTag$2] = false;
function baseIsTypedArray$1(value3) {
  return isObjectLike$3(value3) && isLength$1(value3.length) && !!typedArrayTags[baseGetTag$1(value3)];
}
__name(baseIsTypedArray$1, "baseIsTypedArray$1");
var _baseIsTypedArray = baseIsTypedArray$1;
const _baseIsTypedArray$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseIsTypedArray);
function baseUnary$3(func) {
  return function(value3) {
    return func(value3);
  };
}
__name(baseUnary$3, "baseUnary$3");
var _baseUnary = baseUnary$3;
const _baseUnary$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseUnary);
var _nodeUtil$2 = { exports: {} };
var _nodeUtil = _nodeUtil$2.exports;
(function(module2, exports) {
  var freeGlobal2 = _freeGlobal;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module2 && !module2.nodeType && module2;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var freeProcess = moduleExports && freeGlobal2.process;
  var nodeUtil2 = function() {
    try {
      var types = freeModule && freeModule.require && freeModule.require("util").types;
      if (types) {
        return types;
      }
      return freeProcess && freeProcess.binding && freeProcess.binding("util");
    } catch (e2) {
    }
  }();
  module2.exports = nodeUtil2;
})(_nodeUtil$2, _nodeUtil$2.exports);
var _nodeUtilExports = _nodeUtil$2.exports;
const _nodeUtil$1 = /* @__PURE__ */ getDefaultExportFromCjs(_nodeUtilExports);
var baseIsTypedArray = _baseIsTypedArray, baseUnary$2 = _baseUnary, nodeUtil$2 = _nodeUtilExports;
var nodeIsTypedArray = nodeUtil$2 && nodeUtil$2.isTypedArray;
var isTypedArray$1 = nodeIsTypedArray ? baseUnary$2(nodeIsTypedArray) : baseIsTypedArray;
var isTypedArray_1 = isTypedArray$1;
const isTypedArray$2 = /* @__PURE__ */ getDefaultExportFromCjs(isTypedArray_1);
var baseTimes = _baseTimes, isArguments = isArguments_1, isArray$3 = isArray_1, isBuffer$1 = isBufferExports, isIndex = _isIndex, isTypedArray = isTypedArray_1;
var objectProto$5 = Object.prototype;
var hasOwnProperty$3 = objectProto$5.hasOwnProperty;
function arrayLikeKeys$2(value3, inherited) {
  var isArr = isArray$3(value3), isArg = !isArr && isArguments(value3), isBuff = !isArr && !isArg && isBuffer$1(value3), isType = !isArr && !isArg && !isBuff && isTypedArray(value3), skipIndexes = isArr || isArg || isBuff || isType, result = skipIndexes ? baseTimes(value3.length, String) : [], length = result.length;
  for (var key in value3) {
    if ((inherited || hasOwnProperty$3.call(value3, key)) && !(skipIndexes && // Safari 9 has enumerable `arguments.length` in strict mode.
    (key == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
    isBuff && (key == "offset" || key == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
    isType && (key == "buffer" || key == "byteLength" || key == "byteOffset") || // Skip index properties.
    isIndex(key, length)))) {
      result.push(key);
    }
  }
  return result;
}
__name(arrayLikeKeys$2, "arrayLikeKeys$2");
var _arrayLikeKeys = arrayLikeKeys$2;
const _arrayLikeKeys$1 = /* @__PURE__ */ getDefaultExportFromCjs(_arrayLikeKeys);
var objectProto$4 = Object.prototype;
function isPrototype$3(value3) {
  var Ctor = value3 && value3.constructor, proto = typeof Ctor == "function" && Ctor.prototype || objectProto$4;
  return value3 === proto;
}
__name(isPrototype$3, "isPrototype$3");
var _isPrototype = isPrototype$3;
const _isPrototype$1 = /* @__PURE__ */ getDefaultExportFromCjs(_isPrototype);
function overArg$2(func, transform2) {
  return function(arg) {
    return func(transform2(arg));
  };
}
__name(overArg$2, "overArg$2");
var _overArg = overArg$2;
const _overArg$1 = /* @__PURE__ */ getDefaultExportFromCjs(_overArg);
var overArg$1 = _overArg;
var nativeKeys$1 = overArg$1(Object.keys, Object);
var _nativeKeys = nativeKeys$1;
const _nativeKeys$1 = /* @__PURE__ */ getDefaultExportFromCjs(_nativeKeys);
var isPrototype$2 = _isPrototype, nativeKeys = _nativeKeys;
var objectProto$3 = Object.prototype;
var hasOwnProperty$2 = objectProto$3.hasOwnProperty;
function baseKeys$1(object) {
  if (!isPrototype$2(object)) {
    return nativeKeys(object);
  }
  var result = [];
  for (var key in Object(object)) {
    if (hasOwnProperty$2.call(object, key) && key != "constructor") {
      result.push(key);
    }
  }
  return result;
}
__name(baseKeys$1, "baseKeys$1");
var _baseKeys = baseKeys$1;
const _baseKeys$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseKeys);
var isFunction$2 = isFunction_1, isLength = isLength_1;
function isArrayLike$2(value3) {
  return value3 != null && isLength(value3.length) && !isFunction$2(value3);
}
__name(isArrayLike$2, "isArrayLike$2");
var isArrayLike_1 = isArrayLike$2;
const isArrayLike$3 = /* @__PURE__ */ getDefaultExportFromCjs(isArrayLike_1);
var arrayLikeKeys$1 = _arrayLikeKeys, baseKeys = _baseKeys, isArrayLike$1 = isArrayLike_1;
function keys$4(object) {
  return isArrayLike$1(object) ? arrayLikeKeys$1(object) : baseKeys(object);
}
__name(keys$4, "keys$4");
var keys_1 = keys$4;
const keys$5 = /* @__PURE__ */ getDefaultExportFromCjs(keys_1);
var copyObject$3 = _copyObject, keys$3 = keys_1;
function baseAssign$1(object, source) {
  return object && copyObject$3(source, keys$3(source), object);
}
__name(baseAssign$1, "baseAssign$1");
var _baseAssign = baseAssign$1;
const _baseAssign$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseAssign);
function nativeKeysIn$1(object) {
  var result = [];
  if (object != null) {
    for (var key in Object(object)) {
      result.push(key);
    }
  }
  return result;
}
__name(nativeKeysIn$1, "nativeKeysIn$1");
var _nativeKeysIn = nativeKeysIn$1;
const _nativeKeysIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_nativeKeysIn);
var isObject$4 = isObject_1, isPrototype$1 = _isPrototype, nativeKeysIn = _nativeKeysIn;
var objectProto$2 = Object.prototype;
var hasOwnProperty$1 = objectProto$2.hasOwnProperty;
function baseKeysIn$1(object) {
  if (!isObject$4(object)) {
    return nativeKeysIn(object);
  }
  var isProto = isPrototype$1(object), result = [];
  for (var key in object) {
    if (!(key == "constructor" && (isProto || !hasOwnProperty$1.call(object, key)))) {
      result.push(key);
    }
  }
  return result;
}
__name(baseKeysIn$1, "baseKeysIn$1");
var _baseKeysIn = baseKeysIn$1;
const _baseKeysIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseKeysIn);
var arrayLikeKeys = _arrayLikeKeys, baseKeysIn = _baseKeysIn, isArrayLike = isArrayLike_1;
function keysIn$3(object) {
  return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
}
__name(keysIn$3, "keysIn$3");
var keysIn_1 = keysIn$3;
const keysIn$4 = /* @__PURE__ */ getDefaultExportFromCjs(keysIn_1);
var copyObject$2 = _copyObject, keysIn$2 = keysIn_1;
function baseAssignIn$1(object, source) {
  return object && copyObject$2(source, keysIn$2(source), object);
}
__name(baseAssignIn$1, "baseAssignIn$1");
var _baseAssignIn = baseAssignIn$1;
const _baseAssignIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseAssignIn);
var _cloneBuffer$2 = { exports: {} };
var _cloneBuffer = _cloneBuffer$2.exports;
(function(module2, exports) {
  var root34 = _root;
  var freeExports = exports && !exports.nodeType && exports;
  var freeModule = freeExports && true && module2 && !module2.nodeType && module2;
  var moduleExports = freeModule && freeModule.exports === freeExports;
  var Buffer2 = moduleExports ? root34.Buffer : void 0, allocUnsafe = Buffer2 ? Buffer2.allocUnsafe : void 0;
  function cloneBuffer2(buffer2, isDeep) {
    if (isDeep) {
      return buffer2.slice();
    }
    var length = buffer2.length, result = allocUnsafe ? allocUnsafe(length) : new buffer2.constructor(length);
    buffer2.copy(result);
    return result;
  }
  __name(cloneBuffer2, "cloneBuffer");
  module2.exports = cloneBuffer2;
})(_cloneBuffer$2, _cloneBuffer$2.exports);
var _cloneBufferExports = _cloneBuffer$2.exports;
const _cloneBuffer$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneBufferExports);
function copyArray$1(source, array) {
  var index2 = -1, length = source.length;
  array || (array = Array(length));
  while (++index2 < length) {
    array[index2] = source[index2];
  }
  return array;
}
__name(copyArray$1, "copyArray$1");
var _copyArray = copyArray$1;
const _copyArray$1 = /* @__PURE__ */ getDefaultExportFromCjs(_copyArray);
function arrayFilter$1(array, predicate) {
  var index2 = -1, length = array == null ? 0 : array.length, resIndex = 0, result = [];
  while (++index2 < length) {
    var value3 = array[index2];
    if (predicate(value3, index2, array)) {
      result[resIndex++] = value3;
    }
  }
  return result;
}
__name(arrayFilter$1, "arrayFilter$1");
var _arrayFilter = arrayFilter$1;
const _arrayFilter$1 = /* @__PURE__ */ getDefaultExportFromCjs(_arrayFilter);
function stubArray$2() {
  return [];
}
__name(stubArray$2, "stubArray$2");
var stubArray_1 = stubArray$2;
const stubArray$3 = /* @__PURE__ */ getDefaultExportFromCjs(stubArray_1);
var arrayFilter = _arrayFilter, stubArray$1 = stubArray_1;
var objectProto$1 = Object.prototype;
var propertyIsEnumerable = objectProto$1.propertyIsEnumerable;
var nativeGetSymbols$1 = Object.getOwnPropertySymbols;
var getSymbols$3 = !nativeGetSymbols$1 ? stubArray$1 : function(object) {
  if (object == null) {
    return [];
  }
  object = Object(object);
  return arrayFilter(nativeGetSymbols$1(object), function(symbol) {
    return propertyIsEnumerable.call(object, symbol);
  });
};
var _getSymbols = getSymbols$3;
const _getSymbols$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getSymbols);
var copyObject$1 = _copyObject, getSymbols$2 = _getSymbols;
function copySymbols$1(source, object) {
  return copyObject$1(source, getSymbols$2(source), object);
}
__name(copySymbols$1, "copySymbols$1");
var _copySymbols = copySymbols$1;
const _copySymbols$1 = /* @__PURE__ */ getDefaultExportFromCjs(_copySymbols);
function arrayPush$2(array, values) {
  var index2 = -1, length = values.length, offset = array.length;
  while (++index2 < length) {
    array[offset + index2] = values[index2];
  }
  return array;
}
__name(arrayPush$2, "arrayPush$2");
var _arrayPush = arrayPush$2;
const _arrayPush$1 = /* @__PURE__ */ getDefaultExportFromCjs(_arrayPush);
var overArg = _overArg;
var getPrototype$2 = overArg(Object.getPrototypeOf, Object);
var _getPrototype = getPrototype$2;
const _getPrototype$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getPrototype);
var arrayPush$1 = _arrayPush, getPrototype$1 = _getPrototype, getSymbols$1 = _getSymbols, stubArray = stubArray_1;
var nativeGetSymbols = Object.getOwnPropertySymbols;
var getSymbolsIn$2 = !nativeGetSymbols ? stubArray : function(object) {
  var result = [];
  while (object) {
    arrayPush$1(result, getSymbols$1(object));
    object = getPrototype$1(object);
  }
  return result;
};
var _getSymbolsIn = getSymbolsIn$2;
const _getSymbolsIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getSymbolsIn);
var copyObject = _copyObject, getSymbolsIn$1 = _getSymbolsIn;
function copySymbolsIn$1(source, object) {
  return copyObject(source, getSymbolsIn$1(source), object);
}
__name(copySymbolsIn$1, "copySymbolsIn$1");
var _copySymbolsIn = copySymbolsIn$1;
const _copySymbolsIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_copySymbolsIn);
var arrayPush = _arrayPush, isArray$2 = isArray_1;
function baseGetAllKeys$2(object, keysFunc, symbolsFunc) {
  var result = keysFunc(object);
  return isArray$2(object) ? result : arrayPush(result, symbolsFunc(object));
}
__name(baseGetAllKeys$2, "baseGetAllKeys$2");
var _baseGetAllKeys = baseGetAllKeys$2;
const _baseGetAllKeys$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseGetAllKeys);
var baseGetAllKeys$1 = _baseGetAllKeys, getSymbols = _getSymbols, keys$2 = keys_1;
function getAllKeys$1(object) {
  return baseGetAllKeys$1(object, keys$2, getSymbols);
}
__name(getAllKeys$1, "getAllKeys$1");
var _getAllKeys = getAllKeys$1;
const _getAllKeys$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getAllKeys);
var baseGetAllKeys = _baseGetAllKeys, getSymbolsIn = _getSymbolsIn, keysIn$1 = keysIn_1;
function getAllKeysIn$1(object) {
  return baseGetAllKeys(object, keysIn$1, getSymbolsIn);
}
__name(getAllKeysIn$1, "getAllKeysIn$1");
var _getAllKeysIn = getAllKeysIn$1;
const _getAllKeysIn$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getAllKeysIn);
var getNative$3 = _getNative, root$4 = _root;
var DataView$2 = getNative$3(root$4, "DataView");
var _DataView = DataView$2;
const _DataView$1 = /* @__PURE__ */ getDefaultExportFromCjs(_DataView);
var getNative$2 = _getNative, root$3 = _root;
var Promise$2 = getNative$2(root$3, "Promise");
var _Promise = Promise$2;
const _Promise$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Promise);
var getNative$1 = _getNative, root$2 = _root;
var Set$2 = getNative$1(root$2, "Set");
var _Set = Set$2;
const _Set$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Set);
var getNative = _getNative, root$1 = _root;
var WeakMap$2 = getNative(root$1, "WeakMap");
var _WeakMap = WeakMap$2;
const _WeakMap$1 = /* @__PURE__ */ getDefaultExportFromCjs(_WeakMap);
var DataView$1 = _DataView, Map$1 = _Map, Promise$1 = _Promise, Set$1 = _Set, WeakMap$1 = _WeakMap, baseGetTag = _baseGetTag, toSource = _toSource;
var mapTag$3 = "[object Map]", objectTag$1 = "[object Object]", promiseTag = "[object Promise]", setTag$3 = "[object Set]", weakMapTag$1 = "[object WeakMap]";
var dataViewTag$2 = "[object DataView]";
var dataViewCtorString = toSource(DataView$1), mapCtorString = toSource(Map$1), promiseCtorString = toSource(Promise$1), setCtorString = toSource(Set$1), weakMapCtorString = toSource(WeakMap$1);
var getTag$4 = baseGetTag;
if (DataView$1 && getTag$4(new DataView$1(new ArrayBuffer(1))) != dataViewTag$2 || Map$1 && getTag$4(new Map$1()) != mapTag$3 || Promise$1 && getTag$4(Promise$1.resolve()) != promiseTag || Set$1 && getTag$4(new Set$1()) != setTag$3 || WeakMap$1 && getTag$4(new WeakMap$1()) != weakMapTag$1) {
  getTag$4 = /* @__PURE__ */ __name(function(value3) {
    var result = baseGetTag(value3), Ctor = result == objectTag$1 ? value3.constructor : void 0, ctorString = Ctor ? toSource(Ctor) : "";
    if (ctorString) {
      switch (ctorString) {
        case dataViewCtorString:
          return dataViewTag$2;
        case mapCtorString:
          return mapTag$3;
        case promiseCtorString:
          return promiseTag;
        case setCtorString:
          return setTag$3;
        case weakMapCtorString:
          return weakMapTag$1;
      }
    }
    return result;
  }, "getTag$4");
}
var _getTag = getTag$4;
const _getTag$1 = /* @__PURE__ */ getDefaultExportFromCjs(_getTag);
var objectProto = Object.prototype;
var hasOwnProperty = objectProto.hasOwnProperty;
function initCloneArray$1(array) {
  var length = array.length, result = new array.constructor(length);
  if (length && typeof array[0] == "string" && hasOwnProperty.call(array, "index")) {
    result.index = array.index;
    result.input = array.input;
  }
  return result;
}
__name(initCloneArray$1, "initCloneArray$1");
var _initCloneArray = initCloneArray$1;
const _initCloneArray$1 = /* @__PURE__ */ getDefaultExportFromCjs(_initCloneArray);
var root = _root;
var Uint8Array$2 = root.Uint8Array;
var _Uint8Array = Uint8Array$2;
const _Uint8Array$1 = /* @__PURE__ */ getDefaultExportFromCjs(_Uint8Array);
var Uint8Array$1 = _Uint8Array;
function cloneArrayBuffer$3(arrayBuffer) {
  var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
  new Uint8Array$1(result).set(new Uint8Array$1(arrayBuffer));
  return result;
}
__name(cloneArrayBuffer$3, "cloneArrayBuffer$3");
var _cloneArrayBuffer = cloneArrayBuffer$3;
const _cloneArrayBuffer$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneArrayBuffer);
var cloneArrayBuffer$2 = _cloneArrayBuffer;
function cloneDataView$1(dataView, isDeep) {
  var buffer2 = isDeep ? cloneArrayBuffer$2(dataView.buffer) : dataView.buffer;
  return new dataView.constructor(buffer2, dataView.byteOffset, dataView.byteLength);
}
__name(cloneDataView$1, "cloneDataView$1");
var _cloneDataView = cloneDataView$1;
const _cloneDataView$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneDataView);
var reFlags = /\w*$/;
function cloneRegExp$2(regexp2) {
  var result = new regexp2.constructor(regexp2.source, reFlags.exec(regexp2));
  result.lastIndex = regexp2.lastIndex;
  return result;
}
__name(cloneRegExp$2, "cloneRegExp$2");
var _cloneRegExp = cloneRegExp$2;
const _cloneRegExp$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneRegExp);
var Symbol$1 = _Symbol;
var symbolProto = Symbol$1 ? Symbol$1.prototype : void 0, symbolValueOf = symbolProto ? symbolProto.valueOf : void 0;
function cloneSymbol$1(symbol) {
  return symbolValueOf ? Object(symbolValueOf.call(symbol)) : {};
}
__name(cloneSymbol$1, "cloneSymbol$1");
var _cloneSymbol = cloneSymbol$1;
const _cloneSymbol$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneSymbol);
var cloneArrayBuffer$1 = _cloneArrayBuffer;
function cloneTypedArray$1(typedArray, isDeep) {
  var buffer2 = isDeep ? cloneArrayBuffer$1(typedArray.buffer) : typedArray.buffer;
  return new typedArray.constructor(buffer2, typedArray.byteOffset, typedArray.length);
}
__name(cloneTypedArray$1, "cloneTypedArray$1");
var _cloneTypedArray = cloneTypedArray$1;
const _cloneTypedArray$1 = /* @__PURE__ */ getDefaultExportFromCjs(_cloneTypedArray);
var cloneArrayBuffer = _cloneArrayBuffer, cloneDataView = _cloneDataView, cloneRegExp$1 = _cloneRegExp, cloneSymbol = _cloneSymbol, cloneTypedArray = _cloneTypedArray;
var boolTag$1 = "[object Boolean]", dateTag$1 = "[object Date]", mapTag$2 = "[object Map]", numberTag$1 = "[object Number]", regexpTag$1 = "[object RegExp]", setTag$2 = "[object Set]", stringTag$1 = "[object String]", symbolTag$1 = "[object Symbol]";
var arrayBufferTag$1 = "[object ArrayBuffer]", dataViewTag$1 = "[object DataView]", float32Tag$1 = "[object Float32Array]", float64Tag$1 = "[object Float64Array]", int8Tag$1 = "[object Int8Array]", int16Tag$1 = "[object Int16Array]", int32Tag$1 = "[object Int32Array]", uint8Tag$1 = "[object Uint8Array]", uint8ClampedTag$1 = "[object Uint8ClampedArray]", uint16Tag$1 = "[object Uint16Array]", uint32Tag$1 = "[object Uint32Array]";
function initCloneByTag$1(object, tag, isDeep) {
  var Ctor = object.constructor;
  switch (tag) {
    case arrayBufferTag$1:
      return cloneArrayBuffer(object);
    case boolTag$1:
    case dateTag$1:
      return new Ctor(+object);
    case dataViewTag$1:
      return cloneDataView(object, isDeep);
    case float32Tag$1:
    case float64Tag$1:
    case int8Tag$1:
    case int16Tag$1:
    case int32Tag$1:
    case uint8Tag$1:
    case uint8ClampedTag$1:
    case uint16Tag$1:
    case uint32Tag$1:
      return cloneTypedArray(object, isDeep);
    case mapTag$2:
      return new Ctor();
    case numberTag$1:
    case stringTag$1:
      return new Ctor(object);
    case regexpTag$1:
      return cloneRegExp$1(object);
    case setTag$2:
      return new Ctor();
    case symbolTag$1:
      return cloneSymbol(object);
  }
}
__name(initCloneByTag$1, "initCloneByTag$1");
var _initCloneByTag = initCloneByTag$1;
const _initCloneByTag$1 = /* @__PURE__ */ getDefaultExportFromCjs(_initCloneByTag);
var isObject$3 = isObject_1;
var objectCreate = Object.create;
var baseCreate$1 = /* @__PURE__ */ function() {
  function object() {
  }
  __name(object, "object");
  return function(proto) {
    if (!isObject$3(proto)) {
      return {};
    }
    if (objectCreate) {
      return objectCreate(proto);
    }
    object.prototype = proto;
    var result = new object();
    object.prototype = void 0;
    return result;
  };
}();
var _baseCreate = baseCreate$1;
const _baseCreate$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseCreate);
var baseCreate = _baseCreate, getPrototype = _getPrototype, isPrototype = _isPrototype;
function initCloneObject$1(object) {
  return typeof object.constructor == "function" && !isPrototype(object) ? baseCreate(getPrototype(object)) : {};
}
__name(initCloneObject$1, "initCloneObject$1");
var _initCloneObject = initCloneObject$1;
const _initCloneObject$1 = /* @__PURE__ */ getDefaultExportFromCjs(_initCloneObject);
var getTag$3 = _getTag, isObjectLike$2 = isObjectLike_1;
var mapTag$1 = "[object Map]";
function baseIsMap$1(value3) {
  return isObjectLike$2(value3) && getTag$3(value3) == mapTag$1;
}
__name(baseIsMap$1, "baseIsMap$1");
var _baseIsMap = baseIsMap$1;
const _baseIsMap$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseIsMap);
var baseIsMap = _baseIsMap, baseUnary$1 = _baseUnary, nodeUtil$1 = _nodeUtilExports;
var nodeIsMap = nodeUtil$1 && nodeUtil$1.isMap;
var isMap$1 = nodeIsMap ? baseUnary$1(nodeIsMap) : baseIsMap;
var isMap_1 = isMap$1;
const isMap$2 = /* @__PURE__ */ getDefaultExportFromCjs(isMap_1);
var getTag$2 = _getTag, isObjectLike$1 = isObjectLike_1;
var setTag$1 = "[object Set]";
function baseIsSet$1(value3) {
  return isObjectLike$1(value3) && getTag$2(value3) == setTag$1;
}
__name(baseIsSet$1, "baseIsSet$1");
var _baseIsSet = baseIsSet$1;
const _baseIsSet$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseIsSet);
var baseIsSet = _baseIsSet, baseUnary = _baseUnary, nodeUtil = _nodeUtilExports;
var nodeIsSet = nodeUtil && nodeUtil.isSet;
var isSet$1 = nodeIsSet ? baseUnary(nodeIsSet) : baseIsSet;
var isSet_1 = isSet$1;
const isSet$2 = /* @__PURE__ */ getDefaultExportFromCjs(isSet_1);
var Stack = _Stack, arrayEach = _arrayEach, assignValue = _assignValue, baseAssign = _baseAssign, baseAssignIn = _baseAssignIn, cloneBuffer = _cloneBufferExports, copyArray = _copyArray, copySymbols = _copySymbols, copySymbolsIn = _copySymbolsIn, getAllKeys = _getAllKeys, getAllKeysIn = _getAllKeysIn, getTag$1 = _getTag, initCloneArray = _initCloneArray, initCloneByTag = _initCloneByTag, initCloneObject = _initCloneObject, isArray$1 = isArray_1, isBuffer = isBufferExports, isMap = isMap_1, isObject$2 = isObject_1, isSet = isSet_1, keys$1 = keys_1, keysIn = keysIn_1;
var CLONE_DEEP_FLAG$1 = 1, CLONE_FLAT_FLAG = 2, CLONE_SYMBOLS_FLAG$1 = 4;
var argsTag = "[object Arguments]", arrayTag = "[object Array]", boolTag = "[object Boolean]", dateTag = "[object Date]", errorTag = "[object Error]", funcTag = "[object Function]", genTag = "[object GeneratorFunction]", mapTag = "[object Map]", numberTag = "[object Number]", objectTag = "[object Object]", regexpTag = "[object RegExp]", setTag = "[object Set]", stringTag = "[object String]", symbolTag = "[object Symbol]", weakMapTag = "[object WeakMap]";
var arrayBufferTag = "[object ArrayBuffer]", dataViewTag = "[object DataView]", float32Tag = "[object Float32Array]", float64Tag = "[object Float64Array]", int8Tag = "[object Int8Array]", int16Tag = "[object Int16Array]", int32Tag = "[object Int32Array]", uint8Tag = "[object Uint8Array]", uint8ClampedTag = "[object Uint8ClampedArray]", uint16Tag = "[object Uint16Array]", uint32Tag = "[object Uint32Array]";
var cloneableTags = {};
cloneableTags[argsTag] = cloneableTags[arrayTag] = cloneableTags[arrayBufferTag] = cloneableTags[dataViewTag] = cloneableTags[boolTag] = cloneableTags[dateTag] = cloneableTags[float32Tag] = cloneableTags[float64Tag] = cloneableTags[int8Tag] = cloneableTags[int16Tag] = cloneableTags[int32Tag] = cloneableTags[mapTag] = cloneableTags[numberTag] = cloneableTags[objectTag] = cloneableTags[regexpTag] = cloneableTags[setTag] = cloneableTags[stringTag] = cloneableTags[symbolTag] = cloneableTags[uint8Tag] = cloneableTags[uint8ClampedTag] = cloneableTags[uint16Tag] = cloneableTags[uint32Tag] = true;
cloneableTags[errorTag] = cloneableTags[funcTag] = cloneableTags[weakMapTag] = false;
function baseClone$1(value3, bitmask, customizer, key, object, stack2) {
  var result, isDeep = bitmask & CLONE_DEEP_FLAG$1, isFlat = bitmask & CLONE_FLAT_FLAG, isFull = bitmask & CLONE_SYMBOLS_FLAG$1;
  if (customizer) {
    result = object ? customizer(value3, key, object, stack2) : customizer(value3);
  }
  if (result !== void 0) {
    return result;
  }
  if (!isObject$2(value3)) {
    return value3;
  }
  var isArr = isArray$1(value3);
  if (isArr) {
    result = initCloneArray(value3);
    if (!isDeep) {
      return copyArray(value3, result);
    }
  } else {
    var tag = getTag$1(value3), isFunc = tag == funcTag || tag == genTag;
    if (isBuffer(value3)) {
      return cloneBuffer(value3, isDeep);
    }
    if (tag == objectTag || tag == argsTag || isFunc && !object) {
      result = isFlat || isFunc ? {} : initCloneObject(value3);
      if (!isDeep) {
        return isFlat ? copySymbolsIn(value3, baseAssignIn(result, value3)) : copySymbols(value3, baseAssign(result, value3));
      }
    } else {
      if (!cloneableTags[tag]) {
        return object ? value3 : {};
      }
      result = initCloneByTag(value3, tag, isDeep);
    }
  }
  stack2 || (stack2 = new Stack());
  var stacked = stack2.get(value3);
  if (stacked) {
    return stacked;
  }
  stack2.set(value3, result);
  if (isSet(value3)) {
    value3.forEach(function(subValue) {
      result.add(baseClone$1(subValue, bitmask, customizer, subValue, value3, stack2));
    });
  } else if (isMap(value3)) {
    value3.forEach(function(subValue, key2) {
      result.set(key2, baseClone$1(subValue, bitmask, customizer, key2, value3, stack2));
    });
  }
  var keysFunc = isFull ? isFlat ? getAllKeysIn : getAllKeys : isFlat ? keysIn : keys$1;
  var props = isArr ? void 0 : keysFunc(value3);
  arrayEach(props || value3, function(subValue, key2) {
    if (props) {
      key2 = subValue;
      subValue = value3[key2];
    }
    assignValue(result, key2, baseClone$1(subValue, bitmask, customizer, key2, value3, stack2));
  });
  return result;
}
__name(baseClone$1, "baseClone$1");
var _baseClone = baseClone$1;
const _baseClone$1 = /* @__PURE__ */ getDefaultExportFromCjs(_baseClone);
var baseClone = _baseClone;
var CLONE_DEEP_FLAG = 1, CLONE_SYMBOLS_FLAG = 4;
function cloneDeep(value3) {
  return baseClone(value3, CLONE_DEEP_FLAG | CLONE_SYMBOLS_FLAG);
}
__name(cloneDeep, "cloneDeep");
var cloneDeep_1 = cloneDeep;
const cloneDeep$1 = /* @__PURE__ */ getDefaultExportFromCjs(cloneDeep_1);
var script$S = {
  name: "CheckIcon",
  "extends": script$16
};
function render$Q(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M4.86199 11.5948C4.78717 11.5923 4.71366 11.5745 4.64596 11.5426C4.57826 11.5107 4.51779 11.4652 4.46827 11.4091L0.753985 7.69483C0.683167 7.64891 0.623706 7.58751 0.580092 7.51525C0.536478 7.44299 0.509851 7.36177 0.502221 7.27771C0.49459 7.19366 0.506156 7.10897 0.536046 7.03004C0.565935 6.95111 0.613367 6.88 0.674759 6.82208C0.736151 6.76416 0.8099 6.72095 0.890436 6.69571C0.970973 6.67046 1.05619 6.66385 1.13966 6.67635C1.22313 6.68886 1.30266 6.72017 1.37226 6.76792C1.44186 6.81567 1.4997 6.8786 1.54141 6.95197L4.86199 10.2503L12.6397 2.49483C12.7444 2.42694 12.8689 2.39617 12.9932 2.40745C13.1174 2.41873 13.2343 2.47141 13.3251 2.55705C13.4159 2.64268 13.4753 2.75632 13.4938 2.87973C13.5123 3.00315 13.4888 3.1292 13.4271 3.23768L5.2557 11.4091C5.20618 11.4652 5.14571 11.5107 5.07801 11.5426C5.01031 11.5745 4.9368 11.5923 4.86199 11.5948Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$Q, "render$Q");
script$S.render = render$Q;
var script$R = {
  name: "MinusIcon",
  "extends": script$16
};
function render$P(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M13.2222 7.77778H0.777778C0.571498 7.77778 0.373667 7.69584 0.227806 7.54998C0.0819442 7.40412 0 7.20629 0 7.00001C0 6.79373 0.0819442 6.5959 0.227806 6.45003C0.373667 6.30417 0.571498 6.22223 0.777778 6.22223H13.2222C13.4285 6.22223 13.6263 6.30417 13.7722 6.45003C13.9181 6.5959 14 6.79373 14 7.00001C14 7.20629 13.9181 7.40412 13.7722 7.54998C13.6263 7.69584 13.4285 7.77778 13.2222 7.77778Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$P, "render$P");
script$R.render = render$P;
var theme$v = /* @__PURE__ */ __name(function theme15(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-checkbox {\n    position: relative;\n    display: inline-flex;\n    user-select: none;\n    vertical-align: bottom;\n    width: ".concat(dt2("checkbox.width"), ";\n    height: ").concat(dt2("checkbox.height"), ";\n}\n\n.p-checkbox-input {\n    cursor: pointer;\n    appearance: none;\n    position: absolute;\n    inset-block-start: 0;\n    inset-inline-start: 0;\n    width: 100%;\n    height: 100%;\n    padding: 0;\n    margin: 0;\n    opacity: 0;\n    z-index: 1;\n    outline: 0 none;\n    border: 1px solid transparent;\n    border-radius: ").concat(dt2("checkbox.border.radius"), ";\n}\n\n.p-checkbox-box {\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    border-radius: ").concat(dt2("checkbox.border.radius"), ";\n    border: 1px solid ").concat(dt2("checkbox.border.color"), ";\n    background: ").concat(dt2("checkbox.background"), ";\n    width: ").concat(dt2("checkbox.width"), ";\n    height: ").concat(dt2("checkbox.height"), ";\n    transition: background ").concat(dt2("checkbox.transition.duration"), ", color ").concat(dt2("checkbox.transition.duration"), ", border-color ").concat(dt2("checkbox.transition.duration"), ", box-shadow ").concat(dt2("checkbox.transition.duration"), ", outline-color ").concat(dt2("checkbox.transition.duration"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("checkbox.shadow"), ";\n}\n\n.p-checkbox-icon {\n    transition-duration: ").concat(dt2("checkbox.transition.duration"), ";\n    color: ").concat(dt2("checkbox.icon.color"), ";\n    font-size: ").concat(dt2("checkbox.icon.size"), ";\n    width: ").concat(dt2("checkbox.icon.size"), ";\n    height: ").concat(dt2("checkbox.icon.size"), ";\n}\n\n.p-checkbox:not(.p-disabled):has(.p-checkbox-input:hover) .p-checkbox-box {\n    border-color: ").concat(dt2("checkbox.hover.border.color"), ";\n}\n\n.p-checkbox-checked .p-checkbox-box {\n    border-color: ").concat(dt2("checkbox.checked.border.color"), ";\n    background: ").concat(dt2("checkbox.checked.background"), ";\n}\n\n.p-checkbox-checked .p-checkbox-icon {\n    color: ").concat(dt2("checkbox.icon.checked.color"), ";\n}\n\n.p-checkbox-checked:not(.p-disabled):has(.p-checkbox-input:hover) .p-checkbox-box {\n    background: ").concat(dt2("checkbox.checked.hover.background"), ";\n    border-color: ").concat(dt2("checkbox.checked.hover.border.color"), ";\n}\n\n.p-checkbox-checked:not(.p-disabled):has(.p-checkbox-input:hover) .p-checkbox-icon {\n    color: ").concat(dt2("checkbox.icon.checked.hover.color"), ";\n}\n\n.p-checkbox:not(.p-disabled):has(.p-checkbox-input:focus-visible) .p-checkbox-box {\n    border-color: ").concat(dt2("checkbox.focus.border.color"), ";\n    box-shadow: ").concat(dt2("checkbox.focus.ring.shadow"), ";\n    outline: ").concat(dt2("checkbox.focus.ring.width"), " ").concat(dt2("checkbox.focus.ring.style"), " ").concat(dt2("checkbox.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("checkbox.focus.ring.offset"), ";\n}\n\n.p-checkbox-checked:not(.p-disabled):has(.p-checkbox-input:focus-visible) .p-checkbox-box {\n    border-color: ").concat(dt2("checkbox.checked.focus.border.color"), ";\n}\n\n.p-checkbox.p-invalid > .p-checkbox-box {\n    border-color: ").concat(dt2("checkbox.invalid.border.color"), ";\n}\n\n.p-checkbox.p-variant-filled .p-checkbox-box {\n    background: ").concat(dt2("checkbox.filled.background"), ";\n}\n\n.p-checkbox-checked.p-variant-filled .p-checkbox-box {\n    background: ").concat(dt2("checkbox.checked.background"), ";\n}\n\n.p-checkbox-checked.p-variant-filled:not(.p-disabled):has(.p-checkbox-input:hover) .p-checkbox-box {\n    background: ").concat(dt2("checkbox.checked.hover.background"), ";\n}\n\n.p-checkbox.p-disabled {\n    opacity: 1;\n}\n\n.p-checkbox.p-disabled .p-checkbox-box {\n    background: ").concat(dt2("checkbox.disabled.background"), ";\n    border-color: ").concat(dt2("checkbox.checked.disabled.border.color"), ";\n}\n\n.p-checkbox.p-disabled .p-checkbox-box .p-checkbox-icon {\n    color: ").concat(dt2("checkbox.icon.disabled.color"), ";\n}\n\n.p-checkbox-sm,\n.p-checkbox-sm .p-checkbox-box {\n    width: ").concat(dt2("checkbox.sm.width"), ";\n    height: ").concat(dt2("checkbox.sm.height"), ";\n}\n\n.p-checkbox-sm .p-checkbox-icon {\n    font-size: ").concat(dt2("checkbox.icon.sm.size"), ";\n    width: ").concat(dt2("checkbox.icon.sm.size"), ";\n    height: ").concat(dt2("checkbox.icon.sm.size"), ";\n}\n\n.p-checkbox-lg,\n.p-checkbox-lg .p-checkbox-box {\n    width: ").concat(dt2("checkbox.lg.width"), ";\n    height: ").concat(dt2("checkbox.lg.height"), ";\n}\n\n.p-checkbox-lg .p-checkbox-icon {\n    font-size: ").concat(dt2("checkbox.icon.lg.size"), ";\n    width: ").concat(dt2("checkbox.icon.lg.size"), ";\n    height: ").concat(dt2("checkbox.icon.lg.size"), ";\n}\n");
}, "theme");
var classes$z = {
  root: /* @__PURE__ */ __name(function root8(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-checkbox p-component", {
      "p-checkbox-checked": instance.checked,
      "p-disabled": props.disabled,
      "p-invalid": instance.$pcCheckboxGroup ? instance.$pcCheckboxGroup.$invalid : instance.$invalid,
      "p-variant-filled": instance.$variant === "filled",
      "p-checkbox-sm p-inputfield-sm": props.size === "small",
      "p-checkbox-lg p-inputfield-lg": props.size === "large"
    }];
  }, "root"),
  box: "p-checkbox-box",
  input: "p-checkbox-input",
  icon: "p-checkbox-icon"
};
var CheckboxStyle = BaseStyle$1.extend({
  name: "checkbox",
  theme: theme$v,
  classes: classes$z
});
var script$1$A = {
  name: "BaseCheckbox",
  "extends": script$17,
  props: {
    value: null,
    binary: Boolean,
    indeterminate: {
      type: Boolean,
      "default": false
    },
    trueValue: {
      type: null,
      "default": true
    },
    falseValue: {
      type: null,
      "default": false
    },
    readonly: {
      type: Boolean,
      "default": false
    },
    required: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": null
    },
    inputId: {
      type: String,
      "default": null
    },
    inputClass: {
      type: [String, Object],
      "default": null
    },
    inputStyle: {
      type: Object,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: CheckboxStyle,
  provide: /* @__PURE__ */ __name(function provide15() {
    return {
      $pcCheckbox: this,
      $parentInstance: this
    };
  }, "provide")
};
function _toConsumableArray$b(r2) {
  return _arrayWithoutHoles$b(r2) || _iterableToArray$b(r2) || _unsupportedIterableToArray$d(r2) || _nonIterableSpread$b();
}
__name(_toConsumableArray$b, "_toConsumableArray$b");
function _nonIterableSpread$b() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$b, "_nonIterableSpread$b");
function _unsupportedIterableToArray$d(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$d(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$d(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$d, "_unsupportedIterableToArray$d");
function _iterableToArray$b(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$b, "_iterableToArray$b");
function _arrayWithoutHoles$b(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$d(r2);
}
__name(_arrayWithoutHoles$b, "_arrayWithoutHoles$b");
function _arrayLikeToArray$d(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$d, "_arrayLikeToArray$d");
var script$Q = {
  name: "Checkbox",
  "extends": script$1$A,
  inheritAttrs: false,
  emits: ["change", "focus", "blur", "update:indeterminate"],
  inject: {
    $pcCheckboxGroup: {
      "default": void 0
    }
  },
  data: /* @__PURE__ */ __name(function data7() {
    return {
      d_indeterminate: this.indeterminate
    };
  }, "data"),
  watch: {
    indeterminate: /* @__PURE__ */ __name(function indeterminate(newValue2) {
      this.d_indeterminate = newValue2;
    }, "indeterminate")
  },
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions2(key) {
      var _ptm = key === "root" ? this.ptmi : this.ptm;
      return _ptm(key, {
        context: {
          checked: this.checked,
          indeterminate: this.d_indeterminate,
          disabled: this.disabled
        }
      });
    }, "getPTOptions"),
    onChange: /* @__PURE__ */ __name(function onChange2(event) {
      var _this = this;
      if (!this.disabled && !this.readonly) {
        var value3 = this.$pcCheckboxGroup ? this.$pcCheckboxGroup.d_value : this.d_value;
        var newModelValue;
        if (this.binary) {
          newModelValue = this.d_indeterminate ? this.trueValue : this.checked ? this.falseValue : this.trueValue;
        } else {
          if (this.checked || this.d_indeterminate) newModelValue = value3.filter(function(val) {
            return !equals$2(val, _this.value);
          });
          else newModelValue = value3 ? [].concat(_toConsumableArray$b(value3), [this.value]) : [this.value];
        }
        if (this.d_indeterminate) {
          this.d_indeterminate = false;
          this.$emit("update:indeterminate", this.d_indeterminate);
        }
        this.$pcCheckboxGroup ? this.$pcCheckboxGroup.writeValue(newModelValue, event) : this.writeValue(newModelValue, event);
        this.$emit("change", event);
      }
    }, "onChange"),
    onFocus: /* @__PURE__ */ __name(function onFocus3(event) {
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur3(event) {
      var _this$formField$onBlu, _this$formField;
      this.$emit("blur", event);
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur")
  },
  computed: {
    groupName: /* @__PURE__ */ __name(function groupName() {
      return this.$pcCheckboxGroup ? this.$pcCheckboxGroup.groupName : this.$formName;
    }, "groupName"),
    checked: /* @__PURE__ */ __name(function checked() {
      var value3 = this.$pcCheckboxGroup ? this.$pcCheckboxGroup.d_value : this.d_value;
      return this.d_indeterminate ? false : this.binary ? value3 === this.trueValue : contains$2(this.value, value3);
    }, "checked")
  },
  components: {
    CheckIcon: script$S,
    MinusIcon: script$R
  }
};
var _hoisted_1$1G = ["data-p-checked", "data-p-indeterminate", "data-p-disabled"];
var _hoisted_2$1c = ["id", "value", "name", "checked", "tabindex", "disabled", "readonly", "required", "aria-labelledby", "aria-label", "aria-invalid", "aria-checked"];
function render$O(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_CheckIcon = resolveComponent("CheckIcon");
  var _component_MinusIcon = resolveComponent("MinusIcon");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, $options.getPTOptions("root"), {
    "data-p-checked": $options.checked,
    "data-p-indeterminate": $data.d_indeterminate || void 0,
    "data-p-disabled": _ctx.disabled
  }), [createBaseVNode("input", mergeProps$2({
    id: _ctx.inputId,
    type: "checkbox",
    "class": [_ctx.cx("input"), _ctx.inputClass],
    style: _ctx.inputStyle,
    value: _ctx.value,
    name: $options.groupName,
    checked: $options.checked,
    tabindex: _ctx.tabindex,
    disabled: _ctx.disabled,
    readonly: _ctx.readonly,
    required: _ctx.required,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    "aria-invalid": _ctx.invalid || void 0,
    "aria-checked": $data.d_indeterminate ? "mixed" : void 0,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onChange: _cache[2] || (_cache[2] = function() {
      return $options.onChange && $options.onChange.apply($options, arguments);
    })
  }, $options.getPTOptions("input")), null, 16, _hoisted_2$1c), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("box")
  }, $options.getPTOptions("box")), [renderSlot(_ctx.$slots, "icon", {
    checked: $options.checked,
    indeterminate: $data.d_indeterminate,
    "class": normalizeClass(_ctx.cx("icon"))
  }, function() {
    return [$options.checked ? (openBlock(), createBlock(_component_CheckIcon, mergeProps$2({
      key: 0,
      "class": _ctx.cx("icon")
    }, $options.getPTOptions("icon")), null, 16, ["class"])) : $data.d_indeterminate ? (openBlock(), createBlock(_component_MinusIcon, mergeProps$2({
      key: 1,
      "class": _ctx.cx("icon")
    }, $options.getPTOptions("icon")), null, 16, ["class"])) : createCommentVNode("", true)];
  })], 16)], 16, _hoisted_1$1G);
}
__name(render$O, "render$O");
script$Q.render = render$O;
var theme$u = /* @__PURE__ */ __name(function theme16(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-inputtext {\n    font-family: inherit;\n    font-feature-settings: inherit;\n    font-size: 1rem;\n    color: ".concat(dt2("inputtext.color"), ";\n    background: ").concat(dt2("inputtext.background"), ";\n    padding-block: ").concat(dt2("inputtext.padding.y"), ";\n    padding-inline: ").concat(dt2("inputtext.padding.x"), ";\n    border: 1px solid ").concat(dt2("inputtext.border.color"), ";\n    transition: background ").concat(dt2("inputtext.transition.duration"), ", color ").concat(dt2("inputtext.transition.duration"), ", border-color ").concat(dt2("inputtext.transition.duration"), ", outline-color ").concat(dt2("inputtext.transition.duration"), ", box-shadow ").concat(dt2("inputtext.transition.duration"), ";\n    appearance: none;\n    border-radius: ").concat(dt2("inputtext.border.radius"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("inputtext.shadow"), ";\n}\n\n.p-inputtext:enabled:hover {\n    border-color: ").concat(dt2("inputtext.hover.border.color"), ";\n}\n\n.p-inputtext:enabled:focus {\n    border-color: ").concat(dt2("inputtext.focus.border.color"), ";\n    box-shadow: ").concat(dt2("inputtext.focus.ring.shadow"), ";\n    outline: ").concat(dt2("inputtext.focus.ring.width"), " ").concat(dt2("inputtext.focus.ring.style"), " ").concat(dt2("inputtext.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("inputtext.focus.ring.offset"), ";\n}\n\n.p-inputtext.p-invalid {\n    border-color: ").concat(dt2("inputtext.invalid.border.color"), ";\n}\n\n.p-inputtext.p-variant-filled {\n    background: ").concat(dt2("inputtext.filled.background"), ";\n}\n\n.p-inputtext.p-variant-filled:enabled:hover {\n    background: ").concat(dt2("inputtext.filled.hover.background"), ";\n}\n\n.p-inputtext.p-variant-filled:enabled:focus {\n    background: ").concat(dt2("inputtext.filled.focus.background"), ";\n}\n\n.p-inputtext:disabled {\n    opacity: 1;\n    background: ").concat(dt2("inputtext.disabled.background"), ";\n    color: ").concat(dt2("inputtext.disabled.color"), ";\n}\n\n.p-inputtext::placeholder {\n    color: ").concat(dt2("inputtext.placeholder.color"), ";\n}\n\n.p-inputtext.p-invalid::placeholder {\n    color: ").concat(dt2("inputtext.invalid.placeholder.color"), ";\n}\n\n.p-inputtext-sm {\n    font-size: ").concat(dt2("inputtext.sm.font.size"), ";\n    padding-block: ").concat(dt2("inputtext.sm.padding.y"), ";\n    padding-inline: ").concat(dt2("inputtext.sm.padding.x"), ";\n}\n\n.p-inputtext-lg {\n    font-size: ").concat(dt2("inputtext.lg.font.size"), ";\n    padding-block: ").concat(dt2("inputtext.lg.padding.y"), ";\n    padding-inline: ").concat(dt2("inputtext.lg.padding.x"), ";\n}\n\n.p-inputtext-fluid {\n    width: 100%;\n}\n");
}, "theme");
var classes$y = {
  root: /* @__PURE__ */ __name(function root9(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-inputtext p-component", {
      "p-filled": instance.$filled,
      "p-inputtext-sm p-inputfield-sm": props.size === "small",
      "p-inputtext-lg p-inputfield-lg": props.size === "large",
      "p-invalid": instance.$invalid,
      "p-variant-filled": instance.$variant === "filled",
      "p-inputtext-fluid": instance.$fluid
    }];
  }, "root")
};
var InputTextStyle = BaseStyle$1.extend({
  name: "inputtext",
  theme: theme$u,
  classes: classes$y
});
var script$1$z = {
  name: "BaseInputText",
  "extends": script$17,
  style: InputTextStyle,
  provide: /* @__PURE__ */ __name(function provide16() {
    return {
      $pcInputText: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$P = {
  name: "InputText",
  "extends": script$1$z,
  inheritAttrs: false,
  methods: {
    onInput: /* @__PURE__ */ __name(function onInput(event) {
      this.writeValue(event.target.value, event);
    }, "onInput")
  },
  computed: {
    attrs: /* @__PURE__ */ __name(function attrs3() {
      return mergeProps$2(this.ptmi("root", {
        context: {
          filled: this.$filled,
          disabled: this.disabled
        }
      }), this.formField);
    }, "attrs")
  }
};
var _hoisted_1$1F = ["value", "disabled", "aria-invalid"];
function render$N(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("input", mergeProps$2({
    type: "text",
    "class": _ctx.cx("root"),
    value: _ctx.d_value,
    disabled: _ctx.disabled,
    "aria-invalid": _ctx.$invalid || void 0,
    onInput: _cache[0] || (_cache[0] = function() {
      return $options.onInput && $options.onInput.apply($options, arguments);
    })
  }, $options.attrs), null, 16, _hoisted_1$1F);
}
__name(render$N, "render$N");
script$P.render = render$N;
var script$O = {
  name: "PlusIcon",
  "extends": script$16
};
function render$M(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M7.67742 6.32258V0.677419C7.67742 0.497757 7.60605 0.325452 7.47901 0.198411C7.35197 0.0713707 7.17966 0 7 0C6.82034 0 6.64803 0.0713707 6.52099 0.198411C6.39395 0.325452 6.32258 0.497757 6.32258 0.677419V6.32258H0.677419C0.497757 6.32258 0.325452 6.39395 0.198411 6.52099C0.0713707 6.64803 0 6.82034 0 7C0 7.17966 0.0713707 7.35197 0.198411 7.47901C0.325452 7.60605 0.497757 7.67742 0.677419 7.67742H6.32258V13.3226C6.32492 13.5015 6.39704 13.6725 6.52358 13.799C6.65012 13.9255 6.82106 13.9977 7 14C7.17966 14 7.35197 13.9286 7.47901 13.8016C7.60605 13.6745 7.67742 13.5022 7.67742 13.3226V7.67742H13.3226C13.5022 7.67742 13.6745 7.60605 13.8016 7.47901C13.9286 7.35197 14 7.17966 14 7C13.9977 6.82106 13.9255 6.65012 13.799 6.52358C13.6725 6.39704 13.5015 6.32492 13.3226 6.32258H7.67742Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$M, "render$M");
script$O.render = render$M;
var theme$t = /* @__PURE__ */ __name(function theme17(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-panel {\n    border: 1px solid ".concat(dt2("panel.border.color"), ";\n    border-radius: ").concat(dt2("panel.border.radius"), ";\n    background: ").concat(dt2("panel.background"), ";\n    color: ").concat(dt2("panel.color"), ";\n}\n\n.p-panel-header {\n    display: flex;\n    justify-content: space-between;\n    align-items: center;\n    padding: ").concat(dt2("panel.header.padding"), ";\n    background: ").concat(dt2("panel.header.background"), ";\n    color: ").concat(dt2("panel.header.color"), ";\n    border-style: solid;\n    border-width: ").concat(dt2("panel.header.border.width"), ";\n    border-color: ").concat(dt2("panel.header.border.color"), ";\n    border-radius: ").concat(dt2("panel.header.border.radius"), ";\n}\n\n.p-panel-toggleable .p-panel-header {\n    padding: ").concat(dt2("panel.toggleable.header.padding"), ";\n}\n\n.p-panel-title {\n    line-height: 1;\n    font-weight: ").concat(dt2("panel.title.font.weight"), ";\n}\n\n.p-panel-content {\n    padding: ").concat(dt2("panel.content.padding"), ";\n}\n\n.p-panel-footer {\n    padding: ").concat(dt2("panel.footer.padding"), ";\n}\n");
}, "theme");
var classes$x = {
  root: /* @__PURE__ */ __name(function root10(_ref2) {
    var props = _ref2.props;
    return ["p-panel p-component", {
      "p-panel-toggleable": props.toggleable
    }];
  }, "root"),
  header: "p-panel-header",
  title: "p-panel-title",
  headerActions: "p-panel-header-actions",
  pcToggleButton: "p-panel-toggle-button",
  contentContainer: "p-panel-content-container",
  content: "p-panel-content",
  footer: "p-panel-footer"
};
var PanelStyle = BaseStyle$1.extend({
  name: "panel",
  theme: theme$t,
  classes: classes$x
});
var script$1$y = {
  name: "BasePanel",
  "extends": script$1b,
  props: {
    header: String,
    toggleable: Boolean,
    collapsed: Boolean,
    toggleButtonProps: {
      type: Object,
      "default": /* @__PURE__ */ __name(function _default4() {
        return {
          severity: "secondary",
          text: true,
          rounded: true
        };
      }, "_default")
    }
  },
  style: PanelStyle,
  provide: /* @__PURE__ */ __name(function provide17() {
    return {
      $pcPanel: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$N = {
  name: "Panel",
  "extends": script$1$y,
  inheritAttrs: false,
  emits: ["update:collapsed", "toggle"],
  data: /* @__PURE__ */ __name(function data8() {
    return {
      id: this.$attrs.id,
      d_collapsed: this.collapsed
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId3(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    collapsed: /* @__PURE__ */ __name(function collapsed(newValue2) {
      this.d_collapsed = newValue2;
    }, "collapsed")
  },
  mounted: /* @__PURE__ */ __name(function mounted9() {
    this.id = this.id || UniqueComponentId();
  }, "mounted"),
  methods: {
    toggle: /* @__PURE__ */ __name(function toggle(event) {
      this.d_collapsed = !this.d_collapsed;
      this.$emit("update:collapsed", this.d_collapsed);
      this.$emit("toggle", {
        originalEvent: event,
        value: this.d_collapsed
      });
    }, "toggle"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown4(event) {
      if (event.code === "Enter" || event.code === "NumpadEnter" || event.code === "Space") {
        this.toggle(event);
        event.preventDefault();
      }
    }, "onKeyDown")
  },
  computed: {
    buttonAriaLabel: /* @__PURE__ */ __name(function buttonAriaLabel() {
      return this.toggleButtonProps && this.toggleButtonProps.ariaLabel ? this.toggleButtonProps.ariaLabel : this.header;
    }, "buttonAriaLabel")
  },
  components: {
    PlusIcon: script$O,
    MinusIcon: script$R,
    Button: script$10
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$1E = ["id"];
var _hoisted_2$1b = ["id", "aria-labelledby"];
function render$L(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Button = resolveComponent("Button");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("header")
  }, _ctx.ptm("header")), [renderSlot(_ctx.$slots, "header", {
    id: $data.id + "_header",
    "class": normalizeClass(_ctx.cx("title"))
  }, function() {
    return [_ctx.header ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 0,
      id: $data.id + "_header",
      "class": _ctx.cx("title")
    }, _ctx.ptm("title")), toDisplayString$1(_ctx.header), 17, _hoisted_1$1E)) : createCommentVNode("", true)];
  }), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("headerActions")
  }, _ctx.ptm("headerActions")), [renderSlot(_ctx.$slots, "icons"), _ctx.toggleable ? (openBlock(), createBlock(_component_Button, mergeProps$2({
    key: 0,
    id: $data.id + "_header",
    "class": _ctx.cx("pcToggleButton"),
    "aria-label": $options.buttonAriaLabel,
    "aria-controls": $data.id + "_content",
    "aria-expanded": !$data.d_collapsed,
    unstyled: _ctx.unstyled,
    onClick: $options.toggle,
    onKeydown: $options.onKeyDown
  }, _ctx.toggleButtonProps, {
    pt: _ctx.ptm("pcToggleButton")
  }), {
    icon: withCtx(function(slotProps) {
      return [renderSlot(_ctx.$slots, _ctx.$slots.toggleicon ? "toggleicon" : "togglericon", {
        collapsed: $data.d_collapsed
      }, function() {
        return [(openBlock(), createBlock(resolveDynamicComponent($data.d_collapsed ? "PlusIcon" : "MinusIcon"), mergeProps$2({
          "class": slotProps["class"]
        }, _ctx.ptm("pcToggleButton")["icon"]), null, 16, ["class"]))];
      })];
    }),
    _: 3
  }, 16, ["id", "class", "aria-label", "aria-controls", "aria-expanded", "unstyled", "onClick", "onKeydown", "pt"])) : createCommentVNode("", true)], 16)], 16), createVNode(Transition, mergeProps$2({
    name: "p-toggleable-content"
  }, _ctx.ptm("transition")), {
    "default": withCtx(function() {
      return [withDirectives(createBaseVNode("div", mergeProps$2({
        id: $data.id + "_content",
        "class": _ctx.cx("contentContainer"),
        role: "region",
        "aria-labelledby": $data.id + "_header"
      }, _ctx.ptm("contentContainer")), [createBaseVNode("div", mergeProps$2({
        "class": _ctx.cx("content")
      }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "default")], 16), _ctx.$slots.footer ? (openBlock(), createElementBlock("div", mergeProps$2({
        key: 0,
        "class": _ctx.cx("footer")
      }, _ctx.ptm("footer")), [renderSlot(_ctx.$slots, "footer")], 16)) : createCommentVNode("", true)], 16, _hoisted_2$1b), [[vShow, !$data.d_collapsed]])];
    }),
    _: 3
  }, 16)], 16);
}
__name(render$L, "render$L");
script$N.render = render$L;
var theme$s = /* @__PURE__ */ __name(function theme18(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-textarea {\n    font-family: inherit;\n    font-feature-settings: inherit;\n    font-size: 1rem;\n    color: ".concat(dt2("textarea.color"), ";\n    background: ").concat(dt2("textarea.background"), ";\n    padding-block: ").concat(dt2("textarea.padding.y"), ";\n    padding-inline: ").concat(dt2("textarea.padding.x"), ";\n    border: 1px solid ").concat(dt2("textarea.border.color"), ";\n    transition: background ").concat(dt2("textarea.transition.duration"), ", color ").concat(dt2("textarea.transition.duration"), ", border-color ").concat(dt2("textarea.transition.duration"), ", outline-color ").concat(dt2("textarea.transition.duration"), ", box-shadow ").concat(dt2("textarea.transition.duration"), ";\n    appearance: none;\n    border-radius: ").concat(dt2("textarea.border.radius"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("textarea.shadow"), ";\n}\n\n.p-textarea:enabled:hover {\n    border-color: ").concat(dt2("textarea.hover.border.color"), ";\n}\n\n.p-textarea:enabled:focus {\n    border-color: ").concat(dt2("textarea.focus.border.color"), ";\n    box-shadow: ").concat(dt2("textarea.focus.ring.shadow"), ";\n    outline: ").concat(dt2("textarea.focus.ring.width"), " ").concat(dt2("textarea.focus.ring.style"), " ").concat(dt2("textarea.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("textarea.focus.ring.offset"), ";\n}\n\n.p-textarea.p-invalid {\n    border-color: ").concat(dt2("textarea.invalid.border.color"), ";\n}\n\n.p-textarea.p-variant-filled {\n    background: ").concat(dt2("textarea.filled.background"), ";\n}\n\n.p-textarea.p-variant-filled:enabled:focus {\n    background: ").concat(dt2("textarea.filled.focus.background"), ";\n}\n\n.p-textarea:disabled {\n    opacity: 1;\n    background: ").concat(dt2("textarea.disabled.background"), ";\n    color: ").concat(dt2("textarea.disabled.color"), ";\n}\n\n.p-textarea::placeholder {\n    color: ").concat(dt2("textarea.placeholder.color"), ";\n}\n\n.p-textarea.p-invalid::placeholder {\n    color: ").concat(dt2("textarea.invalid.placeholder.color"), ";\n}\n\n.p-textarea-fluid {\n    width: 100%;\n}\n\n.p-textarea-resizable {\n    overflow: hidden;\n    resize: none;\n}\n\n.p-textarea-sm {\n    font-size: ").concat(dt2("textarea.sm.font.size"), ";\n    padding-block: ").concat(dt2("textarea.sm.padding.y"), ";\n    padding-inline: ").concat(dt2("textarea.sm.padding.x"), ";\n}\n\n.p-textarea-lg {\n    font-size: ").concat(dt2("textarea.lg.font.size"), ";\n    padding-block: ").concat(dt2("textarea.lg.padding.y"), ";\n    padding-inline: ").concat(dt2("textarea.lg.padding.x"), ";\n}\n");
}, "theme");
var classes$w = {
  root: /* @__PURE__ */ __name(function root11(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-textarea p-component", {
      "p-filled": instance.$filled,
      "p-textarea-resizable ": props.autoResize,
      "p-textarea-sm p-inputfield-sm": props.size === "small",
      "p-textarea-lg p-inputfield-lg": props.size === "large",
      "p-invalid": instance.$invalid,
      "p-variant-filled": instance.$variant === "filled",
      "p-textarea-fluid": instance.$fluid
    }];
  }, "root")
};
var TextareaStyle = BaseStyle$1.extend({
  name: "textarea",
  theme: theme$s,
  classes: classes$w
});
var script$1$x = {
  name: "BaseTextarea",
  "extends": script$17,
  props: {
    autoResize: Boolean
  },
  style: TextareaStyle,
  provide: /* @__PURE__ */ __name(function provide18() {
    return {
      $pcTextarea: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$M = {
  name: "Textarea",
  "extends": script$1$x,
  inheritAttrs: false,
  observer: null,
  mounted: /* @__PURE__ */ __name(function mounted10() {
    var _this = this;
    if (this.autoResize) {
      this.observer = new ResizeObserver(function() {
        _this.resize();
      });
      this.observer.observe(this.$el);
    }
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated7() {
    if (this.autoResize) {
      this.resize();
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount5() {
    if (this.observer) {
      this.observer.disconnect();
    }
  }, "beforeUnmount"),
  methods: {
    resize: /* @__PURE__ */ __name(function resize() {
      if (!this.$el.offsetParent) return;
      this.$el.style.height = "auto";
      this.$el.style.height = this.$el.scrollHeight + "px";
      if (parseFloat(this.$el.style.height) >= parseFloat(this.$el.style.maxHeight)) {
        this.$el.style.overflowY = "scroll";
        this.$el.style.height = this.$el.style.maxHeight;
      } else {
        this.$el.style.overflow = "hidden";
      }
    }, "resize"),
    onInput: /* @__PURE__ */ __name(function onInput2(event) {
      if (this.autoResize) {
        this.resize();
      }
      this.writeValue(event.target.value, event);
    }, "onInput")
  },
  computed: {
    attrs: /* @__PURE__ */ __name(function attrs4() {
      return mergeProps$2(this.ptmi("root", {
        context: {
          filled: this.$filled,
          disabled: this.disabled
        }
      }), this.formField);
    }, "attrs")
  }
};
var _hoisted_1$1D = ["value", "disabled", "aria-invalid"];
function render$K(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("textarea", mergeProps$2({
    "class": _ctx.cx("root"),
    value: _ctx.d_value,
    disabled: _ctx.disabled,
    "aria-invalid": _ctx.invalid || void 0,
    onInput: _cache[0] || (_cache[0] = function() {
      return $options.onInput && $options.onInput.apply($options, arguments);
    })
  }, $options.attrs), null, 16, _hoisted_1$1D);
}
__name(render$K, "render$K");
script$M.render = render$K;
const checkboxField = z.boolean().optional();
const issueReportSchema = z.object({
  contactInfo: z.string().email().max(320).optional().or(z.literal("")),
  details: z.string().max(5e3).optional()
}).catchall(checkboxField).refine((data30) => Object.values(data30).some((value3) => value3), {
  path: ["details"]
});
const _hoisted_1$1C = { class: "flex items-center gap-2" };
const _hoisted_2$1a = { class: "font-bold" };
const _hoisted_3$Q = { class: "flex justify-end gap-4" };
const _hoisted_4$B = { class: "p-4 mt-2 border border-round surface-border shadow-1" };
const _hoisted_5$t = { class: "flex flex-row gap-3 mb-2" };
const _hoisted_6$l = ["for"];
const _hoisted_7$a = { class: "flex flex-row gap-3 mt-2" };
const _hoisted_8$7 = ["for"];
const ISSUE_NAME = "User reported issue";
const _sfc_main$1B = /* @__PURE__ */ defineComponent({
  __name: "ReportIssuePanel",
  props: {
    errorType: {},
    defaultFields: {},
    extraFields: {},
    tags: {},
    title: {}
  },
  setup(__props) {
    const props = __props;
    const { defaultFields = ["Workflow", "Logs", "SystemStats", "Settings"] } = props;
    const { t: t2 } = useI18n();
    const toast = useToast();
    const selection = ref([]);
    const contactPrefs = ref([]);
    const submitted = ref(false);
    const contactCheckboxes = [
      { label: t2("issueReport.contactFollowUp"), value: "followUp" },
      { label: t2("issueReport.notifyResolve"), value: "notifyOnResolution" }
    ];
    const defaultFieldsConfig = [
      {
        label: t2("issueReport.systemStats"),
        value: "SystemStats",
        getData: /* @__PURE__ */ __name(() => api.getSystemStats(), "getData"),
        optIn: true
      },
      {
        label: t2("g.workflow"),
        value: "Workflow",
        getData: /* @__PURE__ */ __name(() => cloneDeep$1(app$2.graph.asSerialisable()), "getData"),
        optIn: true
      },
      {
        label: t2("g.logs"),
        value: "Logs",
        getData: /* @__PURE__ */ __name(() => api.getLogs(), "getData"),
        optIn: true
      },
      {
        label: t2("g.settings"),
        value: "Settings",
        getData: /* @__PURE__ */ __name(() => api.getSettings(), "getData"),
        optIn: true
      }
    ];
    const fields = computed(() => [
      ...defaultFieldsConfig.filter(
        ({ value: value3 }) => defaultFields.includes(value3)
      ),
      ...props.extraFields ?? []
    ]);
    const createUser = /* @__PURE__ */ __name((formData) => ({
      email: formData.contactInfo || void 0
    }), "createUser");
    const createExtraData = /* @__PURE__ */ __name(async (formData) => {
      const result = {};
      const isChecked2 = /* @__PURE__ */ __name((fieldValue) => formData[fieldValue], "isChecked");
      await Promise.all(
        fields.value.filter((field2) => !field2.optIn || isChecked2(field2.value)).map(async (field2) => {
          try {
            result[field2.value] = await field2.getData();
          } catch (error2) {
            console.error(`Failed to collect ${field2.value}:`, error2);
            result[field2.value] = { error: String(error2) };
          }
        })
      );
      return result;
    }, "createExtraData");
    const createCaptureContext = /* @__PURE__ */ __name(async (formData) => {
      return {
        user: createUser(formData),
        level: "error",
        tags: {
          errorType: props.errorType,
          followUp: formData.contactInfo ? formData.followUp : false,
          notifyOnResolution: formData.contactInfo ? formData.notifyOnResolution : false,
          isElectron: isElectron(),
          ..._.mapValues(props.tags, (tag) => _.trim(tag).replace(/[\n\r\t]/g, " "))
        },
        extra: {
          details: formData.details,
          ...await createExtraData(formData)
        }
      };
    }, "createCaptureContext");
    const submit = /* @__PURE__ */ __name(async (event) => {
      if (event.valid) {
        try {
          const captureContext = await createCaptureContext(event.values);
          captureMessage(ISSUE_NAME, captureContext);
          submitted.value = true;
          toast.add({
            severity: "success",
            summary: t2("g.reportSent"),
            life: 3e3
          });
        } catch (error2) {
          toast.add({
            severity: "error",
            summary: t2("g.error"),
            detail: error2 instanceof Error ? error2.message : String(error2),
            life: 3e3
          });
        }
      }
    }, "submit");
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createBlock(unref(script$U), {
        onSubmit: submit,
        resolver: unref(zodResolver)(unref(issueReportSchema))
      }, {
        default: withCtx(($form) => [
          createVNode(unref(script$N), {
            pt: _ctx.$attrs.pt
          }, {
            header: withCtx(() => [
              createBaseVNode("div", _hoisted_1$1C, [
                createBaseVNode("span", _hoisted_2$1a, toDisplayString$1(_ctx.title), 1)
              ])
            ]),
            footer: withCtx(() => [
              createBaseVNode("div", _hoisted_3$Q, [
                withDirectives(createVNode(unref(script$10), {
                  label: submitted.value ? _ctx.$t("g.reportSent") : _ctx.$t("g.reportIssue"),
                  severity: submitted.value ? "secondary" : "primary",
                  icon: submitted.value ? "pi pi-check" : "pi pi-send",
                  disabled: submitted.value,
                  type: "submit"
                }, null, 8, ["label", "severity", "icon", "disabled"]), [
                  [_directive_tooltip, !submitted.value ? _ctx.$t("g.reportIssueTooltip") : void 0]
                ])
              ])
            ]),
            default: withCtx(() => [
              createBaseVNode("div", _hoisted_4$B, [
                createBaseVNode("div", _hoisted_5$t, [
                  (openBlock(true), createElementBlock(Fragment$1, null, renderList(fields.value, (field2) => {
                    return openBlock(), createElementBlock("div", {
                      key: field2.value
                    }, [
                      field2.optIn ? (openBlock(), createBlock(unref(script$T), {
                        key: 0,
                        name: field2.value,
                        class: "flex space-x-1"
                      }, {
                        default: withCtx(($field) => [
                          createVNode(unref(script$Q), mergeProps$2({ ref_for: true }, $field, {
                            inputId: field2.value,
                            value: field2.value,
                            modelValue: selection.value,
                            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selection.value = $event)
                          }), null, 16, ["inputId", "value", "modelValue"]),
                          createBaseVNode("label", {
                            for: field2.value
                          }, toDisplayString$1(field2.label), 9, _hoisted_6$l)
                        ]),
                        _: 2
                      }, 1032, ["name"])) : createCommentVNode("", true)
                    ]);
                  }), 128))
                ]),
                createVNode(unref(script$T), {
                  class: "mb-4",
                  name: "details"
                }, {
                  default: withCtx(($field) => [
                    createVNode(unref(script$M), mergeProps$2($field, {
                      class: "w-full",
                      rows: "5",
                      placeholder: _ctx.$t("issueReport.provideAdditionalDetails"),
                      "aria-label": _ctx.$t("issueReport.provideAdditionalDetails")
                    }), null, 16, ["placeholder", "aria-label"]),
                    $field?.error && $field.touched && $field.value ? (openBlock(), createBlock(unref(script$Z), {
                      key: 0,
                      severity: "error",
                      size: "small",
                      variant: "simple"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString$1(unref(t2)("issueReport.validation.maxLength")), 1)
                      ]),
                      _: 1
                    })) : createCommentVNode("", true)
                  ]),
                  _: 1
                }),
                createVNode(unref(script$T), { name: "contactInfo" }, {
                  default: withCtx(($field) => [
                    createVNode(unref(script$P), mergeProps$2($field, {
                      class: "w-full",
                      placeholder: _ctx.$t("issueReport.provideEmail")
                    }), null, 16, ["placeholder"]),
                    $field?.error && $field.touched && $field.value !== "" ? (openBlock(), createBlock(unref(script$Z), {
                      key: 0,
                      severity: "error",
                      size: "small",
                      variant: "simple"
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString$1(unref(t2)("issueReport.validation.invalidEmail")), 1)
                      ]),
                      _: 1
                    })) : createCommentVNode("", true)
                  ]),
                  _: 1
                }),
                createBaseVNode("div", _hoisted_7$a, [
                  (openBlock(), createElementBlock(Fragment$1, null, renderList(contactCheckboxes, (checkbox) => {
                    return createBaseVNode("div", {
                      key: checkbox.value
                    }, [
                      createVNode(unref(script$T), {
                        name: checkbox.value,
                        class: "flex space-x-1"
                      }, {
                        default: withCtx(($field) => [
                          createVNode(unref(script$Q), mergeProps$2({ ref_for: true }, $field, {
                            inputId: checkbox.value,
                            value: checkbox.value,
                            modelValue: contactPrefs.value,
                            "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => contactPrefs.value = $event),
                            disabled: $form.contactInfo?.error || !$form.contactInfo?.value
                          }), null, 16, ["inputId", "value", "modelValue", "disabled"]),
                          createBaseVNode("label", {
                            for: checkbox.value
                          }, toDisplayString$1(checkbox.label), 9, _hoisted_8$7)
                        ]),
                        _: 2
                      }, 1032, ["name"])
                    ]);
                  }), 64))
                ])
              ])
            ]),
            _: 2
          }, 1032, ["pt"])
        ]),
        _: 1
      }, 8, ["resolver"]);
    };
  }
});
const _hoisted_1$1B = { class: "comfy-error-report" };
const _hoisted_2$19 = { class: "flex gap-2 justify-center" };
const _hoisted_3$P = { class: "wrapper-pre" };
const _hoisted_4$A = { class: "action-container" };
const repoOwner = "comfyanonymous";
const repoName = "ComfyUI";
const _sfc_main$1A = /* @__PURE__ */ defineComponent({
  __name: "ExecutionErrorDialogContent",
  props: {
    error: {}
  },
  setup(__props) {
    const props = __props;
    const reportContent = ref("");
    const reportOpen = ref(false);
    const showReport = /* @__PURE__ */ __name(() => {
      reportOpen.value = true;
    }, "showReport");
    const sendReportOpen = ref(false);
    const showSendReport = /* @__PURE__ */ __name(() => {
      sendReportOpen.value = true;
    }, "showSendReport");
    const toast = useToast();
    const { t: t2 } = useI18n();
    const stackTraceField = computed(() => {
      return {
        label: t2("issueReport.stackTrace"),
        value: "StackTrace",
        optIn: true,
        getData: /* @__PURE__ */ __name(() => props.error.traceback?.join("\n"), "getData")
      };
    });
    onMounted(async () => {
      try {
        const [systemStats, logs] = await Promise.all([
          api.getSystemStats(),
          api.getLogs()
        ]);
        generateReport(systemStats, logs);
      } catch (error2) {
        console.error("Error fetching system stats or logs:", error2);
        toast.add({
          severity: "error",
          summary: "Error",
          detail: "Failed to fetch system information",
          life: 5e3
        });
      }
    });
    const generateReport = /* @__PURE__ */ __name((systemStats, logs) => {
      const MAX_JSON_LENGTH = 2e4;
      const workflowJSONString = JSON.stringify(app$2.graph.serialize());
      const workflowText = workflowJSONString.length > MAX_JSON_LENGTH ? "Workflow too large. Please manually upload the workflow from local file system." : workflowJSONString;
      reportContent.value = `
# ComfyUI Error Report
## Error Details
- **Node ID:** ${props.error.node_id}
- **Node Type:** ${props.error.node_type}
- **Exception Type:** ${props.error.exception_type}
- **Exception Message:** ${props.error.exception_message}
## Stack Trace
\`\`\`
${props.error.traceback.join("\n")}
\`\`\`
## System Information
- **ComfyUI Version:** ${systemStats.system.comfyui_version}
- **Arguments:** ${systemStats.system.argv.join(" ")}
- **OS:** ${systemStats.system.os}
- **Python Version:** ${systemStats.system.python_version}
- **Embedded Python:** ${systemStats.system.embedded_python}
- **PyTorch Version:** ${systemStats.system.pytorch_version}
## Devices
${systemStats.devices.map(
        (device) => `
- **Name:** ${device.name}
  - **Type:** ${device.type}
  - **VRAM Total:** ${device.vram_total}
  - **VRAM Free:** ${device.vram_free}
  - **Torch VRAM Total:** ${device.torch_vram_total}
  - **Torch VRAM Free:** ${device.torch_vram_free}
`
      ).join("\n")}
## Logs
\`\`\`
${logs}
\`\`\`
## Attached Workflow
Please make sure that workflow does not contain any sensitive information such as API keys or passwords.
\`\`\`
${workflowText}
\`\`\`

## Additional Context
(Please add any additional context or steps to reproduce the error here)
`;
    }, "generateReport");
    const { copyToClipboard } = useCopyToClipboard();
    const copyReportToClipboard = /* @__PURE__ */ __name(async () => {
      await copyToClipboard(reportContent.value);
    }, "copyReportToClipboard");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(NoResultsPlaceholder, {
          icon: "pi pi-exclamation-circle",
          title: props.error.node_type,
          message: props.error.exception_message
        }, null, 8, ["title", "message"]),
        createBaseVNode("div", _hoisted_1$1B, [
          createBaseVNode("div", _hoisted_2$19, [
            withDirectives(createVNode(unref(script$10), {
              text: "",
              label: _ctx.$t("g.showReport"),
              onClick: showReport
            }, null, 8, ["label"]), [
              [vShow, !reportOpen.value]
            ]),
            withDirectives(createVNode(unref(script$10), {
              text: "",
              label: _ctx.$t("issueReport.helpFix"),
              onClick: showSendReport
            }, null, 8, ["label"]), [
              [vShow, !sendReportOpen.value]
            ])
          ]),
          reportOpen.value ? (openBlock(), createElementBlock(Fragment$1, { key: 0 }, [
            createVNode(unref(script$Y)),
            createVNode(unref(script$X), { style: { "width": "100%", "height": "400px", "max-width": "80vw" } }, {
              default: withCtx(() => [
                createBaseVNode("pre", _hoisted_3$P, toDisplayString$1(reportContent.value), 1)
              ]),
              _: 1
            }),
            createVNode(unref(script$Y))
          ], 64)) : createCommentVNode("", true),
          sendReportOpen.value ? (openBlock(), createBlock(_sfc_main$1B, {
            key: 1,
            title: _ctx.$t("issueReport.submitErrorReport"),
            "error-type": "graphExecutionError",
            "extra-fields": [stackTraceField.value],
            tags: {
              exceptionMessage: props.error.exception_message,
              nodeType: props.error.node_type
            }
          }, null, 8, ["title", "extra-fields", "tags"])) : createCommentVNode("", true),
          createBaseVNode("div", _hoisted_4$A, [
            createVNode(_sfc_main$1C, {
              errorMessage: props.error.exception_message,
              repoOwner,
              repoName
            }, null, 8, ["errorMessage"]),
            reportOpen.value ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              label: _ctx.$t("g.copyToClipboard"),
              icon: "pi pi-copy",
              onClick: copyReportToClipboard
            }, null, 8, ["label"])) : createCommentVNode("", true)
          ])
        ])
      ], 64);
    };
  }
});
const ExecutionErrorDialogContent = /* @__PURE__ */ _export_sfc(_sfc_main$1A, [["__scopeId", "data-v-efb6f586"]]);
const _hoisted_1$1A = {
  class: "p-2 h-full",
  "aria-labelledby": "issue-report-title"
};
const _hoisted_2$18 = { class: "flex flex-col items-center w-full" };
const _hoisted_3$O = {
  id: "issue-report-title",
  class: "text-4xl"
};
const _hoisted_4$z = {
  key: 0,
  class: "text-muted mt-0"
};
const _sfc_main$1z = /* @__PURE__ */ defineComponent({
  __name: "IssueReportDialogContent",
  props: {
    title: {},
    subtitle: {},
    panelProps: {}
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1A, [
        createVNode(unref(script$N), { pt: {
          root: "border-none",
          content: "p-0"
        } }, {
          header: withCtx(() => [
            createBaseVNode("header", _hoisted_2$18, [
              createBaseVNode("h2", _hoisted_3$O, toDisplayString$1(_ctx.title), 1),
              _ctx.subtitle ? (openBlock(), createElementBlock("span", _hoisted_4$z, toDisplayString$1(_ctx.subtitle), 1)) : createCommentVNode("", true)
            ])
          ]),
          default: withCtx(() => [
            createVNode(_sfc_main$1B, mergeProps$2(_ctx.panelProps, { pt: { root: "border-none" } }), null, 16)
          ]),
          _: 1
        })
      ]);
    };
  }
});
var script$L = {
  name: "BlankIcon",
  "extends": script$16
};
function render$J(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("rect", {
    width: "1",
    height: "1",
    fill: "currentColor",
    "fill-opacity": "0"
  }, null, -1)]), 16);
}
__name(render$J, "render$J");
script$L.render = render$J;
var script$K = {
  name: "SearchIcon",
  "extends": script$16
};
function render$I(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    "fill-rule": "evenodd",
    "clip-rule": "evenodd",
    d: "M2.67602 11.0265C3.6661 11.688 4.83011 12.0411 6.02086 12.0411C6.81149 12.0411 7.59438 11.8854 8.32483 11.5828C8.87005 11.357 9.37808 11.0526 9.83317 10.6803L12.9769 13.8241C13.0323 13.8801 13.0983 13.9245 13.171 13.9548C13.2438 13.985 13.3219 14.0003 13.4007 14C13.4795 14.0003 13.5575 13.985 13.6303 13.9548C13.7031 13.9245 13.7691 13.8801 13.8244 13.8241C13.9367 13.7116 13.9998 13.5592 13.9998 13.4003C13.9998 13.2414 13.9367 13.089 13.8244 12.9765L10.6807 9.8328C11.053 9.37773 11.3573 8.86972 11.5831 8.32452C11.8857 7.59408 12.0414 6.81119 12.0414 6.02056C12.0414 4.8298 11.6883 3.66579 11.0268 2.67572C10.3652 1.68564 9.42494 0.913972 8.32483 0.45829C7.22472 0.00260857 6.01418 -0.116618 4.84631 0.115686C3.67844 0.34799 2.60568 0.921393 1.76369 1.76338C0.921698 2.60537 0.348296 3.67813 0.115991 4.84601C-0.116313 6.01388 0.00291375 7.22441 0.458595 8.32452C0.914277 9.42464 1.68595 10.3649 2.67602 11.0265ZM3.35565 2.0158C4.14456 1.48867 5.07206 1.20731 6.02086 1.20731C7.29317 1.20731 8.51338 1.71274 9.41304 2.6124C10.3127 3.51206 10.8181 4.73226 10.8181 6.00457C10.8181 6.95337 10.5368 7.88088 10.0096 8.66978C9.48251 9.45868 8.73328 10.0736 7.85669 10.4367C6.98011 10.7997 6.01554 10.8947 5.08496 10.7096C4.15439 10.5245 3.2996 10.0676 2.62869 9.39674C1.95778 8.72583 1.50089 7.87104 1.31579 6.94046C1.13068 6.00989 1.22568 5.04532 1.58878 4.16874C1.95187 3.29215 2.56675 2.54292 3.35565 2.0158Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$I, "render$I");
script$K.render = render$I;
var theme$r = /* @__PURE__ */ __name(function theme19(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-iconfield {\n    position: relative;\n}\n\n.p-inputicon {\n    position: absolute;\n    top: 50%;\n    margin-top: calc(-1 * (".concat(dt2("icon.size"), " / 2));\n    color: ").concat(dt2("iconfield.icon.color"), ";\n    line-height: 1;\n}\n\n.p-iconfield .p-inputicon:first-child {\n    inset-inline-start: ").concat(dt2("form.field.padding.x"), ";\n}\n\n.p-iconfield .p-inputicon:last-child {\n    inset-inline-end: ").concat(dt2("form.field.padding.x"), ";\n}\n\n.p-iconfield .p-inputtext:not(:first-child) {\n    padding-inline-start: calc((").concat(dt2("form.field.padding.x"), " * 2) + ").concat(dt2("icon.size"), ");\n}\n\n.p-iconfield .p-inputtext:not(:last-child) {\n    padding-inline-end: calc((").concat(dt2("form.field.padding.x"), " * 2) + ").concat(dt2("icon.size"), ");\n}\n\n.p-iconfield:has(.p-inputfield-sm) .p-inputicon {\n    font-size: ").concat(dt2("form.field.sm.font.size"), ";\n    width: ").concat(dt2("form.field.sm.font.size"), ";\n    height: ").concat(dt2("form.field.sm.font.size"), ";\n    margin-top: calc(-1 * (").concat(dt2("form.field.sm.font.size"), " / 2));\n}\n\n.p-iconfield:has(.p-inputfield-lg) .p-inputicon {\n    font-size: ").concat(dt2("form.field.lg.font.size"), ";\n    width: ").concat(dt2("form.field.lg.font.size"), ";\n    height: ").concat(dt2("form.field.lg.font.size"), ";\n    margin-top: calc(-1 * (").concat(dt2("form.field.lg.font.size"), " / 2));\n}\n");
}, "theme");
var classes$v = {
  root: "p-iconfield"
};
var IconFieldStyle = BaseStyle$1.extend({
  name: "iconfield",
  theme: theme$r,
  classes: classes$v
});
var script$1$w = {
  name: "BaseIconField",
  "extends": script$1b,
  style: IconFieldStyle,
  provide: /* @__PURE__ */ __name(function provide19() {
    return {
      $pcIconField: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$J = {
  name: "IconField",
  "extends": script$1$w,
  inheritAttrs: false
};
function render$H(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16);
}
__name(render$H, "render$H");
script$J.render = render$H;
var classes$u = {
  root: "p-inputicon"
};
var InputIconStyle = BaseStyle$1.extend({
  name: "inputicon",
  classes: classes$u
});
var script$1$v = {
  name: "BaseInputIcon",
  "extends": script$1b,
  style: InputIconStyle,
  props: {
    "class": null
  },
  provide: /* @__PURE__ */ __name(function provide20() {
    return {
      $pcInputIcon: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$I = {
  name: "InputIcon",
  "extends": script$1$v,
  inheritAttrs: false,
  computed: {
    containerClass: /* @__PURE__ */ __name(function containerClass() {
      return [this.cx("root"), this["class"]];
    }, "containerClass")
  }
};
function render$G(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("span", mergeProps$2({
    "class": $options.containerClass
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16);
}
__name(render$G, "render$G");
script$I.render = render$G;
var theme$q = /* @__PURE__ */ __name(function theme20(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-virtualscroller-loader {\n    background: ".concat(dt2("virtualscroller.loader.mask.background"), ";\n    color: ").concat(dt2("virtualscroller.loader.mask.color"), ";\n}\n\n.p-virtualscroller-loading-icon {\n    font-size: ").concat(dt2("virtualscroller.loader.icon.size"), ";\n    width: ").concat(dt2("virtualscroller.loader.icon.size"), ";\n    height: ").concat(dt2("virtualscroller.loader.icon.size"), ";\n}\n");
}, "theme");
var css = "\n.p-virtualscroller {\n    position: relative;\n    overflow: auto;\n    contain: strict;\n    transform: translateZ(0);\n    will-change: scroll-position;\n    outline: 0 none;\n}\n\n.p-virtualscroller-content {\n    position: absolute;\n    top: 0;\n    left: 0;\n    min-height: 100%;\n    min-width: 100%;\n    will-change: transform;\n}\n\n.p-virtualscroller-spacer {\n    position: absolute;\n    top: 0;\n    left: 0;\n    height: 1px;\n    width: 1px;\n    transform-origin: 0 0;\n    pointer-events: none;\n}\n\n.p-virtualscroller-loader {\n    position: sticky;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n}\n\n.p-virtualscroller-loader-mask {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n}\n\n.p-virtualscroller-horizontal > .p-virtualscroller-content {\n    display: flex;\n}\n\n.p-virtualscroller-inline .p-virtualscroller-content {\n    position: static;\n}\n";
var VirtualScrollerStyle = BaseStyle$1.extend({
  name: "virtualscroller",
  css,
  theme: theme$q
});
var script$1$u = {
  name: "BaseVirtualScroller",
  "extends": script$1b,
  props: {
    id: {
      type: String,
      "default": null
    },
    style: null,
    "class": null,
    items: {
      type: Array,
      "default": null
    },
    itemSize: {
      type: [Number, Array],
      "default": 0
    },
    scrollHeight: null,
    scrollWidth: null,
    orientation: {
      type: String,
      "default": "vertical"
    },
    numToleratedItems: {
      type: Number,
      "default": null
    },
    delay: {
      type: Number,
      "default": 0
    },
    resizeDelay: {
      type: Number,
      "default": 10
    },
    lazy: {
      type: Boolean,
      "default": false
    },
    disabled: {
      type: Boolean,
      "default": false
    },
    loaderDisabled: {
      type: Boolean,
      "default": false
    },
    columns: {
      type: Array,
      "default": null
    },
    loading: {
      type: Boolean,
      "default": false
    },
    showSpacer: {
      type: Boolean,
      "default": true
    },
    showLoader: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    inline: {
      type: Boolean,
      "default": false
    },
    step: {
      type: Number,
      "default": 0
    },
    appendOnly: {
      type: Boolean,
      "default": false
    },
    autoSize: {
      type: Boolean,
      "default": false
    }
  },
  style: VirtualScrollerStyle,
  provide: /* @__PURE__ */ __name(function provide21() {
    return {
      $pcVirtualScroller: this,
      $parentInstance: this
    };
  }, "provide"),
  beforeMount: /* @__PURE__ */ __name(function beforeMount4() {
    var _this$$primevueConfig;
    VirtualScrollerStyle.loadCSS({
      nonce: (_this$$primevueConfig = this.$primevueConfig) === null || _this$$primevueConfig === void 0 || (_this$$primevueConfig = _this$$primevueConfig.csp) === null || _this$$primevueConfig === void 0 ? void 0 : _this$$primevueConfig.nonce
    });
  }, "beforeMount")
};
function _typeof$b(o2) {
  "@babel/helpers - typeof";
  return _typeof$b = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$b(o2);
}
__name(_typeof$b, "_typeof$b");
function ownKeys$d(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$d, "ownKeys$d");
function _objectSpread$d(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$d(Object(t2), true).forEach(function(r3) {
      _defineProperty$b(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$d(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$d, "_objectSpread$d");
function _defineProperty$b(e2, r2, t2) {
  return (r2 = _toPropertyKey$a(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$b, "_defineProperty$b");
function _toPropertyKey$a(t2) {
  var i2 = _toPrimitive$a(t2, "string");
  return "symbol" == _typeof$b(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$a, "_toPropertyKey$a");
function _toPrimitive$a(t2, r2) {
  if ("object" != _typeof$b(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$b(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$a, "_toPrimitive$a");
var script$H = {
  name: "VirtualScroller",
  "extends": script$1$u,
  inheritAttrs: false,
  emits: ["update:numToleratedItems", "scroll", "scroll-index-change", "lazy-load"],
  data: /* @__PURE__ */ __name(function data9() {
    var both = this.isBoth();
    return {
      first: both ? {
        rows: 0,
        cols: 0
      } : 0,
      last: both ? {
        rows: 0,
        cols: 0
      } : 0,
      page: both ? {
        rows: 0,
        cols: 0
      } : 0,
      numItemsInViewport: both ? {
        rows: 0,
        cols: 0
      } : 0,
      lastScrollPos: both ? {
        top: 0,
        left: 0
      } : 0,
      d_numToleratedItems: this.numToleratedItems,
      d_loading: this.loading,
      loaderArr: [],
      spacerStyle: {},
      contentStyle: {}
    };
  }, "data"),
  element: null,
  content: null,
  lastScrollPos: null,
  scrollTimeout: null,
  resizeTimeout: null,
  defaultWidth: 0,
  defaultHeight: 0,
  defaultContentWidth: 0,
  defaultContentHeight: 0,
  isRangeChanged: false,
  lazyLoadState: {},
  resizeListener: null,
  initialized: false,
  watch: {
    numToleratedItems: /* @__PURE__ */ __name(function numToleratedItems(newValue2) {
      this.d_numToleratedItems = newValue2;
    }, "numToleratedItems"),
    loading: /* @__PURE__ */ __name(function loading(newValue2, oldValue) {
      if (this.lazy && newValue2 !== oldValue && newValue2 !== this.d_loading) {
        this.d_loading = newValue2;
      }
    }, "loading"),
    items: /* @__PURE__ */ __name(function items(newValue2, oldValue) {
      if (!oldValue || oldValue.length !== (newValue2 || []).length) {
        this.init();
        this.calculateAutoSize();
      }
    }, "items"),
    itemSize: /* @__PURE__ */ __name(function itemSize() {
      this.init();
      this.calculateAutoSize();
    }, "itemSize"),
    orientation: /* @__PURE__ */ __name(function orientation() {
      this.lastScrollPos = this.isBoth() ? {
        top: 0,
        left: 0
      } : 0;
    }, "orientation"),
    scrollHeight: /* @__PURE__ */ __name(function scrollHeight() {
      this.init();
      this.calculateAutoSize();
    }, "scrollHeight"),
    scrollWidth: /* @__PURE__ */ __name(function scrollWidth() {
      this.init();
      this.calculateAutoSize();
    }, "scrollWidth")
  },
  mounted: /* @__PURE__ */ __name(function mounted11() {
    this.viewInit();
    this.lastScrollPos = this.isBoth() ? {
      top: 0,
      left: 0
    } : 0;
    this.lazyLoadState = this.lazyLoadState || {};
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated8() {
    !this.initialized && this.viewInit();
  }, "updated"),
  unmounted: /* @__PURE__ */ __name(function unmounted6() {
    this.unbindResizeListener();
    this.initialized = false;
  }, "unmounted"),
  methods: {
    viewInit: /* @__PURE__ */ __name(function viewInit() {
      if (isVisible$1(this.element)) {
        this.setContentEl(this.content);
        this.init();
        this.calculateAutoSize();
        this.bindResizeListener();
        this.defaultWidth = getWidth$1(this.element);
        this.defaultHeight = getHeight$1(this.element);
        this.defaultContentWidth = getWidth$1(this.content);
        this.defaultContentHeight = getHeight$1(this.content);
        this.initialized = true;
      }
    }, "viewInit"),
    init: /* @__PURE__ */ __name(function init2() {
      if (!this.disabled) {
        this.setSize();
        this.calculateOptions();
        this.setSpacerSize();
      }
    }, "init"),
    isVertical: /* @__PURE__ */ __name(function isVertical() {
      return this.orientation === "vertical";
    }, "isVertical"),
    isHorizontal: /* @__PURE__ */ __name(function isHorizontal() {
      return this.orientation === "horizontal";
    }, "isHorizontal"),
    isBoth: /* @__PURE__ */ __name(function isBoth() {
      return this.orientation === "both";
    }, "isBoth"),
    scrollTo: /* @__PURE__ */ __name(function scrollTo2(options5) {
      this.element && this.element.scrollTo(options5);
    }, "scrollTo"),
    scrollToIndex: /* @__PURE__ */ __name(function scrollToIndex(index2) {
      var _this = this;
      var behavior = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "auto";
      var both = this.isBoth();
      var horizontal2 = this.isHorizontal();
      var valid = both ? index2.every(function(i2) {
        return i2 > -1;
      }) : index2 > -1;
      if (valid) {
        var first2 = this.first;
        var _this$element = this.element, _this$element$scrollT = _this$element.scrollTop, scrollTop2 = _this$element$scrollT === void 0 ? 0 : _this$element$scrollT, _this$element$scrollL = _this$element.scrollLeft, scrollLeft = _this$element$scrollL === void 0 ? 0 : _this$element$scrollL;
        var _this$calculateNumIte = this.calculateNumItems(), numToleratedItems2 = _this$calculateNumIte.numToleratedItems;
        var contentPos = this.getContentPosition();
        var itemSize2 = this.itemSize;
        var calculateFirst = /* @__PURE__ */ __name(function calculateFirst2() {
          var _index = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 0;
          var _numT = arguments.length > 1 ? arguments[1] : void 0;
          return _index <= _numT ? 0 : _index;
        }, "calculateFirst");
        var calculateCoord = /* @__PURE__ */ __name(function calculateCoord2(_first, _size, _cpos) {
          return _first * _size + _cpos;
        }, "calculateCoord");
        var scrollTo3 = /* @__PURE__ */ __name(function scrollTo4() {
          var left = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 0;
          var top = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 0;
          return _this.scrollTo({
            left,
            top,
            behavior
          });
        }, "scrollTo");
        var newFirst = both ? {
          rows: 0,
          cols: 0
        } : 0;
        var isRangeChanged = false, isScrollChanged = false;
        if (both) {
          newFirst = {
            rows: calculateFirst(index2[0], numToleratedItems2[0]),
            cols: calculateFirst(index2[1], numToleratedItems2[1])
          };
          scrollTo3(calculateCoord(newFirst.cols, itemSize2[1], contentPos.left), calculateCoord(newFirst.rows, itemSize2[0], contentPos.top));
          isScrollChanged = this.lastScrollPos.top !== scrollTop2 || this.lastScrollPos.left !== scrollLeft;
          isRangeChanged = newFirst.rows !== first2.rows || newFirst.cols !== first2.cols;
        } else {
          newFirst = calculateFirst(index2, numToleratedItems2);
          horizontal2 ? scrollTo3(calculateCoord(newFirst, itemSize2, contentPos.left), scrollTop2) : scrollTo3(scrollLeft, calculateCoord(newFirst, itemSize2, contentPos.top));
          isScrollChanged = this.lastScrollPos !== (horizontal2 ? scrollLeft : scrollTop2);
          isRangeChanged = newFirst !== first2;
        }
        this.isRangeChanged = isRangeChanged;
        isScrollChanged && (this.first = newFirst);
      }
    }, "scrollToIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView2(index2, to) {
      var _this2 = this;
      var behavior = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "auto";
      if (to) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        var valid = both ? index2.every(function(i2) {
          return i2 > -1;
        }) : index2 > -1;
        if (valid) {
          var _this$getRenderedRang = this.getRenderedRange(), first2 = _this$getRenderedRang.first, viewport = _this$getRenderedRang.viewport;
          var scrollTo3 = /* @__PURE__ */ __name(function scrollTo4() {
            var left = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 0;
            var top = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 0;
            return _this2.scrollTo({
              left,
              top,
              behavior
            });
          }, "scrollTo");
          var isToStart = to === "to-start";
          var isToEnd = to === "to-end";
          if (isToStart) {
            if (both) {
              if (viewport.first.rows - first2.rows > index2[0]) {
                scrollTo3(viewport.first.cols * this.itemSize[1], (viewport.first.rows - 1) * this.itemSize[0]);
              } else if (viewport.first.cols - first2.cols > index2[1]) {
                scrollTo3((viewport.first.cols - 1) * this.itemSize[1], viewport.first.rows * this.itemSize[0]);
              }
            } else {
              if (viewport.first - first2 > index2) {
                var pos = (viewport.first - 1) * this.itemSize;
                horizontal2 ? scrollTo3(pos, 0) : scrollTo3(0, pos);
              }
            }
          } else if (isToEnd) {
            if (both) {
              if (viewport.last.rows - first2.rows <= index2[0] + 1) {
                scrollTo3(viewport.first.cols * this.itemSize[1], (viewport.first.rows + 1) * this.itemSize[0]);
              } else if (viewport.last.cols - first2.cols <= index2[1] + 1) {
                scrollTo3((viewport.first.cols + 1) * this.itemSize[1], viewport.first.rows * this.itemSize[0]);
              }
            } else {
              if (viewport.last - first2 <= index2 + 1) {
                var _pos2 = (viewport.first + 1) * this.itemSize;
                horizontal2 ? scrollTo3(_pos2, 0) : scrollTo3(0, _pos2);
              }
            }
          }
        }
      } else {
        this.scrollToIndex(index2, behavior);
      }
    }, "scrollInView"),
    getRenderedRange: /* @__PURE__ */ __name(function getRenderedRange() {
      var calculateFirstInViewport = /* @__PURE__ */ __name(function calculateFirstInViewport2(_pos, _size) {
        return Math.floor(_pos / (_size || _pos));
      }, "calculateFirstInViewport");
      var firstInViewport = this.first;
      var lastInViewport = 0;
      if (this.element) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        var _this$element2 = this.element, scrollTop2 = _this$element2.scrollTop, scrollLeft = _this$element2.scrollLeft;
        if (both) {
          firstInViewport = {
            rows: calculateFirstInViewport(scrollTop2, this.itemSize[0]),
            cols: calculateFirstInViewport(scrollLeft, this.itemSize[1])
          };
          lastInViewport = {
            rows: firstInViewport.rows + this.numItemsInViewport.rows,
            cols: firstInViewport.cols + this.numItemsInViewport.cols
          };
        } else {
          var scrollPos = horizontal2 ? scrollLeft : scrollTop2;
          firstInViewport = calculateFirstInViewport(scrollPos, this.itemSize);
          lastInViewport = firstInViewport + this.numItemsInViewport;
        }
      }
      return {
        first: this.first,
        last: this.last,
        viewport: {
          first: firstInViewport,
          last: lastInViewport
        }
      };
    }, "getRenderedRange"),
    calculateNumItems: /* @__PURE__ */ __name(function calculateNumItems() {
      var both = this.isBoth();
      var horizontal2 = this.isHorizontal();
      var itemSize2 = this.itemSize;
      var contentPos = this.getContentPosition();
      var contentWidth = this.element ? this.element.offsetWidth - contentPos.left : 0;
      var contentHeight = this.element ? this.element.offsetHeight - contentPos.top : 0;
      var calculateNumItemsInViewport = /* @__PURE__ */ __name(function calculateNumItemsInViewport2(_contentSize, _itemSize) {
        return Math.ceil(_contentSize / (_itemSize || _contentSize));
      }, "calculateNumItemsInViewport");
      var calculateNumToleratedItems = /* @__PURE__ */ __name(function calculateNumToleratedItems2(_numItems) {
        return Math.ceil(_numItems / 2);
      }, "calculateNumToleratedItems");
      var numItemsInViewport = both ? {
        rows: calculateNumItemsInViewport(contentHeight, itemSize2[0]),
        cols: calculateNumItemsInViewport(contentWidth, itemSize2[1])
      } : calculateNumItemsInViewport(horizontal2 ? contentWidth : contentHeight, itemSize2);
      var numToleratedItems2 = this.d_numToleratedItems || (both ? [calculateNumToleratedItems(numItemsInViewport.rows), calculateNumToleratedItems(numItemsInViewport.cols)] : calculateNumToleratedItems(numItemsInViewport));
      return {
        numItemsInViewport,
        numToleratedItems: numToleratedItems2
      };
    }, "calculateNumItems"),
    calculateOptions: /* @__PURE__ */ __name(function calculateOptions() {
      var _this3 = this;
      var both = this.isBoth();
      var first2 = this.first;
      var _this$calculateNumIte2 = this.calculateNumItems(), numItemsInViewport = _this$calculateNumIte2.numItemsInViewport, numToleratedItems2 = _this$calculateNumIte2.numToleratedItems;
      var calculateLast = /* @__PURE__ */ __name(function calculateLast2(_first, _num, _numT) {
        var _isCols = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false;
        return _this3.getLast(_first + _num + (_first < _numT ? 2 : 3) * _numT, _isCols);
      }, "calculateLast");
      var last = both ? {
        rows: calculateLast(first2.rows, numItemsInViewport.rows, numToleratedItems2[0]),
        cols: calculateLast(first2.cols, numItemsInViewport.cols, numToleratedItems2[1], true)
      } : calculateLast(first2, numItemsInViewport, numToleratedItems2);
      this.last = last;
      this.numItemsInViewport = numItemsInViewport;
      this.d_numToleratedItems = numToleratedItems2;
      this.$emit("update:numToleratedItems", this.d_numToleratedItems);
      if (this.showLoader) {
        this.loaderArr = both ? Array.from({
          length: numItemsInViewport.rows
        }).map(function() {
          return Array.from({
            length: numItemsInViewport.cols
          });
        }) : Array.from({
          length: numItemsInViewport
        });
      }
      if (this.lazy) {
        Promise.resolve().then(function() {
          var _this3$items;
          _this3.lazyLoadState = {
            first: _this3.step ? both ? {
              rows: 0,
              cols: first2.cols
            } : 0 : first2,
            last: Math.min(_this3.step ? _this3.step : last, ((_this3$items = _this3.items) === null || _this3$items === void 0 ? void 0 : _this3$items.length) || 0)
          };
          _this3.$emit("lazy-load", _this3.lazyLoadState);
        });
      }
    }, "calculateOptions"),
    calculateAutoSize: /* @__PURE__ */ __name(function calculateAutoSize() {
      var _this4 = this;
      if (this.autoSize && !this.d_loading) {
        Promise.resolve().then(function() {
          if (_this4.content) {
            var both = _this4.isBoth();
            var horizontal2 = _this4.isHorizontal();
            var vertical2 = _this4.isVertical();
            _this4.content.style.minHeight = _this4.content.style.minWidth = "auto";
            _this4.content.style.position = "relative";
            _this4.element.style.contain = "none";
            var _ref = [getWidth$1(_this4.element), getHeight$1(_this4.element)], width2 = _ref[0], height = _ref[1];
            (both || horizontal2) && (_this4.element.style.width = width2 < _this4.defaultWidth ? width2 + "px" : _this4.scrollWidth || _this4.defaultWidth + "px");
            (both || vertical2) && (_this4.element.style.height = height < _this4.defaultHeight ? height + "px" : _this4.scrollHeight || _this4.defaultHeight + "px");
            _this4.content.style.minHeight = _this4.content.style.minWidth = "";
            _this4.content.style.position = "";
            _this4.element.style.contain = "";
          }
        });
      }
    }, "calculateAutoSize"),
    getLast: /* @__PURE__ */ __name(function getLast() {
      var _ref2, _this$items;
      var last = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 0;
      var isCols = arguments.length > 1 ? arguments[1] : void 0;
      return this.items ? Math.min(isCols ? ((_ref2 = this.columns || this.items[0]) === null || _ref2 === void 0 ? void 0 : _ref2.length) || 0 : ((_this$items = this.items) === null || _this$items === void 0 ? void 0 : _this$items.length) || 0, last) : 0;
    }, "getLast"),
    getContentPosition: /* @__PURE__ */ __name(function getContentPosition() {
      if (this.content) {
        var style2 = getComputedStyle(this.content);
        var left = parseFloat(style2.paddingLeft) + Math.max(parseFloat(style2.left) || 0, 0);
        var right = parseFloat(style2.paddingRight) + Math.max(parseFloat(style2.right) || 0, 0);
        var top = parseFloat(style2.paddingTop) + Math.max(parseFloat(style2.top) || 0, 0);
        var bottom = parseFloat(style2.paddingBottom) + Math.max(parseFloat(style2.bottom) || 0, 0);
        return {
          left,
          right,
          top,
          bottom,
          x: left + right,
          y: top + bottom
        };
      }
      return {
        left: 0,
        right: 0,
        top: 0,
        bottom: 0,
        x: 0,
        y: 0
      };
    }, "getContentPosition"),
    setSize: /* @__PURE__ */ __name(function setSize() {
      var _this5 = this;
      if (this.element) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        var parentElement = this.element.parentElement;
        var width2 = this.scrollWidth || "".concat(this.element.offsetWidth || parentElement.offsetWidth, "px");
        var height = this.scrollHeight || "".concat(this.element.offsetHeight || parentElement.offsetHeight, "px");
        var setProp = /* @__PURE__ */ __name(function setProp2(_name, _value) {
          return _this5.element.style[_name] = _value;
        }, "setProp");
        if (both || horizontal2) {
          setProp("height", height);
          setProp("width", width2);
        } else {
          setProp("height", height);
        }
      }
    }, "setSize"),
    setSpacerSize: /* @__PURE__ */ __name(function setSpacerSize() {
      var _this6 = this;
      var items2 = this.items;
      if (items2) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        var contentPos = this.getContentPosition();
        var setProp = /* @__PURE__ */ __name(function setProp2(_name, _value, _size) {
          var _cpos = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : 0;
          return _this6.spacerStyle = _objectSpread$d(_objectSpread$d({}, _this6.spacerStyle), _defineProperty$b({}, "".concat(_name), (_value || []).length * _size + _cpos + "px"));
        }, "setProp");
        if (both) {
          setProp("height", items2, this.itemSize[0], contentPos.y);
          setProp("width", this.columns || items2[1], this.itemSize[1], contentPos.x);
        } else {
          horizontal2 ? setProp("width", this.columns || items2, this.itemSize, contentPos.x) : setProp("height", items2, this.itemSize, contentPos.y);
        }
      }
    }, "setSpacerSize"),
    setContentPosition: /* @__PURE__ */ __name(function setContentPosition(pos) {
      var _this7 = this;
      if (this.content && !this.appendOnly) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        var first2 = pos ? pos.first : this.first;
        var calculateTranslateVal = /* @__PURE__ */ __name(function calculateTranslateVal2(_first, _size) {
          return _first * _size;
        }, "calculateTranslateVal");
        var setTransform = /* @__PURE__ */ __name(function setTransform2() {
          var _x = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : 0;
          var _y = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 0;
          return _this7.contentStyle = _objectSpread$d(_objectSpread$d({}, _this7.contentStyle), {
            transform: "translate3d(".concat(_x, "px, ").concat(_y, "px, 0)")
          });
        }, "setTransform");
        if (both) {
          setTransform(calculateTranslateVal(first2.cols, this.itemSize[1]), calculateTranslateVal(first2.rows, this.itemSize[0]));
        } else {
          var translateVal = calculateTranslateVal(first2, this.itemSize);
          horizontal2 ? setTransform(translateVal, 0) : setTransform(0, translateVal);
        }
      }
    }, "setContentPosition"),
    onScrollPositionChange: /* @__PURE__ */ __name(function onScrollPositionChange(event) {
      var _this8 = this;
      var target2 = event.target;
      var both = this.isBoth();
      var horizontal2 = this.isHorizontal();
      var contentPos = this.getContentPosition();
      var calculateScrollPos = /* @__PURE__ */ __name(function calculateScrollPos2(_pos, _cpos) {
        return _pos ? _pos > _cpos ? _pos - _cpos : _pos : 0;
      }, "calculateScrollPos");
      var calculateCurrentIndex = /* @__PURE__ */ __name(function calculateCurrentIndex2(_pos, _size) {
        return Math.floor(_pos / (_size || _pos));
      }, "calculateCurrentIndex");
      var calculateTriggerIndex = /* @__PURE__ */ __name(function calculateTriggerIndex2(_currentIndex, _first, _last, _num, _numT, _isScrollDownOrRight) {
        return _currentIndex <= _numT ? _numT : _isScrollDownOrRight ? _last - _num - _numT : _first + _numT - 1;
      }, "calculateTriggerIndex");
      var calculateFirst = /* @__PURE__ */ __name(function calculateFirst2(_currentIndex, _triggerIndex, _first, _last, _num, _numT, _isScrollDownOrRight) {
        if (_currentIndex <= _numT) return 0;
        else return Math.max(0, _isScrollDownOrRight ? _currentIndex < _triggerIndex ? _first : _currentIndex - _numT : _currentIndex > _triggerIndex ? _first : _currentIndex - 2 * _numT);
      }, "calculateFirst");
      var calculateLast = /* @__PURE__ */ __name(function calculateLast2(_currentIndex, _first, _last, _num, _numT, _isCols) {
        var lastValue = _first + _num + 2 * _numT;
        if (_currentIndex >= _numT) {
          lastValue += _numT + 1;
        }
        return _this8.getLast(lastValue, _isCols);
      }, "calculateLast");
      var scrollTop2 = calculateScrollPos(target2.scrollTop, contentPos.top);
      var scrollLeft = calculateScrollPos(target2.scrollLeft, contentPos.left);
      var newFirst = both ? {
        rows: 0,
        cols: 0
      } : 0;
      var newLast = this.last;
      var isRangeChanged = false;
      var newScrollPos = this.lastScrollPos;
      if (both) {
        var isScrollDown = this.lastScrollPos.top <= scrollTop2;
        var isScrollRight = this.lastScrollPos.left <= scrollLeft;
        if (!this.appendOnly || this.appendOnly && (isScrollDown || isScrollRight)) {
          var currentIndex = {
            rows: calculateCurrentIndex(scrollTop2, this.itemSize[0]),
            cols: calculateCurrentIndex(scrollLeft, this.itemSize[1])
          };
          var triggerIndex = {
            rows: calculateTriggerIndex(currentIndex.rows, this.first.rows, this.last.rows, this.numItemsInViewport.rows, this.d_numToleratedItems[0], isScrollDown),
            cols: calculateTriggerIndex(currentIndex.cols, this.first.cols, this.last.cols, this.numItemsInViewport.cols, this.d_numToleratedItems[1], isScrollRight)
          };
          newFirst = {
            rows: calculateFirst(currentIndex.rows, triggerIndex.rows, this.first.rows, this.last.rows, this.numItemsInViewport.rows, this.d_numToleratedItems[0], isScrollDown),
            cols: calculateFirst(currentIndex.cols, triggerIndex.cols, this.first.cols, this.last.cols, this.numItemsInViewport.cols, this.d_numToleratedItems[1], isScrollRight)
          };
          newLast = {
            rows: calculateLast(currentIndex.rows, newFirst.rows, this.last.rows, this.numItemsInViewport.rows, this.d_numToleratedItems[0]),
            cols: calculateLast(currentIndex.cols, newFirst.cols, this.last.cols, this.numItemsInViewport.cols, this.d_numToleratedItems[1], true)
          };
          isRangeChanged = newFirst.rows !== this.first.rows || newLast.rows !== this.last.rows || newFirst.cols !== this.first.cols || newLast.cols !== this.last.cols || this.isRangeChanged;
          newScrollPos = {
            top: scrollTop2,
            left: scrollLeft
          };
        }
      } else {
        var scrollPos = horizontal2 ? scrollLeft : scrollTop2;
        var isScrollDownOrRight = this.lastScrollPos <= scrollPos;
        if (!this.appendOnly || this.appendOnly && isScrollDownOrRight) {
          var _currentIndex2 = calculateCurrentIndex(scrollPos, this.itemSize);
          var _triggerIndex2 = calculateTriggerIndex(_currentIndex2, this.first, this.last, this.numItemsInViewport, this.d_numToleratedItems, isScrollDownOrRight);
          newFirst = calculateFirst(_currentIndex2, _triggerIndex2, this.first, this.last, this.numItemsInViewport, this.d_numToleratedItems, isScrollDownOrRight);
          newLast = calculateLast(_currentIndex2, newFirst, this.last, this.numItemsInViewport, this.d_numToleratedItems);
          isRangeChanged = newFirst !== this.first || newLast !== this.last || this.isRangeChanged;
          newScrollPos = scrollPos;
        }
      }
      return {
        first: newFirst,
        last: newLast,
        isRangeChanged,
        scrollPos: newScrollPos
      };
    }, "onScrollPositionChange"),
    onScrollChange: /* @__PURE__ */ __name(function onScrollChange(event) {
      var _this$onScrollPositio = this.onScrollPositionChange(event), first2 = _this$onScrollPositio.first, last = _this$onScrollPositio.last, isRangeChanged = _this$onScrollPositio.isRangeChanged, scrollPos = _this$onScrollPositio.scrollPos;
      if (isRangeChanged) {
        var newState = {
          first: first2,
          last
        };
        this.setContentPosition(newState);
        this.first = first2;
        this.last = last;
        this.lastScrollPos = scrollPos;
        this.$emit("scroll-index-change", newState);
        if (this.lazy && this.isPageChanged(first2)) {
          var _this$items2, _this$items3;
          var lazyLoadState = {
            first: this.step ? Math.min(this.getPageByFirst(first2) * this.step, (((_this$items2 = this.items) === null || _this$items2 === void 0 ? void 0 : _this$items2.length) || 0) - this.step) : first2,
            last: Math.min(this.step ? (this.getPageByFirst(first2) + 1) * this.step : last, ((_this$items3 = this.items) === null || _this$items3 === void 0 ? void 0 : _this$items3.length) || 0)
          };
          var isLazyStateChanged = this.lazyLoadState.first !== lazyLoadState.first || this.lazyLoadState.last !== lazyLoadState.last;
          isLazyStateChanged && this.$emit("lazy-load", lazyLoadState);
          this.lazyLoadState = lazyLoadState;
        }
      }
    }, "onScrollChange"),
    onScroll: /* @__PURE__ */ __name(function onScroll2(event) {
      var _this9 = this;
      this.$emit("scroll", event);
      if (this.delay) {
        if (this.scrollTimeout) {
          clearTimeout(this.scrollTimeout);
        }
        if (this.isPageChanged()) {
          if (!this.d_loading && this.showLoader) {
            var _this$onScrollPositio2 = this.onScrollPositionChange(event), isRangeChanged = _this$onScrollPositio2.isRangeChanged;
            var changed = isRangeChanged || (this.step ? this.isPageChanged() : false);
            changed && (this.d_loading = true);
          }
          this.scrollTimeout = setTimeout(function() {
            _this9.onScrollChange(event);
            if (_this9.d_loading && _this9.showLoader && (!_this9.lazy || _this9.loading === void 0)) {
              _this9.d_loading = false;
              _this9.page = _this9.getPageByFirst();
            }
          }, this.delay);
        }
      } else {
        this.onScrollChange(event);
      }
    }, "onScroll"),
    onResize: /* @__PURE__ */ __name(function onResize() {
      var _this10 = this;
      if (this.resizeTimeout) {
        clearTimeout(this.resizeTimeout);
      }
      this.resizeTimeout = setTimeout(function() {
        if (isVisible$1(_this10.element)) {
          var both = _this10.isBoth();
          var vertical2 = _this10.isVertical();
          var horizontal2 = _this10.isHorizontal();
          var _ref3 = [getWidth$1(_this10.element), getHeight$1(_this10.element)], width2 = _ref3[0], height = _ref3[1];
          var isDiffWidth = width2 !== _this10.defaultWidth, isDiffHeight = height !== _this10.defaultHeight;
          var reinit = both ? isDiffWidth || isDiffHeight : horizontal2 ? isDiffWidth : vertical2 ? isDiffHeight : false;
          if (reinit) {
            _this10.d_numToleratedItems = _this10.numToleratedItems;
            _this10.defaultWidth = width2;
            _this10.defaultHeight = height;
            _this10.defaultContentWidth = getWidth$1(_this10.content);
            _this10.defaultContentHeight = getHeight$1(_this10.content);
            _this10.init();
          }
        }
      }, this.resizeDelay);
    }, "onResize"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener() {
      if (!this.resizeListener) {
        this.resizeListener = this.onResize.bind(this);
        window.addEventListener("resize", this.resizeListener);
        window.addEventListener("orientationchange", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        window.removeEventListener("orientationchange", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    getOptions: /* @__PURE__ */ __name(function getOptions2(renderedIndex) {
      var count = (this.items || []).length;
      var index2 = this.isBoth() ? this.first.rows + renderedIndex : this.first + renderedIndex;
      return {
        index: index2,
        count,
        first: index2 === 0,
        last: index2 === count - 1,
        even: index2 % 2 === 0,
        odd: index2 % 2 !== 0
      };
    }, "getOptions"),
    getLoaderOptions: /* @__PURE__ */ __name(function getLoaderOptions(index2, extOptions) {
      var count = this.loaderArr.length;
      return _objectSpread$d({
        index: index2,
        count,
        first: index2 === 0,
        last: index2 === count - 1,
        even: index2 % 2 === 0,
        odd: index2 % 2 !== 0
      }, extOptions);
    }, "getLoaderOptions"),
    getPageByFirst: /* @__PURE__ */ __name(function getPageByFirst(first2) {
      return Math.floor(((first2 !== null && first2 !== void 0 ? first2 : this.first) + this.d_numToleratedItems * 4) / (this.step || 1));
    }, "getPageByFirst"),
    isPageChanged: /* @__PURE__ */ __name(function isPageChanged(first2) {
      return this.step && !this.lazy ? this.page !== this.getPageByFirst(first2 !== null && first2 !== void 0 ? first2 : this.first) : true;
    }, "isPageChanged"),
    setContentEl: /* @__PURE__ */ __name(function setContentEl(el) {
      this.content = el || this.content || findSingle$1(this.element, '[data-pc-section="content"]');
    }, "setContentEl"),
    elementRef: /* @__PURE__ */ __name(function elementRef(el) {
      this.element = el;
    }, "elementRef"),
    contentRef: /* @__PURE__ */ __name(function contentRef2(el) {
      this.content = el;
    }, "contentRef")
  },
  computed: {
    containerClass: /* @__PURE__ */ __name(function containerClass2() {
      return ["p-virtualscroller", this["class"], {
        "p-virtualscroller-inline": this.inline,
        "p-virtualscroller-both p-both-scroll": this.isBoth(),
        "p-virtualscroller-horizontal p-horizontal-scroll": this.isHorizontal()
      }];
    }, "containerClass"),
    contentClass: /* @__PURE__ */ __name(function contentClass() {
      return ["p-virtualscroller-content", {
        "p-virtualscroller-loading": this.d_loading
      }];
    }, "contentClass"),
    loaderClass: /* @__PURE__ */ __name(function loaderClass() {
      return ["p-virtualscroller-loader", {
        "p-virtualscroller-loader-mask": !this.$slots.loader
      }];
    }, "loaderClass"),
    loadedItems: /* @__PURE__ */ __name(function loadedItems() {
      var _this11 = this;
      if (this.items && !this.d_loading) {
        if (this.isBoth()) return this.items.slice(this.appendOnly ? 0 : this.first.rows, this.last.rows).map(function(item3) {
          return _this11.columns ? item3 : item3.slice(_this11.appendOnly ? 0 : _this11.first.cols, _this11.last.cols);
        });
        else if (this.isHorizontal() && this.columns) return this.items;
        else return this.items.slice(this.appendOnly ? 0 : this.first, this.last);
      }
      return [];
    }, "loadedItems"),
    loadedRows: /* @__PURE__ */ __name(function loadedRows() {
      return this.d_loading ? this.loaderDisabled ? this.loaderArr : [] : this.loadedItems;
    }, "loadedRows"),
    loadedColumns: /* @__PURE__ */ __name(function loadedColumns() {
      if (this.columns) {
        var both = this.isBoth();
        var horizontal2 = this.isHorizontal();
        if (both || horizontal2) {
          return this.d_loading && this.loaderDisabled ? both ? this.loaderArr[0] : this.loaderArr : this.columns.slice(both ? this.first.cols : this.first, both ? this.last.cols : this.last);
        }
      }
      return this.columns;
    }, "loadedColumns")
  },
  components: {
    SpinnerIcon: script$12
  }
};
var _hoisted_1$1z = ["tabindex"];
function render$F(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  return !_ctx.disabled ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    ref: $options.elementRef,
    "class": $options.containerClass,
    tabindex: _ctx.tabindex,
    style: _ctx.style,
    onScroll: _cache[0] || (_cache[0] = function() {
      return $options.onScroll && $options.onScroll.apply($options, arguments);
    })
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "content", {
    styleClass: $options.contentClass,
    items: $options.loadedItems,
    getItemOptions: $options.getOptions,
    loading: $data.d_loading,
    getLoaderOptions: $options.getLoaderOptions,
    itemSize: _ctx.itemSize,
    rows: $options.loadedRows,
    columns: $options.loadedColumns,
    contentRef: $options.contentRef,
    spacerStyle: $data.spacerStyle,
    contentStyle: $data.contentStyle,
    vertical: $options.isVertical(),
    horizontal: $options.isHorizontal(),
    both: $options.isBoth()
  }, function() {
    return [createBaseVNode("div", mergeProps$2({
      ref: $options.contentRef,
      "class": $options.contentClass,
      style: $data.contentStyle
    }, _ctx.ptm("content")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($options.loadedItems, function(item3, index2) {
      return renderSlot(_ctx.$slots, "item", {
        key: index2,
        item: item3,
        options: $options.getOptions(index2)
      });
    }), 128))], 16)];
  }), _ctx.showSpacer ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": "p-virtualscroller-spacer",
    style: $data.spacerStyle
  }, _ctx.ptm("spacer")), null, 16)) : createCommentVNode("", true), !_ctx.loaderDisabled && _ctx.showLoader && $data.d_loading ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": $options.loaderClass
  }, _ctx.ptm("loader")), [_ctx.$slots && _ctx.$slots.loader ? (openBlock(true), createElementBlock(Fragment$1, {
    key: 0
  }, renderList($data.loaderArr, function(_2, index2) {
    return renderSlot(_ctx.$slots, "loader", {
      key: index2,
      options: $options.getLoaderOptions(index2, $options.isBoth() && {
        numCols: _ctx.d_numItemsInViewport.cols
      })
    });
  }), 128)) : createCommentVNode("", true), renderSlot(_ctx.$slots, "loadingicon", {}, function() {
    return [createVNode(_component_SpinnerIcon, mergeProps$2({
      spin: "",
      "class": "p-virtualscroller-loading-icon"
    }, _ctx.ptm("loadingIcon")), null, 16)];
  })], 16)) : createCommentVNode("", true)], 16, _hoisted_1$1z)) : (openBlock(), createElementBlock(Fragment$1, {
    key: 1
  }, [renderSlot(_ctx.$slots, "default"), renderSlot(_ctx.$slots, "content", {
    items: _ctx.items,
    rows: _ctx.items,
    columns: $options.loadedColumns
  })], 64));
}
__name(render$F, "render$F");
script$H.render = render$F;
var theme$p = /* @__PURE__ */ __name(function theme21(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-listbox {\n    background: ".concat(dt2("listbox.background"), ";\n    color: ").concat(dt2("listbox.color"), ";\n    border: 1px solid ").concat(dt2("listbox.border.color"), ";\n    border-radius: ").concat(dt2("listbox.border.radius"), ";\n    transition: background ").concat(dt2("listbox.transition.duration"), ", color ").concat(dt2("listbox.transition.duration"), ", border-color ").concat(dt2("listbox.transition.duration"), ",\n            box-shadow ").concat(dt2("listbox.transition.duration"), ", outline-color ").concat(dt2("listbox.transition.duration"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("listbox.shadow"), ";\n}\n\n.p-listbox.p-disabled {\n    opacity: 1;\n    background: ").concat(dt2("listbox.disabled.background"), ";\n    color: ").concat(dt2("listbox.disabled.color"), ";\n}\n\n.p-listbox.p-disabled .p-listbox-option {\n    color: ").concat(dt2("listbox.disabled.color"), ";\n}\n\n.p-listbox.p-invalid {\n    border-color: ").concat(dt2("listbox.invalid.border.color"), ";\n}\n\n.p-listbox-header {\n    padding: ").concat(dt2("listbox.list.header.padding"), ";\n}\n\n.p-listbox-filter {\n    width: 100%;\n}\n\n.p-listbox-list-container {\n    overflow: auto;\n}\n\n.p-listbox-list {\n    list-style-type: none;\n    margin: 0;\n    padding: ").concat(dt2("listbox.list.padding"), ";\n    outline: 0 none;\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("listbox.list.gap"), ";\n}\n\n.p-listbox-option {\n    display: flex;\n    align-items: center;\n    cursor: pointer;\n    position: relative;\n    overflow: hidden;\n    padding: ").concat(dt2("listbox.option.padding"), ";\n    border: 0 none;\n    border-radius: ").concat(dt2("listbox.option.border.radius"), ";\n    color: ").concat(dt2("listbox.option.color"), ";\n    transition: background ").concat(dt2("listbox.transition.duration"), ", color ").concat(dt2("listbox.transition.duration"), ", border-color ").concat(dt2("listbox.transition.duration"), ",\n            box-shadow ").concat(dt2("listbox.transition.duration"), ", outline-color ").concat(dt2("listbox.transition.duration"), ";\n}\n\n.p-listbox-striped li:nth-child(even of .p-listbox-option) {\n    background: ").concat(dt2("listbox.option.striped.background"), ";\n}\n\n.p-listbox .p-listbox-list .p-listbox-option.p-listbox-option-selected {\n    background: ").concat(dt2("listbox.option.selected.background"), ";\n    color: ").concat(dt2("listbox.option.selected.color"), ";\n}\n\n.p-listbox:not(.p-disabled) .p-listbox-option.p-listbox-option-selected.p-focus {\n    background: ").concat(dt2("listbox.option.selected.focus.background"), ";\n    color: ").concat(dt2("listbox.option.selected.focus.color"), ";\n}\n\n.p-listbox:not(.p-disabled) .p-listbox-option:not(.p-listbox-option-selected):not(.p-disabled).p-focus {\n    background: ").concat(dt2("listbox.option.focus.background"), ";\n    color: ").concat(dt2("listbox.option.focus.color"), ";\n}\n\n.p-listbox:not(.p-disabled) .p-listbox-option:not(.p-listbox-option-selected):not(.p-disabled):hover {\n    background: ").concat(dt2("listbox.option.focus.background"), ";\n    color: ").concat(dt2("listbox.option.focus.color"), ";\n}\n\n.p-listbox-option-check-icon {\n    position: relative;\n    margin-inline-start: ").concat(dt2("listbox.checkmark.gutter.start"), ";\n    margin-inline-end: ").concat(dt2("listbox.checkmark.gutter.end"), ";\n    color: ").concat(dt2("listbox.checkmark.color"), ";\n}\n\n.p-listbox-option-group {\n    margin: 0;\n    padding: ").concat(dt2("listbox.option.group.padding"), ";\n    color: ").concat(dt2("listbox.option.group.color"), ";\n    background: ").concat(dt2("listbox.option.group.background"), ";\n    font-weight: ").concat(dt2("listbox.option.group.font.weight"), ";\n}\n\n.p-listbox-empty-message {\n    padding: ").concat(dt2("listbox.empty.message.padding"), ";\n}\n");
}, "theme");
var classes$t = {
  root: /* @__PURE__ */ __name(function root12(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-listbox p-component", {
      "p-listbox-striped": props.striped,
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid
    }];
  }, "root"),
  header: "p-listbox-header",
  pcFilter: "p-listbox-filter",
  listContainer: "p-listbox-list-container",
  list: "p-listbox-list",
  optionGroup: "p-listbox-option-group",
  option: /* @__PURE__ */ __name(function option(_ref3) {
    var instance = _ref3.instance, props = _ref3.props, _option = _ref3.option, index2 = _ref3.index, getItemOptions = _ref3.getItemOptions;
    return ["p-listbox-option", {
      "p-listbox-option-selected": instance.isSelected(_option) && props.highlightOnSelect,
      "p-focus": instance.focusedOptionIndex === instance.getOptionIndex(index2, getItemOptions),
      "p-disabled": instance.isOptionDisabled(_option)
    }];
  }, "option"),
  optionCheckIcon: "p-listbox-option-check-icon",
  optionBlankIcon: "p-listbox-option-blank-icon",
  emptyMessage: "p-listbox-empty-message"
};
var ListboxStyle = BaseStyle$1.extend({
  name: "listbox",
  theme: theme$p,
  classes: classes$t
});
var script$1$t = {
  name: "BaseListbox",
  "extends": script$18,
  props: {
    options: Array,
    optionLabel: null,
    optionValue: null,
    optionDisabled: null,
    optionGroupLabel: null,
    optionGroupChildren: null,
    listStyle: null,
    scrollHeight: {
      type: String,
      "default": "14rem"
    },
    dataKey: null,
    multiple: {
      type: Boolean,
      "default": false
    },
    metaKeySelection: {
      type: Boolean,
      "default": false
    },
    filter: Boolean,
    filterPlaceholder: String,
    filterLocale: String,
    filterMatchMode: {
      type: String,
      "default": "contains"
    },
    filterFields: {
      type: Array,
      "default": null
    },
    virtualScrollerOptions: {
      type: Object,
      "default": null
    },
    autoOptionFocus: {
      type: Boolean,
      "default": true
    },
    selectOnFocus: {
      type: Boolean,
      "default": false
    },
    focusOnHover: {
      type: Boolean,
      "default": true
    },
    highlightOnSelect: {
      type: Boolean,
      "default": true
    },
    checkmark: {
      type: Boolean,
      "default": false
    },
    filterMessage: {
      type: String,
      "default": null
    },
    selectionMessage: {
      type: String,
      "default": null
    },
    emptySelectionMessage: {
      type: String,
      "default": null
    },
    emptyFilterMessage: {
      type: String,
      "default": null
    },
    emptyMessage: {
      type: String,
      "default": null
    },
    filterIcon: {
      type: String,
      "default": void 0
    },
    striped: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    }
  },
  style: ListboxStyle,
  provide: /* @__PURE__ */ __name(function provide22() {
    return {
      $pcListbox: this,
      $parentInstance: this
    };
  }, "provide")
};
function _toConsumableArray$a(r2) {
  return _arrayWithoutHoles$a(r2) || _iterableToArray$a(r2) || _unsupportedIterableToArray$c(r2) || _nonIterableSpread$a();
}
__name(_toConsumableArray$a, "_toConsumableArray$a");
function _nonIterableSpread$a() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$a, "_nonIterableSpread$a");
function _unsupportedIterableToArray$c(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$c(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$c(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$c, "_unsupportedIterableToArray$c");
function _iterableToArray$a(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$a, "_iterableToArray$a");
function _arrayWithoutHoles$a(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$c(r2);
}
__name(_arrayWithoutHoles$a, "_arrayWithoutHoles$a");
function _arrayLikeToArray$c(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$c, "_arrayLikeToArray$c");
var script$G = {
  name: "Listbox",
  "extends": script$1$t,
  inheritAttrs: false,
  emits: ["change", "focus", "blur", "filter", "item-dblclick", "option-dblclick"],
  list: null,
  virtualScroller: null,
  optionTouched: false,
  startRangeIndex: -1,
  searchTimeout: null,
  searchValue: "",
  data: /* @__PURE__ */ __name(function data10() {
    return {
      id: this.$attrs.id,
      filterValue: null,
      focused: false,
      focusedOptionIndex: -1
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId4(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    options: /* @__PURE__ */ __name(function options2() {
      this.autoUpdateModel();
    }, "options")
  },
  mounted: /* @__PURE__ */ __name(function mounted12() {
    this.id = this.id || UniqueComponentId();
    this.autoUpdateModel();
  }, "mounted"),
  methods: {
    getOptionIndex: /* @__PURE__ */ __name(function getOptionIndex(index2, fn) {
      return this.virtualScrollerDisabled ? index2 : fn && fn(index2)["index"];
    }, "getOptionIndex"),
    getOptionLabel: /* @__PURE__ */ __name(function getOptionLabel(option5) {
      return this.optionLabel ? resolveFieldData$2(option5, this.optionLabel) : typeof option5 === "string" ? option5 : null;
    }, "getOptionLabel"),
    getOptionValue: /* @__PURE__ */ __name(function getOptionValue(option5) {
      return this.optionValue ? resolveFieldData$2(option5, this.optionValue) : option5;
    }, "getOptionValue"),
    getOptionRenderKey: /* @__PURE__ */ __name(function getOptionRenderKey(option5, index2) {
      return (this.dataKey ? resolveFieldData$2(option5, this.dataKey) : this.getOptionLabel(option5)) + "_" + index2;
    }, "getOptionRenderKey"),
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions3(option5, itemOptions, index2, key) {
      return this.ptm(key, {
        context: {
          selected: this.isSelected(option5),
          focused: this.focusedOptionIndex === this.getOptionIndex(index2, itemOptions),
          disabled: this.isOptionDisabled(option5)
        }
      });
    }, "getPTOptions"),
    isOptionDisabled: /* @__PURE__ */ __name(function isOptionDisabled(option5) {
      return this.optionDisabled ? resolveFieldData$2(option5, this.optionDisabled) : false;
    }, "isOptionDisabled"),
    isOptionGroup: /* @__PURE__ */ __name(function isOptionGroup(option5) {
      return this.optionGroupLabel && option5.optionGroup && option5.group;
    }, "isOptionGroup"),
    getOptionGroupLabel: /* @__PURE__ */ __name(function getOptionGroupLabel(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupLabel);
    }, "getOptionGroupLabel"),
    getOptionGroupChildren: /* @__PURE__ */ __name(function getOptionGroupChildren(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupChildren);
    }, "getOptionGroupChildren"),
    getAriaPosInset: /* @__PURE__ */ __name(function getAriaPosInset(index2) {
      var _this = this;
      return (this.optionGroupLabel ? index2 - this.visibleOptions.slice(0, index2).filter(function(option5) {
        return _this.isOptionGroup(option5);
      }).length : index2) + 1;
    }, "getAriaPosInset"),
    onFirstHiddenFocus: /* @__PURE__ */ __name(function onFirstHiddenFocus() {
      focus$2(this.list);
      var firstFocusableEl = getFirstFocusableElement$1(this.$el, ':not([data-p-hidden-focusable="true"])');
      this.$refs.lastHiddenFocusableElement.tabIndex = isElement$1(firstFocusableEl) ? void 0 : -1;
      this.$refs.firstHiddenFocusableElement.tabIndex = -1;
    }, "onFirstHiddenFocus"),
    onLastHiddenFocus: /* @__PURE__ */ __name(function onLastHiddenFocus(event) {
      var relatedTarget = event.relatedTarget;
      if (relatedTarget === this.list) {
        var firstFocusableEl = getFirstFocusableElement$1(this.$el, ':not([data-p-hidden-focusable="true"])');
        focus$2(firstFocusableEl);
        this.$refs.firstHiddenFocusableElement.tabIndex = void 0;
      } else {
        focus$2(this.$refs.firstHiddenFocusableElement);
      }
      this.$refs.lastHiddenFocusableElement.tabIndex = -1;
    }, "onLastHiddenFocus"),
    onFocusout: /* @__PURE__ */ __name(function onFocusout(event) {
      if (!this.$el.contains(event.relatedTarget) && this.$refs.lastHiddenFocusableElement && this.$refs.firstHiddenFocusableElement) {
        this.$refs.lastHiddenFocusableElement.tabIndex = this.$refs.firstHiddenFocusableElement.tabIndex = void 0;
      }
    }, "onFocusout"),
    onListFocus: /* @__PURE__ */ __name(function onListFocus(event) {
      this.focused = true;
      this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : this.findSelectedOptionIndex();
      this.autoUpdateModel();
      this.$emit("focus", event);
    }, "onListFocus"),
    onListBlur: /* @__PURE__ */ __name(function onListBlur(event) {
      this.focused = false;
      this.focusedOptionIndex = this.startRangeIndex = -1;
      this.searchValue = "";
      this.$emit("blur", event);
    }, "onListBlur"),
    onListKeyDown: /* @__PURE__ */ __name(function onListKeyDown(event) {
      var _this2 = this;
      var metaKey = event.metaKey || event.ctrlKey;
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event);
          break;
        case "Home":
          this.onHomeKey(event);
          break;
        case "End":
          this.onEndKey(event);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onSpaceKey(event);
          break;
        case "Tab":
          break;
        case "ShiftLeft":
        case "ShiftRight":
          this.onShiftKey(event);
          break;
        default:
          if (this.multiple && event.code === "KeyA" && metaKey) {
            var value3 = this.visibleOptions.filter(function(option5) {
              return _this2.isValidOption(option5);
            }).map(function(option5) {
              return _this2.getOptionValue(option5);
            });
            this.updateModel(event, value3);
            event.preventDefault();
            break;
          }
          if (!metaKey && isPrintableCharacter$2(event.key)) {
            this.searchOptions(event, event.key);
            event.preventDefault();
          }
          break;
      }
    }, "onListKeyDown"),
    onOptionSelect: /* @__PURE__ */ __name(function onOptionSelect(event, option5) {
      var index2 = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : -1;
      if (this.disabled || this.isOptionDisabled(option5)) {
        return;
      }
      this.multiple ? this.onOptionSelectMultiple(event, option5) : this.onOptionSelectSingle(event, option5);
      this.optionTouched = false;
      index2 !== -1 && (this.focusedOptionIndex = index2);
    }, "onOptionSelect"),
    onOptionMouseDown: /* @__PURE__ */ __name(function onOptionMouseDown(event, index2) {
      this.changeFocusedOptionIndex(event, index2);
    }, "onOptionMouseDown"),
    onOptionMouseMove: /* @__PURE__ */ __name(function onOptionMouseMove(event, index2) {
      if (this.focusOnHover && this.focused) {
        this.changeFocusedOptionIndex(event, index2);
      }
    }, "onOptionMouseMove"),
    onOptionTouchEnd: /* @__PURE__ */ __name(function onOptionTouchEnd() {
      if (this.disabled) {
        return;
      }
      this.optionTouched = true;
    }, "onOptionTouchEnd"),
    onOptionDblClick: /* @__PURE__ */ __name(function onOptionDblClick(event, item3) {
      this.$emit("item-dblclick", {
        originalEvent: event,
        value: item3
      });
      this.$emit("option-dblclick", {
        originalEvent: event,
        value: item3
      });
    }, "onOptionDblClick"),
    onOptionSelectSingle: /* @__PURE__ */ __name(function onOptionSelectSingle(event, option5) {
      var selected2 = this.isSelected(option5);
      var valueChanged = false;
      var value3 = null;
      var metaSelection = this.optionTouched ? false : this.metaKeySelection;
      if (metaSelection) {
        var metaKey = event && (event.metaKey || event.ctrlKey);
        if (selected2) {
          if (metaKey) {
            value3 = null;
            valueChanged = true;
          }
        } else {
          value3 = this.getOptionValue(option5);
          valueChanged = true;
        }
      } else {
        value3 = selected2 ? null : this.getOptionValue(option5);
        valueChanged = true;
      }
      if (valueChanged) {
        this.updateModel(event, value3);
      }
    }, "onOptionSelectSingle"),
    onOptionSelectMultiple: /* @__PURE__ */ __name(function onOptionSelectMultiple(event, option5) {
      var selected2 = this.isSelected(option5);
      var value3 = null;
      var metaSelection = this.optionTouched ? false : this.metaKeySelection;
      if (metaSelection) {
        var metaKey = event.metaKey || event.ctrlKey;
        if (selected2) {
          value3 = metaKey ? this.removeOption(option5) : [this.getOptionValue(option5)];
        } else {
          value3 = metaKey ? this.d_value || [] : [];
          value3 = [].concat(_toConsumableArray$a(value3), [this.getOptionValue(option5)]);
        }
      } else {
        value3 = selected2 ? this.removeOption(option5) : [].concat(_toConsumableArray$a(this.d_value || []), [this.getOptionValue(option5)]);
      }
      this.updateModel(event, value3);
    }, "onOptionSelectMultiple"),
    onOptionSelectRange: /* @__PURE__ */ __name(function onOptionSelectRange(event) {
      var _this3 = this;
      var start2 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : -1;
      var end = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : -1;
      start2 === -1 && (start2 = this.findNearestSelectedOptionIndex(end, true));
      end === -1 && (end = this.findNearestSelectedOptionIndex(start2));
      if (start2 !== -1 && end !== -1) {
        var rangeStart = Math.min(start2, end);
        var rangeEnd = Math.max(start2, end);
        var value3 = this.visibleOptions.slice(rangeStart, rangeEnd + 1).filter(function(option5) {
          return _this3.isValidOption(option5);
        }).map(function(option5) {
          return _this3.getOptionValue(option5);
        });
        this.updateModel(event, value3);
      }
    }, "onOptionSelectRange"),
    onFilterChange: /* @__PURE__ */ __name(function onFilterChange(event) {
      this.$emit("filter", {
        originalEvent: event,
        value: event.target.value,
        filterValue: this.visibleOptions
      });
      this.focusedOptionIndex = this.startRangeIndex = -1;
    }, "onFilterChange"),
    onFilterBlur: /* @__PURE__ */ __name(function onFilterBlur() {
      this.focusedOptionIndex = this.startRangeIndex = -1;
    }, "onFilterBlur"),
    onFilterKeyDown: /* @__PURE__ */ __name(function onFilterKeyDown(event) {
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event);
          break;
        case "ArrowLeft":
        case "ArrowRight":
          this.onArrowLeftKey(event, true);
          break;
        case "Home":
          this.onHomeKey(event, true);
          break;
        case "End":
          this.onEndKey(event, true);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "ShiftLeft":
        case "ShiftRight":
          this.onShiftKey(event);
          break;
      }
    }, "onFilterKeyDown"),
    onArrowDownKey: /* @__PURE__ */ __name(function onArrowDownKey(event) {
      var optionIndex = this.focusedOptionIndex !== -1 ? this.findNextOptionIndex(this.focusedOptionIndex) : this.findFirstFocusedOptionIndex();
      if (this.multiple && event.shiftKey) {
        this.onOptionSelectRange(event, this.startRangeIndex, optionIndex);
      }
      this.changeFocusedOptionIndex(event, optionIndex);
      event.preventDefault();
    }, "onArrowDownKey"),
    onArrowUpKey: /* @__PURE__ */ __name(function onArrowUpKey(event) {
      var optionIndex = this.focusedOptionIndex !== -1 ? this.findPrevOptionIndex(this.focusedOptionIndex) : this.findLastFocusedOptionIndex();
      if (this.multiple && event.shiftKey) {
        this.onOptionSelectRange(event, optionIndex, this.startRangeIndex);
      }
      this.changeFocusedOptionIndex(event, optionIndex);
      event.preventDefault();
    }, "onArrowUpKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      pressedInInputText && (this.focusedOptionIndex = -1);
    }, "onArrowLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(0, event.target.selectionStart);
        } else {
          target2.setSelectionRange(0, 0);
          this.focusedOptionIndex = -1;
        }
      } else {
        var metaKey = event.metaKey || event.ctrlKey;
        var optionIndex = this.findFirstOptionIndex();
        if (this.multiple && event.shiftKey && metaKey) {
          this.onOptionSelectRange(event, optionIndex, this.startRangeIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
      }
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(event.target.selectionStart, target2.value.length);
        } else {
          var len = target2.value.length;
          target2.setSelectionRange(len, len);
          this.focusedOptionIndex = -1;
        }
      } else {
        var metaKey = event.metaKey || event.ctrlKey;
        var optionIndex = this.findLastOptionIndex();
        if (this.multiple && event.shiftKey && metaKey) {
          this.onOptionSelectRange(event, this.startRangeIndex, optionIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
      }
      event.preventDefault();
    }, "onEndKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey(event) {
      this.scrollInView(0);
      event.preventDefault();
    }, "onPageUpKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey(event) {
      this.scrollInView(this.visibleOptions.length - 1);
      event.preventDefault();
    }, "onPageDownKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey(event) {
      if (this.focusedOptionIndex !== -1) {
        if (this.multiple && event.shiftKey) this.onOptionSelectRange(event, this.focusedOptionIndex);
        else this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
      }
    }, "onEnterKey"),
    onSpaceKey: /* @__PURE__ */ __name(function onSpaceKey(event) {
      event.preventDefault();
      this.onEnterKey(event);
    }, "onSpaceKey"),
    onShiftKey: /* @__PURE__ */ __name(function onShiftKey() {
      this.startRangeIndex = this.focusedOptionIndex;
    }, "onShiftKey"),
    isOptionMatched: /* @__PURE__ */ __name(function isOptionMatched(option5) {
      var _this$getOptionLabel;
      return this.isValidOption(option5) && typeof this.getOptionLabel(option5) === "string" && ((_this$getOptionLabel = this.getOptionLabel(option5)) === null || _this$getOptionLabel === void 0 ? void 0 : _this$getOptionLabel.toLocaleLowerCase(this.filterLocale).startsWith(this.searchValue.toLocaleLowerCase(this.filterLocale)));
    }, "isOptionMatched"),
    isValidOption: /* @__PURE__ */ __name(function isValidOption(option5) {
      return isNotEmpty$2(option5) && !(this.isOptionDisabled(option5) || this.isOptionGroup(option5));
    }, "isValidOption"),
    isValidSelectedOption: /* @__PURE__ */ __name(function isValidSelectedOption(option5) {
      return this.isValidOption(option5) && this.isSelected(option5);
    }, "isValidSelectedOption"),
    isEquals: /* @__PURE__ */ __name(function isEquals(value1, value22) {
      return equals$2(value1, value22, this.equalityKey);
    }, "isEquals"),
    isSelected: /* @__PURE__ */ __name(function isSelected(option5) {
      var _this4 = this;
      var optionValue = this.getOptionValue(option5);
      if (this.multiple) return (this.d_value || []).some(function(value3) {
        return _this4.isEquals(value3, optionValue);
      });
      else return this.isEquals(this.d_value, optionValue);
    }, "isSelected"),
    findFirstOptionIndex: /* @__PURE__ */ __name(function findFirstOptionIndex() {
      var _this5 = this;
      return this.visibleOptions.findIndex(function(option5) {
        return _this5.isValidOption(option5);
      });
    }, "findFirstOptionIndex"),
    findLastOptionIndex: /* @__PURE__ */ __name(function findLastOptionIndex() {
      var _this6 = this;
      return findLastIndex$2(this.visibleOptions, function(option5) {
        return _this6.isValidOption(option5);
      });
    }, "findLastOptionIndex"),
    findNextOptionIndex: /* @__PURE__ */ __name(function findNextOptionIndex(index2) {
      var _this7 = this;
      var matchedOptionIndex = index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this7.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : index2;
    }, "findNextOptionIndex"),
    findPrevOptionIndex: /* @__PURE__ */ __name(function findPrevOptionIndex(index2) {
      var _this8 = this;
      var matchedOptionIndex = index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this8.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findPrevOptionIndex"),
    findSelectedOptionIndex: /* @__PURE__ */ __name(function findSelectedOptionIndex() {
      var _this9 = this;
      if (this.$filled) {
        if (this.multiple) {
          var _loop = /* @__PURE__ */ __name(function _loop2() {
            var value3 = _this9.d_value[index2];
            var matchedOptionIndex = _this9.visibleOptions.findIndex(function(option5) {
              return _this9.isValidSelectedOption(option5) && _this9.isEquals(value3, _this9.getOptionValue(option5));
            });
            if (matchedOptionIndex > -1) return {
              v: matchedOptionIndex
            };
          }, "_loop"), _ret;
          for (var index2 = this.d_value.length - 1; index2 >= 0; index2--) {
            _ret = _loop();
            if (_ret) return _ret.v;
          }
        } else {
          return this.visibleOptions.findIndex(function(option5) {
            return _this9.isValidSelectedOption(option5);
          });
        }
      }
      return -1;
    }, "findSelectedOptionIndex"),
    findFirstSelectedOptionIndex: /* @__PURE__ */ __name(function findFirstSelectedOptionIndex() {
      var _this10 = this;
      return this.$filled ? this.visibleOptions.findIndex(function(option5) {
        return _this10.isValidSelectedOption(option5);
      }) : -1;
    }, "findFirstSelectedOptionIndex"),
    findLastSelectedOptionIndex: /* @__PURE__ */ __name(function findLastSelectedOptionIndex() {
      var _this11 = this;
      return this.$filled ? findLastIndex$2(this.visibleOptions, function(option5) {
        return _this11.isValidSelectedOption(option5);
      }) : -1;
    }, "findLastSelectedOptionIndex"),
    findNextSelectedOptionIndex: /* @__PURE__ */ __name(function findNextSelectedOptionIndex(index2) {
      var _this12 = this;
      var matchedOptionIndex = this.$filled && index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this12.isValidSelectedOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : -1;
    }, "findNextSelectedOptionIndex"),
    findPrevSelectedOptionIndex: /* @__PURE__ */ __name(function findPrevSelectedOptionIndex(index2) {
      var _this13 = this;
      var matchedOptionIndex = this.$filled && index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this13.isValidSelectedOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : -1;
    }, "findPrevSelectedOptionIndex"),
    findNearestSelectedOptionIndex: /* @__PURE__ */ __name(function findNearestSelectedOptionIndex(index2) {
      var firstCheckUp = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var matchedOptionIndex = -1;
      if (this.$filled) {
        if (firstCheckUp) {
          matchedOptionIndex = this.findPrevSelectedOptionIndex(index2);
          matchedOptionIndex = matchedOptionIndex === -1 ? this.findNextSelectedOptionIndex(index2) : matchedOptionIndex;
        } else {
          matchedOptionIndex = this.findNextSelectedOptionIndex(index2);
          matchedOptionIndex = matchedOptionIndex === -1 ? this.findPrevSelectedOptionIndex(index2) : matchedOptionIndex;
        }
      }
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findNearestSelectedOptionIndex"),
    findFirstFocusedOptionIndex: /* @__PURE__ */ __name(function findFirstFocusedOptionIndex() {
      var selectedIndex = this.findFirstSelectedOptionIndex();
      return selectedIndex < 0 ? this.findFirstOptionIndex() : selectedIndex;
    }, "findFirstFocusedOptionIndex"),
    findLastFocusedOptionIndex: /* @__PURE__ */ __name(function findLastFocusedOptionIndex() {
      var selectedIndex = this.findLastSelectedOptionIndex();
      return selectedIndex < 0 ? this.findLastOptionIndex() : selectedIndex;
    }, "findLastFocusedOptionIndex"),
    searchOptions: /* @__PURE__ */ __name(function searchOptions(event, _char) {
      var _this14 = this;
      this.searchValue = (this.searchValue || "") + _char;
      var optionIndex = -1;
      if (isNotEmpty$2(this.searchValue)) {
        if (this.focusedOptionIndex !== -1) {
          optionIndex = this.visibleOptions.slice(this.focusedOptionIndex).findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          });
          optionIndex = optionIndex === -1 ? this.visibleOptions.slice(0, this.focusedOptionIndex).findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          }) : optionIndex + this.focusedOptionIndex;
        } else {
          optionIndex = this.visibleOptions.findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          });
        }
        if (optionIndex === -1 && this.focusedOptionIndex === -1) {
          optionIndex = this.findFirstFocusedOptionIndex();
        }
        if (optionIndex !== -1) {
          this.changeFocusedOptionIndex(event, optionIndex);
        }
      }
      if (this.searchTimeout) {
        clearTimeout(this.searchTimeout);
      }
      this.searchTimeout = setTimeout(function() {
        _this14.searchValue = "";
        _this14.searchTimeout = null;
      }, 500);
    }, "searchOptions"),
    removeOption: /* @__PURE__ */ __name(function removeOption(option5) {
      var _this15 = this;
      return this.d_value.filter(function(val) {
        return !equals$2(val, _this15.getOptionValue(option5), _this15.equalityKey);
      });
    }, "removeOption"),
    changeFocusedOptionIndex: /* @__PURE__ */ __name(function changeFocusedOptionIndex(event, index2) {
      if (this.focusedOptionIndex !== index2) {
        this.focusedOptionIndex = index2;
        this.scrollInView();
        if (this.selectOnFocus && !this.multiple) {
          this.onOptionSelect(event, this.visibleOptions[index2]);
        }
      }
    }, "changeFocusedOptionIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView3() {
      var _this16 = this;
      var index2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : -1;
      this.$nextTick(function() {
        var id4 = index2 !== -1 ? "".concat(_this16.id, "_").concat(index2) : _this16.focusedOptionId;
        var element = findSingle$1(_this16.list, 'li[id="'.concat(id4, '"]'));
        if (element) {
          element.scrollIntoView && element.scrollIntoView({
            block: "nearest",
            inline: "nearest",
            behavior: "smooth"
          });
        } else if (!_this16.virtualScrollerDisabled) {
          _this16.virtualScroller && _this16.virtualScroller.scrollToIndex(index2 !== -1 ? index2 : _this16.focusedOptionIndex);
        }
      });
    }, "scrollInView"),
    autoUpdateModel: /* @__PURE__ */ __name(function autoUpdateModel() {
      if (this.selectOnFocus && this.autoOptionFocus && !this.$filled && !this.multiple && this.focused) {
        this.focusedOptionIndex = this.findFirstFocusedOptionIndex();
        this.onOptionSelect(null, this.visibleOptions[this.focusedOptionIndex]);
      }
    }, "autoUpdateModel"),
    updateModel: /* @__PURE__ */ __name(function updateModel(event, value3) {
      this.writeValue(value3, event);
      this.$emit("change", {
        originalEvent: event,
        value: value3
      });
    }, "updateModel"),
    listRef: /* @__PURE__ */ __name(function listRef(el, contentRef3) {
      this.list = el;
      contentRef3 && contentRef3(el);
    }, "listRef"),
    virtualScrollerRef: /* @__PURE__ */ __name(function virtualScrollerRef(el) {
      this.virtualScroller = el;
    }, "virtualScrollerRef")
  },
  computed: {
    optionsListFlat: /* @__PURE__ */ __name(function optionsListFlat() {
      return this.filterValue ? FilterService.filter(this.options, this.searchFields, this.filterValue, this.filterMatchMode, this.filterLocale) : this.options;
    }, "optionsListFlat"),
    optionsListGroup: /* @__PURE__ */ __name(function optionsListGroup() {
      var _this17 = this;
      var filteredOptions = [];
      (this.options || []).forEach(function(optionGroup) {
        var optionGroupChildren = _this17.getOptionGroupChildren(optionGroup) || [];
        var filteredChildren = _this17.filterValue ? FilterService.filter(optionGroupChildren, _this17.searchFields, _this17.filterValue, _this17.filterMatchMode, _this17.filterLocale) : optionGroupChildren;
        if (filteredChildren !== null && filteredChildren !== void 0 && filteredChildren.length) {
          filteredOptions.push.apply(filteredOptions, [{
            optionGroup,
            group: true
          }].concat(_toConsumableArray$a(filteredChildren)));
        }
      });
      return filteredOptions;
    }, "optionsListGroup"),
    visibleOptions: /* @__PURE__ */ __name(function visibleOptions() {
      return this.optionGroupLabel ? this.optionsListGroup : this.optionsListFlat;
    }, "visibleOptions"),
    // @deprecated use $filled instead
    hasSelectedOption: /* @__PURE__ */ __name(function hasSelectedOption() {
      return isNotEmpty$2(this.d_value);
    }, "hasSelectedOption"),
    equalityKey: /* @__PURE__ */ __name(function equalityKey() {
      return this.optionValue ? null : this.dataKey;
    }, "equalityKey"),
    searchFields: /* @__PURE__ */ __name(function searchFields() {
      return this.filterFields || [this.optionLabel];
    }, "searchFields"),
    filterResultMessageText: /* @__PURE__ */ __name(function filterResultMessageText() {
      return isNotEmpty$2(this.visibleOptions) ? this.filterMessageText.replaceAll("{0}", this.visibleOptions.length) : this.emptyFilterMessageText;
    }, "filterResultMessageText"),
    filterMessageText: /* @__PURE__ */ __name(function filterMessageText() {
      return this.filterMessage || this.$primevue.config.locale.searchMessage || "";
    }, "filterMessageText"),
    emptyFilterMessageText: /* @__PURE__ */ __name(function emptyFilterMessageText() {
      return this.emptyFilterMessage || this.$primevue.config.locale.emptySearchMessage || this.$primevue.config.locale.emptyFilterMessage || "";
    }, "emptyFilterMessageText"),
    emptyMessageText: /* @__PURE__ */ __name(function emptyMessageText() {
      return this.emptyMessage || this.$primevue.config.locale.emptyMessage || "";
    }, "emptyMessageText"),
    selectionMessageText: /* @__PURE__ */ __name(function selectionMessageText() {
      return this.selectionMessage || this.$primevue.config.locale.selectionMessage || "";
    }, "selectionMessageText"),
    emptySelectionMessageText: /* @__PURE__ */ __name(function emptySelectionMessageText() {
      return this.emptySelectionMessage || this.$primevue.config.locale.emptySelectionMessage || "";
    }, "emptySelectionMessageText"),
    selectedMessageText: /* @__PURE__ */ __name(function selectedMessageText() {
      return this.$filled ? this.selectionMessageText.replaceAll("{0}", this.multiple ? this.d_value.length : "1") : this.emptySelectionMessageText;
    }, "selectedMessageText"),
    focusedOptionId: /* @__PURE__ */ __name(function focusedOptionId() {
      return this.focusedOptionIndex !== -1 ? "".concat(this.id, "_").concat(this.focusedOptionIndex) : null;
    }, "focusedOptionId"),
    ariaSetSize: /* @__PURE__ */ __name(function ariaSetSize() {
      var _this18 = this;
      return this.visibleOptions.filter(function(option5) {
        return !_this18.isOptionGroup(option5);
      }).length;
    }, "ariaSetSize"),
    virtualScrollerDisabled: /* @__PURE__ */ __name(function virtualScrollerDisabled() {
      return !this.virtualScrollerOptions;
    }, "virtualScrollerDisabled")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    InputText: script$P,
    VirtualScroller: script$H,
    InputIcon: script$I,
    IconField: script$J,
    SearchIcon: script$K,
    CheckIcon: script$S,
    BlankIcon: script$L
  }
};
var _hoisted_1$1y = ["id"];
var _hoisted_2$17 = ["tabindex"];
var _hoisted_3$N = ["id", "aria-multiselectable", "aria-label", "aria-labelledby", "aria-activedescendant", "aria-disabled"];
var _hoisted_4$y = ["id"];
var _hoisted_5$s = ["id", "aria-label", "aria-selected", "aria-disabled", "aria-setsize", "aria-posinset", "onClick", "onMousedown", "onMousemove", "onDblclick", "data-p-selected", "data-p-focused", "data-p-disabled"];
var _hoisted_6$k = ["tabindex"];
function render$E(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_InputText = resolveComponent("InputText");
  var _component_SearchIcon = resolveComponent("SearchIcon");
  var _component_InputIcon = resolveComponent("InputIcon");
  var _component_IconField = resolveComponent("IconField");
  var _component_CheckIcon = resolveComponent("CheckIcon");
  var _component_BlankIcon = resolveComponent("BlankIcon");
  var _component_VirtualScroller = resolveComponent("VirtualScroller");
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    id: $data.id,
    "class": _ctx.cx("root"),
    onFocusout: _cache[7] || (_cache[7] = function() {
      return $options.onFocusout && $options.onFocusout.apply($options, arguments);
    })
  }, _ctx.ptmi("root")), [createBaseVNode("span", mergeProps$2({
    ref: "firstHiddenFocusableElement",
    role: "presentation",
    "aria-hidden": "true",
    "class": "p-hidden-accessible p-hidden-focusable",
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFirstHiddenFocus && $options.onFirstHiddenFocus.apply($options, arguments);
    })
  }, _ctx.ptm("hiddenFirstFocusableEl"), {
    "data-p-hidden-accessible": true,
    "data-p-hidden-focusable": true
  }), null, 16, _hoisted_2$17), _ctx.$slots.header ? (openBlock(), createElementBlock("div", {
    key: 0,
    "class": normalizeClass(_ctx.cx("header"))
  }, [renderSlot(_ctx.$slots, "header", {
    value: _ctx.d_value,
    options: $options.visibleOptions
  })], 2)) : createCommentVNode("", true), _ctx.filter ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": _ctx.cx("header")
  }, _ctx.ptm("header")), [createVNode(_component_IconField, {
    unstyled: _ctx.unstyled,
    pt: _ctx.ptm("pcFilterContainer")
  }, {
    "default": withCtx(function() {
      return [createVNode(_component_InputText, {
        modelValue: $data.filterValue,
        "onUpdate:modelValue": _cache[1] || (_cache[1] = function($event) {
          return $data.filterValue = $event;
        }),
        type: "text",
        "class": normalizeClass(_ctx.cx("pcFilter")),
        placeholder: _ctx.filterPlaceholder,
        role: "searchbox",
        autocomplete: "off",
        disabled: _ctx.disabled,
        unstyled: _ctx.unstyled,
        "aria-owns": $data.id + "_list",
        "aria-activedescendant": $options.focusedOptionId,
        tabindex: !_ctx.disabled && !$data.focused ? _ctx.tabindex : -1,
        onInput: $options.onFilterChange,
        onBlur: $options.onFilterBlur,
        onKeydown: $options.onFilterKeyDown,
        pt: _ctx.ptm("pcFilter")
      }, null, 8, ["modelValue", "class", "placeholder", "disabled", "unstyled", "aria-owns", "aria-activedescendant", "tabindex", "onInput", "onBlur", "onKeydown", "pt"]), createVNode(_component_InputIcon, {
        unstyled: _ctx.unstyled,
        pt: _ctx.ptm("pcFilterIconContainer")
      }, {
        "default": withCtx(function() {
          return [renderSlot(_ctx.$slots, "filtericon", {}, function() {
            return [_ctx.filterIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
              key: 0,
              "class": _ctx.filterIcon
            }, _ctx.ptm("filterIcon")), null, 16)) : (openBlock(), createBlock(_component_SearchIcon, normalizeProps(mergeProps$2({
              key: 1
            }, _ctx.ptm("filterIcon"))), null, 16))];
          })];
        }),
        _: 3
      }, 8, ["unstyled", "pt"])];
    }),
    _: 3
  }, 8, ["unstyled", "pt"]), createBaseVNode("span", mergeProps$2({
    role: "status",
    "aria-live": "polite",
    "class": "p-hidden-accessible"
  }, _ctx.ptm("hiddenFilterResult"), {
    "data-p-hidden-accessible": true
  }), toDisplayString$1($options.filterResultMessageText), 17)], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("listContainer"),
    style: [{
      "max-height": $options.virtualScrollerDisabled ? _ctx.scrollHeight : ""
    }, _ctx.listStyle]
  }, _ctx.ptm("listContainer")), [createVNode(_component_VirtualScroller, mergeProps$2({
    ref: $options.virtualScrollerRef
  }, _ctx.virtualScrollerOptions, {
    items: $options.visibleOptions,
    style: [{
      height: _ctx.scrollHeight
    }, _ctx.listStyle],
    tabindex: -1,
    disabled: $options.virtualScrollerDisabled,
    pt: _ctx.ptm("virtualScroller")
  }), createSlots({
    content: withCtx(function(_ref) {
      var styleClass = _ref.styleClass, contentRef3 = _ref.contentRef, items2 = _ref.items, getItemOptions = _ref.getItemOptions, contentStyle = _ref.contentStyle, itemSize2 = _ref.itemSize;
      return [createBaseVNode("ul", mergeProps$2({
        ref: /* @__PURE__ */ __name(function ref2(el) {
          return $options.listRef(el, contentRef3);
        }, "ref"),
        id: $data.id + "_list",
        "class": [_ctx.cx("list"), styleClass],
        style: contentStyle,
        tabindex: -1,
        role: "listbox",
        "aria-multiselectable": _ctx.multiple,
        "aria-label": _ctx.ariaLabel,
        "aria-labelledby": _ctx.ariaLabelledby,
        "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
        "aria-disabled": _ctx.disabled,
        onFocus: _cache[3] || (_cache[3] = function() {
          return $options.onListFocus && $options.onListFocus.apply($options, arguments);
        }),
        onBlur: _cache[4] || (_cache[4] = function() {
          return $options.onListBlur && $options.onListBlur.apply($options, arguments);
        }),
        onKeydown: _cache[5] || (_cache[5] = function() {
          return $options.onListKeyDown && $options.onListKeyDown.apply($options, arguments);
        })
      }, _ctx.ptm("list")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(items2, function(option5, i2) {
        return openBlock(), createElementBlock(Fragment$1, {
          key: $options.getOptionRenderKey(option5, $options.getOptionIndex(i2, getItemOptions))
        }, [$options.isOptionGroup(option5) ? (openBlock(), createElementBlock("li", mergeProps$2({
          key: 0,
          id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
          style: {
            height: itemSize2 ? itemSize2 + "px" : void 0
          },
          "class": _ctx.cx("optionGroup"),
          role: "option",
          ref_for: true
        }, _ctx.ptm("optionGroup")), [renderSlot(_ctx.$slots, "optiongroup", {
          option: option5.optionGroup,
          index: $options.getOptionIndex(i2, getItemOptions)
        }, function() {
          return [createTextVNode(toDisplayString$1($options.getOptionGroupLabel(option5.optionGroup)), 1)];
        })], 16, _hoisted_4$y)) : withDirectives((openBlock(), createElementBlock("li", mergeProps$2({
          key: 1,
          id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
          style: {
            height: itemSize2 ? itemSize2 + "px" : void 0
          },
          "class": _ctx.cx("option", {
            option: option5,
            index: i2,
            getItemOptions
          }),
          role: "option",
          "aria-label": $options.getOptionLabel(option5),
          "aria-selected": $options.isSelected(option5),
          "aria-disabled": $options.isOptionDisabled(option5),
          "aria-setsize": $options.ariaSetSize,
          "aria-posinset": $options.getAriaPosInset($options.getOptionIndex(i2, getItemOptions)),
          onClick: /* @__PURE__ */ __name(function onClick5($event) {
            return $options.onOptionSelect($event, option5, $options.getOptionIndex(i2, getItemOptions));
          }, "onClick"),
          onMousedown: /* @__PURE__ */ __name(function onMousedown($event) {
            return $options.onOptionMouseDown($event, $options.getOptionIndex(i2, getItemOptions));
          }, "onMousedown"),
          onMousemove: /* @__PURE__ */ __name(function onMousemove($event) {
            return $options.onOptionMouseMove($event, $options.getOptionIndex(i2, getItemOptions));
          }, "onMousemove"),
          onTouchend: _cache[2] || (_cache[2] = function($event) {
            return $options.onOptionTouchEnd();
          }),
          onDblclick: /* @__PURE__ */ __name(function onDblclick($event) {
            return $options.onOptionDblClick($event, option5);
          }, "onDblclick"),
          ref_for: true
        }, $options.getPTOptions(option5, getItemOptions, i2, "option"), {
          "data-p-selected": $options.isSelected(option5),
          "data-p-focused": $data.focusedOptionIndex === $options.getOptionIndex(i2, getItemOptions),
          "data-p-disabled": $options.isOptionDisabled(option5)
        }), [_ctx.checkmark ? (openBlock(), createElementBlock(Fragment$1, {
          key: 0
        }, [$options.isSelected(option5) ? (openBlock(), createBlock(_component_CheckIcon, mergeProps$2({
          key: 0,
          "class": _ctx.cx("optionCheckIcon"),
          ref_for: true
        }, _ctx.ptm("optionCheckIcon")), null, 16, ["class"])) : (openBlock(), createBlock(_component_BlankIcon, mergeProps$2({
          key: 1,
          "class": _ctx.cx("optionBlankIcon"),
          ref_for: true
        }, _ctx.ptm("optionBlankIcon")), null, 16, ["class"]))], 64)) : createCommentVNode("", true), renderSlot(_ctx.$slots, "option", {
          option: option5,
          selected: $options.isSelected(option5),
          index: $options.getOptionIndex(i2, getItemOptions)
        }, function() {
          return [createTextVNode(toDisplayString$1($options.getOptionLabel(option5)), 1)];
        })], 16, _hoisted_5$s)), [[_directive_ripple]])], 64);
      }), 128)), $data.filterValue && (!items2 || items2 && items2.length === 0) ? (openBlock(), createElementBlock("li", mergeProps$2({
        key: 0,
        "class": _ctx.cx("emptyMessage"),
        role: "option"
      }, _ctx.ptm("emptyMessage")), [renderSlot(_ctx.$slots, "emptyfilter", {}, function() {
        return [createTextVNode(toDisplayString$1($options.emptyFilterMessageText), 1)];
      })], 16)) : !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("li", mergeProps$2({
        key: 1,
        "class": _ctx.cx("emptyMessage"),
        role: "option"
      }, _ctx.ptm("emptyMessage")), [renderSlot(_ctx.$slots, "empty", {}, function() {
        return [createTextVNode(toDisplayString$1($options.emptyMessageText), 1)];
      })], 16)) : createCommentVNode("", true)], 16, _hoisted_3$N)];
    }),
    _: 2
  }, [_ctx.$slots.loader ? {
    name: "loader",
    fn: withCtx(function(_ref2) {
      var options5 = _ref2.options;
      return [renderSlot(_ctx.$slots, "loader", {
        options: options5
      })];
    }),
    key: "0"
  } : void 0]), 1040, ["items", "style", "disabled", "pt"])], 16), renderSlot(_ctx.$slots, "footer", {
    value: _ctx.d_value,
    options: $options.visibleOptions
  }), !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 2,
    role: "status",
    "aria-live": "polite",
    "class": "p-hidden-accessible"
  }, _ctx.ptm("hiddenEmptyMessage"), {
    "data-p-hidden-accessible": true
  }), toDisplayString$1($options.emptyMessageText), 17)) : createCommentVNode("", true), createBaseVNode("span", mergeProps$2({
    role: "status",
    "aria-live": "polite",
    "class": "p-hidden-accessible"
  }, _ctx.ptm("hiddenSelectedMessage"), {
    "data-p-hidden-accessible": true
  }), toDisplayString$1($options.selectedMessageText), 17), createBaseVNode("span", mergeProps$2({
    ref: "lastHiddenFocusableElement",
    role: "presentation",
    "aria-hidden": "true",
    "class": "p-hidden-accessible p-hidden-focusable",
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    onFocus: _cache[6] || (_cache[6] = function() {
      return $options.onLastHiddenFocus && $options.onLastHiddenFocus.apply($options, arguments);
    })
  }, _ctx.ptm("hiddenLastFocusableEl"), {
    "data-p-hidden-accessible": true,
    "data-p-hidden-focusable": true
  }), null, 16, _hoisted_6$k)], 16, _hoisted_1$1y);
}
__name(render$E, "render$E");
script$G.render = render$E;
const _hoisted_1$1x = { class: "flex align-items-center" };
const _hoisted_2$16 = { class: "node-type" };
const _hoisted_3$M = {
  key: 0,
  class: "node-hint"
};
const _sfc_main$1y = /* @__PURE__ */ defineComponent({
  __name: "LoadWorkflowWarning",
  props: {
    missingNodeTypes: {}
  },
  setup(__props) {
    const props = __props;
    const uniqueNodes = computed(() => {
      const seenTypes = /* @__PURE__ */ new Set();
      return props.missingNodeTypes.filter((node3) => {
        const type = typeof node3 === "object" ? node3.type : node3;
        if (seenTypes.has(type)) return false;
        seenTypes.add(type);
        return true;
      }).map((node3) => {
        if (typeof node3 === "object") {
          return {
            label: node3.type,
            hint: node3.hint,
            action: node3.action
          };
        }
        return { label: node3 };
      });
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(NoResultsPlaceholder, {
          class: "pb-0",
          icon: "pi pi-exclamation-circle",
          title: "Missing Node Types",
          message: "When loading the graph, the following node types were not found"
        }),
        createVNode(unref(script$G), {
          options: uniqueNodes.value,
          optionLabel: "label",
          scrollHeight: "100%",
          class: "comfy-missing-nodes",
          pt: {
            list: { class: "border-none" }
          }
        }, {
          option: withCtx((slotProps) => [
            createBaseVNode("div", _hoisted_1$1x, [
              createBaseVNode("span", _hoisted_2$16, toDisplayString$1(slotProps.option.label), 1),
              slotProps.option.hint ? (openBlock(), createElementBlock("span", _hoisted_3$M, toDisplayString$1(slotProps.option.hint), 1)) : createCommentVNode("", true),
              slotProps.option.action ? (openBlock(), createBlock(unref(script$10), {
                key: 1,
                onClick: slotProps.option.action.callback,
                label: slotProps.option.action.text,
                size: "small",
                outlined: ""
              }, null, 8, ["onClick", "label"])) : createCommentVNode("", true)
            ])
          ]),
          _: 1
        }, 8, ["options"])
      ], 64);
    };
  }
});
const LoadWorkflowWarning = /* @__PURE__ */ _export_sfc(_sfc_main$1y, [["__scopeId", "data-v-425cc3ac"]]);
"use strict";
class QuickLRU {
  static {
    __name(this, "QuickLRU");
  }
  constructor(options5 = {}) {
    if (!(options5.maxSize && options5.maxSize > 0)) {
      throw new TypeError("`maxSize` must be a number greater than 0");
    }
    if (typeof options5.maxAge === "number" && options5.maxAge === 0) {
      throw new TypeError("`maxAge` must be a number greater than 0");
    }
    this.maxSize = options5.maxSize;
    this.maxAge = options5.maxAge || Infinity;
    this.onEviction = options5.onEviction;
    this.cache = /* @__PURE__ */ new Map();
    this.oldCache = /* @__PURE__ */ new Map();
    this._size = 0;
  }
  _emitEvictions(cache2) {
    if (typeof this.onEviction !== "function") {
      return;
    }
    for (const [key, item3] of cache2) {
      this.onEviction(key, item3.value);
    }
  }
  _deleteIfExpired(key, item3) {
    if (typeof item3.expiry === "number" && item3.expiry <= Date.now()) {
      if (typeof this.onEviction === "function") {
        this.onEviction(key, item3.value);
      }
      return this.delete(key);
    }
    return false;
  }
  _getOrDeleteIfExpired(key, item3) {
    const deleted = this._deleteIfExpired(key, item3);
    if (deleted === false) {
      return item3.value;
    }
  }
  _getItemValue(key, item3) {
    return item3.expiry ? this._getOrDeleteIfExpired(key, item3) : item3.value;
  }
  _peek(key, cache2) {
    const item3 = cache2.get(key);
    return this._getItemValue(key, item3);
  }
  _set(key, value3) {
    this.cache.set(key, value3);
    this._size++;
    if (this._size >= this.maxSize) {
      this._size = 0;
      this._emitEvictions(this.oldCache);
      this.oldCache = this.cache;
      this.cache = /* @__PURE__ */ new Map();
    }
  }
  _moveToRecent(key, item3) {
    this.oldCache.delete(key);
    this._set(key, item3);
  }
  *_entriesAscending() {
    for (const item3 of this.oldCache) {
      const [key, value3] = item3;
      if (!this.cache.has(key)) {
        const deleted = this._deleteIfExpired(key, value3);
        if (deleted === false) {
          yield item3;
        }
      }
    }
    for (const item3 of this.cache) {
      const [key, value3] = item3;
      const deleted = this._deleteIfExpired(key, value3);
      if (deleted === false) {
        yield item3;
      }
    }
  }
  get(key) {
    if (this.cache.has(key)) {
      const item3 = this.cache.get(key);
      return this._getItemValue(key, item3);
    }
    if (this.oldCache.has(key)) {
      const item3 = this.oldCache.get(key);
      if (this._deleteIfExpired(key, item3) === false) {
        this._moveToRecent(key, item3);
        return item3.value;
      }
    }
  }
  set(key, value3, { maxAge = this.maxAge === Infinity ? void 0 : Date.now() + this.maxAge } = {}) {
    if (this.cache.has(key)) {
      this.cache.set(key, {
        value: value3,
        maxAge
      });
    } else {
      this._set(key, { value: value3, expiry: maxAge });
    }
  }
  has(key) {
    if (this.cache.has(key)) {
      return !this._deleteIfExpired(key, this.cache.get(key));
    }
    if (this.oldCache.has(key)) {
      return !this._deleteIfExpired(key, this.oldCache.get(key));
    }
    return false;
  }
  peek(key) {
    if (this.cache.has(key)) {
      return this._peek(key, this.cache);
    }
    if (this.oldCache.has(key)) {
      return this._peek(key, this.oldCache);
    }
  }
  delete(key) {
    const deleted = this.cache.delete(key);
    if (deleted) {
      this._size--;
    }
    return this.oldCache.delete(key) || deleted;
  }
  clear() {
    this.cache.clear();
    this.oldCache.clear();
    this._size = 0;
  }
  resize(newSize) {
    if (!(newSize && newSize > 0)) {
      throw new TypeError("`maxSize` must be a number greater than 0");
    }
    const items2 = [...this._entriesAscending()];
    const removeCount = items2.length - newSize;
    if (removeCount < 0) {
      this.cache = new Map(items2);
      this.oldCache = /* @__PURE__ */ new Map();
      this._size = items2.length;
    } else {
      if (removeCount > 0) {
        this._emitEvictions(items2.slice(0, removeCount));
      }
      this.oldCache = new Map(items2.slice(removeCount));
      this.cache = /* @__PURE__ */ new Map();
      this._size = 0;
    }
    this.maxSize = newSize;
  }
  *keys() {
    for (const [key] of this) {
      yield key;
    }
  }
  *values() {
    for (const [, value3] of this) {
      yield value3;
    }
  }
  *[Symbol.iterator]() {
    for (const item3 of this.cache) {
      const [key, value3] = item3;
      const deleted = this._deleteIfExpired(key, value3);
      if (deleted === false) {
        yield [key, value3.value];
      }
    }
    for (const item3 of this.oldCache) {
      const [key, value3] = item3;
      if (!this.cache.has(key)) {
        const deleted = this._deleteIfExpired(key, value3);
        if (deleted === false) {
          yield [key, value3.value];
        }
      }
    }
  }
  *entriesDescending() {
    let items2 = [...this.cache];
    for (let i2 = items2.length - 1; i2 >= 0; --i2) {
      const item3 = items2[i2];
      const [key, value3] = item3;
      const deleted = this._deleteIfExpired(key, value3);
      if (deleted === false) {
        yield [key, value3.value];
      }
    }
    items2 = [...this.oldCache];
    for (let i2 = items2.length - 1; i2 >= 0; --i2) {
      const item3 = items2[i2];
      const [key, value3] = item3;
      if (!this.cache.has(key)) {
        const deleted = this._deleteIfExpired(key, value3);
        if (deleted === false) {
          yield [key, value3.value];
        }
      }
    }
  }
  *entriesAscending() {
    for (const [key, value3] of this._entriesAscending()) {
      yield [key, value3.value];
    }
  }
  get size() {
    if (!this._size) {
      return this.oldCache.size;
    }
    let oldCacheSize = 0;
    for (const key of this.oldCache.keys()) {
      if (!this.cache.has(key)) {
        oldCacheSize++;
      }
    }
    return Math.min(this._size + oldCacheSize, this.maxSize);
  }
}
var quickLru = QuickLRU;
const QuickLRU$1 = /* @__PURE__ */ getDefaultExportFromCjs(quickLru);
function formatCamelCase(str) {
  const isCamelCase = /^([A-Z][a-z]*)+$/.test(str);
  if (!isCamelCase) {
    return str;
  }
  const words = str.split(/(?=[A-Z][a-z])|\d+/);
  const processedWords = words.map((word) => {
    if (word.length > 1 && word === word.toUpperCase()) {
      return word;
    }
    return word.charAt(0).toUpperCase() + word.slice(1);
  });
  return processedWords.join(" ");
}
__name(formatCamelCase, "formatCamelCase");
function appendJsonExt(path) {
  if (!path.toLowerCase().endsWith(".json")) {
    path += ".json";
  }
  return path;
}
__name(appendJsonExt, "appendJsonExt");
function trimJsonExt(path) {
  return path?.replace(/\.json$/, "");
}
__name(trimJsonExt, "trimJsonExt");
function highlightQuery(text2, query) {
  if (!query) return text2;
  const regex2 = new RegExp(`(${query})`, "gi");
  return text2.replace(regex2, '<span class="highlight">$1</span>');
}
__name(highlightQuery, "highlightQuery");
function formatNumberWithSuffix(num, {
  precision = 1,
  roundToInt = false
} = {}) {
  const suffixes = ["", "k", "m", "b", "t"];
  const absNum = Math.abs(num);
  if (absNum < 1e3) {
    return roundToInt ? Math.round(num).toString() : num.toFixed(precision);
  }
  const exp = Math.min(Math.floor(Math.log10(absNum) / 3), suffixes.length - 1);
  const formattedNum = (num / Math.pow(1e3, exp)).toFixed(precision);
  return `${formattedNum}${suffixes[exp]}`;
}
__name(formatNumberWithSuffix, "formatNumberWithSuffix");
function formatSize(value3) {
  if (value3 === null || value3 === void 0) {
    return "-";
  }
  const bytes = value3;
  if (bytes === 0) return "0 B";
  const k2 = 1024;
  const sizes = ["B", "KB", "MB", "GB"];
  const i2 = Math.floor(Math.log(bytes) / Math.log(k2));
  return `${parseFloat((bytes / Math.pow(k2, i2)).toFixed(2))} ${sizes[i2]}`;
}
__name(formatSize, "formatSize");
function findCommonPrefix(path1, path2) {
  const parts1 = path1.split("/");
  const parts2 = path2.split("/");
  const commonParts = [];
  for (let i2 = 0; i2 < Math.min(parts1.length, parts2.length); i2++) {
    if (parts1[i2] === parts2[i2]) {
      commonParts.push(parts1[i2]);
    } else {
      break;
    }
  }
  return commonParts.join("/");
}
__name(findCommonPrefix, "findCommonPrefix");
function getFilenameDetails(fullFilename) {
  if (fullFilename.includes(".")) {
    return {
      filename: fullFilename.split(".").slice(0, -1).join("."),
      suffix: fullFilename.split(".").pop() ?? null
    };
  } else {
    return { filename: fullFilename, suffix: null };
  }
}
__name(getFilenameDetails, "getFilenameDetails");
function getPathDetails(path) {
  const directory = path.split("/").slice(0, -1).join("/");
  const fullFilename = path.split("/").pop() ?? path;
  return { directory, fullFilename, ...getFilenameDetails(fullFilename) };
}
__name(getPathDetails, "getPathDetails");
function normalizeI18nKey(key) {
  return typeof key === "string" ? key.replace(/\./g, "_") : "";
}
__name(normalizeI18nKey, "normalizeI18nKey");
function processDynamicPrompt(input) {
  function stripComments(str) {
    return str.replace(/\/\*[\s\S]*?\*\/|\/\/.*/g, "");
  }
  __name(stripComments, "stripComments");
  let i2 = 0;
  let result = "";
  input = stripComments(input);
  const handleEscape = /* @__PURE__ */ __name(() => {
    const nextChar = input[i2++];
    return "\\" + nextChar;
  }, "handleEscape");
  function parseChoiceBlock() {
    const options5 = [];
    let choice = "";
    let depth = 0;
    while (i2 < input.length) {
      const char = input[i2++];
      if (char === "\\") {
        choice += handleEscape();
        continue;
      } else if (char === "{") {
        depth++;
      } else if (char === "}") {
        if (!depth) break;
        depth--;
      } else if (char === "|") {
        if (!depth) {
          options5.push(choice);
          choice = "";
          continue;
        }
      }
      choice += char;
    }
    options5.push(choice);
    const chosenOption = options5[Math.floor(Math.random() * options5.length)];
    return processDynamicPrompt(chosenOption);
  }
  __name(parseChoiceBlock, "parseChoiceBlock");
  while (i2 < input.length) {
    const char = input[i2++];
    if (char === "\\") {
      result += handleEscape();
    } else if (char === "{") {
      result += parseChoiceBlock();
    } else {
      result += char;
    }
  }
  return result.replace(/\\([{}|])/g, "$1");
}
__name(processDynamicPrompt, "processDynamicPrompt");
function isValidUrl(url) {
  try {
    new URL(url);
    return true;
  } catch {
    return false;
  }
}
__name(isValidUrl, "isValidUrl");
const hasAnnotation = /* @__PURE__ */ __name((filepath) => /\[(input|output|temp)\]/i.test(filepath), "hasAnnotation");
const createAnnotation = /* @__PURE__ */ __name((filepath, rootFolder = "input") => !hasAnnotation(filepath) && rootFolder !== "input" ? ` [${rootFolder}]` : "", "createAnnotation");
const createPath = /* @__PURE__ */ __name((filename, subfolder = "") => subfolder ? `${subfolder}/${filename}` : filename, "createPath");
function createAnnotatedPath(item3, options5 = {}) {
  const { rootFolder = "input", subfolder } = options5;
  if (typeof item3 === "string")
    return `${createPath(item3, subfolder)}${createAnnotation(item3, rootFolder)}`;
  return `${createPath(item3.filename ?? "", item3.subfolder)}${item3.type ? createAnnotation(item3.type, rootFolder) : ""}`;
}
__name(createAnnotatedPath, "createAnnotatedPath");
function parseFilePath(filepath) {
  if (!filepath?.trim()) return { filename: "", subfolder: "" };
  const normalizedPath = filepath.replace(/[\\/]+/g, "/").replace(/^\//, "").replace(/\/$/, "");
  const lastSlashIndex = normalizedPath.lastIndexOf("/");
  if (lastSlashIndex === -1) {
    return {
      filename: normalizedPath,
      subfolder: ""
    };
  }
  return {
    filename: normalizedPath.slice(lastSlashIndex + 1),
    subfolder: normalizedPath.slice(0, lastSlashIndex)
  };
}
__name(parseFilePath, "parseFilePath");
const parts = {
  d: /* @__PURE__ */ __name((d2) => d2.getDate(), "d"),
  M: /* @__PURE__ */ __name((d2) => d2.getMonth() + 1, "M"),
  h: /* @__PURE__ */ __name((d2) => d2.getHours(), "h"),
  m: /* @__PURE__ */ __name((d2) => d2.getMinutes(), "m"),
  s: /* @__PURE__ */ __name((d2) => d2.getSeconds(), "s")
};
const format$2 = Object.keys(parts).map((k2) => k2 + k2 + "?").join("|") + "|yyy?y?";
function formatDate(text2, date) {
  return text2.replace(new RegExp(format$2, "g"), (text22) => {
    if (text22 === "yy") return (date.getFullYear() + "").substring(2);
    if (text22 === "yyyy") return date.getFullYear().toString();
    if (text22[0] in parts) {
      const p2 = parts[text22[0]](date);
      return (p2 + "").padStart(text22.length, "0");
    }
    return text22;
  });
}
__name(formatDate, "formatDate");
const paramsToCacheKey = /* @__PURE__ */ __name((params) => {
  if (typeof params === "string") return params;
  if (typeof params === "object" && params !== null)
    return Object.keys(params).sort((a2, b2) => a2.localeCompare(b2)).map((key) => `${key}:${params[key]}`).join("&");
  return String(params);
}, "paramsToCacheKey");
const generateUUID = /* @__PURE__ */ __name(() => {
  if (typeof crypto !== "undefined" && typeof crypto.randomUUID === "function") {
    return crypto.randomUUID();
  }
  return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, (c2) => {
    const r2 = Math.random() * 16 | 0;
    const v2 = c2 === "x" ? r2 : r2 & 3 | 8;
    return v2.toString(16);
  });
}, "generateUUID");
const isCivitaiModelUrl = /* @__PURE__ */ __name((url) => {
  if (!isValidUrl(url)) return false;
  if (!url.includes("civitai.com")) return false;
  const urlObj = new URL(url);
  const pathname = urlObj.pathname;
  return /^\/api\/download\/models\/(\d+)$/.test(pathname) || /^\/api\/v1\/models\/(\d+)$/.test(pathname) || /^\/api\/v1\/models-versions\/(\d+)$/.test(pathname);
}, "isCivitaiModelUrl");
const downloadUrlToHfRepoUrl = /* @__PURE__ */ __name((url) => {
  try {
    const urlObj = new URL(url);
    const pathname = urlObj.pathname;
    const regex2 = /^(.*?)(?:\/resolve\/|\/blob\/|$)/;
    const repoPathMatch = regex2.exec(pathname);
    const repoPath = repoPathMatch?.[1]?.replace(/^\//, "") || "";
    return `https://huggingface.co/${repoPath}`;
  } catch (error2) {
    return url;
  }
}, "downloadUrlToHfRepoUrl");
const isSemVer = /* @__PURE__ */ __name((version2) => {
  const regex2 = /^(\d+)\.(\d+)\.(\d+)$/;
  return regex2.test(version2);
}, "isSemVer");
const normalizeVersion = /* @__PURE__ */ __name((version2) => version2.split(/[+.-]/).map(Number).filter((part) => !Number.isNaN(part)), "normalizeVersion");
function compareVersions(versionA, versionB) {
  versionA ??= "0.0.0";
  versionB ??= "0.0.0";
  const aParts = normalizeVersion(versionA);
  const bParts = normalizeVersion(versionB);
  for (let i2 = 0; i2 < Math.max(aParts.length, bParts.length); i2++) {
    const aPart = aParts[i2] ?? 0;
    const bPart = bParts[i2] ?? 0;
    if (aPart < bPart) return -1;
    if (aPart > bPart) return 1;
  }
  return 0;
}
__name(compareVersions, "compareVersions");
const DEFAULT_MAX_SIZE = 50;
function useCachedRequest(requestFunction, options5 = {}) {
  const { maxSize = DEFAULT_MAX_SIZE, cacheKeyFn = paramsToCacheKey } = options5;
  const cache2 = new QuickLRU$1({ maxSize });
  const pendingRequests = /* @__PURE__ */ new Map();
  const abortControllers = /* @__PURE__ */ new Map();
  const executeAndCacheCall = /* @__PURE__ */ __name(async (params, cacheKey) => {
    try {
      const controller = new AbortController();
      abortControllers.set(cacheKey, controller);
      const responsePromise = requestFunction(params, controller.signal);
      pendingRequests.set(cacheKey, responsePromise);
      const result = await responsePromise;
      cache2.set(cacheKey, result);
      return result;
    } catch (err) {
      cache2.set(cacheKey, null);
      return null;
    } finally {
      pendingRequests.delete(cacheKey);
      abortControllers.delete(cacheKey);
    }
  }, "executeAndCacheCall");
  const handlePendingRequest = /* @__PURE__ */ __name(async (pendingRequest) => {
    try {
      return await pendingRequest;
    } catch (err) {
      console.error("Error in pending request:", err);
      return null;
    }
  }, "handlePendingRequest");
  const abortAllRequests = /* @__PURE__ */ __name(() => {
    for (const controller of abortControllers.values()) {
      controller.abort();
    }
  }, "abortAllRequests");
  const cancel = /* @__PURE__ */ __name(() => {
    abortAllRequests();
    abortControllers.clear();
    pendingRequests.clear();
  }, "cancel");
  const call = /* @__PURE__ */ __name(async (params) => {
    const cacheKey = cacheKeyFn(params);
    const cachedResult2 = cache2.get(cacheKey);
    if (cachedResult2 !== void 0) return cachedResult2;
    const pendingRequest = pendingRequests.get(cacheKey);
    if (pendingRequest) return handlePendingRequest(pendingRequest);
    return executeAndCacheCall(params, cacheKey);
  }, "call");
  return {
    call,
    cancel,
    clear: /* @__PURE__ */ __name(() => cache2.clear(), "clear")
  };
}
__name(useCachedRequest, "useCachedRequest");
const MANAGER_WS_MSG_TYPE = "cm-queue-status";
var ManagerWsQueueStatus = /* @__PURE__ */ ((ManagerWsQueueStatus2) => {
  ManagerWsQueueStatus2["DONE"] = "done";
  ManagerWsQueueStatus2["IN_PROGRESS"] = "in_progress";
  return ManagerWsQueueStatus2;
})(ManagerWsQueueStatus || {});
const useManagerQueue = /* @__PURE__ */ __name(() => {
  const clientQueueItems = ref([]);
  const clientQueueLength = computed(() => clientQueueItems.value.length);
  const onCompletedQueue = ref([]);
  const onCompleteWaitingCount = ref(0);
  const uncompletedCount = computed(
    () => clientQueueLength.value + onCompleteWaitingCount.value
  );
  const serverQueueStatus = ref(
    "done"
    /* DONE */
  );
  const isServerIdle = computed(
    () => serverQueueStatus.value === "done"
    /* DONE */
  );
  const allTasksDone = computed(
    () => isServerIdle.value && clientQueueLength.value === 0
  );
  const nextTaskReady = computed(
    () => isServerIdle.value && clientQueueLength.value > 0
  );
  const cleanupListener = useEventListener(
    api,
    MANAGER_WS_MSG_TYPE,
    (event) => {
      if (event?.type === MANAGER_WS_MSG_TYPE && event.detail?.status) {
        serverQueueStatus.value = event.detail.status;
      }
    }
  );
  const startNextTask = /* @__PURE__ */ __name(() => {
    const nextTask = clientQueueItems.value.shift();
    if (!nextTask) return;
    const { task, onComplete } = nextTask;
    if (onComplete) {
      onCompletedQueue.value.push(onComplete);
      onCompleteWaitingCount.value++;
    }
    task().catch((e2) => {
      const message3 = `Error enqueuing task for ComfyUI Manager: ${e2}`;
      console.error(message3);
    });
  }, "startNextTask");
  const enqueueTask = /* @__PURE__ */ __name((task) => {
    clientQueueItems.value.push(task);
  }, "enqueueTask");
  const clearQueue = /* @__PURE__ */ __name(() => {
    clientQueueItems.value = [];
    onCompletedQueue.value = [];
    onCompleteWaitingCount.value = 0;
  }, "clearQueue");
  const cleanup = /* @__PURE__ */ __name(() => {
    clearQueue();
    cleanupListener();
  }, "cleanup");
  whenever(nextTaskReady, startNextTask);
  whenever(isServerIdle, () => {
    if (onCompletedQueue.value?.length) {
      while (onCompleteWaitingCount.value > 0 && onCompletedQueue.value.length > 0) {
        const onComplete = onCompletedQueue.value.shift();
        onComplete?.();
        onCompleteWaitingCount.value--;
      }
    }
  });
  return {
    allTasksDone,
    statusMessage: readonly(serverQueueStatus),
    queueLength: clientQueueLength,
    uncompletedCount,
    enqueueTask,
    clearQueue,
    cleanup
  };
}, "useManagerQueue");
const LOGS_MESSAGE_TYPE = "logs";
const useServerLogs = /* @__PURE__ */ __name((options5 = {}) => {
  const {
    immediate = false,
    messageFilter = /* @__PURE__ */ __name((msg) => Boolean(msg.trim()), "messageFilter")
  } = options5;
  const logs = ref([]);
  let stop2 = null;
  const isValidLogEvent = /* @__PURE__ */ __name((event) => event?.type === LOGS_MESSAGE_TYPE && event.detail?.entries?.length > 0, "isValidLogEvent");
  const parseLogMessage = /* @__PURE__ */ __name((event) => event.detail.entries.map((e2) => e2.m).filter(messageFilter), "parseLogMessage");
  const handleLogMessage = /* @__PURE__ */ __name((event) => {
    if (isValidLogEvent(event)) {
      logs.value.push(...parseLogMessage(event));
    }
  }, "handleLogMessage");
  const start2 = /* @__PURE__ */ __name(() => {
    api.subscribeLogs(true);
    stop2 = useEventListener(api, LOGS_MESSAGE_TYPE, handleLogMessage);
  }, "start");
  const stopListening = /* @__PURE__ */ __name(() => {
    stop2?.();
    stop2 = null;
    api.subscribeLogs(false);
  }, "stopListening");
  if (immediate) {
    start2();
  }
  onUnmounted(() => {
    stopListening();
    logs.value = [];
  });
  return {
    logs,
    startListening: start2,
    stopListening
  };
}, "useServerLogs");
const IsInstallingKey = Symbol("isInstalling");
var ManagerPackState = /* @__PURE__ */ ((ManagerPackState2) => {
  ManagerPackState2["INSTALLED"] = "installed";
  ManagerPackState2["DISABLED"] = "disabled";
  ManagerPackState2["NOT_INSTALLED"] = "not_installed";
  ManagerPackState2["IMPORT_FAILED"] = "import_failed";
  ManagerPackState2["NEEDS_UPDATE"] = "needs_update";
  return ManagerPackState2;
})(ManagerPackState || {});
var ManagerPackInstallType = /* @__PURE__ */ ((ManagerPackInstallType2) => {
  ManagerPackInstallType2["GIT"] = "git-clone";
  ManagerPackInstallType2["COPY"] = "copy";
  ManagerPackInstallType2["REGISTRY"] = "cnr";
  return ManagerPackInstallType2;
})(ManagerPackInstallType || {});
var SelectedVersion = /* @__PURE__ */ ((SelectedVersion2) => {
  SelectedVersion2["LATEST"] = "latest";
  SelectedVersion2["NIGHTLY"] = "nightly";
  return SelectedVersion2;
})(SelectedVersion || {});
var ManagerChannel = /* @__PURE__ */ ((ManagerChannel2) => {
  ManagerChannel2["DEFAULT"] = "default";
  ManagerChannel2["RECENT"] = "recent";
  ManagerChannel2["LEGACY"] = "legacy";
  ManagerChannel2["FORKED"] = "forked";
  ManagerChannel2["DEV"] = "dev";
  ManagerChannel2["TUTORIAL"] = "tutorial";
  return ManagerChannel2;
})(ManagerChannel || {});
var ManagerDatabaseSource = /* @__PURE__ */ ((ManagerDatabaseSource2) => {
  ManagerDatabaseSource2["REMOTE"] = "remote";
  ManagerDatabaseSource2["LOCAL"] = "local";
  ManagerDatabaseSource2["CACHE"] = "cache";
  return ManagerDatabaseSource2;
})(ManagerDatabaseSource || {});
function isPrimitiveNode(node3) {
  return node3.type === "PrimitiveNode";
}
__name(isPrimitiveNode, "isPrimitiveNode");
const isAbortError = /* @__PURE__ */ __name((err) => err instanceof DOMException && err.name === "AbortError", "isAbortError");
const GENERIC_SECURITY_ERR_MSG = "Forbidden: A security error has occurred. Please check the terminal logs";
var ManagerRoute = /* @__PURE__ */ ((ManagerRoute2) => {
  ManagerRoute2["START_QUEUE"] = "manager/queue/start";
  ManagerRoute2["RESET_QUEUE"] = "manager/queue/reset";
  ManagerRoute2["QUEUE_STATUS"] = "manager/queue/status";
  ManagerRoute2["INSTALL"] = "manager/queue/install";
  ManagerRoute2["UPDATE"] = "manager/queue/update";
  ManagerRoute2["UPDATE_ALL"] = "manager/queue/update_all";
  ManagerRoute2["UNINSTALL"] = "manager/queue/uninstall";
  ManagerRoute2["DISABLE"] = "manager/queue/disable";
  ManagerRoute2["FIX_NODE"] = "manager/queue/fix";
  ManagerRoute2["LIST_INSTALLED"] = "customnode/installed";
  ManagerRoute2["GET_NODES"] = "customnode/getmappings";
  ManagerRoute2["GET_PACKS"] = "customnode/getlist";
  ManagerRoute2["IMPORT_FAIL_INFO"] = "customnode/import_fail_info";
  ManagerRoute2["REBOOT"] = "manager/reboot";
  return ManagerRoute2;
})(ManagerRoute || {});
const managerApiClient = axios.create({
  baseURL: api.apiURL(""),
  headers: {
    "Content-Type": "application/json"
  }
});
const useComfyManagerService = /* @__PURE__ */ __name(() => {
  const isLoading = ref(false);
  const error2 = ref(null);
  const didStartQueue = ref(false);
  const handleRequestError = /* @__PURE__ */ __name((err, context, routeSpecificErrors) => {
    if (isAbortError(err)) return;
    let message3;
    if (!axios.isAxiosError(err)) {
      message3 = `${context} failed: ${err instanceof Error ? err.message : String(err)}`;
    } else {
      const axiosError = err;
      const status = axiosError.response?.status;
      if (status && routeSpecificErrors?.[status]) {
        message3 = routeSpecificErrors[status];
      } else if (status === 404) {
        message3 = "Could not connect to ComfyUI-Manager";
      } else {
        message3 = axiosError.response?.data?.message ?? `${context} failed with status ${status}`;
      }
    }
    error2.value = message3;
  }, "handleRequestError");
  const executeRequest = /* @__PURE__ */ __name(async (requestCall, options5) => {
    const { errorContext, routeSpecificErrors, isQueueOperation } = options5;
    isLoading.value = true;
    error2.value = null;
    try {
      const response = await requestCall();
      if (isQueueOperation) await startQueue();
      return response.data;
    } catch (err) {
      handleRequestError(err, errorContext, routeSpecificErrors);
      return null;
    } finally {
      isLoading.value = false;
    }
  }, "executeRequest");
  const startQueue = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Starting ComfyUI-Manager job queue";
    const routeSpecificErrors = {
      201: "Created: ComfyUI-Manager job queue is already running"
    };
    didStartQueue.value = true;
    return executeRequest(
      () => managerApiClient.get("manager/queue/start", { signal }),
      { errorContext, routeSpecificErrors }
    );
  }, "startQueue");
  const getQueueStatus = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Getting ComfyUI-Manager queue status";
    return executeRequest(
      () => managerApiClient.get("manager/queue/status", { signal }),
      { errorContext }
    );
  }, "getQueueStatus");
  const resetQueue = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Resetting ComfyUI-Manager queue";
    return executeRequest(
      () => managerApiClient.get("manager/queue/reset", { signal }),
      { errorContext }
    );
  }, "resetQueue");
  const listInstalledPacks = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Fetching installed packs";
    return executeRequest(
      () => managerApiClient.get("customnode/installed", { signal }),
      { errorContext }
    );
  }, "listInstalledPacks");
  const getImportFailInfo = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Fetching import failure information";
    return executeRequest(
      () => managerApiClient.get("customnode/import_fail_info", { signal }),
      { errorContext }
    );
  }, "getImportFailInfo");
  const installPack = /* @__PURE__ */ __name(async (params, signal) => {
    const errorContext = `Installing pack ${params.id}`;
    const routeSpecificErrors = {
      403: GENERIC_SECURITY_ERR_MSG,
      404: params.selected_version === SelectedVersion.NIGHTLY ? `Not Found: Node pack ${params.id} does not provide nightly version` : GENERIC_SECURITY_ERR_MSG
    };
    return executeRequest(
      () => managerApiClient.post("manager/queue/install", params, { signal }),
      { errorContext, routeSpecificErrors, isQueueOperation: true }
    );
  }, "installPack");
  const uninstallPack = /* @__PURE__ */ __name(async (params, signal) => {
    const errorContext = `Uninstalling pack ${params.id}`;
    const routeSpecificErrors = {
      403: GENERIC_SECURITY_ERR_MSG
    };
    return executeRequest(
      () => managerApiClient.post("manager/queue/uninstall", params, { signal }),
      { errorContext, routeSpecificErrors, isQueueOperation: true }
    );
  }, "uninstallPack");
  const disablePack = /* @__PURE__ */ __name(async (params, signal) => {
    const errorContext = `Disabling pack ${params.id}`;
    const routeSpecificErrors = {
      404: `Pack ${params.id} not found or not installed`,
      409: `Pack ${params.id} is already disabled`
    };
    return executeRequest(
      () => managerApiClient.post("manager/queue/disable", params, { signal }),
      { errorContext, routeSpecificErrors, isQueueOperation: true }
    );
  }, "disablePack");
  const updatePack = /* @__PURE__ */ __name(async (params, signal) => {
    const errorContext = `Updating pack ${params.id}`;
    const routeSpecificErrors = {
      403: GENERIC_SECURITY_ERR_MSG
    };
    return executeRequest(
      () => managerApiClient.post("manager/queue/update", params, { signal }),
      { errorContext, routeSpecificErrors, isQueueOperation: true }
    );
  }, "updatePack");
  const updateAllPacks = /* @__PURE__ */ __name(async (params, signal) => {
    const errorContext = "Updating all packs";
    const routeSpecificErrors = {
      403: "Forbidden: To use this action, a security_level of `middle or below` is required",
      401: "Unauthorized: ComfyUI-Manager job queue is busy"
    };
    return executeRequest(
      () => managerApiClient.get("manager/queue/update_all", { params, signal }),
      { errorContext, routeSpecificErrors, isQueueOperation: true }
    );
  }, "updateAllPacks");
  const rebootComfyUI = /* @__PURE__ */ __name(async (signal) => {
    const errorContext = "Rebooting ComfyUI";
    const routeSpecificErrors = {
      403: "Forbidden: Rebooting ComfyUI requires security_level of middle or below"
    };
    return executeRequest(
      () => managerApiClient.get("manager/reboot", { signal }),
      { errorContext, routeSpecificErrors }
    );
  }, "rebootComfyUI");
  return {
    // State
    isLoading,
    error: error2,
    // Queue operations
    startQueue,
    resetQueue,
    getQueueStatus,
    // Pack management
    listInstalledPacks,
    getImportFailInfo,
    installPack,
    uninstallPack,
    enablePack: installPack,
    // enable is done via install
    disablePack,
    updatePack,
    updateAllPacks,
    // System operations
    rebootComfyUI
  };
}, "useComfyManagerService");
const useComfyManagerStore = /* @__PURE__ */ defineStore("comfyManager", () => {
  const managerService = useComfyManagerService();
  const { showManagerProgressDialog } = useDialogService();
  const installedPacks = ref({});
  const enabledPacksIds = ref(/* @__PURE__ */ new Set());
  const disabledPacksIds = ref(/* @__PURE__ */ new Set());
  const installedPacksIds = ref(/* @__PURE__ */ new Set());
  const isStale2 = ref(true);
  const taskLogs = ref([]);
  const { statusMessage, allTasksDone, enqueueTask, uncompletedCount } = useManagerQueue();
  const setStale = /* @__PURE__ */ __name(() => {
    isStale2.value = true;
  }, "setStale");
  const getPackId = /* @__PURE__ */ __name((pack) => pack.cnr_id || pack.aux_id, "getPackId");
  const isInstalledPackId = /* @__PURE__ */ __name((packName) => !!packName && installedPacksIds.value.has(packName), "isInstalledPackId");
  const isEnabledPackId = /* @__PURE__ */ __name((packName) => !!packName && isInstalledPackId(packName) && enabledPacksIds.value.has(packName), "isEnabledPackId");
  const packsToIdSet = /* @__PURE__ */ __name((packs) => packs.reduce((acc, pack) => {
    const id4 = pack.cnr_id || pack.aux_id;
    if (id4) acc.add(id4);
    return acc;
  }, /* @__PURE__ */ new Set()), "packsToIdSet");
  const updateDisabledIds = /* @__PURE__ */ __name((packs) => {
    const enabledIds = /* @__PURE__ */ new Set();
    const disabledIds = /* @__PURE__ */ new Set();
    for (const pack of packs) {
      const id4 = getPackId(pack);
      if (!id4) continue;
      const { enabled } = pack;
      if (enabled === true) enabledIds.add(id4);
      else if (enabled === false) disabledIds.add(id4);
      const inBothSets = enabledIds.has(id4) && disabledIds.has(id4);
      if (inBothSets) disabledIds.delete(id4);
    }
    enabledPacksIds.value = enabledIds;
    disabledPacksIds.value = disabledIds;
  }, "updateDisabledIds");
  const updateInstalledIds = /* @__PURE__ */ __name((packs) => {
    installedPacksIds.value = packsToIdSet(packs);
  }, "updateInstalledIds");
  const onPacksChanged = /* @__PURE__ */ __name(() => {
    const packs = Object.values(installedPacks.value);
    updateDisabledIds(packs);
    updateInstalledIds(packs);
  }, "onPacksChanged");
  watch(installedPacks, onPacksChanged, { deep: true });
  const refreshInstalledList = /* @__PURE__ */ __name(async () => {
    const packs = await managerService.listInstalledPacks();
    if (packs) installedPacks.value = packs;
    isStale2.value = false;
  }, "refreshInstalledList");
  whenever(isStale2, refreshInstalledList, { immediate: true });
  whenever(uncompletedCount, () => showManagerProgressDialog());
  const withLogs = /* @__PURE__ */ __name((task, taskName) => {
    const { startListening, stopListening, logs } = useServerLogs();
    const loggedTask = /* @__PURE__ */ __name(async () => {
      taskLogs.value.push({ taskName, logs: logs.value });
      startListening();
      return task();
    }, "loggedTask");
    const onComplete = /* @__PURE__ */ __name(() => {
      stopListening();
      setStale();
    }, "onComplete");
    return { task: loggedTask, onComplete };
  }, "withLogs");
  const installPack = useCachedRequest(
    async (params, signal) => {
      if (!params.id) return;
      let actionDescription = "Installing";
      if (installedPacksIds.value.has(params.id)) {
        const installedPack = installedPacks.value[params.id];
        if (installedPack && installedPack.ver !== params.selected_version) {
          actionDescription = `Changing version from ${installedPack.ver} to ${params.selected_version}:`;
        } else {
          actionDescription = "Enabling";
        }
      }
      const task = /* @__PURE__ */ __name(() => managerService.installPack(params, signal), "task");
      enqueueTask(withLogs(task, `${actionDescription} ${params.id}`));
    },
    { maxSize: 1 }
  );
  const uninstallPack = /* @__PURE__ */ __name((params, signal) => {
    installPack.clear();
    installPack.cancel();
    const task = /* @__PURE__ */ __name(() => managerService.uninstallPack(params, signal), "task");
    enqueueTask(withLogs(task, `Uninstalling ${params.id}`));
  }, "uninstallPack");
  const updatePack = useCachedRequest(
    async (params, signal) => {
      updateAllPacks.cancel();
      const task = /* @__PURE__ */ __name(() => managerService.updatePack(params, signal), "task");
      enqueueTask(withLogs(task, `Updating ${params.id}`));
    },
    { maxSize: 1 }
  );
  const updateAllPacks = useCachedRequest(
    async (params, signal) => {
      const task = /* @__PURE__ */ __name(() => managerService.updateAllPacks(params, signal), "task");
      enqueueTask(withLogs(task, "Updating all packs"));
    },
    { maxSize: 1 }
  );
  const disablePack = /* @__PURE__ */ __name((params, signal) => {
    const task = /* @__PURE__ */ __name(() => managerService.disablePack(params, signal), "task");
    enqueueTask(withLogs(task, `Disabling ${params.id}`));
  }, "disablePack");
  const getInstalledPackVersion = /* @__PURE__ */ __name((packId) => {
    const pack = installedPacks.value[packId];
    return pack?.ver;
  }, "getInstalledPackVersion");
  const clearLogs = /* @__PURE__ */ __name(() => {
    taskLogs.value = [];
  }, "clearLogs");
  return {
    // Manager state
    isLoading: managerService.isLoading,
    error: managerService.error,
    statusMessage,
    allTasksDone,
    uncompletedCount,
    taskLogs,
    clearLogs,
    setStale,
    // Installed packs state
    installedPacks,
    installedPacksIds,
    isPackInstalled: isInstalledPackId,
    isPackEnabled: isEnabledPackId,
    getInstalledPackVersion,
    // Pack actions
    installPack,
    uninstallPack,
    updatePack,
    updateAllPacks,
    disablePack,
    enablePack: installPack
    // Enable is done via install endpoint with a disabled pack
  };
});
const useManagerProgressDialogStore = /* @__PURE__ */ defineStore(
  "managerProgressDialog",
  () => {
    const isExpanded = ref(false);
    const toggle5 = /* @__PURE__ */ __name(() => {
      isExpanded.value = !isExpanded.value;
    }, "toggle");
    const collapse = /* @__PURE__ */ __name(() => {
      isExpanded.value = false;
    }, "collapse");
    const expand = /* @__PURE__ */ __name(() => {
      isExpanded.value = true;
    }, "expand");
    return {
      isExpanded,
      toggle: toggle5,
      collapse,
      expand
    };
  }
);
const _hoisted_1$1w = { class: "flex items-center justify-between w-full py-2" };
const _hoisted_2$15 = { class: "flex flex-col text-sm font-medium leading-normal" };
const _hoisted_3$L = { class: "text-muted" };
const _hoisted_4$x = { class: "h-full" };
const _hoisted_5$r = { class: "whitespace-pre-wrap break-words" };
const _sfc_main$1x = /* @__PURE__ */ defineComponent({
  __name: "ManagerProgressDialogContent",
  setup(__props) {
    const { taskLogs } = useComfyManagerStore();
    const progressDialogContent = useManagerProgressDialogStore();
    const managerStore = useComfyManagerStore();
    const isInProgress = /* @__PURE__ */ __name((index2) => index2 === taskPanels.value.length - 1 && managerStore.uncompletedCount > 0, "isInProgress");
    const taskPanels = computed(() => taskLogs);
    const isExpanded = computed(() => progressDialogContent.isExpanded);
    const isCollapsed = computed(() => !isExpanded.value);
    const collapsedPanels = ref({});
    const togglePanel = /* @__PURE__ */ __name((index2) => {
      collapsedPanels.value[index2] = !collapsedPanels.value[index2];
    }, "togglePanel");
    const sectionsContainerRef = ref(null);
    const { y: scrollY } = useScroll(sectionsContainerRef, {
      eventListenerOptions: {
        passive: true
      }
    });
    const lastPanelRef = ref(null);
    const isUserScrolling = ref(false);
    const lastPanelLogs = computed(() => taskPanels.value?.at(-1)?.logs);
    const isAtBottom = /* @__PURE__ */ __name((el) => {
      if (!el) return false;
      const threshold = 20;
      return Math.abs(el.scrollHeight - el.scrollTop - el.clientHeight) < threshold;
    }, "isAtBottom");
    const scrollLastPanelToBottom = /* @__PURE__ */ __name(() => {
      if (!lastPanelRef.value || isUserScrolling.value) return;
      lastPanelRef.value.scrollTop = lastPanelRef.value.scrollHeight;
    }, "scrollLastPanelToBottom");
    const scrollContentToBottom = /* @__PURE__ */ __name(() => {
      scrollY.value = sectionsContainerRef.value?.scrollHeight ?? 0;
    }, "scrollContentToBottom");
    const resetUserScrolling = /* @__PURE__ */ __name(() => {
      isUserScrolling.value = false;
    }, "resetUserScrolling");
    const handleScroll = /* @__PURE__ */ __name((e2) => {
      const target2 = e2.target;
      if (target2 !== lastPanelRef.value) return;
      isUserScrolling.value = !isAtBottom(target2);
    }, "handleScroll");
    const onLogsAdded = /* @__PURE__ */ __name(() => {
      if (isUserScrolling.value) return;
      scrollLastPanelToBottom();
    }, "onLogsAdded");
    whenever(lastPanelLogs, onLogsAdded, { flush: "post", deep: true });
    whenever(() => isExpanded.value, scrollContentToBottom);
    whenever(isCollapsed, resetUserScrolling);
    onMounted(() => {
      scrollContentToBottom();
    });
    onBeforeUnmount(() => {
      progressDialogContent.collapse();
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["overflow-hidden transition-all duration-300", {
          "max-h-[500px]": isExpanded.value,
          "max-h-0 p-0 m-0": !isExpanded.value
        }])
      }, [
        createBaseVNode("div", {
          ref_key: "sectionsContainerRef",
          ref: sectionsContainerRef,
          class: normalizeClass(["px-6 py-4 overflow-y-auto max-h-[450px] scroll-container", {
            "max-h-[450px]": isExpanded.value,
            "max-h-0": !isExpanded.value
          }]),
          style: {
            scrollbarWidth: "thin",
            scrollbarColor: "rgba(156, 163, 175, 0.5) transparent"
          }
        }, [
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(taskPanels.value, (panel2, index2) => {
            return openBlock(), createElementBlock("div", { key: index2 }, [
              createVNode(unref(script$N), {
                expanded: collapsedPanels.value[index2] || false,
                toggleable: "",
                class: "shadow-elevation-1 rounded-lg mt-2 dark-theme:bg-black dark-theme:border-black"
              }, {
                header: withCtx(() => [
                  createBaseVNode("div", _hoisted_1$1w, [
                    createBaseVNode("div", _hoisted_2$15, [
                      createBaseVNode("span", null, toDisplayString$1(panel2.taskName), 1),
                      createBaseVNode("span", _hoisted_3$L, toDisplayString$1(isInProgress(index2) ? _ctx.$t("g.inProgress") : _ctx.$t("g.completed") + " ✓"), 1)
                    ])
                  ])
                ]),
                toggleicon: withCtx(() => [
                  createVNode(unref(script$10), {
                    icon: collapsedPanels.value[index2] ? "pi pi-chevron-right" : "pi pi-chevron-down",
                    text: "",
                    class: "text-neutral-300",
                    onClick: /* @__PURE__ */ __name(($event) => togglePanel(index2), "onClick")
                  }, null, 8, ["icon", "onClick"])
                ]),
                default: withCtx(() => [
                  createBaseVNode("div", {
                    ref_for: true,
                    ref: index2 === taskPanels.value.length - 1 ? (el) => lastPanelRef.value = el : void 0,
                    class: normalizeClass(["overflow-y-auto h-64 rounded-lg bg-black", {
                      "h-64": index2 !== taskPanels.value.length - 1,
                      "flex-grow": index2 === taskPanels.value.length - 1
                    }]),
                    onScroll: handleScroll
                  }, [
                    createBaseVNode("div", _hoisted_4$x, [
                      (openBlock(true), createElementBlock(Fragment$1, null, renderList(panel2.logs, (log2, logIndex) => {
                        return openBlock(), createElementBlock("div", {
                          key: logIndex,
                          class: "text-neutral-400 dark-theme:text-muted"
                        }, [
                          createBaseVNode("pre", _hoisted_5$r, toDisplayString$1(log2), 1)
                        ]);
                      }), 128))
                    ])
                  ], 34)
                ]),
                _: 2
              }, 1032, ["expanded"])
            ]);
          }), 128))
        ], 2)
      ], 2);
    };
  }
});
var theme$o = /* @__PURE__ */ __name(function theme22(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-progressbar {\n    position: relative;\n    overflow: hidden;\n    height: ".concat(dt2("progressbar.height"), ";\n    background: ").concat(dt2("progressbar.background"), ";\n    border-radius: ").concat(dt2("progressbar.border.radius"), ";\n}\n\n.p-progressbar-value {\n    margin: 0;\n    background: ").concat(dt2("progressbar.value.background"), ";\n}\n\n.p-progressbar-label {\n    color: ").concat(dt2("progressbar.label.color"), ";\n    font-size: ").concat(dt2("progressbar.label.font.size"), ";\n    font-weight: ").concat(dt2("progressbar.label.font.weight"), ';\n}\n\n.p-progressbar-determinate .p-progressbar-value {\n    height: 100%;\n    width: 0%;\n    position: absolute;\n    display: none;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    overflow: hidden;\n    transition: width 1s ease-in-out;\n}\n\n.p-progressbar-determinate .p-progressbar-label {\n    display: inline-flex;\n}\n\n.p-progressbar-indeterminate .p-progressbar-value::before {\n    content: "";\n    position: absolute;\n    background: inherit;\n    inset-block-start: 0;\n    inset-inline-start: 0;\n    inset-block-end: 0;\n    will-change: inset-inline-start, inset-inline-end;\n    animation: p-progressbar-indeterminate-anim 2.1s cubic-bezier(0.65, 0.815, 0.735, 0.395) infinite;\n}\n\n.p-progressbar-indeterminate .p-progressbar-value::after {\n    content: "";\n    position: absolute;\n    background: inherit;\n    inset-block-start: 0;\n    inset-inline-start: 0;\n    inset-block-end: 0;\n    will-change: inset-inline-start, inset-inline-end;\n    animation: p-progressbar-indeterminate-anim-short 2.1s cubic-bezier(0.165, 0.84, 0.44, 1) infinite;\n    animation-delay: 1.15s;\n}\n\n@keyframes p-progressbar-indeterminate-anim {\n    0% {\n        inset-inline-start: -35%;\n        inset-inline-end: 100%;\n    }\n    60% {\n        inset-inline-start: 100%;\n        inset-inline-end: -90%;\n    }\n    100% {\n        inset-inline-start: 100%;\n        inset-inline-end: -90%;\n    }\n}\n@-webkit-keyframes p-progressbar-indeterminate-anim {\n    0% {\n        inset-inline-start: -35%;\n        inset-inline-end: 100%;\n    }\n    60% {\n        inset-inline-start: 100%;\n        inset-inline-end: -90%;\n    }\n    100% {\n        inset-inline-start: 100%;\n        inset-inline-end: -90%;\n    }\n}\n\n@keyframes p-progressbar-indeterminate-anim-short {\n    0% {\n        inset-inline-start: -200%;\n        inset-inline-end: 100%;\n    }\n    60% {\n        inset-inline-start: 107%;\n        inset-inline-end: -8%;\n    }\n    100% {\n        inset-inline-start: 107%;\n        inset-inline-end: -8%;\n    }\n}\n@-webkit-keyframes p-progressbar-indeterminate-anim-short {\n    0% {\n        inset-inline-start: -200%;\n        inset-inline-end: 100%;\n    }\n    60% {\n        inset-inline-start: 107%;\n        inset-inline-end: -8%;\n    }\n    100% {\n        inset-inline-start: 107%;\n        inset-inline-end: -8%;\n    }\n}\n');
}, "theme");
var classes$s = {
  root: /* @__PURE__ */ __name(function root13(_ref2) {
    var instance = _ref2.instance;
    return ["p-progressbar p-component", {
      "p-progressbar-determinate": instance.determinate,
      "p-progressbar-indeterminate": instance.indeterminate
    }];
  }, "root"),
  value: "p-progressbar-value",
  label: "p-progressbar-label"
};
var ProgressBarStyle = BaseStyle$1.extend({
  name: "progressbar",
  theme: theme$o,
  classes: classes$s
});
var script$1$s = {
  name: "BaseProgressBar",
  "extends": script$1b,
  props: {
    value: {
      type: Number,
      "default": null
    },
    mode: {
      type: String,
      "default": "determinate"
    },
    showValue: {
      type: Boolean,
      "default": true
    }
  },
  style: ProgressBarStyle,
  provide: /* @__PURE__ */ __name(function provide23() {
    return {
      $pcProgressBar: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$F = {
  name: "ProgressBar",
  "extends": script$1$s,
  inheritAttrs: false,
  computed: {
    progressStyle: /* @__PURE__ */ __name(function progressStyle() {
      return {
        width: this.value + "%",
        display: "flex"
      };
    }, "progressStyle"),
    indeterminate: /* @__PURE__ */ __name(function indeterminate2() {
      return this.mode === "indeterminate";
    }, "indeterminate"),
    determinate: /* @__PURE__ */ __name(function determinate() {
      return this.mode === "determinate";
    }, "determinate")
  }
};
var _hoisted_1$1v = ["aria-valuenow"];
function render$D(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    role: "progressbar",
    "class": _ctx.cx("root"),
    "aria-valuemin": "0",
    "aria-valuenow": _ctx.value,
    "aria-valuemax": "100"
  }, _ctx.ptmi("root")), [$options.determinate ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("value"),
    style: $options.progressStyle
  }, _ctx.ptm("value")), [_ctx.value != null && _ctx.value !== 0 && _ctx.showValue ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("label")
  }, _ctx.ptm("label")), [renderSlot(_ctx.$slots, "default", {}, function() {
    return [createTextVNode(toDisplayString$1(_ctx.value + "%"), 1)];
  })], 16)) : createCommentVNode("", true)], 16)) : $options.indeterminate ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": _ctx.cx("value")
  }, _ctx.ptm("value")), null, 16)) : createCommentVNode("", true)], 16, _hoisted_1$1v);
}
__name(render$D, "render$D");
script$F.render = render$D;
function useCivitaiModel(url) {
  const createModelVersionUrl = /* @__PURE__ */ __name((modelId) => `https://civitai.com/api/v1/model-versions/${modelId}`, "createModelVersionUrl");
  const extractModelIdFromUrl = /* @__PURE__ */ __name(() => {
    const urlObj = new URL(url);
    return urlObj.pathname.split("/").pop() || null;
  }, "extractModelIdFromUrl");
  const fetchModelData = /* @__PURE__ */ __name(async () => {
    const modelId = extractModelIdFromUrl();
    if (!modelId) return null;
    const apiUrl = createModelVersionUrl(modelId);
    const res = await fetch(apiUrl);
    return res.json();
  }, "fetchModelData");
  const findMatchingFileSize = /* @__PURE__ */ __name(() => {
    const matchingFile = modelData.value?.files?.find(
      (file) => file.downloadUrl && url.startsWith(file.downloadUrl)
    );
    return matchingFile?.sizeKB ? matchingFile.sizeKB << 10 : null;
  }, "findMatchingFileSize");
  const {
    state: modelData,
    isLoading,
    error: error2
  } = useAsyncState(fetchModelData, null, {
    immediate: true
  });
  const fileSize = computed(
    () => !isLoading.value ? findMatchingFileSize() : null
  );
  return {
    fileSize,
    isLoading,
    error: error2,
    modelData
  };
}
__name(useCivitaiModel, "useCivitaiModel");
function useDownload(url, fileName) {
  const fileSize = ref(null);
  const error2 = ref(null);
  const setFileSize = /* @__PURE__ */ __name((size) => {
    fileSize.value = size;
  }, "setFileSize");
  const fetchFileSize = /* @__PURE__ */ __name(async () => {
    try {
      const response = await fetch(url, { method: "HEAD" });
      if (!response.ok) throw new Error("Failed to fetch file size");
      const size = response.headers.get("content-length");
      if (size) {
        setFileSize(parseInt(size));
      } else {
        console.error('"content-length" header not found');
        return null;
      }
    } catch (e2) {
      console.error("Error fetching file size:", e2);
      error2.value = e2 instanceof Error ? e2 : new Error(String(e2));
      return null;
    }
  }, "fetchFileSize");
  const triggerBrowserDownload = /* @__PURE__ */ __name(() => {
    const link2 = document.createElement("a");
    if (url.includes("huggingface.co") && error2.value) {
      link2.href = downloadUrlToHfRepoUrl(url);
    } else {
      link2.href = url;
      link2.download = fileName || url.split("/").pop() || "download";
    }
    link2.target = "_blank";
    link2.rel = "noopener noreferrer";
    link2.click();
  }, "triggerBrowserDownload");
  onMounted(() => {
    if (isCivitaiModelUrl(url)) {
      const { fileSize: civitaiSize, error: civitaiErr } = useCivitaiModel(url);
      whenever(civitaiSize, setFileSize);
      whenever(civitaiErr, fetchFileSize, { once: true });
    } else {
      fetchFileSize();
    }
  });
  return {
    triggerBrowserDownload,
    fileSize
  };
}
__name(useDownload, "useDownload");
const IPC_CHANNELS = {
  LOADING_PROGRESS: "loading-progress",
  IS_PACKAGED: "is-packaged",
  RENDERER_READY: "renderer-ready",
  RESTART_APP: "restart-app",
  REINSTALL: "reinstall",
  QUIT: "quit",
  LOG_MESSAGE: "log-message",
  DOWNLOAD_PROGRESS: "download-progress",
  START_DOWNLOAD: "start-download",
  PAUSE_DOWNLOAD: "pause-download",
  RESUME_DOWNLOAD: "resume-download",
  CANCEL_DOWNLOAD: "cancel-download",
  DELETE_MODEL: "delete-model",
  GET_ALL_DOWNLOADS: "get-all-downloads",
  GET_ELECTRON_VERSION: "get-electron-version",
  GET_BASE_PATH: "get-base-path",
  SET_BASE_PATH: "set-base-path",
  GET_MODEL_CONFIG_PATH: "get-model-config-path",
  OPEN_PATH: "open-path",
  OPEN_LOGS_PATH: "open-logs-path",
  OPEN_DEV_TOOLS: "open-dev-tools",
  TERMINAL_WRITE: "execute-terminal-command",
  TERMINAL_RESIZE: "resize-terminal",
  TERMINAL_RESTORE: "restore-terminal",
  TERMINAL_ON_OUTPUT: "terminal-output",
  GET_SYSTEM_PATHS: "get-system-paths",
  VALIDATE_INSTALL_PATH: "validate-install-path",
  VALIDATE_COMFYUI_SOURCE: "validate-comfyui-source",
  SHOW_DIRECTORY_PICKER: "show-directory-picker",
  INSTALL_COMFYUI: "install-comfyui",
  CHANGE_THEME: "change-theme",
  SHOW_CONTEXT_MENU: "show-context-menu",
  RESTART_CORE: "restart-core",
  GET_GPU: "get-gpu",
  SET_WINDOW_STYLE: "set-window-style",
  GET_VALIDATION_STATE: "get-validation-state",
  VALIDATION_UPDATE: "validation-update",
  COMPLETE_VALIDATION: "complete-validation",
  CANCEL_VALIDATION: "cancel-validation",
  VALIDATE_INSTALLATION: "start-validation",
  UV_INSTALL_REQUIREMENTS: "uv-install-requirements",
  GET_WINDOW_STYLE: "get-window-style",
  TRACK_EVENT: "track-event",
  SET_METRICS_CONSENT: "set-metrics-consent",
  INCREMENT_USER_PROPERTY: "increment-user-property",
  UV_CLEAR_CACHE: "uv-clear-cache",
  UV_RESET_VENV: "uv-delete-venv",
  CAN_ACCESS_URL: "can-access-url",
  START_TROUBLESHOOTING: "start-troubleshooting",
  DISABLE_CUSTOM_NODES: "disable-custom-nodes"
};
var ProgressStatus = /* @__PURE__ */ ((ProgressStatus2) => {
  ProgressStatus2["INITIAL_STATE"] = "initial-state";
  ProgressStatus2["PYTHON_SETUP"] = "python-setup";
  ProgressStatus2["STARTING_SERVER"] = "starting-server";
  ProgressStatus2["READY"] = "ready";
  ProgressStatus2["ERROR"] = "error";
  return ProgressStatus2;
})(ProgressStatus || {});
const ELECTRON_BRIDGE_API = "electronAPI";
const SENTRY_URL_ENDPOINT = "https://942cadba58d247c9cab96f45221aa813@o4507954455314432.ingest.us.sentry.io/4508007940685824";
const MigrationItems = [
  {
    id: "user_files",
    label: "User Files",
    description: "Settings and user-created workflows"
  },
  {
    id: "models",
    label: "Models",
    description: "Reference model files from existing ComfyUI installations. (No copy)"
  },
  {
    id: "custom_nodes",
    label: "Custom Nodes",
    description: "Reinstall custom nodes from existing ComfyUI installations."
  }
];
const DEFAULT_SERVER_ARGS = {
  listen: "127.0.0.1",
  port: "8000"
};
var DownloadStatus = /* @__PURE__ */ ((DownloadStatus2) => {
  DownloadStatus2["PENDING"] = "pending";
  DownloadStatus2["IN_PROGRESS"] = "in_progress";
  DownloadStatus2["COMPLETED"] = "completed";
  DownloadStatus2["PAUSED"] = "paused";
  DownloadStatus2["ERROR"] = "error";
  DownloadStatus2["CANCELLED"] = "cancelled";
  return DownloadStatus2;
})(DownloadStatus || {});
var TorchMirrorUrl = /* @__PURE__ */ ((TorchMirrorUrl2) => {
  TorchMirrorUrl2["Default"] = "https://pypi.org/simple/";
  TorchMirrorUrl2["Cuda"] = "https://download.pytorch.org/whl/cu126";
  TorchMirrorUrl2["NightlyCpu"] = "https://download.pytorch.org/whl/nightly/cpu";
  return TorchMirrorUrl2;
})(TorchMirrorUrl || {});
const CUDA_TORCH_URL = "https://download.pytorch.org/whl/cu126";
const NIGHTLY_CPU_TORCH_URL = "https://download.pytorch.org/whl/nightly/cpu";
const DEFAULT_PYPI_INDEX_URL = "https://pypi.org/simple/";
var LogFile = /* @__PURE__ */ ((LogFile2) => {
  LogFile2["ComfyUI"] = "comfyui.log";
  LogFile2["Main"] = "main.log";
  return LogFile2;
})(LogFile || {});
const useElectronDownloadStore = /* @__PURE__ */ defineStore("downloads", () => {
  const downloads = ref([]);
  const { DownloadManager } = electronAPI();
  const findByUrl = /* @__PURE__ */ __name((url) => downloads.value.find((download2) => url === download2.url), "findByUrl");
  const initialize2 = /* @__PURE__ */ __name(async () => {
    if (isElectron()) {
      const allDownloads = await DownloadManager.getAllDownloads();
      for (const download2 of allDownloads) {
        downloads.value.push(download2);
      }
      DownloadManager.onDownloadProgress((data30) => {
        if (!findByUrl(data30.url)) {
          downloads.value.push(data30);
        }
        const download2 = findByUrl(data30.url);
        if (download2) {
          download2.progress = data30.progress;
          download2.status = data30.status;
          download2.filename = data30.filename;
          download2.savePath = data30.savePath;
        }
      });
    }
  }, "initialize");
  void initialize2();
  const start2 = /* @__PURE__ */ __name(({
    url,
    savePath,
    filename
  }) => DownloadManager.startDownload(url, savePath, filename), "start");
  const pause = /* @__PURE__ */ __name((url) => DownloadManager.pauseDownload(url), "pause");
  const resume = /* @__PURE__ */ __name((url) => DownloadManager.resumeDownload(url), "resume");
  const cancel = /* @__PURE__ */ __name((url) => DownloadManager.cancelDownload(url), "cancel");
  return {
    downloads,
    start: start2,
    pause,
    resume,
    cancel,
    findByUrl,
    initialize: initialize2,
    inProgressDownloads: computed(
      () => downloads.value.filter(
        ({ status }) => status !== DownloadStatus.COMPLETED
      )
    )
  };
});
const _hoisted_1$1u = { class: "flex flex-col" };
const _hoisted_2$14 = { class: "flex flex-row items-center gap-2" };
const _hoisted_3$K = {
  key: 0,
  class: "pi pi-check text-green-500"
};
const _hoisted_4$w = { class: "file-info" };
const _hoisted_5$q = { class: "file-details" };
const _hoisted_6$j = ["title"];
const _hoisted_7$9 = {
  key: 0,
  class: "file-error"
};
const _hoisted_8$6 = { class: "file-action" };
const _hoisted_9$4 = {
  key: 0,
  class: "flex flex-row items-center gap-2"
};
const _sfc_main$1w = /* @__PURE__ */ defineComponent({
  __name: "ElectronFileDownload",
  props: {
    url: {},
    hint: {},
    label: {},
    error: {}
  },
  setup(__props) {
    const props = __props;
    const { t: t2 } = useI18n();
    const label8 = computed(() => props.label || props.url.split("/").pop());
    const hint = computed(() => props.hint || props.url);
    const download2 = useDownload(props.url);
    const downloadProgress = ref(0);
    const status = ref(null);
    const fileSize = computed(
      () => download2.fileSize.value ? formatSize(download2.fileSize.value) : "?"
    );
    const electronDownloadStore = useElectronDownloadStore();
    const [savePath, filename] = props.label.split("/");
    electronDownloadStore.$subscribe((_2, { downloads }) => {
      const download22 = downloads.find((download3) => props.url === download3.url);
      if (download22) {
        downloadProgress.value = Number((download22.progress * 100).toFixed(1));
        status.value = download22.status;
      }
    });
    const triggerDownload = /* @__PURE__ */ __name(async () => {
      await electronDownloadStore.start({
        url: props.url,
        savePath: savePath.trim(),
        filename: filename.trim()
      });
    }, "triggerDownload");
    const triggerCancelDownload = /* @__PURE__ */ __name(() => electronDownloadStore.cancel(props.url), "triggerCancelDownload");
    const triggerPauseDownload = /* @__PURE__ */ __name(() => electronDownloadStore.pause(props.url), "triggerPauseDownload");
    const triggerResumeDownload = /* @__PURE__ */ __name(() => electronDownloadStore.resume(props.url), "triggerResumeDownload");
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock("div", _hoisted_1$1u, [
        createBaseVNode("div", _hoisted_2$14, [
          status.value === "completed" ? (openBlock(), createElementBlock("i", _hoisted_3$K)) : createCommentVNode("", true),
          createBaseVNode("div", _hoisted_4$w, [
            createBaseVNode("div", _hoisted_5$q, [
              createBaseVNode("span", {
                class: "file-type",
                title: hint.value
              }, toDisplayString$1(label8.value), 9, _hoisted_6$j)
            ]),
            props.error ? (openBlock(), createElementBlock("div", _hoisted_7$9, toDisplayString$1(props.error), 1)) : createCommentVNode("", true)
          ]),
          createBaseVNode("div", _hoisted_8$6, [
            status.value === null || status.value === "error" ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              class: "file-action-button",
              label: _ctx.$t("g.download") + " (" + fileSize.value + ")",
              size: "small",
              outlined: "",
              disabled: !!props.error,
              onClick: triggerDownload,
              icon: "pi pi-download"
            }, null, 8, ["label", "disabled"])) : createCommentVNode("", true)
          ])
        ]),
        status.value === "in_progress" || status.value === "paused" ? (openBlock(), createElementBlock("div", _hoisted_9$4, [
          createVNode(unref(script$F), {
            class: "flex-1",
            value: downloadProgress.value,
            "show-value": downloadProgress.value > 10
          }, null, 8, ["value", "show-value"]),
          status.value === "in_progress" ? withDirectives((openBlock(), createBlock(unref(script$10), {
            key: 0,
            class: "file-action-button",
            size: "small",
            outlined: "",
            disabled: !!props.error,
            onClick: triggerPauseDownload,
            icon: "pi pi-pause-circle"
          }, null, 8, ["disabled"])), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.pause"),
              void 0,
              { top: true }
            ]
          ]) : createCommentVNode("", true),
          status.value === "paused" ? withDirectives((openBlock(), createBlock(unref(script$10), {
            key: 1,
            class: "file-action-button",
            size: "small",
            outlined: "",
            disabled: !!props.error,
            onClick: triggerResumeDownload,
            icon: "pi pi-play-circle"
          }, null, 8, ["disabled"])), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.resume"),
              void 0,
              { top: true }
            ]
          ]) : createCommentVNode("", true),
          withDirectives(createVNode(unref(script$10), {
            class: "file-action-button",
            size: "small",
            outlined: "",
            disabled: !!props.error,
            onClick: triggerCancelDownload,
            icon: "pi pi-times-circle",
            severity: "danger"
          }, null, 8, ["disabled"]), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.cancel"),
              void 0,
              { top: true }
            ]
          ])
        ])) : createCommentVNode("", true)
      ]);
    };
  }
});
const _hoisted_1$1t = { class: "flex flex-row items-center gap-2" };
const _hoisted_2$13 = ["title"];
const _sfc_main$1v = /* @__PURE__ */ defineComponent({
  __name: "FileDownload",
  props: {
    url: {},
    hint: {},
    label: {},
    error: {}
  },
  setup(__props) {
    const props = __props;
    const label8 = computed(() => props.label || props.url.split("/").pop());
    const hint = computed(() => props.hint || props.url);
    const download2 = useDownload(props.url);
    const fileSize = computed(
      () => download2.fileSize.value ? formatSize(download2.fileSize.value) : "?"
    );
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1t, [
        createBaseVNode("div", null, [
          createBaseVNode("div", null, [
            createBaseVNode("span", { title: hint.value }, toDisplayString$1(label8.value), 9, _hoisted_2$13)
          ]),
          props.error ? (openBlock(), createBlock(unref(script$Z), {
            key: 0,
            severity: "error",
            icon: "pi pi-exclamation-triangle",
            size: "small",
            variant: "outlined",
            class: "h-min my-2 px-1 max-w-xs",
            title: props.error,
            pt: {
              text: { class: "overflow-hidden text-ellipsis" }
            }
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString$1(props.error), 1)
            ]),
            _: 1
          }, 8, ["title"])) : createCommentVNode("", true)
        ]),
        createBaseVNode("div", null, [
          createVNode(unref(script$10), {
            label: _ctx.$t("g.download") + " (" + fileSize.value + ")",
            size: "small",
            outlined: "",
            disabled: !!props.error,
            title: props.url,
            onClick: unref(download2).triggerBrowserDownload
          }, null, 8, ["label", "disabled", "title", "onClick"])
        ])
      ]);
    };
  }
});
function buildTree$1(items2, key) {
  const root34 = {
    key: "root",
    label: "root",
    children: []
  };
  const map3 = {
    root: root34
  };
  for (const item3 of items2) {
    const keys2 = key(item3);
    let parent = root34;
    for (let i2 = 0; i2 < keys2.length; i2++) {
      const k2 = keys2[i2];
      if (k2 === "" && i2 === keys2.length - 1) break;
      const id4 = parent.key + "/" + k2;
      if (!map3[id4]) {
        const node3 = {
          key: id4,
          label: k2,
          leaf: false,
          children: []
        };
        map3[id4] = node3;
        parent.children?.push(node3);
      }
      parent = map3[id4];
    }
    parent.leaf = keys2[keys2.length - 1] !== "";
    parent.data = item3;
  }
  return root34;
}
__name(buildTree$1, "buildTree$1");
function flattenTree(tree) {
  const result = [];
  const stack2 = [tree];
  while (stack2.length) {
    const node3 = stack2.pop();
    if (node3.leaf && node3.data) result.push(node3.data);
    stack2.push(...node3.children ?? []);
  }
  return result;
}
__name(flattenTree, "flattenTree");
function sortedTree(node3, {
  groupLeaf = false
} = {}) {
  const newNode = {
    ...node3
  };
  if (node3.children) {
    if (groupLeaf) {
      const folders = node3.children.filter((child) => !child.leaf);
      const files = node3.children.filter((child) => child.leaf);
      const sortedFolders = folders.sort(
        (a2, b2) => (a2.label ?? "").localeCompare(b2.label ?? "")
      );
      const sortedFiles = files.sort(
        (a2, b2) => (a2.label ?? "").localeCompare(b2.label ?? "")
      );
      newNode.children = [
        ...sortedFolders.map(
          (folder) => sortedTree(folder, { groupLeaf: true })
        ),
        ...sortedFiles
      ];
    } else {
      const sortedChildren = [...node3.children].sort(
        (a2, b2) => (a2.label ?? "").localeCompare(b2.label ?? "")
      );
      newNode.children = [
        ...sortedChildren.map(
          (child) => sortedTree(child, { groupLeaf: false })
        )
      ];
    }
  }
  return newNode;
}
__name(sortedTree, "sortedTree");
const findNodeByKey = /* @__PURE__ */ __name((root34, key) => {
  if (root34.key === key) {
    return root34;
  }
  if (!root34.children) {
    return null;
  }
  for (const child of root34.children) {
    const result = findNodeByKey(child, key);
    if (result) {
      return result;
    }
  }
  return null;
}, "findNodeByKey");
function cloneTree(node3) {
  const clone2 = { ...node3 };
  if (node3.children && node3.children.length > 0) {
    clone2.children = node3.children.map((child) => cloneTree(child));
  }
  return clone2;
}
__name(cloneTree, "cloneTree");
const combineTrees = /* @__PURE__ */ __name((root34, subtree) => {
  const newRoot = cloneTree(root34);
  const parentKey = subtree.key.slice(0, subtree.key.lastIndexOf("/"));
  const parent = findNodeByKey(newRoot, parentKey);
  if (parent) {
    parent.children ??= [];
    parent.children.push(cloneTree(subtree));
  }
  return newRoot;
}, "combineTrees");
const getSettingInfo = /* @__PURE__ */ __name((setting) => {
  const parts2 = setting.category || setting.id.split(".");
  return {
    category: parts2[0] ?? "Other",
    subCategory: parts2[1] ?? "Other"
  };
}, "getSettingInfo");
function tryMigrateDeprecatedValue(setting, value3) {
  return setting?.migrateDeprecatedValue?.(value3) ?? value3;
}
__name(tryMigrateDeprecatedValue, "tryMigrateDeprecatedValue");
function onChange(setting, newValue2, oldValue) {
  if (setting?.onChange) {
    setting.onChange(newValue2, oldValue);
  }
  app$2.ui.settings.dispatchChange(setting.id, newValue2, oldValue);
}
__name(onChange, "onChange");
const useSettingStore = /* @__PURE__ */ defineStore("setting", () => {
  const settingValues = ref({});
  const settingsById = ref({});
  const settingTree = computed(() => {
    const root34 = buildTree$1(
      Object.values(settingsById.value).filter(
        (setting) => setting.type !== "hidden"
      ),
      (setting) => setting.category || setting.id.split(".")
    );
    const floatingSettings = (root34.children ?? []).filter((node3) => node3.leaf);
    if (floatingSettings.length) {
      root34.children = (root34.children ?? []).filter((node3) => !node3.leaf);
      root34.children.push({
        key: "Other",
        label: "Other",
        leaf: false,
        children: floatingSettings
      });
    }
    return root34;
  });
  function exists(key) {
    return settingValues.value[key] !== void 0;
  }
  __name(exists, "exists");
  async function set3(key, value3) {
    const clonedValue = _.cloneDeep(value3);
    const newValue2 = tryMigrateDeprecatedValue(
      settingsById.value[key],
      clonedValue
    );
    const oldValue = get3(key);
    if (newValue2 === oldValue) return;
    onChange(settingsById.value[key], newValue2, oldValue);
    settingValues.value[key] = newValue2;
    await api.storeSetting(key, newValue2);
  }
  __name(set3, "set");
  function get3(key) {
    return _.cloneDeep(settingValues.value[key] ?? getDefaultValue2(key));
  }
  __name(get3, "get");
  function getDefaultValue2(key) {
    const param = settingsById.value[key];
    return typeof param?.defaultValue === "function" ? param.defaultValue() : param?.defaultValue;
  }
  __name(getDefaultValue2, "getDefaultValue");
  function addSetting(setting) {
    if (!setting.id) {
      throw new Error("Settings must have an ID");
    }
    if (setting.id in settingsById.value) {
      throw new Error(`Setting ${setting.id} must have a unique ID.`);
    }
    settingsById.value[setting.id] = setting;
    if (settingValues.value[setting.id] !== void 0) {
      settingValues.value[setting.id] = tryMigrateDeprecatedValue(
        setting,
        settingValues.value[setting.id]
      );
    }
    onChange(setting, get3(setting.id), void 0);
  }
  __name(addSetting, "addSetting");
  async function loadSettingValues() {
    if (Object.keys(settingsById.value).length) {
      throw new Error(
        "Setting values must be loaded before any setting is registered."
      );
    }
    settingValues.value = await api.getSettings();
  }
  __name(loadSettingValues, "loadSettingValues");
  return {
    settingValues,
    settingsById,
    settingTree,
    addSetting,
    loadSettingValues,
    set: set3,
    get: get3,
    exists,
    getDefaultValue: getDefaultValue2
  };
});
const _hoisted_1$1s = { class: "flex gap-1 mb-4" };
const _hoisted_2$12 = { for: "doNotAskAgain" };
const _sfc_main$1u = /* @__PURE__ */ defineComponent({
  __name: "MissingModelsWarning",
  props: {
    missingModels: {},
    paths: {}
  },
  setup(__props) {
    const allowedSources = [
      "https://civitai.com/",
      "https://huggingface.co/",
      "http://localhost:"
      // Included for testing usage only
    ];
    const allowedSuffixes = [".safetensors", ".sft"];
    const whiteListedUrls = /* @__PURE__ */ new Set([
      "https://huggingface.co/stabilityai/stable-zero123/resolve/main/stable_zero123.ckpt",
      "https://huggingface.co/TencentARC/T2I-Adapter/resolve/main/models/t2iadapter_depth_sd14v1.pth?download=true",
      "https://github.com/xinntao/Real-ESRGAN/releases/download/v0.1.0/RealESRGAN_x4plus.pth"
    ]);
    const props = __props;
    const { t: t2 } = useI18n();
    const doNotAskAgain = ref(false);
    const modelDownloads = ref({});
    const missingModels = computed(() => {
      return props.missingModels.map((model) => {
        const paths = props.paths[model.directory];
        if (model.directory_invalid || !paths) {
          return {
            label: `${model.directory} / ${model.name}`,
            url: model.url,
            error: "Invalid directory specified (does this require custom nodes?)"
          };
        }
        const downloadInfo = modelDownloads.value[model.name] ?? {
          downloading: false,
          completed: false,
          progress: 0,
          error: null,
          name: model.name,
          directory: model.directory,
          url: model.url,
          folder_path: paths[0]
        };
        modelDownloads.value[model.name] = downloadInfo;
        if (!whiteListedUrls.has(model.url)) {
          if (!allowedSources.some((source) => model.url.startsWith(source))) {
            return {
              label: `${model.directory} / ${model.name}`,
              url: model.url,
              error: `Download not allowed from source '${model.url}', only allowed from '${allowedSources.join("', '")}'`
            };
          }
          if (!allowedSuffixes.some((suffix2) => model.name.endsWith(suffix2))) {
            return {
              label: `${model.directory} / ${model.name}`,
              url: model.url,
              error: `Only allowed suffixes are: '${allowedSuffixes.join("', '")}'`
            };
          }
        }
        return {
          url: model.url,
          label: `${model.directory} / ${model.name}`,
          downloading: downloadInfo.downloading,
          completed: downloadInfo.completed,
          progress: downloadInfo.progress,
          error: downloadInfo.error,
          name: model.name,
          paths,
          folderPath: downloadInfo.folder_path
        };
      });
    });
    onBeforeUnmount(() => {
      if (doNotAskAgain.value) {
        useSettingStore().set("Comfy.Workflow.ShowMissingModelsWarning", false);
      }
    });
    return (_ctx, _cache) => {
      const _component_ElectronFileDownload = _sfc_main$1w;
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(NoResultsPlaceholder, {
          class: "pb-0",
          icon: "pi pi-exclamation-circle",
          title: unref(t2)("missingModelsDialog.missingModels"),
          message: unref(t2)("missingModelsDialog.missingModelsMessage")
        }, null, 8, ["title", "message"]),
        createBaseVNode("div", _hoisted_1$1s, [
          createVNode(unref(script$Q), {
            modelValue: doNotAskAgain.value,
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => doNotAskAgain.value = $event),
            binary: "",
            "input-id": "doNotAskAgain"
          }, null, 8, ["modelValue"]),
          createBaseVNode("label", _hoisted_2$12, toDisplayString$1(unref(t2)("missingModelsDialog.doNotAskAgain")), 1)
        ]),
        createVNode(unref(script$G), {
          options: missingModels.value,
          class: "comfy-missing-models"
        }, {
          option: withCtx(({ option: option5 }) => [
            unref(isElectron)() ? (openBlock(), createBlock(Suspense, { key: 0 }, {
              default: withCtx(() => [
                createVNode(_component_ElectronFileDownload, {
                  url: option5.url,
                  label: option5.label,
                  error: option5.error
                }, null, 8, ["url", "label", "error"])
              ]),
              _: 2
            }, 1024)) : (openBlock(), createBlock(_sfc_main$1v, {
              key: 1,
              url: option5.url,
              label: option5.label,
              error: option5.error
            }, null, 8, ["url", "label", "error"]))
          ]),
          _: 1
        }, 8, ["options"])
      ], 64);
    };
  }
});
const MissingModelsWarning = /* @__PURE__ */ _export_sfc(_sfc_main$1u, [["__scopeId", "data-v-96375185"]]);
var theme$n = /* @__PURE__ */ __name(function theme23(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-floatlabel {\n    display: block;\n    position: relative;\n}\n\n.p-floatlabel label {\n    position: absolute;\n    pointer-events: none;\n    top: 50%;\n    transform: translateY(-50%);\n    transition-property: all;\n    transition-timing-function: ease;\n    line-height: 1;\n    font-weight: ".concat(dt2("floatlabel.font.weight"), ";\n    inset-inline-start: ").concat(dt2("floatlabel.position.x"), ";\n    color: ").concat(dt2("floatlabel.color"), ";\n    transition-duration: ").concat(dt2("floatlabel.transition.duration"), ";\n}\n\n.p-floatlabel:has(.p-textarea) label {\n    top: ").concat(dt2("floatlabel.position.y"), ";\n    transform: translateY(0);\n}\n\n.p-floatlabel:has(.p-inputicon:first-child) label {\n    inset-inline-start: calc((").concat(dt2("form.field.padding.x"), " * 2) + ").concat(dt2("icon.size"), ");\n}\n\n.p-floatlabel:has(.p-invalid) label {\n    color: ").concat(dt2("floatlabel.invalid.color"), ";\n}\n\n.p-floatlabel:has(input:focus) label,\n.p-floatlabel:has(input.p-filled) label,\n.p-floatlabel:has(input:-webkit-autofill) label,\n.p-floatlabel:has(textarea:focus) label,\n.p-floatlabel:has(textarea.p-filled) label,\n.p-floatlabel:has(.p-inputwrapper-focus) label,\n.p-floatlabel:has(.p-inputwrapper-filled) label {\n    top: ").concat(dt2("floatlabel.over.active.top"), ";\n    transform: translateY(0);\n    font-size: ").concat(dt2("floatlabel.active.font.size"), ";\n    font-weight: ").concat(dt2("floatlabel.label.active.font.weight"), ";\n}\n\n.p-floatlabel:has(input.p-filled) label,\n.p-floatlabel:has(textarea.p-filled) label,\n.p-floatlabel:has(.p-inputwrapper-filled) label {\n    color: ").concat(dt2("floatlabel.active.color"), ";\n}\n\n.p-floatlabel:has(input:focus) label,\n.p-floatlabel:has(input:-webkit-autofill) label,\n.p-floatlabel:has(textarea:focus) label,\n.p-floatlabel:has(.p-inputwrapper-focus) label {\n    color: ").concat(dt2("floatlabel.focus.color"), ";\n}\n\n.p-floatlabel-in .p-inputtext,\n.p-floatlabel-in .p-textarea,\n.p-floatlabel-in .p-select-label,\n.p-floatlabel-in .p-multiselect-label,\n.p-floatlabel-in .p-autocomplete-input-multiple,\n.p-floatlabel-in .p-cascadeselect-label,\n.p-floatlabel-in .p-treeselect-label {\n    padding-block-start: ").concat(dt2("floatlabel.in.input.padding.top"), ";\n    padding-block-end: ").concat(dt2("floatlabel.in.input.padding.bottom"), ";\n}\n\n.p-floatlabel-in:has(input:focus) label,\n.p-floatlabel-in:has(input.p-filled) label,\n.p-floatlabel-in:has(input:-webkit-autofill) label,\n.p-floatlabel-in:has(textarea:focus) label,\n.p-floatlabel-in:has(textarea.p-filled) label,\n.p-floatlabel-in:has(.p-inputwrapper-focus) label,\n.p-floatlabel-in:has(.p-inputwrapper-filled) label {\n    top: ").concat(dt2("floatlabel.in.active.top"), ";\n}\n\n.p-floatlabel-on:has(input:focus) label,\n.p-floatlabel-on:has(input.p-filled) label,\n.p-floatlabel-on:has(input:-webkit-autofill) label,\n.p-floatlabel-on:has(textarea:focus) label,\n.p-floatlabel-on:has(textarea.p-filled) label,\n.p-floatlabel-on:has(.p-inputwrapper-focus) label,\n.p-floatlabel-on:has(.p-inputwrapper-filled) label {\n    top: 0;\n    transform: translateY(-50%);\n    border-radius: ").concat(dt2("floatlabel.on.border.radius"), ";\n    background: ").concat(dt2("floatlabel.on.active.background"), ";\n    padding: ").concat(dt2("floatlabel.on.active.padding"), ";\n}\n");
}, "theme");
var classes$r = {
  root: /* @__PURE__ */ __name(function root14(_ref2) {
    _ref2.instance;
    var props = _ref2.props;
    return ["p-floatlabel", {
      "p-floatlabel-over": props.variant === "over",
      "p-floatlabel-on": props.variant === "on",
      "p-floatlabel-in": props.variant === "in"
    }];
  }, "root")
};
var FloatLabelStyle = BaseStyle$1.extend({
  name: "floatlabel",
  theme: theme$n,
  classes: classes$r
});
var script$1$r = {
  name: "BaseFloatLabel",
  "extends": script$1b,
  props: {
    variant: {
      type: String,
      "default": "over"
    }
  },
  style: FloatLabelStyle,
  provide: /* @__PURE__ */ __name(function provide24() {
    return {
      $pcFloatLabel: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$E = {
  name: "FloatLabel",
  "extends": script$1$r,
  inheritAttrs: false
};
function render$C(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("span", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16);
}
__name(render$C, "render$C");
script$E.render = render$C;
const _hoisted_1$1r = { class: "prompt-dialog-content flex flex-col gap-2 pt-8" };
const _sfc_main$1t = /* @__PURE__ */ defineComponent({
  __name: "PromptDialogContent",
  props: {
    message: {},
    defaultValue: {},
    onConfirm: { type: Function }
  },
  setup(__props) {
    const props = __props;
    const inputValue2 = ref(props.defaultValue);
    const onConfirm = /* @__PURE__ */ __name(() => {
      props.onConfirm(inputValue2.value);
      useDialogStore().closeDialog();
    }, "onConfirm");
    const inputRef = ref();
    const selectAllText = /* @__PURE__ */ __name(() => {
      if (!inputRef.value) return;
      const inputElement = inputRef.value.$el;
      inputElement.setSelectionRange(0, inputElement.value.length);
    }, "selectAllText");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1r, [
        createVNode(unref(script$E), null, {
          default: withCtx(() => [
            createVNode(unref(script$P), {
              ref_key: "inputRef",
              ref: inputRef,
              modelValue: inputValue2.value,
              "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => inputValue2.value = $event),
              onKeyup: withKeys(onConfirm, ["enter"]),
              onFocus: selectAllText,
              autofocus: ""
            }, null, 8, ["modelValue"]),
            createBaseVNode("label", null, toDisplayString$1(_ctx.message), 1)
          ]),
          _: 1
        }),
        createVNode(unref(script$10), { onClick: onConfirm }, {
          default: withCtx(() => [
            createTextVNode(toDisplayString$1(_ctx.$t("g.confirm")), 1)
          ]),
          _: 1
        })
      ]);
    };
  }
});
var classes$q = {
  root: "p-tabpanels"
};
var TabPanelsStyle = BaseStyle$1.extend({
  name: "tabpanels",
  classes: classes$q
});
var script$1$q = {
  name: "BaseTabPanels",
  "extends": script$1b,
  props: {},
  style: TabPanelsStyle,
  provide: /* @__PURE__ */ __name(function provide25() {
    return {
      $pcTabPanels: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$D = {
  name: "TabPanels",
  "extends": script$1$q,
  inheritAttrs: false
};
function render$B(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    role: "presentation"
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16);
}
__name(render$B, "render$B");
script$D.render = render$B;
var theme$m = /* @__PURE__ */ __name(function theme24(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tabs {\n    display: flex;\n    flex-direction: column;\n}\n\n.p-tablist {\n    display: flex;\n    position: relative;\n}\n\n.p-tabs-scrollable > .p-tablist {\n    overflow: hidden;\n}\n\n.p-tablist-viewport {\n    overflow-x: auto;\n    overflow-y: hidden;\n    scroll-behavior: smooth;\n    scrollbar-width: none;\n    overscroll-behavior: contain auto;\n}\n\n.p-tablist-viewport::-webkit-scrollbar {\n    display: none;\n}\n\n.p-tablist-tab-list {\n    position: relative;\n    display: flex;\n    background: ".concat(dt2("tabs.tablist.background"), ";\n    border-style: solid;\n    border-color: ").concat(dt2("tabs.tablist.border.color"), ";\n    border-width: ").concat(dt2("tabs.tablist.border.width"), ";\n}\n\n.p-tablist-content {\n    flex-grow: 1;\n}\n\n.p-tablist-nav-button {\n    all: unset;\n    position: absolute !important;\n    flex-shrink: 0;\n    inset-block-start: 0;\n    z-index: 2;\n    height: 100%;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background: ").concat(dt2("tabs.nav.button.background"), ";\n    color: ").concat(dt2("tabs.nav.button.color"), ";\n    width: ").concat(dt2("tabs.nav.button.width"), ";\n    transition: color ").concat(dt2("tabs.transition.duration"), ", outline-color ").concat(dt2("tabs.transition.duration"), ", box-shadow ").concat(dt2("tabs.transition.duration"), ";\n    box-shadow: ").concat(dt2("tabs.nav.button.shadow"), ";\n    outline-color: transparent;\n    cursor: pointer;\n}\n\n.p-tablist-nav-button:focus-visible {\n    z-index: 1;\n    box-shadow: ").concat(dt2("tabs.nav.button.focus.ring.shadow"), ";\n    outline: ").concat(dt2("tabs.nav.button.focus.ring.width"), " ").concat(dt2("tabs.nav.button.focus.ring.style"), " ").concat(dt2("tabs.nav.button.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("tabs.nav.button.focus.ring.offset"), ";\n}\n\n.p-tablist-nav-button:hover {\n    color: ").concat(dt2("tabs.nav.button.hover.color"), ";\n}\n\n.p-tablist-prev-button {\n    inset-inline-start: 0;\n}\n\n.p-tablist-next-button {\n    inset-inline-end: 0;\n}\n\n.p-tablist-prev-button:dir(rtl),\n.p-tablist-next-button:dir(rtl) {\n    transform: rotate(180deg);\n}\n\n\n.p-tab {\n    flex-shrink: 0;\n    cursor: pointer;\n    user-select: none;\n    position: relative;\n    border-style: solid;\n    white-space: nowrap;\n    background: ").concat(dt2("tabs.tab.background"), ";\n    border-width: ").concat(dt2("tabs.tab.border.width"), ";\n    border-color: ").concat(dt2("tabs.tab.border.color"), ";\n    color: ").concat(dt2("tabs.tab.color"), ";\n    padding: ").concat(dt2("tabs.tab.padding"), ";\n    font-weight: ").concat(dt2("tabs.tab.font.weight"), ";\n    transition: background ").concat(dt2("tabs.transition.duration"), ", border-color ").concat(dt2("tabs.transition.duration"), ", color ").concat(dt2("tabs.transition.duration"), ", outline-color ").concat(dt2("tabs.transition.duration"), ", box-shadow ").concat(dt2("tabs.transition.duration"), ";\n    margin: ").concat(dt2("tabs.tab.margin"), ";\n    outline-color: transparent;\n}\n\n.p-tab:not(.p-disabled):focus-visible {\n    z-index: 1;\n    box-shadow: ").concat(dt2("tabs.tab.focus.ring.shadow"), ";\n    outline: ").concat(dt2("tabs.tab.focus.ring.width"), " ").concat(dt2("tabs.tab.focus.ring.style"), " ").concat(dt2("tabs.tab.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("tabs.tab.focus.ring.offset"), ";\n}\n\n.p-tab:not(.p-tab-active):not(.p-disabled):hover {\n    background: ").concat(dt2("tabs.tab.hover.background"), ";\n    border-color: ").concat(dt2("tabs.tab.hover.border.color"), ";\n    color: ").concat(dt2("tabs.tab.hover.color"), ";\n}\n\n.p-tab-active {\n    background: ").concat(dt2("tabs.tab.active.background"), ";\n    border-color: ").concat(dt2("tabs.tab.active.border.color"), ";\n    color: ").concat(dt2("tabs.tab.active.color"), ";\n}\n\n.p-tabpanels {\n    background: ").concat(dt2("tabs.tabpanel.background"), ";\n    color: ").concat(dt2("tabs.tabpanel.color"), ";\n    padding: ").concat(dt2("tabs.tabpanel.padding"), ";\n    outline: 0 none;\n}\n\n.p-tabpanel:focus-visible {\n    box-shadow: ").concat(dt2("tabs.tabpanel.focus.ring.shadow"), ";\n    outline: ").concat(dt2("tabs.tabpanel.focus.ring.width"), " ").concat(dt2("tabs.tabpanel.focus.ring.style"), " ").concat(dt2("tabs.tabpanel.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("tabs.tabpanel.focus.ring.offset"), ";\n}\n\n.p-tablist-active-bar {\n    z-index: 1;\n    display: block;\n    position: absolute;\n    inset-block-end: ").concat(dt2("tabs.active.bar.bottom"), ";\n    height: ").concat(dt2("tabs.active.bar.height"), ";\n    background: ").concat(dt2("tabs.active.bar.background"), ";\n    transition: 250ms cubic-bezier(0.35, 0, 0.25, 1);\n}\n");
}, "theme");
var classes$p = {
  root: /* @__PURE__ */ __name(function root15(_ref2) {
    var props = _ref2.props;
    return ["p-tabs p-component", {
      "p-tabs-scrollable": props.scrollable
    }];
  }, "root")
};
var TabsStyle = BaseStyle$1.extend({
  name: "tabs",
  theme: theme$m,
  classes: classes$p
});
var script$1$p = {
  name: "BaseTabs",
  "extends": script$1b,
  props: {
    value: {
      type: [String, Number],
      "default": void 0
    },
    lazy: {
      type: Boolean,
      "default": false
    },
    scrollable: {
      type: Boolean,
      "default": false
    },
    showNavigators: {
      type: Boolean,
      "default": true
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    selectOnFocus: {
      type: Boolean,
      "default": false
    }
  },
  style: TabsStyle,
  provide: /* @__PURE__ */ __name(function provide26() {
    return {
      $pcTabs: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$C = {
  name: "Tabs",
  "extends": script$1$p,
  inheritAttrs: false,
  emits: ["update:value"],
  data: /* @__PURE__ */ __name(function data11() {
    return {
      id: this.$attrs.id,
      d_value: this.value
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId5(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    value: /* @__PURE__ */ __name(function value(newValue2) {
      this.d_value = newValue2;
    }, "value")
  },
  mounted: /* @__PURE__ */ __name(function mounted13() {
    this.id = this.id || UniqueComponentId();
  }, "mounted"),
  methods: {
    updateValue: /* @__PURE__ */ __name(function updateValue(newValue2) {
      if (this.d_value !== newValue2) {
        this.d_value = newValue2;
        this.$emit("update:value", newValue2);
      }
    }, "updateValue"),
    isVertical: /* @__PURE__ */ __name(function isVertical2() {
      return this.orientation === "vertical";
    }, "isVertical")
  }
};
function render$A(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default")], 16);
}
__name(render$A, "render$A");
script$C.render = render$A;
var script$B = {
  name: "TimesCircleIcon",
  "extends": script$16
};
function render$z(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    "fill-rule": "evenodd",
    "clip-rule": "evenodd",
    d: "M7 14C5.61553 14 4.26215 13.5895 3.11101 12.8203C1.95987 12.0511 1.06266 10.9579 0.532846 9.67879C0.00303296 8.3997 -0.13559 6.99224 0.134506 5.63437C0.404603 4.2765 1.07129 3.02922 2.05026 2.05026C3.02922 1.07129 4.2765 0.404603 5.63437 0.134506C6.99224 -0.13559 8.3997 0.00303296 9.67879 0.532846C10.9579 1.06266 12.0511 1.95987 12.8203 3.11101C13.5895 4.26215 14 5.61553 14 7C14 8.85652 13.2625 10.637 11.9497 11.9497C10.637 13.2625 8.85652 14 7 14ZM7 1.16667C5.84628 1.16667 4.71846 1.50879 3.75918 2.14976C2.79989 2.79074 2.05222 3.70178 1.61071 4.76768C1.16919 5.83358 1.05367 7.00647 1.27876 8.13803C1.50384 9.26958 2.05941 10.309 2.87521 11.1248C3.69102 11.9406 4.73042 12.4962 5.86198 12.7212C6.99353 12.9463 8.16642 12.8308 9.23232 12.3893C10.2982 11.9478 11.2093 11.2001 11.8502 10.2408C12.4912 9.28154 12.8333 8.15373 12.8333 7C12.8333 5.45291 12.2188 3.96918 11.1248 2.87521C10.0308 1.78125 8.5471 1.16667 7 1.16667ZM4.66662 9.91668C4.58998 9.91704 4.51404 9.90209 4.44325 9.87271C4.37246 9.84333 4.30826 9.8001 4.2544 9.74557C4.14516 9.6362 4.0838 9.48793 4.0838 9.33335C4.0838 9.17876 4.14516 9.0305 4.2544 8.92113L6.17553 7L4.25443 5.07891C4.15139 4.96832 4.09529 4.82207 4.09796 4.67094C4.10063 4.51982 4.16185 4.37563 4.26872 4.26876C4.3756 4.16188 4.51979 4.10066 4.67091 4.09799C4.82204 4.09532 4.96829 4.15142 5.07887 4.25446L6.99997 6.17556L8.92106 4.25446C9.03164 4.15142 9.1779 4.09532 9.32903 4.09799C9.48015 4.10066 9.62434 4.16188 9.73121 4.26876C9.83809 4.37563 9.89931 4.51982 9.90198 4.67094C9.90464 4.82207 9.84855 4.96832 9.74551 5.07891L7.82441 7L9.74554 8.92113C9.85478 9.0305 9.91614 9.17876 9.91614 9.33335C9.91614 9.48793 9.85478 9.6362 9.74554 9.74557C9.69168 9.8001 9.62748 9.84333 9.55669 9.87271C9.4859 9.90209 9.40996 9.91704 9.33332 9.91668C9.25668 9.91704 9.18073 9.90209 9.10995 9.87271C9.03916 9.84333 8.97495 9.8001 8.9211 9.74557L6.99997 7.82444L5.07884 9.74557C5.02499 9.8001 4.96078 9.84333 4.88999 9.87271C4.81921 9.90209 4.74326 9.91704 4.66662 9.91668Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$z, "render$z");
script$B.render = render$z;
var theme$l = /* @__PURE__ */ __name(function theme25(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-chip {\n    display: inline-flex;\n    align-items: center;\n    background: ".concat(dt2("chip.background"), ";\n    color: ").concat(dt2("chip.color"), ";\n    border-radius: ").concat(dt2("chip.border.radius"), ";\n    padding-block: ").concat(dt2("chip.padding.y"), ";\n    padding-inline: ").concat(dt2("chip.padding.x"), ";\n    gap: ").concat(dt2("chip.gap"), ";\n}\n\n.p-chip-icon {\n    color: ").concat(dt2("chip.icon.color"), ";\n    font-size: ").concat(dt2("chip.icon.font.size"), ";\n    width: ").concat(dt2("chip.icon.size"), ";\n    height: ").concat(dt2("chip.icon.size"), ";\n}\n\n.p-chip-image {\n    border-radius: 50%;\n    width: ").concat(dt2("chip.image.width"), ";\n    height: ").concat(dt2("chip.image.height"), ";\n    margin-inline-start: calc(-1 * ").concat(dt2("chip.padding.y"), ");\n}\n\n.p-chip:has(.p-chip-remove-icon) {\n    padding-inline-end: ").concat(dt2("chip.padding.y"), ";\n}\n\n.p-chip:has(.p-chip-image) {\n    padding-block-start: calc(").concat(dt2("chip.padding.y"), " / 2);\n    padding-block-end: calc(").concat(dt2("chip.padding.y"), " / 2);\n}\n\n.p-chip-remove-icon {\n    cursor: pointer;\n    font-size: ").concat(dt2("chip.remove.icon.size"), ";\n    width: ").concat(dt2("chip.remove.icon.size"), ";\n    height: ").concat(dt2("chip.remove.icon.size"), ";\n    color: ").concat(dt2("chip.remove.icon.color"), ";\n    border-radius: 50%;\n    transition: outline-color ").concat(dt2("chip.transition.duration"), ", box-shadow ").concat(dt2("chip.transition.duration"), ";\n    outline-color: transparent;\n}\n\n.p-chip-remove-icon:focus-visible {\n    box-shadow: ").concat(dt2("chip.remove.icon.focus.ring.shadow"), ";\n    outline: ").concat(dt2("chip.remove.icon.focus.ring.width"), " ").concat(dt2("chip.remove.icon.focus.ring.style"), " ").concat(dt2("chip.remove.icon.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("chip.remove.icon.focus.ring.offset"), ";\n}\n");
}, "theme");
var classes$o = {
  root: "p-chip p-component",
  image: "p-chip-image",
  icon: "p-chip-icon",
  label: "p-chip-label",
  removeIcon: "p-chip-remove-icon"
};
var ChipStyle = BaseStyle$1.extend({
  name: "chip",
  theme: theme$l,
  classes: classes$o
});
var script$1$o = {
  name: "BaseChip",
  "extends": script$1b,
  props: {
    label: {
      type: String,
      "default": null
    },
    icon: {
      type: String,
      "default": null
    },
    image: {
      type: String,
      "default": null
    },
    removable: {
      type: Boolean,
      "default": false
    },
    removeIcon: {
      type: String,
      "default": void 0
    }
  },
  style: ChipStyle,
  provide: /* @__PURE__ */ __name(function provide27() {
    return {
      $pcChip: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$A = {
  name: "Chip",
  "extends": script$1$o,
  inheritAttrs: false,
  emits: ["remove"],
  data: /* @__PURE__ */ __name(function data12() {
    return {
      visible: true
    };
  }, "data"),
  methods: {
    onKeydown: /* @__PURE__ */ __name(function onKeydown2(event) {
      if (event.key === "Enter" || event.key === "Backspace") {
        this.close(event);
      }
    }, "onKeydown"),
    close: /* @__PURE__ */ __name(function close4(event) {
      this.visible = false;
      this.$emit("remove", event);
    }, "close")
  },
  components: {
    TimesCircleIcon: script$B
  }
};
var _hoisted_1$1q = ["aria-label"];
var _hoisted_2$11 = ["src"];
function render$y(_ctx, _cache, $props, $setup, $data, $options) {
  return $data.visible ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("root"),
    "aria-label": _ctx.label
  }, _ctx.ptmi("root")), [renderSlot(_ctx.$slots, "default", {}, function() {
    return [_ctx.image ? (openBlock(), createElementBlock("img", mergeProps$2({
      key: 0,
      src: _ctx.image
    }, _ctx.ptm("image"), {
      "class": _ctx.cx("image")
    }), null, 16, _hoisted_2$11)) : _ctx.$slots.icon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.icon), mergeProps$2({
      key: 1,
      "class": _ctx.cx("icon")
    }, _ctx.ptm("icon")), null, 16, ["class"])) : _ctx.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 2,
      "class": [_ctx.cx("icon"), _ctx.icon]
    }, _ctx.ptm("icon")), null, 16)) : createCommentVNode("", true), _ctx.label ? (openBlock(), createElementBlock("div", mergeProps$2({
      key: 3,
      "class": _ctx.cx("label")
    }, _ctx.ptm("label")), toDisplayString$1(_ctx.label), 17)) : createCommentVNode("", true)];
  }), _ctx.removable ? renderSlot(_ctx.$slots, "removeicon", {
    key: 0,
    removeCallback: $options.close,
    keydownCallback: $options.onKeydown
  }, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.removeIcon ? "span" : "TimesCircleIcon"), mergeProps$2({
      "class": [_ctx.cx("removeIcon"), _ctx.removeIcon],
      onClick: $options.close,
      onKeydown: $options.onKeydown
    }, _ctx.ptm("removeIcon")), null, 16, ["class", "onClick", "onKeydown"]))];
  }) : createCommentVNode("", true)], 16, _hoisted_1$1q)) : createCommentVNode("", true);
}
__name(render$y, "render$y");
script$A.render = render$y;
const _sfc_main$1s = /* @__PURE__ */ defineComponent({
  __name: "SearchFilterChip",
  props: {
    text: {},
    badge: {},
    badgeClass: {}
  },
  emits: ["remove"],
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$A), {
        removable: "",
        onRemove: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("remove", $event))
      }, {
        default: withCtx(() => [
          createVNode(unref(script$11), {
            size: "small",
            class: normalizeClass(_ctx.badgeClass)
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString$1(_ctx.badge), 1)
            ]),
            _: 1
          }, 8, ["class"]),
          createTextVNode(" " + toDisplayString$1(_ctx.text), 1)
        ]),
        _: 1
      });
    };
  }
});
const SearchFilterChip = /* @__PURE__ */ _export_sfc(_sfc_main$1s, [["__scopeId", "data-v-53692f7e"]]);
const _hoisted_1$1p = {
  key: 0,
  class: "search-filters pt-2 flex flex-wrap gap-2"
};
const _sfc_main$1r = /* @__PURE__ */ defineComponent({
  __name: "SearchBox",
  props: {
    modelValue: {},
    placeholder: { default: "Search..." },
    icon: { default: "pi pi-search" },
    debounceTime: { default: 300 },
    filterIcon: {},
    filters: { default: /* @__PURE__ */ __name(() => [], "default") }
  },
  emits: ["update:modelValue", "search", "showFilter", "removeFilter"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const emitSearch = lodashExports.debounce((value3) => {
      emit2("search", value3, __props.filters);
    }, __props.debounceTime);
    const handleInput = /* @__PURE__ */ __name((event) => {
      const target2 = event.target;
      emit2("update:modelValue", target2.value);
      emitSearch(target2.value);
    }, "handleInput");
    const clearSearch = /* @__PURE__ */ __name(() => {
      emit2("update:modelValue", "");
      emitSearch("");
    }, "clearSearch");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", null, [
        createVNode(unref(script$J), null, {
          default: withCtx(() => [
            _ctx.filterIcon ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              class: "p-inputicon filter-button",
              icon: _ctx.filterIcon,
              text: "",
              severity: "contrast",
              onClick: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("showFilter", $event))
            }, null, 8, ["icon"])) : createCommentVNode("", true),
            createVNode(unref(script$P), {
              class: "search-box-input w-full",
              onInput: handleInput,
              modelValue: _ctx.modelValue,
              placeholder: _ctx.placeholder
            }, null, 8, ["modelValue", "placeholder"]),
            !_ctx.modelValue ? (openBlock(), createBlock(unref(script$I), {
              key: 1,
              class: normalizeClass(_ctx.icon)
            }, null, 8, ["class"])) : createCommentVNode("", true),
            _ctx.modelValue ? (openBlock(), createBlock(unref(script$10), {
              key: 2,
              class: "p-inputicon clear-button",
              icon: "pi pi-times",
              text: "",
              severity: "contrast",
              onClick: clearSearch
            })) : createCommentVNode("", true)
          ]),
          _: 1
        }),
        _ctx.filters?.length ? (openBlock(), createElementBlock("div", _hoisted_1$1p, [
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.filters, (filter4) => {
            return openBlock(), createBlock(SearchFilterChip, {
              key: filter4.id,
              text: filter4.text,
              badge: filter4.badge,
              "badge-class": filter4.badgeClass,
              onRemove: /* @__PURE__ */ __name(($event) => _ctx.$emit("removeFilter", filter4), "onRemove")
            }, null, 8, ["text", "badge", "badge-class", "onRemove"]);
          }), 128))
        ])) : createCommentVNode("", true)
      ]);
    };
  }
});
const SearchBox = /* @__PURE__ */ _export_sfc(_sfc_main$1r, [["__scopeId", "data-v-b3ab067d"]]);
var theme$k = /* @__PURE__ */ __name(function theme26(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tag {\n    display: inline-flex;\n    align-items: center;\n    justify-content: center;\n    background: ".concat(dt2("tag.primary.background"), ";\n    color: ").concat(dt2("tag.primary.color"), ";\n    font-size: ").concat(dt2("tag.font.size"), ";\n    font-weight: ").concat(dt2("tag.font.weight"), ";\n    padding: ").concat(dt2("tag.padding"), ";\n    border-radius: ").concat(dt2("tag.border.radius"), ";\n    gap: ").concat(dt2("tag.gap"), ";\n}\n\n.p-tag-icon {\n    font-size: ").concat(dt2("tag.icon.size"), ";\n    width: ").concat(dt2("tag.icon.size"), ";\n    height:").concat(dt2("tag.icon.size"), ";\n}\n\n.p-tag-rounded {\n    border-radius: ").concat(dt2("tag.rounded.border.radius"), ";\n}\n\n.p-tag-success {\n    background: ").concat(dt2("tag.success.background"), ";\n    color: ").concat(dt2("tag.success.color"), ";\n}\n\n.p-tag-info {\n    background: ").concat(dt2("tag.info.background"), ";\n    color: ").concat(dt2("tag.info.color"), ";\n}\n\n.p-tag-warn {\n    background: ").concat(dt2("tag.warn.background"), ";\n    color: ").concat(dt2("tag.warn.color"), ";\n}\n\n.p-tag-danger {\n    background: ").concat(dt2("tag.danger.background"), ";\n    color: ").concat(dt2("tag.danger.color"), ";\n}\n\n.p-tag-secondary {\n    background: ").concat(dt2("tag.secondary.background"), ";\n    color: ").concat(dt2("tag.secondary.color"), ";\n}\n\n.p-tag-contrast {\n    background: ").concat(dt2("tag.contrast.background"), ";\n    color: ").concat(dt2("tag.contrast.color"), ";\n}\n");
}, "theme");
var classes$n = {
  root: /* @__PURE__ */ __name(function root16(_ref2) {
    var props = _ref2.props;
    return ["p-tag p-component", {
      "p-tag-info": props.severity === "info",
      "p-tag-success": props.severity === "success",
      "p-tag-warn": props.severity === "warn",
      "p-tag-danger": props.severity === "danger",
      "p-tag-secondary": props.severity === "secondary",
      "p-tag-contrast": props.severity === "contrast",
      "p-tag-rounded": props.rounded
    }];
  }, "root"),
  icon: "p-tag-icon",
  label: "p-tag-label"
};
var TagStyle = BaseStyle$1.extend({
  name: "tag",
  theme: theme$k,
  classes: classes$n
});
var script$1$n = {
  name: "BaseTag",
  "extends": script$1b,
  props: {
    value: null,
    severity: null,
    rounded: Boolean,
    icon: String
  },
  style: TagStyle,
  provide: /* @__PURE__ */ __name(function provide28() {
    return {
      $pcTag: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$z = {
  name: "Tag",
  "extends": script$1$n,
  inheritAttrs: false
};
function render$x(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("span", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [_ctx.$slots.icon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.icon), mergeProps$2({
    key: 0,
    "class": _ctx.cx("icon")
  }, _ctx.ptm("icon")), null, 16, ["class"])) : _ctx.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 1,
    "class": [_ctx.cx("icon"), _ctx.icon]
  }, _ctx.ptm("icon")), null, 16)) : createCommentVNode("", true), _ctx.value != null || _ctx.$slots["default"] ? renderSlot(_ctx.$slots, "default", {
    key: 2
  }, function() {
    return [createBaseVNode("span", mergeProps$2({
      "class": _ctx.cx("label")
    }, _ctx.ptm("label")), toDisplayString$1(_ctx.value), 17)];
  }) : createCommentVNode("", true)], 16);
}
__name(render$x, "render$x");
script$z.render = render$x;
var classes$m = {
  root: /* @__PURE__ */ __name(function root17(_ref) {
    var instance = _ref.instance;
    return ["p-tabpanel", {
      "p-tabpanel-active": instance.active
    }];
  }, "root")
};
var TabPanelStyle = BaseStyle$1.extend({
  name: "tabpanel",
  classes: classes$m
});
var script$1$m = {
  name: "BaseTabPanel",
  "extends": script$1b,
  props: {
    // in Tabs
    value: {
      type: [String, Number],
      "default": void 0
    },
    as: {
      type: [String, Object],
      "default": "DIV"
    },
    asChild: {
      type: Boolean,
      "default": false
    },
    // in TabView
    header: null,
    headerStyle: null,
    headerClass: null,
    headerProps: null,
    headerActionProps: null,
    contentStyle: null,
    contentClass: null,
    contentProps: null,
    disabled: Boolean
  },
  style: TabPanelStyle,
  provide: /* @__PURE__ */ __name(function provide29() {
    return {
      $pcTabPanel: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$y = {
  name: "TabPanel",
  "extends": script$1$m,
  inheritAttrs: false,
  inject: ["$pcTabs"],
  computed: {
    active: /* @__PURE__ */ __name(function active() {
      var _this$$pcTabs;
      return equals$2((_this$$pcTabs = this.$pcTabs) === null || _this$$pcTabs === void 0 ? void 0 : _this$$pcTabs.d_value, this.value);
    }, "active"),
    id: /* @__PURE__ */ __name(function id2() {
      var _this$$pcTabs2;
      return "".concat((_this$$pcTabs2 = this.$pcTabs) === null || _this$$pcTabs2 === void 0 ? void 0 : _this$$pcTabs2.id, "_tabpanel_").concat(this.value);
    }, "id"),
    ariaLabelledby: /* @__PURE__ */ __name(function ariaLabelledby() {
      var _this$$pcTabs3;
      return "".concat((_this$$pcTabs3 = this.$pcTabs) === null || _this$$pcTabs3 === void 0 ? void 0 : _this$$pcTabs3.id, "_tab_").concat(this.value);
    }, "ariaLabelledby"),
    attrs: /* @__PURE__ */ __name(function attrs5() {
      return mergeProps$2(this.a11yAttrs, this.ptmi("root", this.ptParams));
    }, "attrs"),
    a11yAttrs: /* @__PURE__ */ __name(function a11yAttrs2() {
      var _this$$pcTabs4;
      return {
        id: this.id,
        tabindex: (_this$$pcTabs4 = this.$pcTabs) === null || _this$$pcTabs4 === void 0 ? void 0 : _this$$pcTabs4.tabindex,
        role: "tabpanel",
        "aria-labelledby": this.ariaLabelledby,
        "data-pc-name": "tabpanel",
        "data-p-active": this.active
      };
    }, "a11yAttrs"),
    ptParams: /* @__PURE__ */ __name(function ptParams() {
      return {
        context: {
          active: this.active
        }
      };
    }, "ptParams")
  }
};
function render$w(_ctx, _cache, $props, $setup, $data, $options) {
  var _$options$$pcTabs, _$options$$pcTabs2;
  return !$options.$pcTabs ? renderSlot(_ctx.$slots, "default", {
    key: 0
  }) : (openBlock(), createElementBlock(Fragment$1, {
    key: 1
  }, [!_ctx.asChild ? (openBlock(), createElementBlock(Fragment$1, {
    key: 0
  }, [((_$options$$pcTabs = $options.$pcTabs) !== null && _$options$$pcTabs !== void 0 && _$options$$pcTabs.lazy ? $options.active : true) ? withDirectives((openBlock(), createBlock(resolveDynamicComponent(_ctx.as), mergeProps$2({
    key: 0,
    "class": _ctx.cx("root")
  }, $options.attrs), {
    "default": withCtx(function() {
      return [renderSlot(_ctx.$slots, "default")];
    }),
    _: 3
  }, 16, ["class"])), [[vShow, (_$options$$pcTabs2 = $options.$pcTabs) !== null && _$options$$pcTabs2 !== void 0 && _$options$$pcTabs2.lazy ? true : $options.active]]) : createCommentVNode("", true)], 64)) : renderSlot(_ctx.$slots, "default", {
    key: 1,
    "class": normalizeClass(_ctx.cx("root")),
    active: $options.active,
    a11yAttrs: $options.a11yAttrs
  })], 64));
}
__name(render$w, "render$w");
script$y.render = render$w;
var script$x = {
  name: "ChevronLeftIcon",
  "extends": script$16
};
function render$v(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M9.61296 13C9.50997 13.0005 9.40792 12.9804 9.3128 12.9409C9.21767 12.9014 9.13139 12.8433 9.05902 12.7701L3.83313 7.54416C3.68634 7.39718 3.60388 7.19795 3.60388 6.99022C3.60388 6.78249 3.68634 6.58325 3.83313 6.43628L9.05902 1.21039C9.20762 1.07192 9.40416 0.996539 9.60724 1.00012C9.81032 1.00371 10.0041 1.08597 10.1477 1.22959C10.2913 1.37322 10.3736 1.56698 10.3772 1.77005C10.3808 1.97313 10.3054 2.16968 10.1669 2.31827L5.49496 6.99022L10.1669 11.6622C10.3137 11.8091 10.3962 12.0084 10.3962 12.2161C10.3962 12.4238 10.3137 12.6231 10.1669 12.7701C10.0945 12.8433 10.0083 12.9014 9.91313 12.9409C9.81801 12.9804 9.71596 13.0005 9.61296 13Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$v, "render$v");
script$x.render = render$v;
var script$w = {
  name: "ChevronRightIcon",
  "extends": script$16
};
function render$u(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M4.38708 13C4.28408 13.0005 4.18203 12.9804 4.08691 12.9409C3.99178 12.9014 3.9055 12.8433 3.83313 12.7701C3.68634 12.6231 3.60388 12.4238 3.60388 12.2161C3.60388 12.0084 3.68634 11.8091 3.83313 11.6622L8.50507 6.99022L3.83313 2.31827C3.69467 2.16968 3.61928 1.97313 3.62287 1.77005C3.62645 1.56698 3.70872 1.37322 3.85234 1.22959C3.99596 1.08597 4.18972 1.00371 4.3928 1.00012C4.59588 0.996539 4.79242 1.07192 4.94102 1.21039L10.1669 6.43628C10.3137 6.58325 10.3962 6.78249 10.3962 6.99022C10.3962 7.19795 10.3137 7.39718 10.1669 7.54416L4.94102 12.7701C4.86865 12.8433 4.78237 12.9014 4.68724 12.9409C4.59212 12.9804 4.49007 13.0005 4.38708 13Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$u, "render$u");
script$w.render = render$u;
var theme$j = /* @__PURE__ */ __name(function theme27(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tabview-tablist-container {\n    position: relative;\n}\n\n.p-tabview-scrollable > .p-tabview-tablist-container {\n    overflow: hidden;\n}\n\n.p-tabview-tablist-scroll-container {\n    overflow-x: auto;\n    overflow-y: hidden;\n    scroll-behavior: smooth;\n    scrollbar-width: none;\n    overscroll-behavior: contain auto;\n}\n\n.p-tabview-tablist-scroll-container::-webkit-scrollbar {\n    display: none;\n}\n\n.p-tabview-tablist {\n    display: flex;\n    margin: 0;\n    padding: 0;\n    list-style-type: none;\n    flex: 1 1 auto;\n    background: ".concat(dt2("tabview.tab.list.background"), ";\n    border: 1px solid ").concat(dt2("tabview.tab.list.border.color"), ";\n    border-width: 0 0 1px 0;\n    position: relative;\n}\n\n.p-tabview-tab-header {\n    cursor: pointer;\n    user-select: none;\n    display: flex;\n    align-items: center;\n    text-decoration: none;\n    position: relative;\n    overflow: hidden;\n    border-style: solid;\n    border-width: 0 0 1px 0;\n    border-color: transparent transparent ").concat(dt2("tabview.tab.border.color"), " transparent;\n    color: ").concat(dt2("tabview.tab.color"), ";\n    padding: 1rem 1.125rem;\n    font-weight: 600;\n    border-top-right-radius: ").concat(dt2("border.radius.md"), ";\n    border-top-left-radius: ").concat(dt2("border.radius.md"), ";\n    transition: color ").concat(dt2("tabview.transition.duration"), ", outline-color ").concat(dt2("tabview.transition.duration"), ";\n    margin: 0 0 -1px 0;\n    outline-color: transparent;\n}\n\n.p-tabview-tablist-item:not(.p-disabled) .p-tabview-tab-header:focus-visible {\n    outline: ").concat(dt2("focus.ring.width"), " ").concat(dt2("focus.ring.style"), " ").concat(dt2("focus.ring.color"), ";\n    outline-offset: -1px;\n}\n\n.p-tabview-tablist-item:not(.p-highlight):not(.p-disabled):hover > .p-tabview-tab-header {\n    color: ").concat(dt2("tabview.tab.hover.color"), ";\n}\n\n.p-tabview-tablist-item.p-highlight > .p-tabview-tab-header {\n    color: ").concat(dt2("tabview.tab.active.color"), ";\n}\n\n.p-tabview-tab-title {\n    line-height: 1;\n    white-space: nowrap;\n}\n\n.p-tabview-next-button,\n.p-tabview-prev-button {\n    position: absolute;\n    top: 0;\n    margin: 0;\n    padding: 0;\n    z-index: 2;\n    height: 100%;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    background: ").concat(dt2("tabview.nav.button.background"), ";\n    color: ").concat(dt2("tabview.nav.button.color"), ";\n    width: 2.5rem;\n    border-radius: 0;\n    outline-color: transparent;\n    transition: color ").concat(dt2("tabview.transition.duration"), ", outline-color ").concat(dt2("tabview.transition.duration"), ";\n    box-shadow: ").concat(dt2("tabview.nav.button.shadow"), ";\n    border: none;\n    cursor: pointer;\n    user-select: none;\n}\n\n.p-tabview-next-button:focus-visible,\n.p-tabview-prev-button:focus-visible {\n    outline: ").concat(dt2("focus.ring.width"), " ").concat(dt2("focus.ring.style"), " ").concat(dt2("focus.ring.color"), ";\n    outline-offset: ").concat(dt2("focus.ring.offset"), ";\n}\n\n.p-tabview-next-button:hover,\n.p-tabview-prev-button:hover {\n    color: ").concat(dt2("tabview.nav.button.hover.color"), ";\n}\n\n.p-tabview-prev-button {\n    left: 0;\n}\n\n.p-tabview-next-button {\n    right: 0;\n}\n\n.p-tabview-panels {\n    background: ").concat(dt2("tabview.tab.panel.background"), ";\n    color: ").concat(dt2("tabview.tab.panel.color"), ";\n    padding: 0.875rem 1.125rem 1.125rem 1.125rem;\n}\n\n.p-tabview-ink-bar {\n    z-index: 1;\n    display: block;\n    position: absolute;\n    bottom: -1px;\n    height: 1px;\n    background: ").concat(dt2("tabview.tab.active.border.color"), ";\n    transition: 250ms cubic-bezier(0.35, 0, 0.25, 1);\n}\n");
}, "theme");
var classes$l = {
  root: /* @__PURE__ */ __name(function root18(_ref2) {
    var props = _ref2.props;
    return ["p-tabview p-component", {
      "p-tabview-scrollable": props.scrollable
    }];
  }, "root"),
  navContainer: "p-tabview-tablist-container",
  prevButton: "p-tabview-prev-button",
  navContent: "p-tabview-tablist-scroll-container",
  nav: "p-tabview-tablist",
  tab: {
    header: /* @__PURE__ */ __name(function header(_ref3) {
      var instance = _ref3.instance, tab = _ref3.tab, index2 = _ref3.index;
      return ["p-tabview-tablist-item", instance.getTabProp(tab, "headerClass"), {
        "p-tabview-tablist-item-active": instance.d_activeIndex === index2,
        "p-disabled": instance.getTabProp(tab, "disabled")
      }];
    }, "header"),
    headerAction: "p-tabview-tab-header",
    headerTitle: "p-tabview-tab-title",
    content: /* @__PURE__ */ __name(function content(_ref4) {
      var instance = _ref4.instance, tab = _ref4.tab;
      return ["p-tabview-panel", instance.getTabProp(tab, "contentClass")];
    }, "content")
  },
  inkbar: "p-tabview-ink-bar",
  nextButton: "p-tabview-next-button",
  panelContainer: "p-tabview-panels"
};
var TabViewStyle = BaseStyle$1.extend({
  name: "tabview",
  theme: theme$j,
  classes: classes$l
});
var script$1$l = {
  name: "BaseTabView",
  "extends": script$1b,
  props: {
    activeIndex: {
      type: Number,
      "default": 0
    },
    lazy: {
      type: Boolean,
      "default": false
    },
    scrollable: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    selectOnFocus: {
      type: Boolean,
      "default": false
    },
    prevButtonProps: {
      type: null,
      "default": null
    },
    nextButtonProps: {
      type: null,
      "default": null
    },
    prevIcon: {
      type: String,
      "default": void 0
    },
    nextIcon: {
      type: String,
      "default": void 0
    }
  },
  style: TabViewStyle,
  provide: /* @__PURE__ */ __name(function provide30() {
    return {
      $pcTabs: void 0,
      // Backwards compatible to prevent <TabPanel> component from breaking
      $pcTabView: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$v = {
  name: "TabView",
  "extends": script$1$l,
  inheritAttrs: false,
  emits: ["update:activeIndex", "tab-change", "tab-click"],
  data: /* @__PURE__ */ __name(function data13() {
    return {
      id: this.$attrs.id,
      d_activeIndex: this.activeIndex,
      isPrevButtonDisabled: true,
      isNextButtonDisabled: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId6(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    activeIndex: /* @__PURE__ */ __name(function activeIndex(newValue2) {
      this.d_activeIndex = newValue2;
      this.scrollInView({
        index: newValue2
      });
    }, "activeIndex")
  },
  mounted: /* @__PURE__ */ __name(function mounted14() {
    console.warn("Deprecated since v4. Use Tabs component instead.");
    this.id = this.id || UniqueComponentId();
    this.updateInkBar();
    this.scrollable && this.updateButtonState();
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated9() {
    this.updateInkBar();
    this.scrollable && this.updateButtonState();
  }, "updated"),
  methods: {
    isTabPanel: /* @__PURE__ */ __name(function isTabPanel(child) {
      return child.type.name === "TabPanel";
    }, "isTabPanel"),
    isTabActive: /* @__PURE__ */ __name(function isTabActive(index2) {
      return this.d_activeIndex === index2;
    }, "isTabActive"),
    getTabProp: /* @__PURE__ */ __name(function getTabProp(tab, name2) {
      return tab.props ? tab.props[name2] : void 0;
    }, "getTabProp"),
    getKey: /* @__PURE__ */ __name(function getKey(tab, index2) {
      return this.getTabProp(tab, "header") || index2;
    }, "getKey"),
    getTabHeaderActionId: /* @__PURE__ */ __name(function getTabHeaderActionId(index2) {
      return "".concat(this.id, "_").concat(index2, "_header_action");
    }, "getTabHeaderActionId"),
    getTabContentId: /* @__PURE__ */ __name(function getTabContentId(index2) {
      return "".concat(this.id, "_").concat(index2, "_content");
    }, "getTabContentId"),
    getTabPT: /* @__PURE__ */ __name(function getTabPT(tab, key, index2) {
      var count = this.tabs.length;
      var tabMetaData = {
        props: tab.props,
        parent: {
          instance: this,
          props: this.$props,
          state: this.$data
        },
        context: {
          index: index2,
          count,
          first: index2 === 0,
          last: index2 === count - 1,
          active: this.isTabActive(index2)
        }
      };
      return mergeProps$2(this.ptm("tabpanel.".concat(key), {
        tabpanel: tabMetaData
      }), this.ptm("tabpanel.".concat(key), tabMetaData), this.ptmo(this.getTabProp(tab, "pt"), key, tabMetaData));
    }, "getTabPT"),
    onScroll: /* @__PURE__ */ __name(function onScroll3(event) {
      this.scrollable && this.updateButtonState();
      event.preventDefault();
    }, "onScroll"),
    onPrevButtonClick: /* @__PURE__ */ __name(function onPrevButtonClick() {
      var content3 = this.$refs.content;
      var width2 = getWidth$1(content3);
      var pos = content3.scrollLeft - width2;
      content3.scrollLeft = pos <= 0 ? 0 : pos;
    }, "onPrevButtonClick"),
    onNextButtonClick: /* @__PURE__ */ __name(function onNextButtonClick() {
      var content3 = this.$refs.content;
      var width2 = getWidth$1(content3) - this.getVisibleButtonWidths();
      var pos = content3.scrollLeft + width2;
      var lastPos = content3.scrollWidth - width2;
      content3.scrollLeft = pos >= lastPos ? lastPos : pos;
    }, "onNextButtonClick"),
    onTabClick: /* @__PURE__ */ __name(function onTabClick(event, tab, index2) {
      this.changeActiveIndex(event, tab, index2);
      this.$emit("tab-click", {
        originalEvent: event,
        index: index2
      });
    }, "onTabClick"),
    onTabKeyDown: /* @__PURE__ */ __name(function onTabKeyDown(event, tab, index2) {
      switch (event.code) {
        case "ArrowLeft":
          this.onTabArrowLeftKey(event);
          break;
        case "ArrowRight":
          this.onTabArrowRightKey(event);
          break;
        case "Home":
          this.onTabHomeKey(event);
          break;
        case "End":
          this.onTabEndKey(event);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onTabEnterKey(event, tab, index2);
          break;
      }
    }, "onTabKeyDown"),
    onTabArrowRightKey: /* @__PURE__ */ __name(function onTabArrowRightKey(event) {
      var nextHeaderAction = this.findNextHeaderAction(event.target.parentElement);
      nextHeaderAction ? this.changeFocusedTab(event, nextHeaderAction) : this.onTabHomeKey(event);
      event.preventDefault();
    }, "onTabArrowRightKey"),
    onTabArrowLeftKey: /* @__PURE__ */ __name(function onTabArrowLeftKey(event) {
      var prevHeaderAction = this.findPrevHeaderAction(event.target.parentElement);
      prevHeaderAction ? this.changeFocusedTab(event, prevHeaderAction) : this.onTabEndKey(event);
      event.preventDefault();
    }, "onTabArrowLeftKey"),
    onTabHomeKey: /* @__PURE__ */ __name(function onTabHomeKey(event) {
      var firstHeaderAction = this.findFirstHeaderAction();
      this.changeFocusedTab(event, firstHeaderAction);
      event.preventDefault();
    }, "onTabHomeKey"),
    onTabEndKey: /* @__PURE__ */ __name(function onTabEndKey(event) {
      var lastHeaderAction = this.findLastHeaderAction();
      this.changeFocusedTab(event, lastHeaderAction);
      event.preventDefault();
    }, "onTabEndKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey2(event) {
      this.scrollInView({
        index: this.$refs.nav.children.length - 2
      });
      event.preventDefault();
    }, "onPageDownKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey2(event) {
      this.scrollInView({
        index: 0
      });
      event.preventDefault();
    }, "onPageUpKey"),
    onTabEnterKey: /* @__PURE__ */ __name(function onTabEnterKey(event, tab, index2) {
      this.changeActiveIndex(event, tab, index2);
      event.preventDefault();
    }, "onTabEnterKey"),
    findNextHeaderAction: /* @__PURE__ */ __name(function findNextHeaderAction(tabElement) {
      var selfCheck = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var headerElement = selfCheck ? tabElement : tabElement.nextElementSibling;
      return headerElement ? getAttribute$1(headerElement, "data-p-disabled") || getAttribute$1(headerElement, "data-pc-section") === "inkbar" ? this.findNextHeaderAction(headerElement) : findSingle$1(headerElement, '[data-pc-section="headeraction"]') : null;
    }, "findNextHeaderAction"),
    findPrevHeaderAction: /* @__PURE__ */ __name(function findPrevHeaderAction(tabElement) {
      var selfCheck = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var headerElement = selfCheck ? tabElement : tabElement.previousElementSibling;
      return headerElement ? getAttribute$1(headerElement, "data-p-disabled") || getAttribute$1(headerElement, "data-pc-section") === "inkbar" ? this.findPrevHeaderAction(headerElement) : findSingle$1(headerElement, '[data-pc-section="headeraction"]') : null;
    }, "findPrevHeaderAction"),
    findFirstHeaderAction: /* @__PURE__ */ __name(function findFirstHeaderAction() {
      return this.findNextHeaderAction(this.$refs.nav.firstElementChild, true);
    }, "findFirstHeaderAction"),
    findLastHeaderAction: /* @__PURE__ */ __name(function findLastHeaderAction() {
      return this.findPrevHeaderAction(this.$refs.nav.lastElementChild, true);
    }, "findLastHeaderAction"),
    changeActiveIndex: /* @__PURE__ */ __name(function changeActiveIndex(event, tab, index2) {
      if (!this.getTabProp(tab, "disabled") && this.d_activeIndex !== index2) {
        this.d_activeIndex = index2;
        this.$emit("update:activeIndex", index2);
        this.$emit("tab-change", {
          originalEvent: event,
          index: index2
        });
        this.scrollInView({
          index: index2
        });
      }
    }, "changeActiveIndex"),
    changeFocusedTab: /* @__PURE__ */ __name(function changeFocusedTab(event, element) {
      if (element) {
        focus$2(element);
        this.scrollInView({
          element
        });
        if (this.selectOnFocus) {
          var index2 = parseInt(element.parentElement.dataset.pcIndex, 10);
          var tab = this.tabs[index2];
          this.changeActiveIndex(event, tab, index2);
        }
      }
    }, "changeFocusedTab"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView4(_ref) {
      var element = _ref.element, _ref$index = _ref.index, index2 = _ref$index === void 0 ? -1 : _ref$index;
      var currentElement = element || this.$refs.nav.children[index2];
      if (currentElement) {
        currentElement.scrollIntoView && currentElement.scrollIntoView({
          block: "nearest"
        });
      }
    }, "scrollInView"),
    updateInkBar: /* @__PURE__ */ __name(function updateInkBar() {
      var tabHeader = this.$refs.nav.children[this.d_activeIndex];
      this.$refs.inkbar.style.width = getWidth$1(tabHeader) + "px";
      this.$refs.inkbar.style.left = getOffset$1(tabHeader).left - getOffset$1(this.$refs.nav).left + "px";
    }, "updateInkBar"),
    updateButtonState: /* @__PURE__ */ __name(function updateButtonState() {
      var content3 = this.$refs.content;
      var scrollLeft = content3.scrollLeft, scrollWidth2 = content3.scrollWidth;
      var width2 = getWidth$1(content3);
      this.isPrevButtonDisabled = scrollLeft === 0;
      this.isNextButtonDisabled = parseInt(scrollLeft) === scrollWidth2 - width2;
    }, "updateButtonState"),
    getVisibleButtonWidths: /* @__PURE__ */ __name(function getVisibleButtonWidths() {
      var _this$$refs = this.$refs, prevBtn = _this$$refs.prevBtn, nextBtn = _this$$refs.nextBtn;
      return [prevBtn, nextBtn].reduce(function(acc, el) {
        return el ? acc + getWidth$1(el) : acc;
      }, 0);
    }, "getVisibleButtonWidths")
  },
  computed: {
    tabs: /* @__PURE__ */ __name(function tabs() {
      var _this = this;
      return this.$slots["default"]().reduce(function(tabs2, child) {
        if (_this.isTabPanel(child)) {
          tabs2.push(child);
        } else if (child.children && child.children instanceof Array) {
          child.children.forEach(function(nestedChild) {
            if (_this.isTabPanel(nestedChild)) {
              tabs2.push(nestedChild);
            }
          });
        }
        return tabs2;
      }, []);
    }, "tabs"),
    prevButtonAriaLabel: /* @__PURE__ */ __name(function prevButtonAriaLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.previous : void 0;
    }, "prevButtonAriaLabel"),
    nextButtonAriaLabel: /* @__PURE__ */ __name(function nextButtonAriaLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.next : void 0;
    }, "nextButtonAriaLabel")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    ChevronLeftIcon: script$x,
    ChevronRightIcon: script$w
  }
};
function _typeof$a(o2) {
  "@babel/helpers - typeof";
  return _typeof$a = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$a(o2);
}
__name(_typeof$a, "_typeof$a");
function ownKeys$c(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$c, "ownKeys$c");
function _objectSpread$c(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$c(Object(t2), true).forEach(function(r3) {
      _defineProperty$a(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$c(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$c, "_objectSpread$c");
function _defineProperty$a(e2, r2, t2) {
  return (r2 = _toPropertyKey$9(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$a, "_defineProperty$a");
function _toPropertyKey$9(t2) {
  var i2 = _toPrimitive$9(t2, "string");
  return "symbol" == _typeof$a(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$9, "_toPropertyKey$9");
function _toPrimitive$9(t2, r2) {
  if ("object" != _typeof$a(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$a(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$9, "_toPrimitive$9");
var _hoisted_1$1o = ["tabindex", "aria-label"];
var _hoisted_2$10 = ["data-p-active", "data-p-disabled", "data-pc-index"];
var _hoisted_3$J = ["id", "tabindex", "aria-disabled", "aria-selected", "aria-controls", "onClick", "onKeydown"];
var _hoisted_4$v = ["tabindex", "aria-label"];
var _hoisted_5$p = ["id", "aria-labelledby", "data-pc-index", "data-p-active"];
function render$t(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    role: "tablist"
  }, _ctx.ptmi("root")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("navContainer")
  }, _ctx.ptm("navContainer")), [_ctx.scrollable && !$data.isPrevButtonDisabled ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 0,
    ref: "prevBtn",
    type: "button",
    "class": _ctx.cx("prevButton"),
    tabindex: _ctx.tabindex,
    "aria-label": $options.prevButtonAriaLabel,
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.onPrevButtonClick && $options.onPrevButtonClick.apply($options, arguments);
    })
  }, _objectSpread$c(_objectSpread$c({}, _ctx.prevButtonProps), _ctx.ptm("prevButton")), {
    "data-pc-group-section": "navbutton"
  }), [renderSlot(_ctx.$slots, "previcon", {}, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.prevIcon ? "span" : "ChevronLeftIcon"), mergeProps$2({
      "aria-hidden": "true",
      "class": _ctx.prevIcon
    }, _ctx.ptm("prevIcon")), null, 16, ["class"]))];
  })], 16, _hoisted_1$1o)), [[_directive_ripple]]) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    ref: "content",
    "class": _ctx.cx("navContent"),
    onScroll: _cache[1] || (_cache[1] = function() {
      return $options.onScroll && $options.onScroll.apply($options, arguments);
    })
  }, _ctx.ptm("navContent")), [createBaseVNode("ul", mergeProps$2({
    ref: "nav",
    "class": _ctx.cx("nav")
  }, _ctx.ptm("nav")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($options.tabs, function(tab, index2) {
    return openBlock(), createElementBlock("li", mergeProps$2({
      key: $options.getKey(tab, index2),
      style: $options.getTabProp(tab, "headerStyle"),
      "class": _ctx.cx("tab.header", {
        tab,
        index: index2
      }),
      role: "presentation",
      ref_for: true
    }, _objectSpread$c(_objectSpread$c(_objectSpread$c({}, $options.getTabProp(tab, "headerProps")), $options.getTabPT(tab, "root", index2)), $options.getTabPT(tab, "header", index2)), {
      "data-pc-name": "tabpanel",
      "data-p-active": $data.d_activeIndex === index2,
      "data-p-disabled": $options.getTabProp(tab, "disabled"),
      "data-pc-index": index2
    }), [withDirectives((openBlock(), createElementBlock("a", mergeProps$2({
      id: $options.getTabHeaderActionId(index2),
      "class": _ctx.cx("tab.headerAction"),
      tabindex: $options.getTabProp(tab, "disabled") || !$options.isTabActive(index2) ? -1 : _ctx.tabindex,
      role: "tab",
      "aria-disabled": $options.getTabProp(tab, "disabled"),
      "aria-selected": $options.isTabActive(index2),
      "aria-controls": $options.getTabContentId(index2),
      onClick: /* @__PURE__ */ __name(function onClick5($event) {
        return $options.onTabClick($event, tab, index2);
      }, "onClick"),
      onKeydown: /* @__PURE__ */ __name(function onKeydown4($event) {
        return $options.onTabKeyDown($event, tab, index2);
      }, "onKeydown"),
      ref_for: true
    }, _objectSpread$c(_objectSpread$c({}, $options.getTabProp(tab, "headerActionProps")), $options.getTabPT(tab, "headerAction", index2))), [tab.props && tab.props.header ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 0,
      "class": _ctx.cx("tab.headerTitle"),
      ref_for: true
    }, $options.getTabPT(tab, "headerTitle", index2)), toDisplayString$1(tab.props.header), 17)) : createCommentVNode("", true), tab.children && tab.children.header ? (openBlock(), createBlock(resolveDynamicComponent(tab.children.header), {
      key: 1
    })) : createCommentVNode("", true)], 16, _hoisted_3$J)), [[_directive_ripple]])], 16, _hoisted_2$10);
  }), 128)), createBaseVNode("li", mergeProps$2({
    ref: "inkbar",
    "class": _ctx.cx("inkbar"),
    role: "presentation",
    "aria-hidden": "true"
  }, _ctx.ptm("inkbar")), null, 16)], 16)], 16), _ctx.scrollable && !$data.isNextButtonDisabled ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 1,
    ref: "nextBtn",
    type: "button",
    "class": _ctx.cx("nextButton"),
    tabindex: _ctx.tabindex,
    "aria-label": $options.nextButtonAriaLabel,
    onClick: _cache[2] || (_cache[2] = function() {
      return $options.onNextButtonClick && $options.onNextButtonClick.apply($options, arguments);
    })
  }, _objectSpread$c(_objectSpread$c({}, _ctx.nextButtonProps), _ctx.ptm("nextButton")), {
    "data-pc-group-section": "navbutton"
  }), [renderSlot(_ctx.$slots, "nexticon", {}, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.nextIcon ? "span" : "ChevronRightIcon"), mergeProps$2({
      "aria-hidden": "true",
      "class": _ctx.nextIcon
    }, _ctx.ptm("nextIcon")), null, 16, ["class"]))];
  })], 16, _hoisted_4$v)), [[_directive_ripple]]) : createCommentVNode("", true)], 16), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("panelContainer")
  }, _ctx.ptm("panelContainer")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($options.tabs, function(tab, index2) {
    return openBlock(), createElementBlock(Fragment$1, {
      key: $options.getKey(tab, index2)
    }, [(_ctx.lazy ? $options.isTabActive(index2) : true) ? withDirectives((openBlock(), createElementBlock("div", mergeProps$2({
      key: 0,
      id: $options.getTabContentId(index2),
      style: $options.getTabProp(tab, "contentStyle"),
      "class": _ctx.cx("tab.content", {
        tab
      }),
      role: "tabpanel",
      "aria-labelledby": $options.getTabHeaderActionId(index2),
      ref_for: true
    }, _objectSpread$c(_objectSpread$c(_objectSpread$c({}, $options.getTabProp(tab, "contentProps")), $options.getTabPT(tab, "root", index2)), $options.getTabPT(tab, "content", index2)), {
      "data-pc-name": "tabpanel",
      "data-pc-index": index2,
      "data-p-active": $data.d_activeIndex === index2
    }), [(openBlock(), createBlock(resolveDynamicComponent(tab)))], 16, _hoisted_5$p)), [[vShow, _ctx.lazy ? true : $options.isTabActive(index2)]]) : createCommentVNode("", true)], 64);
  }), 128))], 16)], 16);
}
__name(render$t, "render$t");
script$v.render = render$t;
const _hoisted_1$1n = { class: "grid grid-cols-2 gap-2" };
const _hoisted_2$$ = { class: "font-medium" };
const _sfc_main$1q = /* @__PURE__ */ defineComponent({
  __name: "DeviceInfo",
  props: {
    device: {}
  },
  setup(__props) {
    const props = __props;
    const deviceColumns = [
      { field: "name", header: "Name" },
      { field: "type", header: "Type" },
      { field: "vram_total", header: "VRAM Total" },
      { field: "vram_free", header: "VRAM Free" },
      { field: "torch_vram_total", header: "Torch VRAM Total" },
      { field: "torch_vram_free", header: "Torch VRAM Free" }
    ];
    const formatValue2 = /* @__PURE__ */ __name((value3, field2) => {
      if (["vram_total", "vram_free", "torch_vram_total", "torch_vram_free"].includes(
        field2
      )) {
        return formatSize(value3);
      }
      return value3;
    }, "formatValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1n, [
        (openBlock(), createElementBlock(Fragment$1, null, renderList(deviceColumns, (col) => {
          return openBlock(), createElementBlock(Fragment$1, {
            key: col.field
          }, [
            createBaseVNode("div", _hoisted_2$$, toDisplayString$1(col.header), 1),
            createBaseVNode("div", null, toDisplayString$1(formatValue2(props.device[col.field], col.field)), 1)
          ], 64);
        }), 64))
      ]);
    };
  }
});
const _hoisted_1$1m = { class: "system-stats" };
const _hoisted_2$_ = { class: "mb-6" };
const _hoisted_3$I = { class: "text-2xl font-semibold mb-4" };
const _hoisted_4$u = { class: "grid grid-cols-2 gap-2" };
const _hoisted_5$o = { class: "font-medium" };
const _hoisted_6$i = { class: "text-2xl font-semibold mb-4" };
const _sfc_main$1p = /* @__PURE__ */ defineComponent({
  __name: "SystemStatsPanel",
  props: {
    stats: {}
  },
  setup(__props) {
    const props = __props;
    const systemInfo = computed(() => ({
      ...props.stats.system,
      argv: props.stats.system.argv.join(" ")
    }));
    const systemColumns = [
      { field: "os", header: "OS" },
      { field: "python_version", header: "Python Version" },
      { field: "embedded_python", header: "Embedded Python" },
      { field: "pytorch_version", header: "Pytorch Version" },
      { field: "argv", header: "Arguments" },
      { field: "ram_total", header: "RAM Total" },
      { field: "ram_free", header: "RAM Free" }
    ];
    const formatValue2 = /* @__PURE__ */ __name((value3, field2) => {
      if (["ram_total", "ram_free"].includes(field2)) {
        return formatSize(value3);
      }
      return value3;
    }, "formatValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1m, [
        createBaseVNode("div", _hoisted_2$_, [
          createBaseVNode("h2", _hoisted_3$I, toDisplayString$1(_ctx.$t("g.systemInfo")), 1),
          createBaseVNode("div", _hoisted_4$u, [
            (openBlock(), createElementBlock(Fragment$1, null, renderList(systemColumns, (col) => {
              return openBlock(), createElementBlock(Fragment$1, {
                key: col.field
              }, [
                createBaseVNode("div", _hoisted_5$o, toDisplayString$1(col.header), 1),
                createBaseVNode("div", null, toDisplayString$1(formatValue2(systemInfo.value[col.field], col.field)), 1)
              ], 64);
            }), 64))
          ])
        ]),
        createVNode(unref(script$Y)),
        createBaseVNode("div", null, [
          createBaseVNode("h2", _hoisted_6$i, toDisplayString$1(_ctx.$t("g.devices")), 1),
          props.stats.devices.length > 1 ? (openBlock(), createBlock(unref(script$v), { key: 0 }, {
            default: withCtx(() => [
              (openBlock(true), createElementBlock(Fragment$1, null, renderList(props.stats.devices, (device) => {
                return openBlock(), createBlock(unref(script$y), {
                  key: device.index,
                  header: device.name,
                  value: device.index
                }, {
                  default: withCtx(() => [
                    createVNode(_sfc_main$1q, { device }, null, 8, ["device"])
                  ]),
                  _: 2
                }, 1032, ["header", "value"]);
              }), 128))
            ]),
            _: 1
          })) : (openBlock(), createBlock(_sfc_main$1q, {
            key: 1,
            device: props.stats.devices[0]
          }, null, 8, ["device"]))
        ])
      ]);
    };
  }
});
const ALWAYS_ENABLED_EXTENSIONS = [];
const ALWAYS_DISABLED_EXTENSIONS = [
  // pysssss.Locking is replaced by pin/unpin in ComfyUI core.
  // https://github.com/Comfy-Org/litegraph.js/pull/117
  "pysssss.Locking",
  // pysssss.SnapToGrid is replaced by Comfy.Graph.AlwaysSnapToGrid in ComfyUI core.
  // pysssss.SnapToGrid tries to write global app.shiftDown state, which is no longer
  // allowed since v1.3.12.
  // https://github.com/Comfy-Org/ComfyUI_frontend/issues/1176
  "pysssss.SnapToGrid"
];
const useExtensionStore = /* @__PURE__ */ defineStore("extension", () => {
  const extensionByName = ref({});
  const extensions = computed(() => Object.values(extensionByName.value));
  const disabledExtensionNames = ref(/* @__PURE__ */ new Set());
  const inactiveDisabledExtensionNames = computed(() => {
    return Array.from(disabledExtensionNames.value).filter(
      (name2) => !(name2 in extensionByName.value)
    );
  });
  const isExtensionEnabled = /* @__PURE__ */ __name((name2) => !disabledExtensionNames.value.has(name2), "isExtensionEnabled");
  const enabledExtensions = computed(() => {
    return extensions.value.filter((ext) => isExtensionEnabled(ext.name));
  });
  function isExtensionReadOnly(name2) {
    return ALWAYS_DISABLED_EXTENSIONS.includes(name2) || ALWAYS_ENABLED_EXTENSIONS.includes(name2);
  }
  __name(isExtensionReadOnly, "isExtensionReadOnly");
  function registerExtension(extension) {
    if (!extension.name) {
      throw new Error("Extensions must have a 'name' property.");
    }
    if (extensionByName.value[extension.name]) {
      throw new Error(`Extension named '${extension.name}' already registered.`);
    }
    if (disabledExtensionNames.value.has(extension.name)) {
      console.log(`Extension ${extension.name} is disabled.`);
    }
    extensionByName.value[extension.name] = markRaw(extension);
  }
  __name(registerExtension, "registerExtension");
  function loadDisabledExtensionNames(names) {
    disabledExtensionNames.value = new Set(names);
    for (const name2 of ALWAYS_DISABLED_EXTENSIONS) {
      disabledExtensionNames.value.add(name2);
    }
    for (const name2 of ALWAYS_ENABLED_EXTENSIONS) {
      disabledExtensionNames.value.delete(name2);
    }
  }
  __name(loadDisabledExtensionNames, "loadDisabledExtensionNames");
  const coreExtensionNames = ref([]);
  function captureCoreExtensions() {
    coreExtensionNames.value = extensions.value.map((ext) => ext.name);
  }
  __name(captureCoreExtensions, "captureCoreExtensions");
  function isCoreExtension(name2) {
    return coreExtensionNames.value.includes(name2);
  }
  __name(isCoreExtension, "isCoreExtension");
  const hasThirdPartyExtensions = computed(() => {
    return extensions.value.some((ext) => !isCoreExtension(ext.name));
  });
  return {
    extensions,
    enabledExtensions,
    inactiveDisabledExtensionNames,
    isExtensionEnabled,
    isExtensionReadOnly,
    registerExtension,
    loadDisabledExtensionNames,
    captureCoreExtensions,
    isCoreExtension,
    hasThirdPartyExtensions
  };
});
const useSystemStatsStore = /* @__PURE__ */ defineStore("systemStats", () => {
  const systemStats = ref(null);
  const isLoading = ref(false);
  const error2 = ref(null);
  async function fetchSystemStats() {
    isLoading.value = true;
    error2.value = null;
    try {
      systemStats.value = await api.getSystemStats();
    } catch (err) {
      error2.value = err instanceof Error ? err.message : "An error occurred while fetching system stats";
      console.error("Error fetching system stats:", err);
    } finally {
      isLoading.value = false;
    }
  }
  __name(fetchSystemStats, "fetchSystemStats");
  return {
    systemStats,
    isLoading,
    error: error2,
    fetchSystemStats
  };
});
const useAboutPanelStore = /* @__PURE__ */ defineStore("aboutPanel", () => {
  const frontendVersion = "1.14.5";
  const extensionStore = useExtensionStore();
  const systemStatsStore = useSystemStatsStore();
  const coreVersion = computed(
    () => systemStatsStore?.systemStats?.system?.comfyui_version ?? ""
  );
  const coreBadges = computed(() => [
    // In electron, the ComfyUI is packaged without the git repo,
    // so the python server's API doesn't have the version info.
    {
      label: `ComfyUI ${isElectron() ? "v" + electronAPI().getComfyUIVersion() : coreVersion.value}`,
      url: "https://github.com/comfyanonymous/ComfyUI",
      icon: "pi pi-github"
    },
    {
      label: `ComfyUI_frontend v${frontendVersion}`,
      url: "https://github.com/Comfy-Org/ComfyUI_frontend",
      icon: "pi pi-github"
    },
    {
      label: "Discord",
      url: "https://www.comfy.org/discord",
      icon: "pi pi-discord"
    },
    { label: "ComfyOrg", url: "https://www.comfy.org/", icon: "pi pi-globe" }
  ]);
  const allBadges = computed(() => [
    ...coreBadges.value,
    ...extensionStore.extensions.flatMap((e2) => e2.aboutPageBadges ?? [])
  ]);
  return {
    badges: allBadges
  };
});
const _hoisted_1$1l = { class: "flex flex-col h-full w-full gap-2" };
const _sfc_main$1o = /* @__PURE__ */ defineComponent({
  __name: "PanelTemplate",
  props: {
    value: {},
    class: {}
  },
  setup(__props) {
    const props = __props;
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$y), {
        value: props.value,
        class: normalizeClass(["h-full w-full", props.class])
      }, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$1l, [
            renderSlot(_ctx.$slots, "header"),
            createVNode(unref(script$X), { class: "flex-grow h-0 pr-2" }, {
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "default")
              ]),
              _: 3
            }),
            renderSlot(_ctx.$slots, "footer")
          ])
        ]),
        _: 3
      }, 8, ["value", "class"]);
    };
  }
});
const _hoisted_1$1k = { class: "text-2xl font-bold mb-2" };
const _hoisted_2$Z = { class: "space-y-2" };
const _hoisted_3$H = ["href", "title"];
const _sfc_main$1n = /* @__PURE__ */ defineComponent({
  __name: "AboutPanel",
  setup(__props) {
    const systemStatsStore = useSystemStatsStore();
    const aboutPanelStore = useAboutPanelStore();
    onMounted(async () => {
      if (!systemStatsStore.systemStats) {
        await systemStatsStore.fetchSystemStats();
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createBlock(_sfc_main$1o, {
        value: "About",
        class: "about-container"
      }, {
        default: withCtx(() => [
          createBaseVNode("h2", _hoisted_1$1k, toDisplayString$1(_ctx.$t("g.about")), 1),
          createBaseVNode("div", _hoisted_2$Z, [
            (openBlock(true), createElementBlock(Fragment$1, null, renderList(unref(aboutPanelStore).badges, (badge) => {
              return openBlock(), createElementBlock("a", {
                key: badge.url,
                href: badge.url,
                target: "_blank",
                rel: "noopener noreferrer",
                class: "about-badge inline-flex items-center no-underline",
                title: badge.url
              }, [
                createVNode(unref(script$z), { class: "mr-2" }, {
                  icon: withCtx(() => [
                    createBaseVNode("i", {
                      class: normalizeClass([badge.icon, "mr-2 text-xl"])
                    }, null, 2)
                  ]),
                  default: withCtx(() => [
                    createTextVNode(" " + toDisplayString$1(badge.label), 1)
                  ]),
                  _: 2
                }, 1024)
              ], 8, _hoisted_3$H);
            }), 128))
          ]),
          createVNode(unref(script$Y)),
          unref(systemStatsStore).systemStats ? (openBlock(), createBlock(_sfc_main$1p, {
            key: 0,
            stats: unref(systemStatsStore).systemStats
          }, null, 8, ["stats"])) : createCommentVNode("", true)
        ]),
        _: 1
      });
    };
  }
});
var script$u = {
  name: "ChevronDownIcon",
  "extends": script$16
};
function render$s(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M7.01744 10.398C6.91269 10.3985 6.8089 10.378 6.71215 10.3379C6.61541 10.2977 6.52766 10.2386 6.45405 10.1641L1.13907 4.84913C1.03306 4.69404 0.985221 4.5065 1.00399 4.31958C1.02276 4.13266 1.10693 3.95838 1.24166 3.82747C1.37639 3.69655 1.55301 3.61742 1.74039 3.60402C1.92777 3.59062 2.11386 3.64382 2.26584 3.75424L7.01744 8.47394L11.769 3.75424C11.9189 3.65709 12.097 3.61306 12.2748 3.62921C12.4527 3.64535 12.6199 3.72073 12.7498 3.84328C12.8797 3.96582 12.9647 4.12842 12.9912 4.30502C13.0177 4.48162 12.9841 4.662 12.8958 4.81724L7.58083 10.1322C7.50996 10.2125 7.42344 10.2775 7.32656 10.3232C7.22968 10.3689 7.12449 10.3944 7.01744 10.398Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$s, "render$s");
script$u.render = render$s;
var OverlayEventBus = EventBus$1();
var theme$i = /* @__PURE__ */ __name(function theme28(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-select {\n    display: inline-flex;\n    cursor: pointer;\n    position: relative;\n    user-select: none;\n    background: ".concat(dt2("select.background"), ";\n    border: 1px solid ").concat(dt2("select.border.color"), ";\n    transition: background ").concat(dt2("select.transition.duration"), ", color ").concat(dt2("select.transition.duration"), ", border-color ").concat(dt2("select.transition.duration"), ",\n        outline-color ").concat(dt2("select.transition.duration"), ", box-shadow ").concat(dt2("select.transition.duration"), ";\n    border-radius: ").concat(dt2("select.border.radius"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("select.shadow"), ";\n}\n\n.p-select:not(.p-disabled):hover {\n    border-color: ").concat(dt2("select.hover.border.color"), ";\n}\n\n.p-select:not(.p-disabled).p-focus {\n    border-color: ").concat(dt2("select.focus.border.color"), ";\n    box-shadow: ").concat(dt2("select.focus.ring.shadow"), ";\n    outline: ").concat(dt2("select.focus.ring.width"), " ").concat(dt2("select.focus.ring.style"), " ").concat(dt2("select.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("select.focus.ring.offset"), ";\n}\n\n.p-select.p-variant-filled {\n    background: ").concat(dt2("select.filled.background"), ";\n}\n\n.p-select.p-variant-filled:not(.p-disabled):hover {\n    background: ").concat(dt2("select.filled.hover.background"), ";\n}\n\n.p-select.p-variant-filled:not(.p-disabled).p-focus {\n    background: ").concat(dt2("select.filled.focus.background"), ";\n}\n\n.p-select.p-invalid {\n    border-color: ").concat(dt2("select.invalid.border.color"), ";\n}\n\n.p-select.p-disabled {\n    opacity: 1;\n    background: ").concat(dt2("select.disabled.background"), ";\n}\n\n.p-select-clear-icon {\n    position: absolute;\n    top: 50%;\n    margin-top: -0.5rem;\n    color: ").concat(dt2("select.clear.icon.color"), ";\n    inset-inline-end: ").concat(dt2("select.dropdown.width"), ";\n}\n\n.p-select-dropdown {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    flex-shrink: 0;\n    background: transparent;\n    color: ").concat(dt2("select.dropdown.color"), ";\n    width: ").concat(dt2("select.dropdown.width"), ";\n    border-start-end-radius: ").concat(dt2("select.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("select.border.radius"), ";\n}\n\n.p-select-label {\n    display: block;\n    white-space: nowrap;\n    overflow: hidden;\n    flex: 1 1 auto;\n    width: 1%;\n    padding: ").concat(dt2("select.padding.y"), " ").concat(dt2("select.padding.x"), ";\n    text-overflow: ellipsis;\n    cursor: pointer;\n    color: ").concat(dt2("select.color"), ";\n    background: transparent;\n    border: 0 none;\n    outline: 0 none;\n}\n\n.p-select-label.p-placeholder {\n    color: ").concat(dt2("select.placeholder.color"), ";\n}\n\n.p-select.p-invalid .p-select-label.p-placeholder {\n    color: ").concat(dt2("select.invalid.placeholder.color"), ";\n}\n\n.p-select:has(.p-select-clear-icon) .p-select-label {\n    padding-inline-end: calc(1rem + ").concat(dt2("select.padding.x"), ");\n}\n\n.p-select.p-disabled .p-select-label {\n    color: ").concat(dt2("select.disabled.color"), ";\n}\n\n.p-select-label-empty {\n    overflow: hidden;\n    opacity: 0;\n}\n\ninput.p-select-label {\n    cursor: default;\n}\n\n.p-select .p-select-overlay {\n    min-width: 100%;\n}\n\n.p-select-overlay {\n    position: absolute;\n    top: 0;\n    left: 0;\n    background: ").concat(dt2("select.overlay.background"), ";\n    color: ").concat(dt2("select.overlay.color"), ";\n    border: 1px solid ").concat(dt2("select.overlay.border.color"), ";\n    border-radius: ").concat(dt2("select.overlay.border.radius"), ";\n    box-shadow: ").concat(dt2("select.overlay.shadow"), ";\n}\n\n.p-select-header {\n    padding: ").concat(dt2("select.list.header.padding"), ";\n}\n\n.p-select-filter {\n    width: 100%;\n}\n\n.p-select-list-container {\n    overflow: auto;\n}\n\n.p-select-option-group {\n    cursor: auto;\n    margin: 0;\n    padding: ").concat(dt2("select.option.group.padding"), ";\n    background: ").concat(dt2("select.option.group.background"), ";\n    color: ").concat(dt2("select.option.group.color"), ";\n    font-weight: ").concat(dt2("select.option.group.font.weight"), ";\n}\n\n.p-select-list {\n    margin: 0;\n    padding: 0;\n    list-style-type: none;\n    padding: ").concat(dt2("select.list.padding"), ";\n    gap: ").concat(dt2("select.list.gap"), ";\n    display: flex;\n    flex-direction: column;\n}\n\n.p-select-option {\n    cursor: pointer;\n    font-weight: normal;\n    white-space: nowrap;\n    position: relative;\n    overflow: hidden;\n    display: flex;\n    align-items: center;\n    padding: ").concat(dt2("select.option.padding"), ";\n    border: 0 none;\n    color: ").concat(dt2("select.option.color"), ";\n    background: transparent;\n    transition: background ").concat(dt2("select.transition.duration"), ", color ").concat(dt2("select.transition.duration"), ", border-color ").concat(dt2("select.transition.duration"), ",\n            box-shadow ").concat(dt2("select.transition.duration"), ", outline-color ").concat(dt2("select.transition.duration"), ";\n    border-radius: ").concat(dt2("select.option.border.radius"), ";\n}\n\n.p-select-option:not(.p-select-option-selected):not(.p-disabled).p-focus {\n    background: ").concat(dt2("select.option.focus.background"), ";\n    color: ").concat(dt2("select.option.focus.color"), ";\n}\n\n.p-select-option.p-select-option-selected {\n    background: ").concat(dt2("select.option.selected.background"), ";\n    color: ").concat(dt2("select.option.selected.color"), ";\n}\n\n.p-select-option.p-select-option-selected.p-focus {\n    background: ").concat(dt2("select.option.selected.focus.background"), ";\n    color: ").concat(dt2("select.option.selected.focus.color"), ";\n}\n\n.p-select-option-check-icon {\n    position: relative;\n    margin-inline-start: ").concat(dt2("select.checkmark.gutter.start"), ";\n    margin-inline-end: ").concat(dt2("select.checkmark.gutter.end"), ";\n    color: ").concat(dt2("select.checkmark.color"), ";\n}\n\n.p-select-empty-message {\n    padding: ").concat(dt2("select.empty.message.padding"), ";\n}\n\n.p-select-fluid {\n    display: flex;\n    width: 100%;\n}\n\n.p-select-sm .p-select-label {\n    font-size: ").concat(dt2("select.sm.font.size"), ";\n    padding-block: ").concat(dt2("select.sm.padding.y"), ";\n    padding-inline: ").concat(dt2("select.sm.padding.x"), ";\n}\n\n.p-select-sm .p-select-dropdown .p-icon {\n    font-size: ").concat(dt2("select.sm.font.size"), ";\n    width: ").concat(dt2("select.sm.font.size"), ";\n    height: ").concat(dt2("select.sm.font.size"), ";\n}\n\n.p-select-lg .p-select-label {\n    font-size: ").concat(dt2("select.lg.font.size"), ";\n    padding-block: ").concat(dt2("select.lg.padding.y"), ";\n    padding-inline: ").concat(dt2("select.lg.padding.x"), ";\n}\n\n.p-select-lg .p-select-dropdown .p-icon {\n    font-size: ").concat(dt2("select.lg.font.size"), ";\n    width: ").concat(dt2("select.lg.font.size"), ";\n    height: ").concat(dt2("select.lg.font.size"), ";\n}\n");
}, "theme");
var classes$k = {
  root: /* @__PURE__ */ __name(function root19(_ref2) {
    var instance = _ref2.instance, props = _ref2.props, state = _ref2.state;
    return ["p-select p-component p-inputwrapper", {
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid,
      "p-variant-filled": instance.$variant === "filled",
      "p-focus": state.focused,
      "p-inputwrapper-filled": instance.$filled,
      "p-inputwrapper-focus": state.focused || state.overlayVisible,
      "p-select-open": state.overlayVisible,
      "p-select-fluid": instance.$fluid,
      "p-select-sm p-inputfield-sm": props.size === "small",
      "p-select-lg p-inputfield-lg": props.size === "large"
    }];
  }, "root"),
  label: /* @__PURE__ */ __name(function label(_ref3) {
    var instance = _ref3.instance, props = _ref3.props;
    return ["p-select-label", {
      "p-placeholder": !props.editable && instance.label === props.placeholder,
      "p-select-label-empty": !props.editable && !instance.$slots["value"] && (instance.label === "p-emptylabel" || instance.label.length === 0)
    }];
  }, "label"),
  clearIcon: "p-select-clear-icon",
  dropdown: "p-select-dropdown",
  loadingicon: "p-select-loading-icon",
  dropdownIcon: "p-select-dropdown-icon",
  overlay: "p-select-overlay p-component",
  header: "p-select-header",
  pcFilter: "p-select-filter",
  listContainer: "p-select-list-container",
  list: "p-select-list",
  optionGroup: "p-select-option-group",
  optionGroupLabel: "p-select-option-group-label",
  option: /* @__PURE__ */ __name(function option2(_ref4) {
    var instance = _ref4.instance, props = _ref4.props, state = _ref4.state, _option = _ref4.option, focusedOption = _ref4.focusedOption;
    return ["p-select-option", {
      "p-select-option-selected": instance.isSelected(_option) && props.highlightOnSelect,
      "p-focus": state.focusedOptionIndex === focusedOption,
      "p-disabled": instance.isOptionDisabled(_option)
    }];
  }, "option"),
  optionLabel: "p-select-option-label",
  optionCheckIcon: "p-select-option-check-icon",
  optionBlankIcon: "p-select-option-blank-icon",
  emptyMessage: "p-select-empty-message"
};
var SelectStyle = BaseStyle$1.extend({
  name: "select",
  theme: theme$i,
  classes: classes$k
});
var script$1$k = {
  name: "BaseSelect",
  "extends": script$17,
  props: {
    options: Array,
    optionLabel: [String, Function],
    optionValue: [String, Function],
    optionDisabled: [String, Function],
    optionGroupLabel: [String, Function],
    optionGroupChildren: [String, Function],
    scrollHeight: {
      type: String,
      "default": "14rem"
    },
    filter: Boolean,
    filterPlaceholder: String,
    filterLocale: String,
    filterMatchMode: {
      type: String,
      "default": "contains"
    },
    filterFields: {
      type: Array,
      "default": null
    },
    editable: Boolean,
    placeholder: {
      type: String,
      "default": null
    },
    dataKey: null,
    showClear: {
      type: Boolean,
      "default": false
    },
    inputId: {
      type: String,
      "default": null
    },
    inputClass: {
      type: [String, Object],
      "default": null
    },
    inputStyle: {
      type: Object,
      "default": null
    },
    labelId: {
      type: String,
      "default": null
    },
    labelClass: {
      type: [String, Object],
      "default": null
    },
    labelStyle: {
      type: Object,
      "default": null
    },
    panelClass: {
      type: [String, Object],
      "default": null
    },
    overlayStyle: {
      type: Object,
      "default": null
    },
    overlayClass: {
      type: [String, Object],
      "default": null
    },
    panelStyle: {
      type: Object,
      "default": null
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    loading: {
      type: Boolean,
      "default": false
    },
    clearIcon: {
      type: String,
      "default": void 0
    },
    dropdownIcon: {
      type: String,
      "default": void 0
    },
    filterIcon: {
      type: String,
      "default": void 0
    },
    loadingIcon: {
      type: String,
      "default": void 0
    },
    resetFilterOnHide: {
      type: Boolean,
      "default": false
    },
    resetFilterOnClear: {
      type: Boolean,
      "default": false
    },
    virtualScrollerOptions: {
      type: Object,
      "default": null
    },
    autoOptionFocus: {
      type: Boolean,
      "default": false
    },
    autoFilterFocus: {
      type: Boolean,
      "default": false
    },
    selectOnFocus: {
      type: Boolean,
      "default": false
    },
    focusOnHover: {
      type: Boolean,
      "default": true
    },
    highlightOnSelect: {
      type: Boolean,
      "default": true
    },
    checkmark: {
      type: Boolean,
      "default": false
    },
    filterMessage: {
      type: String,
      "default": null
    },
    selectionMessage: {
      type: String,
      "default": null
    },
    emptySelectionMessage: {
      type: String,
      "default": null
    },
    emptyFilterMessage: {
      type: String,
      "default": null
    },
    emptyMessage: {
      type: String,
      "default": null
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    }
  },
  style: SelectStyle,
  provide: /* @__PURE__ */ __name(function provide31() {
    return {
      $pcSelect: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$9(o2) {
  "@babel/helpers - typeof";
  return _typeof$9 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$9(o2);
}
__name(_typeof$9, "_typeof$9");
function _toConsumableArray$9(r2) {
  return _arrayWithoutHoles$9(r2) || _iterableToArray$9(r2) || _unsupportedIterableToArray$b(r2) || _nonIterableSpread$9();
}
__name(_toConsumableArray$9, "_toConsumableArray$9");
function _nonIterableSpread$9() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$9, "_nonIterableSpread$9");
function _unsupportedIterableToArray$b(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$b(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$b(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$b, "_unsupportedIterableToArray$b");
function _iterableToArray$9(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$9, "_iterableToArray$9");
function _arrayWithoutHoles$9(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$b(r2);
}
__name(_arrayWithoutHoles$9, "_arrayWithoutHoles$9");
function _arrayLikeToArray$b(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$b, "_arrayLikeToArray$b");
function ownKeys$b(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$b, "ownKeys$b");
function _objectSpread$b(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$b(Object(t2), true).forEach(function(r3) {
      _defineProperty$9(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$b(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$b, "_objectSpread$b");
function _defineProperty$9(e2, r2, t2) {
  return (r2 = _toPropertyKey$8(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$9, "_defineProperty$9");
function _toPropertyKey$8(t2) {
  var i2 = _toPrimitive$8(t2, "string");
  return "symbol" == _typeof$9(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$8, "_toPropertyKey$8");
function _toPrimitive$8(t2, r2) {
  if ("object" != _typeof$9(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$9(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$8, "_toPrimitive$8");
var script$t = {
  name: "Select",
  "extends": script$1$k,
  inheritAttrs: false,
  emits: ["change", "focus", "blur", "before-show", "before-hide", "show", "hide", "filter"],
  outsideClickListener: null,
  scrollHandler: null,
  resizeListener: null,
  labelClickListener: null,
  overlay: null,
  list: null,
  virtualScroller: null,
  searchTimeout: null,
  searchValue: null,
  isModelValueChanged: false,
  data: /* @__PURE__ */ __name(function data14() {
    return {
      id: this.$attrs.id,
      clicked: false,
      focused: false,
      focusedOptionIndex: -1,
      filterValue: null,
      overlayVisible: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId7(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    modelValue: /* @__PURE__ */ __name(function modelValue2() {
      this.isModelValueChanged = true;
    }, "modelValue"),
    options: /* @__PURE__ */ __name(function options3() {
      this.autoUpdateModel();
    }, "options")
  },
  mounted: /* @__PURE__ */ __name(function mounted15() {
    this.id = this.id || UniqueComponentId();
    this.autoUpdateModel();
    this.bindLabelClickListener();
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated10() {
    if (this.overlayVisible && this.isModelValueChanged) {
      this.scrollInView(this.findSelectedOptionIndex());
    }
    this.isModelValueChanged = false;
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount6() {
    this.unbindOutsideClickListener();
    this.unbindResizeListener();
    this.unbindLabelClickListener();
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    if (this.overlay) {
      ZIndex$1.clear(this.overlay);
      this.overlay = null;
    }
  }, "beforeUnmount"),
  methods: {
    getOptionIndex: /* @__PURE__ */ __name(function getOptionIndex2(index2, fn) {
      return this.virtualScrollerDisabled ? index2 : fn && fn(index2)["index"];
    }, "getOptionIndex"),
    getOptionLabel: /* @__PURE__ */ __name(function getOptionLabel2(option5) {
      return this.optionLabel ? resolveFieldData$2(option5, this.optionLabel) : option5;
    }, "getOptionLabel"),
    getOptionValue: /* @__PURE__ */ __name(function getOptionValue2(option5) {
      return this.optionValue ? resolveFieldData$2(option5, this.optionValue) : option5;
    }, "getOptionValue"),
    getOptionRenderKey: /* @__PURE__ */ __name(function getOptionRenderKey2(option5, index2) {
      return (this.dataKey ? resolveFieldData$2(option5, this.dataKey) : this.getOptionLabel(option5)) + "_" + index2;
    }, "getOptionRenderKey"),
    getPTItemOptions: /* @__PURE__ */ __name(function getPTItemOptions(option5, itemOptions, index2, key) {
      return this.ptm(key, {
        context: {
          option: option5,
          index: index2,
          selected: this.isSelected(option5),
          focused: this.focusedOptionIndex === this.getOptionIndex(index2, itemOptions),
          disabled: this.isOptionDisabled(option5)
        }
      });
    }, "getPTItemOptions"),
    isOptionDisabled: /* @__PURE__ */ __name(function isOptionDisabled2(option5) {
      return this.optionDisabled ? resolveFieldData$2(option5, this.optionDisabled) : false;
    }, "isOptionDisabled"),
    isOptionGroup: /* @__PURE__ */ __name(function isOptionGroup2(option5) {
      return this.optionGroupLabel && option5.optionGroup && option5.group;
    }, "isOptionGroup"),
    getOptionGroupLabel: /* @__PURE__ */ __name(function getOptionGroupLabel2(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupLabel);
    }, "getOptionGroupLabel"),
    getOptionGroupChildren: /* @__PURE__ */ __name(function getOptionGroupChildren2(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupChildren);
    }, "getOptionGroupChildren"),
    getAriaPosInset: /* @__PURE__ */ __name(function getAriaPosInset2(index2) {
      var _this = this;
      return (this.optionGroupLabel ? index2 - this.visibleOptions.slice(0, index2).filter(function(option5) {
        return _this.isOptionGroup(option5);
      }).length : index2) + 1;
    }, "getAriaPosInset"),
    show: /* @__PURE__ */ __name(function show2(isFocus) {
      this.$emit("before-show");
      this.overlayVisible = true;
      this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : this.editable ? -1 : this.findSelectedOptionIndex();
      isFocus && focus$2(this.$refs.focusInput);
    }, "show"),
    hide: /* @__PURE__ */ __name(function hide2(isFocus) {
      var _this2 = this;
      var _hide = /* @__PURE__ */ __name(function _hide2() {
        _this2.$emit("before-hide");
        _this2.overlayVisible = false;
        _this2.clicked = false;
        _this2.focusedOptionIndex = -1;
        _this2.searchValue = "";
        _this2.resetFilterOnHide && (_this2.filterValue = null);
        isFocus && focus$2(_this2.$refs.focusInput);
      }, "_hide");
      setTimeout(function() {
        _hide();
      }, 0);
    }, "hide"),
    onFocus: /* @__PURE__ */ __name(function onFocus4(event) {
      if (this.disabled) {
        return;
      }
      this.focused = true;
      if (this.overlayVisible) {
        this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : this.editable ? -1 : this.findSelectedOptionIndex();
        this.scrollInView(this.focusedOptionIndex);
      }
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur4(event) {
      var _this$formField$onBlu, _this$formField;
      this.focused = false;
      this.focusedOptionIndex = -1;
      this.searchValue = "";
      this.$emit("blur", event);
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown5(event) {
      if (this.disabled || isAndroid$3()) {
        event.preventDefault();
        return;
      }
      var metaKey = event.metaKey || event.ctrlKey;
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event, this.editable);
          break;
        case "ArrowLeft":
        case "ArrowRight":
          this.onArrowLeftKey(event, this.editable);
          break;
        case "Home":
          this.onHomeKey(event, this.editable);
          break;
        case "End":
          this.onEndKey(event, this.editable);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Space":
          this.onSpaceKey(event, this.editable);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event);
          break;
        case "Backspace":
          this.onBackspaceKey(event, this.editable);
          break;
        case "ShiftLeft":
        case "ShiftRight":
          break;
        default:
          if (!metaKey && isPrintableCharacter$2(event.key)) {
            !this.overlayVisible && this.show();
            !this.editable && this.searchOptions(event, event.key);
          }
          break;
      }
      this.clicked = false;
    }, "onKeyDown"),
    onEditableInput: /* @__PURE__ */ __name(function onEditableInput(event) {
      var value3 = event.target.value;
      this.searchValue = "";
      var matched = this.searchOptions(event, value3);
      !matched && (this.focusedOptionIndex = -1);
      this.updateModel(event, value3);
      !this.overlayVisible && isNotEmpty$2(value3) && this.show();
    }, "onEditableInput"),
    onContainerClick: /* @__PURE__ */ __name(function onContainerClick(event) {
      if (this.disabled || this.loading) {
        return;
      }
      if (event.target.tagName === "INPUT" || event.target.getAttribute("data-pc-section") === "clearicon" || event.target.closest('[data-pc-section="clearicon"]')) {
        return;
      } else if (!this.overlay || !this.overlay.contains(event.target)) {
        this.overlayVisible ? this.hide(true) : this.show(true);
      }
      this.clicked = true;
    }, "onContainerClick"),
    onClearClick: /* @__PURE__ */ __name(function onClearClick(event) {
      this.updateModel(event, null);
      this.resetFilterOnClear && (this.filterValue = null);
    }, "onClearClick"),
    onFirstHiddenFocus: /* @__PURE__ */ __name(function onFirstHiddenFocus2(event) {
      var focusableEl = event.relatedTarget === this.$refs.focusInput ? getFirstFocusableElement$1(this.overlay, ':not([data-p-hidden-focusable="true"])') : this.$refs.focusInput;
      focus$2(focusableEl);
    }, "onFirstHiddenFocus"),
    onLastHiddenFocus: /* @__PURE__ */ __name(function onLastHiddenFocus2(event) {
      var focusableEl = event.relatedTarget === this.$refs.focusInput ? getLastFocusableElement$1(this.overlay, ':not([data-p-hidden-focusable="true"])') : this.$refs.focusInput;
      focus$2(focusableEl);
    }, "onLastHiddenFocus"),
    onOptionSelect: /* @__PURE__ */ __name(function onOptionSelect2(event, option5) {
      var isHide = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true;
      var value3 = this.getOptionValue(option5);
      this.updateModel(event, value3);
      isHide && this.hide(true);
    }, "onOptionSelect"),
    onOptionMouseMove: /* @__PURE__ */ __name(function onOptionMouseMove2(event, index2) {
      if (this.focusOnHover) {
        this.changeFocusedOptionIndex(event, index2);
      }
    }, "onOptionMouseMove"),
    onFilterChange: /* @__PURE__ */ __name(function onFilterChange2(event) {
      var value3 = event.target.value;
      this.filterValue = value3;
      this.focusedOptionIndex = -1;
      this.$emit("filter", {
        originalEvent: event,
        value: value3
      });
      !this.virtualScrollerDisabled && this.virtualScroller.scrollToIndex(0);
    }, "onFilterChange"),
    onFilterKeyDown: /* @__PURE__ */ __name(function onFilterKeyDown2(event) {
      if (event.isComposing) return;
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event, true);
          break;
        case "ArrowLeft":
        case "ArrowRight":
          this.onArrowLeftKey(event, true);
          break;
        case "Home":
          this.onHomeKey(event, true);
          break;
        case "End":
          this.onEndKey(event, true);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event, true);
          break;
      }
    }, "onFilterKeyDown"),
    onFilterBlur: /* @__PURE__ */ __name(function onFilterBlur2() {
      this.focusedOptionIndex = -1;
    }, "onFilterBlur"),
    onFilterUpdated: /* @__PURE__ */ __name(function onFilterUpdated() {
      if (this.overlayVisible) {
        this.alignOverlay();
      }
    }, "onFilterUpdated"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.$el
      });
    }, "onOverlayClick"),
    onOverlayKeyDown: /* @__PURE__ */ __name(function onOverlayKeyDown(event) {
      switch (event.code) {
        case "Escape":
          this.onEscapeKey(event);
          break;
      }
    }, "onOverlayKeyDown"),
    onArrowDownKey: /* @__PURE__ */ __name(function onArrowDownKey2(event) {
      if (!this.overlayVisible) {
        this.show();
        this.editable && this.changeFocusedOptionIndex(event, this.findSelectedOptionIndex());
      } else {
        var optionIndex = this.focusedOptionIndex !== -1 ? this.findNextOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findFirstOptionIndex() : this.findFirstFocusedOptionIndex();
        this.changeFocusedOptionIndex(event, optionIndex);
      }
      event.preventDefault();
    }, "onArrowDownKey"),
    onArrowUpKey: /* @__PURE__ */ __name(function onArrowUpKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (event.altKey && !pressedInInputText) {
        if (this.focusedOptionIndex !== -1) {
          this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
        }
        this.overlayVisible && this.hide();
        event.preventDefault();
      } else {
        var optionIndex = this.focusedOptionIndex !== -1 ? this.findPrevOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findLastOptionIndex() : this.findLastFocusedOptionIndex();
        this.changeFocusedOptionIndex(event, optionIndex);
        !this.overlayVisible && this.show();
        event.preventDefault();
      }
    }, "onArrowUpKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      pressedInInputText && (this.focusedOptionIndex = -1);
    }, "onArrowLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(0, event.target.selectionStart);
        } else {
          target2.setSelectionRange(0, 0);
          this.focusedOptionIndex = -1;
        }
      } else {
        this.changeFocusedOptionIndex(event, this.findFirstOptionIndex());
        !this.overlayVisible && this.show();
      }
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(event.target.selectionStart, target2.value.length);
        } else {
          var len = target2.value.length;
          target2.setSelectionRange(len, len);
          this.focusedOptionIndex = -1;
        }
      } else {
        this.changeFocusedOptionIndex(event, this.findLastOptionIndex());
        !this.overlayVisible && this.show();
      }
      event.preventDefault();
    }, "onEndKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey3(event) {
      this.scrollInView(0);
      event.preventDefault();
    }, "onPageUpKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey3(event) {
      this.scrollInView(this.visibleOptions.length - 1);
      event.preventDefault();
    }, "onPageDownKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey2(event) {
      if (!this.overlayVisible) {
        this.focusedOptionIndex = -1;
        this.onArrowDownKey(event);
      } else {
        if (this.focusedOptionIndex !== -1) {
          this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
        }
        this.hide();
      }
      event.preventDefault();
    }, "onEnterKey"),
    onSpaceKey: /* @__PURE__ */ __name(function onSpaceKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      !pressedInInputText && this.onEnterKey(event);
    }, "onSpaceKey"),
    onEscapeKey: /* @__PURE__ */ __name(function onEscapeKey(event) {
      this.overlayVisible && this.hide(true);
      event.preventDefault();
      event.stopPropagation();
    }, "onEscapeKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (!pressedInInputText) {
        if (this.overlayVisible && this.hasFocusableElements()) {
          focus$2(this.$refs.firstHiddenFocusableElementOnOverlay);
          event.preventDefault();
        } else {
          if (this.focusedOptionIndex !== -1) {
            this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
          }
          this.overlayVisible && this.hide(this.filter);
        }
      }
    }, "onTabKey"),
    onBackspaceKey: /* @__PURE__ */ __name(function onBackspaceKey(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        !this.overlayVisible && this.show();
      }
    }, "onBackspaceKey"),
    onOverlayEnter: /* @__PURE__ */ __name(function onOverlayEnter(el) {
      var _this3 = this;
      ZIndex$1.set("overlay", el, this.$primevue.config.zIndex.overlay);
      addStyle$1(el, {
        position: "absolute",
        top: "0",
        left: "0"
      });
      this.alignOverlay();
      this.scrollInView();
      setTimeout(function() {
        _this3.autoFilterFocus && _this3.filter && focus$2(_this3.$refs.filterInput.$el);
      }, 1);
    }, "onOverlayEnter"),
    onOverlayAfterEnter: /* @__PURE__ */ __name(function onOverlayAfterEnter() {
      this.bindOutsideClickListener();
      this.bindScrollListener();
      this.bindResizeListener();
      this.$emit("show");
    }, "onOverlayAfterEnter"),
    onOverlayLeave: /* @__PURE__ */ __name(function onOverlayLeave() {
      var _this4 = this;
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
      if (this.autoFilterFocus && this.filter && !this.editable) {
        this.$nextTick(function() {
          focus$2(_this4.$refs.filterInput.$el);
        });
      }
      this.$emit("hide");
      this.overlay = null;
    }, "onOverlayLeave"),
    onOverlayAfterLeave: /* @__PURE__ */ __name(function onOverlayAfterLeave(el) {
      ZIndex$1.clear(el);
    }, "onOverlayAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay2() {
      if (this.appendTo === "self") {
        relativePosition$1(this.overlay, this.$el);
      } else {
        this.overlay.style.minWidth = getOuterWidth$1(this.$el) + "px";
        absolutePosition$1(this.overlay, this.$el);
      }
    }, "alignOverlay"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener() {
      var _this5 = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          if (_this5.overlayVisible && _this5.overlay && !_this5.$el.contains(event.target) && !_this5.overlay.contains(event.target)) {
            _this5.hide();
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener2() {
      var _this6 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.$refs.container, function() {
          if (_this6.overlayVisible) {
            _this6.hide();
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener2() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener2() {
      var _this7 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this7.overlayVisible && !isTouchDevice$1()) {
            _this7.hide();
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener2() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    bindLabelClickListener: /* @__PURE__ */ __name(function bindLabelClickListener() {
      var _this8 = this;
      if (!this.editable && !this.labelClickListener) {
        var label8 = document.querySelector('label[for="'.concat(this.labelId, '"]'));
        if (label8 && isVisible$1(label8)) {
          this.labelClickListener = function() {
            focus$2(_this8.$refs.focusInput);
          };
          label8.addEventListener("click", this.labelClickListener);
        }
      }
    }, "bindLabelClickListener"),
    unbindLabelClickListener: /* @__PURE__ */ __name(function unbindLabelClickListener() {
      if (this.labelClickListener) {
        var label8 = document.querySelector('label[for="'.concat(this.labelId, '"]'));
        if (label8 && isVisible$1(label8)) {
          label8.removeEventListener("click", this.labelClickListener);
        }
      }
    }, "unbindLabelClickListener"),
    hasFocusableElements: /* @__PURE__ */ __name(function hasFocusableElements() {
      return getFocusableElements$1(this.overlay, ':not([data-p-hidden-focusable="true"])').length > 0;
    }, "hasFocusableElements"),
    isOptionMatched: /* @__PURE__ */ __name(function isOptionMatched2(option5) {
      var _this$getOptionLabel;
      return this.isValidOption(option5) && typeof this.getOptionLabel(option5) === "string" && ((_this$getOptionLabel = this.getOptionLabel(option5)) === null || _this$getOptionLabel === void 0 ? void 0 : _this$getOptionLabel.toLocaleLowerCase(this.filterLocale).startsWith(this.searchValue.toLocaleLowerCase(this.filterLocale)));
    }, "isOptionMatched"),
    isValidOption: /* @__PURE__ */ __name(function isValidOption2(option5) {
      return isNotEmpty$2(option5) && !(this.isOptionDisabled(option5) || this.isOptionGroup(option5));
    }, "isValidOption"),
    isValidSelectedOption: /* @__PURE__ */ __name(function isValidSelectedOption2(option5) {
      return this.isValidOption(option5) && this.isSelected(option5);
    }, "isValidSelectedOption"),
    isSelected: /* @__PURE__ */ __name(function isSelected2(option5) {
      return equals$2(this.d_value, this.getOptionValue(option5), this.equalityKey);
    }, "isSelected"),
    findFirstOptionIndex: /* @__PURE__ */ __name(function findFirstOptionIndex2() {
      var _this9 = this;
      return this.visibleOptions.findIndex(function(option5) {
        return _this9.isValidOption(option5);
      });
    }, "findFirstOptionIndex"),
    findLastOptionIndex: /* @__PURE__ */ __name(function findLastOptionIndex2() {
      var _this10 = this;
      return findLastIndex$2(this.visibleOptions, function(option5) {
        return _this10.isValidOption(option5);
      });
    }, "findLastOptionIndex"),
    findNextOptionIndex: /* @__PURE__ */ __name(function findNextOptionIndex2(index2) {
      var _this11 = this;
      var matchedOptionIndex = index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this11.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : index2;
    }, "findNextOptionIndex"),
    findPrevOptionIndex: /* @__PURE__ */ __name(function findPrevOptionIndex2(index2) {
      var _this12 = this;
      var matchedOptionIndex = index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this12.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findPrevOptionIndex"),
    findSelectedOptionIndex: /* @__PURE__ */ __name(function findSelectedOptionIndex2() {
      var _this13 = this;
      return this.$filled ? this.visibleOptions.findIndex(function(option5) {
        return _this13.isValidSelectedOption(option5);
      }) : -1;
    }, "findSelectedOptionIndex"),
    findFirstFocusedOptionIndex: /* @__PURE__ */ __name(function findFirstFocusedOptionIndex2() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findFirstOptionIndex() : selectedIndex;
    }, "findFirstFocusedOptionIndex"),
    findLastFocusedOptionIndex: /* @__PURE__ */ __name(function findLastFocusedOptionIndex2() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findLastOptionIndex() : selectedIndex;
    }, "findLastFocusedOptionIndex"),
    searchOptions: /* @__PURE__ */ __name(function searchOptions2(event, _char) {
      var _this14 = this;
      this.searchValue = (this.searchValue || "") + _char;
      var optionIndex = -1;
      var matched = false;
      if (isNotEmpty$2(this.searchValue)) {
        if (this.focusedOptionIndex !== -1) {
          optionIndex = this.visibleOptions.slice(this.focusedOptionIndex).findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          });
          optionIndex = optionIndex === -1 ? this.visibleOptions.slice(0, this.focusedOptionIndex).findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          }) : optionIndex + this.focusedOptionIndex;
        } else {
          optionIndex = this.visibleOptions.findIndex(function(option5) {
            return _this14.isOptionMatched(option5);
          });
        }
        if (optionIndex !== -1) {
          matched = true;
        }
        if (optionIndex === -1 && this.focusedOptionIndex === -1) {
          optionIndex = this.findFirstFocusedOptionIndex();
        }
        if (optionIndex !== -1) {
          this.changeFocusedOptionIndex(event, optionIndex);
        }
      }
      if (this.searchTimeout) {
        clearTimeout(this.searchTimeout);
      }
      this.searchTimeout = setTimeout(function() {
        _this14.searchValue = "";
        _this14.searchTimeout = null;
      }, 500);
      return matched;
    }, "searchOptions"),
    changeFocusedOptionIndex: /* @__PURE__ */ __name(function changeFocusedOptionIndex2(event, index2) {
      if (this.focusedOptionIndex !== index2) {
        this.focusedOptionIndex = index2;
        this.scrollInView();
        if (this.selectOnFocus) {
          this.onOptionSelect(event, this.visibleOptions[index2], false);
        }
      }
    }, "changeFocusedOptionIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView5() {
      var _this15 = this;
      var index2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : -1;
      this.$nextTick(function() {
        var id4 = index2 !== -1 ? "".concat(_this15.id, "_").concat(index2) : _this15.focusedOptionId;
        var element = findSingle$1(_this15.list, 'li[id="'.concat(id4, '"]'));
        if (element) {
          element.scrollIntoView && element.scrollIntoView({
            block: "nearest",
            inline: "start"
          });
        } else if (!_this15.virtualScrollerDisabled) {
          _this15.virtualScroller && _this15.virtualScroller.scrollToIndex(index2 !== -1 ? index2 : _this15.focusedOptionIndex);
        }
      });
    }, "scrollInView"),
    autoUpdateModel: /* @__PURE__ */ __name(function autoUpdateModel2() {
      if (this.selectOnFocus && this.autoOptionFocus && !this.$filled) {
        this.focusedOptionIndex = this.findFirstFocusedOptionIndex();
        this.onOptionSelect(null, this.visibleOptions[this.focusedOptionIndex], false);
      }
    }, "autoUpdateModel"),
    updateModel: /* @__PURE__ */ __name(function updateModel2(event, value3) {
      this.writeValue(value3, event);
      this.$emit("change", {
        originalEvent: event,
        value: value3
      });
    }, "updateModel"),
    flatOptions: /* @__PURE__ */ __name(function flatOptions(options5) {
      var _this16 = this;
      return (options5 || []).reduce(function(result, option5, index2) {
        result.push({
          optionGroup: option5,
          group: true,
          index: index2
        });
        var optionGroupChildren = _this16.getOptionGroupChildren(option5);
        optionGroupChildren && optionGroupChildren.forEach(function(o2) {
          return result.push(o2);
        });
        return result;
      }, []);
    }, "flatOptions"),
    overlayRef: /* @__PURE__ */ __name(function overlayRef(el) {
      this.overlay = el;
    }, "overlayRef"),
    listRef: /* @__PURE__ */ __name(function listRef2(el, contentRef3) {
      this.list = el;
      contentRef3 && contentRef3(el);
    }, "listRef"),
    virtualScrollerRef: /* @__PURE__ */ __name(function virtualScrollerRef2(el) {
      this.virtualScroller = el;
    }, "virtualScrollerRef")
  },
  computed: {
    visibleOptions: /* @__PURE__ */ __name(function visibleOptions2() {
      var _this17 = this;
      var options5 = this.optionGroupLabel ? this.flatOptions(this.options) : this.options || [];
      if (this.filterValue) {
        var filteredOptions = FilterService.filter(options5, this.searchFields, this.filterValue, this.filterMatchMode, this.filterLocale);
        if (this.optionGroupLabel) {
          var optionGroups = this.options || [];
          var filtered = [];
          optionGroups.forEach(function(group) {
            var groupChildren = _this17.getOptionGroupChildren(group);
            var filteredItems = groupChildren.filter(function(item3) {
              return filteredOptions.includes(item3);
            });
            if (filteredItems.length > 0) filtered.push(_objectSpread$b(_objectSpread$b({}, group), {}, _defineProperty$9({}, typeof _this17.optionGroupChildren === "string" ? _this17.optionGroupChildren : "items", _toConsumableArray$9(filteredItems))));
          });
          return this.flatOptions(filtered);
        }
        return filteredOptions;
      }
      return options5;
    }, "visibleOptions"),
    // @deprecated use $filled instead
    hasSelectedOption: /* @__PURE__ */ __name(function hasSelectedOption2() {
      return this.$filled;
    }, "hasSelectedOption"),
    label: /* @__PURE__ */ __name(function label2() {
      var selectedOptionIndex = this.findSelectedOptionIndex();
      return selectedOptionIndex !== -1 ? this.getOptionLabel(this.visibleOptions[selectedOptionIndex]) : this.placeholder || "p-emptylabel";
    }, "label"),
    editableInputValue: /* @__PURE__ */ __name(function editableInputValue() {
      var selectedOptionIndex = this.findSelectedOptionIndex();
      return selectedOptionIndex !== -1 ? this.getOptionLabel(this.visibleOptions[selectedOptionIndex]) : this.d_value || "";
    }, "editableInputValue"),
    equalityKey: /* @__PURE__ */ __name(function equalityKey2() {
      return this.optionValue ? null : this.dataKey;
    }, "equalityKey"),
    searchFields: /* @__PURE__ */ __name(function searchFields2() {
      return this.filterFields || [this.optionLabel];
    }, "searchFields"),
    filterResultMessageText: /* @__PURE__ */ __name(function filterResultMessageText2() {
      return isNotEmpty$2(this.visibleOptions) ? this.filterMessageText.replaceAll("{0}", this.visibleOptions.length) : this.emptyFilterMessageText;
    }, "filterResultMessageText"),
    filterMessageText: /* @__PURE__ */ __name(function filterMessageText2() {
      return this.filterMessage || this.$primevue.config.locale.searchMessage || "";
    }, "filterMessageText"),
    emptyFilterMessageText: /* @__PURE__ */ __name(function emptyFilterMessageText2() {
      return this.emptyFilterMessage || this.$primevue.config.locale.emptySearchMessage || this.$primevue.config.locale.emptyFilterMessage || "";
    }, "emptyFilterMessageText"),
    emptyMessageText: /* @__PURE__ */ __name(function emptyMessageText2() {
      return this.emptyMessage || this.$primevue.config.locale.emptyMessage || "";
    }, "emptyMessageText"),
    selectionMessageText: /* @__PURE__ */ __name(function selectionMessageText2() {
      return this.selectionMessage || this.$primevue.config.locale.selectionMessage || "";
    }, "selectionMessageText"),
    emptySelectionMessageText: /* @__PURE__ */ __name(function emptySelectionMessageText2() {
      return this.emptySelectionMessage || this.$primevue.config.locale.emptySelectionMessage || "";
    }, "emptySelectionMessageText"),
    selectedMessageText: /* @__PURE__ */ __name(function selectedMessageText2() {
      return this.$filled ? this.selectionMessageText.replaceAll("{0}", "1") : this.emptySelectionMessageText;
    }, "selectedMessageText"),
    focusedOptionId: /* @__PURE__ */ __name(function focusedOptionId2() {
      return this.focusedOptionIndex !== -1 ? "".concat(this.id, "_").concat(this.focusedOptionIndex) : null;
    }, "focusedOptionId"),
    ariaSetSize: /* @__PURE__ */ __name(function ariaSetSize2() {
      var _this18 = this;
      return this.visibleOptions.filter(function(option5) {
        return !_this18.isOptionGroup(option5);
      }).length;
    }, "ariaSetSize"),
    isClearIconVisible: /* @__PURE__ */ __name(function isClearIconVisible() {
      return this.showClear && this.d_value != null && isNotEmpty$2(this.options);
    }, "isClearIconVisible"),
    virtualScrollerDisabled: /* @__PURE__ */ __name(function virtualScrollerDisabled2() {
      return !this.virtualScrollerOptions;
    }, "virtualScrollerDisabled")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    InputText: script$P,
    VirtualScroller: script$H,
    Portal: script$$,
    InputIcon: script$I,
    IconField: script$J,
    TimesIcon: script$15,
    ChevronDownIcon: script$u,
    SpinnerIcon: script$12,
    SearchIcon: script$K,
    CheckIcon: script$S,
    BlankIcon: script$L
  }
};
var _hoisted_1$1j = ["id"];
var _hoisted_2$Y = ["id", "value", "placeholder", "tabindex", "disabled", "aria-label", "aria-labelledby", "aria-expanded", "aria-controls", "aria-activedescendant", "aria-invalid"];
var _hoisted_3$G = ["id", "tabindex", "aria-label", "aria-labelledby", "aria-expanded", "aria-controls", "aria-activedescendant", "aria-disabled"];
var _hoisted_4$t = ["id"];
var _hoisted_5$n = ["id"];
var _hoisted_6$h = ["id", "aria-label", "aria-selected", "aria-disabled", "aria-setsize", "aria-posinset", "onClick", "onMousemove", "data-p-selected", "data-p-focused", "data-p-disabled"];
function render$r(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_InputText = resolveComponent("InputText");
  var _component_SearchIcon = resolveComponent("SearchIcon");
  var _component_InputIcon = resolveComponent("InputIcon");
  var _component_IconField = resolveComponent("IconField");
  var _component_CheckIcon = resolveComponent("CheckIcon");
  var _component_BlankIcon = resolveComponent("BlankIcon");
  var _component_VirtualScroller = resolveComponent("VirtualScroller");
  var _component_Portal = resolveComponent("Portal");
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "container",
    id: $data.id,
    "class": _ctx.cx("root"),
    onClick: _cache[11] || (_cache[11] = function() {
      return $options.onContainerClick && $options.onContainerClick.apply($options, arguments);
    })
  }, _ctx.ptmi("root")), [_ctx.editable ? (openBlock(), createElementBlock("input", mergeProps$2({
    key: 0,
    ref: "focusInput",
    id: _ctx.labelId || _ctx.inputId,
    type: "text",
    "class": [_ctx.cx("label"), _ctx.inputClass, _ctx.labelClass],
    style: [_ctx.inputStyle, _ctx.labelStyle],
    value: $options.editableInputValue,
    placeholder: _ctx.placeholder,
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    disabled: _ctx.disabled,
    autocomplete: "off",
    role: "combobox",
    "aria-label": _ctx.ariaLabel,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-haspopup": "listbox",
    "aria-expanded": $data.overlayVisible,
    "aria-controls": $data.id + "_list",
    "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
    "aria-invalid": _ctx.invalid || void 0,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onKeydown: _cache[2] || (_cache[2] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    }),
    onInput: _cache[3] || (_cache[3] = function() {
      return $options.onEditableInput && $options.onEditableInput.apply($options, arguments);
    })
  }, _ctx.ptm("label")), null, 16, _hoisted_2$Y)) : (openBlock(), createElementBlock("span", mergeProps$2({
    key: 1,
    ref: "focusInput",
    id: _ctx.labelId || _ctx.inputId,
    "class": [_ctx.cx("label"), _ctx.inputClass, _ctx.labelClass],
    style: [_ctx.inputStyle, _ctx.labelStyle],
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    role: "combobox",
    "aria-label": _ctx.ariaLabel || ($options.label === "p-emptylabel" ? void 0 : $options.label),
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-haspopup": "listbox",
    "aria-expanded": $data.overlayVisible,
    "aria-controls": $data.id + "_list",
    "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
    "aria-disabled": _ctx.disabled,
    onFocus: _cache[4] || (_cache[4] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[5] || (_cache[5] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onKeydown: _cache[6] || (_cache[6] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    })
  }, _ctx.ptm("label")), [renderSlot(_ctx.$slots, "value", {
    value: _ctx.d_value,
    placeholder: _ctx.placeholder
  }, function() {
    var _$options$label;
    return [createTextVNode(toDisplayString$1($options.label === "p-emptylabel" ? " " : (_$options$label = $options.label) !== null && _$options$label !== void 0 ? _$options$label : "empty"), 1)];
  })], 16, _hoisted_3$G)), $options.isClearIconVisible ? renderSlot(_ctx.$slots, "clearicon", {
    key: 2,
    "class": normalizeClass(_ctx.cx("clearIcon")),
    clearCallback: $options.onClearClick
  }, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.clearIcon ? "i" : "TimesIcon"), mergeProps$2({
      ref: "clearIcon",
      "class": [_ctx.cx("clearIcon"), _ctx.clearIcon],
      onClick: $options.onClearClick
    }, _ctx.ptm("clearIcon"), {
      "data-pc-section": "clearicon"
    }), null, 16, ["class", "onClick"]))];
  }) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("dropdown")
  }, _ctx.ptm("dropdown")), [_ctx.loading ? renderSlot(_ctx.$slots, "loadingicon", {
    key: 0,
    "class": normalizeClass(_ctx.cx("loadingIcon"))
  }, function() {
    return [_ctx.loadingIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 0,
      "class": [_ctx.cx("loadingIcon"), "pi-spin", _ctx.loadingIcon],
      "aria-hidden": "true"
    }, _ctx.ptm("loadingIcon")), null, 16)) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
      key: 1,
      "class": _ctx.cx("loadingIcon"),
      spin: "",
      "aria-hidden": "true"
    }, _ctx.ptm("loadingIcon")), null, 16, ["class"]))];
  }) : renderSlot(_ctx.$slots, "dropdownicon", {
    key: 1,
    "class": normalizeClass(_ctx.cx("dropdownIcon"))
  }, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.dropdownIcon ? "span" : "ChevronDownIcon"), mergeProps$2({
      "class": [_ctx.cx("dropdownIcon"), _ctx.dropdownIcon],
      "aria-hidden": "true"
    }, _ctx.ptm("dropdownIcon")), null, 16, ["class"]))];
  })], 16), createVNode(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-connected-overlay",
        onEnter: $options.onOverlayEnter,
        onAfterEnter: $options.onOverlayAfterEnter,
        onLeave: $options.onOverlayLeave,
        onAfterLeave: $options.onOverlayAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [$data.overlayVisible ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.overlayRef,
            "class": [_ctx.cx("overlay"), _ctx.panelClass, _ctx.overlayClass],
            style: [_ctx.panelStyle, _ctx.overlayStyle],
            onClick: _cache[9] || (_cache[9] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            }),
            onKeydown: _cache[10] || (_cache[10] = function() {
              return $options.onOverlayKeyDown && $options.onOverlayKeyDown.apply($options, arguments);
            })
          }, _ctx.ptm("overlay")), [createBaseVNode("span", mergeProps$2({
            ref: "firstHiddenFocusableElementOnOverlay",
            role: "presentation",
            "aria-hidden": "true",
            "class": "p-hidden-accessible p-hidden-focusable",
            tabindex: 0,
            onFocus: _cache[7] || (_cache[7] = function() {
              return $options.onFirstHiddenFocus && $options.onFirstHiddenFocus.apply($options, arguments);
            })
          }, _ctx.ptm("hiddenFirstFocusableEl"), {
            "data-p-hidden-accessible": true,
            "data-p-hidden-focusable": true
          }), null, 16), renderSlot(_ctx.$slots, "header", {
            value: _ctx.d_value,
            options: $options.visibleOptions
          }), _ctx.filter ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            "class": _ctx.cx("header")
          }, _ctx.ptm("header")), [createVNode(_component_IconField, {
            unstyled: _ctx.unstyled,
            pt: _ctx.ptm("pcFilterContainer")
          }, {
            "default": withCtx(function() {
              return [createVNode(_component_InputText, {
                ref: "filterInput",
                type: "text",
                value: $data.filterValue,
                onVnodeMounted: $options.onFilterUpdated,
                onVnodeUpdated: $options.onFilterUpdated,
                "class": normalizeClass(_ctx.cx("pcFilter")),
                placeholder: _ctx.filterPlaceholder,
                variant: _ctx.variant,
                unstyled: _ctx.unstyled,
                role: "searchbox",
                autocomplete: "off",
                "aria-owns": $data.id + "_list",
                "aria-activedescendant": $options.focusedOptionId,
                onKeydown: $options.onFilterKeyDown,
                onBlur: $options.onFilterBlur,
                onInput: $options.onFilterChange,
                pt: _ctx.ptm("pcFilter")
              }, null, 8, ["value", "onVnodeMounted", "onVnodeUpdated", "class", "placeholder", "variant", "unstyled", "aria-owns", "aria-activedescendant", "onKeydown", "onBlur", "onInput", "pt"]), createVNode(_component_InputIcon, {
                unstyled: _ctx.unstyled,
                pt: _ctx.ptm("pcFilterIconContainer")
              }, {
                "default": withCtx(function() {
                  return [renderSlot(_ctx.$slots, "filtericon", {}, function() {
                    return [_ctx.filterIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
                      key: 0,
                      "class": _ctx.filterIcon
                    }, _ctx.ptm("filterIcon")), null, 16)) : (openBlock(), createBlock(_component_SearchIcon, normalizeProps(mergeProps$2({
                      key: 1
                    }, _ctx.ptm("filterIcon"))), null, 16))];
                  })];
                }),
                _: 3
              }, 8, ["unstyled", "pt"])];
            }),
            _: 3
          }, 8, ["unstyled", "pt"]), createBaseVNode("span", mergeProps$2({
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenFilterResult"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.filterResultMessageText), 17)], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("listContainer"),
            style: {
              "max-height": $options.virtualScrollerDisabled ? _ctx.scrollHeight : ""
            }
          }, _ctx.ptm("listContainer")), [createVNode(_component_VirtualScroller, mergeProps$2({
            ref: $options.virtualScrollerRef
          }, _ctx.virtualScrollerOptions, {
            items: $options.visibleOptions,
            style: {
              height: _ctx.scrollHeight
            },
            tabindex: -1,
            disabled: $options.virtualScrollerDisabled,
            pt: _ctx.ptm("virtualScroller")
          }), createSlots({
            content: withCtx(function(_ref) {
              var styleClass = _ref.styleClass, contentRef3 = _ref.contentRef, items2 = _ref.items, getItemOptions = _ref.getItemOptions, contentStyle = _ref.contentStyle, itemSize2 = _ref.itemSize;
              return [createBaseVNode("ul", mergeProps$2({
                ref: /* @__PURE__ */ __name(function ref2(el) {
                  return $options.listRef(el, contentRef3);
                }, "ref"),
                id: $data.id + "_list",
                "class": [_ctx.cx("list"), styleClass],
                style: contentStyle,
                role: "listbox"
              }, _ctx.ptm("list")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(items2, function(option5, i2) {
                return openBlock(), createElementBlock(Fragment$1, {
                  key: $options.getOptionRenderKey(option5, $options.getOptionIndex(i2, getItemOptions))
                }, [$options.isOptionGroup(option5) ? (openBlock(), createElementBlock("li", mergeProps$2({
                  key: 0,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  "class": _ctx.cx("optionGroup"),
                  role: "option",
                  ref_for: true
                }, _ctx.ptm("optionGroup")), [renderSlot(_ctx.$slots, "optiongroup", {
                  option: option5.optionGroup,
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createBaseVNode("span", mergeProps$2({
                    "class": _ctx.cx("optionGroupLabel"),
                    ref_for: true
                  }, _ctx.ptm("optionGroupLabel")), toDisplayString$1($options.getOptionGroupLabel(option5.optionGroup)), 17)];
                })], 16, _hoisted_5$n)) : withDirectives((openBlock(), createElementBlock("li", mergeProps$2({
                  key: 1,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  "class": _ctx.cx("option", {
                    option: option5,
                    focusedOption: $options.getOptionIndex(i2, getItemOptions)
                  }),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  role: "option",
                  "aria-label": $options.getOptionLabel(option5),
                  "aria-selected": $options.isSelected(option5),
                  "aria-disabled": $options.isOptionDisabled(option5),
                  "aria-setsize": $options.ariaSetSize,
                  "aria-posinset": $options.getAriaPosInset($options.getOptionIndex(i2, getItemOptions)),
                  onClick: /* @__PURE__ */ __name(function onClick5($event) {
                    return $options.onOptionSelect($event, option5);
                  }, "onClick"),
                  onMousemove: /* @__PURE__ */ __name(function onMousemove($event) {
                    return $options.onOptionMouseMove($event, $options.getOptionIndex(i2, getItemOptions));
                  }, "onMousemove"),
                  "data-p-selected": $options.isSelected(option5),
                  "data-p-focused": $data.focusedOptionIndex === $options.getOptionIndex(i2, getItemOptions),
                  "data-p-disabled": $options.isOptionDisabled(option5),
                  ref_for: true
                }, $options.getPTItemOptions(option5, getItemOptions, i2, "option")), [_ctx.checkmark ? (openBlock(), createElementBlock(Fragment$1, {
                  key: 0
                }, [$options.isSelected(option5) ? (openBlock(), createBlock(_component_CheckIcon, mergeProps$2({
                  key: 0,
                  "class": _ctx.cx("optionCheckIcon"),
                  ref_for: true
                }, _ctx.ptm("optionCheckIcon")), null, 16, ["class"])) : (openBlock(), createBlock(_component_BlankIcon, mergeProps$2({
                  key: 1,
                  "class": _ctx.cx("optionBlankIcon"),
                  ref_for: true
                }, _ctx.ptm("optionBlankIcon")), null, 16, ["class"]))], 64)) : createCommentVNode("", true), renderSlot(_ctx.$slots, "option", {
                  option: option5,
                  selected: $options.isSelected(option5),
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createBaseVNode("span", mergeProps$2({
                    "class": _ctx.cx("optionLabel"),
                    ref_for: true
                  }, _ctx.ptm("optionLabel")), toDisplayString$1($options.getOptionLabel(option5)), 17)];
                })], 16, _hoisted_6$h)), [[_directive_ripple]])], 64);
              }), 128)), $data.filterValue && (!items2 || items2 && items2.length === 0) ? (openBlock(), createElementBlock("li", mergeProps$2({
                key: 0,
                "class": _ctx.cx("emptyMessage"),
                role: "option"
              }, _ctx.ptm("emptyMessage"), {
                "data-p-hidden-accessible": true
              }), [renderSlot(_ctx.$slots, "emptyfilter", {}, function() {
                return [createTextVNode(toDisplayString$1($options.emptyFilterMessageText), 1)];
              })], 16)) : !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("li", mergeProps$2({
                key: 1,
                "class": _ctx.cx("emptyMessage"),
                role: "option"
              }, _ctx.ptm("emptyMessage"), {
                "data-p-hidden-accessible": true
              }), [renderSlot(_ctx.$slots, "empty", {}, function() {
                return [createTextVNode(toDisplayString$1($options.emptyMessageText), 1)];
              })], 16)) : createCommentVNode("", true)], 16, _hoisted_4$t)];
            }),
            _: 2
          }, [_ctx.$slots.loader ? {
            name: "loader",
            fn: withCtx(function(_ref2) {
              var options5 = _ref2.options;
              return [renderSlot(_ctx.$slots, "loader", {
                options: options5
              })];
            }),
            key: "0"
          } : void 0]), 1040, ["items", "style", "disabled", "pt"])], 16), renderSlot(_ctx.$slots, "footer", {
            value: _ctx.d_value,
            options: $options.visibleOptions
          }), !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("span", mergeProps$2({
            key: 1,
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenEmptyMessage"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.emptyMessageText), 17)) : createCommentVNode("", true), createBaseVNode("span", mergeProps$2({
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenSelectedMessage"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.selectedMessageText), 17), createBaseVNode("span", mergeProps$2({
            ref: "lastHiddenFocusableElementOnOverlay",
            role: "presentation",
            "aria-hidden": "true",
            "class": "p-hidden-accessible p-hidden-focusable",
            tabindex: 0,
            onFocus: _cache[8] || (_cache[8] = function() {
              return $options.onLastHiddenFocus && $options.onLastHiddenFocus.apply($options, arguments);
            })
          }, _ctx.ptm("hiddenLastFocusableEl"), {
            "data-p-hidden-accessible": true,
            "data-p-hidden-focusable": true
          }), null, 16)], 16)) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onAfterEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 3
  }, 8, ["appendTo"])], 16, _hoisted_1$1j);
}
__name(render$r, "render$r");
script$t.render = render$r;
const id$5 = "arc";
const name$5 = "Arc";
const colors$5 = {
  node_slot: {
    BOOLEAN: "",
    CLIP: "#eacb8b",
    CLIP_VISION: "#A8DADC",
    CLIP_VISION_OUTPUT: "#ad7452",
    CONDITIONING: "#cf876f",
    CONTROL_NET: "#00d78d",
    CONTROL_NET_WEIGHTS: "",
    FLOAT: "",
    GLIGEN: "",
    IMAGE: "#80a1c0",
    IMAGEUPLOAD: "",
    INT: "",
    LATENT: "#b38ead",
    LATENT_KEYFRAME: "",
    MASK: "#a3bd8d",
    MODEL: "#8978a7",
    SAMPLER: "",
    SIGMAS: "",
    STRING: "",
    STYLE_MODEL: "#C2FFAE",
    T2I_ADAPTER_WEIGHTS: "",
    TAESD: "#DCC274",
    TIMESTEP_KEYFRAME: "",
    UPSCALE_MODEL: "",
    VAE: "#be616b"
  },
  litegraph_base: {
    BACKGROUND_IMAGE: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGQAAABkCAYAAABw4pVUAAAACXBIWXMAAAsTAAALEwEAmpwYAAABcklEQVR4nO3YMUoDARgF4RfxBqZI6/0vZqFn0MYtrLIQMFN8U6V4LAtD+Jm9XG/v30OGl2e/AP7yevz4+vx45nvgF/+QGITEICQGITEIiUFIjNNC3q43u3/YnRJyPOzeQ+0e220nhRzReC8e7R7bbdvl+Jal1Bs46jEIiUFIDEJiEBKDkBhKPbZT6qHdptRTu02p53DUYxASg5AYhMQgJAYhMZR6bKfUQ7tNqad2m1LP4ajHICQGITEIiUFIDEJiKPXYTqmHdptST+02pZ7DUY9BSAxCYhASg5AYhMRQ6rGdUg/tNqWe2m1KPYejHoOQGITEICQGITEIiaHUYzulHtptSj2125R6Dkc9BiExCIlBSAxCYhASQ6nHdko9tNuUemq3KfUcjnoMQmIQEoOQGITEICSGUo/tlHpotyn11G5T6jkc9RiExCAkBiExCIlBSAylHtsp9dBuU+qp3abUczjqMQiJQUgMQmIQEoOQGITE+AHFISNQrFTGuwAAAABJRU5ErkJggg==",
    CLEAR_BACKGROUND_COLOR: "#2b2f38",
    NODE_TITLE_COLOR: "#b2b7bd",
    NODE_SELECTED_TITLE_COLOR: "#FFF",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#AAA",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#2b2f38",
    NODE_DEFAULT_BGCOLOR: "#242730",
    NODE_DEFAULT_BOXCOLOR: "#6e7581",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#FFF",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.5)",
    DEFAULT_GROUP_FONT: 22,
    WIDGET_BGCOLOR: "#2b2f38",
    WIDGET_OUTLINE_COLOR: "#6e7581",
    WIDGET_TEXT_COLOR: "#DDD",
    WIDGET_SECONDARY_TEXT_COLOR: "#b2b7bd",
    LINK_COLOR: "#9A9",
    EVENT_LINK_COLOR: "#A86",
    CONNECTING_LINK_COLOR: "#AFA"
  },
  comfy_base: {
    "fg-color": "#fff",
    "bg-color": "#2b2f38",
    "comfy-menu-bg": "#242730",
    "comfy-menu-secondary-bg": "#22252E",
    "comfy-input-bg": "#2b2f38",
    "input-text": "#ddd",
    "descrip-text": "#b2b7bd",
    "drag-text": "#ccc",
    "error-text": "#ff4444",
    "border-color": "#6e7581",
    "tr-even-bg-color": "#2b2f38",
    "tr-odd-bg-color": "#242730",
    "content-bg": "#6e7581",
    "content-fg": "#fff",
    "content-hover-bg": "#2b2f38",
    "content-hover-fg": "#fff",
    "bar-shadow": "rgba(8, 8, 8, 0.75) 0 0 0.5rem"
  }
};
const arc = {
  id: id$5,
  name: name$5,
  colors: colors$5
};
const id$4 = "dark";
const name$4 = "Dark (Default)";
const colors$4 = {
  node_slot: {
    CLIP: "#FFD500",
    CLIP_VISION: "#A8DADC",
    CLIP_VISION_OUTPUT: "#ad7452",
    CONDITIONING: "#FFA931",
    CONTROL_NET: "#6EE7B7",
    IMAGE: "#64B5F6",
    LATENT: "#FF9CF9",
    MASK: "#81C784",
    MODEL: "#B39DDB",
    STYLE_MODEL: "#C2FFAE",
    VAE: "#FF6E6E",
    NOISE: "#B0B0B0",
    GUIDER: "#66FFFF",
    SAMPLER: "#ECB4B4",
    SIGMAS: "#CDFFCD",
    TAESD: "#DCC274"
  },
  litegraph_base: {
    BACKGROUND_IMAGE: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGQAAABkCAIAAAD/gAIDAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAQBJREFUeNrs1rEKwjAUhlETUkj3vP9rdmr1Ysammk2w5wdxuLgcMHyptfawuZX4pJSWZTnfnu/lnIe/jNNxHHGNn//HNbbv+4dr6V+11uF527arU7+u63qfa/bnmh8sWLBgwYJlqRf8MEptXPBXJXa37BSl3ixYsGDBMliwFLyCV/DeLIMFCxYsWLBMwSt4Be/NggXLYMGCBUvBK3iNruC9WbBgwYJlsGApeAWv4L1ZBgsWLFiwYJmCV/AK3psFC5bBggULloJX8BpdwXuzYMGCBctgwVLwCl7Be7MMFixYsGDBsu8FH1FaSmExVfAxBa/gvVmwYMGCZbBg/W4vAQYA5tRF9QYlv/QAAAAASUVORK5CYII=",
    CLEAR_BACKGROUND_COLOR: "#222",
    NODE_TITLE_COLOR: "#999",
    NODE_SELECTED_TITLE_COLOR: "#FFF",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#AAA",
    NODE_TEXT_HIGHLIGHT_COLOR: "#FFF",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#333",
    NODE_DEFAULT_BGCOLOR: "#353535",
    NODE_DEFAULT_BOXCOLOR: "#666",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#FFF",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.5)",
    DEFAULT_GROUP_FONT: 24,
    WIDGET_BGCOLOR: "#222",
    WIDGET_OUTLINE_COLOR: "#666",
    WIDGET_TEXT_COLOR: "#DDD",
    WIDGET_SECONDARY_TEXT_COLOR: "#999",
    LINK_COLOR: "#9A9",
    EVENT_LINK_COLOR: "#A86",
    CONNECTING_LINK_COLOR: "#AFA",
    BADGE_FG_COLOR: "#FFF",
    BADGE_BG_COLOR: "#0F1F0F"
  },
  comfy_base: {
    "fg-color": "#fff",
    "bg-color": "#202020",
    "comfy-menu-bg": "#353535",
    "comfy-menu-secondary-bg": "#303030",
    "comfy-input-bg": "#222",
    "input-text": "#ddd",
    "descrip-text": "#999",
    "drag-text": "#ccc",
    "error-text": "#ff4444",
    "border-color": "#4e4e4e",
    "tr-even-bg-color": "#222",
    "tr-odd-bg-color": "#353535",
    "content-bg": "#4e4e4e",
    "content-fg": "#fff",
    "content-hover-bg": "#222",
    "content-hover-fg": "#fff",
    "bar-shadow": "rgba(16, 16, 16, 0.5) 0 0 0.5rem"
  }
};
const dark = {
  id: id$4,
  name: name$4,
  colors: colors$4
};
const id$3 = "github";
const name$3 = "Github";
const colors$3 = {
  node_slot: {
    BOOLEAN: "",
    CLIP: "#eacb8b",
    CLIP_VISION: "#A8DADC",
    CLIP_VISION_OUTPUT: "#ad7452",
    CONDITIONING: "#cf876f",
    CONTROL_NET: "#00d78d",
    CONTROL_NET_WEIGHTS: "",
    FLOAT: "",
    GLIGEN: "",
    IMAGE: "#80a1c0",
    IMAGEUPLOAD: "",
    INT: "",
    LATENT: "#b38ead",
    LATENT_KEYFRAME: "",
    MASK: "#a3bd8d",
    MODEL: "#8978a7",
    SAMPLER: "",
    SIGMAS: "",
    STRING: "",
    STYLE_MODEL: "#C2FFAE",
    T2I_ADAPTER_WEIGHTS: "",
    TAESD: "#DCC274",
    TIMESTEP_KEYFRAME: "",
    UPSCALE_MODEL: "",
    VAE: "#be616b"
  },
  litegraph_base: {
    BACKGROUND_IMAGE: "data:image/png;base64,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",
    CLEAR_BACKGROUND_COLOR: "#040506",
    NODE_TITLE_COLOR: "#999",
    NODE_SELECTED_TITLE_COLOR: "#e5eaf0",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#bcc2c8",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#161b22",
    NODE_DEFAULT_BGCOLOR: "#13171d",
    NODE_DEFAULT_BOXCOLOR: "#30363d",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#e5eaf0",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.5)",
    DEFAULT_GROUP_FONT: 24,
    WIDGET_BGCOLOR: "#161b22",
    WIDGET_OUTLINE_COLOR: "#30363d",
    WIDGET_TEXT_COLOR: "#bcc2c8",
    WIDGET_SECONDARY_TEXT_COLOR: "#999",
    LINK_COLOR: "#9A9",
    EVENT_LINK_COLOR: "#A86",
    CONNECTING_LINK_COLOR: "#AFA"
  },
  comfy_base: {
    "fg-color": "#e5eaf0",
    "bg-color": "#161b22",
    "comfy-menu-bg": "#13171d",
    "comfy-menu-secondary-bg": "#11141A",
    "comfy-input-bg": "#161b22",
    "input-text": "#bcc2c8",
    "descrip-text": "#999",
    "drag-text": "#ccc",
    "error-text": "#ff4444",
    "border-color": "#30363d",
    "tr-even-bg-color": "#161b22",
    "tr-odd-bg-color": "#13171d",
    "content-bg": "#30363d",
    "content-fg": "#e5eaf0",
    "content-hover-bg": "#161b22",
    "content-hover-fg": "#e5eaf0",
    "bar-shadow": "rgba(0, 0, 0, 1) 0 0 0.5rem"
  }
};
const github = {
  id: id$3,
  name: name$3,
  colors: colors$3
};
const id$2 = "light";
const name$2 = "Light";
const light_theme = true;
const colors$2 = {
  node_slot: {
    CLIP: "#FFA726",
    CLIP_VISION: "#5C6BC0",
    CLIP_VISION_OUTPUT: "#8D6E63",
    CONDITIONING: "#EF5350",
    CONTROL_NET: "#66BB6A",
    IMAGE: "#42A5F5",
    LATENT: "#AB47BC",
    MASK: "#9CCC65",
    MODEL: "#7E57C2",
    STYLE_MODEL: "#D4E157",
    VAE: "#FF7043",
    NOISE: "#B0B0B0",
    GUIDER: "#66FFFF",
    SAMPLER: "#ECB4B4",
    SIGMAS: "#CDFFCD",
    TAESD: "#DCC274"
  },
  litegraph_base: {
    BACKGROUND_IMAGE: "data:image/gif;base64,R0lGODlhZABkALMAAAAAAP///+vr6+rq6ujo6Ofn5+bm5uXl5d3d3f///wAAAAAAAAAAAAAAAAAAAAAAACH5BAEAAAkALAAAAABkAGQAAAT/UMhJq7046827HkcoHkYxjgZhnGG6si5LqnIM0/fL4qwwIMAg0CAsEovBIxKhRDaNy2GUOX0KfVFrssrNdpdaqTeKBX+dZ+jYvEaTf+y4W66mC8PUdrE879f9d2mBeoNLfH+IhYBbhIx2jkiHiomQlGKPl4uZe3CaeZifnnijgkESBqipqqusra6vsLGys62SlZO4t7qbuby7CLa+wqGWxL3Gv3jByMOkjc2lw8vOoNSi0czAncXW3Njdx9Pf48/Z4Kbbx+fQ5evZ4u3k1fKR6cn03vHlp7T9/v8A/8Gbp4+gwXoFryXMB2qgwoMMHyKEqA5fxX322FG8tzBcRnMW/zlulPbRncmQGidKjMjyYsOSKEF2FBlJQMCbOHP6c9iSZs+UnGYCdbnSo1CZI5F64kn0p1KnTH02nSoV3dGTV7FFHVqVq1dtWcMmVQZTbNGu72zqXMuW7danVL+6e4t1bEy6MeueBYLXrNO5Ze36jQtWsOG97wIj1vt3St/DjTEORss4nNq2mDP3e7w4r1bFkSET5hy6s2TRlD2/mSxXtSHQhCunXo26NevCpmvD/UU6tuullzULH76q92zdZG/Ltv1a+W+osI/nRmyc+fRi1Xdbh+68+0vv10dH3+77KD/i6IdnX669/frn5Zsjh4/2PXju8+8bzc9/6fj27LFnX11/+IUnXWl7BJfegm79FyB9JOl3oHgSklefgxAC+FmFGpqHIYcCfkhgfCohSKKJVo044YUMttggiBkmp6KFXw1oII24oYhjiDByaKOOHcp3Y5BD/njikSkO+eBREQAAOw==",
    CLEAR_BACKGROUND_COLOR: "lightgray",
    NODE_TITLE_COLOR: "#222",
    NODE_SELECTED_TITLE_COLOR: "#000",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#444",
    NODE_TEXT_HIGHLIGHT_COLOR: "#1e293b",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#F7F7F7",
    NODE_DEFAULT_BGCOLOR: "#F5F5F5",
    NODE_DEFAULT_BOXCOLOR: "#CCC",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#000",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.1)",
    DEFAULT_GROUP_FONT: 24,
    WIDGET_BGCOLOR: "#D4D4D4",
    WIDGET_OUTLINE_COLOR: "#999",
    WIDGET_TEXT_COLOR: "#222",
    WIDGET_SECONDARY_TEXT_COLOR: "#555",
    LINK_COLOR: "#4CAF50",
    EVENT_LINK_COLOR: "#FF9800",
    CONNECTING_LINK_COLOR: "#2196F3",
    BADGE_FG_COLOR: "#000",
    BADGE_BG_COLOR: "#FFF"
  },
  comfy_base: {
    "fg-color": "#222",
    "bg-color": "#DDD",
    "comfy-menu-bg": "#F5F5F5",
    "comfy-menu-hover-bg": "#ccc",
    "comfy-menu-secondary-bg": "#EEE",
    "comfy-input-bg": "#C9C9C9",
    "input-text": "#222",
    "descrip-text": "#444",
    "drag-text": "#555",
    "error-text": "#F44336",
    "border-color": "#888",
    "tr-even-bg-color": "#f9f9f9",
    "tr-odd-bg-color": "#fff",
    "content-bg": "#e0e0e0",
    "content-fg": "#222",
    "content-hover-bg": "#adadad",
    "content-hover-fg": "#222",
    "bar-shadow": "rgba(16, 16, 16, 0.25) 0 0 0.5rem"
  }
};
const light = {
  id: id$2,
  name: name$2,
  light_theme,
  colors: colors$2
};
const id$1 = "nord";
const name$1 = "Nord";
const colors$1 = {
  node_slot: {
    BOOLEAN: "",
    CLIP: "#eacb8b",
    CLIP_VISION: "#A8DADC",
    CLIP_VISION_OUTPUT: "#ad7452",
    CONDITIONING: "#cf876f",
    CONTROL_NET: "#00d78d",
    CONTROL_NET_WEIGHTS: "",
    FLOAT: "",
    GLIGEN: "",
    IMAGE: "#80a1c0",
    IMAGEUPLOAD: "",
    INT: "",
    LATENT: "#b38ead",
    LATENT_KEYFRAME: "",
    MASK: "#a3bd8d",
    MODEL: "#8978a7",
    SAMPLER: "",
    SIGMAS: "",
    STRING: "",
    STYLE_MODEL: "#C2FFAE",
    T2I_ADAPTER_WEIGHTS: "",
    TAESD: "#DCC274",
    TIMESTEP_KEYFRAME: "",
    UPSCALE_MODEL: "",
    VAE: "#be616b"
  },
  litegraph_base: {
    BACKGROUND_IMAGE: "data:image/png;base64,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",
    CLEAR_BACKGROUND_COLOR: "#212732",
    NODE_TITLE_COLOR: "#999",
    NODE_SELECTED_TITLE_COLOR: "#e5eaf0",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#bcc2c8",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#2e3440",
    NODE_DEFAULT_BGCOLOR: "#161b22",
    NODE_DEFAULT_BOXCOLOR: "#545d70",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#e5eaf0",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.5)",
    DEFAULT_GROUP_FONT: 24,
    WIDGET_BGCOLOR: "#2e3440",
    WIDGET_OUTLINE_COLOR: "#545d70",
    WIDGET_TEXT_COLOR: "#bcc2c8",
    WIDGET_SECONDARY_TEXT_COLOR: "#999",
    LINK_COLOR: "#9A9",
    EVENT_LINK_COLOR: "#A86",
    CONNECTING_LINK_COLOR: "#AFA"
  },
  comfy_base: {
    "fg-color": "#e5eaf0",
    "bg-color": "#2e3440",
    "comfy-menu-bg": "#161b22",
    "comfy-menu-secondary-bg": "#14181F",
    "comfy-input-bg": "#2e3440",
    "input-text": "#bcc2c8",
    "descrip-text": "#999",
    "drag-text": "#ccc",
    "error-text": "#ff4444",
    "border-color": "#545d70",
    "tr-even-bg-color": "#2e3440",
    "tr-odd-bg-color": "#161b22",
    "content-bg": "#545d70",
    "content-fg": "#e5eaf0",
    "content-hover-bg": "#2e3440",
    "content-hover-fg": "#e5eaf0",
    "bar-shadow": "rgba(0, 0, 0, 0.75) 0 0 0.5rem"
  }
};
const nord = {
  id: id$1,
  name: name$1,
  colors: colors$1
};
const id = "solarized";
const name = "Solarized";
const colors = {
  node_slot: {
    CLIP: "#2AB7CA",
    CLIP_VISION: "#6c71c4",
    CLIP_VISION_OUTPUT: "#859900",
    CONDITIONING: "#d33682",
    CONTROL_NET: "#d1ffd7",
    IMAGE: "#5940bb",
    LATENT: "#268bd2",
    MASK: "#CCC9E7",
    MODEL: "#dc322f",
    STYLE_MODEL: "#1a998a",
    UPSCALE_MODEL: "#054A29",
    VAE: "#facfad"
  },
  litegraph_base: {
    NODE_TITLE_COLOR: "#fdf6e3",
    NODE_SELECTED_TITLE_COLOR: "#A9D400",
    NODE_TEXT_SIZE: 14,
    NODE_TEXT_COLOR: "#657b83",
    NODE_SUBTEXT_SIZE: 12,
    NODE_DEFAULT_COLOR: "#094656",
    NODE_DEFAULT_BGCOLOR: "#073642",
    NODE_DEFAULT_BOXCOLOR: "#839496",
    NODE_DEFAULT_SHAPE: 2,
    NODE_BOX_OUTLINE_COLOR: "#fdf6e3",
    NODE_BYPASS_BGCOLOR: "#FF00FF",
    NODE_ERROR_COLOUR: "#E00",
    DEFAULT_SHADOW_COLOR: "rgba(0,0,0,0.5)",
    DEFAULT_GROUP_FONT: 24,
    WIDGET_BGCOLOR: "#002b36",
    WIDGET_OUTLINE_COLOR: "#839496",
    WIDGET_TEXT_COLOR: "#fdf6e3",
    WIDGET_SECONDARY_TEXT_COLOR: "#93a1a1",
    LINK_COLOR: "#2aa198",
    EVENT_LINK_COLOR: "#268bd2",
    CONNECTING_LINK_COLOR: "#859900"
  },
  comfy_base: {
    "fg-color": "#fdf6e3",
    "bg-color": "#002b36",
    "comfy-menu-bg": "#073642",
    "comfy-menu-secondary-bg": "#06323D",
    "comfy-input-bg": "#002b36",
    "input-text": "#93a1a1",
    "descrip-text": "#586e75",
    "drag-text": "#839496",
    "error-text": "#dc322f",
    "border-color": "#657b83",
    "tr-even-bg-color": "#002b36",
    "tr-odd-bg-color": "#073642",
    "content-bg": "#657b83",
    "content-fg": "#fdf6e3",
    "content-hover-bg": "#002b36",
    "content-hover-fg": "#fdf6e3",
    "bar-shadow": "rgba(16, 16, 16, 0.5) 0 0 0.5rem"
  }
};
const solarized = {
  id,
  name,
  colors
};
const CORE_COLOR_PALETTES = {
  dark,
  light,
  solarized,
  arc,
  nord,
  github
};
const DEFAULT_COLOR_PALETTE = dark;
const DEFAULT_DARK_COLOR_PALETTE = dark;
const DEFAULT_LIGHT_COLOR_PALETTE = light;
const useColorPaletteStore = /* @__PURE__ */ defineStore("colorPalette", () => {
  const customPalettes = ref({});
  const activePaletteId = ref(DEFAULT_COLOR_PALETTE.id);
  const palettesLookup = computed(() => ({
    ...CORE_COLOR_PALETTES,
    ...customPalettes.value
  }));
  const palettes = computed(() => Object.values(palettesLookup.value));
  const completedActivePalette = computed(
    () => completePalette(palettesLookup.value[activePaletteId.value])
  );
  const addCustomPalette = /* @__PURE__ */ __name((palette) => {
    if (palette.id in palettesLookup.value) {
      throw new Error(`Palette with id ${palette.id} already exists`);
    }
    customPalettes.value[palette.id] = palette;
    activePaletteId.value = palette.id;
  }, "addCustomPalette");
  const deleteCustomPalette = /* @__PURE__ */ __name((id4) => {
    if (!(id4 in customPalettes.value)) {
      throw new Error(`Palette with id ${id4} does not exist`);
    }
    delete customPalettes.value[id4];
    activePaletteId.value = CORE_COLOR_PALETTES.dark.id;
  }, "deleteCustomPalette");
  const isCustomPalette = /* @__PURE__ */ __name((id4) => {
    return id4 in customPalettes.value;
  }, "isCustomPalette");
  const completePalette = /* @__PURE__ */ __name((palette) => {
    if (palette.colors.comfy_base["comfy-menu-bg"] && !palette.colors.comfy_base["comfy-menu-secondary-bg"]) {
      palette.colors.comfy_base["comfy-menu-secondary-bg"] = palette.colors.comfy_base["comfy-menu-bg"];
    }
    const defaultPalette = palette.light_theme ? DEFAULT_LIGHT_COLOR_PALETTE : DEFAULT_DARK_COLOR_PALETTE;
    return {
      ...palette,
      colors: {
        ...palette.colors,
        node_slot: {
          ...defaultPalette.colors.node_slot,
          ...palette.colors.node_slot
        },
        litegraph_base: {
          ...defaultPalette.colors.litegraph_base,
          ...palette.colors.litegraph_base
        },
        comfy_base: {
          ...defaultPalette.colors.comfy_base,
          ...palette.colors.comfy_base
        }
      }
    };
  }, "completePalette");
  return {
    // State
    customPalettes,
    activePaletteId,
    // Getters
    palettesLookup,
    palettes,
    completedActivePalette,
    // Actions
    isCustomPalette,
    addCustomPalette,
    deleteCustomPalette,
    completePalette
  };
});
const _hoisted_1$1i = { class: "flex items-center justify-between" };
const _hoisted_2$X = { class: "actions" };
const _sfc_main$1m = /* @__PURE__ */ defineComponent({
  __name: "ColorPaletteMessage",
  setup(__props) {
    const settingStore = useSettingStore();
    const colorPaletteStore = useColorPaletteStore();
    const colorPaletteService = useColorPaletteService();
    const { palettes, activePaletteId } = storeToRefs(colorPaletteStore);
    const importCustomPalette = /* @__PURE__ */ __name(async () => {
      const palette = await colorPaletteService.importColorPalette();
      if (palette) {
        settingStore.set("Comfy.ColorPalette", palette.id);
      }
    }, "importCustomPalette");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$Z), {
        severity: "info",
        icon: "pi pi-palette",
        "pt:text": "w-full"
      }, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$1i, [
            createBaseVNode("div", null, toDisplayString$1(_ctx.$t("settingsCategories.ColorPalette")), 1),
            createBaseVNode("div", _hoisted_2$X, [
              createVNode(unref(script$t), {
                class: "w-44",
                modelValue: unref(activePaletteId),
                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => isRef(activePaletteId) ? activePaletteId.value = $event : null),
                options: unref(palettes),
                optionLabel: "name",
                optionValue: "id"
              }, null, 8, ["modelValue", "options"]),
              createVNode(unref(script$10), {
                icon: "pi pi-file-export",
                text: "",
                title: _ctx.$t("g.export"),
                onClick: _cache[1] || (_cache[1] = ($event) => unref(colorPaletteService).exportColorPalette(unref(activePaletteId)))
              }, null, 8, ["title"]),
              createVNode(unref(script$10), {
                icon: "pi pi-file-import",
                text: "",
                title: _ctx.$t("g.import"),
                onClick: importCustomPalette
              }, null, 8, ["title"]),
              createVNode(unref(script$10), {
                icon: "pi pi-trash",
                severity: "danger",
                text: "",
                title: _ctx.$t("g.delete"),
                onClick: _cache[2] || (_cache[2] = ($event) => unref(colorPaletteService).deleteCustomColorPalette(unref(activePaletteId))),
                disabled: !unref(colorPaletteStore).isCustomPalette(unref(activePaletteId))
              }, null, 8, ["title", "disabled"])
            ])
          ])
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1$1h = { class: "flex items-center justify-between" };
const _sfc_main$1l = /* @__PURE__ */ defineComponent({
  __name: "CurrentUserMessage",
  setup(__props) {
    const userStore = useUserStore();
    const logout = /* @__PURE__ */ __name(() => {
      userStore.logout();
      window.location.reload();
    }, "logout");
    return (_ctx, _cache) => {
      return unref(userStore).isMultiUserServer ? (openBlock(), createBlock(unref(script$Z), {
        key: 0,
        severity: "info",
        icon: "pi pi-user",
        "pt:text": "w-full"
      }, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$1h, [
            createBaseVNode("div", null, toDisplayString$1(_ctx.$t("g.currentUser")) + ": " + toDisplayString$1(unref(userStore).currentUser?.username), 1),
            createVNode(unref(script$10), {
              icon: "pi pi-sign-out",
              onClick: logout,
              text: ""
            })
          ])
        ]),
        _: 1
      })) : createCommentVNode("", true);
    };
  }
});
const _sfc_main$1k = /* @__PURE__ */ defineComponent({
  __name: "FirstTimeUIMessage",
  setup(__props) {
    const settingStore = useSettingStore();
    const show7 = computed(() => !settingStore.exists("Comfy.UseNewMenu"));
    const handleClose = /* @__PURE__ */ __name(() => {
      const currentValue = settingStore.get("Comfy.UseNewMenu");
      settingStore.set("Comfy.UseNewMenu", currentValue);
    }, "handleClose");
    return (_ctx, _cache) => {
      return show7.value ? (openBlock(), createBlock(unref(script$Z), {
        key: 0,
        class: "first-time-ui-message",
        severity: "info",
        closable: true,
        onClose: handleClose
      }, {
        default: withCtx(() => [
          createTextVNode(toDisplayString$1(_ctx.$t("g.firstTimeUIMessage")), 1)
        ]),
        _: 1
      })) : createCommentVNode("", true);
    };
  }
});
var script$s = {
  name: "AngleDownIcon",
  "extends": script$16
};
function render$q(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M3.58659 4.5007C3.68513 4.50023 3.78277 4.51945 3.87379 4.55723C3.9648 4.59501 4.04735 4.65058 4.11659 4.7207L7.11659 7.7207L10.1166 4.7207C10.2619 4.65055 10.4259 4.62911 10.5843 4.65956C10.7427 4.69002 10.8871 4.77074 10.996 4.88976C11.1049 5.00877 11.1726 5.15973 11.1889 5.32022C11.2052 5.48072 11.1693 5.6422 11.0866 5.7807L7.58659 9.2807C7.44597 9.42115 7.25534 9.50004 7.05659 9.50004C6.85784 9.50004 6.66722 9.42115 6.52659 9.2807L3.02659 5.7807C2.88614 5.64007 2.80725 5.44945 2.80725 5.2507C2.80725 5.05195 2.88614 4.86132 3.02659 4.7207C3.09932 4.64685 3.18675 4.58911 3.28322 4.55121C3.37969 4.51331 3.48305 4.4961 3.58659 4.5007Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$q, "render$q");
script$s.render = render$q;
var script$r = {
  name: "AngleUpIcon",
  "extends": script$16
};
function render$p(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M10.4134 9.49931C10.3148 9.49977 10.2172 9.48055 10.1262 9.44278C10.0352 9.405 9.95263 9.34942 9.88338 9.27931L6.88338 6.27931L3.88338 9.27931C3.73811 9.34946 3.57409 9.3709 3.41567 9.34044C3.25724 9.30999 3.11286 9.22926 3.00395 9.11025C2.89504 8.99124 2.82741 8.84028 2.8111 8.67978C2.79478 8.51928 2.83065 8.35781 2.91338 8.21931L6.41338 4.71931C6.55401 4.57886 6.74463 4.49997 6.94338 4.49997C7.14213 4.49997 7.33276 4.57886 7.47338 4.71931L10.9734 8.21931C11.1138 8.35994 11.1927 8.55056 11.1927 8.74931C11.1927 8.94806 11.1138 9.13868 10.9734 9.27931C10.9007 9.35315 10.8132 9.41089 10.7168 9.44879C10.6203 9.48669 10.5169 9.5039 10.4134 9.49931Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$p, "render$p");
script$r.render = render$p;
var theme$h = /* @__PURE__ */ __name(function theme29(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-inputnumber {\n    display: inline-flex;\n    position: relative;\n}\n\n.p-inputnumber-button {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    flex: 0 0 auto;\n    cursor: pointer;\n    background: ".concat(dt2("inputnumber.button.background"), ";\n    color: ").concat(dt2("inputnumber.button.color"), ";\n    width: ").concat(dt2("inputnumber.button.width"), ";\n    transition: background ").concat(dt2("inputnumber.transition.duration"), ", color ").concat(dt2("inputnumber.transition.duration"), ", border-color ").concat(dt2("inputnumber.transition.duration"), ", outline-color ").concat(dt2("inputnumber.transition.duration"), ";\n}\n\n.p-inputnumber-button:hover {\n    background: ").concat(dt2("inputnumber.button.hover.background"), ";\n    color: ").concat(dt2("inputnumber.button.hover.color"), ";\n}\n\n.p-inputnumber-button:active {\n    background: ").concat(dt2("inputnumber.button.active.background"), ";\n    color: ").concat(dt2("inputnumber.button.active.color"), ";\n}\n\n.p-inputnumber-stacked .p-inputnumber-button {\n    position: relative;\n    border: 0 none;\n}\n\n.p-inputnumber-stacked .p-inputnumber-button-group {\n    display: flex;\n    flex-direction: column;\n    position: absolute;\n    inset-block-start: 1px;\n    inset-inline-end: 1px;\n    height: calc(100% - 2px);\n    z-index: 1;\n}\n\n.p-inputnumber-stacked .p-inputnumber-increment-button {\n    padding: 0;\n    border-start-end-radius: calc(").concat(dt2("inputnumber.button.border.radius"), " - 1px);\n}\n\n.p-inputnumber-stacked .p-inputnumber-decrement-button {\n    padding: 0;\n    border-end-end-radius: calc(").concat(dt2("inputnumber.button.border.radius"), " - 1px);\n}\n\n.p-inputnumber-stacked .p-inputnumber-button {\n    flex: 1 1 auto;\n    border: 0 none;\n}\n\n.p-inputnumber-horizontal .p-inputnumber-button {\n    border: 1px solid ").concat(dt2("inputnumber.button.border.color"), ";\n}\n\n.p-inputnumber-horizontal .p-inputnumber-button:hover {\n    border-color: ").concat(dt2("inputnumber.button.hover.border.color"), ";\n}\n\n.p-inputnumber-horizontal .p-inputnumber-button:active {\n    border-color: ").concat(dt2("inputnumber.button.active.border.color"), ";\n}\n\n.p-inputnumber-horizontal .p-inputnumber-increment-button {\n    order: 3;\n    border-start-end-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-inline-start: 0 none;\n}\n\n.p-inputnumber-horizontal .p-inputnumber-input {\n    order: 2;\n    border-radius: 0;\n}\n\n.p-inputnumber-horizontal .p-inputnumber-decrement-button {\n    order: 1;\n    border-start-start-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-end-start-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-inline-end: 0 none;\n}\n\n.p-floatlabel:has(.p-inputnumber-horizontal) label {\n    margin-inline-start: ").concat(dt2("inputnumber.button.width"), ";\n}\n\n.p-inputnumber-vertical {\n    flex-direction: column;\n}\n\n.p-inputnumber-vertical .p-inputnumber-button {\n    border: 1px solid ").concat(dt2("inputnumber.button.border.color"), ";\n    padding: ").concat(dt2("inputnumber.button.vertical.padding"), ";\n}\n\n.p-inputnumber-vertical .p-inputnumber-button:hover {\n    border-color: ").concat(dt2("inputnumber.button.hover.border.color"), ";\n}\n\n.p-inputnumber-vertical .p-inputnumber-button:active {\n    border-color: ").concat(dt2("inputnumber.button.active.border.color"), ";\n}\n\n.p-inputnumber-vertical .p-inputnumber-increment-button {\n    order: 1;\n    border-start-start-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-start-end-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    width: 100%;\n    border-block-end: 0 none;\n}\n\n.p-inputnumber-vertical .p-inputnumber-input {\n    order: 2;\n    border-radius: 0;\n    text-align: center;\n}\n\n.p-inputnumber-vertical .p-inputnumber-decrement-button {\n    order: 3;\n    border-end-start-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("inputnumber.button.border.radius"), ";\n    width: 100%;\n    border-block-start: 0 none;\n}\n\n.p-inputnumber-input {\n    flex: 1 1 auto;\n}\n\n.p-inputnumber-fluid {\n    width: 100%;\n}\n\n.p-inputnumber-fluid .p-inputnumber-input {\n    width: 1%;\n}\n\n.p-inputnumber-fluid.p-inputnumber-vertical .p-inputnumber-input {\n    width: 100%;\n}\n\n.p-inputnumber:has(.p-inputtext-sm) .p-inputnumber-button .p-icon {\n    font-size: ").concat(dt2("form.field.sm.font.size"), ";\n    width: ").concat(dt2("form.field.sm.font.size"), ";\n    height: ").concat(dt2("form.field.sm.font.size"), ";\n}\n\n.p-inputnumber:has(.p-inputtext-lg) .p-inputnumber-button .p-icon {\n    font-size: ").concat(dt2("form.field.lg.font.size"), ";\n    width: ").concat(dt2("form.field.lg.font.size"), ";\n    height: ").concat(dt2("form.field.lg.font.size"), ";\n}\n");
}, "theme");
var classes$j = {
  root: /* @__PURE__ */ __name(function root20(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-inputnumber p-component p-inputwrapper", {
      "p-inputwrapper-filled": instance.$filled || props.allowEmpty === false,
      "p-inputwrapper-focus": instance.focused,
      "p-inputnumber-stacked": props.showButtons && props.buttonLayout === "stacked",
      "p-inputnumber-horizontal": props.showButtons && props.buttonLayout === "horizontal",
      "p-inputnumber-vertical": props.showButtons && props.buttonLayout === "vertical",
      "p-inputnumber-fluid": instance.$fluid
    }];
  }, "root"),
  pcInputText: "p-inputnumber-input",
  buttonGroup: "p-inputnumber-button-group",
  incrementButton: /* @__PURE__ */ __name(function incrementButton(_ref3) {
    var instance = _ref3.instance, props = _ref3.props;
    return ["p-inputnumber-button p-inputnumber-increment-button", {
      "p-disabled": props.showButtons && props.max !== null && instance.maxBoundry()
    }];
  }, "incrementButton"),
  decrementButton: /* @__PURE__ */ __name(function decrementButton(_ref4) {
    var instance = _ref4.instance, props = _ref4.props;
    return ["p-inputnumber-button p-inputnumber-decrement-button", {
      "p-disabled": props.showButtons && props.min !== null && instance.minBoundry()
    }];
  }, "decrementButton")
};
var InputNumberStyle = BaseStyle$1.extend({
  name: "inputnumber",
  theme: theme$h,
  classes: classes$j
});
var script$1$j = {
  name: "BaseInputNumber",
  "extends": script$17,
  props: {
    format: {
      type: Boolean,
      "default": true
    },
    showButtons: {
      type: Boolean,
      "default": false
    },
    buttonLayout: {
      type: String,
      "default": "stacked"
    },
    incrementButtonClass: {
      type: String,
      "default": null
    },
    decrementButtonClass: {
      type: String,
      "default": null
    },
    incrementButtonIcon: {
      type: String,
      "default": void 0
    },
    incrementIcon: {
      type: String,
      "default": void 0
    },
    decrementButtonIcon: {
      type: String,
      "default": void 0
    },
    decrementIcon: {
      type: String,
      "default": void 0
    },
    locale: {
      type: String,
      "default": void 0
    },
    localeMatcher: {
      type: String,
      "default": void 0
    },
    mode: {
      type: String,
      "default": "decimal"
    },
    prefix: {
      type: String,
      "default": null
    },
    suffix: {
      type: String,
      "default": null
    },
    currency: {
      type: String,
      "default": void 0
    },
    currencyDisplay: {
      type: String,
      "default": void 0
    },
    useGrouping: {
      type: Boolean,
      "default": true
    },
    minFractionDigits: {
      type: Number,
      "default": void 0
    },
    maxFractionDigits: {
      type: Number,
      "default": void 0
    },
    roundingMode: {
      type: String,
      "default": "halfExpand",
      validator: /* @__PURE__ */ __name(function validator2(value3) {
        return ["ceil", "floor", "expand", "trunc", "halfCeil", "halfFloor", "halfExpand", "halfTrunc", "halfEven"].includes(value3);
      }, "validator")
    },
    min: {
      type: Number,
      "default": null
    },
    max: {
      type: Number,
      "default": null
    },
    step: {
      type: Number,
      "default": 1
    },
    allowEmpty: {
      type: Boolean,
      "default": true
    },
    highlightOnFocus: {
      type: Boolean,
      "default": false
    },
    readonly: {
      type: Boolean,
      "default": false
    },
    placeholder: {
      type: String,
      "default": null
    },
    inputId: {
      type: String,
      "default": null
    },
    inputClass: {
      type: [String, Object],
      "default": null
    },
    inputStyle: {
      type: Object,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: InputNumberStyle,
  provide: /* @__PURE__ */ __name(function provide32() {
    return {
      $pcInputNumber: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$8(o2) {
  "@babel/helpers - typeof";
  return _typeof$8 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$8(o2);
}
__name(_typeof$8, "_typeof$8");
function ownKeys$a(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$a, "ownKeys$a");
function _objectSpread$a(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$a(Object(t2), true).forEach(function(r3) {
      _defineProperty$8(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$a(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$a, "_objectSpread$a");
function _defineProperty$8(e2, r2, t2) {
  return (r2 = _toPropertyKey$7(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$8, "_defineProperty$8");
function _toPropertyKey$7(t2) {
  var i2 = _toPrimitive$7(t2, "string");
  return "symbol" == _typeof$8(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$7, "_toPropertyKey$7");
function _toPrimitive$7(t2, r2) {
  if ("object" != _typeof$8(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$8(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$7, "_toPrimitive$7");
function _toConsumableArray$8(r2) {
  return _arrayWithoutHoles$8(r2) || _iterableToArray$8(r2) || _unsupportedIterableToArray$a(r2) || _nonIterableSpread$8();
}
__name(_toConsumableArray$8, "_toConsumableArray$8");
function _nonIterableSpread$8() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$8, "_nonIterableSpread$8");
function _unsupportedIterableToArray$a(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$a(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$a(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$a, "_unsupportedIterableToArray$a");
function _iterableToArray$8(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$8, "_iterableToArray$8");
function _arrayWithoutHoles$8(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$a(r2);
}
__name(_arrayWithoutHoles$8, "_arrayWithoutHoles$8");
function _arrayLikeToArray$a(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$a, "_arrayLikeToArray$a");
var script$q = {
  name: "InputNumber",
  "extends": script$1$j,
  inheritAttrs: false,
  emits: ["input", "focus", "blur"],
  inject: {
    $pcFluid: {
      "default": null
    }
  },
  numberFormat: null,
  _numeral: null,
  _decimal: null,
  _group: null,
  _minusSign: null,
  _currency: null,
  _suffix: null,
  _prefix: null,
  _index: null,
  groupChar: "",
  isSpecialChar: null,
  prefixChar: null,
  suffixChar: null,
  timer: null,
  data: /* @__PURE__ */ __name(function data15() {
    return {
      // @deprecated
      d_modelValue: this.d_value,
      focused: false
    };
  }, "data"),
  watch: {
    d_value: /* @__PURE__ */ __name(function d_value(newValue2) {
      this.d_modelValue = newValue2;
    }, "d_value"),
    locale: /* @__PURE__ */ __name(function locale(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "locale"),
    localeMatcher: /* @__PURE__ */ __name(function localeMatcher(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "localeMatcher"),
    mode: /* @__PURE__ */ __name(function mode(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "mode"),
    currency: /* @__PURE__ */ __name(function currency(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "currency"),
    currencyDisplay: /* @__PURE__ */ __name(function currencyDisplay(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "currencyDisplay"),
    useGrouping: /* @__PURE__ */ __name(function useGrouping(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "useGrouping"),
    minFractionDigits: /* @__PURE__ */ __name(function minFractionDigits(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "minFractionDigits"),
    maxFractionDigits: /* @__PURE__ */ __name(function maxFractionDigits(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "maxFractionDigits"),
    suffix: /* @__PURE__ */ __name(function suffix(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "suffix"),
    prefix: /* @__PURE__ */ __name(function prefix(newValue2, oldValue) {
      this.updateConstructParser(newValue2, oldValue);
    }, "prefix")
  },
  created: /* @__PURE__ */ __name(function created3() {
    this.constructParser();
  }, "created"),
  methods: {
    getOptions: /* @__PURE__ */ __name(function getOptions3() {
      return {
        localeMatcher: this.localeMatcher,
        style: this.mode,
        currency: this.currency,
        currencyDisplay: this.currencyDisplay,
        useGrouping: this.useGrouping,
        minimumFractionDigits: this.minFractionDigits,
        maximumFractionDigits: this.maxFractionDigits,
        roundingMode: this.roundingMode
      };
    }, "getOptions"),
    constructParser: /* @__PURE__ */ __name(function constructParser() {
      this.numberFormat = new Intl.NumberFormat(this.locale, this.getOptions());
      var numerals = _toConsumableArray$8(new Intl.NumberFormat(this.locale, {
        useGrouping: false
      }).format(9876543210)).reverse();
      var index2 = new Map(numerals.map(function(d2, i2) {
        return [d2, i2];
      }));
      this._numeral = new RegExp("[".concat(numerals.join(""), "]"), "g");
      this._group = this.getGroupingExpression();
      this._minusSign = this.getMinusSignExpression();
      this._currency = this.getCurrencyExpression();
      this._decimal = this.getDecimalExpression();
      this._suffix = this.getSuffixExpression();
      this._prefix = this.getPrefixExpression();
      this._index = function(d2) {
        return index2.get(d2);
      };
    }, "constructParser"),
    updateConstructParser: /* @__PURE__ */ __name(function updateConstructParser(newValue2, oldValue) {
      if (newValue2 !== oldValue) {
        this.constructParser();
      }
    }, "updateConstructParser"),
    escapeRegExp: /* @__PURE__ */ __name(function escapeRegExp(text2) {
      return text2.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, "\\$&");
    }, "escapeRegExp"),
    getDecimalExpression: /* @__PURE__ */ __name(function getDecimalExpression() {
      var formatter = new Intl.NumberFormat(this.locale, _objectSpread$a(_objectSpread$a({}, this.getOptions()), {}, {
        useGrouping: false
      }));
      return new RegExp("[".concat(formatter.format(1.1).replace(this._currency, "").trim().replace(this._numeral, ""), "]"), "g");
    }, "getDecimalExpression"),
    getGroupingExpression: /* @__PURE__ */ __name(function getGroupingExpression() {
      var formatter = new Intl.NumberFormat(this.locale, {
        useGrouping: true
      });
      this.groupChar = formatter.format(1e6).trim().replace(this._numeral, "").charAt(0);
      return new RegExp("[".concat(this.groupChar, "]"), "g");
    }, "getGroupingExpression"),
    getMinusSignExpression: /* @__PURE__ */ __name(function getMinusSignExpression() {
      var formatter = new Intl.NumberFormat(this.locale, {
        useGrouping: false
      });
      return new RegExp("[".concat(formatter.format(-1).trim().replace(this._numeral, ""), "]"), "g");
    }, "getMinusSignExpression"),
    getCurrencyExpression: /* @__PURE__ */ __name(function getCurrencyExpression() {
      if (this.currency) {
        var formatter = new Intl.NumberFormat(this.locale, {
          style: "currency",
          currency: this.currency,
          currencyDisplay: this.currencyDisplay,
          minimumFractionDigits: 0,
          maximumFractionDigits: 0,
          roundingMode: this.roundingMode
        });
        return new RegExp("[".concat(formatter.format(1).replace(/\s/g, "").replace(this._numeral, "").replace(this._group, ""), "]"), "g");
      }
      return new RegExp("[]", "g");
    }, "getCurrencyExpression"),
    getPrefixExpression: /* @__PURE__ */ __name(function getPrefixExpression() {
      if (this.prefix) {
        this.prefixChar = this.prefix;
      } else {
        var formatter = new Intl.NumberFormat(this.locale, {
          style: this.mode,
          currency: this.currency,
          currencyDisplay: this.currencyDisplay
        });
        this.prefixChar = formatter.format(1).split("1")[0];
      }
      return new RegExp("".concat(this.escapeRegExp(this.prefixChar || "")), "g");
    }, "getPrefixExpression"),
    getSuffixExpression: /* @__PURE__ */ __name(function getSuffixExpression() {
      if (this.suffix) {
        this.suffixChar = this.suffix;
      } else {
        var formatter = new Intl.NumberFormat(this.locale, {
          style: this.mode,
          currency: this.currency,
          currencyDisplay: this.currencyDisplay,
          minimumFractionDigits: 0,
          maximumFractionDigits: 0,
          roundingMode: this.roundingMode
        });
        this.suffixChar = formatter.format(1).split("1")[1];
      }
      return new RegExp("".concat(this.escapeRegExp(this.suffixChar || "")), "g");
    }, "getSuffixExpression"),
    formatValue: /* @__PURE__ */ __name(function formatValue(value3) {
      if (value3 != null) {
        if (value3 === "-") {
          return value3;
        }
        if (this.format) {
          var formatter = new Intl.NumberFormat(this.locale, this.getOptions());
          var formattedValue2 = formatter.format(value3);
          if (this.prefix) {
            formattedValue2 = this.prefix + formattedValue2;
          }
          if (this.suffix) {
            formattedValue2 = formattedValue2 + this.suffix;
          }
          return formattedValue2;
        }
        return value3.toString();
      }
      return "";
    }, "formatValue"),
    parseValue: /* @__PURE__ */ __name(function parseValue2(text2) {
      var filteredText = text2.replace(this._suffix, "").replace(this._prefix, "").trim().replace(/\s/g, "").replace(this._currency, "").replace(this._group, "").replace(this._minusSign, "-").replace(this._decimal, ".").replace(this._numeral, this._index);
      if (filteredText) {
        if (filteredText === "-")
          return filteredText;
        var parsedValue = +filteredText;
        return isNaN(parsedValue) ? null : parsedValue;
      }
      return null;
    }, "parseValue"),
    repeat: /* @__PURE__ */ __name(function repeat3(event, interval, dir) {
      var _this = this;
      if (this.readonly) {
        return;
      }
      var i2 = interval || 500;
      this.clearTimer();
      this.timer = setTimeout(function() {
        _this.repeat(event, 40, dir);
      }, i2);
      this.spin(event, dir);
    }, "repeat"),
    spin: /* @__PURE__ */ __name(function spin(event, dir) {
      if (this.$refs.input) {
        var step2 = this.step * dir;
        var currentValue = this.parseValue(this.$refs.input.$el.value) || 0;
        var newValue2 = this.validateValue(currentValue + step2);
        this.updateInput(newValue2, null, "spin");
        this.updateModel(event, newValue2);
        this.handleOnInput(event, currentValue, newValue2);
      }
    }, "spin"),
    onUpButtonMouseDown: /* @__PURE__ */ __name(function onUpButtonMouseDown(event) {
      if (!this.disabled) {
        this.$refs.input.$el.focus();
        this.repeat(event, null, 1);
        event.preventDefault();
      }
    }, "onUpButtonMouseDown"),
    onUpButtonMouseUp: /* @__PURE__ */ __name(function onUpButtonMouseUp() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onUpButtonMouseUp"),
    onUpButtonMouseLeave: /* @__PURE__ */ __name(function onUpButtonMouseLeave() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onUpButtonMouseLeave"),
    onUpButtonKeyUp: /* @__PURE__ */ __name(function onUpButtonKeyUp() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onUpButtonKeyUp"),
    onUpButtonKeyDown: /* @__PURE__ */ __name(function onUpButtonKeyDown(event) {
      if (event.code === "Space" || event.code === "Enter" || event.code === "NumpadEnter") {
        this.repeat(event, null, 1);
      }
    }, "onUpButtonKeyDown"),
    onDownButtonMouseDown: /* @__PURE__ */ __name(function onDownButtonMouseDown(event) {
      if (!this.disabled) {
        this.$refs.input.$el.focus();
        this.repeat(event, null, -1);
        event.preventDefault();
      }
    }, "onDownButtonMouseDown"),
    onDownButtonMouseUp: /* @__PURE__ */ __name(function onDownButtonMouseUp() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onDownButtonMouseUp"),
    onDownButtonMouseLeave: /* @__PURE__ */ __name(function onDownButtonMouseLeave() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onDownButtonMouseLeave"),
    onDownButtonKeyUp: /* @__PURE__ */ __name(function onDownButtonKeyUp() {
      if (!this.disabled) {
        this.clearTimer();
      }
    }, "onDownButtonKeyUp"),
    onDownButtonKeyDown: /* @__PURE__ */ __name(function onDownButtonKeyDown(event) {
      if (event.code === "Space" || event.code === "Enter" || event.code === "NumpadEnter") {
        this.repeat(event, null, -1);
      }
    }, "onDownButtonKeyDown"),
    onUserInput: /* @__PURE__ */ __name(function onUserInput() {
      if (this.isSpecialChar) {
        this.$refs.input.$el.value = this.lastValue;
      }
      this.isSpecialChar = false;
    }, "onUserInput"),
    onInputKeyDown: /* @__PURE__ */ __name(function onInputKeyDown(event) {
      if (this.readonly) {
        return;
      }
      if (event.altKey || event.ctrlKey || event.metaKey) {
        this.isSpecialChar = true;
        this.lastValue = this.$refs.input.$el.value;
        return;
      }
      this.lastValue = event.target.value;
      var selectionStart = event.target.selectionStart;
      var selectionEnd = event.target.selectionEnd;
      var selectionRange = selectionEnd - selectionStart;
      var inputValue2 = event.target.value;
      var newValueStr = null;
      var code2 = event.code || event.key;
      switch (code2) {
        case "ArrowUp":
          this.spin(event, 1);
          event.preventDefault();
          break;
        case "ArrowDown":
          this.spin(event, -1);
          event.preventDefault();
          break;
        case "ArrowLeft":
          if (selectionRange > 1) {
            var cursorPosition = this.isNumeralChar(inputValue2.charAt(selectionStart)) ? selectionStart + 1 : selectionStart + 2;
            this.$refs.input.$el.setSelectionRange(cursorPosition, cursorPosition);
          } else if (!this.isNumeralChar(inputValue2.charAt(selectionStart - 1))) {
            event.preventDefault();
          }
          break;
        case "ArrowRight":
          if (selectionRange > 1) {
            var _cursorPosition = selectionEnd - 1;
            this.$refs.input.$el.setSelectionRange(_cursorPosition, _cursorPosition);
          } else if (!this.isNumeralChar(inputValue2.charAt(selectionStart))) {
            event.preventDefault();
          }
          break;
        case "Tab":
        case "Enter":
        case "NumpadEnter":
          newValueStr = this.validateValue(this.parseValue(inputValue2));
          this.$refs.input.$el.value = this.formatValue(newValueStr);
          this.$refs.input.$el.setAttribute("aria-valuenow", newValueStr);
          this.updateModel(event, newValueStr);
          break;
        case "Backspace": {
          event.preventDefault();
          if (selectionStart === selectionEnd) {
            var deleteChar = inputValue2.charAt(selectionStart - 1);
            var _this$getDecimalCharI = this.getDecimalCharIndexes(inputValue2), decimalCharIndex = _this$getDecimalCharI.decimalCharIndex, decimalCharIndexWithoutPrefix = _this$getDecimalCharI.decimalCharIndexWithoutPrefix;
            if (this.isNumeralChar(deleteChar)) {
              var decimalLength = this.getDecimalLength(inputValue2);
              if (this._group.test(deleteChar)) {
                this._group.lastIndex = 0;
                newValueStr = inputValue2.slice(0, selectionStart - 2) + inputValue2.slice(selectionStart - 1);
              } else if (this._decimal.test(deleteChar)) {
                this._decimal.lastIndex = 0;
                if (decimalLength) {
                  this.$refs.input.$el.setSelectionRange(selectionStart - 1, selectionStart - 1);
                } else {
                  newValueStr = inputValue2.slice(0, selectionStart - 1) + inputValue2.slice(selectionStart);
                }
              } else if (decimalCharIndex > 0 && selectionStart > decimalCharIndex) {
                var insertedText = this.isDecimalMode() && (this.minFractionDigits || 0) < decimalLength ? "" : "0";
                newValueStr = inputValue2.slice(0, selectionStart - 1) + insertedText + inputValue2.slice(selectionStart);
              } else if (decimalCharIndexWithoutPrefix === 1) {
                newValueStr = inputValue2.slice(0, selectionStart - 1) + "0" + inputValue2.slice(selectionStart);
                newValueStr = this.parseValue(newValueStr) > 0 ? newValueStr : "";
              } else {
                newValueStr = inputValue2.slice(0, selectionStart - 1) + inputValue2.slice(selectionStart);
              }
            }
            this.updateValue(event, newValueStr, null, "delete-single");
          } else {
            newValueStr = this.deleteRange(inputValue2, selectionStart, selectionEnd);
            this.updateValue(event, newValueStr, null, "delete-range");
          }
          break;
        }
        case "Delete":
          event.preventDefault();
          if (selectionStart === selectionEnd) {
            var _deleteChar = inputValue2.charAt(selectionStart);
            var _this$getDecimalCharI2 = this.getDecimalCharIndexes(inputValue2), _decimalCharIndex = _this$getDecimalCharI2.decimalCharIndex, _decimalCharIndexWithoutPrefix = _this$getDecimalCharI2.decimalCharIndexWithoutPrefix;
            if (this.isNumeralChar(_deleteChar)) {
              var _decimalLength = this.getDecimalLength(inputValue2);
              if (this._group.test(_deleteChar)) {
                this._group.lastIndex = 0;
                newValueStr = inputValue2.slice(0, selectionStart) + inputValue2.slice(selectionStart + 2);
              } else if (this._decimal.test(_deleteChar)) {
                this._decimal.lastIndex = 0;
                if (_decimalLength) {
                  this.$refs.input.$el.setSelectionRange(selectionStart + 1, selectionStart + 1);
                } else {
                  newValueStr = inputValue2.slice(0, selectionStart) + inputValue2.slice(selectionStart + 1);
                }
              } else if (_decimalCharIndex > 0 && selectionStart > _decimalCharIndex) {
                var _insertedText = this.isDecimalMode() && (this.minFractionDigits || 0) < _decimalLength ? "" : "0";
                newValueStr = inputValue2.slice(0, selectionStart) + _insertedText + inputValue2.slice(selectionStart + 1);
              } else if (_decimalCharIndexWithoutPrefix === 1) {
                newValueStr = inputValue2.slice(0, selectionStart) + "0" + inputValue2.slice(selectionStart + 1);
                newValueStr = this.parseValue(newValueStr) > 0 ? newValueStr : "";
              } else {
                newValueStr = inputValue2.slice(0, selectionStart) + inputValue2.slice(selectionStart + 1);
              }
            }
            this.updateValue(event, newValueStr, null, "delete-back-single");
          } else {
            newValueStr = this.deleteRange(inputValue2, selectionStart, selectionEnd);
            this.updateValue(event, newValueStr, null, "delete-range");
          }
          break;
        case "Home":
          event.preventDefault();
          if (isNotEmpty$2(this.min)) {
            this.updateModel(event, this.min);
          }
          break;
        case "End":
          event.preventDefault();
          if (isNotEmpty$2(this.max)) {
            this.updateModel(event, this.max);
          }
          break;
      }
    }, "onInputKeyDown"),
    onInputKeyPress: /* @__PURE__ */ __name(function onInputKeyPress(event) {
      if (this.readonly) {
        return;
      }
      var _char = event.key;
      var isDecimalSign2 = this.isDecimalSign(_char);
      var isMinusSign2 = this.isMinusSign(_char);
      if (event.code !== "Enter") {
        event.preventDefault();
      }
      if (Number(_char) >= 0 && Number(_char) <= 9 || isMinusSign2 || isDecimalSign2) {
        this.insert(event, _char, {
          isDecimalSign: isDecimalSign2,
          isMinusSign: isMinusSign2
        });
      }
    }, "onInputKeyPress"),
    onPaste: /* @__PURE__ */ __name(function onPaste(event) {
      event.preventDefault();
      var data30 = (event.clipboardData || window["clipboardData"]).getData("Text");
      if (data30) {
        var filteredData = this.parseValue(data30);
        if (filteredData != null) {
          this.insert(event, filteredData.toString());
        }
      }
    }, "onPaste"),
    allowMinusSign: /* @__PURE__ */ __name(function allowMinusSign() {
      return this.min === null || this.min < 0;
    }, "allowMinusSign"),
    isMinusSign: /* @__PURE__ */ __name(function isMinusSign(_char2) {
      if (this._minusSign.test(_char2) || _char2 === "-") {
        this._minusSign.lastIndex = 0;
        return true;
      }
      return false;
    }, "isMinusSign"),
    isDecimalSign: /* @__PURE__ */ __name(function isDecimalSign(_char3) {
      if (this._decimal.test(_char3)) {
        this._decimal.lastIndex = 0;
        return true;
      }
      return false;
    }, "isDecimalSign"),
    isDecimalMode: /* @__PURE__ */ __name(function isDecimalMode() {
      return this.mode === "decimal";
    }, "isDecimalMode"),
    getDecimalCharIndexes: /* @__PURE__ */ __name(function getDecimalCharIndexes(val) {
      var decimalCharIndex = val.search(this._decimal);
      this._decimal.lastIndex = 0;
      var filteredVal = val.replace(this._prefix, "").trim().replace(/\s/g, "").replace(this._currency, "");
      var decimalCharIndexWithoutPrefix = filteredVal.search(this._decimal);
      this._decimal.lastIndex = 0;
      return {
        decimalCharIndex,
        decimalCharIndexWithoutPrefix
      };
    }, "getDecimalCharIndexes"),
    getCharIndexes: /* @__PURE__ */ __name(function getCharIndexes(val) {
      var decimalCharIndex = val.search(this._decimal);
      this._decimal.lastIndex = 0;
      var minusCharIndex = val.search(this._minusSign);
      this._minusSign.lastIndex = 0;
      var suffixCharIndex = val.search(this._suffix);
      this._suffix.lastIndex = 0;
      var currencyCharIndex = val.search(this._currency);
      this._currency.lastIndex = 0;
      return {
        decimalCharIndex,
        minusCharIndex,
        suffixCharIndex,
        currencyCharIndex
      };
    }, "getCharIndexes"),
    insert: /* @__PURE__ */ __name(function insert(event, text2) {
      var sign = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {
        isDecimalSign: false,
        isMinusSign: false
      };
      var minusCharIndexOnText = text2.search(this._minusSign);
      this._minusSign.lastIndex = 0;
      if (!this.allowMinusSign() && minusCharIndexOnText !== -1) {
        return;
      }
      var selectionStart = this.$refs.input.$el.selectionStart;
      var selectionEnd = this.$refs.input.$el.selectionEnd;
      var inputValue2 = this.$refs.input.$el.value.trim();
      var _this$getCharIndexes = this.getCharIndexes(inputValue2), decimalCharIndex = _this$getCharIndexes.decimalCharIndex, minusCharIndex = _this$getCharIndexes.minusCharIndex, suffixCharIndex = _this$getCharIndexes.suffixCharIndex, currencyCharIndex = _this$getCharIndexes.currencyCharIndex;
      var newValueStr;
      if (sign.isMinusSign) {
        if (selectionStart === 0) {
          newValueStr = inputValue2;
          if (minusCharIndex === -1 || selectionEnd !== 0) {
            newValueStr = this.insertText(inputValue2, text2, 0, selectionEnd);
          }
          this.updateValue(event, newValueStr, text2, "insert");
        }
      } else if (sign.isDecimalSign) {
        if (decimalCharIndex > 0 && selectionStart === decimalCharIndex) {
          this.updateValue(event, inputValue2, text2, "insert");
        } else if (decimalCharIndex > selectionStart && decimalCharIndex < selectionEnd) {
          newValueStr = this.insertText(inputValue2, text2, selectionStart, selectionEnd);
          this.updateValue(event, newValueStr, text2, "insert");
        } else if (decimalCharIndex === -1 && this.maxFractionDigits) {
          newValueStr = this.insertText(inputValue2, text2, selectionStart, selectionEnd);
          this.updateValue(event, newValueStr, text2, "insert");
        }
      } else {
        var maxFractionDigits2 = this.numberFormat.resolvedOptions().maximumFractionDigits;
        var operation = selectionStart !== selectionEnd ? "range-insert" : "insert";
        if (decimalCharIndex > 0 && selectionStart > decimalCharIndex) {
          if (selectionStart + text2.length - (decimalCharIndex + 1) <= maxFractionDigits2) {
            var charIndex = currencyCharIndex >= selectionStart ? currencyCharIndex - 1 : suffixCharIndex >= selectionStart ? suffixCharIndex : inputValue2.length;
            newValueStr = inputValue2.slice(0, selectionStart) + text2 + inputValue2.slice(selectionStart + text2.length, charIndex) + inputValue2.slice(charIndex);
            this.updateValue(event, newValueStr, text2, operation);
          }
        } else {
          newValueStr = this.insertText(inputValue2, text2, selectionStart, selectionEnd);
          this.updateValue(event, newValueStr, text2, operation);
        }
      }
    }, "insert"),
    insertText: /* @__PURE__ */ __name(function insertText(value3, text2, start2, end) {
      var textSplit = text2 === "." ? text2 : text2.split(".");
      if (textSplit.length === 2) {
        var decimalCharIndex = value3.slice(start2, end).search(this._decimal);
        this._decimal.lastIndex = 0;
        return decimalCharIndex > 0 ? value3.slice(0, start2) + this.formatValue(text2) + value3.slice(end) : this.formatValue(text2) || value3;
      } else if (end - start2 === value3.length) {
        return this.formatValue(text2);
      } else if (start2 === 0) {
        return text2 + value3.slice(end);
      } else if (end === value3.length) {
        return value3.slice(0, start2) + text2;
      } else {
        return value3.slice(0, start2) + text2 + value3.slice(end);
      }
    }, "insertText"),
    deleteRange: /* @__PURE__ */ __name(function deleteRange2(value3, start2, end) {
      var newValueStr;
      if (end - start2 === value3.length) newValueStr = "";
      else if (start2 === 0) newValueStr = value3.slice(end);
      else if (end === value3.length) newValueStr = value3.slice(0, start2);
      else newValueStr = value3.slice(0, start2) + value3.slice(end);
      return newValueStr;
    }, "deleteRange"),
    initCursor: /* @__PURE__ */ __name(function initCursor() {
      var selectionStart = this.$refs.input.$el.selectionStart;
      var inputValue2 = this.$refs.input.$el.value;
      var valueLength = inputValue2.length;
      var index2 = null;
      var prefixLength = (this.prefixChar || "").length;
      inputValue2 = inputValue2.replace(this._prefix, "");
      selectionStart = selectionStart - prefixLength;
      var _char4 = inputValue2.charAt(selectionStart);
      if (this.isNumeralChar(_char4)) {
        return selectionStart + prefixLength;
      }
      var i2 = selectionStart - 1;
      while (i2 >= 0) {
        _char4 = inputValue2.charAt(i2);
        if (this.isNumeralChar(_char4)) {
          index2 = i2 + prefixLength;
          break;
        } else {
          i2--;
        }
      }
      if (index2 !== null) {
        this.$refs.input.$el.setSelectionRange(index2 + 1, index2 + 1);
      } else {
        i2 = selectionStart;
        while (i2 < valueLength) {
          _char4 = inputValue2.charAt(i2);
          if (this.isNumeralChar(_char4)) {
            index2 = i2 + prefixLength;
            break;
          } else {
            i2++;
          }
        }
        if (index2 !== null) {
          this.$refs.input.$el.setSelectionRange(index2, index2);
        }
      }
      return index2 || 0;
    }, "initCursor"),
    onInputClick: /* @__PURE__ */ __name(function onInputClick() {
      var currentValue = this.$refs.input.$el.value;
      if (!this.readonly && currentValue !== getSelection$2()) {
        this.initCursor();
      }
    }, "onInputClick"),
    isNumeralChar: /* @__PURE__ */ __name(function isNumeralChar(_char5) {
      if (_char5.length === 1 && (this._numeral.test(_char5) || this._decimal.test(_char5) || this._group.test(_char5) || this._minusSign.test(_char5))) {
        this.resetRegex();
        return true;
      }
      return false;
    }, "isNumeralChar"),
    resetRegex: /* @__PURE__ */ __name(function resetRegex() {
      this._numeral.lastIndex = 0;
      this._decimal.lastIndex = 0;
      this._group.lastIndex = 0;
      this._minusSign.lastIndex = 0;
    }, "resetRegex"),
    updateValue: /* @__PURE__ */ __name(function updateValue2(event, valueStr, insertedValueStr, operation) {
      var currentValue = this.$refs.input.$el.value;
      var newValue2 = null;
      if (valueStr != null) {
        newValue2 = this.parseValue(valueStr);
        newValue2 = !newValue2 && !this.allowEmpty ? 0 : newValue2;
        this.updateInput(newValue2, insertedValueStr, operation, valueStr);
        this.handleOnInput(event, currentValue, newValue2);
      }
    }, "updateValue"),
    handleOnInput: /* @__PURE__ */ __name(function handleOnInput(event, currentValue, newValue2) {
      if (this.isValueChanged(currentValue, newValue2)) {
        var _this$formField$onInp, _this$formField;
        this.$emit("input", {
          originalEvent: event,
          value: newValue2,
          formattedValue: currentValue
        });
        (_this$formField$onInp = (_this$formField = this.formField).onInput) === null || _this$formField$onInp === void 0 || _this$formField$onInp.call(_this$formField, {
          originalEvent: event,
          value: newValue2
        });
      }
    }, "handleOnInput"),
    isValueChanged: /* @__PURE__ */ __name(function isValueChanged(currentValue, newValue2) {
      if (newValue2 === null && currentValue !== null) {
        return true;
      }
      if (newValue2 != null) {
        var parsedCurrentValue = typeof currentValue === "string" ? this.parseValue(currentValue) : currentValue;
        return newValue2 !== parsedCurrentValue;
      }
      return false;
    }, "isValueChanged"),
    validateValue: /* @__PURE__ */ __name(function validateValue(value3) {
      if (value3 === "-" || value3 == null) {
        return null;
      }
      if (this.min != null && value3 < this.min) {
        return this.min;
      }
      if (this.max != null && value3 > this.max) {
        return this.max;
      }
      return value3;
    }, "validateValue"),
    updateInput: /* @__PURE__ */ __name(function updateInput(value3, insertedValueStr, operation, valueStr) {
      insertedValueStr = insertedValueStr || "";
      var inputValue2 = this.$refs.input.$el.value;
      var newValue2 = this.formatValue(value3);
      var currentLength = inputValue2.length;
      if (newValue2 !== valueStr) {
        newValue2 = this.concatValues(newValue2, valueStr);
      }
      if (currentLength === 0) {
        this.$refs.input.$el.value = newValue2;
        this.$refs.input.$el.setSelectionRange(0, 0);
        var index2 = this.initCursor();
        var selectionEnd = index2 + insertedValueStr.length;
        this.$refs.input.$el.setSelectionRange(selectionEnd, selectionEnd);
      } else {
        var selectionStart = this.$refs.input.$el.selectionStart;
        var _selectionEnd = this.$refs.input.$el.selectionEnd;
        this.$refs.input.$el.value = newValue2;
        var newLength = newValue2.length;
        if (operation === "range-insert") {
          var startValue = this.parseValue((inputValue2 || "").slice(0, selectionStart));
          var startValueStr = startValue !== null ? startValue.toString() : "";
          var startExpr = startValueStr.split("").join("(".concat(this.groupChar, ")?"));
          var sRegex = new RegExp(startExpr, "g");
          sRegex.test(newValue2);
          var tExpr = insertedValueStr.split("").join("(".concat(this.groupChar, ")?"));
          var tRegex = new RegExp(tExpr, "g");
          tRegex.test(newValue2.slice(sRegex.lastIndex));
          _selectionEnd = sRegex.lastIndex + tRegex.lastIndex;
          this.$refs.input.$el.setSelectionRange(_selectionEnd, _selectionEnd);
        } else if (newLength === currentLength) {
          if (operation === "insert" || operation === "delete-back-single") {
            this.$refs.input.$el.setSelectionRange(_selectionEnd + 1, _selectionEnd + 1);
          } else if (operation === "delete-single") {
            this.$refs.input.$el.setSelectionRange(_selectionEnd - 1, _selectionEnd - 1);
          } else if (operation === "delete-range" || operation === "spin") {
            this.$refs.input.$el.setSelectionRange(_selectionEnd, _selectionEnd);
          }
        } else if (operation === "delete-back-single") {
          var prevChar = inputValue2.charAt(_selectionEnd - 1);
          var nextChar = inputValue2.charAt(_selectionEnd);
          var diff2 = currentLength - newLength;
          var isGroupChar = this._group.test(nextChar);
          if (isGroupChar && diff2 === 1) {
            _selectionEnd += 1;
          } else if (!isGroupChar && this.isNumeralChar(prevChar)) {
            _selectionEnd += -1 * diff2 + 1;
          }
          this._group.lastIndex = 0;
          this.$refs.input.$el.setSelectionRange(_selectionEnd, _selectionEnd);
        } else if (inputValue2 === "-" && operation === "insert") {
          this.$refs.input.$el.setSelectionRange(0, 0);
          var _index = this.initCursor();
          var _selectionEnd2 = _index + insertedValueStr.length + 1;
          this.$refs.input.$el.setSelectionRange(_selectionEnd2, _selectionEnd2);
        } else {
          _selectionEnd = _selectionEnd + (newLength - currentLength);
          this.$refs.input.$el.setSelectionRange(_selectionEnd, _selectionEnd);
        }
      }
      this.$refs.input.$el.setAttribute("aria-valuenow", value3);
    }, "updateInput"),
    concatValues: /* @__PURE__ */ __name(function concatValues(val1, val2) {
      if (val1 && val2) {
        var decimalCharIndex = val2.search(this._decimal);
        this._decimal.lastIndex = 0;
        if (this.suffixChar) {
          return decimalCharIndex !== -1 ? val1.replace(this.suffixChar, "").split(this._decimal)[0] + val2.replace(this.suffixChar, "").slice(decimalCharIndex) + this.suffixChar : val1;
        } else {
          return decimalCharIndex !== -1 ? val1.split(this._decimal)[0] + val2.slice(decimalCharIndex) : val1;
        }
      }
      return val1;
    }, "concatValues"),
    getDecimalLength: /* @__PURE__ */ __name(function getDecimalLength(value3) {
      if (value3) {
        var valueSplit = value3.split(this._decimal);
        if (valueSplit.length === 2) {
          return valueSplit[1].replace(this._suffix, "").trim().replace(/\s/g, "").replace(this._currency, "").length;
        }
      }
      return 0;
    }, "getDecimalLength"),
    updateModel: /* @__PURE__ */ __name(function updateModel3(event, value3) {
      this.writeValue(value3, event);
    }, "updateModel"),
    onInputFocus: /* @__PURE__ */ __name(function onInputFocus(event) {
      this.focused = true;
      if (!this.disabled && !this.readonly && this.$refs.input.$el.value !== getSelection$2() && this.highlightOnFocus) {
        event.target.select();
      }
      this.$emit("focus", event);
    }, "onInputFocus"),
    onInputBlur: /* @__PURE__ */ __name(function onInputBlur(event) {
      var _this$formField$onBlu, _this$formField2;
      this.focused = false;
      var input = event.target;
      var newValue2 = this.validateValue(this.parseValue(input.value));
      this.$emit("blur", {
        originalEvent: event,
        value: input.value
      });
      (_this$formField$onBlu = (_this$formField2 = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField2, event);
      input.value = this.formatValue(newValue2);
      input.setAttribute("aria-valuenow", newValue2);
      this.updateModel(event, newValue2);
      if (!this.disabled && !this.readonly && this.highlightOnFocus) {
        clearSelection$1();
      }
    }, "onInputBlur"),
    clearTimer: /* @__PURE__ */ __name(function clearTimer2() {
      if (this.timer) {
        clearInterval(this.timer);
      }
    }, "clearTimer"),
    maxBoundry: /* @__PURE__ */ __name(function maxBoundry() {
      return this.d_value >= this.max;
    }, "maxBoundry"),
    minBoundry: /* @__PURE__ */ __name(function minBoundry() {
      return this.d_value <= this.min;
    }, "minBoundry")
  },
  computed: {
    upButtonListeners: /* @__PURE__ */ __name(function upButtonListeners() {
      var _this2 = this;
      return {
        mousedown: /* @__PURE__ */ __name(function mousedown(event) {
          return _this2.onUpButtonMouseDown(event);
        }, "mousedown"),
        mouseup: /* @__PURE__ */ __name(function mouseup(event) {
          return _this2.onUpButtonMouseUp(event);
        }, "mouseup"),
        mouseleave: /* @__PURE__ */ __name(function mouseleave(event) {
          return _this2.onUpButtonMouseLeave(event);
        }, "mouseleave"),
        keydown: /* @__PURE__ */ __name(function keydown(event) {
          return _this2.onUpButtonKeyDown(event);
        }, "keydown"),
        keyup: /* @__PURE__ */ __name(function keyup(event) {
          return _this2.onUpButtonKeyUp(event);
        }, "keyup")
      };
    }, "upButtonListeners"),
    downButtonListeners: /* @__PURE__ */ __name(function downButtonListeners() {
      var _this3 = this;
      return {
        mousedown: /* @__PURE__ */ __name(function mousedown(event) {
          return _this3.onDownButtonMouseDown(event);
        }, "mousedown"),
        mouseup: /* @__PURE__ */ __name(function mouseup(event) {
          return _this3.onDownButtonMouseUp(event);
        }, "mouseup"),
        mouseleave: /* @__PURE__ */ __name(function mouseleave(event) {
          return _this3.onDownButtonMouseLeave(event);
        }, "mouseleave"),
        keydown: /* @__PURE__ */ __name(function keydown(event) {
          return _this3.onDownButtonKeyDown(event);
        }, "keydown"),
        keyup: /* @__PURE__ */ __name(function keyup(event) {
          return _this3.onDownButtonKeyUp(event);
        }, "keyup")
      };
    }, "downButtonListeners"),
    formattedValue: /* @__PURE__ */ __name(function formattedValue() {
      var val = !this.d_value && !this.allowEmpty ? 0 : this.d_value;
      return this.formatValue(val);
    }, "formattedValue"),
    getFormatter: /* @__PURE__ */ __name(function getFormatter() {
      return this.numberFormat;
    }, "getFormatter")
  },
  components: {
    InputText: script$P,
    AngleUpIcon: script$r,
    AngleDownIcon: script$s
  }
};
var _hoisted_1$1g = ["disabled"];
var _hoisted_2$W = ["disabled"];
var _hoisted_3$F = ["disabled"];
var _hoisted_4$s = ["disabled"];
function render$o(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_InputText = resolveComponent("InputText");
  return openBlock(), createElementBlock("span", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [createVNode(_component_InputText, {
    ref: "input",
    id: _ctx.inputId,
    role: "spinbutton",
    "class": normalizeClass([_ctx.cx("pcInputText"), _ctx.inputClass]),
    style: normalizeStyle(_ctx.inputStyle),
    value: $options.formattedValue,
    "aria-valuemin": _ctx.min,
    "aria-valuemax": _ctx.max,
    "aria-valuenow": _ctx.d_value,
    inputmode: _ctx.mode === "decimal" && !_ctx.minFractionDigits ? "numeric" : "decimal",
    disabled: _ctx.disabled,
    readonly: _ctx.readonly,
    placeholder: _ctx.placeholder,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    size: _ctx.size,
    invalid: _ctx.invalid,
    variant: _ctx.variant,
    onInput: $options.onUserInput,
    onKeydown: $options.onInputKeyDown,
    onKeypress: $options.onInputKeyPress,
    onPaste: $options.onPaste,
    onClick: $options.onInputClick,
    onFocus: $options.onInputFocus,
    onBlur: $options.onInputBlur,
    pt: _ctx.ptm("pcInputText"),
    unstyled: _ctx.unstyled
  }, null, 8, ["id", "class", "style", "value", "aria-valuemin", "aria-valuemax", "aria-valuenow", "inputmode", "disabled", "readonly", "placeholder", "aria-labelledby", "aria-label", "size", "invalid", "variant", "onInput", "onKeydown", "onKeypress", "onPaste", "onClick", "onFocus", "onBlur", "pt", "unstyled"]), _ctx.showButtons && _ctx.buttonLayout === "stacked" ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 0,
    "class": _ctx.cx("buttonGroup")
  }, _ctx.ptm("buttonGroup")), [renderSlot(_ctx.$slots, "incrementbutton", {
    listeners: $options.upButtonListeners
  }, function() {
    return [createBaseVNode("button", mergeProps$2({
      "class": [_ctx.cx("incrementButton"), _ctx.incrementButtonClass]
    }, toHandlers($options.upButtonListeners, true), {
      disabled: _ctx.disabled,
      tabindex: -1,
      "aria-hidden": "true",
      type: "button"
    }, _ctx.ptm("incrementButton")), [renderSlot(_ctx.$slots, _ctx.$slots.incrementicon ? "incrementicon" : "incrementbuttonicon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.incrementIcon || _ctx.incrementButtonIcon ? "span" : "AngleUpIcon"), mergeProps$2({
        "class": [_ctx.incrementIcon, _ctx.incrementButtonIcon]
      }, _ctx.ptm("incrementIcon"), {
        "data-pc-section": "incrementicon"
      }), null, 16, ["class"]))];
    })], 16, _hoisted_1$1g)];
  }), renderSlot(_ctx.$slots, "decrementbutton", {
    listeners: $options.downButtonListeners
  }, function() {
    return [createBaseVNode("button", mergeProps$2({
      "class": [_ctx.cx("decrementButton"), _ctx.decrementButtonClass]
    }, toHandlers($options.downButtonListeners, true), {
      disabled: _ctx.disabled,
      tabindex: -1,
      "aria-hidden": "true",
      type: "button"
    }, _ctx.ptm("decrementButton")), [renderSlot(_ctx.$slots, _ctx.$slots.decrementicon ? "decrementicon" : "decrementbuttonicon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.decrementIcon || _ctx.decrementButtonIcon ? "span" : "AngleDownIcon"), mergeProps$2({
        "class": [_ctx.decrementIcon, _ctx.decrementButtonIcon]
      }, _ctx.ptm("decrementIcon"), {
        "data-pc-section": "decrementicon"
      }), null, 16, ["class"]))];
    })], 16, _hoisted_2$W)];
  })], 16)) : createCommentVNode("", true), renderSlot(_ctx.$slots, "incrementbutton", {
    listeners: $options.upButtonListeners
  }, function() {
    return [_ctx.showButtons && _ctx.buttonLayout !== "stacked" ? (openBlock(), createElementBlock("button", mergeProps$2({
      key: 0,
      "class": [_ctx.cx("incrementButton"), _ctx.incrementButtonClass]
    }, toHandlers($options.upButtonListeners, true), {
      disabled: _ctx.disabled,
      tabindex: -1,
      "aria-hidden": "true",
      type: "button"
    }, _ctx.ptm("incrementButton")), [renderSlot(_ctx.$slots, _ctx.$slots.incrementicon ? "incrementicon" : "incrementbuttonicon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.incrementIcon || _ctx.incrementButtonIcon ? "span" : "AngleUpIcon"), mergeProps$2({
        "class": [_ctx.incrementIcon, _ctx.incrementButtonIcon]
      }, _ctx.ptm("incrementIcon"), {
        "data-pc-section": "incrementicon"
      }), null, 16, ["class"]))];
    })], 16, _hoisted_3$F)) : createCommentVNode("", true)];
  }), renderSlot(_ctx.$slots, "decrementbutton", {
    listeners: $options.downButtonListeners
  }, function() {
    return [_ctx.showButtons && _ctx.buttonLayout !== "stacked" ? (openBlock(), createElementBlock("button", mergeProps$2({
      key: 0,
      "class": [_ctx.cx("decrementButton"), _ctx.decrementButtonClass]
    }, toHandlers($options.downButtonListeners, true), {
      disabled: _ctx.disabled,
      tabindex: -1,
      "aria-hidden": "true",
      type: "button"
    }, _ctx.ptm("decrementButton")), [renderSlot(_ctx.$slots, _ctx.$slots.decrementicon ? "decrementicon" : "decrementbuttonicon", {}, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.decrementIcon || _ctx.decrementButtonIcon ? "span" : "AngleDownIcon"), mergeProps$2({
        "class": [_ctx.decrementIcon, _ctx.decrementButtonIcon]
      }, _ctx.ptm("decrementIcon"), {
        "data-pc-section": "decrementicon"
      }), null, 16, ["class"]))];
    })], 16, _hoisted_4$s)) : createCommentVNode("", true)];
  })], 16);
}
__name(render$o, "render$o");
script$q.render = render$o;
var theme$g = /* @__PURE__ */ __name(function theme30(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-toggleswitch {\n    display: inline-block;\n    width: ".concat(dt2("toggleswitch.width"), ";\n    height: ").concat(dt2("toggleswitch.height"), ";\n}\n\n.p-toggleswitch-input {\n    cursor: pointer;\n    appearance: none;\n    position: absolute;\n    top: 0;\n    inset-inline-start: 0;\n    width: 100%;\n    height: 100%;\n    padding: 0;\n    margin: 0;\n    opacity: 0;\n    z-index: 1;\n    outline: 0 none;\n    border-radius: ").concat(dt2("toggleswitch.border.radius"), ";\n}\n\n.p-toggleswitch-slider {\n    cursor: pointer;\n    width: 100%;\n    height: 100%;\n    border-width: ").concat(dt2("toggleswitch.border.width"), ";\n    border-style: solid;\n    border-color: ").concat(dt2("toggleswitch.border.color"), ";\n    background: ").concat(dt2("toggleswitch.background"), ";\n    transition: background ").concat(dt2("toggleswitch.transition.duration"), ", color ").concat(dt2("toggleswitch.transition.duration"), ", border-color ").concat(dt2("toggleswitch.transition.duration"), ", outline-color ").concat(dt2("toggleswitch.transition.duration"), ", box-shadow ").concat(dt2("toggleswitch.transition.duration"), ";\n    border-radius: ").concat(dt2("toggleswitch.border.radius"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("toggleswitch.shadow"), ";\n}\n\n.p-toggleswitch-handle {\n    position: absolute;\n    top: 50%;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    background: ").concat(dt2("toggleswitch.handle.background"), ";\n    color: ").concat(dt2("toggleswitch.handle.color"), ";\n    width: ").concat(dt2("toggleswitch.handle.size"), ";\n    height: ").concat(dt2("toggleswitch.handle.size"), ";\n    inset-inline-start: ").concat(dt2("toggleswitch.gap"), ";\n    margin-block-start: calc(-1 * calc(").concat(dt2("toggleswitch.handle.size"), " / 2));\n    border-radius: ").concat(dt2("toggleswitch.handle.border.radius"), ";\n    transition: background ").concat(dt2("toggleswitch.transition.duration"), ", color ").concat(dt2("toggleswitch.transition.duration"), ", inset-inline-start ").concat(dt2("toggleswitch.slide.duration"), ", box-shadow ").concat(dt2("toggleswitch.slide.duration"), ";\n}\n\n.p-toggleswitch.p-toggleswitch-checked .p-toggleswitch-slider {\n    background: ").concat(dt2("toggleswitch.checked.background"), ";\n    border-color: ").concat(dt2("toggleswitch.checked.border.color"), ";\n}\n\n.p-toggleswitch.p-toggleswitch-checked .p-toggleswitch-handle {\n    background: ").concat(dt2("toggleswitch.handle.checked.background"), ";\n    color: ").concat(dt2("toggleswitch.handle.checked.color"), ";\n    inset-inline-start: calc(").concat(dt2("toggleswitch.width"), " - calc(").concat(dt2("toggleswitch.handle.size"), " + ").concat(dt2("toggleswitch.gap"), "));\n}\n\n.p-toggleswitch:not(.p-disabled):has(.p-toggleswitch-input:hover) .p-toggleswitch-slider {\n    background: ").concat(dt2("toggleswitch.hover.background"), ";\n    border-color: ").concat(dt2("toggleswitch.hover.border.color"), ";\n}\n\n.p-toggleswitch:not(.p-disabled):has(.p-toggleswitch-input:hover) .p-toggleswitch-handle {\n    background: ").concat(dt2("toggleswitch.handle.hover.background"), ";\n    color: ").concat(dt2("toggleswitch.handle.hover.color"), ";\n}\n\n.p-toggleswitch:not(.p-disabled):has(.p-toggleswitch-input:hover).p-toggleswitch-checked .p-toggleswitch-slider {\n    background: ").concat(dt2("toggleswitch.checked.hover.background"), ";\n    border-color: ").concat(dt2("toggleswitch.checked.hover.border.color"), ";\n}\n\n.p-toggleswitch:not(.p-disabled):has(.p-toggleswitch-input:hover).p-toggleswitch-checked .p-toggleswitch-handle {\n    background: ").concat(dt2("toggleswitch.handle.checked.hover.background"), ";\n    color: ").concat(dt2("toggleswitch.handle.checked.hover.color"), ";\n}\n\n.p-toggleswitch:not(.p-disabled):has(.p-toggleswitch-input:focus-visible) .p-toggleswitch-slider {\n    box-shadow: ").concat(dt2("toggleswitch.focus.ring.shadow"), ";\n    outline: ").concat(dt2("toggleswitch.focus.ring.width"), " ").concat(dt2("toggleswitch.focus.ring.style"), " ").concat(dt2("toggleswitch.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("toggleswitch.focus.ring.offset"), ";\n}\n\n.p-toggleswitch.p-invalid > .p-toggleswitch-slider {\n    border-color: ").concat(dt2("toggleswitch.invalid.border.color"), ";\n}\n\n.p-toggleswitch.p-disabled {\n    opacity: 1;\n}\n\n.p-toggleswitch.p-disabled .p-toggleswitch-slider {\n    background: ").concat(dt2("toggleswitch.disabled.background"), ";\n}\n\n.p-toggleswitch.p-disabled .p-toggleswitch-handle {\n    background: ").concat(dt2("toggleswitch.handle.disabled.background"), ";\n}\n");
}, "theme");
var inlineStyles$4 = {
  root: {
    position: "relative"
  }
};
var classes$i = {
  root: /* @__PURE__ */ __name(function root21(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-toggleswitch p-component", {
      "p-toggleswitch-checked": instance.checked,
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid
    }];
  }, "root"),
  input: "p-toggleswitch-input",
  slider: "p-toggleswitch-slider",
  handle: "p-toggleswitch-handle"
};
var ToggleSwitchStyle = BaseStyle$1.extend({
  name: "toggleswitch",
  theme: theme$g,
  classes: classes$i,
  inlineStyles: inlineStyles$4
});
var script$1$i = {
  name: "BaseToggleSwitch",
  "extends": script$18,
  props: {
    trueValue: {
      type: null,
      "default": true
    },
    falseValue: {
      type: null,
      "default": false
    },
    readonly: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": null
    },
    inputId: {
      type: String,
      "default": null
    },
    inputClass: {
      type: [String, Object],
      "default": null
    },
    inputStyle: {
      type: Object,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: ToggleSwitchStyle,
  provide: /* @__PURE__ */ __name(function provide33() {
    return {
      $pcToggleSwitch: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$p = {
  name: "ToggleSwitch",
  "extends": script$1$i,
  inheritAttrs: false,
  emits: ["change", "focus", "blur"],
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions4(key) {
      var _ptm = key === "root" ? this.ptmi : this.ptm;
      return _ptm(key, {
        context: {
          checked: this.checked,
          disabled: this.disabled
        }
      });
    }, "getPTOptions"),
    onChange: /* @__PURE__ */ __name(function onChange3(event) {
      if (!this.disabled && !this.readonly) {
        var newValue2 = this.checked ? this.falseValue : this.trueValue;
        this.writeValue(newValue2, event);
        this.$emit("change", event);
      }
    }, "onChange"),
    onFocus: /* @__PURE__ */ __name(function onFocus5(event) {
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur5(event) {
      var _this$formField$onBlu, _this$formField;
      this.$emit("blur", event);
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur")
  },
  computed: {
    checked: /* @__PURE__ */ __name(function checked2() {
      return this.d_value === this.trueValue;
    }, "checked")
  }
};
var _hoisted_1$1f = ["data-p-checked", "data-p-disabled"];
var _hoisted_2$V = ["id", "checked", "tabindex", "disabled", "readonly", "aria-checked", "aria-labelledby", "aria-label", "aria-invalid"];
function render$n(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    style: _ctx.sx("root")
  }, $options.getPTOptions("root"), {
    "data-p-checked": $options.checked,
    "data-p-disabled": _ctx.disabled
  }), [createBaseVNode("input", mergeProps$2({
    id: _ctx.inputId,
    type: "checkbox",
    role: "switch",
    "class": [_ctx.cx("input"), _ctx.inputClass],
    style: _ctx.inputStyle,
    checked: $options.checked,
    tabindex: _ctx.tabindex,
    disabled: _ctx.disabled,
    readonly: _ctx.readonly,
    "aria-checked": $options.checked,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    "aria-invalid": _ctx.invalid || void 0,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onChange: _cache[2] || (_cache[2] = function() {
      return $options.onChange && $options.onChange.apply($options, arguments);
    })
  }, $options.getPTOptions("input")), null, 16, _hoisted_2$V), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("slider")
  }, $options.getPTOptions("slider")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("handle")
  }, $options.getPTOptions("handle")), [renderSlot(_ctx.$slots, "handle", {
    checked: $options.checked
  })], 16)], 16)], 16, _hoisted_1$1f);
}
__name(render$n, "render$n");
script$p.render = render$n;
const _sfc_main$1j = /* @__PURE__ */ defineComponent({
  __name: "CustomFormValue",
  props: {
    renderFunction: { type: Function }
  },
  setup(__props) {
    const props = __props;
    const container = ref(null);
    function renderContent() {
      if (container.value) {
        container.value.innerHTML = "";
        const element = props.renderFunction();
        container.value.appendChild(element);
      }
    }
    __name(renderContent, "renderContent");
    onMounted(renderContent);
    watch(() => props.renderFunction, renderContent);
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "container",
        ref: container
      }, null, 512);
    };
  }
});
var theme$f = /* @__PURE__ */ __name(function theme31(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-colorpicker {\n    display: inline-block;\n    position: relative;\n}\n\n.p-colorpicker-dragging {\n    cursor: pointer;\n}\n\n.p-colorpicker-preview {\n    width: ".concat(dt2("colorpicker.preview.width"), ";\n    height: ").concat(dt2("colorpicker.preview.height"), ";\n    padding: 0;\n    border: 0 none;\n    border-radius: ").concat(dt2("colorpicker.preview.border.radius"), ";\n    transition: background ").concat(dt2("colorpicker.transition.duration"), ", color ").concat(dt2("colorpicker.transition.duration"), ", border-color ").concat(dt2("colorpicker.transition.duration"), ", outline-color ").concat(dt2("colorpicker.transition.duration"), ", box-shadow ").concat(dt2("colorpicker.transition.duration"), ";\n    outline-color: transparent;\n    cursor: pointer;\n}\n\n.p-colorpicker-preview:enabled:focus-visible {\n    border-color: ").concat(dt2("colorpicker.preview.focus.border.color"), ";\n    box-shadow: ").concat(dt2("colorpicker.preview.focus.ring.shadow"), ";\n    outline: ").concat(dt2("colorpicker.preview.focus.ring.width"), " ").concat(dt2("colorpicker.preview.focus.ring.style"), " ").concat(dt2("colorpicker.preview.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("colorpicker.preview.focus.ring.offset"), ";\n}\n\n.p-colorpicker-panel {\n    background: ").concat(dt2("colorpicker.panel.background"), ";\n    border: 1px solid ").concat(dt2("colorpicker.panel.border.color"), ";\n    border-radius: ").concat(dt2("colorpicker.panel.border.radius"), ";\n    box-shadow: ").concat(dt2("colorpicker.panel.shadow"), ";\n    width: 193px;\n    height: 166px;\n    position: absolute;\n    top: 0;\n    left: 0;\n}\n\n.p-colorpicker-panel-inline {\n    box-shadow: none;\n    position: static;\n}\n\n.p-colorpicker-content {\n    position: relative;\n}\n\n.p-colorpicker-color-selector {\n    width: 150px;\n    height: 150px;\n    inset-block-start: 8px;\n    inset-inline-start: 8px;\n    position: absolute;\n}\n\n.p-colorpicker-color-background {\n    width: 100%;\n    height: 100%;\n    background: linear-gradient(to top, #000 0%, rgba(0, 0, 0, 0) 100%), linear-gradient(to right, #fff 0%, rgba(255, 255, 255, 0) 100%);\n}\n\n.p-colorpicker-color-handle {\n    position: absolute;\n    inset-block-start: 0px;\n    inset-inline-start: 150px;\n    border-radius: 100%;\n    width: 10px;\n    height: 10px;\n    border-width: 1px;\n    border-style: solid;\n    margin: -5px 0 0 -5px;\n    cursor: pointer;\n    opacity: 0.85;\n    border-color: ").concat(dt2("colorpicker.handle.color"), ";\n}\n\n.p-colorpicker-hue {\n    width: 17px;\n    height: 150px;\n    inset-block-start: 8px;\n    inset-inline-start: 167px;\n    position: absolute;\n    opacity: 0.85;\n    background: linear-gradient(0deg,\n        red 0,\n        #ff0 17%,\n        #0f0 33%,\n        #0ff 50%,\n        #00f 67%,\n        #f0f 83%,\n        red);\n}\n\n.p-colorpicker-hue-handle {\n    position: absolute;\n    inset-block-start: 150px;\n    inset-inline-start: 0px;\n    width: 21px;\n    margin-inline-start: -2px;\n    margin-block-start: -5px;\n    height: 10px;\n    border-width: 2px;\n    border-style: solid;\n    opacity: 0.85;\n    cursor: pointer;\n    border-color: ").concat(dt2("colorpicker.handle.color"), ";\n}\n");
}, "theme");
var classes$h = {
  root: "p-colorpicker p-component",
  preview: /* @__PURE__ */ __name(function preview(_ref2) {
    var props = _ref2.props;
    return ["p-colorpicker-preview", {
      "p-disabled": props.disabled
    }];
  }, "preview"),
  panel: /* @__PURE__ */ __name(function panel(_ref3) {
    var instance = _ref3.instance, props = _ref3.props;
    return ["p-colorpicker-panel", {
      "p-colorpicker-panel-inline": props.inline,
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid
    }];
  }, "panel"),
  colorSelector: "p-colorpicker-color-selector",
  colorBackground: "p-colorpicker-color-background",
  colorHandle: "p-colorpicker-color-handle",
  hue: "p-colorpicker-hue",
  hueHandle: "p-colorpicker-hue-handle"
};
var ColorPickerStyle = BaseStyle$1.extend({
  name: "colorpicker",
  theme: theme$f,
  classes: classes$h
});
var script$1$h = {
  name: "BaseColorPicker",
  "extends": script$18,
  props: {
    defaultColor: {
      type: null,
      "default": "ff0000"
    },
    inline: {
      type: Boolean,
      "default": false
    },
    format: {
      type: String,
      "default": "hex"
    },
    tabindex: {
      type: String,
      "default": null
    },
    autoZIndex: {
      type: Boolean,
      "default": true
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    inputId: {
      type: String,
      "default": null
    },
    panelClass: null,
    overlayClass: null
  },
  style: ColorPickerStyle,
  provide: /* @__PURE__ */ __name(function provide34() {
    return {
      $pcColorPicker: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$o = {
  name: "ColorPicker",
  "extends": script$1$h,
  inheritAttrs: false,
  emits: ["change", "show", "hide"],
  data: /* @__PURE__ */ __name(function data16() {
    return {
      overlayVisible: false
    };
  }, "data"),
  hsbValue: null,
  outsideClickListener: null,
  documentMouseMoveListener: null,
  documentMouseUpListener: null,
  scrollHandler: null,
  resizeListener: null,
  hueDragging: null,
  colorDragging: null,
  selfUpdate: null,
  picker: null,
  colorSelector: null,
  colorHandle: null,
  hueView: null,
  hueHandle: null,
  watch: {
    modelValue: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler10(newValue2) {
        this.hsbValue = this.toHSB(newValue2);
        if (this.selfUpdate) this.selfUpdate = false;
        else this.updateUI();
      }, "handler")
    }
  },
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount7() {
    this.unbindOutsideClickListener();
    this.unbindDragListeners();
    this.unbindResizeListener();
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    if (this.picker && this.autoZIndex) {
      ZIndex$1.clear(this.picker);
    }
    this.clearRefs();
  }, "beforeUnmount"),
  mounted: /* @__PURE__ */ __name(function mounted16() {
    this.updateUI();
  }, "mounted"),
  methods: {
    pickColor: /* @__PURE__ */ __name(function pickColor(event) {
      var rect = this.colorSelector.getBoundingClientRect();
      var top = rect.top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0);
      var left = rect.left + document.body.scrollLeft;
      var saturation = Math.floor(100 * Math.max(0, Math.min(150, (event.pageX || event.changedTouches[0].pageX) - left)) / 150);
      var brightness = Math.floor(100 * (150 - Math.max(0, Math.min(150, (event.pageY || event.changedTouches[0].pageY) - top))) / 150);
      this.hsbValue = this.validateHSB({
        h: this.hsbValue.h,
        s: saturation,
        b: brightness
      });
      this.selfUpdate = true;
      this.updateColorHandle();
      this.updateInput();
      this.updateModel(event);
    }, "pickColor"),
    pickHue: /* @__PURE__ */ __name(function pickHue(event) {
      var top = this.hueView.getBoundingClientRect().top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0);
      this.hsbValue = this.validateHSB({
        h: Math.floor(360 * (150 - Math.max(0, Math.min(150, (event.pageY || event.changedTouches[0].pageY) - top))) / 150),
        s: 100,
        b: 100
      });
      this.selfUpdate = true;
      this.updateColorSelector();
      this.updateHue();
      this.updateModel(event);
      this.updateInput();
    }, "pickHue"),
    updateModel: /* @__PURE__ */ __name(function updateModel4(event) {
      var value3 = this.d_value;
      switch (this.format) {
        case "hex":
          value3 = this.HSBtoHEX(this.hsbValue);
          break;
        case "rgb":
          value3 = this.HSBtoRGB(this.hsbValue);
          break;
        case "hsb":
          value3 = this.hsbValue;
          break;
      }
      this.writeValue(value3, event);
      this.$emit("change", {
        event,
        value: value3
      });
    }, "updateModel"),
    updateColorSelector: /* @__PURE__ */ __name(function updateColorSelector() {
      if (this.colorSelector) {
        var hsbValue = this.validateHSB({
          h: this.hsbValue.h,
          s: 100,
          b: 100
        });
        this.colorSelector.style.backgroundColor = "#" + this.HSBtoHEX(hsbValue);
      }
    }, "updateColorSelector"),
    updateColorHandle: /* @__PURE__ */ __name(function updateColorHandle() {
      if (this.colorHandle) {
        this.colorHandle.style.left = Math.floor(150 * this.hsbValue.s / 100) + "px";
        this.colorHandle.style.top = Math.floor(150 * (100 - this.hsbValue.b) / 100) + "px";
      }
    }, "updateColorHandle"),
    updateHue: /* @__PURE__ */ __name(function updateHue() {
      if (this.hueHandle) {
        this.hueHandle.style.top = Math.floor(150 - 150 * this.hsbValue.h / 360) + "px";
      }
    }, "updateHue"),
    updateInput: /* @__PURE__ */ __name(function updateInput2() {
      if (this.$refs.input) {
        this.$refs.input.style.backgroundColor = "#" + this.HSBtoHEX(this.hsbValue);
      }
    }, "updateInput"),
    updateUI: /* @__PURE__ */ __name(function updateUI() {
      this.updateHue();
      this.updateColorHandle();
      this.updateInput();
      this.updateColorSelector();
    }, "updateUI"),
    validateHSB: /* @__PURE__ */ __name(function validateHSB(hsb) {
      return {
        h: Math.min(360, Math.max(0, hsb.h)),
        s: Math.min(100, Math.max(0, hsb.s)),
        b: Math.min(100, Math.max(0, hsb.b))
      };
    }, "validateHSB"),
    validateRGB: /* @__PURE__ */ __name(function validateRGB(rgb) {
      return {
        r: Math.min(255, Math.max(0, rgb.r)),
        g: Math.min(255, Math.max(0, rgb.g)),
        b: Math.min(255, Math.max(0, rgb.b))
      };
    }, "validateRGB"),
    validateHEX: /* @__PURE__ */ __name(function validateHEX(hex) {
      var len = 6 - hex.length;
      if (len > 0) {
        var o2 = [];
        for (var i2 = 0; i2 < len; i2++) {
          o2.push("0");
        }
        o2.push(hex);
        hex = o2.join("");
      }
      return hex;
    }, "validateHEX"),
    HEXtoRGB: /* @__PURE__ */ __name(function HEXtoRGB(hex) {
      var hexValue = parseInt(hex.indexOf("#") > -1 ? hex.substring(1) : hex, 16);
      return {
        r: hexValue >> 16,
        g: (hexValue & 65280) >> 8,
        b: hexValue & 255
      };
    }, "HEXtoRGB"),
    HEXtoHSB: /* @__PURE__ */ __name(function HEXtoHSB(hex) {
      return this.RGBtoHSB(this.HEXtoRGB(hex));
    }, "HEXtoHSB"),
    RGBtoHSB: /* @__PURE__ */ __name(function RGBtoHSB(rgb) {
      var hsb = {
        h: 0,
        s: 0,
        b: 0
      };
      var min = Math.min(rgb.r, rgb.g, rgb.b);
      var max = Math.max(rgb.r, rgb.g, rgb.b);
      var delta2 = max - min;
      hsb.b = max;
      hsb.s = max !== 0 ? 255 * delta2 / max : 0;
      if (hsb.s !== 0) {
        if (rgb.r === max) {
          hsb.h = (rgb.g - rgb.b) / delta2;
        } else if (rgb.g === max) {
          hsb.h = 2 + (rgb.b - rgb.r) / delta2;
        } else {
          hsb.h = 4 + (rgb.r - rgb.g) / delta2;
        }
      } else {
        hsb.h = -1;
      }
      hsb.h *= 60;
      if (hsb.h < 0) {
        hsb.h += 360;
      }
      hsb.s *= 100 / 255;
      hsb.b *= 100 / 255;
      return hsb;
    }, "RGBtoHSB"),
    HSBtoRGB: /* @__PURE__ */ __name(function HSBtoRGB(hsb) {
      var rgb = {
        r: null,
        g: null,
        b: null
      };
      var h2 = Math.round(hsb.h);
      var s2 = Math.round(hsb.s * 255 / 100);
      var v2 = Math.round(hsb.b * 255 / 100);
      if (s2 === 0) {
        rgb = {
          r: v2,
          g: v2,
          b: v2
        };
      } else {
        var t1 = v2;
        var t2 = (255 - s2) * v2 / 255;
        var t3 = (t1 - t2) * (h2 % 60) / 60;
        if (h2 === 360) h2 = 0;
        if (h2 < 60) {
          rgb.r = t1;
          rgb.b = t2;
          rgb.g = t2 + t3;
        } else if (h2 < 120) {
          rgb.g = t1;
          rgb.b = t2;
          rgb.r = t1 - t3;
        } else if (h2 < 180) {
          rgb.g = t1;
          rgb.r = t2;
          rgb.b = t2 + t3;
        } else if (h2 < 240) {
          rgb.b = t1;
          rgb.r = t2;
          rgb.g = t1 - t3;
        } else if (h2 < 300) {
          rgb.b = t1;
          rgb.g = t2;
          rgb.r = t2 + t3;
        } else if (h2 < 360) {
          rgb.r = t1;
          rgb.g = t2;
          rgb.b = t1 - t3;
        } else {
          rgb.r = 0;
          rgb.g = 0;
          rgb.b = 0;
        }
      }
      return {
        r: Math.round(rgb.r),
        g: Math.round(rgb.g),
        b: Math.round(rgb.b)
      };
    }, "HSBtoRGB"),
    RGBtoHEX: /* @__PURE__ */ __name(function RGBtoHEX(rgb) {
      var hex = [rgb.r.toString(16), rgb.g.toString(16), rgb.b.toString(16)];
      for (var key in hex) {
        if (hex[key].length === 1) {
          hex[key] = "0" + hex[key];
        }
      }
      return hex.join("");
    }, "RGBtoHEX"),
    HSBtoHEX: /* @__PURE__ */ __name(function HSBtoHEX(hsb) {
      return this.RGBtoHEX(this.HSBtoRGB(hsb));
    }, "HSBtoHEX"),
    toHSB: /* @__PURE__ */ __name(function toHSB(value3) {
      var hsb;
      if (value3) {
        switch (this.format) {
          case "hex":
            hsb = this.HEXtoHSB(value3);
            break;
          case "rgb":
            hsb = this.RGBtoHSB(value3);
            break;
          case "hsb":
            hsb = value3;
            break;
        }
      } else {
        hsb = this.HEXtoHSB(this.defaultColor);
      }
      return hsb;
    }, "toHSB"),
    onOverlayEnter: /* @__PURE__ */ __name(function onOverlayEnter2(el) {
      this.updateUI();
      this.alignOverlay();
      this.bindOutsideClickListener();
      this.bindScrollListener();
      this.bindResizeListener();
      if (this.autoZIndex) {
        ZIndex$1.set("overlay", el, this.baseZIndex, this.$primevue.config.zIndex.overlay);
      }
      this.$emit("show");
    }, "onOverlayEnter"),
    onOverlayLeave: /* @__PURE__ */ __name(function onOverlayLeave2() {
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
      this.clearRefs();
      this.$emit("hide");
    }, "onOverlayLeave"),
    onOverlayAfterLeave: /* @__PURE__ */ __name(function onOverlayAfterLeave2(el) {
      if (this.autoZIndex) {
        ZIndex$1.clear(el);
      }
    }, "onOverlayAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay3() {
      if (this.appendTo === "self") relativePosition$1(this.picker, this.$refs.input);
      else absolutePosition$1(this.picker, this.$refs.input);
    }, "alignOverlay"),
    onInputClick: /* @__PURE__ */ __name(function onInputClick2() {
      if (this.disabled) {
        return;
      }
      this.overlayVisible = !this.overlayVisible;
    }, "onInputClick"),
    onInputKeydown: /* @__PURE__ */ __name(function onInputKeydown(event) {
      switch (event.code) {
        case "Space":
          this.overlayVisible = !this.overlayVisible;
          event.preventDefault();
          break;
        case "Escape":
        case "Tab":
          this.overlayVisible = false;
          break;
      }
    }, "onInputKeydown"),
    onInputBlur: /* @__PURE__ */ __name(function onInputBlur2(event) {
      var _this$formField$onBlu, _this$formField;
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField);
    }, "onInputBlur"),
    onColorMousedown: /* @__PURE__ */ __name(function onColorMousedown(event) {
      if (this.disabled) {
        return;
      }
      this.bindDragListeners();
      this.onColorDragStart(event);
    }, "onColorMousedown"),
    onColorDragStart: /* @__PURE__ */ __name(function onColorDragStart(event) {
      if (this.disabled) {
        return;
      }
      this.colorDragging = true;
      this.pickColor(event);
      this.$el.setAttribute("p-colorpicker-dragging", "true");
      !this.isUnstyled && addClass$1(this.$el, "p-colorpicker-dragging");
      event.preventDefault();
    }, "onColorDragStart"),
    onDrag: /* @__PURE__ */ __name(function onDrag(event) {
      if (this.colorDragging) {
        this.pickColor(event);
        event.preventDefault();
      }
      if (this.hueDragging) {
        this.pickHue(event);
        event.preventDefault();
      }
    }, "onDrag"),
    onDragEnd: /* @__PURE__ */ __name(function onDragEnd() {
      this.colorDragging = false;
      this.hueDragging = false;
      this.$el.setAttribute("p-colorpicker-dragging", "false");
      !this.isUnstyled && removeClass$1(this.$el, "p-colorpicker-dragging");
      this.unbindDragListeners();
    }, "onDragEnd"),
    onHueMousedown: /* @__PURE__ */ __name(function onHueMousedown(event) {
      if (this.disabled) {
        return;
      }
      this.bindDragListeners();
      this.onHueDragStart(event);
    }, "onHueMousedown"),
    onHueDragStart: /* @__PURE__ */ __name(function onHueDragStart(event) {
      if (this.disabled) {
        return;
      }
      this.hueDragging = true;
      this.pickHue(event);
      !this.isUnstyled && addClass$1(this.$el, "p-colorpicker-dragging");
    }, "onHueDragStart"),
    isInputClicked: /* @__PURE__ */ __name(function isInputClicked(event) {
      return this.$refs.input && this.$refs.input.isSameNode(event.target);
    }, "isInputClicked"),
    bindDragListeners: /* @__PURE__ */ __name(function bindDragListeners() {
      this.bindDocumentMouseMoveListener();
      this.bindDocumentMouseUpListener();
    }, "bindDragListeners"),
    unbindDragListeners: /* @__PURE__ */ __name(function unbindDragListeners() {
      this.unbindDocumentMouseMoveListener();
      this.unbindDocumentMouseUpListener();
    }, "unbindDragListeners"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener2() {
      var _this = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          if (_this.overlayVisible && _this.picker && !_this.picker.contains(event.target) && !_this.isInputClicked(event)) {
            _this.overlayVisible = false;
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener2() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener3() {
      var _this2 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.$refs.container, function() {
          if (_this2.overlayVisible) {
            _this2.overlayVisible = false;
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener3() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener3() {
      var _this3 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this3.overlayVisible && !isTouchDevice$1()) {
            _this3.overlayVisible = false;
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener3() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    bindDocumentMouseMoveListener: /* @__PURE__ */ __name(function bindDocumentMouseMoveListener() {
      if (!this.documentMouseMoveListener) {
        this.documentMouseMoveListener = this.onDrag.bind(this);
        document.addEventListener("mousemove", this.documentMouseMoveListener);
      }
    }, "bindDocumentMouseMoveListener"),
    unbindDocumentMouseMoveListener: /* @__PURE__ */ __name(function unbindDocumentMouseMoveListener() {
      if (this.documentMouseMoveListener) {
        document.removeEventListener("mousemove", this.documentMouseMoveListener);
        this.documentMouseMoveListener = null;
      }
    }, "unbindDocumentMouseMoveListener"),
    bindDocumentMouseUpListener: /* @__PURE__ */ __name(function bindDocumentMouseUpListener() {
      if (!this.documentMouseUpListener) {
        this.documentMouseUpListener = this.onDragEnd.bind(this);
        document.addEventListener("mouseup", this.documentMouseUpListener);
      }
    }, "bindDocumentMouseUpListener"),
    unbindDocumentMouseUpListener: /* @__PURE__ */ __name(function unbindDocumentMouseUpListener() {
      if (this.documentMouseUpListener) {
        document.removeEventListener("mouseup", this.documentMouseUpListener);
        this.documentMouseUpListener = null;
      }
    }, "unbindDocumentMouseUpListener"),
    pickerRef: /* @__PURE__ */ __name(function pickerRef(el) {
      this.picker = el;
    }, "pickerRef"),
    colorSelectorRef: /* @__PURE__ */ __name(function colorSelectorRef(el) {
      this.colorSelector = el;
    }, "colorSelectorRef"),
    colorHandleRef: /* @__PURE__ */ __name(function colorHandleRef(el) {
      this.colorHandle = el;
    }, "colorHandleRef"),
    hueViewRef: /* @__PURE__ */ __name(function hueViewRef(el) {
      this.hueView = el;
    }, "hueViewRef"),
    hueHandleRef: /* @__PURE__ */ __name(function hueHandleRef(el) {
      this.hueHandle = el;
    }, "hueHandleRef"),
    clearRefs: /* @__PURE__ */ __name(function clearRefs() {
      this.picker = null;
      this.colorSelector = null;
      this.colorHandle = null;
      this.hueView = null;
      this.hueHandle = null;
    }, "clearRefs"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick2(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.$el
      });
    }, "onOverlayClick")
  },
  components: {
    Portal: script$$
  }
};
function _typeof$7(o2) {
  "@babel/helpers - typeof";
  return _typeof$7 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$7(o2);
}
__name(_typeof$7, "_typeof$7");
function ownKeys$9(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$9, "ownKeys$9");
function _objectSpread$9(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$9(Object(t2), true).forEach(function(r3) {
      _defineProperty$7(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$9(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$9, "_objectSpread$9");
function _defineProperty$7(e2, r2, t2) {
  return (r2 = _toPropertyKey$6(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$7, "_defineProperty$7");
function _toPropertyKey$6(t2) {
  var i2 = _toPrimitive$6(t2, "string");
  return "symbol" == _typeof$7(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$6, "_toPropertyKey$6");
function _toPrimitive$6(t2, r2) {
  if ("object" != _typeof$7(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$7(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$6, "_toPrimitive$6");
var _hoisted_1$1e = ["id", "tabindex", "disabled"];
function render$m(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Portal = resolveComponent("Portal");
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "container",
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [!_ctx.inline ? (openBlock(), createElementBlock("input", mergeProps$2({
    key: 0,
    ref: "input",
    id: _ctx.inputId,
    type: "text",
    "class": _ctx.cx("preview"),
    readonly: "",
    tabindex: _ctx.tabindex,
    disabled: _ctx.disabled,
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.onInputClick && $options.onInputClick.apply($options, arguments);
    }),
    onKeydown: _cache[1] || (_cache[1] = function() {
      return $options.onInputKeydown && $options.onInputKeydown.apply($options, arguments);
    }),
    onBlur: _cache[2] || (_cache[2] = function() {
      return $options.onInputBlur && $options.onInputBlur.apply($options, arguments);
    })
  }, _ctx.ptm("preview")), null, 16, _hoisted_1$1e)) : createCommentVNode("", true), createVNode(_component_Portal, {
    appendTo: _ctx.appendTo,
    disabled: _ctx.inline
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-connected-overlay",
        onEnter: $options.onOverlayEnter,
        onLeave: $options.onOverlayLeave,
        onAfterLeave: $options.onOverlayAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [(_ctx.inline ? true : $data.overlayVisible) ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.pickerRef,
            "class": [_ctx.cx("panel"), _ctx.panelClass, _ctx.overlayClass],
            onClick: _cache[11] || (_cache[11] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            })
          }, _objectSpread$9(_objectSpread$9({}, _ctx.ptm("panel")), _ctx.ptm("overlay"))), [createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("content")
          }, _ctx.ptm("content")), [createBaseVNode("div", mergeProps$2({
            ref: $options.colorSelectorRef,
            "class": _ctx.cx("colorSelector"),
            onMousedown: _cache[3] || (_cache[3] = function($event) {
              return $options.onColorMousedown($event);
            }),
            onTouchstart: _cache[4] || (_cache[4] = function($event) {
              return $options.onColorDragStart($event);
            }),
            onTouchmove: _cache[5] || (_cache[5] = function($event) {
              return $options.onDrag($event);
            }),
            onTouchend: _cache[6] || (_cache[6] = function($event) {
              return $options.onDragEnd();
            })
          }, _ctx.ptm("colorSelector")), [createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("colorBackground")
          }, _ctx.ptm("colorBackground")), [createBaseVNode("div", mergeProps$2({
            ref: $options.colorHandleRef,
            "class": _ctx.cx("colorHandle")
          }, _ctx.ptm("colorHandle")), null, 16)], 16)], 16), createBaseVNode("div", mergeProps$2({
            ref: $options.hueViewRef,
            "class": _ctx.cx("hue"),
            onMousedown: _cache[7] || (_cache[7] = function($event) {
              return $options.onHueMousedown($event);
            }),
            onTouchstart: _cache[8] || (_cache[8] = function($event) {
              return $options.onHueDragStart($event);
            }),
            onTouchmove: _cache[9] || (_cache[9] = function($event) {
              return $options.onDrag($event);
            }),
            onTouchend: _cache[10] || (_cache[10] = function($event) {
              return $options.onDragEnd();
            })
          }, _ctx.ptm("hue")), [createBaseVNode("div", mergeProps$2({
            ref: $options.hueHandleRef,
            "class": _ctx.cx("hueHandle")
          }, _ctx.ptm("hueHandle")), null, 16)], 16)], 16)], 16)) : createCommentVNode("", true)];
        }),
        _: 1
      }, 16, ["onEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 1
  }, 8, ["appendTo", "disabled"])], 16);
}
__name(render$m, "render$m");
script$o.render = render$m;
const _hoisted_1$1d = { class: "color-picker-wrapper flex items-center gap-2" };
const _sfc_main$1i = /* @__PURE__ */ defineComponent({
  ...{
    inheritAttrs: false
  },
  __name: "FormColorPicker",
  props: /* @__PURE__ */ mergeModels({
    defaultValue: {},
    label: {}
  }, {
    "modelValue": {},
    "modelModifiers": {}
  }),
  emits: ["update:modelValue"],
  setup(__props) {
    const modelValue3 = useModel(__props, "modelValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1d, [
        createVNode(unref(script$o), mergeProps$2({
          modelValue: modelValue3.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => modelValue3.value = $event)
        }, _ctx.$attrs), null, 16, ["modelValue"]),
        createVNode(unref(script$P), {
          modelValue: modelValue3.value,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => modelValue3.value = $event),
          class: "w-28",
          placeholder: _ctx.label
        }, null, 8, ["modelValue", "placeholder"])
      ]);
    };
  }
});
const _hoisted_1$1c = { class: "image-upload-wrapper" };
const _hoisted_2$U = { class: "flex gap-2 items-center" };
const _hoisted_3$E = ["src"];
const _hoisted_4$r = {
  key: 1,
  class: "pi pi-image text-gray-400 text-xl"
};
const _hoisted_5$m = { class: "flex flex-col gap-2" };
const _sfc_main$1h = /* @__PURE__ */ defineComponent({
  __name: "FormImageUpload",
  props: {
    modelValue: {}
  },
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const fileInput2 = ref(null);
    const triggerFileInput = /* @__PURE__ */ __name(() => {
      fileInput2.value?.click();
    }, "triggerFileInput");
    const handleFileUpload = /* @__PURE__ */ __name((event) => {
      const target2 = event.target;
      if (target2.files && target2.files[0]) {
        const file = target2.files[0];
        const reader = new FileReader();
        reader.onload = (e2) => {
          emit2("update:modelValue", e2.target?.result);
        };
        reader.readAsDataURL(file);
      }
    }, "handleFileUpload");
    const clearImage = /* @__PURE__ */ __name(() => {
      emit2("update:modelValue", "");
      if (fileInput2.value) {
        fileInput2.value.value = "";
      }
    }, "clearImage");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1c, [
        createBaseVNode("div", _hoisted_2$U, [
          createBaseVNode("div", {
            class: normalizeClass(["preview-box border rounded p-2 w-16 h-16 flex items-center justify-center", { "bg-gray-100 dark:bg-gray-800": !_ctx.modelValue }])
          }, [
            _ctx.modelValue ? (openBlock(), createElementBlock("img", {
              key: 0,
              src: _ctx.modelValue,
              class: "max-w-full max-h-full object-contain"
            }, null, 8, _hoisted_3$E)) : (openBlock(), createElementBlock("i", _hoisted_4$r))
          ], 2),
          createBaseVNode("div", _hoisted_5$m, [
            createVNode(unref(script$10), {
              icon: "pi pi-upload",
              label: _ctx.$t("g.upload"),
              size: "small",
              onClick: triggerFileInput
            }, null, 8, ["label"]),
            _ctx.modelValue ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              class: "w-full",
              outlined: "",
              icon: "pi pi-trash",
              severity: "danger",
              size: "small",
              onClick: clearImage
            })) : createCommentVNode("", true)
          ])
        ]),
        createBaseVNode("input", {
          ref_key: "fileInput",
          ref: fileInput2,
          type: "file",
          class: "hidden",
          accept: "image/*",
          onChange: handleFileUpload
        }, null, 544)
      ]);
    };
  }
});
var theme$e = /* @__PURE__ */ __name(function theme32(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-knob-range {\n    fill: none;\n    transition: stroke 0.1s ease-in;\n}\n\n.p-knob-value {\n    animation-name: p-knob-dash-frame;\n    animation-fill-mode: forwards;\n    fill: none;\n}\n\n.p-knob-text {\n    font-size: 1.3rem;\n    text-align: center;\n}\n\n.p-knob svg {\n    border-radius: 50%;\n    outline-color: transparent;\n    transition: background ".concat(dt2("knob.transition.duration"), ", color ").concat(dt2("knob.transition.duration"), ", outline-color ").concat(dt2("knob.transition.duration"), ", box-shadow ").concat(dt2("knob.transition.duration"), ";\n}\n\n.p-knob svg:focus-visible {\n    box-shadow: ").concat(dt2("knob.focus.ring.shadow"), ";\n    outline: ").concat(dt2("knob.focus.ring.width"), " ").concat(dt2("knob.focus.ring.style"), " ").concat(dt2("knob.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("knob.focus.ring.offset"), ";\n}\n\n@keyframes p-knob-dash-frame {\n    100% {\n        stroke-dashoffset: 0;\n    }\n}\n");
}, "theme");
var classes$g = {
  root: /* @__PURE__ */ __name(function root22(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-knob p-component", {
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid
    }];
  }, "root"),
  range: "p-knob-range",
  value: "p-knob-value",
  text: "p-knob-text"
};
var KnobStyle = BaseStyle$1.extend({
  name: "knob",
  theme: theme$e,
  classes: classes$g
});
var script$1$g = {
  name: "BaseKnob",
  "extends": script$18,
  props: {
    size: {
      type: Number,
      "default": 100
    },
    readonly: {
      type: Boolean,
      "default": false
    },
    step: {
      type: Number,
      "default": 1
    },
    min: {
      type: Number,
      "default": 0
    },
    max: {
      type: Number,
      "default": 100
    },
    valueColor: {
      type: String,
      "default": /* @__PURE__ */ __name(function _default5() {
        return $dt$1("knob.value.background").variable;
      }, "_default")
    },
    rangeColor: {
      type: String,
      "default": /* @__PURE__ */ __name(function _default6() {
        return $dt$1("knob.range.background").variable;
      }, "_default")
    },
    textColor: {
      type: String,
      "default": /* @__PURE__ */ __name(function _default7() {
        return $dt$1("knob.text.color").variable;
      }, "_default")
    },
    strokeWidth: {
      type: Number,
      "default": 14
    },
    showValue: {
      type: Boolean,
      "default": true
    },
    valueTemplate: {
      type: [String, Function],
      "default": "{value}"
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: KnobStyle,
  provide: /* @__PURE__ */ __name(function provide35() {
    return {
      $pcKnob: this,
      $parentInstance: this
    };
  }, "provide")
};
var Math_PI = 3.14159265358979;
var script$n = {
  name: "Knob",
  "extends": script$1$g,
  inheritAttrs: false,
  emits: ["change"],
  data: /* @__PURE__ */ __name(function data17() {
    return {
      radius: 40,
      midX: 50,
      midY: 50,
      minRadians: 4 * Math_PI / 3,
      maxRadians: -Math_PI / 3
    };
  }, "data"),
  methods: {
    updateValueByOffset: /* @__PURE__ */ __name(function updateValueByOffset(offsetX, offsetY) {
      var dx = offsetX - this.size / 2;
      var dy = this.size / 2 - offsetY;
      var angle = Math.atan2(dy, dx);
      var start2 = -Math_PI / 2 - Math_PI / 6;
      this.updateModel(angle, start2);
    }, "updateValueByOffset"),
    updateModel: /* @__PURE__ */ __name(function updateModel5(angle, start2) {
      var mappedValue;
      if (angle > this.maxRadians) mappedValue = this.mapRange(angle, this.minRadians, this.maxRadians, this.min, this.max);
      else if (angle < start2) mappedValue = this.mapRange(angle + 2 * Math_PI, this.minRadians, this.maxRadians, this.min, this.max);
      else return;
      var newValue2 = Math.round((mappedValue - this.min) / this.step) * this.step + this.min;
      this.writeValue(newValue2);
      this.$emit("change", newValue2);
    }, "updateModel"),
    updateModelValue: /* @__PURE__ */ __name(function updateModelValue(newValue2) {
      if (newValue2 > this.max) this.writeValue(this.max);
      else if (newValue2 < this.min) this.writeValue(this.min);
      else this.writeValue(newValue2);
    }, "updateModelValue"),
    mapRange: /* @__PURE__ */ __name(function mapRange(x2, inMin, inMax, outMin, outMax) {
      return (x2 - inMin) * (outMax - outMin) / (inMax - inMin) + outMin;
    }, "mapRange"),
    onClick: /* @__PURE__ */ __name(function onClick2(event) {
      if (!this.disabled && !this.readonly) {
        this.updateValueByOffset(event.offsetX, event.offsetY);
      }
    }, "onClick"),
    onBlur: /* @__PURE__ */ __name(function onBlur6(event) {
      var _this$formField$onBlu, _this$formField;
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur"),
    onMouseDown: /* @__PURE__ */ __name(function onMouseDown2(event) {
      if (!this.disabled && !this.readonly) {
        window.addEventListener("mousemove", this.onMouseMove);
        window.addEventListener("mouseup", this.onMouseUp);
        event.preventDefault();
      }
    }, "onMouseDown"),
    onMouseUp: /* @__PURE__ */ __name(function onMouseUp(event) {
      if (!this.disabled && !this.readonly) {
        window.removeEventListener("mousemove", this.onMouseMove);
        window.removeEventListener("mouseup", this.onMouseUp);
        event.preventDefault();
      }
    }, "onMouseUp"),
    onTouchStart: /* @__PURE__ */ __name(function onTouchStart(event) {
      if (!this.disabled && !this.readonly) {
        window.addEventListener("touchmove", this.onTouchMove);
        window.addEventListener("touchend", this.onTouchEnd);
        event.preventDefault();
      }
    }, "onTouchStart"),
    onTouchEnd: /* @__PURE__ */ __name(function onTouchEnd(event) {
      if (!this.disabled && !this.readonly) {
        window.removeEventListener("touchmove", this.onTouchMove);
        window.removeEventListener("touchend", this.onTouchEnd);
        event.preventDefault();
      }
    }, "onTouchEnd"),
    onMouseMove: /* @__PURE__ */ __name(function onMouseMove(event) {
      if (!this.disabled && !this.readonly) {
        this.updateValueByOffset(event.offsetX, event.offsetY);
        event.preventDefault();
      }
    }, "onMouseMove"),
    onTouchMove: /* @__PURE__ */ __name(function onTouchMove(event) {
      if (!this.disabled && !this.readonly && event.touches.length == 1) {
        var rect = this.$el.getBoundingClientRect();
        var touch = event.targetTouches.item(0);
        var offsetX = touch.clientX - rect.left;
        var offsetY = touch.clientY - rect.top;
        this.updateValueByOffset(offsetX, offsetY);
      }
    }, "onTouchMove"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown6(event) {
      if (!this.disabled && !this.readonly) {
        switch (event.code) {
          case "ArrowRight":
          case "ArrowUp": {
            event.preventDefault();
            this.updateModelValue(this.d_value + this.step);
            break;
          }
          case "ArrowLeft":
          case "ArrowDown": {
            event.preventDefault();
            this.updateModelValue(this.d_value - this.step);
            break;
          }
          case "Home": {
            event.preventDefault();
            this.writeValue(this.min);
            break;
          }
          case "End": {
            event.preventDefault();
            this.writeValue(this.max);
            break;
          }
          case "PageUp": {
            event.preventDefault();
            this.updateModelValue(this.d_value + 10);
            break;
          }
          case "PageDown": {
            event.preventDefault();
            this.updateModelValue(this.d_value - 10);
            break;
          }
        }
      }
    }, "onKeyDown")
  },
  computed: {
    rangePath: /* @__PURE__ */ __name(function rangePath() {
      return "M ".concat(this.minX, " ").concat(this.minY, " A ").concat(this.radius, " ").concat(this.radius, " 0 1 1 ").concat(this.maxX, " ").concat(this.maxY);
    }, "rangePath"),
    valuePath: /* @__PURE__ */ __name(function valuePath() {
      return "M ".concat(this.zeroX, " ").concat(this.zeroY, " A ").concat(this.radius, " ").concat(this.radius, " 0 ").concat(this.largeArc, " ").concat(this.sweep, " ").concat(this.valueX, " ").concat(this.valueY);
    }, "valuePath"),
    zeroRadians: /* @__PURE__ */ __name(function zeroRadians() {
      if (this.min > 0 && this.max > 0) return this.mapRange(this.min, this.min, this.max, this.minRadians, this.maxRadians);
      else return this.mapRange(0, this.min, this.max, this.minRadians, this.maxRadians);
    }, "zeroRadians"),
    valueRadians: /* @__PURE__ */ __name(function valueRadians() {
      return this.mapRange(this.d_value, this.min, this.max, this.minRadians, this.maxRadians);
    }, "valueRadians"),
    minX: /* @__PURE__ */ __name(function minX() {
      return this.midX + Math.cos(this.minRadians) * this.radius;
    }, "minX"),
    minY: /* @__PURE__ */ __name(function minY() {
      return this.midY - Math.sin(this.minRadians) * this.radius;
    }, "minY"),
    maxX: /* @__PURE__ */ __name(function maxX() {
      return this.midX + Math.cos(this.maxRadians) * this.radius;
    }, "maxX"),
    maxY: /* @__PURE__ */ __name(function maxY() {
      return this.midY - Math.sin(this.maxRadians) * this.radius;
    }, "maxY"),
    zeroX: /* @__PURE__ */ __name(function zeroX() {
      return this.midX + Math.cos(this.zeroRadians) * this.radius;
    }, "zeroX"),
    zeroY: /* @__PURE__ */ __name(function zeroY() {
      return this.midY - Math.sin(this.zeroRadians) * this.radius;
    }, "zeroY"),
    valueX: /* @__PURE__ */ __name(function valueX() {
      return this.midX + Math.cos(this.valueRadians) * this.radius;
    }, "valueX"),
    valueY: /* @__PURE__ */ __name(function valueY() {
      return this.midY - Math.sin(this.valueRadians) * this.radius;
    }, "valueY"),
    largeArc: /* @__PURE__ */ __name(function largeArc() {
      return Math.abs(this.zeroRadians - this.valueRadians) < Math_PI ? 0 : 1;
    }, "largeArc"),
    sweep: /* @__PURE__ */ __name(function sweep() {
      return this.valueRadians > this.zeroRadians ? 0 : 1;
    }, "sweep"),
    valueToDisplay: /* @__PURE__ */ __name(function valueToDisplay() {
      if (typeof this.valueTemplate === "string") {
        return this.valueTemplate.replace(/{value}/g, this.d_value);
      } else {
        return this.valueTemplate(this.d_value);
      }
    }, "valueToDisplay")
  }
};
var _hoisted_1$1b = ["width", "height", "tabindex", "aria-valuemin", "aria-valuemax", "aria-valuenow", "aria-labelledby", "aria-label"];
var _hoisted_2$T = ["d", "stroke-width", "stroke"];
var _hoisted_3$D = ["d", "stroke-width", "stroke"];
var _hoisted_4$q = ["fill"];
function render$l(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [(openBlock(), createElementBlock("svg", mergeProps$2({
    viewBox: "0 0 100 100",
    role: "slider",
    width: _ctx.size,
    height: _ctx.size,
    tabindex: _ctx.readonly || _ctx.disabled ? -1 : _ctx.tabindex,
    "aria-valuemin": _ctx.min,
    "aria-valuemax": _ctx.max,
    "aria-valuenow": _ctx.d_value,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.onClick && $options.onClick.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onKeydown: _cache[2] || (_cache[2] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    }),
    onMousedown: _cache[3] || (_cache[3] = function() {
      return $options.onMouseDown && $options.onMouseDown.apply($options, arguments);
    }),
    onMouseup: _cache[4] || (_cache[4] = function() {
      return $options.onMouseUp && $options.onMouseUp.apply($options, arguments);
    }),
    onTouchstartPassive: _cache[5] || (_cache[5] = function() {
      return $options.onTouchStart && $options.onTouchStart.apply($options, arguments);
    }),
    onTouchend: _cache[6] || (_cache[6] = function() {
      return $options.onTouchEnd && $options.onTouchEnd.apply($options, arguments);
    })
  }, _ctx.ptm("svg")), [createBaseVNode("path", mergeProps$2({
    d: $options.rangePath,
    "stroke-width": _ctx.strokeWidth,
    stroke: _ctx.rangeColor,
    "class": _ctx.cx("range")
  }, _ctx.ptm("range")), null, 16, _hoisted_2$T), createBaseVNode("path", mergeProps$2({
    d: $options.valuePath,
    "stroke-width": _ctx.strokeWidth,
    stroke: _ctx.valueColor,
    "class": _ctx.cx("value")
  }, _ctx.ptm("value")), null, 16, _hoisted_3$D), _ctx.showValue ? (openBlock(), createElementBlock("text", mergeProps$2({
    key: 0,
    x: 50,
    y: 57,
    "text-anchor": "middle",
    fill: _ctx.textColor,
    "class": _ctx.cx("text")
  }, _ctx.ptm("text")), toDisplayString$1($options.valueToDisplay), 17, _hoisted_4$q)) : createCommentVNode("", true)], 16, _hoisted_1$1b))], 16);
}
__name(render$l, "render$l");
script$n.render = render$l;
const _hoisted_1$1a = { class: "input-knob flex flex-row items-center gap-2" };
const _sfc_main$1g = /* @__PURE__ */ defineComponent({
  ...{
    inheritAttrs: false
  },
  __name: "InputKnob",
  props: {
    modelValue: {},
    inputClass: {},
    knobClass: {},
    min: {},
    max: {},
    step: {},
    resolution: {}
  },
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit2 = __emit;
    const localValue = ref(props.modelValue);
    watch(
      () => props.modelValue,
      (newValue2) => {
        localValue.value = newValue2;
      }
    );
    const updateValue3 = /* @__PURE__ */ __name((newValue2) => {
      if (newValue2 === null) {
        newValue2 = Number(props.min) || 0;
      }
      const min = Number(props.min ?? Number.NEGATIVE_INFINITY);
      const max = Number(props.max ?? Number.POSITIVE_INFINITY);
      const step2 = Number(props.step) || 1;
      newValue2 = Math.max(min, Math.min(max, newValue2));
      newValue2 = Math.round(newValue2 / step2) * step2;
      localValue.value = newValue2;
      emit2("update:modelValue", newValue2);
    }, "updateValue");
    const displayValue = /* @__PURE__ */ __name((value3) => {
      updateValue3(value3);
      const stepString = (props.step ?? 1).toString();
      const resolution = stepString.includes(".") ? stepString.split(".")[1].length : 0;
      return value3.toFixed(props.resolution ?? resolution);
    }, "displayValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1a, [
        createVNode(unref(script$n), mergeProps$2({
          modelValue: _ctx.modelValue,
          "onUpdate:modelValue": updateValue3,
          valueTemplate: displayValue,
          class: ["knob-part", _ctx.knobClass],
          min: _ctx.min,
          max: _ctx.max,
          step: _ctx.step
        }, _ctx.$attrs), null, 16, ["modelValue", "class", "min", "max", "step"]),
        createVNode(unref(script$q), {
          modelValue: _ctx.modelValue,
          "onUpdate:modelValue": updateValue3,
          class: normalizeClass(["input-part", _ctx.inputClass]),
          "max-fraction-digits": 3,
          min: _ctx.min,
          max: _ctx.max,
          step: _ctx.step,
          allowEmpty: false
        }, null, 8, ["modelValue", "class", "min", "max", "step"])
      ]);
    };
  }
});
var theme$d = /* @__PURE__ */ __name(function theme33(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-slider {\n    position: relative;\n    background: ".concat(dt2("slider.track.background"), ";\n    border-radius: ").concat(dt2("slider.track.border.radius"), ";\n}\n\n.p-slider-handle {\n    cursor: grab;\n    touch-action: none;\n    user-select: none;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    height: ").concat(dt2("slider.handle.height"), ";\n    width: ").concat(dt2("slider.handle.width"), ";\n    background: ").concat(dt2("slider.handle.background"), ";\n    border-radius: ").concat(dt2("slider.handle.border.radius"), ";\n    transition: background ").concat(dt2("slider.transition.duration"), ", color ").concat(dt2("slider.transition.duration"), ", border-color ").concat(dt2("slider.transition.duration"), ", box-shadow ").concat(dt2("slider.transition.duration"), ", outline-color ").concat(dt2("slider.transition.duration"), ';\n    outline-color: transparent;\n}\n\n.p-slider-handle::before {\n    content: "";\n    width: ').concat(dt2("slider.handle.content.width"), ";\n    height: ").concat(dt2("slider.handle.content.height"), ";\n    display: block;\n    background: ").concat(dt2("slider.handle.content.background"), ";\n    border-radius: ").concat(dt2("slider.handle.content.border.radius"), ";\n    box-shadow: ").concat(dt2("slider.handle.content.shadow"), ";\n    transition: background ").concat(dt2("slider.transition.duration"), ";\n}\n\n.p-slider:not(.p-disabled) .p-slider-handle:hover {\n    background: ").concat(dt2("slider.handle.hover.background"), ";\n}\n\n.p-slider:not(.p-disabled) .p-slider-handle:hover::before {\n    background: ").concat(dt2("slider.handle.content.hover.background"), ";\n}\n\n.p-slider-handle:focus-visible {\n    box-shadow: ").concat(dt2("slider.handle.focus.ring.shadow"), ";\n    outline: ").concat(dt2("slider.handle.focus.ring.width"), " ").concat(dt2("slider.handle.focus.ring.style"), " ").concat(dt2("slider.handle.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("slider.handle.focus.ring.offset"), ";\n}\n\n.p-slider-range {\n    display: block;\n    background: ").concat(dt2("slider.range.background"), ";\n    border-radius: ").concat(dt2("slider.border.radius"), ";\n}\n\n.p-slider.p-slider-horizontal {\n    height: ").concat(dt2("slider.track.size"), ";\n}\n\n.p-slider-horizontal .p-slider-range {\n    inset-block-start: 0;\n    inset-inline-start: 0;\n    height: 100%;\n}\n\n.p-slider-horizontal .p-slider-handle {\n    inset-block-start: 50%;\n    margin-block-start: calc(-1 * calc(").concat(dt2("slider.handle.height"), " / 2));\n    margin-inline-start: calc(-1 * calc(").concat(dt2("slider.handle.width"), " / 2));\n}\n\n.p-slider-vertical {\n    min-height: 100px;\n    width: ").concat(dt2("slider.track.size"), ";\n}\n\n.p-slider-vertical .p-slider-handle {\n    inset-inline-start: 50%;\n    margin-inline-start: calc(-1 * calc(").concat(dt2("slider.handle.width"), " / 2));\n    margin-block-end: calc(-1 * calc(").concat(dt2("slider.handle.height"), " / 2));\n}\n\n.p-slider-vertical .p-slider-range {\n    inset-block-end: 0;\n    inset-inline-start: 0;\n    width: 100%;\n}\n");
}, "theme");
var inlineStyles$3 = {
  handle: {
    position: "absolute"
  },
  range: {
    position: "absolute"
  }
};
var classes$f = {
  root: /* @__PURE__ */ __name(function root23(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-slider p-component", {
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid,
      "p-slider-horizontal": props.orientation === "horizontal",
      "p-slider-vertical": props.orientation === "vertical"
    }];
  }, "root"),
  range: "p-slider-range",
  handle: "p-slider-handle"
};
var SliderStyle = BaseStyle$1.extend({
  name: "slider",
  theme: theme$d,
  classes: classes$f,
  inlineStyles: inlineStyles$3
});
var script$1$f = {
  name: "BaseSlider",
  "extends": script$18,
  props: {
    min: {
      type: Number,
      "default": 0
    },
    max: {
      type: Number,
      "default": 100
    },
    orientation: {
      type: String,
      "default": "horizontal"
    },
    step: {
      type: Number,
      "default": null
    },
    range: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: SliderStyle,
  provide: /* @__PURE__ */ __name(function provide36() {
    return {
      $pcSlider: this,
      $parentInstance: this
    };
  }, "provide")
};
function _toConsumableArray$7(r2) {
  return _arrayWithoutHoles$7(r2) || _iterableToArray$7(r2) || _unsupportedIterableToArray$9(r2) || _nonIterableSpread$7();
}
__name(_toConsumableArray$7, "_toConsumableArray$7");
function _nonIterableSpread$7() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$7, "_nonIterableSpread$7");
function _unsupportedIterableToArray$9(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$9(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$9(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$9, "_unsupportedIterableToArray$9");
function _iterableToArray$7(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$7, "_iterableToArray$7");
function _arrayWithoutHoles$7(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$9(r2);
}
__name(_arrayWithoutHoles$7, "_arrayWithoutHoles$7");
function _arrayLikeToArray$9(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$9, "_arrayLikeToArray$9");
var script$m = {
  name: "Slider",
  "extends": script$1$f,
  inheritAttrs: false,
  emits: ["change", "slideend"],
  dragging: false,
  handleIndex: null,
  initX: null,
  initY: null,
  barWidth: null,
  barHeight: null,
  dragListener: null,
  dragEndListener: null,
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount8() {
    this.unbindDragListeners();
  }, "beforeUnmount"),
  methods: {
    updateDomData: /* @__PURE__ */ __name(function updateDomData() {
      var rect = this.$el.getBoundingClientRect();
      this.initX = rect.left + getWindowScrollLeft$1();
      this.initY = rect.top + getWindowScrollTop$1();
      this.barWidth = this.$el.offsetWidth;
      this.barHeight = this.$el.offsetHeight;
    }, "updateDomData"),
    setValue: /* @__PURE__ */ __name(function setValue(event) {
      var handleValue;
      var pageX = event.touches ? event.touches[0].pageX : event.pageX;
      var pageY = event.touches ? event.touches[0].pageY : event.pageY;
      if (this.orientation === "horizontal") {
        if (isRTL$1(this.$el)) {
          handleValue = (this.initX + this.barWidth - pageX) * 100 / this.barWidth;
        } else {
          handleValue = (pageX - this.initX) * 100 / this.barWidth;
        }
      } else {
        handleValue = (this.initY + this.barHeight - pageY) * 100 / this.barHeight;
      }
      var newValue2 = (this.max - this.min) * (handleValue / 100) + this.min;
      if (this.step) {
        var oldValue = this.range ? this.value[this.handleIndex] : this.value;
        var diff2 = newValue2 - oldValue;
        if (diff2 < 0) newValue2 = oldValue + Math.ceil(newValue2 / this.step - oldValue / this.step) * this.step;
        else if (diff2 > 0) newValue2 = oldValue + Math.floor(newValue2 / this.step - oldValue / this.step) * this.step;
      } else {
        newValue2 = Math.floor(newValue2);
      }
      this.updateModel(event, newValue2);
    }, "setValue"),
    updateModel: /* @__PURE__ */ __name(function updateModel6(event, value3) {
      var newValue2 = parseFloat(value3.toFixed(10));
      var modelValue3;
      if (this.range) {
        modelValue3 = this.value ? _toConsumableArray$7(this.value) : [];
        if (this.handleIndex == 0) {
          if (newValue2 < this.min) newValue2 = this.min;
          else if (newValue2 >= this.max) newValue2 = this.max;
          modelValue3[0] = newValue2;
        } else {
          if (newValue2 > this.max) newValue2 = this.max;
          else if (newValue2 <= this.min) newValue2 = this.min;
          modelValue3[1] = newValue2;
        }
      } else {
        if (newValue2 < this.min) newValue2 = this.min;
        else if (newValue2 > this.max) newValue2 = this.max;
        modelValue3 = newValue2;
      }
      this.writeValue(modelValue3, event);
      this.$emit("change", modelValue3);
    }, "updateModel"),
    onDragStart: /* @__PURE__ */ __name(function onDragStart(event, index2) {
      if (this.disabled) {
        return;
      }
      this.$el.setAttribute("data-p-sliding", true);
      this.dragging = true;
      this.updateDomData();
      if (this.range && this.value[0] === this.max) {
        this.handleIndex = 0;
      } else {
        this.handleIndex = index2;
      }
      event.currentTarget.focus();
    }, "onDragStart"),
    onDrag: /* @__PURE__ */ __name(function onDrag2(event) {
      if (this.dragging) {
        this.setValue(event);
      }
    }, "onDrag"),
    onDragEnd: /* @__PURE__ */ __name(function onDragEnd2(event) {
      if (this.dragging) {
        this.dragging = false;
        this.$el.setAttribute("data-p-sliding", false);
        this.$emit("slideend", {
          originalEvent: event,
          value: this.value
        });
      }
    }, "onDragEnd"),
    onBarClick: /* @__PURE__ */ __name(function onBarClick(event) {
      if (this.disabled) {
        return;
      }
      if (getAttribute$1(event.target, "data-pc-section") !== "handle") {
        this.updateDomData();
        this.setValue(event);
      }
    }, "onBarClick"),
    onMouseDown: /* @__PURE__ */ __name(function onMouseDown3(event, index2) {
      this.bindDragListeners();
      this.onDragStart(event, index2);
    }, "onMouseDown"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown7(event, index2) {
      this.handleIndex = index2;
      switch (event.code) {
        case "ArrowDown":
        case "ArrowLeft":
          this.decrementValue(event, index2);
          event.preventDefault();
          break;
        case "ArrowUp":
        case "ArrowRight":
          this.incrementValue(event, index2);
          event.preventDefault();
          break;
        case "PageDown":
          this.decrementValue(event, index2, true);
          event.preventDefault();
          break;
        case "PageUp":
          this.incrementValue(event, index2, true);
          event.preventDefault();
          break;
        case "Home":
          this.updateModel(event, this.min);
          event.preventDefault();
          break;
        case "End":
          this.updateModel(event, this.max);
          event.preventDefault();
          break;
      }
    }, "onKeyDown"),
    onBlur: /* @__PURE__ */ __name(function onBlur7(event, index2) {
      var _this$formField$onBlu, _this$formField;
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur"),
    decrementValue: /* @__PURE__ */ __name(function decrementValue(event, index2) {
      var pageKey = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
      var newValue2;
      if (this.range) {
        if (this.step) newValue2 = this.value[index2] - this.step;
        else newValue2 = this.value[index2] - 1;
      } else {
        if (this.step) newValue2 = this.value - this.step;
        else if (!this.step && pageKey) newValue2 = this.value - 10;
        else newValue2 = this.value - 1;
      }
      this.updateModel(event, newValue2);
      event.preventDefault();
    }, "decrementValue"),
    incrementValue: /* @__PURE__ */ __name(function incrementValue(event, index2) {
      var pageKey = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : false;
      var newValue2;
      if (this.range) {
        if (this.step) newValue2 = this.value[index2] + this.step;
        else newValue2 = this.value[index2] + 1;
      } else {
        if (this.step) newValue2 = this.value + this.step;
        else if (!this.step && pageKey) newValue2 = this.value + 10;
        else newValue2 = this.value + 1;
      }
      this.updateModel(event, newValue2);
      event.preventDefault();
    }, "incrementValue"),
    bindDragListeners: /* @__PURE__ */ __name(function bindDragListeners2() {
      if (!this.dragListener) {
        this.dragListener = this.onDrag.bind(this);
        document.addEventListener("mousemove", this.dragListener);
      }
      if (!this.dragEndListener) {
        this.dragEndListener = this.onDragEnd.bind(this);
        document.addEventListener("mouseup", this.dragEndListener);
      }
    }, "bindDragListeners"),
    unbindDragListeners: /* @__PURE__ */ __name(function unbindDragListeners2() {
      if (this.dragListener) {
        document.removeEventListener("mousemove", this.dragListener);
        this.dragListener = null;
      }
      if (this.dragEndListener) {
        document.removeEventListener("mouseup", this.dragEndListener);
        this.dragEndListener = null;
      }
    }, "unbindDragListeners"),
    rangeStyle: /* @__PURE__ */ __name(function rangeStyle() {
      if (this.range) {
        var rangeSliderWidth = this.rangeEndPosition > this.rangeStartPosition ? this.rangeEndPosition - this.rangeStartPosition : this.rangeStartPosition - this.rangeEndPosition;
        var rangeSliderPosition = this.rangeEndPosition > this.rangeStartPosition ? this.rangeStartPosition : this.rangeEndPosition;
        if (this.horizontal) {
          return {
            "inset-inline-start": rangeSliderPosition + "%",
            width: rangeSliderWidth + "%"
          };
        } else {
          return {
            bottom: rangeSliderPosition + "%",
            height: rangeSliderWidth + "%"
          };
        }
      } else {
        if (this.horizontal) {
          return {
            width: this.handlePosition + "%"
          };
        } else {
          return {
            height: this.handlePosition + "%"
          };
        }
      }
    }, "rangeStyle"),
    handleStyle: /* @__PURE__ */ __name(function handleStyle() {
      if (this.horizontal) {
        return {
          "inset-inline-start": this.handlePosition + "%"
        };
      } else {
        return {
          bottom: this.handlePosition + "%"
        };
      }
    }, "handleStyle"),
    rangeStartHandleStyle: /* @__PURE__ */ __name(function rangeStartHandleStyle() {
      if (this.horizontal) {
        return {
          "inset-inline-start": this.rangeStartPosition + "%"
        };
      } else {
        return {
          bottom: this.rangeStartPosition + "%"
        };
      }
    }, "rangeStartHandleStyle"),
    rangeEndHandleStyle: /* @__PURE__ */ __name(function rangeEndHandleStyle() {
      if (this.horizontal) {
        return {
          "inset-inline-start": this.rangeEndPosition + "%"
        };
      } else {
        return {
          bottom: this.rangeEndPosition + "%"
        };
      }
    }, "rangeEndHandleStyle")
  },
  computed: {
    value: /* @__PURE__ */ __name(function value2() {
      var _this$d_value3;
      if (this.range) {
        var _this$d_value$, _this$d_value, _this$d_value$2, _this$d_value2;
        return [(_this$d_value$ = (_this$d_value = this.d_value) === null || _this$d_value === void 0 ? void 0 : _this$d_value[0]) !== null && _this$d_value$ !== void 0 ? _this$d_value$ : this.min, (_this$d_value$2 = (_this$d_value2 = this.d_value) === null || _this$d_value2 === void 0 ? void 0 : _this$d_value2[1]) !== null && _this$d_value$2 !== void 0 ? _this$d_value$2 : this.max];
      }
      return (_this$d_value3 = this.d_value) !== null && _this$d_value3 !== void 0 ? _this$d_value3 : this.min;
    }, "value"),
    horizontal: /* @__PURE__ */ __name(function horizontal() {
      return this.orientation === "horizontal";
    }, "horizontal"),
    vertical: /* @__PURE__ */ __name(function vertical() {
      return this.orientation === "vertical";
    }, "vertical"),
    handlePosition: /* @__PURE__ */ __name(function handlePosition() {
      if (this.value < this.min) return 0;
      else if (this.value > this.max) return 100;
      else return (this.value - this.min) * 100 / (this.max - this.min);
    }, "handlePosition"),
    rangeStartPosition: /* @__PURE__ */ __name(function rangeStartPosition() {
      if (this.value && this.value[0] !== void 0) {
        if (this.value[0] < this.min) return 0;
        else return (this.value[0] - this.min) * 100 / (this.max - this.min);
      } else return 0;
    }, "rangeStartPosition"),
    rangeEndPosition: /* @__PURE__ */ __name(function rangeEndPosition() {
      if (this.value && this.value.length === 2 && this.value[1] !== void 0) {
        if (this.value[1] > this.max) return 100;
        else return (this.value[1] - this.min) * 100 / (this.max - this.min);
      } else return 100;
    }, "rangeEndPosition")
  }
};
var _hoisted_1$19 = ["tabindex", "aria-valuemin", "aria-valuenow", "aria-valuemax", "aria-labelledby", "aria-label", "aria-orientation"];
var _hoisted_2$S = ["tabindex", "aria-valuemin", "aria-valuenow", "aria-valuemax", "aria-labelledby", "aria-label", "aria-orientation"];
var _hoisted_3$C = ["tabindex", "aria-valuemin", "aria-valuenow", "aria-valuemax", "aria-labelledby", "aria-label", "aria-orientation"];
function render$k(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    onClick: _cache[18] || (_cache[18] = function() {
      return $options.onBarClick && $options.onBarClick.apply($options, arguments);
    })
  }, _ctx.ptmi("root"), {
    "data-p-sliding": false
  }), [createBaseVNode("span", mergeProps$2({
    "class": _ctx.cx("range"),
    style: [_ctx.sx("range"), $options.rangeStyle()]
  }, _ctx.ptm("range")), null, 16), !_ctx.range ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 0,
    "class": _ctx.cx("handle"),
    style: [_ctx.sx("handle"), $options.handleStyle()],
    onTouchstartPassive: _cache[0] || (_cache[0] = function($event) {
      return $options.onDragStart($event);
    }),
    onTouchmovePassive: _cache[1] || (_cache[1] = function($event) {
      return $options.onDrag($event);
    }),
    onTouchend: _cache[2] || (_cache[2] = function($event) {
      return $options.onDragEnd($event);
    }),
    onMousedown: _cache[3] || (_cache[3] = function($event) {
      return $options.onMouseDown($event);
    }),
    onKeydown: _cache[4] || (_cache[4] = function($event) {
      return $options.onKeyDown($event);
    }),
    onBlur: _cache[5] || (_cache[5] = function($event) {
      return $options.onBlur($event);
    }),
    tabindex: _ctx.tabindex,
    role: "slider",
    "aria-valuemin": _ctx.min,
    "aria-valuenow": _ctx.d_value,
    "aria-valuemax": _ctx.max,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    "aria-orientation": _ctx.orientation
  }, _ctx.ptm("handle")), null, 16, _hoisted_1$19)) : createCommentVNode("", true), _ctx.range ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 1,
    "class": _ctx.cx("handle"),
    style: [_ctx.sx("handle"), $options.rangeStartHandleStyle()],
    onTouchstartPassive: _cache[6] || (_cache[6] = function($event) {
      return $options.onDragStart($event, 0);
    }),
    onTouchmovePassive: _cache[7] || (_cache[7] = function($event) {
      return $options.onDrag($event);
    }),
    onTouchend: _cache[8] || (_cache[8] = function($event) {
      return $options.onDragEnd($event);
    }),
    onMousedown: _cache[9] || (_cache[9] = function($event) {
      return $options.onMouseDown($event, 0);
    }),
    onKeydown: _cache[10] || (_cache[10] = function($event) {
      return $options.onKeyDown($event, 0);
    }),
    onBlur: _cache[11] || (_cache[11] = function($event) {
      return $options.onBlur($event, 0);
    }),
    tabindex: _ctx.tabindex,
    role: "slider",
    "aria-valuemin": _ctx.min,
    "aria-valuenow": _ctx.d_value ? _ctx.d_value[0] : null,
    "aria-valuemax": _ctx.max,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    "aria-orientation": _ctx.orientation
  }, _ctx.ptm("startHandler")), null, 16, _hoisted_2$S)) : createCommentVNode("", true), _ctx.range ? (openBlock(), createElementBlock("span", mergeProps$2({
    key: 2,
    "class": _ctx.cx("handle"),
    style: [_ctx.sx("handle"), $options.rangeEndHandleStyle()],
    onTouchstartPassive: _cache[12] || (_cache[12] = function($event) {
      return $options.onDragStart($event, 1);
    }),
    onTouchmovePassive: _cache[13] || (_cache[13] = function($event) {
      return $options.onDrag($event);
    }),
    onTouchend: _cache[14] || (_cache[14] = function($event) {
      return $options.onDragEnd($event);
    }),
    onMousedown: _cache[15] || (_cache[15] = function($event) {
      return $options.onMouseDown($event, 1);
    }),
    onKeydown: _cache[16] || (_cache[16] = function($event) {
      return $options.onKeyDown($event, 1);
    }),
    onBlur: _cache[17] || (_cache[17] = function($event) {
      return $options.onBlur($event, 1);
    }),
    tabindex: _ctx.tabindex,
    role: "slider",
    "aria-valuemin": _ctx.min,
    "aria-valuenow": _ctx.d_value ? _ctx.d_value[1] : null,
    "aria-valuemax": _ctx.max,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel,
    "aria-orientation": _ctx.orientation
  }, _ctx.ptm("endHandler")), null, 16, _hoisted_3$C)) : createCommentVNode("", true)], 16);
}
__name(render$k, "render$k");
script$m.render = render$k;
const _hoisted_1$18 = { class: "input-slider flex flex-row items-center gap-2" };
const _sfc_main$1f = /* @__PURE__ */ defineComponent({
  ...{
    inheritAttrs: false
  },
  __name: "InputSlider",
  props: {
    modelValue: {},
    inputClass: {},
    sliderClass: {},
    min: {},
    max: {},
    step: {}
  },
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit2 = __emit;
    const localValue = ref(props.modelValue);
    watch(
      () => props.modelValue,
      (newValue2) => {
        localValue.value = newValue2;
      }
    );
    const updateValue3 = /* @__PURE__ */ __name((newValue2) => {
      if (newValue2 === null) {
        newValue2 = Number(props.min) || 0;
      }
      const min = Number(props.min ?? Number.NEGATIVE_INFINITY);
      const max = Number(props.max ?? Number.POSITIVE_INFINITY);
      const step2 = Number(props.step) || 1;
      newValue2 = Math.max(min, Math.min(max, newValue2));
      newValue2 = Math.round(newValue2 / step2) * step2;
      localValue.value = newValue2;
      emit2("update:modelValue", newValue2);
    }, "updateValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$18, [
        createVNode(unref(script$m), mergeProps$2({
          modelValue: _ctx.modelValue,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = (value3) => updateValue3(value3)),
          class: ["slider-part", _ctx.sliderClass],
          min: _ctx.min,
          max: _ctx.max,
          step: _ctx.step
        }, _ctx.$attrs), null, 16, ["modelValue", "class", "min", "max", "step"]),
        createVNode(unref(script$q), {
          modelValue: _ctx.modelValue,
          "onUpdate:modelValue": updateValue3,
          class: normalizeClass(["input-part", _ctx.inputClass]),
          "max-fraction-digits": 3,
          min: _ctx.min,
          max: _ctx.max,
          step: _ctx.step,
          allowEmpty: false
        }, null, 8, ["modelValue", "class", "min", "max", "step"])
      ]);
    };
  }
});
const VALID_STATUS_CODES = [200, 201, 301, 302, 307, 308];
const checkUrlReachable = /* @__PURE__ */ __name(async (url) => {
  try {
    const response = await axios.head(url);
    return VALID_STATUS_CODES.includes(response.status);
  } catch {
    return false;
  }
}, "checkUrlReachable");
const checkMirrorReachable = /* @__PURE__ */ __name(async (mirror2) => {
  return isValidUrl(mirror2) && await electronAPI().NetWork.canAccessUrl(mirror2);
}, "checkMirrorReachable");
async function isInChina() {
  const isChineseLocale = navigator.language.toLowerCase().startsWith("zh-cn");
  try {
    const googleTest = await Promise.race([
      fetch("https://www.google.com", {
        mode: "no-cors",
        cache: "no-cache"
      }),
      new Promise((_2, reject3) => setTimeout(() => reject3(), 2e3))
    ]);
    if (googleTest) {
      return false;
    }
  } catch {
    if (isChineseLocale) {
      return true;
    }
    try {
      const start2 = performance.now();
      await fetch("https://www.baidu.com", {
        mode: "no-cors",
        cache: "no-cache"
      });
      const latency = performance.now() - start2;
      return latency < 150;
    } catch {
      return isChineseLocale;
    }
  }
  return false;
}
__name(isInChina, "isInChina");
var ValidationState = /* @__PURE__ */ ((ValidationState2) => {
  ValidationState2["IDLE"] = "IDLE";
  ValidationState2["LOADING"] = "LOADING";
  ValidationState2["VALID"] = "VALID";
  ValidationState2["INVALID"] = "INVALID";
  return ValidationState2;
})(ValidationState || {});
const mergeValidationStates = /* @__PURE__ */ __name((states) => {
  if (states.some(
    (state) => state === "INVALID"
    /* INVALID */
  )) {
    return "INVALID";
  }
  if (states.some(
    (state) => state === "LOADING"
    /* LOADING */
  )) {
    return "LOADING";
  }
  if (states.every(
    (state) => state === "VALID"
    /* VALID */
  )) {
    return "VALID";
  }
  return "IDLE";
}, "mergeValidationStates");
const _sfc_main$1e = /* @__PURE__ */ defineComponent({
  ...{
    inheritAttrs: false
  },
  __name: "UrlInput",
  props: {
    modelValue: {},
    validateUrlFn: { type: Function }
  },
  emits: ["update:modelValue", "state-change"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit2 = __emit;
    const validationState = ref(ValidationState.IDLE);
    const cleanInput = /* @__PURE__ */ __name((value3) => value3 ? value3.replace(/\s+/g, "") : "", "cleanInput");
    const internalValue = ref(cleanInput(props.modelValue));
    watch(
      () => props.modelValue,
      async (newValue2) => {
        internalValue.value = cleanInput(newValue2);
        await validateUrl(newValue2);
      }
    );
    watch(validationState, (newState) => {
      emit2("state-change", newState);
    });
    onMounted(async () => {
      await validateUrl(props.modelValue);
    });
    const handleInput = /* @__PURE__ */ __name((value3) => {
      internalValue.value = cleanInput(value3 ?? "");
      validationState.value = ValidationState.IDLE;
    }, "handleInput");
    const handleBlur = /* @__PURE__ */ __name(async () => {
      const input = cleanInput(internalValue.value);
      let normalizedUrl = input;
      try {
        const url = new URL(input);
        normalizedUrl = url.toString();
      } catch {
      }
      emit2("update:modelValue", normalizedUrl);
    }, "handleBlur");
    const defaultValidateUrl = /* @__PURE__ */ __name(async (url) => {
      if (!isValidUrl(url)) return false;
      try {
        return await checkUrlReachable(url);
      } catch {
        return false;
      }
    }, "defaultValidateUrl");
    const validateUrl = /* @__PURE__ */ __name(async (value3) => {
      if (validationState.value === ValidationState.LOADING) return;
      const url = cleanInput(value3);
      validationState.value = ValidationState.IDLE;
      if (!url) return;
      validationState.value = ValidationState.LOADING;
      try {
        const isValid2 = await (props.validateUrlFn ?? defaultValidateUrl)(url);
        validationState.value = isValid2 ? ValidationState.VALID : ValidationState.INVALID;
      } catch {
        validationState.value = ValidationState.INVALID;
      }
    }, "validateUrl");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$J), { class: "w-full" }, {
        default: withCtx(() => [
          createVNode(unref(script$P), mergeProps$2(_ctx.$attrs, {
            "model-value": internalValue.value,
            class: "w-full",
            invalid: validationState.value === unref(ValidationState).INVALID,
            "onUpdate:modelValue": handleInput,
            onBlur: handleBlur
          }), null, 16, ["model-value", "invalid"]),
          createVNode(unref(script$I), {
            class: normalizeClass({
              "pi pi-spin pi-spinner text-neutral-400": validationState.value === unref(ValidationState).LOADING,
              "pi pi-check text-green-500 cursor-pointer": validationState.value === unref(ValidationState).VALID,
              "pi pi-times text-red-500 cursor-pointer": validationState.value === unref(ValidationState).INVALID
            }),
            onClick: _cache[0] || (_cache[0] = ($event) => validateUrl(props.modelValue))
          }, null, 8, ["class"])
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1$17 = { class: "flex flex-row items-center gap-2" };
const _hoisted_2$R = { class: "form-label flex flex-grow items-center" };
const _hoisted_3$B = ["id"];
const _hoisted_4$p = {
  key: 0,
  class: "pi pi-info-circle bg-transparent"
};
const _hoisted_5$l = { class: "form-input flex justify-end" };
const _sfc_main$1d = /* @__PURE__ */ defineComponent({
  __name: "FormItem",
  props: /* @__PURE__ */ mergeModels({
    item: {},
    id: {},
    labelClass: {}
  }, {
    "formValue": {},
    "formValueModifiers": {}
  }),
  emits: ["update:formValue"],
  setup(__props) {
    const formValue = useModel(__props, "formValue");
    const props = __props;
    function getFormAttrs(item3) {
      const attrs7 = { ...item3.attrs || {} };
      const inputType = item3.type;
      if (typeof inputType === "function") {
        attrs7["renderFunction"] = () => inputType(
          props.item.name,
          (v2) => formValue.value = v2,
          formValue.value,
          item3.attrs
        );
      }
      switch (item3.type) {
        case "combo":
          attrs7["options"] = typeof item3.options === "function" ? (
            // @ts-expect-error: Audit and deprecate usage of legacy options type:
            // (value) => [string | {text: string, value: string}]
            item3.options(formValue.value)
          ) : item3.options;
          if (typeof item3.options?.[0] !== "string") {
            attrs7["optionLabel"] = "text";
            attrs7["optionValue"] = "value";
          }
          break;
      }
      return attrs7;
    }
    __name(getFormAttrs, "getFormAttrs");
    function getFormComponent(item3) {
      if (typeof item3.type === "function") {
        return _sfc_main$1j;
      }
      switch (item3.type) {
        case "boolean":
          return script$p;
        case "number":
          return script$q;
        case "slider":
          return _sfc_main$1f;
        case "knob":
          return _sfc_main$1g;
        case "combo":
          return script$t;
        case "image":
          return _sfc_main$1h;
        case "color":
          return _sfc_main$1i;
        case "url":
          return _sfc_main$1e;
        default:
          return script$P;
      }
    }
    __name(getFormComponent, "getFormComponent");
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock("div", _hoisted_1$17, [
        createBaseVNode("div", _hoisted_2$R, [
          createBaseVNode("span", {
            class: normalizeClass(["text-muted", props.labelClass]),
            id: `${props.id}-label`
          }, [
            renderSlot(_ctx.$slots, "name-prefix", {}, void 0, true),
            createTextVNode(" " + toDisplayString$1(props.item.name) + " ", 1),
            props.item.tooltip ? withDirectives((openBlock(), createElementBlock("i", _hoisted_4$p, null, 512)), [
              [_directive_tooltip, props.item.tooltip]
            ]) : createCommentVNode("", true),
            renderSlot(_ctx.$slots, "name-suffix", {}, void 0, true)
          ], 10, _hoisted_3$B)
        ]),
        createBaseVNode("div", _hoisted_5$l, [
          (openBlock(), createBlock(resolveDynamicComponent(markRaw(getFormComponent(props.item))), mergeProps$2({
            id: props.id,
            "aria-labelledby": `${props.id}-label`,
            modelValue: formValue.value,
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => formValue.value = $event)
          }, getFormAttrs(props.item)), null, 16, ["id", "aria-labelledby", "modelValue"]))
        ])
      ]);
    };
  }
});
const FormItem = /* @__PURE__ */ _export_sfc(_sfc_main$1d, [["__scopeId", "data-v-3d97e121"]]);
const _sfc_main$1c = /* @__PURE__ */ defineComponent({
  __name: "SettingItem",
  props: {
    setting: {}
  },
  setup(__props) {
    const props = __props;
    const { t: t2 } = useI18n();
    function translateOptions(options5) {
      if (typeof options5 === "function") {
        return translateOptions(options5(props.setting.value ?? ""));
      }
      return options5.map((option5) => {
        const optionLabel = typeof option5 === "string" ? option5 : option5.text;
        const optionValue = typeof option5 === "string" ? option5 : option5.value;
        return {
          text: t2(
            `settings.${normalizeI18nKey(props.setting.id)}.options.${normalizeI18nKey(optionLabel)}`,
            optionLabel
          ),
          value: optionValue
        };
      });
    }
    __name(translateOptions, "translateOptions");
    const formItem = computed(() => {
      const normalizedId = normalizeI18nKey(props.setting.id);
      return {
        ...props.setting,
        name: t2(`settings.${normalizedId}.name`, props.setting.name),
        tooltip: props.setting.tooltip ? t2(`settings.${normalizedId}.tooltip`, props.setting.tooltip) : void 0,
        options: props.setting.options ? translateOptions(props.setting.options) : void 0
      };
    });
    const settingStore = useSettingStore();
    const settingValue = computed(() => settingStore.get(props.setting.id));
    const updateSettingValue = /* @__PURE__ */ __name((value3) => {
      settingStore.set(props.setting.id, value3);
    }, "updateSettingValue");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(FormItem, {
        item: formItem.value,
        id: _ctx.setting.id,
        formValue: settingValue.value,
        "onUpdate:formValue": updateSettingValue
      }, {
        "name-prefix": withCtx(() => [
          _ctx.setting.experimental ? (openBlock(), createBlock(unref(script$z), {
            key: 0,
            value: _ctx.$t("g.experimental")
          }, null, 8, ["value"])) : createCommentVNode("", true),
          _ctx.setting.deprecated ? (openBlock(), createBlock(unref(script$z), {
            key: 1,
            value: _ctx.$t("g.deprecated"),
            severity: "danger"
          }, null, 8, ["value"])) : createCommentVNode("", true)
        ]),
        _: 1
      }, 8, ["item", "id", "formValue"]);
    };
  }
});
const _hoisted_1$16 = { class: "setting-group" };
const _sfc_main$1b = /* @__PURE__ */ defineComponent({
  __name: "SettingGroup",
  props: {
    group: {},
    divider: { type: Boolean }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$16, [
        _ctx.divider ? (openBlock(), createBlock(unref(script$Y), { key: 0 })) : createCommentVNode("", true),
        createBaseVNode("h3", null, toDisplayString$1(_ctx.$t(`settingsCategories.${unref(normalizeI18nKey)(_ctx.group.label)}`, _ctx.group.label)), 1),
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.group.settings, (setting) => {
          return openBlock(), createElementBlock("div", {
            key: setting.id,
            class: "setting-item mb-4"
          }, [
            createVNode(_sfc_main$1c, { setting }, null, 8, ["setting"])
          ]);
        }), 128))
      ]);
    };
  }
});
const _hoisted_1$15 = { key: 0 };
const _sfc_main$1a = /* @__PURE__ */ defineComponent({
  __name: "SettingsPanel",
  props: {
    settingGroups: {}
  },
  setup(__props) {
    const props = __props;
    return (_ctx, _cache) => {
      return props.settingGroups.length > 0 ? (openBlock(), createElementBlock("div", _hoisted_1$15, [
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(props.settingGroups, (group, i2) => {
          return openBlock(), createBlock(_sfc_main$1b, {
            key: group.label,
            divider: i2 !== 0,
            group
          }, null, 8, ["divider", "group"]);
        }), 128))
      ])) : (openBlock(), createBlock(NoResultsPlaceholder, {
        key: 1,
        icon: "pi pi-search",
        title: _ctx.$t("g.noResultsFound"),
        message: _ctx.$t("g.searchFailedMessage")
      }, null, 8, ["title", "message"]));
    };
  }
});
const _hoisted_1$14 = { class: "settings-container" };
const _sfc_main$19 = /* @__PURE__ */ defineComponent({
  __name: "SettingDialogContent",
  props: {
    defaultPanel: {}
  },
  setup(__props) {
    const props = __props;
    const KeybindingPanel = /* @__PURE__ */ defineAsyncComponent(
      () => __vitePreload(() => import("./KeybindingPanel-C-c9VhnA.js"), true ? __vite__mapDeps([32,26,2,4,33]) : void 0, import.meta.url)
    );
    const ExtensionPanel = /* @__PURE__ */ defineAsyncComponent(
      () => __vitePreload(() => import("./ExtensionPanel-CPmGRZ_x.js"), true ? __vite__mapDeps([34,26,2]) : void 0, import.meta.url)
    );
    const ServerConfigPanel = /* @__PURE__ */ defineAsyncComponent(
      () => __vitePreload(() => import("./ServerConfigPanel-0V5kfAZ5.js"), true ? __vite__mapDeps([35,5]) : void 0, import.meta.url)
    );
    const aboutPanelNode = {
      key: "about",
      label: "About",
      children: []
    };
    const keybindingPanelNode = {
      key: "keybinding",
      label: "Keybinding",
      children: []
    };
    const extensionPanelNode = {
      key: "extension",
      label: "Extension",
      children: []
    };
    const serverConfigPanelNode = {
      key: "server-config",
      label: "Server-Config",
      children: []
    };
    const serverConfigPanelNodeList = computed(() => {
      return isElectron() ? [serverConfigPanelNode] : [];
    });
    const settingStore = useSettingStore();
    const settingRoot = computed(() => settingStore.settingTree);
    const settingCategories = computed(
      () => settingRoot.value.children ?? []
    );
    const { t: t2 } = useI18n();
    const categories = computed(
      () => [
        ...settingCategories.value,
        keybindingPanelNode,
        extensionPanelNode,
        ...serverConfigPanelNodeList.value,
        aboutPanelNode
      ].map((node3) => ({
        ...node3,
        translatedLabel: t2(
          `settingsCategories.${normalizeI18nKey(node3.label)}`,
          node3.label
        )
      }))
    );
    const activeCategory = ref(null);
    const getDefaultCategory = /* @__PURE__ */ __name(() => {
      return props.defaultPanel ? categories.value.find((x2) => x2.key === props.defaultPanel) ?? categories.value[0] : categories.value[0];
    }, "getDefaultCategory");
    onMounted(() => {
      activeCategory.value = getDefaultCategory();
    });
    const sortedGroups = /* @__PURE__ */ __name((category) => {
      return [...category.children ?? []].sort((a2, b2) => a2.label.localeCompare(b2.label)).map((group) => ({
        label: group.label,
        settings: flattenTree(group)
      }));
    }, "sortedGroups");
    const searchQuery = ref("");
    const filteredSettingIds = ref([]);
    const searchInProgress = ref(false);
    watch(searchQuery, () => searchInProgress.value = true);
    const searchResults = computed(() => {
      const groupedSettings = {};
      filteredSettingIds.value.forEach((id4) => {
        const setting = settingStore.settingsById[id4];
        const info = getSettingInfo(setting);
        const groupLabel = info.subCategory;
        if (activeCategory.value === null || activeCategory.value.label === info.category) {
          if (!groupedSettings[groupLabel]) {
            groupedSettings[groupLabel] = [];
          }
          groupedSettings[groupLabel].push(setting);
        }
      });
      return Object.entries(groupedSettings).map(([label8, settings]) => ({
        label: label8,
        settings
      }));
    });
    const searchResultsCategories = computed(() => {
      return new Set(
        filteredSettingIds.value.map(
          (id4) => getSettingInfo(settingStore.settingsById[id4]).category
        )
      );
    });
    const handleSearch = /* @__PURE__ */ __name((query) => {
      if (!query) {
        filteredSettingIds.value = [];
        activeCategory.value ??= getDefaultCategory();
        return;
      }
      const queryLower = query.toLocaleLowerCase();
      const allSettings = flattenTree(settingRoot.value);
      const filteredSettings = allSettings.filter((setting) => {
        const idLower = setting.id.toLowerCase();
        const nameLower = setting.name.toLowerCase();
        const translatedName = st(
          `settings.${normalizeI18nKey(setting.id)}.name`,
          setting.name
        ).toLocaleLowerCase();
        const info = getSettingInfo(setting);
        const translatedCategory = st(
          `settingsCategories.${normalizeI18nKey(info.category)}`,
          info.category
        ).toLocaleLowerCase();
        const translatedSubCategory = st(
          `settingsCategories.${normalizeI18nKey(info.subCategory)}`,
          info.subCategory
        ).toLocaleLowerCase();
        return idLower.includes(queryLower) || nameLower.includes(queryLower) || translatedName.includes(queryLower) || translatedCategory.includes(queryLower) || translatedSubCategory.includes(queryLower);
      });
      filteredSettingIds.value = filteredSettings.map((x2) => x2.id);
      searchInProgress.value = false;
      activeCategory.value = null;
    }, "handleSearch");
    const queryIsEmpty = computed(() => searchQuery.value.length === 0);
    const inSearch = computed(() => !queryIsEmpty.value && !searchInProgress.value);
    const tabValue = computed(
      () => inSearch.value ? "Search Results" : activeCategory.value?.label ?? ""
    );
    watch(activeCategory, (_2, oldValue) => {
      if (!tabValue.value) {
        activeCategory.value = oldValue;
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$14, [
        createVNode(unref(script$X), { class: "settings-sidebar flex-shrink-0 p-2 w-48 2xl:w-64" }, {
          default: withCtx(() => [
            createVNode(SearchBox, {
              class: "settings-search-box w-full mb-2",
              modelValue: searchQuery.value,
              "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => searchQuery.value = $event),
              onSearch: handleSearch,
              placeholder: _ctx.$t("g.searchSettings") + "...",
              "debounce-time": 128
            }, null, 8, ["modelValue", "placeholder"]),
            createVNode(unref(script$G), {
              modelValue: activeCategory.value,
              "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => activeCategory.value = $event),
              options: categories.value,
              optionLabel: "translatedLabel",
              scrollHeight: "100%",
              optionDisabled: /* @__PURE__ */ __name((option5) => !queryIsEmpty.value && !searchResultsCategories.value.has(option5.label ?? ""), "optionDisabled"),
              class: "border-none w-full"
            }, null, 8, ["modelValue", "options", "optionDisabled"])
          ]),
          _: 1
        }),
        createVNode(unref(script$Y), {
          layout: "vertical",
          class: "mx-1 2xl:mx-4 hidden md:flex"
        }),
        createVNode(unref(script$Y), {
          layout: "horizontal",
          class: "flex md:hidden"
        }),
        createVNode(unref(script$C), {
          value: tabValue.value,
          lazy: true,
          class: "settings-content h-full w-full"
        }, {
          default: withCtx(() => [
            createVNode(unref(script$D), { class: "settings-tab-panels h-full w-full pr-0" }, {
              default: withCtx(() => [
                createVNode(_sfc_main$1o, { value: "Search Results" }, {
                  default: withCtx(() => [
                    createVNode(_sfc_main$1a, { settingGroups: searchResults.value }, null, 8, ["settingGroups"])
                  ]),
                  _: 1
                }),
                (openBlock(true), createElementBlock(Fragment$1, null, renderList(settingCategories.value, (category) => {
                  return openBlock(), createBlock(_sfc_main$1o, {
                    key: category.key,
                    value: category.label ?? ""
                  }, {
                    header: withCtx(() => [
                      tabValue.value === "Comfy" ? (openBlock(), createBlock(_sfc_main$1l, { key: 0 })) : createCommentVNode("", true),
                      tabValue.value === "Comfy" ? (openBlock(), createBlock(_sfc_main$1k, { key: 1 })) : createCommentVNode("", true),
                      tabValue.value === "Appearance" ? (openBlock(), createBlock(_sfc_main$1m, { key: 2 })) : createCommentVNode("", true)
                    ]),
                    default: withCtx(() => [
                      createVNode(_sfc_main$1a, {
                        settingGroups: sortedGroups(category)
                      }, null, 8, ["settingGroups"])
                    ]),
                    _: 2
                  }, 1032, ["value"]);
                }), 128)),
                createVNode(_sfc_main$1n),
                (openBlock(), createBlock(Suspense, null, {
                  fallback: withCtx(() => _cache[2] || (_cache[2] = [
                    createBaseVNode("div", null, "Loading keybinding panel...", -1)
                  ])),
                  default: withCtx(() => [
                    createVNode(unref(KeybindingPanel))
                  ]),
                  _: 1
                })),
                (openBlock(), createBlock(Suspense, null, {
                  fallback: withCtx(() => _cache[3] || (_cache[3] = [
                    createBaseVNode("div", null, "Loading extension panel...", -1)
                  ])),
                  default: withCtx(() => [
                    createVNode(unref(ExtensionPanel))
                  ]),
                  _: 1
                })),
                (openBlock(), createBlock(Suspense, null, {
                  fallback: withCtx(() => _cache[4] || (_cache[4] = [
                    createBaseVNode("div", null, "Loading server config panel...", -1)
                  ])),
                  default: withCtx(() => [
                    createVNode(unref(ServerConfigPanel))
                  ]),
                  _: 1
                }))
              ]),
              _: 1
            })
          ]),
          _: 1
        }, 8, ["value"])
      ]);
    };
  }
});
const SettingDialogContent = /* @__PURE__ */ _export_sfc(_sfc_main$19, [["__scopeId", "data-v-c8fd4821"]]);
const _sfc_main$18 = /* @__PURE__ */ defineComponent({
  __name: "ContentDivider",
  props: {
    orientation: { default: "horizontal" },
    width: { default: 0.3 }
  },
  setup(__props) {
    const colorPaletteStore = useColorPaletteStore();
    const isLightTheme = computed(
      () => colorPaletteStore.completedActivePalette.light_theme
    );
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("hr", {
        class: normalizeClass({
          "m-0": true,
          "border-t": _ctx.orientation === "horizontal",
          "border-l": _ctx.orientation === "vertical",
          "h-full": _ctx.orientation === "vertical",
          "w-full": _ctx.orientation === "horizontal"
        }),
        style: normalizeStyle({
          borderColor: isLightTheme.value ? "#DCDAE1" : "#2C2C2C",
          borderWidth: `${_ctx.width}px !important`
        })
      }, null, 6);
    };
  }
});
const _sfc_main$17 = /* @__PURE__ */ defineComponent({
  __name: "VirtualGrid",
  props: {
    items: {},
    gridStyle: {},
    bufferRows: { default: 1 },
    scrollThrottle: { default: 64 },
    resizeDebounce: { default: 64 },
    defaultItemHeight: { default: 200 },
    defaultItemWidth: { default: 200 }
  },
  emits: ["approach-end"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const itemHeight = ref(__props.defaultItemHeight);
    const itemWidth = ref(__props.defaultItemWidth);
    const container = ref(null);
    const { width: width2, height } = useElementSize(container);
    const { y: scrollY } = useScroll(container, {
      throttle: __props.scrollThrottle,
      eventListenerOptions: { passive: true }
    });
    const cols = computed(() => Math.floor(width2.value / itemWidth.value) || 1);
    const viewRows = computed(() => Math.ceil(height.value / itemHeight.value));
    const offsetRows = computed(() => Math.floor(scrollY.value / itemHeight.value));
    const isValidGrid = computed(() => height.value && width2.value && __props.items?.length);
    const state = computed(() => {
      const fromRow = offsetRows.value - __props.bufferRows;
      const toRow = offsetRows.value + __props.bufferRows + viewRows.value;
      const fromCol = fromRow * cols.value;
      const toCol = toRow * cols.value;
      const remainingCol = __props.items.length - toCol;
      return {
        start: lodashExports.clamp(fromCol, 0, __props.items?.length),
        end: lodashExports.clamp(toCol, fromCol, __props.items?.length),
        isNearEnd: remainingCol <= cols.value * __props.bufferRows
      };
    });
    const renderedItems = computed(
      () => isValidGrid.value ? __props.items.slice(state.value.start, state.value.end) : []
    );
    whenever(
      () => state.value.isNearEnd,
      () => {
        emit2("approach-end");
      }
    );
    const updateItemSize = /* @__PURE__ */ __name(() => {
      if (container.value) {
        const firstItem = container.value.querySelector("[data-virtual-grid-item]");
        itemHeight.value = firstItem?.clientHeight || __props.defaultItemHeight;
        itemWidth.value = firstItem?.clientWidth || __props.defaultItemWidth;
      }
    }, "updateItemSize");
    const onResize2 = lodashExports.debounce(updateItemSize, __props.resizeDebounce);
    watch([width2, height], onResize2, { flush: "post" });
    onBeforeUnmount(() => {
      onResize2.cancel();
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "container",
        ref: container,
        class: "scroll-container"
      }, [
        createBaseVNode("div", {
          style: normalizeStyle({ height: `${state.value.start / cols.value * itemHeight.value}px` })
        }, null, 4),
        createBaseVNode("div", {
          style: normalizeStyle(_ctx.gridStyle)
        }, [
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(renderedItems.value, (item3) => {
            return openBlock(), createElementBlock("div", {
              key: item3.key,
              "data-virtual-grid-item": ""
            }, [
              renderSlot(_ctx.$slots, "item", { item: item3 }, void 0, true)
            ]);
          }), 128))
        ], 4),
        createBaseVNode("div", {
          style: normalizeStyle({
            height: `${(_ctx.items.length - state.value.end) / cols.value * itemHeight.value}px`
          })
        }, null, 4)
      ], 512);
    };
  }
});
const VirtualGrid = /* @__PURE__ */ _export_sfc(_sfc_main$17, [["__scopeId", "data-v-40817131"]]);
const _hoisted_1$13 = { class: "absolute translate-x-0 top-0 left-0 h-full w-80 shadow-md z-5 transition-transform duration-300 ease-in-out flex" };
const _hoisted_2$Q = { class: "text-left flex items-center" };
const _hoisted_3$A = { class: "text-lg" };
const _sfc_main$16 = /* @__PURE__ */ defineComponent({
  __name: "ManagerNavSidebar",
  props: /* @__PURE__ */ mergeModels({
    tabs: {}
  }, {
    "selectedTab": {},
    "selectedTabModifiers": {}
  }),
  emits: ["update:selectedTab"],
  setup(__props) {
    const selectedTab = useModel(__props, "selectedTab");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("aside", _hoisted_1$13, [
        createVNode(unref(script$X), { class: "w-80 mt-7" }, {
          default: withCtx(() => [
            createVNode(unref(script$G), {
              modelValue: selectedTab.value,
              "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedTab.value = $event),
              options: _ctx.tabs,
              optionLabel: "label",
              listStyle: "max-height:unset",
              class: "w-full border-0 bg-transparent shadow-none",
              pt: {
                list: { class: "p-5" },
                option: { class: "px-8 py-3 text-lg rounded-xl" },
                optionGroup: { class: "p-0 text-left text-inherit" }
              }
            }, {
              option: withCtx((slotProps) => [
                createBaseVNode("div", _hoisted_2$Q, [
                  createBaseVNode("i", {
                    class: normalizeClass(["pi", slotProps.option.icon, "mr-3"])
                  }, null, 2),
                  createBaseVNode("span", _hoisted_3$A, toDisplayString$1(slotProps.option.label), 1)
                ])
              ]),
              _: 1
            }, 8, ["modelValue", "options"])
          ]),
          _: 1
        }),
        createVNode(_sfc_main$18, { orientation: "vertical" })
      ]);
    };
  }
});
const _sfc_main$15 = /* @__PURE__ */ defineComponent({
  __name: "PackStatusMessage",
  props: {
    statusType: {}
  },
  setup(__props) {
    const statusPropsMap = {
      NodeStatusActive: {
        label: "active",
        severity: "success"
      },
      NodeStatusDeleted: {
        label: "deleted",
        severity: "warn"
      },
      NodeStatusBanned: {
        label: "banned",
        severity: "danger"
      },
      NodeVersionStatusActive: {
        label: "active",
        severity: "success"
      },
      NodeVersionStatusPending: {
        label: "pending",
        severity: "warn"
      },
      NodeVersionStatusDeleted: {
        label: "deleted",
        severity: "warn"
      },
      NodeVersionStatusFlagged: {
        label: "flagged",
        severity: "danger"
      },
      NodeVersionStatusBanned: {
        label: "banned",
        severity: "danger"
      }
    };
    const statusLabel = computed(
      () => statusPropsMap[__props.statusType]?.label || "unknown"
    );
    const statusSeverity = computed(
      () => statusPropsMap[__props.statusType]?.severity || "secondary"
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$Z), {
        severity: statusSeverity.value,
        class: "p-0 flex items-center rounded-xl break-words w-fit",
        pt: {
          text: { class: "text-xs" },
          content: { class: "px-2 py-0.5" }
        }
      }, {
        default: withCtx(() => [
          _cache[0] || (_cache[0] = createBaseVNode("i", {
            class: "pi pi-circle-fill mr-1.5 text-[0.6rem] p-0",
            style: { opacity: 0.8 }
          }, null, -1)),
          createTextVNode(" " + toDisplayString$1(_ctx.$t(`manager.status.${statusLabel.value}`)), 1)
        ]),
        _: 1
      }, 8, ["severity"]);
    };
  }
});
var theme$c = /* @__PURE__ */ __name(function theme34(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-popover {\n    margin-block-start: ".concat(dt2("popover.gutter"), ";\n    background: ").concat(dt2("popover.background"), ";\n    color: ").concat(dt2("popover.color"), ";\n    border: 1px solid ").concat(dt2("popover.border.color"), ";\n    border-radius: ").concat(dt2("popover.border.radius"), ";\n    box-shadow: ").concat(dt2("popover.shadow"), ";\n}\n\n.p-popover-content {\n    padding: ").concat(dt2("popover.content.padding"), ";\n}\n\n.p-popover-flipped {\n    margin-block-start: calc(").concat(dt2("popover.gutter"), " * -1);\n    margin-block-end: ").concat(dt2("popover.gutter"), ";\n}\n\n.p-popover-enter-from {\n    opacity: 0;\n    transform: scaleY(0.8);\n}\n\n.p-popover-leave-to {\n    opacity: 0;\n}\n\n.p-popover-enter-active {\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1), opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-popover-leave-active {\n    transition: opacity 0.1s linear;\n}\n\n.p-popover:after,\n.p-popover:before {\n    bottom: 100%;\n    left: calc(").concat(dt2("popover.arrow.offset"), " + ").concat(dt2("popover.arrow.left"), ');\n    content: " ";\n    height: 0;\n    width: 0;\n    position: absolute;\n    pointer-events: none;\n}\n\n.p-popover:after {\n    border-width: calc(').concat(dt2("popover.gutter"), " - 2px);\n    margin-left: calc(-1 * (").concat(dt2("popover.gutter"), " - 2px));\n    border-style: solid;\n    border-color: transparent;\n    border-bottom-color: ").concat(dt2("popover.background"), ";\n}\n\n.p-popover:before {\n    border-width: ").concat(dt2("popover.gutter"), ";\n    margin-left: calc(-1 * ").concat(dt2("popover.gutter"), ");\n    border-style: solid;\n    border-color: transparent;\n    border-bottom-color: ").concat(dt2("popover.border.color"), ";\n}\n\n.p-popover-flipped:after,\n.p-popover-flipped:before {\n    bottom: auto;\n    top: 100%;\n}\n\n.p-popover.p-popover-flipped:after {\n    border-bottom-color: transparent;\n    border-top-color: ").concat(dt2("popover.background"), ";\n}\n\n.p-popover.p-popover-flipped:before {\n    border-bottom-color: transparent;\n    border-top-color: ").concat(dt2("popover.border.color"), ";\n}\n");
}, "theme");
var classes$e = {
  root: "p-popover p-component",
  content: "p-popover-content"
};
var PopoverStyle = BaseStyle$1.extend({
  name: "popover",
  theme: theme$c,
  classes: classes$e
});
var script$1$e = {
  name: "BasePopover",
  "extends": script$1b,
  props: {
    dismissable: {
      type: Boolean,
      "default": true
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    autoZIndex: {
      type: Boolean,
      "default": true
    },
    breakpoints: {
      type: Object,
      "default": null
    },
    closeOnEscape: {
      type: Boolean,
      "default": true
    }
  },
  style: PopoverStyle,
  provide: /* @__PURE__ */ __name(function provide37() {
    return {
      $pcPopover: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$l = {
  name: "Popover",
  "extends": script$1$e,
  inheritAttrs: false,
  emits: ["show", "hide"],
  data: /* @__PURE__ */ __name(function data18() {
    return {
      visible: false
    };
  }, "data"),
  watch: {
    dismissable: {
      immediate: true,
      handler: /* @__PURE__ */ __name(function handler11(newValue2) {
        if (newValue2) {
          this.bindOutsideClickListener();
        } else {
          this.unbindOutsideClickListener();
        }
      }, "handler")
    }
  },
  selfClick: false,
  target: null,
  eventTarget: null,
  outsideClickListener: null,
  scrollHandler: null,
  resizeListener: null,
  container: null,
  styleElement: null,
  overlayEventListener: null,
  documentKeydownListener: null,
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount9() {
    if (this.dismissable) {
      this.unbindOutsideClickListener();
    }
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    this.destroyStyle();
    this.unbindResizeListener();
    this.target = null;
    if (this.container && this.autoZIndex) {
      ZIndex$1.clear(this.container);
    }
    if (this.overlayEventListener) {
      OverlayEventBus.off("overlay-click", this.overlayEventListener);
      this.overlayEventListener = null;
    }
    this.container = null;
  }, "beforeUnmount"),
  mounted: /* @__PURE__ */ __name(function mounted17() {
    if (this.breakpoints) {
      this.createStyle();
    }
  }, "mounted"),
  methods: {
    toggle: /* @__PURE__ */ __name(function toggle2(event, target2) {
      if (this.visible) this.hide();
      else this.show(event, target2);
    }, "toggle"),
    show: /* @__PURE__ */ __name(function show3(event, target2) {
      this.visible = true;
      this.eventTarget = event.currentTarget;
      this.target = target2 || event.currentTarget;
    }, "show"),
    hide: /* @__PURE__ */ __name(function hide3() {
      this.visible = false;
    }, "hide"),
    onContentClick: /* @__PURE__ */ __name(function onContentClick() {
      this.selfClick = true;
    }, "onContentClick"),
    onEnter: /* @__PURE__ */ __name(function onEnter2(el) {
      var _this = this;
      addStyle$1(el, {
        position: "absolute",
        top: "0",
        left: "0"
      });
      this.alignOverlay();
      if (this.dismissable) {
        this.bindOutsideClickListener();
      }
      this.bindScrollListener();
      this.bindResizeListener();
      if (this.autoZIndex) {
        ZIndex$1.set("overlay", el, this.baseZIndex + this.$primevue.config.zIndex.overlay);
      }
      this.overlayEventListener = function(e2) {
        if (_this.container.contains(e2.target)) {
          _this.selfClick = true;
        }
      };
      this.focus();
      OverlayEventBus.on("overlay-click", this.overlayEventListener);
      this.$emit("show");
      if (this.closeOnEscape) {
        this.bindDocumentKeyDownListener();
      }
    }, "onEnter"),
    onLeave: /* @__PURE__ */ __name(function onLeave2() {
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
      this.unbindDocumentKeyDownListener();
      OverlayEventBus.off("overlay-click", this.overlayEventListener);
      this.overlayEventListener = null;
      this.$emit("hide");
    }, "onLeave"),
    onAfterLeave: /* @__PURE__ */ __name(function onAfterLeave2(el) {
      if (this.autoZIndex) {
        ZIndex$1.clear(el);
      }
    }, "onAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay4() {
      absolutePosition$1(this.container, this.target, false);
      var containerOffset = getOffset$1(this.container);
      var targetOffset = getOffset$1(this.target);
      var arrowLeft = 0;
      if (containerOffset.left < targetOffset.left) {
        arrowLeft = targetOffset.left - containerOffset.left;
      }
      this.container.style.setProperty($dt$1("popover.arrow.left").name, "".concat(arrowLeft, "px"));
      if (containerOffset.top < targetOffset.top) {
        this.container.setAttribute("data-p-popover-flipped", "true");
        !this.isUnstyled && addClass$1(this.container, "p-popover-flipped");
      }
    }, "alignOverlay"),
    onContentKeydown: /* @__PURE__ */ __name(function onContentKeydown(event) {
      if (event.code === "Escape" && this.closeOnEscape) {
        this.hide();
        focus$2(this.target);
      }
    }, "onContentKeydown"),
    onButtonKeydown: /* @__PURE__ */ __name(function onButtonKeydown(event) {
      switch (event.code) {
        case "ArrowDown":
        case "ArrowUp":
        case "ArrowLeft":
        case "ArrowRight":
          event.preventDefault();
      }
    }, "onButtonKeydown"),
    focus: /* @__PURE__ */ __name(function focus2() {
      var focusTarget = this.container.querySelector("[autofocus]");
      if (focusTarget) {
        focusTarget.focus();
      }
    }, "focus"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown8(event) {
      if (event.code === "Escape" && this.closeOnEscape) {
        this.visible = false;
      }
    }, "onKeyDown"),
    bindDocumentKeyDownListener: /* @__PURE__ */ __name(function bindDocumentKeyDownListener2() {
      if (!this.documentKeydownListener) {
        this.documentKeydownListener = this.onKeyDown.bind(this);
        window.document.addEventListener("keydown", this.documentKeydownListener);
      }
    }, "bindDocumentKeyDownListener"),
    unbindDocumentKeyDownListener: /* @__PURE__ */ __name(function unbindDocumentKeyDownListener2() {
      if (this.documentKeydownListener) {
        window.document.removeEventListener("keydown", this.documentKeydownListener);
        this.documentKeydownListener = null;
      }
    }, "unbindDocumentKeyDownListener"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener3() {
      var _this2 = this;
      if (!this.outsideClickListener && isClient$2()) {
        this.outsideClickListener = function(event) {
          if (_this2.visible && !_this2.selfClick && !_this2.isTargetClicked(event)) {
            _this2.visible = false;
          }
          _this2.selfClick = false;
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener3() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
        this.selfClick = false;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener4() {
      var _this3 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.target, function() {
          if (_this3.visible) {
            _this3.visible = false;
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener4() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener4() {
      var _this4 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this4.visible && !isTouchDevice$1()) {
            _this4.visible = false;
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener4() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    isTargetClicked: /* @__PURE__ */ __name(function isTargetClicked(event) {
      return this.eventTarget && (this.eventTarget === event.target || this.eventTarget.contains(event.target));
    }, "isTargetClicked"),
    containerRef: /* @__PURE__ */ __name(function containerRef2(el) {
      this.container = el;
    }, "containerRef"),
    createStyle: /* @__PURE__ */ __name(function createStyle2() {
      if (!this.styleElement && !this.isUnstyled) {
        var _this$$primevue;
        this.styleElement = document.createElement("style");
        this.styleElement.type = "text/css";
        setAttribute$1(this.styleElement, "nonce", (_this$$primevue = this.$primevue) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.config) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.csp) === null || _this$$primevue === void 0 ? void 0 : _this$$primevue.nonce);
        document.head.appendChild(this.styleElement);
        var innerHTML = "";
        for (var breakpoint in this.breakpoints) {
          innerHTML += "\n                        @media screen and (max-width: ".concat(breakpoint, ") {\n                            .p-popover[").concat(this.$attrSelector, "] {\n                                width: ").concat(this.breakpoints[breakpoint], " !important;\n                            }\n                        }\n                    ");
        }
        this.styleElement.innerHTML = innerHTML;
      }
    }, "createStyle"),
    destroyStyle: /* @__PURE__ */ __name(function destroyStyle2() {
      if (this.styleElement) {
        document.head.removeChild(this.styleElement);
        this.styleElement = null;
      }
    }, "destroyStyle"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick3(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.target
      });
    }, "onOverlayClick")
  },
  directives: {
    focustrap: FocusTrap,
    ripple: Ripple
  },
  components: {
    Portal: script$$
  }
};
var _hoisted_1$12 = ["aria-modal"];
function render$j(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Portal = resolveComponent("Portal");
  var _directive_focustrap = resolveDirective("focustrap");
  return openBlock(), createBlock(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-popover",
        onEnter: $options.onEnter,
        onLeave: $options.onLeave,
        onAfterLeave: $options.onAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [$data.visible ? withDirectives((openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.containerRef,
            role: "dialog",
            "aria-modal": $data.visible,
            onClick: _cache[3] || (_cache[3] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            }),
            "class": _ctx.cx("root")
          }, _ctx.ptmi("root")), [_ctx.$slots.container ? renderSlot(_ctx.$slots, "container", {
            key: 0,
            closeCallback: $options.hide,
            keydownCallback: /* @__PURE__ */ __name(function keydownCallback(event) {
              return $options.onButtonKeydown(event);
            }, "keydownCallback")
          }) : (openBlock(), createElementBlock("div", mergeProps$2({
            key: 1,
            "class": _ctx.cx("content"),
            onClick: _cache[0] || (_cache[0] = function() {
              return $options.onContentClick && $options.onContentClick.apply($options, arguments);
            }),
            onMousedown: _cache[1] || (_cache[1] = function() {
              return $options.onContentClick && $options.onContentClick.apply($options, arguments);
            }),
            onKeydown: _cache[2] || (_cache[2] = function() {
              return $options.onContentKeydown && $options.onContentKeydown.apply($options, arguments);
            })
          }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "default")], 16))], 16, _hoisted_1$12)), [[_directive_focustrap]]) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 3
  }, 8, ["appendTo"]);
}
__name(render$j, "render$j");
script$l.render = render$j;
function transformNodeDefV1ToV2(nodeDefV1) {
  const inputs = {};
  if (nodeDefV1.input?.required) {
    Object.entries(nodeDefV1.input.required).forEach(([name2, inputSpecV1]) => {
      inputs[name2] = transformInputSpecV1ToV2(inputSpecV1, {
        name: name2,
        isOptional: false
      });
    });
  }
  if (nodeDefV1.input?.optional) {
    Object.entries(nodeDefV1.input.optional).forEach(([name2, inputSpecV1]) => {
      inputs[name2] = transformInputSpecV1ToV2(inputSpecV1, {
        name: name2,
        isOptional: true
      });
    });
  }
  const outputs = [];
  if (nodeDefV1.output) {
    nodeDefV1.output.forEach((outputType, index2) => {
      const outputSpec = {
        index: index2,
        name: nodeDefV1.output_name?.[index2] || `output_${index2}`,
        type: Array.isArray(outputType) ? "COMBO" : outputType,
        is_list: nodeDefV1.output_is_list?.[index2] || false,
        tooltip: nodeDefV1.output_tooltips?.[index2]
      };
      if (Array.isArray(outputType)) {
        outputSpec.options = outputType;
      }
      outputs.push(outputSpec);
    });
  }
  return {
    inputs,
    outputs,
    hidden: nodeDefV1.input?.hidden,
    name: nodeDefV1.name,
    display_name: nodeDefV1.display_name,
    description: nodeDefV1.description,
    category: nodeDefV1.category,
    output_node: nodeDefV1.output_node,
    python_module: nodeDefV1.python_module,
    deprecated: nodeDefV1.deprecated,
    experimental: nodeDefV1.experimental
  };
}
__name(transformNodeDefV1ToV2, "transformNodeDefV1ToV2");
function transformInputSpecV1ToV2(inputSpecV1, kwargs) {
  const { name: name2, isOptional = false } = kwargs;
  const options5 = inputSpecV1[1] || {};
  const baseProps = {
    name: name2,
    isOptional,
    ...options5
  };
  if (isComboInputSpec$1(inputSpecV1)) {
    return {
      type: "COMBO",
      ...baseProps,
      options: isComboInputSpecV1(inputSpecV1) ? inputSpecV1[0] : getComboSpecComboOptions(inputSpecV1)
    };
  } else if (typeof inputSpecV1[0] === "string") {
    return {
      type: inputSpecV1[0],
      ...baseProps
    };
  }
  return {
    type: "UNKNOWN",
    ...baseProps
  };
}
__name(transformInputSpecV1ToV2, "transformInputSpecV1ToV2");
function transformInputSpecV2ToV1(inputSpecV2) {
  return [inputSpecV2.type, inputSpecV2];
}
__name(transformInputSpecV2ToV1, "transformInputSpecV2ToV1");
function isArray(value3) {
  return !Array.isArray ? getTag(value3) === "[object Array]" : Array.isArray(value3);
}
__name(isArray, "isArray");
const INFINITY = 1 / 0;
function baseToString(value3) {
  if (typeof value3 == "string") {
    return value3;
  }
  let result = value3 + "";
  return result == "0" && 1 / value3 == -INFINITY ? "-0" : result;
}
__name(baseToString, "baseToString");
function toString(value3) {
  return value3 == null ? "" : baseToString(value3);
}
__name(toString, "toString");
function isString$3(value3) {
  return typeof value3 === "string";
}
__name(isString$3, "isString$3");
function isNumber$2(value3) {
  return typeof value3 === "number";
}
__name(isNumber$2, "isNumber$2");
function isBoolean(value3) {
  return value3 === true || value3 === false || isObjectLike(value3) && getTag(value3) == "[object Boolean]";
}
__name(isBoolean, "isBoolean");
function isObject$1(value3) {
  return typeof value3 === "object";
}
__name(isObject$1, "isObject$1");
function isObjectLike(value3) {
  return isObject$1(value3) && value3 !== null;
}
__name(isObjectLike, "isObjectLike");
function isDefined(value3) {
  return value3 !== void 0 && value3 !== null;
}
__name(isDefined, "isDefined");
function isBlank(value3) {
  return !value3.trim().length;
}
__name(isBlank, "isBlank");
function getTag(value3) {
  return value3 == null ? value3 === void 0 ? "[object Undefined]" : "[object Null]" : Object.prototype.toString.call(value3);
}
__name(getTag, "getTag");
const EXTENDED_SEARCH_UNAVAILABLE = "Extended search is not available";
const INCORRECT_INDEX_TYPE = "Incorrect 'index' type";
const LOGICAL_SEARCH_INVALID_QUERY_FOR_KEY = /* @__PURE__ */ __name((key) => `Invalid value for key ${key}`, "LOGICAL_SEARCH_INVALID_QUERY_FOR_KEY");
const PATTERN_LENGTH_TOO_LARGE = /* @__PURE__ */ __name((max) => `Pattern length exceeds max of ${max}.`, "PATTERN_LENGTH_TOO_LARGE");
const MISSING_KEY_PROPERTY = /* @__PURE__ */ __name((name2) => `Missing ${name2} property in key`, "MISSING_KEY_PROPERTY");
const INVALID_KEY_WEIGHT_VALUE = /* @__PURE__ */ __name((key) => `Property 'weight' in key '${key}' must be a positive integer`, "INVALID_KEY_WEIGHT_VALUE");
const hasOwn = Object.prototype.hasOwnProperty;
class KeyStore {
  static {
    __name(this, "KeyStore");
  }
  constructor(keys2) {
    this._keys = [];
    this._keyMap = {};
    let totalWeight = 0;
    keys2.forEach((key) => {
      let obj = createKey$1(key);
      this._keys.push(obj);
      this._keyMap[obj.id] = obj;
      totalWeight += obj.weight;
    });
    this._keys.forEach((key) => {
      key.weight /= totalWeight;
    });
  }
  get(keyId) {
    return this._keyMap[keyId];
  }
  keys() {
    return this._keys;
  }
  toJSON() {
    return JSON.stringify(this._keys);
  }
}
function createKey$1(key) {
  let path = null;
  let id4 = null;
  let src = null;
  let weight = 1;
  let getFn = null;
  if (isString$3(key) || isArray(key)) {
    src = key;
    path = createKeyPath(key);
    id4 = createKeyId(key);
  } else {
    if (!hasOwn.call(key, "name")) {
      throw new Error(MISSING_KEY_PROPERTY("name"));
    }
    const name2 = key.name;
    src = name2;
    if (hasOwn.call(key, "weight")) {
      weight = key.weight;
      if (weight <= 0) {
        throw new Error(INVALID_KEY_WEIGHT_VALUE(name2));
      }
    }
    path = createKeyPath(name2);
    id4 = createKeyId(name2);
    getFn = key.getFn;
  }
  return { path, id: id4, weight, src, getFn };
}
__name(createKey$1, "createKey$1");
function createKeyPath(key) {
  return isArray(key) ? key : key.split(".");
}
__name(createKeyPath, "createKeyPath");
function createKeyId(key) {
  return isArray(key) ? key.join(".") : key;
}
__name(createKeyId, "createKeyId");
function get$1(obj, path) {
  let list2 = [];
  let arr = false;
  const deepGet = /* @__PURE__ */ __name((obj2, path2, index2) => {
    if (!isDefined(obj2)) {
      return;
    }
    if (!path2[index2]) {
      list2.push(obj2);
    } else {
      let key = path2[index2];
      const value3 = obj2[key];
      if (!isDefined(value3)) {
        return;
      }
      if (index2 === path2.length - 1 && (isString$3(value3) || isNumber$2(value3) || isBoolean(value3))) {
        list2.push(toString(value3));
      } else if (isArray(value3)) {
        arr = true;
        for (let i2 = 0, len = value3.length; i2 < len; i2 += 1) {
          deepGet(value3[i2], path2, index2 + 1);
        }
      } else if (path2.length) {
        deepGet(value3, path2, index2 + 1);
      }
    }
  }, "deepGet");
  deepGet(obj, isString$3(path) ? path.split(".") : path, 0);
  return arr ? list2 : list2[0];
}
__name(get$1, "get$1");
const MatchOptions = {
  // Whether the matches should be included in the result set. When `true`, each record in the result
  // set will include the indices of the matched characters.
  // These can consequently be used for highlighting purposes.
  includeMatches: false,
  // When `true`, the matching function will continue to the end of a search pattern even if
  // a perfect match has already been located in the string.
  findAllMatches: false,
  // Minimum number of characters that must be matched before a result is considered a match
  minMatchCharLength: 1
};
const BasicOptions = {
  // When `true`, the algorithm continues searching to the end of the input even if a perfect
  // match is found before the end of the same input.
  isCaseSensitive: false,
  // When true, the matching function will continue to the end of a search pattern even if
  includeScore: false,
  // List of properties that will be searched. This also supports nested properties.
  keys: [],
  // Whether to sort the result list, by score
  shouldSort: true,
  // Default sort function: sort by ascending score, ascending index
  sortFn: /* @__PURE__ */ __name((a2, b2) => a2.score === b2.score ? a2.idx < b2.idx ? -1 : 1 : a2.score < b2.score ? -1 : 1, "sortFn")
};
const FuzzyOptions = {
  // Approximately where in the text is the pattern expected to be found?
  location: 0,
  // At what point does the match algorithm give up. A threshold of '0.0' requires a perfect match
  // (of both letters and location), a threshold of '1.0' would match anything.
  threshold: 0.6,
  // Determines how close the match must be to the fuzzy location (specified above).
  // An exact letter match which is 'distance' characters away from the fuzzy location
  // would score as a complete mismatch. A distance of '0' requires the match be at
  // the exact location specified, a threshold of '1000' would require a perfect match
  // to be within 800 characters of the fuzzy location to be found using a 0.8 threshold.
  distance: 100
};
const AdvancedOptions = {
  // When `true`, it enables the use of unix-like search commands
  useExtendedSearch: false,
  // The get function to use when fetching an object's properties.
  // The default will search nested paths *ie foo.bar.baz*
  getFn: get$1,
  // When `true`, search will ignore `location` and `distance`, so it won't matter
  // where in the string the pattern appears.
  // More info: https://fusejs.io/concepts/scoring-theory.html#fuzziness-score
  ignoreLocation: false,
  // When `true`, the calculation for the relevance score (used for sorting) will
  // ignore the field-length norm.
  // More info: https://fusejs.io/concepts/scoring-theory.html#field-length-norm
  ignoreFieldNorm: false,
  // The weight to determine how much field length norm effects scoring.
  fieldNormWeight: 1
};
var Config = {
  ...BasicOptions,
  ...MatchOptions,
  ...FuzzyOptions,
  ...AdvancedOptions
};
const SPACE$1 = /[^ ]+/g;
function norm(weight = 1, mantissa = 3) {
  const cache2 = /* @__PURE__ */ new Map();
  const m2 = Math.pow(10, mantissa);
  return {
    get(value3) {
      const numTokens = value3.match(SPACE$1).length;
      if (cache2.has(numTokens)) {
        return cache2.get(numTokens);
      }
      const norm2 = 1 / Math.pow(numTokens, 0.5 * weight);
      const n2 = parseFloat(Math.round(norm2 * m2) / m2);
      cache2.set(numTokens, n2);
      return n2;
    },
    clear() {
      cache2.clear();
    }
  };
}
__name(norm, "norm");
class FuseIndex {
  static {
    __name(this, "FuseIndex");
  }
  constructor({
    getFn = Config.getFn,
    fieldNormWeight = Config.fieldNormWeight
  } = {}) {
    this.norm = norm(fieldNormWeight, 3);
    this.getFn = getFn;
    this.isCreated = false;
    this.setIndexRecords();
  }
  setSources(docs = []) {
    this.docs = docs;
  }
  setIndexRecords(records = []) {
    this.records = records;
  }
  setKeys(keys2 = []) {
    this.keys = keys2;
    this._keysMap = {};
    keys2.forEach((key, idx) => {
      this._keysMap[key.id] = idx;
    });
  }
  create() {
    if (this.isCreated || !this.docs.length) {
      return;
    }
    this.isCreated = true;
    if (isString$3(this.docs[0])) {
      this.docs.forEach((doc2, docIndex) => {
        this._addString(doc2, docIndex);
      });
    } else {
      this.docs.forEach((doc2, docIndex) => {
        this._addObject(doc2, docIndex);
      });
    }
    this.norm.clear();
  }
  // Adds a doc to the end of the index
  add(doc2) {
    const idx = this.size();
    if (isString$3(doc2)) {
      this._addString(doc2, idx);
    } else {
      this._addObject(doc2, idx);
    }
  }
  // Removes the doc at the specified index of the index
  removeAt(idx) {
    this.records.splice(idx, 1);
    for (let i2 = idx, len = this.size(); i2 < len; i2 += 1) {
      this.records[i2].i -= 1;
    }
  }
  getValueForItemAtKeyId(item3, keyId) {
    return item3[this._keysMap[keyId]];
  }
  size() {
    return this.records.length;
  }
  _addString(doc2, docIndex) {
    if (!isDefined(doc2) || isBlank(doc2)) {
      return;
    }
    let record2 = {
      v: doc2,
      i: docIndex,
      n: this.norm.get(doc2)
    };
    this.records.push(record2);
  }
  _addObject(doc2, docIndex) {
    let record2 = { i: docIndex, $: {} };
    this.keys.forEach((key, keyIndex) => {
      let value3 = key.getFn ? key.getFn(doc2) : this.getFn(doc2, key.path);
      if (!isDefined(value3)) {
        return;
      }
      if (isArray(value3)) {
        let subRecords = [];
        const stack2 = [{ nestedArrIndex: -1, value: value3 }];
        while (stack2.length) {
          const { nestedArrIndex, value: value4 } = stack2.pop();
          if (!isDefined(value4)) {
            continue;
          }
          if (isString$3(value4) && !isBlank(value4)) {
            let subRecord = {
              v: value4,
              i: nestedArrIndex,
              n: this.norm.get(value4)
            };
            subRecords.push(subRecord);
          } else if (isArray(value4)) {
            value4.forEach((item3, k2) => {
              stack2.push({
                nestedArrIndex: k2,
                value: item3
              });
            });
          } else ;
        }
        record2.$[keyIndex] = subRecords;
      } else if (isString$3(value3) && !isBlank(value3)) {
        let subRecord = {
          v: value3,
          n: this.norm.get(value3)
        };
        record2.$[keyIndex] = subRecord;
      }
    });
    this.records.push(record2);
  }
  toJSON() {
    return {
      keys: this.keys,
      records: this.records
    };
  }
}
function createIndex(keys2, docs, { getFn = Config.getFn, fieldNormWeight = Config.fieldNormWeight } = {}) {
  const myIndex = new FuseIndex({ getFn, fieldNormWeight });
  myIndex.setKeys(keys2.map(createKey$1));
  myIndex.setSources(docs);
  myIndex.create();
  return myIndex;
}
__name(createIndex, "createIndex");
function parseIndex(data30, { getFn = Config.getFn, fieldNormWeight = Config.fieldNormWeight } = {}) {
  const { keys: keys2, records } = data30;
  const myIndex = new FuseIndex({ getFn, fieldNormWeight });
  myIndex.setKeys(keys2);
  myIndex.setIndexRecords(records);
  return myIndex;
}
__name(parseIndex, "parseIndex");
function computeScore$1(pattern, {
  errors: errors2 = 0,
  currentLocation = 0,
  expectedLocation = 0,
  distance: distance2 = Config.distance,
  ignoreLocation = Config.ignoreLocation
} = {}) {
  const accuracy = errors2 / pattern.length;
  if (ignoreLocation) {
    return accuracy;
  }
  const proximity = Math.abs(expectedLocation - currentLocation);
  if (!distance2) {
    return proximity ? 1 : accuracy;
  }
  return accuracy + proximity / distance2;
}
__name(computeScore$1, "computeScore$1");
function convertMaskToIndices(matchmask = [], minMatchCharLength = Config.minMatchCharLength) {
  let indices = [];
  let start2 = -1;
  let end = -1;
  let i2 = 0;
  for (let len = matchmask.length; i2 < len; i2 += 1) {
    let match2 = matchmask[i2];
    if (match2 && start2 === -1) {
      start2 = i2;
    } else if (!match2 && start2 !== -1) {
      end = i2 - 1;
      if (end - start2 + 1 >= minMatchCharLength) {
        indices.push([start2, end]);
      }
      start2 = -1;
    }
  }
  if (matchmask[i2 - 1] && i2 - start2 >= minMatchCharLength) {
    indices.push([start2, i2 - 1]);
  }
  return indices;
}
__name(convertMaskToIndices, "convertMaskToIndices");
const MAX_BITS = 32;
function search(text2, pattern, patternAlphabet, {
  location: location2 = Config.location,
  distance: distance2 = Config.distance,
  threshold = Config.threshold,
  findAllMatches = Config.findAllMatches,
  minMatchCharLength = Config.minMatchCharLength,
  includeMatches = Config.includeMatches,
  ignoreLocation = Config.ignoreLocation
} = {}) {
  if (pattern.length > MAX_BITS) {
    throw new Error(PATTERN_LENGTH_TOO_LARGE(MAX_BITS));
  }
  const patternLen = pattern.length;
  const textLen = text2.length;
  const expectedLocation = Math.max(0, Math.min(location2, textLen));
  let currentThreshold = threshold;
  let bestLocation = expectedLocation;
  const computeMatches = minMatchCharLength > 1 || includeMatches;
  const matchMask = computeMatches ? Array(textLen) : [];
  let index2;
  while ((index2 = text2.indexOf(pattern, bestLocation)) > -1) {
    let score = computeScore$1(pattern, {
      currentLocation: index2,
      expectedLocation,
      distance: distance2,
      ignoreLocation
    });
    currentThreshold = Math.min(score, currentThreshold);
    bestLocation = index2 + patternLen;
    if (computeMatches) {
      let i2 = 0;
      while (i2 < patternLen) {
        matchMask[index2 + i2] = 1;
        i2 += 1;
      }
    }
  }
  bestLocation = -1;
  let lastBitArr = [];
  let finalScore = 1;
  let binMax = patternLen + textLen;
  const mask3 = 1 << patternLen - 1;
  for (let i2 = 0; i2 < patternLen; i2 += 1) {
    let binMin = 0;
    let binMid = binMax;
    while (binMin < binMid) {
      const score2 = computeScore$1(pattern, {
        errors: i2,
        currentLocation: expectedLocation + binMid,
        expectedLocation,
        distance: distance2,
        ignoreLocation
      });
      if (score2 <= currentThreshold) {
        binMin = binMid;
      } else {
        binMax = binMid;
      }
      binMid = Math.floor((binMax - binMin) / 2 + binMin);
    }
    binMax = binMid;
    let start2 = Math.max(1, expectedLocation - binMid + 1);
    let finish = findAllMatches ? textLen : Math.min(expectedLocation + binMid, textLen) + patternLen;
    let bitArr = Array(finish + 2);
    bitArr[finish + 1] = (1 << i2) - 1;
    for (let j2 = finish; j2 >= start2; j2 -= 1) {
      let currentLocation = j2 - 1;
      let charMatch = patternAlphabet[text2.charAt(currentLocation)];
      if (computeMatches) {
        matchMask[currentLocation] = +!!charMatch;
      }
      bitArr[j2] = (bitArr[j2 + 1] << 1 | 1) & charMatch;
      if (i2) {
        bitArr[j2] |= (lastBitArr[j2 + 1] | lastBitArr[j2]) << 1 | 1 | lastBitArr[j2 + 1];
      }
      if (bitArr[j2] & mask3) {
        finalScore = computeScore$1(pattern, {
          errors: i2,
          currentLocation,
          expectedLocation,
          distance: distance2,
          ignoreLocation
        });
        if (finalScore <= currentThreshold) {
          currentThreshold = finalScore;
          bestLocation = currentLocation;
          if (bestLocation <= expectedLocation) {
            break;
          }
          start2 = Math.max(1, 2 * expectedLocation - bestLocation);
        }
      }
    }
    const score = computeScore$1(pattern, {
      errors: i2 + 1,
      currentLocation: expectedLocation,
      expectedLocation,
      distance: distance2,
      ignoreLocation
    });
    if (score > currentThreshold) {
      break;
    }
    lastBitArr = bitArr;
  }
  const result = {
    isMatch: bestLocation >= 0,
    // Count exact matches (those with a score of 0) to be "almost" exact
    score: Math.max(1e-3, finalScore)
  };
  if (computeMatches) {
    const indices = convertMaskToIndices(matchMask, minMatchCharLength);
    if (!indices.length) {
      result.isMatch = false;
    } else if (includeMatches) {
      result.indices = indices;
    }
  }
  return result;
}
__name(search, "search");
function createPatternAlphabet(pattern) {
  let mask3 = {};
  for (let i2 = 0, len = pattern.length; i2 < len; i2 += 1) {
    const char = pattern.charAt(i2);
    mask3[char] = (mask3[char] || 0) | 1 << len - i2 - 1;
  }
  return mask3;
}
__name(createPatternAlphabet, "createPatternAlphabet");
class BitapSearch {
  static {
    __name(this, "BitapSearch");
  }
  constructor(pattern, {
    location: location2 = Config.location,
    threshold = Config.threshold,
    distance: distance2 = Config.distance,
    includeMatches = Config.includeMatches,
    findAllMatches = Config.findAllMatches,
    minMatchCharLength = Config.minMatchCharLength,
    isCaseSensitive = Config.isCaseSensitive,
    ignoreLocation = Config.ignoreLocation
  } = {}) {
    this.options = {
      location: location2,
      threshold,
      distance: distance2,
      includeMatches,
      findAllMatches,
      minMatchCharLength,
      isCaseSensitive,
      ignoreLocation
    };
    this.pattern = isCaseSensitive ? pattern : pattern.toLowerCase();
    this.chunks = [];
    if (!this.pattern.length) {
      return;
    }
    const addChunk = /* @__PURE__ */ __name((pattern2, startIndex) => {
      this.chunks.push({
        pattern: pattern2,
        alphabet: createPatternAlphabet(pattern2),
        startIndex
      });
    }, "addChunk");
    const len = this.pattern.length;
    if (len > MAX_BITS) {
      let i2 = 0;
      const remainder = len % MAX_BITS;
      const end = len - remainder;
      while (i2 < end) {
        addChunk(this.pattern.substr(i2, MAX_BITS), i2);
        i2 += MAX_BITS;
      }
      if (remainder) {
        const startIndex = len - MAX_BITS;
        addChunk(this.pattern.substr(startIndex), startIndex);
      }
    } else {
      addChunk(this.pattern, 0);
    }
  }
  searchIn(text2) {
    const { isCaseSensitive, includeMatches } = this.options;
    if (!isCaseSensitive) {
      text2 = text2.toLowerCase();
    }
    if (this.pattern === text2) {
      let result2 = {
        isMatch: true,
        score: 0
      };
      if (includeMatches) {
        result2.indices = [[0, text2.length - 1]];
      }
      return result2;
    }
    const {
      location: location2,
      distance: distance2,
      threshold,
      findAllMatches,
      minMatchCharLength,
      ignoreLocation
    } = this.options;
    let allIndices = [];
    let totalScore = 0;
    let hasMatches = false;
    this.chunks.forEach(({ pattern, alphabet, startIndex }) => {
      const { isMatch, score, indices } = search(text2, pattern, alphabet, {
        location: location2 + startIndex,
        distance: distance2,
        threshold,
        findAllMatches,
        minMatchCharLength,
        includeMatches,
        ignoreLocation
      });
      if (isMatch) {
        hasMatches = true;
      }
      totalScore += score;
      if (isMatch && indices) {
        allIndices = [...allIndices, ...indices];
      }
    });
    let result = {
      isMatch: hasMatches,
      score: hasMatches ? totalScore / this.chunks.length : 1
    };
    if (hasMatches && includeMatches) {
      result.indices = allIndices;
    }
    return result;
  }
}
class BaseMatch {
  static {
    __name(this, "BaseMatch");
  }
  constructor(pattern) {
    this.pattern = pattern;
  }
  static isMultiMatch(pattern) {
    return getMatch(pattern, this.multiRegex);
  }
  static isSingleMatch(pattern) {
    return getMatch(pattern, this.singleRegex);
  }
  search() {
  }
}
function getMatch(pattern, exp) {
  const matches2 = pattern.match(exp);
  return matches2 ? matches2[1] : null;
}
__name(getMatch, "getMatch");
class ExactMatch extends BaseMatch {
  static {
    __name(this, "ExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "exact";
  }
  static get multiRegex() {
    return /^="(.*)"$/;
  }
  static get singleRegex() {
    return /^=(.*)$/;
  }
  search(text2) {
    const isMatch = text2 === this.pattern;
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [0, this.pattern.length - 1]
    };
  }
}
class InverseExactMatch extends BaseMatch {
  static {
    __name(this, "InverseExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "inverse-exact";
  }
  static get multiRegex() {
    return /^!"(.*)"$/;
  }
  static get singleRegex() {
    return /^!(.*)$/;
  }
  search(text2) {
    const index2 = text2.indexOf(this.pattern);
    const isMatch = index2 === -1;
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [0, text2.length - 1]
    };
  }
}
class PrefixExactMatch extends BaseMatch {
  static {
    __name(this, "PrefixExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "prefix-exact";
  }
  static get multiRegex() {
    return /^\^"(.*)"$/;
  }
  static get singleRegex() {
    return /^\^(.*)$/;
  }
  search(text2) {
    const isMatch = text2.startsWith(this.pattern);
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [0, this.pattern.length - 1]
    };
  }
}
class InversePrefixExactMatch extends BaseMatch {
  static {
    __name(this, "InversePrefixExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "inverse-prefix-exact";
  }
  static get multiRegex() {
    return /^!\^"(.*)"$/;
  }
  static get singleRegex() {
    return /^!\^(.*)$/;
  }
  search(text2) {
    const isMatch = !text2.startsWith(this.pattern);
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [0, text2.length - 1]
    };
  }
}
class SuffixExactMatch extends BaseMatch {
  static {
    __name(this, "SuffixExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "suffix-exact";
  }
  static get multiRegex() {
    return /^"(.*)"\$$/;
  }
  static get singleRegex() {
    return /^(.*)\$$/;
  }
  search(text2) {
    const isMatch = text2.endsWith(this.pattern);
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [text2.length - this.pattern.length, text2.length - 1]
    };
  }
}
class InverseSuffixExactMatch extends BaseMatch {
  static {
    __name(this, "InverseSuffixExactMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "inverse-suffix-exact";
  }
  static get multiRegex() {
    return /^!"(.*)"\$$/;
  }
  static get singleRegex() {
    return /^!(.*)\$$/;
  }
  search(text2) {
    const isMatch = !text2.endsWith(this.pattern);
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices: [0, text2.length - 1]
    };
  }
}
class FuzzyMatch extends BaseMatch {
  static {
    __name(this, "FuzzyMatch");
  }
  constructor(pattern, {
    location: location2 = Config.location,
    threshold = Config.threshold,
    distance: distance2 = Config.distance,
    includeMatches = Config.includeMatches,
    findAllMatches = Config.findAllMatches,
    minMatchCharLength = Config.minMatchCharLength,
    isCaseSensitive = Config.isCaseSensitive,
    ignoreLocation = Config.ignoreLocation
  } = {}) {
    super(pattern);
    this._bitapSearch = new BitapSearch(pattern, {
      location: location2,
      threshold,
      distance: distance2,
      includeMatches,
      findAllMatches,
      minMatchCharLength,
      isCaseSensitive,
      ignoreLocation
    });
  }
  static get type() {
    return "fuzzy";
  }
  static get multiRegex() {
    return /^"(.*)"$/;
  }
  static get singleRegex() {
    return /^(.*)$/;
  }
  search(text2) {
    return this._bitapSearch.searchIn(text2);
  }
}
class IncludeMatch extends BaseMatch {
  static {
    __name(this, "IncludeMatch");
  }
  constructor(pattern) {
    super(pattern);
  }
  static get type() {
    return "include";
  }
  static get multiRegex() {
    return /^'"(.*)"$/;
  }
  static get singleRegex() {
    return /^'(.*)$/;
  }
  search(text2) {
    let location2 = 0;
    let index2;
    const indices = [];
    const patternLen = this.pattern.length;
    while ((index2 = text2.indexOf(this.pattern, location2)) > -1) {
      location2 = index2 + patternLen;
      indices.push([index2, location2 - 1]);
    }
    const isMatch = !!indices.length;
    return {
      isMatch,
      score: isMatch ? 0 : 1,
      indices
    };
  }
}
const searchers = [
  ExactMatch,
  IncludeMatch,
  PrefixExactMatch,
  InversePrefixExactMatch,
  InverseSuffixExactMatch,
  SuffixExactMatch,
  InverseExactMatch,
  FuzzyMatch
];
const searchersLen = searchers.length;
const SPACE_RE = / +(?=(?:[^\"]*\"[^\"]*\")*[^\"]*$)/;
const OR_TOKEN = "|";
function parseQuery(pattern, options5 = {}) {
  return pattern.split(OR_TOKEN).map((item3) => {
    let query = item3.trim().split(SPACE_RE).filter((item4) => item4 && !!item4.trim());
    let results = [];
    for (let i2 = 0, len = query.length; i2 < len; i2 += 1) {
      const queryItem = query[i2];
      let found2 = false;
      let idx = -1;
      while (!found2 && ++idx < searchersLen) {
        const searcher = searchers[idx];
        let token = searcher.isMultiMatch(queryItem);
        if (token) {
          results.push(new searcher(token, options5));
          found2 = true;
        }
      }
      if (found2) {
        continue;
      }
      idx = -1;
      while (++idx < searchersLen) {
        const searcher = searchers[idx];
        let token = searcher.isSingleMatch(queryItem);
        if (token) {
          results.push(new searcher(token, options5));
          break;
        }
      }
    }
    return results;
  });
}
__name(parseQuery, "parseQuery");
const MultiMatchSet = /* @__PURE__ */ new Set([FuzzyMatch.type, IncludeMatch.type]);
class ExtendedSearch {
  static {
    __name(this, "ExtendedSearch");
  }
  constructor(pattern, {
    isCaseSensitive = Config.isCaseSensitive,
    includeMatches = Config.includeMatches,
    minMatchCharLength = Config.minMatchCharLength,
    ignoreLocation = Config.ignoreLocation,
    findAllMatches = Config.findAllMatches,
    location: location2 = Config.location,
    threshold = Config.threshold,
    distance: distance2 = Config.distance
  } = {}) {
    this.query = null;
    this.options = {
      isCaseSensitive,
      includeMatches,
      minMatchCharLength,
      findAllMatches,
      ignoreLocation,
      location: location2,
      threshold,
      distance: distance2
    };
    this.pattern = isCaseSensitive ? pattern : pattern.toLowerCase();
    this.query = parseQuery(this.pattern, this.options);
  }
  static condition(_2, options5) {
    return options5.useExtendedSearch;
  }
  searchIn(text2) {
    const query = this.query;
    if (!query) {
      return {
        isMatch: false,
        score: 1
      };
    }
    const { includeMatches, isCaseSensitive } = this.options;
    text2 = isCaseSensitive ? text2 : text2.toLowerCase();
    let numMatches = 0;
    let allIndices = [];
    let totalScore = 0;
    for (let i2 = 0, qLen = query.length; i2 < qLen; i2 += 1) {
      const searchers2 = query[i2];
      allIndices.length = 0;
      numMatches = 0;
      for (let j2 = 0, pLen = searchers2.length; j2 < pLen; j2 += 1) {
        const searcher = searchers2[j2];
        const { isMatch, indices, score } = searcher.search(text2);
        if (isMatch) {
          numMatches += 1;
          totalScore += score;
          if (includeMatches) {
            const type = searcher.constructor.type;
            if (MultiMatchSet.has(type)) {
              allIndices = [...allIndices, ...indices];
            } else {
              allIndices.push(indices);
            }
          }
        } else {
          totalScore = 0;
          numMatches = 0;
          allIndices.length = 0;
          break;
        }
      }
      if (numMatches) {
        let result = {
          isMatch: true,
          score: totalScore / numMatches
        };
        if (includeMatches) {
          result.indices = allIndices;
        }
        return result;
      }
    }
    return {
      isMatch: false,
      score: 1
    };
  }
}
const registeredSearchers = [];
function register$1(...args) {
  registeredSearchers.push(...args);
}
__name(register$1, "register$1");
function createSearcher(pattern, options5) {
  for (let i2 = 0, len = registeredSearchers.length; i2 < len; i2 += 1) {
    let searcherClass = registeredSearchers[i2];
    if (searcherClass.condition(pattern, options5)) {
      return new searcherClass(pattern, options5);
    }
  }
  return new BitapSearch(pattern, options5);
}
__name(createSearcher, "createSearcher");
const LogicalOperator = {
  AND: "$and",
  OR: "$or"
};
const KeyType = {
  PATH: "$path",
  PATTERN: "$val"
};
const isExpression = /* @__PURE__ */ __name((query) => !!(query[LogicalOperator.AND] || query[LogicalOperator.OR]), "isExpression");
const isPath = /* @__PURE__ */ __name((query) => !!query[KeyType.PATH], "isPath");
const isLeaf = /* @__PURE__ */ __name((query) => !isArray(query) && isObject$1(query) && !isExpression(query), "isLeaf");
const convertToExplicit = /* @__PURE__ */ __name((query) => ({
  [LogicalOperator.AND]: Object.keys(query).map((key) => ({
    [key]: query[key]
  }))
}), "convertToExplicit");
function parse(query, options5, { auto = true } = {}) {
  const next2 = /* @__PURE__ */ __name((query2) => {
    let keys2 = Object.keys(query2);
    const isQueryPath = isPath(query2);
    if (!isQueryPath && keys2.length > 1 && !isExpression(query2)) {
      return next2(convertToExplicit(query2));
    }
    if (isLeaf(query2)) {
      const key = isQueryPath ? query2[KeyType.PATH] : keys2[0];
      const pattern = isQueryPath ? query2[KeyType.PATTERN] : query2[key];
      if (!isString$3(pattern)) {
        throw new Error(LOGICAL_SEARCH_INVALID_QUERY_FOR_KEY(key));
      }
      const obj = {
        keyId: createKeyId(key),
        pattern
      };
      if (auto) {
        obj.searcher = createSearcher(pattern, options5);
      }
      return obj;
    }
    let node3 = {
      children: [],
      operator: keys2[0]
    };
    keys2.forEach((key) => {
      const value3 = query2[key];
      if (isArray(value3)) {
        value3.forEach((item3) => {
          node3.children.push(next2(item3));
        });
      }
    });
    return node3;
  }, "next");
  if (!isExpression(query)) {
    query = convertToExplicit(query);
  }
  return next2(query);
}
__name(parse, "parse");
function computeScore(results, { ignoreFieldNorm = Config.ignoreFieldNorm }) {
  results.forEach((result) => {
    let totalScore = 1;
    result.matches.forEach(({ key, norm: norm2, score }) => {
      const weight = key ? key.weight : null;
      totalScore *= Math.pow(
        score === 0 && weight ? Number.EPSILON : score,
        (weight || 1) * (ignoreFieldNorm ? 1 : norm2)
      );
    });
    result.score = totalScore;
  });
}
__name(computeScore, "computeScore");
function transformMatches(result, data30) {
  const matches2 = result.matches;
  data30.matches = [];
  if (!isDefined(matches2)) {
    return;
  }
  matches2.forEach((match2) => {
    if (!isDefined(match2.indices) || !match2.indices.length) {
      return;
    }
    const { indices, value: value3 } = match2;
    let obj = {
      indices,
      value: value3
    };
    if (match2.key) {
      obj.key = match2.key.src;
    }
    if (match2.idx > -1) {
      obj.refIndex = match2.idx;
    }
    data30.matches.push(obj);
  });
}
__name(transformMatches, "transformMatches");
function transformScore(result, data30) {
  data30.score = result.score;
}
__name(transformScore, "transformScore");
function format$1(results, docs, {
  includeMatches = Config.includeMatches,
  includeScore = Config.includeScore
} = {}) {
  const transformers = [];
  if (includeMatches) transformers.push(transformMatches);
  if (includeScore) transformers.push(transformScore);
  return results.map((result) => {
    const { idx } = result;
    const data30 = {
      item: docs[idx],
      refIndex: idx
    };
    if (transformers.length) {
      transformers.forEach((transformer) => {
        transformer(result, data30);
      });
    }
    return data30;
  });
}
__name(format$1, "format$1");
class Fuse {
  static {
    __name(this, "Fuse");
  }
  constructor(docs, options5 = {}, index2) {
    this.options = { ...Config, ...options5 };
    if (this.options.useExtendedSearch && false) {
      throw new Error(EXTENDED_SEARCH_UNAVAILABLE);
    }
    this._keyStore = new KeyStore(this.options.keys);
    this.setCollection(docs, index2);
  }
  setCollection(docs, index2) {
    this._docs = docs;
    if (index2 && !(index2 instanceof FuseIndex)) {
      throw new Error(INCORRECT_INDEX_TYPE);
    }
    this._myIndex = index2 || createIndex(this.options.keys, this._docs, {
      getFn: this.options.getFn,
      fieldNormWeight: this.options.fieldNormWeight
    });
  }
  add(doc2) {
    if (!isDefined(doc2)) {
      return;
    }
    this._docs.push(doc2);
    this._myIndex.add(doc2);
  }
  remove(predicate = () => false) {
    const results = [];
    for (let i2 = 0, len = this._docs.length; i2 < len; i2 += 1) {
      const doc2 = this._docs[i2];
      if (predicate(doc2, i2)) {
        this.removeAt(i2);
        i2 -= 1;
        len -= 1;
        results.push(doc2);
      }
    }
    return results;
  }
  removeAt(idx) {
    this._docs.splice(idx, 1);
    this._myIndex.removeAt(idx);
  }
  getIndex() {
    return this._myIndex;
  }
  search(query, { limit = -1 } = {}) {
    const {
      includeMatches,
      includeScore,
      shouldSort,
      sortFn,
      ignoreFieldNorm
    } = this.options;
    let results = isString$3(query) ? isString$3(this._docs[0]) ? this._searchStringList(query) : this._searchObjectList(query) : this._searchLogical(query);
    computeScore(results, { ignoreFieldNorm });
    if (shouldSort) {
      results.sort(sortFn);
    }
    if (isNumber$2(limit) && limit > -1) {
      results = results.slice(0, limit);
    }
    return format$1(results, this._docs, {
      includeMatches,
      includeScore
    });
  }
  _searchStringList(query) {
    const searcher = createSearcher(query, this.options);
    const { records } = this._myIndex;
    const results = [];
    records.forEach(({ v: text2, i: idx, n: norm2 }) => {
      if (!isDefined(text2)) {
        return;
      }
      const { isMatch, score, indices } = searcher.searchIn(text2);
      if (isMatch) {
        results.push({
          item: text2,
          idx,
          matches: [{ score, value: text2, norm: norm2, indices }]
        });
      }
    });
    return results;
  }
  _searchLogical(query) {
    const expression = parse(query, this.options);
    const evaluate = /* @__PURE__ */ __name((node3, item3, idx) => {
      if (!node3.children) {
        const { keyId, searcher } = node3;
        const matches2 = this._findMatches({
          key: this._keyStore.get(keyId),
          value: this._myIndex.getValueForItemAtKeyId(item3, keyId),
          searcher
        });
        if (matches2 && matches2.length) {
          return [
            {
              idx,
              item: item3,
              matches: matches2
            }
          ];
        }
        return [];
      }
      const res = [];
      for (let i2 = 0, len = node3.children.length; i2 < len; i2 += 1) {
        const child = node3.children[i2];
        const result = evaluate(child, item3, idx);
        if (result.length) {
          res.push(...result);
        } else if (node3.operator === LogicalOperator.AND) {
          return [];
        }
      }
      return res;
    }, "evaluate");
    const records = this._myIndex.records;
    const resultMap = {};
    const results = [];
    records.forEach(({ $: item3, i: idx }) => {
      if (isDefined(item3)) {
        let expResults = evaluate(expression, item3, idx);
        if (expResults.length) {
          if (!resultMap[idx]) {
            resultMap[idx] = { idx, item: item3, matches: [] };
            results.push(resultMap[idx]);
          }
          expResults.forEach(({ matches: matches2 }) => {
            resultMap[idx].matches.push(...matches2);
          });
        }
      }
    });
    return results;
  }
  _searchObjectList(query) {
    const searcher = createSearcher(query, this.options);
    const { keys: keys2, records } = this._myIndex;
    const results = [];
    records.forEach(({ $: item3, i: idx }) => {
      if (!isDefined(item3)) {
        return;
      }
      let matches2 = [];
      keys2.forEach((key, keyIndex) => {
        matches2.push(
          ...this._findMatches({
            key,
            value: item3[keyIndex],
            searcher
          })
        );
      });
      if (matches2.length) {
        results.push({
          idx,
          item: item3,
          matches: matches2
        });
      }
    });
    return results;
  }
  _findMatches({ key, value: value3, searcher }) {
    if (!isDefined(value3)) {
      return [];
    }
    let matches2 = [];
    if (isArray(value3)) {
      value3.forEach(({ v: text2, i: idx, n: norm2 }) => {
        if (!isDefined(text2)) {
          return;
        }
        const { isMatch, score, indices } = searcher.searchIn(text2);
        if (isMatch) {
          matches2.push({
            score,
            key,
            value: text2,
            idx,
            norm: norm2,
            indices
          });
        }
      });
    } else {
      const { v: text2, n: norm2 } = value3;
      const { isMatch, score, indices } = searcher.searchIn(text2);
      if (isMatch) {
        matches2.push({ score, key, value: text2, norm: norm2, indices });
      }
    }
    return matches2;
  }
}
Fuse.version = "7.0.0";
Fuse.createIndex = createIndex;
Fuse.parseIndex = parseIndex;
Fuse.config = Config;
{
  Fuse.parseQuery = parse;
}
{
  register$1(ExtendedSearch);
}
class FuseSearch {
  static {
    __name(this, "FuseSearch");
  }
  fuse;
  keys;
  data;
  advancedScoring;
  constructor(data30, options5, createIndex2 = true, advancedScoring = false) {
    this.data = data30;
    this.keys = options5.keys ?? [];
    this.advancedScoring = advancedScoring;
    const index2 = createIndex2 && options5?.keys ? Fuse.createIndex(options5.keys, data30) : void 0;
    this.fuse = new Fuse(data30, options5, index2);
  }
  search(query, options5) {
    const fuseResult = !query ? this.data.map((x2) => ({ item: x2, score: 0 })) : this.fuse.search(query, options5);
    if (!this.advancedScoring) {
      return fuseResult.map((x2) => x2.item);
    }
    const aux = fuseResult.map((x2) => ({
      item: x2.item,
      // @ts-expect-error fixme ts strict error
      scores: this.calcAuxScores(query.toLocaleLowerCase(), x2.item, x2.score)
    })).sort((a2, b2) => this.compareAux(a2.scores, b2.scores));
    return aux.map((x2) => x2.item);
  }
  calcAuxScores(query, entry, score) {
    let values = [];
    if (!this.keys.length) values = [entry];
    else values = this.keys.map((x2) => entry[x2]);
    const scores = values.map((x2) => this.calcAuxSingle(query, x2, score));
    let result = scores.sort(this.compareAux)[0];
    const deprecated = values.some(
      (x2) => x2.toLocaleLowerCase().includes("deprecated")
    );
    result[0] += deprecated && result[0] != 0 ? 5 : 0;
    if (entry["postProcessSearchScores"]) {
      result = entry["postProcessSearchScores"](result);
    }
    return result;
  }
  calcAuxSingle(query, item3, score) {
    const itemWords = item3.split(/ |\b|(?<=[a-z])(?=[A-Z])|(?=[A-Z][a-z])/).map((x2) => x2.toLocaleLowerCase());
    const queryParts = query.split(" ");
    item3 = item3.toLocaleLowerCase();
    let main = 9;
    let aux1 = 0;
    let aux2 = 0;
    if (item3 == query) {
      main = 0;
    } else if (item3.startsWith(query)) {
      main = 1;
      aux2 = item3.length;
    } else if (itemWords.includes(query)) {
      main = 2;
      aux1 = item3.indexOf(query) + item3.length * 0.5;
      aux2 = item3.length;
    } else if (item3.includes(query)) {
      main = 3;
      aux1 = item3.indexOf(query) + item3.length * 0.5;
      aux2 = item3.length;
    } else if (queryParts.every((x2) => itemWords.includes(x2))) {
      const indexes = queryParts.map((x2) => itemWords.indexOf(x2));
      const min = Math.min(...indexes);
      const max = Math.max(...indexes);
      main = 4;
      aux1 = max - min + max * 0.5 + item3.length * 0.5;
      aux2 = item3.length;
    } else if (queryParts.every((x2) => item3.includes(x2))) {
      const min = Math.min(...queryParts.map((x2) => item3.indexOf(x2)));
      const max = Math.max(...queryParts.map((x2) => item3.indexOf(x2) + x2.length));
      main = 5;
      aux1 = max - min + max * 0.5 + item3.length * 0.5;
      aux2 = item3.length;
    }
    const lengthPenalty = 0.2 * (1 - Math.min(item3.length, query.length) / Math.max(item3.length, query.length));
    return [main, aux1, aux2, score + lengthPenalty];
  }
  compareAux(a2, b2) {
    for (let i2 = 0; i2 < Math.min(a2.length, b2.length); i2++) {
      if (a2[i2] !== b2[i2]) {
        return a2[i2] - b2[i2];
      }
    }
    return a2.length - b2.length;
  }
}
class NodeFilter {
  static {
    __name(this, "NodeFilter");
  }
  constructor(id4, name2, invokeSequence, longInvokeSequence, nodeOptions, nodeDefs, options5) {
    this.id = id4;
    this.name = name2;
    this.invokeSequence = invokeSequence;
    this.longInvokeSequence = longInvokeSequence;
    this.nodeOptions = nodeOptions;
    this.fuseSearch = new FuseSearch(this.getAllNodeOptions(nodeDefs), options5);
  }
  fuseSearch;
  getNodeOptions(node3) {
    return this.nodeOptions instanceof Function ? this.nodeOptions(node3) : this.nodeOptions;
  }
  getAllNodeOptions(nodeDefs) {
    return [
      ...new Set(
        // @ts-expect-error fixme ts strict error
        nodeDefs.reduce((acc, nodeDef) => {
          return [...acc, ...this.getNodeOptions(nodeDef)];
        }, [])
      )
    ];
  }
  matches(node3, value3, extraOptions) {
    const matchWildcards = extraOptions?.matchWildcards !== false;
    if (matchWildcards && value3 === "*") {
      return true;
    }
    const options5 = this.getNodeOptions(node3);
    return options5.includes(value3) || matchWildcards && _.some(options5, (option5) => option5 === "*");
  }
}
class NodeSearchService {
  static {
    __name(this, "NodeSearchService");
  }
  nodeFuseSearch;
  nodeFilters;
  constructor(data30) {
    this.nodeFuseSearch = new FuseSearch(
      data30,
      {
        keys: ["name", "display_name"],
        includeScore: true,
        threshold: 0.3,
        shouldSort: false,
        useExtendedSearch: true
      },
      true,
      true
    );
    const filterSearchOptions = {
      includeScore: true,
      threshold: 0.3,
      shouldSort: true
    };
    const inputTypeFilter = new NodeFilter(
      /* id */
      "input",
      /* name */
      "Input Type",
      /* invokeSequence */
      "i",
      /* longInvokeSequence */
      "input",
      (node3) => Object.values(node3.inputs).map((input) => input.type),
      data30,
      filterSearchOptions
    );
    const outputTypeFilter = new NodeFilter(
      /* id */
      "output",
      /* name */
      "Output Type",
      /* invokeSequence */
      "o",
      /* longInvokeSequence */
      "output",
      (node3) => node3.outputs.map((output) => output.type),
      data30,
      filterSearchOptions
    );
    const nodeCategoryFilter = new NodeFilter(
      /* id */
      "category",
      /* name */
      "Category",
      /* invokeSequence */
      "c",
      /* longInvokeSequence */
      "category",
      (node3) => [node3.category],
      data30,
      filterSearchOptions
    );
    const nodeSourceFilter = new NodeFilter(
      /* id */
      "source",
      /* name */
      "Source",
      /* invokeSequence */
      "s",
      /* longInvokeSequence */
      "source",
      (node3) => [node3.nodeSource.displayText],
      data30,
      filterSearchOptions
    );
    this.nodeFilters = [
      inputTypeFilter,
      outputTypeFilter,
      nodeCategoryFilter,
      nodeSourceFilter
    ];
  }
  endsWithFilterStartSequence(query) {
    return query.endsWith(":");
  }
  searchNode(query, filters = [], options5, extraOptions) {
    const matchedNodes = this.nodeFuseSearch.search(query);
    const results = matchedNodes.filter((node3) => {
      return _.every(filters, (filterAndValue) => {
        const [filter4, value3] = filterAndValue;
        return filter4.matches(node3, value3, extraOptions);
      });
    });
    return options5?.limit ? results.slice(0, options5.limit) : results;
  }
  getFilterById(id4) {
    return this.nodeFilters.find((filter4) => filter4.id === id4);
  }
}
var NodeSourceType = /* @__PURE__ */ ((NodeSourceType2) => {
  NodeSourceType2["Core"] = "core";
  NodeSourceType2["CustomNodes"] = "custom_nodes";
  NodeSourceType2["Unknown"] = "unknown";
  return NodeSourceType2;
})(NodeSourceType || {});
const UNKNOWN_NODE_SOURCE = {
  type: "unknown",
  className: "comfy-unknown",
  displayText: "Unknown",
  badgeText: "?"
};
const shortenNodeName = /* @__PURE__ */ __name((name2) => {
  return name2.replace(/^(ComfyUI-|ComfyUI_|Comfy-|Comfy_)/, "").replace(/(-ComfyUI|_ComfyUI|-Comfy|_Comfy)$/, "");
}, "shortenNodeName");
const getNodeSource = /* @__PURE__ */ __name((python_module) => {
  if (!python_module) {
    return UNKNOWN_NODE_SOURCE;
  }
  const modules = python_module.split(".");
  if (["nodes", "comfy_extras"].includes(modules[0])) {
    return {
      type: "core",
      className: "comfy-core",
      displayText: "Comfy Core",
      badgeText: "🦊"
    };
  } else if (modules[0] === "custom_nodes") {
    const moduleName = modules[1];
    const customNodeName = moduleName.split("@")[0];
    const displayName = shortenNodeName(customNodeName);
    return {
      type: "custom_nodes",
      className: "comfy-custom-nodes",
      displayText: displayName,
      badgeText: displayName
    };
  } else {
    return UNKNOWN_NODE_SOURCE;
  }
}, "getNodeSource");
var NodeBadgeMode = /* @__PURE__ */ ((NodeBadgeMode2) => {
  NodeBadgeMode2["None"] = "None";
  NodeBadgeMode2["ShowAll"] = "Show all";
  NodeBadgeMode2["HideBuiltIn"] = "Hide built-in";
  return NodeBadgeMode2;
})(NodeBadgeMode || {});
class ComfyNodeDefImpl {
  static {
    __name(this, "ComfyNodeDefImpl");
  }
  // ComfyNodeDef fields (V1)
  name;
  display_name;
  /**
   * Category is not marked as readonly as the bookmark system
   * needs to write to it to assign a node to a custom folder.
   */
  category;
  python_module;
  description;
  deprecated;
  experimental;
  output_node;
  /**
   * @deprecated Use `inputs` instead
   */
  input;
  /**
   * @deprecated Use `outputs` instead
   */
  output;
  /**
   * @deprecated Use `outputs[n].is_list` instead
   */
  output_is_list;
  /**
   * @deprecated Use `outputs[n].name` instead
   */
  output_name;
  /**
   * @deprecated Use `outputs[n].tooltip` instead
   */
  output_tooltips;
  // V2 fields
  inputs;
  outputs;
  hidden;
  // ComfyNodeDefImpl fields
  nodeSource;
  constructor(obj) {
    Object.assign(this, obj);
    this.name = obj.name;
    this.display_name = obj.display_name;
    this.category = obj.category;
    this.python_module = obj.python_module;
    this.description = obj.description;
    this.deprecated = obj.deprecated ?? obj.category === "";
    this.experimental = obj.experimental ?? obj.category.startsWith("_for_testing");
    this.output_node = obj.output_node;
    this.input = obj.input ?? {};
    this.output = obj.output ?? [];
    this.output_is_list = obj.output_is_list;
    this.output_name = obj.output_name;
    this.output_tooltips = obj.output_tooltips;
    const defV2 = transformNodeDefV1ToV2(obj);
    this.inputs = defV2.inputs;
    this.outputs = defV2.outputs;
    this.hidden = defV2.hidden;
    this.nodeSource = getNodeSource(obj.python_module);
  }
  get nodePath() {
    return (this.category ? this.category + "/" : "") + this.name;
  }
  get isDummyFolder() {
    return this.name === "";
  }
  postProcessSearchScores(scores) {
    const nodeFrequencyStore = useNodeFrequencyStore();
    const nodeFrequency = nodeFrequencyStore.getNodeFrequencyByName(this.name);
    return [scores[0], -nodeFrequency, ...scores.slice(1)];
  }
  get isCoreNode() {
    return this.nodeSource.type === NodeSourceType.Core;
  }
  get nodeLifeCycleBadgeText() {
    if (this.deprecated) return "[DEPR]";
    if (this.experimental) return "[BETA]";
    return "";
  }
}
const SYSTEM_NODE_DEFS = {
  PrimitiveNode: {
    name: "PrimitiveNode",
    display_name: "Primitive",
    category: "utils",
    input: { required: {}, optional: {} },
    output: ["*"],
    output_name: ["connect to widget input"],
    output_is_list: [false],
    output_node: false,
    python_module: "nodes",
    description: "Primitive values like numbers, strings, and booleans."
  },
  Reroute: {
    name: "Reroute",
    display_name: "Reroute",
    category: "utils",
    input: { required: { "": ["*", {}] }, optional: {} },
    output: ["*"],
    output_name: [""],
    output_is_list: [false],
    output_node: false,
    python_module: "nodes",
    description: "Reroute the connection to another node."
  },
  Note: {
    name: "Note",
    display_name: "Note",
    category: "utils",
    input: { required: {}, optional: {} },
    output: [],
    output_name: [],
    output_is_list: [],
    output_node: false,
    python_module: "nodes",
    description: "Node that add notes to your project"
  },
  MarkdownNote: {
    name: "MarkdownNote",
    display_name: "Markdown Note",
    category: "utils",
    input: { required: {}, optional: {} },
    output: [],
    output_name: [],
    output_is_list: [],
    output_node: false,
    python_module: "nodes",
    description: "Node that add notes to your project. Reformats text as markdown."
  }
};
function buildNodeDefTree(nodeDefs) {
  return buildTree$1(
    nodeDefs,
    (nodeDef) => nodeDef.nodePath.split("/")
  );
}
__name(buildNodeDefTree, "buildNodeDefTree");
function createDummyFolderNodeDef(folderPath) {
  return new ComfyNodeDefImpl({
    name: "",
    display_name: "",
    category: folderPath.endsWith("/") ? folderPath.slice(0, -1) : folderPath,
    python_module: "nodes",
    description: "Dummy Folder Node (User should never see this string)",
    input: {},
    output: [],
    output_name: [],
    output_is_list: [],
    output_node: false
  });
}
__name(createDummyFolderNodeDef, "createDummyFolderNodeDef");
const useNodeDefStore = /* @__PURE__ */ defineStore("nodeDef", () => {
  const nodeDefsByName = ref({});
  const nodeDefsByDisplayName = ref({});
  const showDeprecated = ref(false);
  const showExperimental = ref(false);
  const nodeDefs = computed(() => Object.values(nodeDefsByName.value));
  const nodeDataTypes = computed(() => {
    const types = /* @__PURE__ */ new Set();
    for (const nodeDef of nodeDefs.value) {
      for (const input of Object.values(nodeDef.inputs)) {
        types.add(input.type);
      }
      for (const output of nodeDef.outputs) {
        types.add(output.type);
      }
    }
    return types;
  });
  const visibleNodeDefs = computed(
    () => nodeDefs.value.filter(
      (nodeDef) => (showDeprecated.value || !nodeDef.deprecated) && (showExperimental.value || !nodeDef.experimental)
    )
  );
  const nodeSearchService = computed(
    () => new NodeSearchService(visibleNodeDefs.value)
  );
  const nodeTree = computed(() => buildNodeDefTree(visibleNodeDefs.value));
  function updateNodeDefs(nodeDefs2) {
    const newNodeDefsByName = {};
    const newNodeDefsByDisplayName = {};
    for (const nodeDef of nodeDefs2) {
      const nodeDefImpl = nodeDef instanceof ComfyNodeDefImpl ? nodeDef : new ComfyNodeDefImpl(nodeDef);
      newNodeDefsByName[nodeDef.name] = nodeDefImpl;
      newNodeDefsByDisplayName[nodeDef.display_name] = nodeDefImpl;
    }
    nodeDefsByName.value = newNodeDefsByName;
    nodeDefsByDisplayName.value = newNodeDefsByDisplayName;
  }
  __name(updateNodeDefs, "updateNodeDefs");
  function addNodeDef(nodeDef) {
    const nodeDefImpl = new ComfyNodeDefImpl(nodeDef);
    nodeDefsByName.value[nodeDef.name] = nodeDefImpl;
    nodeDefsByDisplayName.value[nodeDef.display_name] = nodeDefImpl;
  }
  __name(addNodeDef, "addNodeDef");
  function fromLGraphNode(node3) {
    return nodeDefsByName.value[node3.constructor?.nodeData?.name] ?? null;
  }
  __name(fromLGraphNode, "fromLGraphNode");
  return {
    nodeDefsByName,
    nodeDefsByDisplayName,
    showDeprecated,
    showExperimental,
    nodeDefs,
    nodeDataTypes,
    visibleNodeDefs,
    nodeSearchService,
    nodeTree,
    updateNodeDefs,
    addNodeDef,
    fromLGraphNode
  };
});
const useNodeFrequencyStore = /* @__PURE__ */ defineStore("nodeFrequency", () => {
  const topNodeDefLimit = ref(64);
  const nodeFrequencyLookup = ref({});
  const nodeNamesByFrequency = computed(
    () => Object.keys(nodeFrequencyLookup.value)
  );
  const isLoaded = ref(false);
  const loadNodeFrequencies = /* @__PURE__ */ __name(async () => {
    if (!isLoaded.value) {
      try {
        const response = await axios.get("assets/sorted-custom-node-map.json");
        nodeFrequencyLookup.value = response.data;
        isLoaded.value = true;
      } catch (error2) {
        console.error("Error loading node frequencies:", error2);
      }
    }
  }, "loadNodeFrequencies");
  const getNodeFrequency = /* @__PURE__ */ __name((nodeDef) => {
    return getNodeFrequencyByName(nodeDef.name);
  }, "getNodeFrequency");
  const getNodeFrequencyByName = /* @__PURE__ */ __name((nodeName) => {
    return nodeFrequencyLookup.value[nodeName] ?? 0;
  }, "getNodeFrequencyByName");
  const nodeDefStore = useNodeDefStore();
  const topNodeDefs = computed(() => {
    return nodeNamesByFrequency.value.map((nodeName) => nodeDefStore.nodeDefsByName[nodeName]).filter((nodeDef) => nodeDef !== void 0).slice(0, topNodeDefLimit.value);
  });
  return {
    nodeNamesByFrequency,
    topNodeDefs,
    isLoaded,
    loadNodeFrequencies,
    getNodeFrequency,
    getNodeFrequencyByName
  };
});
const API_BASE_URL = "https://api.comfy.org";
const registryApiClient = axios.create({
  baseURL: API_BASE_URL,
  headers: {
    "Content-Type": "application/json"
  }
});
const useComfyRegistryService = /* @__PURE__ */ __name(() => {
  const isLoading = ref(false);
  const error2 = ref(null);
  const nodeDefStore = useNodeDefStore();
  const isLocalNodePack = /* @__PURE__ */ __name((nodePackId) => !!nodeDefStore.nodeDefsByName[nodePackId], "isLocalNodePack");
  const isLocalNode = /* @__PURE__ */ __name((nodeName, nodePackId) => {
    if (!nodeDefStore.nodeDefsByName[nodeName]) return false;
    return nodeDefStore.nodeDefsByName[nodeName].python_module.toLowerCase() === nodePackId.toLowerCase();
  }, "isLocalNode");
  const packNodesAvailable = /* @__PURE__ */ __name((node3) => {
    if (node3.id && isLocalNodePack(node3.id)) return true;
    if (node3.latest_version?.comfy_node_extract_status !== "success")
      return false;
    return true;
  }, "packNodesAvailable");
  const handleApiError = /* @__PURE__ */ __name((err, context, routeSpecificErrors) => {
    if (!axios.isAxiosError(err))
      return err instanceof Error ? `${context}: ${err.message}` : `${context}: Unknown error occurred`;
    const axiosError = err;
    if (axiosError.response) {
      const { status, data: data30 } = axiosError.response;
      if (routeSpecificErrors && routeSpecificErrors[status])
        return routeSpecificErrors[status];
      switch (status) {
        case 400:
          return `Bad request: ${data30?.message || "Invalid input"}`;
        case 401:
          return "Unauthorized: Authentication required";
        case 403:
          return `Forbidden: ${data30?.message || "Access denied"}`;
        case 404:
          return `Not found: ${data30?.message || "Resource not found"}`;
        case 409:
          return `Conflict: ${data30?.message || "Resource conflict"}`;
        case 500:
          return `Server error: ${data30?.message || "Internal server error"}`;
        default:
          return `${context}: ${data30?.message || axiosError.message}`;
      }
    }
    return `${context}: ${axiosError.message}`;
  }, "handleApiError");
  const executeApiRequest = /* @__PURE__ */ __name(async (apiCall, errorContext, routeSpecificErrors) => {
    isLoading.value = true;
    error2.value = null;
    try {
      const response = await apiCall();
      return response.data;
    } catch (err) {
      if (isAbortError(err)) return null;
      error2.value = handleApiError(err, errorContext, routeSpecificErrors);
      return null;
    } finally {
      isLoading.value = false;
    }
  }, "executeApiRequest");
  const getNodeDefs = /* @__PURE__ */ __name(async (params, signal) => {
    const { packId, versionId } = params;
    if (!packId || !versionId) return null;
    const endpoint = `/nodes/${packId}/versions/${versionId}/comfy-nodes`;
    const errorContext = "Failed to get node definitions";
    const routeSpecificErrors = {
      403: "This pack has been banned and its definition is not available",
      404: "The requested node, version, or comfy node does not exist"
    };
    return executeApiRequest(
      () => registryApiClient.get(endpoint, {
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "getNodeDefs");
  const getNodeDef = /* @__PURE__ */ __name(async (params, signal) => {
    const { packId, versionId, comfyNodeName } = params;
    if (!comfyNodeName || !packId || !versionId) return null;
    if (isLocalNode(comfyNodeName, packId))
      return nodeDefStore.nodeDefsByName[comfyNodeName];
    const nodeDefs = await getNodeDefs({ packId, versionId }, signal);
    return nodeDefs?.find((nodeDef) => nodeDef.comfy_node_name === comfyNodeName) || null;
  }, "getNodeDef");
  const search3 = /* @__PURE__ */ __name(async (params, signal) => {
    const endpoint = "/nodes/search";
    const errorContext = "Failed to perform search";
    return executeApiRequest(
      () => registryApiClient.get(endpoint, { params, signal }),
      errorContext
    );
  }, "search");
  const getPublisherById = /* @__PURE__ */ __name(async (publisherId, signal) => {
    const endpoint = `/publishers/${publisherId}`;
    const errorContext = "Failed to get publisher";
    const routeSpecificErrors = {
      404: `Publisher not found: The publisher with ID ${publisherId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.get(endpoint, {
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "getPublisherById");
  const listPacksForPublisher = /* @__PURE__ */ __name(async (publisherId, includeBanned, signal) => {
    const params = includeBanned ? { include_banned: true } : void 0;
    const endpoint = `/publishers/${publisherId}/nodes`;
    const errorContext = "Failed to list packs for publisher";
    const routeSpecificErrors = {
      400: "Bad request: Invalid input data",
      404: `Publisher not found: The publisher with ID ${publisherId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.get(endpoint, {
        params,
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "listPacksForPublisher");
  const postPackReview = /* @__PURE__ */ __name(async (packId, star, signal) => {
    const endpoint = `/nodes/${packId}/reviews`;
    const params = { star };
    const errorContext = "Failed to add review";
    const routeSpecificErrors = {
      400: "Bad request: Invalid review",
      404: `Pack not found: Pack with ID ${packId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.post(endpoint, null, {
        params,
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "postPackReview");
  const listAllPacks = /* @__PURE__ */ __name(async (params, signal) => {
    const endpoint = "/nodes";
    const errorContext = "Failed to list packs";
    return executeApiRequest(
      () => registryApiClient.get(endpoint, { params, signal }),
      errorContext
    );
  }, "listAllPacks");
  const getPackVersions = /* @__PURE__ */ __name(async (packId, params, signal) => {
    const endpoint = `/nodes/${packId}/versions`;
    const errorContext = "Failed to get pack versions";
    const routeSpecificErrors = {
      403: "This pack has been banned and its versions are not available",
      404: `Pack not found: Pack with ID ${packId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.get(
        endpoint,
        { params, signal }
      ),
      errorContext,
      routeSpecificErrors
    );
  }, "getPackVersions");
  const getPackByVersion = /* @__PURE__ */ __name(async (packId, versionId, signal) => {
    const endpoint = `/nodes/${packId}/versions/${versionId}`;
    const errorContext = "Failed to get pack version";
    const routeSpecificErrors = {
      403: "This pack has been banned and its versions are not available",
      404: `Pack not found: Pack with ID ${packId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.get(endpoint, {
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "getPackByVersion");
  const getPackById = /* @__PURE__ */ __name(async (packId, signal) => {
    const endpoint = `/nodes/${packId}`;
    const errorContext = "Failed to get pack";
    const routeSpecificErrors = {
      404: `Pack not found: The pack with ID ${packId} does not exist`
    };
    return executeApiRequest(
      () => registryApiClient.get(endpoint, {
        signal
      }),
      errorContext,
      routeSpecificErrors
    );
  }, "getPackById");
  return {
    isLoading,
    error: error2,
    listAllPacks,
    search: search3,
    getPackById,
    getPackVersions,
    getPackByVersion,
    getPublisherById,
    listPacksForPublisher,
    getNodeDef,
    getNodeDefs,
    postPackReview,
    packNodesAvailable
  };
}, "useComfyRegistryService");
const _hoisted_1$11 = { class: "w-64 mt-2" };
const _hoisted_2$P = { class: "pl-3 text-muted text-md font-semibold opacity-70" };
const _hoisted_3$z = {
  key: 0,
  class: "text-center text-muted py-4 flex flex-col items-center"
};
const _hoisted_4$o = {
  key: 1,
  class: "py-2"
};
const _hoisted_5$k = { class: "flex justify-between items-center w-full p-1" };
const _hoisted_6$g = {
  key: 0,
  class: "pi pi-check text-highlight"
};
const _hoisted_7$8 = { class: "flex justify-end gap-2 p-1 px-3" };
const _sfc_main$14 = /* @__PURE__ */ defineComponent({
  __name: "PackVersionSelectorPopover",
  props: {
    nodePack: {}
  },
  emits: ["cancel", "submit"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const { t: t2 } = useI18n();
    const registryService = useComfyRegistryService();
    const managerStore = useComfyManagerStore();
    const isQueueing = ref(false);
    const selectedVersion = ref(SelectedVersion.LATEST);
    onMounted(() => {
      selectedVersion.value = __props.nodePack.publisher?.name === "Unclaimed" ? SelectedVersion.NIGHTLY : __props.nodePack.latest_version?.version ?? SelectedVersion.NIGHTLY;
    });
    const fetchVersions = /* @__PURE__ */ __name(async () => {
      if (!__props.nodePack?.id) return [];
      return await registryService.getPackVersions(__props.nodePack.id) || [];
    }, "fetchVersions");
    const {
      isLoading: isLoadingVersions,
      state: versions,
      execute: startFetchVersions
    } = useAsyncState(fetchVersions, []);
    const specialOptions = computed(() => {
      const options5 = [
        {
          value: SelectedVersion.LATEST,
          label: t2("manager.latestVersion")
        }
      ];
      if (__props.nodePack.repository?.length) {
        options5.push({
          value: SelectedVersion.NIGHTLY,
          label: t2("manager.nightlyVersion")
        });
      }
      return options5;
    });
    const versionOptions = computed(
      () => versions.value.map((version2) => ({
        value: version2.version,
        label: version2.version
      }))
    );
    const allVersionOptions = computed(() => [
      ...specialOptions.value,
      ...versionOptions.value
    ]);
    whenever(
      () => __props.nodePack.id,
      () => startFetchVersions(),
      { deep: true }
    );
    const handleSubmit = /* @__PURE__ */ __name(async () => {
      isQueueing.value = true;
      await managerStore.installPack.call({
        id: __props.nodePack.id,
        repository: __props.nodePack.repository ?? "",
        channel: ManagerChannel.DEFAULT,
        mode: ManagerDatabaseSource.CACHE,
        version: selectedVersion.value,
        selected_version: selectedVersion.value
      });
      isQueueing.value = false;
      emit2("submit");
    }, "handleSubmit");
    onUnmounted(() => {
      managerStore.installPack.clear();
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$11, [
        createBaseVNode("span", _hoisted_2$P, toDisplayString$1(_ctx.$t("manager.selectVersion")), 1),
        unref(isLoadingVersions) || isQueueing.value ? (openBlock(), createElementBlock("div", _hoisted_3$z, [
          createVNode(unref(script$19), { class: "w-8 h-8 mb-2" }),
          createTextVNode(" " + toDisplayString$1(_ctx.$t("manager.loadingVersions")), 1)
        ])) : allVersionOptions.value.length === 0 ? (openBlock(), createElementBlock("div", _hoisted_4$o, [
          createVNode(NoResultsPlaceholder, {
            title: _ctx.$t("g.noResultsFound"),
            message: _ctx.$t("manager.tryAgainLater"),
            icon: "pi pi-exclamation-circle",
            class: "p-0"
          }, null, 8, ["title", "message"])
        ])) : (openBlock(), createBlock(unref(script$G), {
          key: 2,
          modelValue: selectedVersion.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedVersion.value = $event),
          "option-label": "label",
          "option-value": "value",
          options: allVersionOptions.value,
          "highlight-on-select": false,
          class: "my-3 w-full max-h-[50vh] border-none shadow-none"
        }, {
          option: withCtx((slotProps) => [
            createBaseVNode("div", _hoisted_5$k, [
              createBaseVNode("span", null, toDisplayString$1(slotProps.option.label), 1),
              selectedVersion.value === slotProps.option.value ? (openBlock(), createElementBlock("i", _hoisted_6$g)) : createCommentVNode("", true)
            ])
          ]),
          _: 1
        }, 8, ["modelValue", "options"])),
        createVNode(_sfc_main$18, { class: "my-2" }),
        createBaseVNode("div", _hoisted_7$8, [
          createVNode(unref(script$10), {
            text: "",
            severity: "secondary",
            label: _ctx.$t("g.cancel"),
            disabled: isQueueing.value,
            onClick: _cache[1] || (_cache[1] = ($event) => emit2("cancel"))
          }, null, 8, ["label", "disabled"]),
          createVNode(unref(script$10), {
            severity: "secondary",
            label: _ctx.$t("g.install"),
            class: "py-3 px-4 dark-theme:bg-unset bg-black/80 dark-theme:text-unset text-neutral-100 rounded-lg",
            disabled: isQueueing.value,
            onClick: handleSubmit
          }, null, 8, ["label", "disabled"])
        ])
      ]);
    };
  }
});
const _hoisted_1$10 = { class: "relative" };
const _sfc_main$13 = /* @__PURE__ */ defineComponent({
  __name: "PackVersionBadge",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const popoverRef = ref();
    const managerStore = useComfyManagerStore();
    const installedVersion = computed(() => {
      if (!__props.nodePack.id) return SelectedVersion.NIGHTLY;
      return managerStore.installedPacks[__props.nodePack.id]?.ver ?? __props.nodePack.latest_version?.version ?? SelectedVersion.NIGHTLY;
    });
    const toggleVersionSelector = /* @__PURE__ */ __name((event) => {
      popoverRef.value.toggle(event);
    }, "toggleVersionSelector");
    const closeVersionSelector = /* @__PURE__ */ __name(() => {
      popoverRef.value.hide();
    }, "closeVersionSelector");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$10, [
        createVNode(unref(script$10), {
          label: installedVersion.value,
          severity: "secondary",
          icon: "pi pi-chevron-right",
          "icon-pos": "right",
          class: "rounded-xl text-xs tracking-tighter p-0",
          pt: {
            label: { class: "pl-2 pr-0 py-0.5" },
            icon: { class: "text-xs pl-0 pr-2 py-0.5" }
          },
          "aria-haspopup": "true",
          onClick: toggleVersionSelector
        }, null, 8, ["label"]),
        createVNode(unref(script$l), {
          ref_key: "popoverRef",
          ref: popoverRef,
          pt: {
            content: { class: "px-0" }
          }
        }, {
          default: withCtx(() => [
            createVNode(_sfc_main$14, {
              "installed-version": installedVersion.value,
              "node-pack": _ctx.nodePack,
              onCancel: closeVersionSelector,
              onSubmit: closeVersionSelector
            }, null, 8, ["installed-version", "node-pack"])
          ]),
          _: 1
        }, 512)
      ]);
    };
  }
});
const _hoisted_1$$ = { class: "flex items-center" };
const TOGGLE_DEBOUNCE_MS = 256;
const _sfc_main$12 = /* @__PURE__ */ defineComponent({
  __name: "PackEnableToggle",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const { isPackEnabled, enablePack, disablePack, installedPacks } = useComfyManagerStore();
    const isLoading = ref(false);
    const isEnabled2 = computed(() => isPackEnabled(__props.nodePack.id));
    const version2 = computed(() => {
      const id4 = __props.nodePack.id;
      if (!id4) return SelectedVersion.NIGHTLY;
      return installedPacks[id4]?.ver ?? __props.nodePack.latest_version?.version ?? SelectedVersion.NIGHTLY;
    });
    const handleEnable = /* @__PURE__ */ __name(() => enablePack.call({
      id: __props.nodePack.id,
      version: version2.value,
      selected_version: version2.value,
      repository: __props.nodePack.repository ?? "",
      channel: ManagerChannel.DEFAULT,
      mode: "default"
    }), "handleEnable");
    const handleDisable = /* @__PURE__ */ __name(() => disablePack({
      id: __props.nodePack.id,
      version: version2.value
    }), "handleDisable");
    const handleToggle = /* @__PURE__ */ __name(async (enable) => {
      if (isLoading.value) return;
      isLoading.value = true;
      if (enable) {
        await handleEnable();
      } else {
        handleDisable();
      }
      isLoading.value = false;
    }, "handleToggle");
    const onToggle = lodashExports.debounce(handleToggle, TOGGLE_DEBOUNCE_MS, { trailing: true });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$$, [
        createVNode(unref(script$p), {
          "model-value": isEnabled2.value,
          disabled: isLoading.value,
          "aria-label": "Enable or disable pack",
          "onUpdate:modelValue": unref(onToggle)
        }, null, 8, ["model-value", "disabled", "onUpdate:modelValue"])
      ]);
    };
  }
});
const _hoisted_1$_ = { class: "py-2.5 px-3" };
const _sfc_main$11 = /* @__PURE__ */ defineComponent({
  ...{
    inheritAttrs: false
  },
  __name: "PackActionButton",
  props: {
    label: {},
    loadingMessage: {},
    fullWidth: { type: Boolean, default: false }
  },
  emits: ["action"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const isInstalling = inject(IsInstallingKey, ref(false));
    const onClick5 = /* @__PURE__ */ __name(() => {
      isInstalling.value = true;
      emit2("action");
    }, "onClick");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$10), mergeProps$2({
        outlined: "",
        class: ["m-0 p-0 rounded-lg border-neutral-700", {
          "w-full": _ctx.fullWidth,
          "w-min-content": !_ctx.fullWidth
        }],
        disabled: unref(isInstalling)
      }, _ctx.$attrs, { onClick: onClick5 }), {
        default: withCtx(() => [
          createBaseVNode("span", _hoisted_1$_, [
            unref(isInstalling) ? (openBlock(), createElementBlock(Fragment$1, { key: 0 }, [
              createTextVNode(toDisplayString$1(_ctx.loadingMessage ?? _ctx.$t("g.loading")), 1)
            ], 64)) : (openBlock(), createElementBlock(Fragment$1, { key: 1 }, [
              createTextVNode(toDisplayString$1(_ctx.label), 1)
            ], 64))
          ])
        ]),
        _: 1
      }, 16, ["class", "disabled"]);
    };
  }
});
const _sfc_main$10 = /* @__PURE__ */ defineComponent({
  __name: "PackInstallButton",
  props: {
    nodePacks: {}
  },
  setup(__props) {
    const isInstalling = inject(IsInstallingKey, ref(false));
    const managerStore = useComfyManagerStore();
    const createPayload = /* @__PURE__ */ __name((installItem) => {
      const isUnclaimedPack = installItem.publisher?.name === "Unclaimed";
      const versionToInstall = isUnclaimedPack ? SelectedVersion.NIGHTLY : installItem.latest_version?.version ?? SelectedVersion.LATEST;
      return {
        id: installItem.id,
        repository: installItem.repository ?? "",
        channel: ManagerChannel.DEV,
        mode: ManagerDatabaseSource.CACHE,
        selected_version: versionToInstall,
        version: versionToInstall
      };
    }, "createPayload");
    const installPack = /* @__PURE__ */ __name((item3) => managerStore.installPack.call(createPayload(item3)), "installPack");
    const installAllPacks = /* @__PURE__ */ __name(async () => {
      if (!__props.nodePacks?.length) return;
      isInstalling.value = true;
      const uninstalledPacks = __props.nodePacks.filter(
        (pack) => !managerStore.isPackInstalled(pack.id)
      );
      if (!uninstalledPacks.length) return;
      await Promise.all(uninstalledPacks.map(installPack));
      managerStore.installPack.clear();
    }, "installAllPacks");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(_sfc_main$11, mergeProps$2(_ctx.$attrs, {
        label: _ctx.nodePacks.length > 1 ? _ctx.$t("manager.installSelected") : _ctx.$t("g.install"),
        severity: "secondary",
        "loading-message": _ctx.$t("g.installing"),
        onAction: installAllPacks
      }), null, 16, ["label", "loading-message"]);
    };
  }
});
const _sfc_main$$ = /* @__PURE__ */ defineComponent({
  __name: "PackUninstallButton",
  props: {
    nodePacks: {}
  },
  setup(__props) {
    const managerStore = useComfyManagerStore();
    const createPayload = /* @__PURE__ */ __name((uninstallItem) => {
      return {
        id: uninstallItem.id,
        version: uninstallItem.latest_version?.version
      };
    }, "createPayload");
    const uninstallPack = /* @__PURE__ */ __name((item3) => managerStore.uninstallPack(createPayload(item3)), "uninstallPack");
    const uninstallItems = /* @__PURE__ */ __name(async () => {
      if (!__props.nodePacks?.length) return;
      await Promise.all(__props.nodePacks.map(uninstallPack));
    }, "uninstallItems");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(_sfc_main$11, mergeProps$2(_ctx.$attrs, {
        label: _ctx.nodePacks.length > 1 ? _ctx.$t("manager.uninstallSelected") : _ctx.$t("manager.uninstall"),
        severity: "danger",
        "loading-message": _ctx.$t("manager.uninstalling"),
        onAction: uninstallItems
      }), null, 16, ["label", "loading-message"]);
    };
  }
});
const _hoisted_1$Z = ["src", "alt"];
const DEFAULT_ICON = "/assets/images/fallback-gradient-avatar.svg";
const _sfc_main$_ = /* @__PURE__ */ defineComponent({
  __name: "PackIcon",
  props: {
    nodePack: {},
    width: { default: "4.5rem" },
    height: { default: "4.5rem" }
  },
  setup(__props) {
    const isImageError = ref(false);
    const shouldShowFallback = computed(
      () => !__props.nodePack.icon || __props.nodePack.icon.trim() === "" || isImageError.value
    );
    const imgSrc = computed(
      () => shouldShowFallback.value ? DEFAULT_ICON : __props.nodePack.icon
    );
    const convertToCssValue = /* @__PURE__ */ __name((value3) => typeof value3 === "number" ? `${value3}rem` : value3, "convertToCssValue");
    const cssWidth = computed(() => convertToCssValue(__props.width));
    const cssHeight = computed(() => convertToCssValue(__props.height));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("img", {
        src: isImageError.value ? DEFAULT_ICON : imgSrc.value,
        alt: _ctx.nodePack.name + " icon",
        class: "object-contain rounded-lg max-h-72 max-w-72",
        style: normalizeStyle({ width: cssWidth.value, height: cssHeight.value }),
        onError: _cache[0] || (_cache[0] = ($event) => isImageError.value = true)
      }, null, 44, _hoisted_1$Z);
    };
  }
});
const _hoisted_1$Y = {
  key: 0,
  class: "flex flex-col items-center mb-6"
};
const _hoisted_2$O = {
  class: "text-2xl font-bold text-center mt-4 mb-2",
  style: { "word-break": "break-all" }
};
const _hoisted_3$y = { class: "mt-2 mb-4 w-full max-w-xs flex justify-center" };
const _hoisted_4$n = {
  key: 1,
  class: "flex flex-col items-center mb-6"
};
const _sfc_main$Z = /* @__PURE__ */ defineComponent({
  __name: "InfoPanelHeader",
  props: {
    nodePacks: {}
  },
  setup(__props) {
    const managerStore = useComfyManagerStore();
    const isAllInstalled = computed(
      () => __props.nodePacks.every((nodePack) => managerStore.isPackInstalled(nodePack.id))
    );
    return (_ctx, _cache) => {
      return _ctx.nodePacks?.length ? (openBlock(), createElementBlock("div", _hoisted_1$Y, [
        renderSlot(_ctx.$slots, "thumbnail", {}, () => [
          createVNode(_sfc_main$_, {
            "node-pack": _ctx.nodePacks[0],
            width: "24",
            height: "24"
          }, null, 8, ["node-pack"])
        ]),
        createBaseVNode("h2", _hoisted_2$O, [
          renderSlot(_ctx.$slots, "title", {}, () => [
            createTextVNode(toDisplayString$1(_ctx.nodePacks[0].name), 1)
          ])
        ]),
        createBaseVNode("div", _hoisted_3$y, [
          renderSlot(_ctx.$slots, "install-button", {}, () => [
            isAllInstalled.value ? (openBlock(), createBlock(_sfc_main$$, mergeProps$2({ key: 0 }, _ctx.$attrs, { "node-packs": _ctx.nodePacks }), null, 16, ["node-packs"])) : (openBlock(), createBlock(_sfc_main$10, mergeProps$2({ key: 1 }, _ctx.$attrs, { "node-packs": _ctx.nodePacks }), null, 16, ["node-packs"]))
          ])
        ])
      ])) : (openBlock(), createElementBlock("div", _hoisted_4$n, [
        createVNode(NoResultsPlaceholder, {
          message: _ctx.$t("manager.status.unknown"),
          title: _ctx.$t("manager.tryAgainLater")
        }, null, 8, ["message", "title"])
      ]));
    };
  }
});
var classes$d = {
  root: /* @__PURE__ */ __name(function root24(_ref) {
    var instance = _ref.instance, props = _ref.props;
    return ["p-tab", {
      "p-tab-active": instance.active,
      "p-disabled": props.disabled
    }];
  }, "root")
};
var TabStyle = BaseStyle$1.extend({
  name: "tab",
  classes: classes$d
});
var script$1$d = {
  name: "BaseTab",
  "extends": script$1b,
  props: {
    value: {
      type: [String, Number],
      "default": void 0
    },
    disabled: {
      type: Boolean,
      "default": false
    },
    as: {
      type: [String, Object],
      "default": "BUTTON"
    },
    asChild: {
      type: Boolean,
      "default": false
    }
  },
  style: TabStyle,
  provide: /* @__PURE__ */ __name(function provide38() {
    return {
      $pcTab: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$k = {
  name: "Tab",
  "extends": script$1$d,
  inheritAttrs: false,
  inject: ["$pcTabs", "$pcTabList"],
  methods: {
    onFocus: /* @__PURE__ */ __name(function onFocus6() {
      this.$pcTabs.selectOnFocus && this.changeActiveValue();
    }, "onFocus"),
    onClick: /* @__PURE__ */ __name(function onClick3() {
      this.changeActiveValue();
    }, "onClick"),
    onKeydown: /* @__PURE__ */ __name(function onKeydown3(event) {
      switch (event.code) {
        case "ArrowRight":
          this.onArrowRightKey(event);
          break;
        case "ArrowLeft":
          this.onArrowLeftKey(event);
          break;
        case "Home":
          this.onHomeKey(event);
          break;
        case "End":
          this.onEndKey(event);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onEnterKey(event);
          break;
      }
    }, "onKeydown"),
    onArrowRightKey: /* @__PURE__ */ __name(function onArrowRightKey(event) {
      var nextTab = this.findNextTab(event.currentTarget);
      nextTab ? this.changeFocusedTab(event, nextTab) : this.onHomeKey(event);
      event.preventDefault();
    }, "onArrowRightKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey3(event) {
      var prevTab = this.findPrevTab(event.currentTarget);
      prevTab ? this.changeFocusedTab(event, prevTab) : this.onEndKey(event);
      event.preventDefault();
    }, "onArrowLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey3(event) {
      var firstTab = this.findFirstTab();
      this.changeFocusedTab(event, firstTab);
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey3(event) {
      var lastTab = this.findLastTab();
      this.changeFocusedTab(event, lastTab);
      event.preventDefault();
    }, "onEndKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey4(event) {
      this.scrollInView(this.findLastTab());
      event.preventDefault();
    }, "onPageDownKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey4(event) {
      this.scrollInView(this.findFirstTab());
      event.preventDefault();
    }, "onPageUpKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey3(event) {
      this.changeActiveValue();
      event.preventDefault();
    }, "onEnterKey"),
    findNextTab: /* @__PURE__ */ __name(function findNextTab(tabElement) {
      var selfCheck = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var element = selfCheck ? tabElement : tabElement.nextElementSibling;
      return element ? getAttribute$1(element, "data-p-disabled") || getAttribute$1(element, "data-pc-section") === "inkbar" ? this.findNextTab(element) : findSingle$1(element, '[data-pc-name="tab"]') : null;
    }, "findNextTab"),
    findPrevTab: /* @__PURE__ */ __name(function findPrevTab(tabElement) {
      var selfCheck = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var element = selfCheck ? tabElement : tabElement.previousElementSibling;
      return element ? getAttribute$1(element, "data-p-disabled") || getAttribute$1(element, "data-pc-section") === "inkbar" ? this.findPrevTab(element) : findSingle$1(element, '[data-pc-name="tab"]') : null;
    }, "findPrevTab"),
    findFirstTab: /* @__PURE__ */ __name(function findFirstTab() {
      return this.findNextTab(this.$pcTabList.$refs.content.firstElementChild, true);
    }, "findFirstTab"),
    findLastTab: /* @__PURE__ */ __name(function findLastTab() {
      return this.findPrevTab(this.$pcTabList.$refs.content.lastElementChild, true);
    }, "findLastTab"),
    changeActiveValue: /* @__PURE__ */ __name(function changeActiveValue() {
      this.$pcTabs.updateValue(this.value);
    }, "changeActiveValue"),
    changeFocusedTab: /* @__PURE__ */ __name(function changeFocusedTab2(event, element) {
      focus$2(element);
      this.scrollInView(element);
    }, "changeFocusedTab"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView6(element) {
      var _element$scrollIntoVi;
      element === null || element === void 0 || (_element$scrollIntoVi = element.scrollIntoView) === null || _element$scrollIntoVi === void 0 || _element$scrollIntoVi.call(element, {
        block: "nearest"
      });
    }, "scrollInView")
  },
  computed: {
    active: /* @__PURE__ */ __name(function active2() {
      var _this$$pcTabs;
      return equals$2((_this$$pcTabs = this.$pcTabs) === null || _this$$pcTabs === void 0 ? void 0 : _this$$pcTabs.d_value, this.value);
    }, "active"),
    id: /* @__PURE__ */ __name(function id3() {
      var _this$$pcTabs2;
      return "".concat((_this$$pcTabs2 = this.$pcTabs) === null || _this$$pcTabs2 === void 0 ? void 0 : _this$$pcTabs2.id, "_tab_").concat(this.value);
    }, "id"),
    ariaControls: /* @__PURE__ */ __name(function ariaControls() {
      var _this$$pcTabs3;
      return "".concat((_this$$pcTabs3 = this.$pcTabs) === null || _this$$pcTabs3 === void 0 ? void 0 : _this$$pcTabs3.id, "_tabpanel_").concat(this.value);
    }, "ariaControls"),
    attrs: /* @__PURE__ */ __name(function attrs6() {
      return mergeProps$2(this.asAttrs, this.a11yAttrs, this.ptmi("root", this.ptParams));
    }, "attrs"),
    asAttrs: /* @__PURE__ */ __name(function asAttrs2() {
      return this.as === "BUTTON" ? {
        type: "button",
        disabled: this.disabled
      } : void 0;
    }, "asAttrs"),
    a11yAttrs: /* @__PURE__ */ __name(function a11yAttrs3() {
      return {
        id: this.id,
        tabindex: this.active ? this.$pcTabs.tabindex : -1,
        role: "tab",
        "aria-selected": this.active,
        "aria-controls": this.ariaControls,
        "data-pc-name": "tab",
        "data-p-disabled": this.disabled,
        "data-p-active": this.active,
        onFocus: this.onFocus,
        onKeydown: this.onKeydown
      };
    }, "a11yAttrs"),
    ptParams: /* @__PURE__ */ __name(function ptParams2() {
      return {
        context: {
          active: this.active
        }
      };
    }, "ptParams")
  },
  directives: {
    ripple: Ripple
  }
};
function render$i(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return !_ctx.asChild ? withDirectives((openBlock(), createBlock(resolveDynamicComponent(_ctx.as), mergeProps$2({
    key: 0,
    "class": _ctx.cx("root"),
    onClick: $options.onClick
  }, $options.attrs), {
    "default": withCtx(function() {
      return [renderSlot(_ctx.$slots, "default")];
    }),
    _: 3
  }, 16, ["class", "onClick"])), [[_directive_ripple]]) : renderSlot(_ctx.$slots, "default", {
    key: 1,
    "class": normalizeClass(_ctx.cx("root")),
    active: $options.active,
    a11yAttrs: $options.a11yAttrs,
    onClick: $options.onClick
  });
}
__name(render$i, "render$i");
script$k.render = render$i;
var classes$c = {
  root: "p-tablist",
  content: /* @__PURE__ */ __name(function content2(_ref) {
    var instance = _ref.instance;
    return ["p-tablist-content", {
      "p-tablist-viewport": instance.$pcTabs.scrollable
    }];
  }, "content"),
  tabList: "p-tablist-tab-list",
  activeBar: "p-tablist-active-bar",
  prevButton: "p-tablist-prev-button p-tablist-nav-button",
  nextButton: "p-tablist-next-button p-tablist-nav-button"
};
var TabListStyle = BaseStyle$1.extend({
  name: "tablist",
  classes: classes$c
});
var script$1$c = {
  name: "BaseTabList",
  "extends": script$1b,
  props: {},
  style: TabListStyle,
  provide: /* @__PURE__ */ __name(function provide39() {
    return {
      $pcTabList: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$j = {
  name: "TabList",
  "extends": script$1$c,
  inheritAttrs: false,
  inject: ["$pcTabs"],
  data: /* @__PURE__ */ __name(function data19() {
    return {
      isPrevButtonEnabled: false,
      isNextButtonEnabled: true
    };
  }, "data"),
  resizeObserver: void 0,
  watch: {
    showNavigators: /* @__PURE__ */ __name(function showNavigators(newValue2) {
      newValue2 ? this.bindResizeObserver() : this.unbindResizeObserver();
    }, "showNavigators"),
    activeValue: {
      flush: "post",
      handler: /* @__PURE__ */ __name(function handler12() {
        this.updateInkBar();
      }, "handler")
    }
  },
  mounted: /* @__PURE__ */ __name(function mounted18() {
    var _this = this;
    this.$nextTick(function() {
      _this.updateInkBar();
    });
    if (this.showNavigators) {
      this.updateButtonState();
      this.bindResizeObserver();
    }
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated11() {
    this.showNavigators && this.updateButtonState();
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount10() {
    this.unbindResizeObserver();
  }, "beforeUnmount"),
  methods: {
    onScroll: /* @__PURE__ */ __name(function onScroll4(event) {
      this.showNavigators && this.updateButtonState();
      event.preventDefault();
    }, "onScroll"),
    onPrevButtonClick: /* @__PURE__ */ __name(function onPrevButtonClick2() {
      var content3 = this.$refs.content;
      var buttonWidths = this.getVisibleButtonWidths();
      var width2 = getWidth$1(content3) - buttonWidths;
      var currentScrollLeft = Math.abs(content3.scrollLeft);
      var scrollStep = width2 * 0.8;
      var targetScrollLeft = currentScrollLeft - scrollStep;
      var scrollLeft = Math.max(targetScrollLeft, 0);
      content3.scrollLeft = isRTL$1(content3) ? -1 * scrollLeft : scrollLeft;
    }, "onPrevButtonClick"),
    onNextButtonClick: /* @__PURE__ */ __name(function onNextButtonClick2() {
      var content3 = this.$refs.content;
      var buttonWidths = this.getVisibleButtonWidths();
      var width2 = getWidth$1(content3) - buttonWidths;
      var currentScrollLeft = Math.abs(content3.scrollLeft);
      var scrollStep = width2 * 0.8;
      var targetScrollLeft = currentScrollLeft + scrollStep;
      var maxScrollLeft = content3.scrollWidth - width2;
      var scrollLeft = Math.min(targetScrollLeft, maxScrollLeft);
      content3.scrollLeft = isRTL$1(content3) ? -1 * scrollLeft : scrollLeft;
    }, "onNextButtonClick"),
    bindResizeObserver: /* @__PURE__ */ __name(function bindResizeObserver() {
      var _this2 = this;
      this.resizeObserver = new ResizeObserver(function() {
        return _this2.updateButtonState();
      });
      this.resizeObserver.observe(this.$refs.list);
    }, "bindResizeObserver"),
    unbindResizeObserver: /* @__PURE__ */ __name(function unbindResizeObserver() {
      var _this$resizeObserver;
      (_this$resizeObserver = this.resizeObserver) === null || _this$resizeObserver === void 0 || _this$resizeObserver.unobserve(this.$refs.list);
      this.resizeObserver = void 0;
    }, "unbindResizeObserver"),
    updateInkBar: /* @__PURE__ */ __name(function updateInkBar2() {
      var _this$$refs = this.$refs, content3 = _this$$refs.content, inkbar = _this$$refs.inkbar, tabs2 = _this$$refs.tabs;
      var activeTab = findSingle$1(content3, '[data-pc-name="tab"][data-p-active="true"]');
      if (this.$pcTabs.isVertical()) {
        inkbar.style.height = getOuterHeight$1(activeTab) + "px";
        inkbar.style.top = getOffset$1(activeTab).top - getOffset$1(tabs2).top + "px";
      } else {
        inkbar.style.width = getOuterWidth$1(activeTab) + "px";
        inkbar.style.left = getOffset$1(activeTab).left - getOffset$1(tabs2).left + "px";
      }
    }, "updateInkBar"),
    updateButtonState: /* @__PURE__ */ __name(function updateButtonState2() {
      var _this$$refs2 = this.$refs, list2 = _this$$refs2.list, content3 = _this$$refs2.content;
      var scrollTop2 = content3.scrollTop, scrollWidth2 = content3.scrollWidth, scrollHeight2 = content3.scrollHeight, offsetWidth = content3.offsetWidth, offsetHeight = content3.offsetHeight;
      var scrollLeft = Math.abs(content3.scrollLeft);
      var _ref = [getWidth$1(content3), getHeight$1(content3)], width2 = _ref[0], height = _ref[1];
      if (this.$pcTabs.isVertical()) {
        this.isPrevButtonEnabled = scrollTop2 !== 0;
        this.isNextButtonEnabled = list2.offsetHeight >= offsetHeight && parseInt(scrollTop2) !== scrollHeight2 - height;
      } else {
        this.isPrevButtonEnabled = scrollLeft !== 0;
        this.isNextButtonEnabled = list2.offsetWidth >= offsetWidth && parseInt(scrollLeft) !== scrollWidth2 - width2;
      }
    }, "updateButtonState"),
    getVisibleButtonWidths: /* @__PURE__ */ __name(function getVisibleButtonWidths2() {
      var _this$$refs3 = this.$refs, prevButton2 = _this$$refs3.prevButton, nextButton2 = _this$$refs3.nextButton;
      var width2 = 0;
      if (this.showNavigators) {
        width2 = ((prevButton2 === null || prevButton2 === void 0 ? void 0 : prevButton2.offsetWidth) || 0) + ((nextButton2 === null || nextButton2 === void 0 ? void 0 : nextButton2.offsetWidth) || 0);
      }
      return width2;
    }, "getVisibleButtonWidths")
  },
  computed: {
    templates: /* @__PURE__ */ __name(function templates() {
      return this.$pcTabs.$slots;
    }, "templates"),
    activeValue: /* @__PURE__ */ __name(function activeValue() {
      return this.$pcTabs.d_value;
    }, "activeValue"),
    showNavigators: /* @__PURE__ */ __name(function showNavigators2() {
      return this.$pcTabs.scrollable && this.$pcTabs.showNavigators;
    }, "showNavigators"),
    prevButtonAriaLabel: /* @__PURE__ */ __name(function prevButtonAriaLabel2() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.previous : void 0;
    }, "prevButtonAriaLabel"),
    nextButtonAriaLabel: /* @__PURE__ */ __name(function nextButtonAriaLabel2() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.next : void 0;
    }, "nextButtonAriaLabel")
  },
  components: {
    ChevronLeftIcon: script$x,
    ChevronRightIcon: script$w
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$X = ["aria-label", "tabindex"];
var _hoisted_2$N = ["aria-orientation"];
var _hoisted_3$x = ["aria-label", "tabindex"];
function render$h(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "list",
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [$options.showNavigators && $data.isPrevButtonEnabled ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 0,
    ref: "prevButton",
    "class": _ctx.cx("prevButton"),
    "aria-label": $options.prevButtonAriaLabel,
    tabindex: $options.$pcTabs.tabindex,
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.onPrevButtonClick && $options.onPrevButtonClick.apply($options, arguments);
    })
  }, _ctx.ptm("prevButton"), {
    "data-pc-group-section": "navigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($options.templates.previcon || "ChevronLeftIcon"), mergeProps$2({
    "aria-hidden": "true"
  }, _ctx.ptm("prevIcon")), null, 16))], 16, _hoisted_1$X)), [[_directive_ripple]]) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    ref: "content",
    "class": _ctx.cx("content"),
    onScroll: _cache[1] || (_cache[1] = function() {
      return $options.onScroll && $options.onScroll.apply($options, arguments);
    })
  }, _ctx.ptm("content")), [createBaseVNode("div", mergeProps$2({
    ref: "tabs",
    "class": _ctx.cx("tabList"),
    role: "tablist",
    "aria-orientation": $options.$pcTabs.orientation || "horizontal"
  }, _ctx.ptm("tabList")), [renderSlot(_ctx.$slots, "default"), createBaseVNode("span", mergeProps$2({
    ref: "inkbar",
    "class": _ctx.cx("activeBar"),
    role: "presentation",
    "aria-hidden": "true"
  }, _ctx.ptm("activeBar")), null, 16)], 16, _hoisted_2$N)], 16), $options.showNavigators && $data.isNextButtonEnabled ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 1,
    ref: "nextButton",
    "class": _ctx.cx("nextButton"),
    "aria-label": $options.nextButtonAriaLabel,
    tabindex: $options.$pcTabs.tabindex,
    onClick: _cache[2] || (_cache[2] = function() {
      return $options.onNextButtonClick && $options.onNextButtonClick.apply($options, arguments);
    })
  }, _ctx.ptm("nextButton"), {
    "data-pc-group-section": "navigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($options.templates.nexticon || "ChevronRightIcon"), mergeProps$2({
    "aria-hidden": "true"
  }, _ctx.ptm("nextIcon")), null, 16))], 16, _hoisted_3$x)), [[_directive_ripple]]) : createCommentVNode("", true)], 16);
}
__name(render$h, "render$h");
script$j.render = render$h;
const _hoisted_1$W = ["textContent"];
const _hoisted_2$M = {
  key: 1,
  class: "break-words"
};
const _hoisted_3$w = ["href"];
const _hoisted_4$m = { class: "text-blue-600" };
const _hoisted_5$j = { key: 1 };
const _hoisted_6$f = { key: 2 };
const _hoisted_7$7 = {
  key: 3,
  class: "bg-surface-100 px-1 py-0.5 rounded text-xs"
};
const _hoisted_8$5 = { key: 4 };
const _sfc_main$Y = /* @__PURE__ */ defineComponent({
  __name: "MarkdownText",
  props: {
    text: {}
  },
  setup(__props) {
    const hasMarkdown = computed(() => {
      const hasMarkdown2 = /(\[.*?\]\(.*?\)|(\*\*|__)(.*?)(\*\*|__)|(\*|_)(.*?)(\*|_)|`(.*?)`)/.test(
        __props.text
      );
      return hasMarkdown2;
    });
    const parsedSegments = computed(() => {
      if (!hasMarkdown.value) return [{ type: "text", text: __props.text }];
      const segments = [];
      const remainingText = __props.text;
      let lastIndex = 0;
      const linkRegex = /\[(.*?)\]\((.*?)\)/g;
      let linkMatch;
      while ((linkMatch = linkRegex.exec(remainingText)) !== null) {
        if (linkMatch.index > lastIndex) {
          segments.push({
            type: "text",
            text: remainingText.substring(lastIndex, linkMatch.index)
          });
        }
        segments.push({
          type: "link",
          text: linkMatch[1],
          url: linkMatch[2]
        });
        lastIndex = linkMatch.index + linkMatch[0].length;
      }
      if (lastIndex < remainingText.length) {
        let rest = remainingText.substring(lastIndex);
        rest = rest.replace(/(\*\*|__)(.*?)(\*\*|__)/g, (_2, __, p2) => {
          segments.push({ type: "bold", text: p2 });
          return "";
        });
        rest = rest.replace(/(\*|_)(.*?)(\*|_)/g, (_2, __, p2) => {
          segments.push({ type: "italic", text: p2 });
          return "";
        });
        rest = rest.replace(/`(.*?)`/g, (_2, p1) => {
          segments.push({ type: "code", text: p1 });
          return "";
        });
        if (rest) {
          segments.push({ type: "text", text: rest });
        }
      }
      return segments;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", null, [
        !hasMarkdown.value ? (openBlock(), createElementBlock("div", {
          key: 0,
          textContent: toDisplayString$1(_ctx.text),
          class: "break-words"
        }, null, 8, _hoisted_1$W)) : (openBlock(), createElementBlock("div", _hoisted_2$M, [
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(parsedSegments.value, (segment, index2) => {
            return openBlock(), createElementBlock(Fragment$1, { key: index2 }, [
              segment.type === "link" && "url" in segment ? (openBlock(), createElementBlock("a", {
                key: 0,
                href: segment.url,
                target: "_blank",
                rel: "noopener noreferrer",
                class: "hover:underline"
              }, [
                createBaseVNode("span", _hoisted_4$m, toDisplayString$1(segment.text), 1)
              ], 8, _hoisted_3$w)) : segment.type === "bold" ? (openBlock(), createElementBlock("strong", _hoisted_5$j, toDisplayString$1(segment.text), 1)) : segment.type === "italic" ? (openBlock(), createElementBlock("em", _hoisted_6$f, toDisplayString$1(segment.text), 1)) : segment.type === "code" ? (openBlock(), createElementBlock("code", _hoisted_7$7, toDisplayString$1(segment.text), 1)) : (openBlock(), createElementBlock("span", _hoisted_8$5, toDisplayString$1(segment.text), 1))
            ], 64);
          }), 128))
        ]))
      ]);
    };
  }
});
const _hoisted_1$V = { class: "flex flex-col gap-4 text-sm" };
const _hoisted_2$L = { class: "mb-1" };
const _hoisted_3$v = { class: "text-muted break-words" };
const _hoisted_4$l = ["href"];
const _hoisted_5$i = {
  key: 0,
  class: "pi pi-github text-base"
};
const _hoisted_6$e = { class: "break-all" };
const _sfc_main$X = /* @__PURE__ */ defineComponent({
  __name: "InfoTextSection",
  props: {
    sections: {}
  },
  setup(__props) {
    const isGitHubLink = /* @__PURE__ */ __name((url) => url.includes("github.com"), "isGitHubLink");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$V, [
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.sections, (section, index2) => {
          return openBlock(), createElementBlock("div", {
            key: index2,
            class: "mb-4"
          }, [
            createBaseVNode("div", _hoisted_2$L, toDisplayString$1(section.title), 1),
            createBaseVNode("div", _hoisted_3$v, [
              section.isUrl ? (openBlock(), createElementBlock("a", {
                key: 0,
                href: section.text,
                target: "_blank",
                rel: "noopener noreferrer",
                class: "flex items-center gap-2"
              }, [
                isGitHubLink(section.text) ? (openBlock(), createElementBlock("i", _hoisted_5$i)) : createCommentVNode("", true),
                createBaseVNode("span", _hoisted_6$e, toDisplayString$1(section.text), 1)
              ], 8, _hoisted_4$l)) : (openBlock(), createBlock(_sfc_main$Y, {
                key: 1,
                text: section.text,
                class: "text-muted"
              }, null, 8, ["text"]))
            ])
          ]);
        }), 128))
      ]);
    };
  }
});
const _hoisted_1$U = { class: "mt-4 overflow-hidden" };
const _hoisted_2$K = {
  key: 1,
  class: "text-muted italic text-sm"
};
const _hoisted_3$u = { key: 2 };
const _hoisted_4$k = { class: "mb-1" };
const _sfc_main$W = /* @__PURE__ */ defineComponent({
  __name: "DescriptionTabPanel",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const { t: t2 } = useI18n();
    const isLicenseFile = /* @__PURE__ */ __name((filename) => {
      const licensePattern = /^license(\.md|\.txt)?$/i;
      return licensePattern.test(filename);
    }, "isLicenseFile");
    const extractBaseRepoUrl = /* @__PURE__ */ __name((repoUrl) => {
      const githubRepoPattern = /^(https?:\/\/github\.com\/[^/]+\/[^/]+)/i;
      const match2 = repoUrl.match(githubRepoPattern);
      return match2 ? match2[1] : repoUrl;
    }, "extractBaseRepoUrl");
    const createLicenseUrl = /* @__PURE__ */ __name((filename, repoUrl) => {
      if (!repoUrl || !filename) return "";
      const licenseFile = isLicenseFile(filename) ? filename : "LICENSE";
      const baseRepoUrl = extractBaseRepoUrl(repoUrl);
      return `${baseRepoUrl}/blob/main/${licenseFile}`;
    }, "createLicenseUrl");
    const parseLicenseObject = /* @__PURE__ */ __name((licenseObj) => {
      const licenseFile = licenseObj.file || licenseObj.text;
      if (typeof licenseFile === "string" && isLicenseFile(licenseFile) && __props.nodePack.repository) {
        const url = createLicenseUrl(licenseFile, __props.nodePack.repository);
        return {
          text: url,
          isUrl: !!url && isValidUrl(url)
        };
      } else if (licenseObj.text) {
        return {
          text: licenseObj.text,
          isUrl: false
        };
      } else if (typeof licenseFile === "string") {
        return {
          text: licenseFile,
          isUrl: false
        };
      }
      return {
        text: JSON.stringify(licenseObj),
        isUrl: false
      };
    }, "parseLicenseObject");
    const formatLicense = /* @__PURE__ */ __name((license) => {
      if (license === "{}") return null;
      try {
        const licenseObj = JSON.parse(license);
        if (Object.keys(licenseObj).length === 0) {
          return null;
        }
        return parseLicenseObject(licenseObj);
      } catch (e2) {
        if (isLicenseFile(license) && __props.nodePack.repository) {
          const url = createLicenseUrl(license, __props.nodePack.repository);
          return {
            text: url,
            isUrl: !!url && isValidUrl(url)
          };
        }
        return {
          text: license,
          isUrl: false
        };
      }
    }, "formatLicense");
    const descriptionSections = computed(() => {
      const sections = [
        {
          title: t2("g.description"),
          text: __props.nodePack.description || t2("manager.noDescription")
        }
      ];
      if (__props.nodePack.repository) {
        sections.push({
          title: t2("manager.repository"),
          text: __props.nodePack.repository,
          isUrl: isValidUrl(__props.nodePack.repository)
        });
      }
      if (__props.nodePack.license) {
        const licenseInfo = formatLicense(__props.nodePack.license);
        if (licenseInfo && licenseInfo.text) {
          sections.push({
            title: t2("manager.license"),
            text: licenseInfo.text,
            isUrl: licenseInfo.isUrl
          });
        }
      }
      return sections;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$U, [
        _ctx.nodePack?.description ? (openBlock(), createBlock(_sfc_main$X, {
          key: 0,
          sections: descriptionSections.value
        }, null, 8, ["sections"])) : (openBlock(), createElementBlock("p", _hoisted_2$K, toDisplayString$1(_ctx.$t("manager.noDescription")), 1)),
        _ctx.nodePack?.latest_version?.dependencies?.length ? (openBlock(), createElementBlock("div", _hoisted_3$u, [
          createBaseVNode("p", _hoisted_4$k, toDisplayString$1(_ctx.$t("manager.dependencies")), 1),
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.nodePack.latest_version.dependencies, (dep, index2) => {
            return openBlock(), createElementBlock("div", {
              key: index2,
              class: "text-muted break-words"
            }, toDisplayString$1(dep), 1);
          }), 128))
        ])) : createCommentVNode("", true)
      ]);
    };
  }
});
const zIntInputSpec = zIntInputOptions.extend({
  type: z.literal("INT"),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zFloatInputSpec = zFloatInputOptions.extend({
  type: z.literal("FLOAT"),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zBooleanInputSpec = zBooleanInputOptions.extend({
  type: z.literal("BOOLEAN"),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zStringInputSpec = zStringInputOptions.extend({
  type: z.literal("STRING"),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zComboInputSpec = zComboInputOptions.extend({
  type: z.literal("COMBO"),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zCustomInputSpec = zBaseInputOptions.extend({
  type: z.string(),
  name: z.string(),
  isOptional: z.boolean().optional()
});
const zInputSpec = z.union([
  zIntInputSpec,
  zFloatInputSpec,
  zBooleanInputSpec,
  zStringInputSpec,
  zComboInputSpec,
  zCustomInputSpec
]);
const zOutputSpec = z.object({
  index: z.number(),
  name: z.string(),
  type: z.string(),
  is_list: z.boolean(),
  options: z.array(z.any()).optional(),
  tooltip: z.string().optional()
});
const zComfyNodeDef = z.object({
  inputs: z.record(zInputSpec),
  outputs: z.array(zOutputSpec),
  hidden: z.record(z.any()).optional(),
  name: z.string(),
  display_name: z.string(),
  description: z.string(),
  category: z.string(),
  output_node: z.boolean(),
  python_module: z.string(),
  deprecated: z.boolean().optional(),
  experimental: z.boolean().optional()
});
const isIntInputSpec = /* @__PURE__ */ __name((inputSpec) => {
  return inputSpec.type === "INT";
}, "isIntInputSpec");
const isFloatInputSpec = /* @__PURE__ */ __name((inputSpec) => {
  return inputSpec.type === "FLOAT";
}, "isFloatInputSpec");
const isBooleanInputSpec = /* @__PURE__ */ __name((inputSpec) => {
  return inputSpec.type === "BOOLEAN";
}, "isBooleanInputSpec");
const isStringInputSpec = /* @__PURE__ */ __name((inputSpec) => {
  return inputSpec.type === "STRING";
}, "isStringInputSpec");
const isComboInputSpec = /* @__PURE__ */ __name((inputSpec) => {
  return inputSpec.type === "COMBO";
}, "isComboInputSpec");
const isComfyNodeDef = /* @__PURE__ */ __name((nodeDef) => {
  return !!nodeDef && typeof nodeDef === "object" && ["inputs", "outputs"].every((key) => key in nodeDef);
}, "isComfyNodeDef");
const useBooleanWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    if (!isBooleanInputSpec(inputSpec)) {
      throw new Error(`Invalid input data: ${inputSpec}`);
    }
    const defaultVal = inputSpec.default ?? false;
    const options5 = {
      on: inputSpec.label_on,
      off: inputSpec.label_off
    };
    return node3.addWidget(
      "toggle",
      inputSpec.name,
      defaultVal,
      () => {
      },
      options5
    );
  }, "widgetConstructor");
  return widgetConstructor;
}, "useBooleanWidget");
var theme$b = /* @__PURE__ */ __name(function theme35(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-multiselect {\n    display: inline-flex;\n    cursor: pointer;\n    position: relative;\n    user-select: none;\n    background: ".concat(dt2("multiselect.background"), ";\n    border: 1px solid ").concat(dt2("multiselect.border.color"), ";\n    transition: background ").concat(dt2("multiselect.transition.duration"), ", color ").concat(dt2("multiselect.transition.duration"), ", border-color ").concat(dt2("multiselect.transition.duration"), ", outline-color ").concat(dt2("multiselect.transition.duration"), ", box-shadow ").concat(dt2("multiselect.transition.duration"), ";\n    border-radius: ").concat(dt2("multiselect.border.radius"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("multiselect.shadow"), ";\n}\n\n.p-multiselect:not(.p-disabled):hover {\n    border-color: ").concat(dt2("multiselect.hover.border.color"), ";\n}\n\n.p-multiselect:not(.p-disabled).p-focus {\n    border-color: ").concat(dt2("multiselect.focus.border.color"), ";\n    box-shadow: ").concat(dt2("multiselect.focus.ring.shadow"), ";\n    outline: ").concat(dt2("multiselect.focus.ring.width"), " ").concat(dt2("multiselect.focus.ring.style"), " ").concat(dt2("multiselect.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("multiselect.focus.ring.offset"), ";\n}\n\n.p-multiselect.p-variant-filled {\n    background: ").concat(dt2("multiselect.filled.background"), ";\n}\n\n.p-multiselect.p-variant-filled:not(.p-disabled):hover {\n    background: ").concat(dt2("multiselect.filled.hover.background"), ";\n}\n\n.p-multiselect.p-variant-filled.p-focus {\n    background: ").concat(dt2("multiselect.filled.focus.background"), ";\n}\n\n.p-multiselect.p-invalid {\n    border-color: ").concat(dt2("multiselect.invalid.border.color"), ";\n}\n\n.p-multiselect.p-disabled {\n    opacity: 1;\n    background: ").concat(dt2("multiselect.disabled.background"), ";\n}\n\n.p-multiselect-dropdown {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    flex-shrink: 0;\n    background: transparent;\n    color: ").concat(dt2("multiselect.dropdown.color"), ";\n    width: ").concat(dt2("multiselect.dropdown.width"), ";\n    border-start-end-radius: ").concat(dt2("multiselect.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("multiselect.border.radius"), ";\n}\n\n.p-multiselect-clear-icon {\n    position: absolute;\n    top: 50%;\n    margin-top: -0.5rem;\n    color: ").concat(dt2("multiselect.clear.icon.color"), ";\n    inset-inline-end: ").concat(dt2("multiselect.dropdown.width"), ";\n}\n\n.p-multiselect-label-container {\n    overflow: hidden;\n    flex: 1 1 auto;\n    cursor: pointer;\n}\n\n.p-multiselect-label {\n    display: flex;\n    align-items: center;\n    gap: calc(").concat(dt2("multiselect.padding.y"), " / 2);\n    white-space: nowrap;\n    cursor: pointer;\n    overflow: hidden;\n    text-overflow: ellipsis;\n    padding: ").concat(dt2("multiselect.padding.y"), " ").concat(dt2("multiselect.padding.x"), ";\n    color: ").concat(dt2("multiselect.color"), ";\n}\n\n.p-multiselect-label.p-placeholder {\n    color: ").concat(dt2("multiselect.placeholder.color"), ";\n}\n\n.p-multiselect.p-invalid .p-multiselect-label.p-placeholder {\n    color: ").concat(dt2("multiselect.invalid.placeholder.color"), ";\n}\n\n.p-multiselect.p-disabled .p-multiselect-label {\n    color: ").concat(dt2("multiselect.disabled.color"), ";\n}\n\n.p-multiselect-label-empty {\n    overflow: hidden;\n    visibility: hidden;\n}\n\n.p-multiselect .p-multiselect-overlay {\n    min-width: 100%;\n}\n\n.p-multiselect-overlay {\n    position: absolute;\n    top: 0;\n    left: 0;\n    background: ").concat(dt2("multiselect.overlay.background"), ";\n    color: ").concat(dt2("multiselect.overlay.color"), ";\n    border: 1px solid ").concat(dt2("multiselect.overlay.border.color"), ";\n    border-radius: ").concat(dt2("multiselect.overlay.border.radius"), ";\n    box-shadow: ").concat(dt2("multiselect.overlay.shadow"), ";\n}\n\n.p-multiselect-header {\n    display: flex;\n    align-items: center;\n    padding: ").concat(dt2("multiselect.list.header.padding"), ";\n}\n\n.p-multiselect-header .p-checkbox {\n    margin-inline-end: ").concat(dt2("multiselect.option.gap"), ";\n}\n\n.p-multiselect-filter-container {\n    flex: 1 1 auto;\n}\n\n.p-multiselect-filter {\n    width: 100%;\n}\n\n.p-multiselect-list-container {\n    overflow: auto;\n}\n\n.p-multiselect-list {\n    margin: 0;\n    padding: 0;\n    list-style-type: none;\n    padding: ").concat(dt2("multiselect.list.padding"), ";\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("multiselect.list.gap"), ";\n}\n\n.p-multiselect-option {\n    cursor: pointer;\n    font-weight: normal;\n    white-space: nowrap;\n    position: relative;\n    overflow: hidden;\n    display: flex;\n    align-items: center;\n    gap: ").concat(dt2("multiselect.option.gap"), ";\n    padding: ").concat(dt2("multiselect.option.padding"), ";\n    border: 0 none;\n    color: ").concat(dt2("multiselect.option.color"), ";\n    background: transparent;\n    transition: background ").concat(dt2("multiselect.transition.duration"), ", color ").concat(dt2("multiselect.transition.duration"), ", border-color ").concat(dt2("multiselect.transition.duration"), ", box-shadow ").concat(dt2("multiselect.transition.duration"), ", outline-color ").concat(dt2("multiselect.transition.duration"), ";\n    border-radius: ").concat(dt2("multiselect.option.border.radius"), ";\n}\n\n.p-multiselect-option:not(.p-multiselect-option-selected):not(.p-disabled).p-focus {\n    background: ").concat(dt2("multiselect.option.focus.background"), ";\n    color: ").concat(dt2("multiselect.option.focus.color"), ";\n}\n\n.p-multiselect-option.p-multiselect-option-selected {\n    background: ").concat(dt2("multiselect.option.selected.background"), ";\n    color: ").concat(dt2("multiselect.option.selected.color"), ";\n}\n\n.p-multiselect-option.p-multiselect-option-selected.p-focus {\n    background: ").concat(dt2("multiselect.option.selected.focus.background"), ";\n    color: ").concat(dt2("multiselect.option.selected.focus.color"), ";\n}\n\n.p-multiselect-option-group {\n    cursor: auto;\n    margin: 0;\n    padding: ").concat(dt2("multiselect.option.group.padding"), ";\n    background: ").concat(dt2("multiselect.option.group.background"), ";\n    color: ").concat(dt2("multiselect.option.group.color"), ";\n    font-weight: ").concat(dt2("multiselect.option.group.font.weight"), ";\n}\n\n.p-multiselect-empty-message {\n    padding: ").concat(dt2("multiselect.empty.message.padding"), ";\n}\n\n.p-multiselect-label .p-chip {\n    padding-block-start: calc(").concat(dt2("multiselect.padding.y"), " / 2);\n    padding-block-end: calc(").concat(dt2("multiselect.padding.y"), " / 2);\n    border-radius: ").concat(dt2("multiselect.chip.border.radius"), ";\n}\n\n.p-multiselect-label:has(.p-chip) {\n    padding: calc(").concat(dt2("multiselect.padding.y"), " / 2) calc(").concat(dt2("multiselect.padding.x"), " / 2);\n}\n\n.p-multiselect-fluid {\n    display: flex;\n    width: 100%;\n}\n\n.p-multiselect-sm .p-multiselect-label {\n    font-size: ").concat(dt2("multiselect.sm.font.size"), ";\n    padding-block: ").concat(dt2("multiselect.sm.padding.y"), ";\n    padding-inline: ").concat(dt2("multiselect.sm.padding.x"), ";\n}\n\n.p-multiselect-sm .p-multiselect-dropdown .p-icon {\n    font-size: ").concat(dt2("multiselect.sm.font.size"), ";\n    width: ").concat(dt2("multiselect.sm.font.size"), ";\n    height: ").concat(dt2("multiselect.sm.font.size"), ";\n}\n\n.p-multiselect-lg .p-multiselect-label {\n    font-size: ").concat(dt2("multiselect.lg.font.size"), ";\n    padding-block: ").concat(dt2("multiselect.lg.padding.y"), ";\n    padding-inline: ").concat(dt2("multiselect.lg.padding.x"), ";\n}\n\n.p-multiselect-lg .p-multiselect-dropdown .p-icon {\n    font-size: ").concat(dt2("multiselect.lg.font.size"), ";\n    width: ").concat(dt2("multiselect.lg.font.size"), ";\n    height: ").concat(dt2("multiselect.lg.font.size"), ";\n}\n");
}, "theme");
var inlineStyles$2 = {
  root: /* @__PURE__ */ __name(function root25(_ref2) {
    var props = _ref2.props;
    return {
      position: props.appendTo === "self" ? "relative" : void 0
    };
  }, "root")
};
var classes$b = {
  root: /* @__PURE__ */ __name(function root26(_ref3) {
    var instance = _ref3.instance, props = _ref3.props;
    return ["p-multiselect p-component p-inputwrapper", {
      "p-multiselect-display-chip": props.display === "chip",
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid,
      "p-variant-filled": instance.$variant === "filled",
      "p-focus": instance.focused,
      "p-inputwrapper-filled": instance.$filled,
      "p-inputwrapper-focus": instance.focused || instance.overlayVisible,
      "p-multiselect-open": instance.overlayVisible,
      "p-multiselect-fluid": instance.$fluid,
      "p-multiselect-sm p-inputfield-sm": props.size === "small",
      "p-multiselect-lg p-inputfield-lg": props.size === "large"
    }];
  }, "root"),
  labelContainer: "p-multiselect-label-container",
  label: /* @__PURE__ */ __name(function label3(_ref4) {
    var instance = _ref4.instance, props = _ref4.props;
    return ["p-multiselect-label", {
      "p-placeholder": instance.label === props.placeholder,
      "p-multiselect-label-empty": !props.placeholder && (!props.modelValue || props.modelValue.length === 0)
    }];
  }, "label"),
  clearIcon: "p-multiselect-clear-icon",
  chipItem: "p-multiselect-chip-item",
  pcChip: "p-multiselect-chip",
  chipIcon: "p-multiselect-chip-icon",
  dropdown: "p-multiselect-dropdown",
  loadingIcon: "p-multiselect-loading-icon",
  dropdownIcon: "p-multiselect-dropdown-icon",
  overlay: "p-multiselect-overlay p-component",
  header: "p-multiselect-header",
  pcFilterContainer: "p-multiselect-filter-container",
  pcFilter: "p-multiselect-filter",
  listContainer: "p-multiselect-list-container",
  list: "p-multiselect-list",
  optionGroup: "p-multiselect-option-group",
  option: /* @__PURE__ */ __name(function option3(_ref5) {
    var instance = _ref5.instance, _option = _ref5.option, index2 = _ref5.index, getItemOptions = _ref5.getItemOptions, props = _ref5.props;
    return ["p-multiselect-option", {
      "p-multiselect-option-selected": instance.isSelected(_option) && props.highlightOnSelect,
      "p-focus": instance.focusedOptionIndex === instance.getOptionIndex(index2, getItemOptions),
      "p-disabled": instance.isOptionDisabled(_option)
    }];
  }, "option"),
  emptyMessage: "p-multiselect-empty-message"
};
var MultiSelectStyle = BaseStyle$1.extend({
  name: "multiselect",
  theme: theme$b,
  classes: classes$b,
  inlineStyles: inlineStyles$2
});
var script$1$b = {
  name: "BaseMultiSelect",
  "extends": script$17,
  props: {
    options: Array,
    optionLabel: null,
    optionValue: null,
    optionDisabled: null,
    optionGroupLabel: null,
    optionGroupChildren: null,
    scrollHeight: {
      type: String,
      "default": "14rem"
    },
    placeholder: String,
    inputId: {
      type: String,
      "default": null
    },
    panelClass: {
      type: String,
      "default": null
    },
    panelStyle: {
      type: null,
      "default": null
    },
    overlayClass: {
      type: String,
      "default": null
    },
    overlayStyle: {
      type: null,
      "default": null
    },
    dataKey: null,
    showClear: {
      type: Boolean,
      "default": false
    },
    clearIcon: {
      type: String,
      "default": void 0
    },
    resetFilterOnClear: {
      type: Boolean,
      "default": false
    },
    filter: Boolean,
    filterPlaceholder: String,
    filterLocale: String,
    filterMatchMode: {
      type: String,
      "default": "contains"
    },
    filterFields: {
      type: Array,
      "default": null
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    display: {
      type: String,
      "default": "comma"
    },
    selectedItemsLabel: {
      type: String,
      "default": null
    },
    maxSelectedLabels: {
      type: Number,
      "default": null
    },
    selectionLimit: {
      type: Number,
      "default": null
    },
    showToggleAll: {
      type: Boolean,
      "default": true
    },
    loading: {
      type: Boolean,
      "default": false
    },
    checkboxIcon: {
      type: String,
      "default": void 0
    },
    dropdownIcon: {
      type: String,
      "default": void 0
    },
    filterIcon: {
      type: String,
      "default": void 0
    },
    loadingIcon: {
      type: String,
      "default": void 0
    },
    removeTokenIcon: {
      type: String,
      "default": void 0
    },
    chipIcon: {
      type: String,
      "default": void 0
    },
    selectAll: {
      type: Boolean,
      "default": null
    },
    resetFilterOnHide: {
      type: Boolean,
      "default": false
    },
    virtualScrollerOptions: {
      type: Object,
      "default": null
    },
    autoOptionFocus: {
      type: Boolean,
      "default": false
    },
    autoFilterFocus: {
      type: Boolean,
      "default": false
    },
    focusOnHover: {
      type: Boolean,
      "default": true
    },
    highlightOnSelect: {
      type: Boolean,
      "default": false
    },
    filterMessage: {
      type: String,
      "default": null
    },
    selectionMessage: {
      type: String,
      "default": null
    },
    emptySelectionMessage: {
      type: String,
      "default": null
    },
    emptyFilterMessage: {
      type: String,
      "default": null
    },
    emptyMessage: {
      type: String,
      "default": null
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    }
  },
  style: MultiSelectStyle,
  provide: /* @__PURE__ */ __name(function provide40() {
    return {
      $pcMultiSelect: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$1$3(o2) {
  "@babel/helpers - typeof";
  return _typeof$1$3 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$1$3(o2);
}
__name(_typeof$1$3, "_typeof$1$3");
function ownKeys$8(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$8, "ownKeys$8");
function _objectSpread$8(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$8(Object(t2), true).forEach(function(r3) {
      _defineProperty$1$2(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$8(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$8, "_objectSpread$8");
function _defineProperty$1$2(e2, r2, t2) {
  return (r2 = _toPropertyKey$1$2(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$1$2, "_defineProperty$1$2");
function _toPropertyKey$1$2(t2) {
  var i2 = _toPrimitive$1$2(t2, "string");
  return "symbol" == _typeof$1$3(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$1$2, "_toPropertyKey$1$2");
function _toPrimitive$1$2(t2, r2) {
  if ("object" != _typeof$1$3(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$1$3(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$1$2, "_toPrimitive$1$2");
function _toConsumableArray$6(r2) {
  return _arrayWithoutHoles$6(r2) || _iterableToArray$6(r2) || _unsupportedIterableToArray$8(r2) || _nonIterableSpread$6();
}
__name(_toConsumableArray$6, "_toConsumableArray$6");
function _nonIterableSpread$6() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$6, "_nonIterableSpread$6");
function _unsupportedIterableToArray$8(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$8(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$8(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$8, "_unsupportedIterableToArray$8");
function _iterableToArray$6(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$6, "_iterableToArray$6");
function _arrayWithoutHoles$6(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$8(r2);
}
__name(_arrayWithoutHoles$6, "_arrayWithoutHoles$6");
function _arrayLikeToArray$8(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$8, "_arrayLikeToArray$8");
var script$i = {
  name: "MultiSelect",
  "extends": script$1$b,
  inheritAttrs: false,
  emits: ["change", "focus", "blur", "before-show", "before-hide", "show", "hide", "filter", "selectall-change"],
  inject: {
    $pcFluid: {
      "default": null
    }
  },
  outsideClickListener: null,
  scrollHandler: null,
  resizeListener: null,
  overlay: null,
  list: null,
  virtualScroller: null,
  startRangeIndex: -1,
  searchTimeout: null,
  searchValue: "",
  selectOnFocus: false,
  data: /* @__PURE__ */ __name(function data20() {
    return {
      id: this.$attrs.id,
      clicked: false,
      focused: false,
      focusedOptionIndex: -1,
      filterValue: null,
      overlayVisible: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId8(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    options: /* @__PURE__ */ __name(function options4() {
      this.autoUpdateModel();
    }, "options")
  },
  mounted: /* @__PURE__ */ __name(function mounted19() {
    this.id = this.id || UniqueComponentId();
    this.autoUpdateModel();
  }, "mounted"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount11() {
    this.unbindOutsideClickListener();
    this.unbindResizeListener();
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    if (this.overlay) {
      ZIndex$1.clear(this.overlay);
      this.overlay = null;
    }
  }, "beforeUnmount"),
  methods: {
    getOptionIndex: /* @__PURE__ */ __name(function getOptionIndex3(index2, fn) {
      return this.virtualScrollerDisabled ? index2 : fn && fn(index2)["index"];
    }, "getOptionIndex"),
    getOptionLabel: /* @__PURE__ */ __name(function getOptionLabel3(option5) {
      return this.optionLabel ? resolveFieldData$2(option5, this.optionLabel) : option5;
    }, "getOptionLabel"),
    getOptionValue: /* @__PURE__ */ __name(function getOptionValue3(option5) {
      return this.optionValue ? resolveFieldData$2(option5, this.optionValue) : option5;
    }, "getOptionValue"),
    getOptionRenderKey: /* @__PURE__ */ __name(function getOptionRenderKey3(option5, index2) {
      return this.dataKey ? resolveFieldData$2(option5, this.dataKey) : this.getOptionLabel(option5) + "_".concat(index2);
    }, "getOptionRenderKey"),
    getHeaderCheckboxPTOptions: /* @__PURE__ */ __name(function getHeaderCheckboxPTOptions(key) {
      return this.ptm(key, {
        context: {
          selected: this.allSelected
        }
      });
    }, "getHeaderCheckboxPTOptions"),
    getCheckboxPTOptions: /* @__PURE__ */ __name(function getCheckboxPTOptions(option5, itemOptions, index2, key) {
      return this.ptm(key, {
        context: {
          selected: this.isSelected(option5),
          focused: this.focusedOptionIndex === this.getOptionIndex(index2, itemOptions),
          disabled: this.isOptionDisabled(option5)
        }
      });
    }, "getCheckboxPTOptions"),
    isOptionDisabled: /* @__PURE__ */ __name(function isOptionDisabled3(option5) {
      if (this.maxSelectionLimitReached && !this.isSelected(option5)) {
        return true;
      }
      return this.optionDisabled ? resolveFieldData$2(option5, this.optionDisabled) : false;
    }, "isOptionDisabled"),
    isOptionGroup: /* @__PURE__ */ __name(function isOptionGroup3(option5) {
      return this.optionGroupLabel && option5.optionGroup && option5.group;
    }, "isOptionGroup"),
    getOptionGroupLabel: /* @__PURE__ */ __name(function getOptionGroupLabel3(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupLabel);
    }, "getOptionGroupLabel"),
    getOptionGroupChildren: /* @__PURE__ */ __name(function getOptionGroupChildren3(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupChildren);
    }, "getOptionGroupChildren"),
    getAriaPosInset: /* @__PURE__ */ __name(function getAriaPosInset3(index2) {
      var _this = this;
      return (this.optionGroupLabel ? index2 - this.visibleOptions.slice(0, index2).filter(function(option5) {
        return _this.isOptionGroup(option5);
      }).length : index2) + 1;
    }, "getAriaPosInset"),
    show: /* @__PURE__ */ __name(function show4(isFocus) {
      this.$emit("before-show");
      this.overlayVisible = true;
      this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : this.findSelectedOptionIndex();
      isFocus && focus$2(this.$refs.focusInput);
    }, "show"),
    hide: /* @__PURE__ */ __name(function hide4(isFocus) {
      var _this2 = this;
      var _hide = /* @__PURE__ */ __name(function _hide2() {
        _this2.$emit("before-hide");
        _this2.overlayVisible = false;
        _this2.clicked = false;
        _this2.focusedOptionIndex = -1;
        _this2.searchValue = "";
        _this2.resetFilterOnHide && (_this2.filterValue = null);
        isFocus && focus$2(_this2.$refs.focusInput);
      }, "_hide");
      setTimeout(function() {
        _hide();
      }, 0);
    }, "hide"),
    onFocus: /* @__PURE__ */ __name(function onFocus7(event) {
      if (this.disabled) {
        return;
      }
      this.focused = true;
      if (this.overlayVisible) {
        this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : this.findSelectedOptionIndex();
        this.scrollInView(this.focusedOptionIndex);
      }
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur8(event) {
      var _this$formField$onBlu, _this$formField;
      this.clicked = false;
      this.focused = false;
      this.focusedOptionIndex = -1;
      this.searchValue = "";
      this.$emit("blur", event);
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField);
    }, "onBlur"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown9(event) {
      var _this3 = this;
      if (this.disabled) {
        event.preventDefault();
        return;
      }
      var metaKey = event.metaKey || event.ctrlKey;
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event);
          break;
        case "Home":
          this.onHomeKey(event);
          break;
        case "End":
          this.onEndKey(event);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event);
          break;
        case "ShiftLeft":
        case "ShiftRight":
          this.onShiftKey(event);
          break;
        default:
          if (event.code === "KeyA" && metaKey) {
            var value3 = this.visibleOptions.filter(function(option5) {
              return _this3.isValidOption(option5);
            }).map(function(option5) {
              return _this3.getOptionValue(option5);
            });
            this.updateModel(event, value3);
            event.preventDefault();
            break;
          }
          if (!metaKey && isPrintableCharacter$2(event.key)) {
            !this.overlayVisible && this.show();
            this.searchOptions(event);
            event.preventDefault();
          }
          break;
      }
      this.clicked = false;
    }, "onKeyDown"),
    onContainerClick: /* @__PURE__ */ __name(function onContainerClick2(event) {
      if (this.disabled || this.loading) {
        return;
      }
      if (event.target.tagName === "INPUT" || event.target.getAttribute("data-pc-section") === "clearicon" || event.target.closest('[data-pc-section="clearicon"]')) {
        return;
      } else if (!this.overlay || !this.overlay.contains(event.target)) {
        this.overlayVisible ? this.hide(true) : this.show(true);
      }
      this.clicked = true;
    }, "onContainerClick"),
    onClearClick: /* @__PURE__ */ __name(function onClearClick2(event) {
      this.updateModel(event, null);
      this.resetFilterOnClear && (this.filterValue = null);
    }, "onClearClick"),
    onFirstHiddenFocus: /* @__PURE__ */ __name(function onFirstHiddenFocus3(event) {
      var focusableEl = event.relatedTarget === this.$refs.focusInput ? getFirstFocusableElement$1(this.overlay, ':not([data-p-hidden-focusable="true"])') : this.$refs.focusInput;
      focus$2(focusableEl);
    }, "onFirstHiddenFocus"),
    onLastHiddenFocus: /* @__PURE__ */ __name(function onLastHiddenFocus3(event) {
      var focusableEl = event.relatedTarget === this.$refs.focusInput ? getLastFocusableElement$1(this.overlay, ':not([data-p-hidden-focusable="true"])') : this.$refs.focusInput;
      focus$2(focusableEl);
    }, "onLastHiddenFocus"),
    onOptionSelect: /* @__PURE__ */ __name(function onOptionSelect3(event, option5) {
      var _this4 = this;
      var index2 = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : -1;
      var isFocus = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : false;
      if (this.disabled || this.isOptionDisabled(option5)) {
        return;
      }
      var selected2 = this.isSelected(option5);
      var value3 = null;
      if (selected2) value3 = this.d_value.filter(function(val) {
        return !equals$2(val, _this4.getOptionValue(option5), _this4.equalityKey);
      });
      else value3 = [].concat(_toConsumableArray$6(this.d_value || []), [this.getOptionValue(option5)]);
      this.updateModel(event, value3);
      index2 !== -1 && (this.focusedOptionIndex = index2);
      isFocus && focus$2(this.$refs.focusInput);
    }, "onOptionSelect"),
    onOptionMouseMove: /* @__PURE__ */ __name(function onOptionMouseMove3(event, index2) {
      if (this.focusOnHover) {
        this.changeFocusedOptionIndex(event, index2);
      }
    }, "onOptionMouseMove"),
    onOptionSelectRange: /* @__PURE__ */ __name(function onOptionSelectRange2(event) {
      var _this5 = this;
      var start2 = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : -1;
      var end = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : -1;
      start2 === -1 && (start2 = this.findNearestSelectedOptionIndex(end, true));
      end === -1 && (end = this.findNearestSelectedOptionIndex(start2));
      if (start2 !== -1 && end !== -1) {
        var rangeStart = Math.min(start2, end);
        var rangeEnd = Math.max(start2, end);
        var value3 = this.visibleOptions.slice(rangeStart, rangeEnd + 1).filter(function(option5) {
          return _this5.isValidOption(option5);
        }).map(function(option5) {
          return _this5.getOptionValue(option5);
        });
        this.updateModel(event, value3);
      }
    }, "onOptionSelectRange"),
    onFilterChange: /* @__PURE__ */ __name(function onFilterChange3(event) {
      var value3 = event.target.value;
      this.filterValue = value3;
      this.focusedOptionIndex = -1;
      this.$emit("filter", {
        originalEvent: event,
        value: value3
      });
      !this.virtualScrollerDisabled && this.virtualScroller.scrollToIndex(0);
    }, "onFilterChange"),
    onFilterKeyDown: /* @__PURE__ */ __name(function onFilterKeyDown3(event) {
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event, true);
          break;
        case "ArrowLeft":
        case "ArrowRight":
          this.onArrowLeftKey(event, true);
          break;
        case "Home":
          this.onHomeKey(event, true);
          break;
        case "End":
          this.onEndKey(event, true);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event, true);
          break;
      }
    }, "onFilterKeyDown"),
    onFilterBlur: /* @__PURE__ */ __name(function onFilterBlur3() {
      this.focusedOptionIndex = -1;
    }, "onFilterBlur"),
    onFilterUpdated: /* @__PURE__ */ __name(function onFilterUpdated2() {
      if (this.overlayVisible) {
        this.alignOverlay();
      }
    }, "onFilterUpdated"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick4(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.$el
      });
    }, "onOverlayClick"),
    onOverlayKeyDown: /* @__PURE__ */ __name(function onOverlayKeyDown2(event) {
      switch (event.code) {
        case "Escape":
          this.onEscapeKey(event);
          break;
      }
    }, "onOverlayKeyDown"),
    onArrowDownKey: /* @__PURE__ */ __name(function onArrowDownKey3(event) {
      if (!this.overlayVisible) {
        this.show();
      } else {
        var optionIndex = this.focusedOptionIndex !== -1 ? this.findNextOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findFirstOptionIndex() : this.findFirstFocusedOptionIndex();
        if (event.shiftKey) {
          this.onOptionSelectRange(event, this.startRangeIndex, optionIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
      }
      event.preventDefault();
    }, "onArrowDownKey"),
    onArrowUpKey: /* @__PURE__ */ __name(function onArrowUpKey3(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (event.altKey && !pressedInInputText) {
        if (this.focusedOptionIndex !== -1) {
          this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
        }
        this.overlayVisible && this.hide();
        event.preventDefault();
      } else {
        var optionIndex = this.focusedOptionIndex !== -1 ? this.findPrevOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findLastOptionIndex() : this.findLastFocusedOptionIndex();
        if (event.shiftKey) {
          this.onOptionSelectRange(event, optionIndex, this.startRangeIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
        !this.overlayVisible && this.show();
        event.preventDefault();
      }
    }, "onArrowUpKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey4(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      pressedInInputText && (this.focusedOptionIndex = -1);
    }, "onArrowLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey4(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(0, event.target.selectionStart);
        } else {
          target2.setSelectionRange(0, 0);
          this.focusedOptionIndex = -1;
        }
      } else {
        var metaKey = event.metaKey || event.ctrlKey;
        var optionIndex = this.findFirstOptionIndex();
        if (event.shiftKey && metaKey) {
          this.onOptionSelectRange(event, optionIndex, this.startRangeIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
        !this.overlayVisible && this.show();
      }
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey4(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (pressedInInputText) {
        var target2 = event.currentTarget;
        if (event.shiftKey) {
          target2.setSelectionRange(event.target.selectionStart, target2.value.length);
        } else {
          var len = target2.value.length;
          target2.setSelectionRange(len, len);
          this.focusedOptionIndex = -1;
        }
      } else {
        var metaKey = event.metaKey || event.ctrlKey;
        var optionIndex = this.findLastOptionIndex();
        if (event.shiftKey && metaKey) {
          this.onOptionSelectRange(event, this.startRangeIndex, optionIndex);
        }
        this.changeFocusedOptionIndex(event, optionIndex);
        !this.overlayVisible && this.show();
      }
      event.preventDefault();
    }, "onEndKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey5(event) {
      this.scrollInView(0);
      event.preventDefault();
    }, "onPageUpKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey5(event) {
      this.scrollInView(this.visibleOptions.length - 1);
      event.preventDefault();
    }, "onPageDownKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey4(event) {
      if (!this.overlayVisible) {
        this.focusedOptionIndex = -1;
        this.onArrowDownKey(event);
      } else {
        if (this.focusedOptionIndex !== -1) {
          if (event.shiftKey) this.onOptionSelectRange(event, this.focusedOptionIndex);
          else this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
        }
      }
      event.preventDefault();
    }, "onEnterKey"),
    onEscapeKey: /* @__PURE__ */ __name(function onEscapeKey2(event) {
      this.overlayVisible && this.hide(true);
      event.preventDefault();
    }, "onEscapeKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey2(event) {
      var pressedInInputText = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      if (!pressedInInputText) {
        if (this.overlayVisible && this.hasFocusableElements()) {
          focus$2(event.shiftKey ? this.$refs.lastHiddenFocusableElementOnOverlay : this.$refs.firstHiddenFocusableElementOnOverlay);
          event.preventDefault();
        } else {
          if (this.focusedOptionIndex !== -1) {
            this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
          }
          this.overlayVisible && this.hide(this.filter);
        }
      }
    }, "onTabKey"),
    onShiftKey: /* @__PURE__ */ __name(function onShiftKey2() {
      this.startRangeIndex = this.focusedOptionIndex;
    }, "onShiftKey"),
    onOverlayEnter: /* @__PURE__ */ __name(function onOverlayEnter3(el) {
      ZIndex$1.set("overlay", el, this.$primevue.config.zIndex.overlay);
      addStyle$1(el, {
        position: "absolute",
        top: "0",
        left: "0"
      });
      this.alignOverlay();
      this.scrollInView();
      this.autoFilterFocus && focus$2(this.$refs.filterInput.$el);
    }, "onOverlayEnter"),
    onOverlayAfterEnter: /* @__PURE__ */ __name(function onOverlayAfterEnter2() {
      this.bindOutsideClickListener();
      this.bindScrollListener();
      this.bindResizeListener();
      this.$emit("show");
    }, "onOverlayAfterEnter"),
    onOverlayLeave: /* @__PURE__ */ __name(function onOverlayLeave3() {
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
      this.$emit("hide");
      this.overlay = null;
    }, "onOverlayLeave"),
    onOverlayAfterLeave: /* @__PURE__ */ __name(function onOverlayAfterLeave3(el) {
      ZIndex$1.clear(el);
    }, "onOverlayAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay5() {
      if (this.appendTo === "self") {
        relativePosition$1(this.overlay, this.$el);
      } else {
        this.overlay.style.minWidth = getOuterWidth$1(this.$el) + "px";
        absolutePosition$1(this.overlay, this.$el);
      }
    }, "alignOverlay"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener4() {
      var _this6 = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          if (_this6.overlayVisible && _this6.isOutsideClicked(event)) {
            _this6.hide();
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener4() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener5() {
      var _this7 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.$refs.container, function() {
          if (_this7.overlayVisible) {
            _this7.hide();
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener5() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener5() {
      var _this8 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this8.overlayVisible && !isTouchDevice$1()) {
            _this8.hide();
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener5() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    isOutsideClicked: /* @__PURE__ */ __name(function isOutsideClicked(event) {
      return !(this.$el.isSameNode(event.target) || this.$el.contains(event.target) || this.overlay && this.overlay.contains(event.target));
    }, "isOutsideClicked"),
    getLabelByValue: /* @__PURE__ */ __name(function getLabelByValue(value3) {
      var _this9 = this;
      var options5 = this.optionGroupLabel ? this.flatOptions(this.options) : this.options || [];
      var matchedOption = options5.find(function(option5) {
        return !_this9.isOptionGroup(option5) && equals$2(_this9.getOptionValue(option5), value3, _this9.equalityKey);
      });
      return matchedOption ? this.getOptionLabel(matchedOption) : null;
    }, "getLabelByValue"),
    getSelectedItemsLabel: /* @__PURE__ */ __name(function getSelectedItemsLabel() {
      var pattern = /{(.*?)}/;
      var selectedItemsLabel = this.selectedItemsLabel || this.$primevue.config.locale.selectionMessage;
      if (pattern.test(selectedItemsLabel)) {
        return selectedItemsLabel.replace(selectedItemsLabel.match(pattern)[0], this.d_value.length + "");
      }
      return selectedItemsLabel;
    }, "getSelectedItemsLabel"),
    onToggleAll: /* @__PURE__ */ __name(function onToggleAll(event) {
      var _this10 = this;
      if (this.selectAll !== null) {
        this.$emit("selectall-change", {
          originalEvent: event,
          checked: !this.allSelected
        });
      } else {
        var value3 = this.allSelected ? [] : this.visibleOptions.filter(function(option5) {
          return _this10.isValidOption(option5);
        }).map(function(option5) {
          return _this10.getOptionValue(option5);
        });
        this.updateModel(event, value3);
      }
    }, "onToggleAll"),
    removeOption: /* @__PURE__ */ __name(function removeOption2(event, optionValue) {
      var _this11 = this;
      event.stopPropagation();
      var value3 = this.d_value.filter(function(val) {
        return !equals$2(val, optionValue, _this11.equalityKey);
      });
      this.updateModel(event, value3);
    }, "removeOption"),
    clearFilter: /* @__PURE__ */ __name(function clearFilter() {
      this.filterValue = null;
    }, "clearFilter"),
    hasFocusableElements: /* @__PURE__ */ __name(function hasFocusableElements2() {
      return getFocusableElements$1(this.overlay, ':not([data-p-hidden-focusable="true"])').length > 0;
    }, "hasFocusableElements"),
    isOptionMatched: /* @__PURE__ */ __name(function isOptionMatched3(option5) {
      var _this$getOptionLabel;
      return this.isValidOption(option5) && typeof this.getOptionLabel(option5) === "string" && ((_this$getOptionLabel = this.getOptionLabel(option5)) === null || _this$getOptionLabel === void 0 ? void 0 : _this$getOptionLabel.toLocaleLowerCase(this.filterLocale).startsWith(this.searchValue.toLocaleLowerCase(this.filterLocale)));
    }, "isOptionMatched"),
    isValidOption: /* @__PURE__ */ __name(function isValidOption3(option5) {
      return isNotEmpty$2(option5) && !(this.isOptionDisabled(option5) || this.isOptionGroup(option5));
    }, "isValidOption"),
    isValidSelectedOption: /* @__PURE__ */ __name(function isValidSelectedOption3(option5) {
      return this.isValidOption(option5) && this.isSelected(option5);
    }, "isValidSelectedOption"),
    isEquals: /* @__PURE__ */ __name(function isEquals2(value1, value22) {
      return equals$2(value1, value22, this.equalityKey);
    }, "isEquals"),
    isSelected: /* @__PURE__ */ __name(function isSelected3(option5) {
      var _this12 = this;
      var optionValue = this.getOptionValue(option5);
      return (this.d_value || []).some(function(value3) {
        return _this12.isEquals(value3, optionValue);
      });
    }, "isSelected"),
    findFirstOptionIndex: /* @__PURE__ */ __name(function findFirstOptionIndex3() {
      var _this13 = this;
      return this.visibleOptions.findIndex(function(option5) {
        return _this13.isValidOption(option5);
      });
    }, "findFirstOptionIndex"),
    findLastOptionIndex: /* @__PURE__ */ __name(function findLastOptionIndex3() {
      var _this14 = this;
      return findLastIndex$2(this.visibleOptions, function(option5) {
        return _this14.isValidOption(option5);
      });
    }, "findLastOptionIndex"),
    findNextOptionIndex: /* @__PURE__ */ __name(function findNextOptionIndex3(index2) {
      var _this15 = this;
      var matchedOptionIndex = index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this15.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : index2;
    }, "findNextOptionIndex"),
    findPrevOptionIndex: /* @__PURE__ */ __name(function findPrevOptionIndex3(index2) {
      var _this16 = this;
      var matchedOptionIndex = index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this16.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findPrevOptionIndex"),
    findSelectedOptionIndex: /* @__PURE__ */ __name(function findSelectedOptionIndex3() {
      var _this17 = this;
      if (this.$filled) {
        var _loop = /* @__PURE__ */ __name(function _loop2() {
          var value3 = _this17.d_value[index2];
          var matchedOptionIndex = _this17.visibleOptions.findIndex(function(option5) {
            return _this17.isValidSelectedOption(option5) && _this17.isEquals(value3, _this17.getOptionValue(option5));
          });
          if (matchedOptionIndex > -1) return {
            v: matchedOptionIndex
          };
        }, "_loop"), _ret;
        for (var index2 = this.d_value.length - 1; index2 >= 0; index2--) {
          _ret = _loop();
          if (_ret) return _ret.v;
        }
      }
      return -1;
    }, "findSelectedOptionIndex"),
    findFirstSelectedOptionIndex: /* @__PURE__ */ __name(function findFirstSelectedOptionIndex2() {
      var _this18 = this;
      return this.$filled ? this.visibleOptions.findIndex(function(option5) {
        return _this18.isValidSelectedOption(option5);
      }) : -1;
    }, "findFirstSelectedOptionIndex"),
    findLastSelectedOptionIndex: /* @__PURE__ */ __name(function findLastSelectedOptionIndex2() {
      var _this19 = this;
      return this.$filled ? findLastIndex$2(this.visibleOptions, function(option5) {
        return _this19.isValidSelectedOption(option5);
      }) : -1;
    }, "findLastSelectedOptionIndex"),
    findNextSelectedOptionIndex: /* @__PURE__ */ __name(function findNextSelectedOptionIndex2(index2) {
      var _this20 = this;
      var matchedOptionIndex = this.$filled && index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this20.isValidSelectedOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : -1;
    }, "findNextSelectedOptionIndex"),
    findPrevSelectedOptionIndex: /* @__PURE__ */ __name(function findPrevSelectedOptionIndex2(index2) {
      var _this21 = this;
      var matchedOptionIndex = this.$filled && index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this21.isValidSelectedOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : -1;
    }, "findPrevSelectedOptionIndex"),
    findNearestSelectedOptionIndex: /* @__PURE__ */ __name(function findNearestSelectedOptionIndex2(index2) {
      var firstCheckUp = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : false;
      var matchedOptionIndex = -1;
      if (this.$filled) {
        if (firstCheckUp) {
          matchedOptionIndex = this.findPrevSelectedOptionIndex(index2);
          matchedOptionIndex = matchedOptionIndex === -1 ? this.findNextSelectedOptionIndex(index2) : matchedOptionIndex;
        } else {
          matchedOptionIndex = this.findNextSelectedOptionIndex(index2);
          matchedOptionIndex = matchedOptionIndex === -1 ? this.findPrevSelectedOptionIndex(index2) : matchedOptionIndex;
        }
      }
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findNearestSelectedOptionIndex"),
    findFirstFocusedOptionIndex: /* @__PURE__ */ __name(function findFirstFocusedOptionIndex3() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findFirstOptionIndex() : selectedIndex;
    }, "findFirstFocusedOptionIndex"),
    findLastFocusedOptionIndex: /* @__PURE__ */ __name(function findLastFocusedOptionIndex3() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findLastOptionIndex() : selectedIndex;
    }, "findLastFocusedOptionIndex"),
    searchOptions: /* @__PURE__ */ __name(function searchOptions3(event) {
      var _this22 = this;
      this.searchValue = (this.searchValue || "") + event.key;
      var optionIndex = -1;
      if (isNotEmpty$2(this.searchValue)) {
        if (this.focusedOptionIndex !== -1) {
          optionIndex = this.visibleOptions.slice(this.focusedOptionIndex).findIndex(function(option5) {
            return _this22.isOptionMatched(option5);
          });
          optionIndex = optionIndex === -1 ? this.visibleOptions.slice(0, this.focusedOptionIndex).findIndex(function(option5) {
            return _this22.isOptionMatched(option5);
          }) : optionIndex + this.focusedOptionIndex;
        } else {
          optionIndex = this.visibleOptions.findIndex(function(option5) {
            return _this22.isOptionMatched(option5);
          });
        }
        if (optionIndex === -1 && this.focusedOptionIndex === -1) {
          optionIndex = this.findFirstFocusedOptionIndex();
        }
        if (optionIndex !== -1) {
          this.changeFocusedOptionIndex(event, optionIndex);
        }
      }
      if (this.searchTimeout) {
        clearTimeout(this.searchTimeout);
      }
      this.searchTimeout = setTimeout(function() {
        _this22.searchValue = "";
        _this22.searchTimeout = null;
      }, 500);
    }, "searchOptions"),
    changeFocusedOptionIndex: /* @__PURE__ */ __name(function changeFocusedOptionIndex3(event, index2) {
      if (this.focusedOptionIndex !== index2) {
        this.focusedOptionIndex = index2;
        this.scrollInView();
        if (this.selectOnFocus) {
          this.onOptionSelect(event, this.visibleOptions[index2]);
        }
      }
    }, "changeFocusedOptionIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView7() {
      var _this23 = this;
      var index2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : -1;
      this.$nextTick(function() {
        var id4 = index2 !== -1 ? "".concat(_this23.id, "_").concat(index2) : _this23.focusedOptionId;
        var element = findSingle$1(_this23.list, 'li[id="'.concat(id4, '"]'));
        if (element) {
          element.scrollIntoView && element.scrollIntoView({
            block: "nearest",
            inline: "nearest"
          });
        } else if (!_this23.virtualScrollerDisabled) {
          _this23.virtualScroller && _this23.virtualScroller.scrollToIndex(index2 !== -1 ? index2 : _this23.focusedOptionIndex);
        }
      });
    }, "scrollInView"),
    autoUpdateModel: /* @__PURE__ */ __name(function autoUpdateModel3() {
      if (this.selectOnFocus && this.autoOptionFocus && !this.$filled) {
        this.focusedOptionIndex = this.findFirstFocusedOptionIndex();
        var value3 = this.getOptionValue(this.visibleOptions[this.focusedOptionIndex]);
        this.updateModel(null, [value3]);
      }
    }, "autoUpdateModel"),
    updateModel: /* @__PURE__ */ __name(function updateModel7(event, value3) {
      this.writeValue(value3, event);
      this.$emit("change", {
        originalEvent: event,
        value: value3
      });
    }, "updateModel"),
    flatOptions: /* @__PURE__ */ __name(function flatOptions2(options5) {
      var _this24 = this;
      return (options5 || []).reduce(function(result, option5, index2) {
        result.push({
          optionGroup: option5,
          group: true,
          index: index2
        });
        var optionGroupChildren = _this24.getOptionGroupChildren(option5);
        optionGroupChildren && optionGroupChildren.forEach(function(o2) {
          return result.push(o2);
        });
        return result;
      }, []);
    }, "flatOptions"),
    overlayRef: /* @__PURE__ */ __name(function overlayRef2(el) {
      this.overlay = el;
    }, "overlayRef"),
    listRef: /* @__PURE__ */ __name(function listRef3(el, contentRef3) {
      this.list = el;
      contentRef3 && contentRef3(el);
    }, "listRef"),
    virtualScrollerRef: /* @__PURE__ */ __name(function virtualScrollerRef3(el) {
      this.virtualScroller = el;
    }, "virtualScrollerRef")
  },
  computed: {
    visibleOptions: /* @__PURE__ */ __name(function visibleOptions3() {
      var _this25 = this;
      var options5 = this.optionGroupLabel ? this.flatOptions(this.options) : this.options || [];
      if (this.filterValue) {
        var filteredOptions = FilterService.filter(options5, this.searchFields, this.filterValue, this.filterMatchMode, this.filterLocale);
        if (this.optionGroupLabel) {
          var optionGroups = this.options || [];
          var filtered = [];
          optionGroups.forEach(function(group) {
            var groupChildren = _this25.getOptionGroupChildren(group);
            var filteredItems = groupChildren.filter(function(item3) {
              return filteredOptions.includes(item3);
            });
            if (filteredItems.length > 0) filtered.push(_objectSpread$8(_objectSpread$8({}, group), {}, _defineProperty$1$2({}, typeof _this25.optionGroupChildren === "string" ? _this25.optionGroupChildren : "items", _toConsumableArray$6(filteredItems))));
          });
          return this.flatOptions(filtered);
        }
        return filteredOptions;
      }
      return options5;
    }, "visibleOptions"),
    label: /* @__PURE__ */ __name(function label4() {
      var label8;
      if (this.d_value && this.d_value.length) {
        if (isNotEmpty$2(this.maxSelectedLabels) && this.d_value.length > this.maxSelectedLabels) {
          return this.getSelectedItemsLabel();
        } else {
          label8 = "";
          for (var i2 = 0; i2 < this.d_value.length; i2++) {
            if (i2 !== 0) {
              label8 += ", ";
            }
            label8 += this.getLabelByValue(this.d_value[i2]);
          }
        }
      } else {
        label8 = this.placeholder;
      }
      return label8;
    }, "label"),
    chipSelectedItems: /* @__PURE__ */ __name(function chipSelectedItems() {
      return isNotEmpty$2(this.maxSelectedLabels) && this.d_value && this.d_value.length > this.maxSelectedLabels;
    }, "chipSelectedItems"),
    allSelected: /* @__PURE__ */ __name(function allSelected() {
      var _this26 = this;
      return this.selectAll !== null ? this.selectAll : isNotEmpty$2(this.visibleOptions) && this.visibleOptions.every(function(option5) {
        return _this26.isOptionGroup(option5) || _this26.isOptionDisabled(option5) || _this26.isSelected(option5);
      });
    }, "allSelected"),
    // @deprecated use $filled instead.
    hasSelectedOption: /* @__PURE__ */ __name(function hasSelectedOption3() {
      return this.$filled;
    }, "hasSelectedOption"),
    equalityKey: /* @__PURE__ */ __name(function equalityKey3() {
      return this.optionValue ? null : this.dataKey;
    }, "equalityKey"),
    searchFields: /* @__PURE__ */ __name(function searchFields3() {
      return this.filterFields || [this.optionLabel];
    }, "searchFields"),
    maxSelectionLimitReached: /* @__PURE__ */ __name(function maxSelectionLimitReached() {
      return this.selectionLimit && this.d_value && this.d_value.length === this.selectionLimit;
    }, "maxSelectionLimitReached"),
    filterResultMessageText: /* @__PURE__ */ __name(function filterResultMessageText3() {
      return isNotEmpty$2(this.visibleOptions) ? this.filterMessageText.replaceAll("{0}", this.visibleOptions.length) : this.emptyFilterMessageText;
    }, "filterResultMessageText"),
    filterMessageText: /* @__PURE__ */ __name(function filterMessageText3() {
      return this.filterMessage || this.$primevue.config.locale.searchMessage || "";
    }, "filterMessageText"),
    emptyFilterMessageText: /* @__PURE__ */ __name(function emptyFilterMessageText3() {
      return this.emptyFilterMessage || this.$primevue.config.locale.emptySearchMessage || this.$primevue.config.locale.emptyFilterMessage || "";
    }, "emptyFilterMessageText"),
    emptyMessageText: /* @__PURE__ */ __name(function emptyMessageText3() {
      return this.emptyMessage || this.$primevue.config.locale.emptyMessage || "";
    }, "emptyMessageText"),
    selectionMessageText: /* @__PURE__ */ __name(function selectionMessageText3() {
      return this.selectionMessage || this.$primevue.config.locale.selectionMessage || "";
    }, "selectionMessageText"),
    emptySelectionMessageText: /* @__PURE__ */ __name(function emptySelectionMessageText3() {
      return this.emptySelectionMessage || this.$primevue.config.locale.emptySelectionMessage || "";
    }, "emptySelectionMessageText"),
    selectedMessageText: /* @__PURE__ */ __name(function selectedMessageText3() {
      return this.$filled ? this.selectionMessageText.replaceAll("{0}", this.d_value.length) : this.emptySelectionMessageText;
    }, "selectedMessageText"),
    focusedOptionId: /* @__PURE__ */ __name(function focusedOptionId3() {
      return this.focusedOptionIndex !== -1 ? "".concat(this.id, "_").concat(this.focusedOptionIndex) : null;
    }, "focusedOptionId"),
    ariaSetSize: /* @__PURE__ */ __name(function ariaSetSize3() {
      var _this27 = this;
      return this.visibleOptions.filter(function(option5) {
        return !_this27.isOptionGroup(option5);
      }).length;
    }, "ariaSetSize"),
    toggleAllAriaLabel: /* @__PURE__ */ __name(function toggleAllAriaLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria[this.allSelected ? "selectAll" : "unselectAll"] : void 0;
    }, "toggleAllAriaLabel"),
    listAriaLabel: /* @__PURE__ */ __name(function listAriaLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.listLabel : void 0;
    }, "listAriaLabel"),
    virtualScrollerDisabled: /* @__PURE__ */ __name(function virtualScrollerDisabled3() {
      return !this.virtualScrollerOptions;
    }, "virtualScrollerDisabled"),
    hasFluid: /* @__PURE__ */ __name(function hasFluid3() {
      return isEmpty$3(this.fluid) ? !!this.$pcFluid : this.fluid;
    }, "hasFluid"),
    isClearIconVisible: /* @__PURE__ */ __name(function isClearIconVisible2() {
      return this.showClear && this.d_value != null && isNotEmpty$2(this.options);
    }, "isClearIconVisible")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    InputText: script$P,
    Checkbox: script$Q,
    VirtualScroller: script$H,
    Portal: script$$,
    Chip: script$A,
    IconField: script$J,
    InputIcon: script$I,
    TimesIcon: script$15,
    SearchIcon: script$K,
    ChevronDownIcon: script$u,
    SpinnerIcon: script$12,
    CheckIcon: script$S
  }
};
function _typeof$6(o2) {
  "@babel/helpers - typeof";
  return _typeof$6 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$6(o2);
}
__name(_typeof$6, "_typeof$6");
function _defineProperty$6(e2, r2, t2) {
  return (r2 = _toPropertyKey$5(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$6, "_defineProperty$6");
function _toPropertyKey$5(t2) {
  var i2 = _toPrimitive$5(t2, "string");
  return "symbol" == _typeof$6(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$5, "_toPropertyKey$5");
function _toPrimitive$5(t2, r2) {
  if ("object" != _typeof$6(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$6(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$5, "_toPrimitive$5");
var _hoisted_1$T = ["id", "disabled", "placeholder", "tabindex", "aria-label", "aria-labelledby", "aria-expanded", "aria-controls", "aria-activedescendant", "aria-invalid"];
var _hoisted_2$J = {
  key: 0
};
var _hoisted_3$t = ["id", "aria-label"];
var _hoisted_4$j = ["id"];
var _hoisted_5$h = ["id", "aria-label", "aria-selected", "aria-disabled", "aria-setsize", "aria-posinset", "onClick", "onMousemove", "data-p-selected", "data-p-focused", "data-p-disabled"];
function render$g(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Chip = resolveComponent("Chip");
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_Checkbox = resolveComponent("Checkbox");
  var _component_InputText = resolveComponent("InputText");
  var _component_SearchIcon = resolveComponent("SearchIcon");
  var _component_InputIcon = resolveComponent("InputIcon");
  var _component_IconField = resolveComponent("IconField");
  var _component_VirtualScroller = resolveComponent("VirtualScroller");
  var _component_Portal = resolveComponent("Portal");
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "container",
    "class": _ctx.cx("root"),
    style: _ctx.sx("root"),
    onClick: _cache[7] || (_cache[7] = function() {
      return $options.onContainerClick && $options.onContainerClick.apply($options, arguments);
    })
  }, _ctx.ptmi("root")), [createBaseVNode("div", mergeProps$2({
    "class": "p-hidden-accessible"
  }, _ctx.ptm("hiddenInputContainer"), {
    "data-p-hidden-accessible": true
  }), [createBaseVNode("input", mergeProps$2({
    ref: "focusInput",
    id: _ctx.inputId,
    type: "text",
    readonly: "",
    disabled: _ctx.disabled,
    placeholder: _ctx.placeholder,
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    role: "combobox",
    "aria-label": _ctx.ariaLabel,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-haspopup": "listbox",
    "aria-expanded": $data.overlayVisible,
    "aria-controls": $data.id + "_list",
    "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
    "aria-invalid": _ctx.invalid || void 0,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onKeydown: _cache[2] || (_cache[2] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    })
  }, _ctx.ptm("hiddenInput")), null, 16, _hoisted_1$T)], 16), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("labelContainer")
  }, _ctx.ptm("labelContainer")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("label")
  }, _ctx.ptm("label")), [renderSlot(_ctx.$slots, "value", {
    value: _ctx.d_value,
    placeholder: _ctx.placeholder
  }, function() {
    return [_ctx.display === "comma" ? (openBlock(), createElementBlock(Fragment$1, {
      key: 0
    }, [createTextVNode(toDisplayString$1($options.label || "empty"), 1)], 64)) : _ctx.display === "chip" ? (openBlock(), createElementBlock(Fragment$1, {
      key: 1
    }, [$options.chipSelectedItems ? (openBlock(), createElementBlock("span", _hoisted_2$J, toDisplayString$1($options.label), 1)) : (openBlock(true), createElementBlock(Fragment$1, {
      key: 1
    }, renderList(_ctx.d_value, function(item3) {
      return openBlock(), createElementBlock("span", mergeProps$2({
        key: $options.getLabelByValue(item3),
        "class": _ctx.cx("chipItem"),
        ref_for: true
      }, _ctx.ptm("chipItem")), [renderSlot(_ctx.$slots, "chip", {
        value: item3,
        removeCallback: /* @__PURE__ */ __name(function removeCallback(event) {
          return $options.removeOption(event, item3);
        }, "removeCallback")
      }, function() {
        return [createVNode(_component_Chip, {
          "class": normalizeClass(_ctx.cx("pcChip")),
          label: $options.getLabelByValue(item3),
          removeIcon: _ctx.chipIcon || _ctx.removeTokenIcon,
          removable: "",
          unstyled: _ctx.unstyled,
          onRemove: /* @__PURE__ */ __name(function onRemove($event) {
            return $options.removeOption($event, item3);
          }, "onRemove"),
          pt: _ctx.ptm("pcChip")
        }, {
          removeicon: withCtx(function() {
            return [renderSlot(_ctx.$slots, _ctx.$slots.chipicon ? "chipicon" : "removetokenicon", {
              "class": normalizeClass(_ctx.cx("chipIcon")),
              item: item3,
              removeCallback: /* @__PURE__ */ __name(function removeCallback(event) {
                return $options.removeOption(event, item3);
              }, "removeCallback")
            })];
          }),
          _: 2
        }, 1032, ["class", "label", "removeIcon", "unstyled", "onRemove", "pt"])];
      })], 16);
    }), 128)), !_ctx.d_value || _ctx.d_value.length === 0 ? (openBlock(), createElementBlock(Fragment$1, {
      key: 2
    }, [createTextVNode(toDisplayString$1(_ctx.placeholder || "empty"), 1)], 64)) : createCommentVNode("", true)], 64)) : createCommentVNode("", true)];
  })], 16)], 16), $options.isClearIconVisible ? renderSlot(_ctx.$slots, "clearicon", {
    key: 0,
    "class": normalizeClass(_ctx.cx("clearIcon")),
    clearCallback: $options.onClearClick
  }, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.clearIcon ? "i" : "TimesIcon"), mergeProps$2({
      ref: "clearIcon",
      "class": [_ctx.cx("clearIcon"), _ctx.clearIcon],
      onClick: $options.onClearClick
    }, _ctx.ptm("clearIcon"), {
      "data-pc-section": "clearicon"
    }), null, 16, ["class", "onClick"]))];
  }) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("dropdown")
  }, _ctx.ptm("dropdown")), [_ctx.loading ? renderSlot(_ctx.$slots, "loadingicon", {
    key: 0,
    "class": normalizeClass(_ctx.cx("loadingIcon"))
  }, function() {
    return [_ctx.loadingIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 0,
      "class": [_ctx.cx("loadingIcon"), "pi-spin", _ctx.loadingIcon],
      "aria-hidden": "true"
    }, _ctx.ptm("loadingIcon")), null, 16)) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
      key: 1,
      "class": _ctx.cx("loadingIcon"),
      spin: "",
      "aria-hidden": "true"
    }, _ctx.ptm("loadingIcon")), null, 16, ["class"]))];
  }) : renderSlot(_ctx.$slots, "dropdownicon", {
    key: 1,
    "class": normalizeClass(_ctx.cx("dropdownIcon"))
  }, function() {
    return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.dropdownIcon ? "span" : "ChevronDownIcon"), mergeProps$2({
      "class": [_ctx.cx("dropdownIcon"), _ctx.dropdownIcon],
      "aria-hidden": "true"
    }, _ctx.ptm("dropdownIcon")), null, 16, ["class"]))];
  })], 16), createVNode(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-connected-overlay",
        onEnter: $options.onOverlayEnter,
        onAfterEnter: $options.onOverlayAfterEnter,
        onLeave: $options.onOverlayLeave,
        onAfterLeave: $options.onOverlayAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [$data.overlayVisible ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.overlayRef,
            style: [_ctx.panelStyle, _ctx.overlayStyle],
            "class": [_ctx.cx("overlay"), _ctx.panelClass, _ctx.overlayClass],
            onClick: _cache[5] || (_cache[5] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            }),
            onKeydown: _cache[6] || (_cache[6] = function() {
              return $options.onOverlayKeyDown && $options.onOverlayKeyDown.apply($options, arguments);
            })
          }, _ctx.ptm("overlay")), [createBaseVNode("span", mergeProps$2({
            ref: "firstHiddenFocusableElementOnOverlay",
            role: "presentation",
            "aria-hidden": "true",
            "class": "p-hidden-accessible p-hidden-focusable",
            tabindex: 0,
            onFocus: _cache[3] || (_cache[3] = function() {
              return $options.onFirstHiddenFocus && $options.onFirstHiddenFocus.apply($options, arguments);
            })
          }, _ctx.ptm("hiddenFirstFocusableEl"), {
            "data-p-hidden-accessible": true,
            "data-p-hidden-focusable": true
          }), null, 16), renderSlot(_ctx.$slots, "header", {
            value: _ctx.d_value,
            options: $options.visibleOptions
          }), _ctx.showToggleAll && _ctx.selectionLimit == null || _ctx.filter ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            "class": _ctx.cx("header")
          }, _ctx.ptm("header")), [_ctx.showToggleAll && _ctx.selectionLimit == null ? (openBlock(), createBlock(_component_Checkbox, {
            key: 0,
            modelValue: $options.allSelected,
            binary: true,
            disabled: _ctx.disabled,
            variant: _ctx.variant,
            "aria-label": $options.toggleAllAriaLabel,
            onChange: $options.onToggleAll,
            unstyled: _ctx.unstyled,
            pt: $options.getHeaderCheckboxPTOptions("pcHeaderCheckbox")
          }, {
            icon: withCtx(function(slotProps) {
              return [_ctx.$slots.headercheckboxicon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.headercheckboxicon), {
                key: 0,
                checked: slotProps.checked,
                "class": normalizeClass(slotProps["class"])
              }, null, 8, ["checked", "class"])) : slotProps.checked ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.checkboxIcon ? "span" : "CheckIcon"), mergeProps$2({
                key: 1,
                "class": [slotProps["class"], _defineProperty$6({}, _ctx.checkboxIcon, slotProps.checked)]
              }, $options.getHeaderCheckboxPTOptions("pcHeaderCheckbox.icon")), null, 16, ["class"])) : createCommentVNode("", true)];
            }),
            _: 1
          }, 8, ["modelValue", "disabled", "variant", "aria-label", "onChange", "unstyled", "pt"])) : createCommentVNode("", true), _ctx.filter ? (openBlock(), createBlock(_component_IconField, {
            key: 1,
            "class": normalizeClass(_ctx.cx("pcFilterContainer")),
            unstyled: _ctx.unstyled,
            pt: _ctx.ptm("pcFilterContainer")
          }, {
            "default": withCtx(function() {
              return [createVNode(_component_InputText, {
                ref: "filterInput",
                value: $data.filterValue,
                onVnodeMounted: $options.onFilterUpdated,
                onVnodeUpdated: $options.onFilterUpdated,
                "class": normalizeClass(_ctx.cx("pcFilter")),
                placeholder: _ctx.filterPlaceholder,
                disabled: _ctx.disabled,
                variant: _ctx.variant,
                unstyled: _ctx.unstyled,
                role: "searchbox",
                autocomplete: "off",
                "aria-owns": $data.id + "_list",
                "aria-activedescendant": $options.focusedOptionId,
                onKeydown: $options.onFilterKeyDown,
                onBlur: $options.onFilterBlur,
                onInput: $options.onFilterChange,
                pt: _ctx.ptm("pcFilter")
              }, null, 8, ["value", "onVnodeMounted", "onVnodeUpdated", "class", "placeholder", "disabled", "variant", "unstyled", "aria-owns", "aria-activedescendant", "onKeydown", "onBlur", "onInput", "pt"]), createVNode(_component_InputIcon, {
                unstyled: _ctx.unstyled,
                pt: _ctx.ptm("pcFilterIconContainer")
              }, {
                "default": withCtx(function() {
                  return [renderSlot(_ctx.$slots, "filtericon", {}, function() {
                    return [_ctx.filterIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
                      key: 0,
                      "class": _ctx.filterIcon
                    }, _ctx.ptm("filterIcon")), null, 16)) : (openBlock(), createBlock(_component_SearchIcon, normalizeProps(mergeProps$2({
                      key: 1
                    }, _ctx.ptm("filterIcon"))), null, 16))];
                  })];
                }),
                _: 3
              }, 8, ["unstyled", "pt"])];
            }),
            _: 3
          }, 8, ["class", "unstyled", "pt"])) : createCommentVNode("", true), _ctx.filter ? (openBlock(), createElementBlock("span", mergeProps$2({
            key: 2,
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenFilterResult"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.filterResultMessageText), 17)) : createCommentVNode("", true)], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("listContainer"),
            style: {
              "max-height": $options.virtualScrollerDisabled ? _ctx.scrollHeight : ""
            }
          }, _ctx.ptm("listContainer")), [createVNode(_component_VirtualScroller, mergeProps$2({
            ref: $options.virtualScrollerRef
          }, _ctx.virtualScrollerOptions, {
            items: $options.visibleOptions,
            style: {
              height: _ctx.scrollHeight
            },
            tabindex: -1,
            disabled: $options.virtualScrollerDisabled,
            pt: _ctx.ptm("virtualScroller")
          }), createSlots({
            content: withCtx(function(_ref2) {
              var styleClass = _ref2.styleClass, contentRef3 = _ref2.contentRef, items2 = _ref2.items, getItemOptions = _ref2.getItemOptions, contentStyle = _ref2.contentStyle, itemSize2 = _ref2.itemSize;
              return [createBaseVNode("ul", mergeProps$2({
                ref: /* @__PURE__ */ __name(function ref2(el) {
                  return $options.listRef(el, contentRef3);
                }, "ref"),
                id: $data.id + "_list",
                "class": [_ctx.cx("list"), styleClass],
                style: contentStyle,
                role: "listbox",
                "aria-multiselectable": "true",
                "aria-label": $options.listAriaLabel
              }, _ctx.ptm("list")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(items2, function(option5, i2) {
                return openBlock(), createElementBlock(Fragment$1, {
                  key: $options.getOptionRenderKey(option5, $options.getOptionIndex(i2, getItemOptions))
                }, [$options.isOptionGroup(option5) ? (openBlock(), createElementBlock("li", mergeProps$2({
                  key: 0,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  "class": _ctx.cx("optionGroup"),
                  role: "option",
                  ref_for: true
                }, _ctx.ptm("optionGroup")), [renderSlot(_ctx.$slots, "optiongroup", {
                  option: option5.optionGroup,
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createTextVNode(toDisplayString$1($options.getOptionGroupLabel(option5.optionGroup)), 1)];
                })], 16, _hoisted_4$j)) : withDirectives((openBlock(), createElementBlock("li", mergeProps$2({
                  key: 1,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  "class": _ctx.cx("option", {
                    option: option5,
                    index: i2,
                    getItemOptions
                  }),
                  role: "option",
                  "aria-label": $options.getOptionLabel(option5),
                  "aria-selected": $options.isSelected(option5),
                  "aria-disabled": $options.isOptionDisabled(option5),
                  "aria-setsize": $options.ariaSetSize,
                  "aria-posinset": $options.getAriaPosInset($options.getOptionIndex(i2, getItemOptions)),
                  onClick: /* @__PURE__ */ __name(function onClick5($event) {
                    return $options.onOptionSelect($event, option5, $options.getOptionIndex(i2, getItemOptions), true);
                  }, "onClick"),
                  onMousemove: /* @__PURE__ */ __name(function onMousemove($event) {
                    return $options.onOptionMouseMove($event, $options.getOptionIndex(i2, getItemOptions));
                  }, "onMousemove"),
                  ref_for: true
                }, $options.getCheckboxPTOptions(option5, getItemOptions, i2, "option"), {
                  "data-p-selected": $options.isSelected(option5),
                  "data-p-focused": $data.focusedOptionIndex === $options.getOptionIndex(i2, getItemOptions),
                  "data-p-disabled": $options.isOptionDisabled(option5)
                }), [createVNode(_component_Checkbox, {
                  defaultValue: $options.isSelected(option5),
                  binary: true,
                  tabindex: -1,
                  variant: _ctx.variant,
                  unstyled: _ctx.unstyled,
                  pt: $options.getCheckboxPTOptions(option5, getItemOptions, i2, "pcOptionCheckbox")
                }, {
                  icon: withCtx(function(slotProps) {
                    return [_ctx.$slots.optioncheckboxicon || _ctx.$slots.itemcheckboxicon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.optioncheckboxicon || _ctx.$slots.itemcheckboxicon), {
                      key: 0,
                      checked: slotProps.checked,
                      "class": normalizeClass(slotProps["class"])
                    }, null, 8, ["checked", "class"])) : slotProps.checked ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.checkboxIcon ? "span" : "CheckIcon"), mergeProps$2({
                      key: 1,
                      "class": [slotProps["class"], _defineProperty$6({}, _ctx.checkboxIcon, slotProps.checked)],
                      ref_for: true
                    }, $options.getCheckboxPTOptions(option5, getItemOptions, i2, "pcOptionCheckbox.icon")), null, 16, ["class"])) : createCommentVNode("", true)];
                  }),
                  _: 2
                }, 1032, ["defaultValue", "variant", "unstyled", "pt"]), renderSlot(_ctx.$slots, "option", {
                  option: option5,
                  selected: $options.isSelected(option5),
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createBaseVNode("span", mergeProps$2({
                    ref_for: true
                  }, _ctx.ptm("optionLabel")), toDisplayString$1($options.getOptionLabel(option5)), 17)];
                })], 16, _hoisted_5$h)), [[_directive_ripple]])], 64);
              }), 128)), $data.filterValue && (!items2 || items2 && items2.length === 0) ? (openBlock(), createElementBlock("li", mergeProps$2({
                key: 0,
                "class": _ctx.cx("emptyMessage"),
                role: "option"
              }, _ctx.ptm("emptyMessage")), [renderSlot(_ctx.$slots, "emptyfilter", {}, function() {
                return [createTextVNode(toDisplayString$1($options.emptyFilterMessageText), 1)];
              })], 16)) : !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("li", mergeProps$2({
                key: 1,
                "class": _ctx.cx("emptyMessage"),
                role: "option"
              }, _ctx.ptm("emptyMessage")), [renderSlot(_ctx.$slots, "empty", {}, function() {
                return [createTextVNode(toDisplayString$1($options.emptyMessageText), 1)];
              })], 16)) : createCommentVNode("", true)], 16, _hoisted_3$t)];
            }),
            _: 2
          }, [_ctx.$slots.loader ? {
            name: "loader",
            fn: withCtx(function(_ref4) {
              var options5 = _ref4.options;
              return [renderSlot(_ctx.$slots, "loader", {
                options: options5
              })];
            }),
            key: "0"
          } : void 0]), 1040, ["items", "style", "disabled", "pt"])], 16), renderSlot(_ctx.$slots, "footer", {
            value: _ctx.d_value,
            options: $options.visibleOptions
          }), !_ctx.options || _ctx.options && _ctx.options.length === 0 ? (openBlock(), createElementBlock("span", mergeProps$2({
            key: 1,
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenEmptyMessage"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.emptyMessageText), 17)) : createCommentVNode("", true), createBaseVNode("span", mergeProps$2({
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenSelectedMessage"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.selectedMessageText), 17), createBaseVNode("span", mergeProps$2({
            ref: "lastHiddenFocusableElementOnOverlay",
            role: "presentation",
            "aria-hidden": "true",
            "class": "p-hidden-accessible p-hidden-focusable",
            tabindex: 0,
            onFocus: _cache[4] || (_cache[4] = function() {
              return $options.onLastHiddenFocus && $options.onLastHiddenFocus.apply($options, arguments);
            })
          }, _ctx.ptm("hiddenLastFocusableEl"), {
            "data-p-hidden-accessible": true,
            "data-p-hidden-focusable": true
          }), null, 16)], 16)) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onAfterEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 3
  }, 8, ["appendTo"])], 16);
}
__name(render$g, "render$g");
script$i.render = render$g;
const _sfc_main$V = /* @__PURE__ */ defineComponent({
  __name: "MultiSelectWidget",
  props: /* @__PURE__ */ mergeModels({
    widget: {}
  }, {
    "modelValue": { required: true },
    "modelModifiers": {}
  }),
  emits: ["update:modelValue"],
  setup(__props) {
    const selectedItems = useModel(__props, "modelValue");
    const inputSpec = __props.widget.inputSpec;
    const options5 = inputSpec.options ?? [];
    const placeholder = inputSpec.multi_select?.placeholder ?? "Select items";
    const display = inputSpec.multi_select?.chip ? "chip" : "comma";
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", null, [
        createVNode(unref(script$i), {
          modelValue: selectedItems.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedItems.value = $event),
          options: unref(options5),
          filter: "",
          placeholder: unref(placeholder),
          maxSelectedLabels: 3,
          display: unref(display),
          class: "w-full"
        }, null, 8, ["modelValue", "options", "placeholder", "display"])
      ]);
    };
  }
});
const useChainCallback = /* @__PURE__ */ __name((originalCallback, ...callbacks) => {
  return (...args) => {
    originalCallback?.(...args);
    callbacks.forEach((callback) => callback(...args));
  };
}, "useChainCallback");
const useDomWidgetStore = /* @__PURE__ */ defineStore("domWidget", () => {
  const widgetStates = ref(/* @__PURE__ */ new Map());
  const widgetInstances = ref(/* @__PURE__ */ new Map());
  const registerWidget = /* @__PURE__ */ __name((widget) => {
    widgetInstances.value.set(
      widget.id,
      markRaw(widget)
    );
    widgetStates.value.set(widget.id, {
      visible: true,
      readonly: false,
      zIndex: 0,
      pos: [0, 0],
      size: [0, 0]
    });
  }, "registerWidget");
  const unregisterWidget = /* @__PURE__ */ __name((widgetId) => {
    widgetInstances.value.delete(widgetId);
    widgetStates.value.delete(widgetId);
  }, "unregisterWidget");
  return {
    widgetStates,
    widgetInstances,
    registerWidget,
    unregisterWidget
  };
});
const isDOMWidget = /* @__PURE__ */ __name((widget) => "element" in widget && !!widget.element, "isDOMWidget");
const isComponentWidget = /* @__PURE__ */ __name((widget) => "component" in widget && !!widget.component, "isComponentWidget");
class BaseDOMWidgetImpl {
  static {
    __name(this, "BaseDOMWidgetImpl");
  }
  type;
  name;
  options;
  computedHeight;
  y = 0;
  callback;
  id;
  node;
  constructor(obj) {
    this.type = obj.type;
    this.name = obj.name;
    this.options = obj.options;
    this.id = obj.id;
    this.node = obj.node;
  }
  get value() {
    return this.options.getValue?.() ?? "";
  }
  set value(v2) {
    this.options.setValue?.(v2);
    this.callback?.(this.value);
  }
  isVisible() {
    return !_.isNil(this.computedHeight) && this.computedHeight > 0 && !["converted-widget", "hidden"].includes(this.type) && !this.node.collapsed;
  }
  draw() {
    this.options.onDraw?.(this);
  }
  onRemove() {
    useDomWidgetStore().unregisterWidget(this.id);
  }
}
class DOMWidgetImpl extends BaseDOMWidgetImpl {
  static {
    __name(this, "DOMWidgetImpl");
  }
  element;
  constructor(obj) {
    super(obj);
    this.element = obj.element;
  }
  /** Extract DOM widget size info */
  computeLayoutSize(node3) {
    if (this.type === "hidden") {
      return {
        minHeight: 0,
        maxHeight: 0,
        minWidth: 0
      };
    }
    const styles = getComputedStyle(this.element);
    let minHeight = this.options.getMinHeight?.() ?? parseInt(styles.getPropertyValue("--comfy-widget-min-height"));
    let maxHeight = this.options.getMaxHeight?.() ?? parseInt(styles.getPropertyValue("--comfy-widget-max-height"));
    let prefHeight = this.options.getHeight?.() ?? styles.getPropertyValue("--comfy-widget-height");
    if (typeof prefHeight === "string" && prefHeight.endsWith?.("%")) {
      prefHeight = node3.size[1] * (parseFloat(prefHeight.substring(0, prefHeight.length - 1)) / 100);
    } else {
      prefHeight = typeof prefHeight === "number" ? prefHeight : parseInt(prefHeight);
      if (isNaN(minHeight)) {
        minHeight = prefHeight;
      }
    }
    return {
      minHeight: isNaN(minHeight) ? 50 : minHeight,
      maxHeight: isNaN(maxHeight) ? void 0 : maxHeight,
      minWidth: 0
    };
  }
}
class ComponentWidgetImpl extends BaseDOMWidgetImpl {
  static {
    __name(this, "ComponentWidgetImpl");
  }
  component;
  inputSpec;
  constructor(obj) {
    super({
      ...obj,
      type: "custom"
    });
    this.component = obj.component;
    this.inputSpec = obj.inputSpec;
  }
  computeLayoutSize() {
    const minHeight = this.options.getMinHeight?.() ?? 50;
    const maxHeight = this.options.getMaxHeight?.();
    return {
      minHeight,
      maxHeight,
      minWidth: 0
    };
  }
  serializeValue() {
    return toRaw(this.value);
  }
}
const addWidget = /* @__PURE__ */ __name((node3, widget) => {
  node3.addCustomWidget(widget);
  node3.onRemoved = useChainCallback(node3.onRemoved, () => {
    widget.onRemove?.();
  });
  node3.onResize = useChainCallback(node3.onResize, () => {
    widget.options.beforeResize?.call(widget, node3);
    widget.options.afterResize?.call(widget, node3);
  });
  useDomWidgetStore().registerWidget(widget);
}, "addWidget");
LGraphNode.prototype.addDOMWidget = function(name2, type, element, options5 = {}) {
  const widget = new DOMWidgetImpl({
    id: generateUUID(),
    node: this,
    name: name2,
    type,
    element,
    options: { hideOnZoom: true, ...options5 }
  });
  addWidget(this, widget);
  Object.defineProperty(widget, "value", {
    get() {
      return this.options.getValue?.() ?? "";
    },
    set(v2) {
      this.options.setValue?.(v2);
      this.callback?.(this.value);
    }
  });
  return widget;
};
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.domWidget = window.comfyAPI.domWidget || {};
window.comfyAPI.domWidget.isDOMWidget = isDOMWidget;
window.comfyAPI.domWidget.isComponentWidget = isComponentWidget;
window.comfyAPI.domWidget.DOMWidgetImpl = DOMWidgetImpl;
window.comfyAPI.domWidget.ComponentWidgetImpl = ComponentWidgetImpl;
window.comfyAPI.domWidget.addWidget = addWidget;
const MAX_RETRIES$1 = 5;
const TIMEOUT = 4096;
const dataCache = /* @__PURE__ */ new Map();
const createCacheKey = /* @__PURE__ */ __name((config2) => {
  const { route, query_params = {}, refresh: refresh2 = 0 } = config2;
  const paramsKey = Object.entries(query_params).sort(([a2], [b2]) => a2.localeCompare(b2)).map(([k2, v2]) => `${k2}=${v2}`).join("&");
  return [route, `r=${refresh2}`, paramsKey].join(";");
}, "createCacheKey");
const getBackoff = /* @__PURE__ */ __name((retryCount) => Math.min(1e3 * Math.pow(2, retryCount), 512), "getBackoff");
const isInitialized = /* @__PURE__ */ __name((entry) => entry?.data && entry?.timestamp && entry.timestamp > 0, "isInitialized");
const isStale = /* @__PURE__ */ __name((entry, ttl) => entry?.timestamp && Date.now() - entry.timestamp >= ttl, "isStale");
const isFetching = /* @__PURE__ */ __name((entry) => entry?.fetchPromise !== void 0, "isFetching");
const isFailed = /* @__PURE__ */ __name((entry) => entry?.failed === true, "isFailed");
const isBackingOff = /* @__PURE__ */ __name((entry) => entry?.error && entry?.lastErrorTime && Date.now() - entry.lastErrorTime < getBackoff(entry.retryCount || 0), "isBackingOff");
const fetchData = /* @__PURE__ */ __name(async (config2, controller) => {
  const { route, response_key, query_params, timeout = TIMEOUT } = config2;
  const res = await axios.get(route, {
    params: query_params,
    signal: controller.signal,
    timeout
  });
  return response_key ? res.data[response_key] : res.data;
}, "fetchData");
function useRemoteWidget(options5) {
  const { remoteConfig, defaultValue: defaultValue2, node: node3, widget } = options5;
  const { refresh: refresh2 = 0, max_retries = MAX_RETRIES$1 } = remoteConfig;
  const isPermanent = refresh2 <= 0;
  const cacheKey = createCacheKey(remoteConfig);
  let isLoaded = false;
  let refreshQueued = false;
  const setSuccess = /* @__PURE__ */ __name((entry, data30) => {
    entry.retryCount = 0;
    entry.lastErrorTime = 0;
    entry.error = null;
    entry.timestamp = Date.now();
    entry.data = data30 ?? defaultValue2;
  }, "setSuccess");
  const setError = /* @__PURE__ */ __name((entry, error2) => {
    entry.retryCount = (entry.retryCount || 0) + 1;
    entry.lastErrorTime = Date.now();
    entry.error = error2 instanceof Error ? error2 : new Error(String(error2));
    entry.data ??= defaultValue2;
    entry.fetchPromise = void 0;
    if (entry.retryCount >= max_retries) {
      setFailed(entry);
    }
  }, "setError");
  const setFailed = /* @__PURE__ */ __name((entry) => {
    dataCache.set(cacheKey, {
      data: entry.data ?? defaultValue2,
      failed: true
    });
  }, "setFailed");
  const isFirstLoad = /* @__PURE__ */ __name(() => {
    return !isLoaded && isInitialized(dataCache.get(cacheKey));
  }, "isFirstLoad");
  const onFirstLoad = /* @__PURE__ */ __name((data30) => {
    isLoaded = true;
    widget.value = data30[0];
    widget.callback?.(widget.value);
    node3.graph?.setDirtyCanvas(true);
  }, "onFirstLoad");
  const fetchValue = /* @__PURE__ */ __name(async () => {
    const entry = dataCache.get(cacheKey);
    if (isFailed(entry)) return entry.data;
    const isValid2 = isInitialized(entry) && (isPermanent || !isStale(entry, refresh2));
    if (isValid2 || isBackingOff(entry) || isFetching(entry)) return entry.data;
    const currentEntry = entry || { data: defaultValue2 };
    dataCache.set(cacheKey, currentEntry);
    try {
      currentEntry.controller = new AbortController();
      currentEntry.fetchPromise = fetchData(
        remoteConfig,
        currentEntry.controller
      );
      const data30 = await currentEntry.fetchPromise;
      setSuccess(currentEntry, data30);
      return currentEntry.data;
    } catch (err) {
      setError(currentEntry, err);
      return currentEntry.data;
    } finally {
      currentEntry.fetchPromise = void 0;
      currentEntry.controller = void 0;
    }
  }, "fetchValue");
  const onRefresh = /* @__PURE__ */ __name(() => {
    if (remoteConfig.control_after_refresh) {
      const data30 = getCachedValue();
      if (!Array.isArray(data30)) return;
      switch (remoteConfig.control_after_refresh) {
        case "first":
          widget.value = data30[0] ?? defaultValue2;
          break;
        case "last":
          widget.value = data30.at(-1) ?? defaultValue2;
          break;
      }
      widget.callback?.(widget.value);
      node3.graph?.setDirtyCanvas(true);
    }
  }, "onRefresh");
  const clearCachedValue = /* @__PURE__ */ __name(() => {
    const entry = dataCache.get(cacheKey);
    if (!entry) return;
    if (entry.fetchPromise) entry.controller?.abort();
    dataCache.delete(cacheKey);
  }, "clearCachedValue");
  function getCachedValue() {
    return dataCache.get(cacheKey)?.data;
  }
  __name(getCachedValue, "getCachedValue");
  function getValue2(onFulfilled) {
    fetchValue().then((data30) => {
      if (isFirstLoad()) onFirstLoad(data30);
      if (refreshQueued && data30 !== defaultValue2) {
        onRefresh();
        refreshQueued = false;
      }
      onFulfilled?.();
    });
    return getCachedValue() ?? defaultValue2;
  }
  __name(getValue2, "getValue");
  widget.refresh = function() {
    refreshQueued = true;
    clearCachedValue();
    getValue2();
  };
  function addRefreshButton() {
    node3.addWidget("button", "refresh", "refresh", widget.refresh);
  }
  __name(addRefreshButton, "addRefreshButton");
  return {
    getCachedValue,
    getValue: getValue2,
    refreshValue: widget.refresh,
    addRefreshButton,
    getCacheEntry: /* @__PURE__ */ __name(() => dataCache.get(cacheKey), "getCacheEntry"),
    cacheKey
  };
}
__name(useRemoteWidget, "useRemoteWidget");
const getDefaultValue = /* @__PURE__ */ __name((inputSpec) => {
  if (inputSpec.default) return inputSpec.default;
  if (inputSpec.options?.length) return inputSpec.options[0];
  if (inputSpec.remote) return "Loading...";
  return void 0;
}, "getDefaultValue");
const addMultiSelectWidget = /* @__PURE__ */ __name((node3, inputSpec) => {
  const widgetValue = ref([]);
  const widget = new ComponentWidgetImpl({
    id: generateUUID(),
    node: node3,
    name: inputSpec.name,
    component: _sfc_main$V,
    inputSpec,
    options: {
      getValue: /* @__PURE__ */ __name(() => widgetValue.value, "getValue"),
      setValue: /* @__PURE__ */ __name((value3) => {
        widgetValue.value = value3;
      }, "setValue")
    }
  });
  addWidget(node3, widget);
  return widget;
}, "addMultiSelectWidget");
const addComboWidget = /* @__PURE__ */ __name((node3, inputSpec) => {
  const defaultValue2 = getDefaultValue(inputSpec);
  const comboOptions = inputSpec.options ?? [];
  const widget = node3.addWidget(
    "combo",
    inputSpec.name,
    defaultValue2,
    () => {
    },
    {
      values: comboOptions
    }
  );
  if (inputSpec.remote) {
    const remoteWidget = useRemoteWidget({
      remoteConfig: inputSpec.remote,
      defaultValue: defaultValue2,
      node: node3,
      widget
    });
    if (inputSpec.remote.refresh_button) remoteWidget.addRefreshButton();
    const origOptions = widget.options;
    widget.options = new Proxy(origOptions, {
      get(target2, prop2) {
        if (prop2 !== "values") return target2[prop2];
        return remoteWidget.getValue();
      }
    });
  }
  if (inputSpec.control_after_generate) {
    widget.linkedWidgets = addValueControlWidgets(
      node3,
      widget,
      void 0,
      void 0,
      transformInputSpecV2ToV1(inputSpec)
    );
  }
  return widget;
}, "addComboWidget");
const useComboWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    if (!isComboInputSpec(inputSpec)) {
      throw new Error(`Invalid input data: ${inputSpec}`);
    }
    return inputSpec.multi_select ? addMultiSelectWidget(node3, inputSpec) : addComboWidget(node3, inputSpec);
  }, "widgetConstructor");
  return widgetConstructor;
}, "useComboWidget");
function onFloatValueChange(v2) {
  this.value = this.options.round ? _.clamp(
    Math.round((v2 + Number.EPSILON) / this.options.round) * this.options.round,
    this.options.min ?? -Infinity,
    this.options.max ?? Infinity
  ) : v2;
}
__name(onFloatValueChange, "onFloatValueChange");
const _for_testing$1 = {
  onFloatValueChange
};
const useFloatWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    if (!isFloatInputSpec(inputSpec)) {
      throw new Error(`Invalid input data: ${inputSpec}`);
    }
    const settingStore = useSettingStore();
    const sliderEnabled = !settingStore.get("Comfy.DisableSliders");
    const display_type = inputSpec.display;
    const widgetType = sliderEnabled && display_type == "slider" ? "slider" : display_type == "knob" ? "knob" : "number";
    const step2 = inputSpec.step ?? 0.5;
    const precision = settingStore.get("Comfy.FloatRoundingPrecision") || Math.max(0, -Math.floor(Math.log10(step2)));
    const enableRounding = !settingStore.get("Comfy.DisableFloatRounding");
    const defaultValue2 = inputSpec.default ?? 0;
    return node3.addWidget(
      widgetType,
      inputSpec.name,
      defaultValue2,
      onFloatValueChange,
      {
        min: inputSpec.min ?? 0,
        max: inputSpec.max ?? 2048,
        round: enableRounding && precision && !inputSpec.round ? 1e6 * Math.pow(0.1, precision) / 1e6 : inputSpec.round,
        /** @deprecated Use step2 instead. The 10x value is a legacy implementation. */
        step: step2 * 10,
        step2,
        precision
      }
    );
  }, "widgetConstructor");
  return widgetConstructor;
}, "useFloatWidget");
function isImageNode(node3) {
  if (!node3) return false;
  return node3.previewMediaType === "image" || node3.previewMediaType !== "video" && !!node3.imgs?.length;
}
__name(isImageNode, "isImageNode");
function isVideoNode(node3) {
  if (!node3) return false;
  return node3.previewMediaType === "video" || !!node3.videoContainer;
}
__name(isVideoNode, "isVideoNode");
function isAudioNode(node3) {
  return !!node3 && node3.previewMediaType === "audio";
}
__name(isAudioNode, "isAudioNode");
function addToComboValues(widget, value3) {
  if (!widget.options) widget.options = { values: [] };
  if (!widget.options.values) widget.options.values = [];
  if (!widget.options.values.includes(value3)) {
    widget.options.values.push(value3);
  }
}
__name(addToComboValues, "addToComboValues");
const isLGraphNode = /* @__PURE__ */ __name((item3) => {
  return item3 instanceof LGraphNode;
}, "isLGraphNode");
const isLGraphGroup = /* @__PURE__ */ __name((item3) => {
  return item3 instanceof LGraphGroup;
}, "isLGraphGroup");
const getItemsColorOption = /* @__PURE__ */ __name((items2) => {
  const validItems = _.filter(items2, isColorable);
  if (_.isEmpty(validItems)) return null;
  const colorOptions = _.map(validItems, (item3) => item3.getColorOption());
  return _.every(
    colorOptions,
    (option5) => _.isEqual(option5, _.head(colorOptions))
  ) ? _.head(colorOptions) : null;
}, "getItemsColorOption");
function executeWidgetsCallback(nodes, callbackName) {
  for (const node3 of nodes) {
    for (const widget of node3.widgets ?? []) {
      widget[callbackName]?.();
    }
  }
}
__name(executeWidgetsCallback, "executeWidgetsCallback");
const createOutputs = /* @__PURE__ */ __name((filenames, type) => {
  return {
    images: filenames.map((image2) => ({ type, ...parseFilePath(image2) }))
  };
}, "createOutputs");
const getPreviewParam = /* @__PURE__ */ __name((node3) => {
  if (node3.animatedImages || isVideoNode(node3)) return "";
  return app.getPreviewFormatParam();
}, "getPreviewParam");
const useNodeOutputStore = /* @__PURE__ */ defineStore("nodeOutput", () => {
  const getNodeId = /* @__PURE__ */ __name((node3) => node3.id.toString(), "getNodeId");
  function getNodeOutputs(node3) {
    return app.nodeOutputs[getNodeId(node3)];
  }
  __name(getNodeOutputs, "getNodeOutputs");
  function getNodePreviews(node3) {
    return app.nodePreviewImages[getNodeId(node3)];
  }
  __name(getNodePreviews, "getNodePreviews");
  function getNodeImageUrls(node3) {
    const previews = getNodePreviews(node3);
    if (previews?.length) return previews;
    const outputs = getNodeOutputs(node3);
    if (!outputs?.images?.length) return;
    const rand2 = app.getRandParam();
    const previewParam = getPreviewParam(node3);
    return outputs.images.map((image2) => {
      const imgUrlPart = new URLSearchParams(image2);
      return api.apiURL(`/view?${imgUrlPart}${previewParam}${rand2}`);
    });
  }
  __name(getNodeImageUrls, "getNodeImageUrls");
  function setNodeOutputs(node3, filenames, { folder = "input" } = {}) {
    if (!filenames || !node3) return;
    const nodeId = getNodeId(node3);
    if (typeof filenames === "string") {
      app.nodeOutputs[nodeId] = createOutputs([filenames], folder);
    } else if (!Array.isArray(filenames)) {
      app.nodeOutputs[nodeId] = filenames;
    } else {
      const resultItems = createOutputs(filenames, folder);
      if (!resultItems?.images?.length) return;
      app.nodeOutputs[nodeId] = resultItems;
    }
  }
  __name(setNodeOutputs, "setNodeOutputs");
  return {
    getNodeOutputs,
    getNodeImageUrls,
    getNodePreviews,
    setNodeOutputs
  };
});
const VIDEO_WIDGET_NAME = "video-preview";
const VIDEO_DEFAULT_OPTIONS = {
  playsInline: true,
  controls: true,
  loop: true
};
const MEDIA_LOAD_TIMEOUT = 8192;
const MAX_RETRIES = 1;
const DEFAULT_VIDEO_SIZE = 256;
const createContainer = /* @__PURE__ */ __name(() => {
  const container = document.createElement("div");
  container.classList.add("comfy-img-preview");
  return container;
}, "createContainer");
const createTimeout = /* @__PURE__ */ __name((ms) => new Promise((resolve2) => setTimeout(() => resolve2(null), ms)), "createTimeout");
const useNodePreview = /* @__PURE__ */ __name((node3, options5) => {
  const { loadElement, onLoaded, onFailedLoading } = options5;
  const nodeOutputStore = useNodeOutputStore();
  const loadElementWithTimeout = /* @__PURE__ */ __name(async (url, retryCount = 0) => {
    const result = await Promise.race([
      loadElement(url),
      createTimeout(MEDIA_LOAD_TIMEOUT)
    ]);
    if (result === null && retryCount < MAX_RETRIES) {
      return loadElementWithTimeout(url, retryCount + 1);
    }
    return result;
  }, "loadElementWithTimeout");
  const loadElements = /* @__PURE__ */ __name(async (urls) => Promise.all(urls.map((url) => loadElementWithTimeout(url))), "loadElements");
  function showPreview(options22 = {}) {
    if (node3.isLoading) return;
    const outputUrls = nodeOutputStore.getNodeImageUrls(node3);
    if (!outputUrls?.length) return;
    if (options22?.block) node3.isLoading = true;
    loadElements(outputUrls).then((elements) => {
      const validElements = elements.filter(
        (el) => el !== null
      );
      if (validElements.length) {
        onLoaded?.(validElements);
        node3.graph?.setDirtyCanvas(true);
      }
    }).catch(() => {
      onFailedLoading?.();
    }).finally(() => {
      node3.isLoading = false;
    });
  }
  __name(showPreview, "showPreview");
  return {
    showPreview
  };
}, "useNodePreview");
const useNodeImage = /* @__PURE__ */ __name((node3) => {
  node3.previewMediaType = "image";
  const loadElement = /* @__PURE__ */ __name((url) => new Promise((resolve2) => {
    const img = new Image();
    img.onload = () => resolve2(img);
    img.onerror = () => resolve2(null);
    img.src = url;
  }), "loadElement");
  const onLoaded = /* @__PURE__ */ __name((elements) => {
    node3.imageIndex = null;
    node3.imgs = elements;
  }, "onLoaded");
  return useNodePreview(node3, {
    loadElement,
    onLoaded,
    onFailedLoading: /* @__PURE__ */ __name(() => {
      node3.imgs = void 0;
    }, "onFailedLoading")
  });
}, "useNodeImage");
const useNodeVideo = /* @__PURE__ */ __name((node3) => {
  node3.previewMediaType = "video";
  let minHeight = DEFAULT_VIDEO_SIZE;
  let minWidth = DEFAULT_VIDEO_SIZE;
  const setMinDimensions = /* @__PURE__ */ __name((video) => {
    const intrinsicAspectRatio = video.videoWidth / video.videoHeight;
    if (!intrinsicAspectRatio || isNaN(intrinsicAspectRatio)) return;
    minWidth = node3.size?.[0] || DEFAULT_VIDEO_SIZE;
    minHeight = Math.max(minWidth / intrinsicAspectRatio, 64);
  }, "setMinDimensions");
  const loadElement = /* @__PURE__ */ __name((url) => new Promise((resolve2) => {
    const video = document.createElement("video");
    Object.assign(video, VIDEO_DEFAULT_OPTIONS);
    video.onloadeddata = () => {
      setMinDimensions(video);
      resolve2(video);
    };
    video.onerror = () => resolve2(null);
    video.src = url;
  }), "loadElement");
  const addVideoDomWidget = /* @__PURE__ */ __name((container) => {
    const hasWidget = node3.widgets?.some((w2) => w2.name === VIDEO_WIDGET_NAME);
    if (!hasWidget) {
      const widget = node3.addDOMWidget(VIDEO_WIDGET_NAME, "video", container, {
        hideOnZoom: false,
        serialize: false
      });
      widget.computeLayoutSize = () => ({
        minHeight,
        minWidth
      });
    }
  }, "addVideoDomWidget");
  const onLoaded = /* @__PURE__ */ __name((videoElements) => {
    const videoElement = videoElements[0];
    if (!videoElement) return;
    if (!node3.videoContainer) {
      node3.videoContainer = createContainer();
      addVideoDomWidget(node3.videoContainer);
    }
    node3.videoContainer.replaceChildren(videoElement);
  }, "onLoaded");
  return useNodePreview(node3, {
    loadElement,
    onLoaded,
    onFailedLoading: /* @__PURE__ */ __name(() => {
      node3.videoContainer = void 0;
    }, "onFailedLoading")
  });
}, "useNodeVideo");
const useNodeDragAndDrop = /* @__PURE__ */ __name((node3, options5) => {
  const { onDragOver, onDrop, fileFilter = /* @__PURE__ */ __name(() => true, "fileFilter") } = options5;
  const hasFiles = /* @__PURE__ */ __name((items2) => !!Array.from(items2).find((f2) => f2.kind === "file"), "hasFiles");
  const filterFiles = /* @__PURE__ */ __name((files) => Array.from(files).filter(fileFilter), "filterFiles");
  const hasValidFiles = /* @__PURE__ */ __name((files) => filterFiles(files).length > 0, "hasValidFiles");
  const isDraggingFiles = /* @__PURE__ */ __name((e2) => {
    if (!e2?.dataTransfer?.items) return false;
    return onDragOver?.(e2) ?? hasFiles(e2.dataTransfer.items);
  }, "isDraggingFiles");
  const isDraggingValidFiles = /* @__PURE__ */ __name((e2) => {
    if (!e2?.dataTransfer?.files) return false;
    return hasValidFiles(e2.dataTransfer.files);
  }, "isDraggingValidFiles");
  node3.onDragOver = isDraggingFiles;
  node3.onDragDrop = function(e2) {
    if (!isDraggingValidFiles(e2)) return false;
    const files = filterFiles(e2.dataTransfer.files);
    onDrop(files).then((results) => {
      if (!results?.length) return;
    });
    return true;
  };
}, "useNodeDragAndDrop");
function useNodeFileInput(node3, options5) {
  const {
    accept: accept3,
    allow_batch = false,
    fileFilter = /* @__PURE__ */ __name(() => true, "fileFilter"),
    onSelect
  } = options5;
  let fileInput2 = document.createElement("input");
  fileInput2.type = "file";
  fileInput2.accept = accept3 ?? "*";
  fileInput2.multiple = allow_batch;
  fileInput2.onchange = () => {
    if (fileInput2?.files?.length) {
      const files = Array.from(fileInput2.files).filter(fileFilter);
      if (files.length) onSelect(files);
    }
  };
  node3.onRemoved = useChainCallback(node3.onRemoved, () => {
    if (fileInput2) {
      fileInput2.onchange = null;
      fileInput2 = null;
    }
  });
  return {
    openFileSelection: /* @__PURE__ */ __name(() => fileInput2?.click(), "openFileSelection")
  };
}
__name(useNodeFileInput, "useNodeFileInput");
const useNodePaste = /* @__PURE__ */ __name((node3, options5) => {
  const { onPaste: onPaste2, fileFilter = /* @__PURE__ */ __name(() => true, "fileFilter"), allow_batch = false } = options5;
  node3.pasteFiles = function(files) {
    const filteredFiles = Array.from(files).filter(fileFilter);
    if (!filteredFiles.length) return false;
    const paste = allow_batch ? filteredFiles : filteredFiles.slice(0, 1);
    onPaste2(paste).then((result) => {
      if (!result) return;
    });
    return true;
  };
}, "useNodePaste");
const PASTED_IMAGE_EXPIRY_MS = 2e3;
const uploadFile$1 = /* @__PURE__ */ __name(async (file, isPasted) => {
  const body = new FormData();
  body.append("image", file);
  if (isPasted) body.append("subfolder", "pasted");
  const resp = await api.fetchApi("/upload/image", {
    method: "POST",
    body
  });
  if (resp.status !== 200) {
    useToastStore().addAlert(resp.status + " - " + resp.statusText);
    return;
  }
  const data30 = await resp.json();
  return data30.subfolder ? `${data30.subfolder}/${data30.name}` : data30.name;
}, "uploadFile$1");
const useNodeImageUpload = /* @__PURE__ */ __name((node3, options5) => {
  const { fileFilter, onUploadComplete, allow_batch, accept: accept3 } = options5;
  const isPastedFile = /* @__PURE__ */ __name((file) => file.name === "image.png" && file.lastModified - Date.now() < PASTED_IMAGE_EXPIRY_MS, "isPastedFile");
  const handleUpload = /* @__PURE__ */ __name(async (file) => {
    try {
      const path = await uploadFile$1(file, isPastedFile(file));
      if (!path) return;
      return path;
    } catch (error2) {
      useToastStore().addAlert(String(error2));
    }
  }, "handleUpload");
  const handleUploadBatch = /* @__PURE__ */ __name(async (files) => {
    const paths = await Promise.all(files.map(handleUpload));
    const validPaths = paths.filter((p2) => !!p2);
    if (validPaths.length) onUploadComplete(validPaths);
    return validPaths;
  }, "handleUploadBatch");
  useNodeDragAndDrop(node3, {
    fileFilter,
    onDrop: handleUploadBatch
  });
  useNodePaste(node3, {
    fileFilter,
    allow_batch,
    onPaste: handleUploadBatch
  });
  const { openFileSelection } = useNodeFileInput(node3, {
    fileFilter,
    allow_batch,
    accept: accept3,
    onSelect: handleUploadBatch
  });
  return { openFileSelection, handleUpload };
}, "useNodeImageUpload");
function useValueTransform(transform2, initialValue) {
  let internalValue = initialValue;
  let cachedValue = transform2(initialValue);
  let isChanged = false;
  return {
    get: /* @__PURE__ */ __name(() => {
      if (!isChanged) return cachedValue;
      cachedValue = transform2(internalValue);
      return cachedValue;
    }, "get"),
    set: /* @__PURE__ */ __name((value3) => {
      isChanged = true;
      internalValue = value3;
    }, "set")
  };
}
__name(useValueTransform, "useValueTransform");
const ACCEPTED_IMAGE_TYPES = "image/png,image/jpeg,image/webp";
const ACCEPTED_VIDEO_TYPES = "video/webm,video/mp4";
const isImageFile = /* @__PURE__ */ __name((file) => file.type.startsWith("image/"), "isImageFile");
const isVideoFile = /* @__PURE__ */ __name((file) => file.type.startsWith("video/"), "isVideoFile");
const findFileComboWidget = /* @__PURE__ */ __name((node3, inputName) => node3.widgets.find((w2) => w2.name === inputName), "findFileComboWidget");
const useImageUploadWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputName, inputData) => {
    const inputOptions = inputData[1] ?? {};
    const { imageInputName, allow_batch, image_folder = "input" } = inputOptions;
    const nodeOutputStore = useNodeOutputStore();
    const isVideo = !!inputOptions.video_upload;
    const accept3 = isVideo ? ACCEPTED_VIDEO_TYPES : ACCEPTED_IMAGE_TYPES;
    const { showPreview } = isVideo ? useNodeVideo(node3) : useNodeImage(node3);
    const fileFilter = isVideo ? isVideoFile : isImageFile;
    const fileComboWidget = findFileComboWidget(node3, imageInputName);
    const initialFile = `${fileComboWidget.value}`;
    const formatPath = /* @__PURE__ */ __name((value3) => (
      // @ts-expect-error InputSpec is not typed correctly
      createAnnotatedPath(value3, { rootFolder: image_folder })
    ), "formatPath");
    const transform2 = /* @__PURE__ */ __name((internalValue) => {
      if (!internalValue) return initialFile;
      if (Array.isArray(internalValue))
        return allow_batch ? internalValue.map(formatPath) : formatPath(internalValue[0]);
      return formatPath(internalValue);
    }, "transform");
    Object.defineProperty(
      fileComboWidget,
      "value",
      useValueTransform(transform2, initialFile)
    );
    const { openFileSelection } = useNodeImageUpload(node3, {
      // @ts-expect-error InputSpec is not typed correctly
      allow_batch,
      fileFilter,
      accept: accept3,
      onUploadComplete: /* @__PURE__ */ __name((output) => {
        output.forEach((path) => addToComboValues(fileComboWidget, path));
        fileComboWidget.value = output;
        fileComboWidget.callback?.(output);
      }, "onUploadComplete")
    });
    const uploadWidget = node3.addWidget(
      "button",
      inputName,
      "image",
      () => openFileSelection(),
      {
        serialize: false
      }
    );
    uploadWidget.label = t("g.choose_file_to_upload");
    fileComboWidget.callback = function() {
      nodeOutputStore.setNodeOutputs(node3, fileComboWidget.value);
      node3.graph?.setDirtyCanvas(true);
    };
    requestAnimationFrame(() => {
      nodeOutputStore.setNodeOutputs(node3, fileComboWidget.value);
      showPreview({ block: false });
    });
    return { widget: uploadWidget };
  }, "widgetConstructor");
  return widgetConstructor;
}, "useImageUploadWidget");
function onValueChange(v2) {
  const step2 = this.options.step2 || 1;
  if (step2 === 1) {
    this.value = Math.round(v2);
  } else {
    const min = this.options.min ?? 0;
    const offset = min % step2;
    this.value = Math.round((v2 - offset) / step2) * step2 + offset;
  }
}
__name(onValueChange, "onValueChange");
const _for_testing = {
  onValueChange
};
const useIntWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    if (!isIntInputSpec(inputSpec)) {
      throw new Error(`Invalid input data: ${inputSpec}`);
    }
    const settingStore = useSettingStore();
    const sliderEnabled = !settingStore.get("Comfy.DisableSliders");
    const display_type = inputSpec.display;
    const widgetType = sliderEnabled && display_type == "slider" ? "slider" : display_type == "knob" ? "knob" : "number";
    const step2 = inputSpec.step ?? 1;
    const defaultValue2 = inputSpec.default ?? 0;
    const widget = node3.addWidget(
      widgetType,
      inputSpec.name,
      defaultValue2,
      onValueChange,
      {
        min: inputSpec.min ?? 0,
        max: inputSpec.max ?? 2048,
        /** @deprecated Use step2 instead. The 10x value is a legacy implementation. */
        step: step2 * 10,
        step2,
        precision: 0
      }
    );
    const controlAfterGenerate = inputSpec.control_after_generate ?? /**
    * Compatibility with legacy node convention. Int input with name
    * 'seed' or 'noise_seed' get automatically added a control widget.
    */
    ["seed", "noise_seed"].includes(inputSpec.name);
    if (controlAfterGenerate) {
      const seedControl = addValueControlWidget(
        node3,
        widget,
        "randomize",
        void 0,
        void 0,
        transformInputSpecV2ToV1(inputSpec)
      );
      widget.linkedWidgets = [seedControl];
    }
    return widget;
  }, "widgetConstructor");
  return widgetConstructor;
}, "useIntWidget");
function OrderedMap(content3) {
  this.content = content3;
}
__name(OrderedMap, "OrderedMap");
OrderedMap.prototype = {
  constructor: OrderedMap,
  find: /* @__PURE__ */ __name(function(key) {
    for (var i2 = 0; i2 < this.content.length; i2 += 2)
      if (this.content[i2] === key) return i2;
    return -1;
  }, "find"),
  // :: (string) → ?any
  // Retrieve the value stored under `key`, or return undefined when
  // no such key exists.
  get: /* @__PURE__ */ __name(function(key) {
    var found2 = this.find(key);
    return found2 == -1 ? void 0 : this.content[found2 + 1];
  }, "get"),
  // :: (string, any, ?string) → OrderedMap
  // Create a new map by replacing the value of `key` with a new
  // value, or adding a binding to the end of the map. If `newKey` is
  // given, the key of the binding will be replaced with that key.
  update: /* @__PURE__ */ __name(function(key, value3, newKey) {
    var self2 = newKey && newKey != key ? this.remove(newKey) : this;
    var found2 = self2.find(key), content3 = self2.content.slice();
    if (found2 == -1) {
      content3.push(newKey || key, value3);
    } else {
      content3[found2 + 1] = value3;
      if (newKey) content3[found2] = newKey;
    }
    return new OrderedMap(content3);
  }, "update"),
  // :: (string) → OrderedMap
  // Return a map with the given key removed, if it existed.
  remove: /* @__PURE__ */ __name(function(key) {
    var found2 = this.find(key);
    if (found2 == -1) return this;
    var content3 = this.content.slice();
    content3.splice(found2, 2);
    return new OrderedMap(content3);
  }, "remove"),
  // :: (string, any) → OrderedMap
  // Add a new key to the start of the map.
  addToStart: /* @__PURE__ */ __name(function(key, value3) {
    return new OrderedMap([key, value3].concat(this.remove(key).content));
  }, "addToStart"),
  // :: (string, any) → OrderedMap
  // Add a new key to the end of the map.
  addToEnd: /* @__PURE__ */ __name(function(key, value3) {
    var content3 = this.remove(key).content.slice();
    content3.push(key, value3);
    return new OrderedMap(content3);
  }, "addToEnd"),
  // :: (string, string, any) → OrderedMap
  // Add a key after the given key. If `place` is not found, the new
  // key is added to the end.
  addBefore: /* @__PURE__ */ __name(function(place, key, value3) {
    var without = this.remove(key), content3 = without.content.slice();
    var found2 = without.find(place);
    content3.splice(found2 == -1 ? content3.length : found2, 0, key, value3);
    return new OrderedMap(content3);
  }, "addBefore"),
  // :: ((key: string, value: any))
  // Call the given function for each key/value pair in the map, in
  // order.
  forEach: /* @__PURE__ */ __name(function(f2) {
    for (var i2 = 0; i2 < this.content.length; i2 += 2)
      f2(this.content[i2], this.content[i2 + 1]);
  }, "forEach"),
  // :: (union<Object, OrderedMap>) → OrderedMap
  // Create a new map by prepending the keys in this map that don't
  // appear in `map` before the keys in `map`.
  prepend: /* @__PURE__ */ __name(function(map3) {
    map3 = OrderedMap.from(map3);
    if (!map3.size) return this;
    return new OrderedMap(map3.content.concat(this.subtract(map3).content));
  }, "prepend"),
  // :: (union<Object, OrderedMap>) → OrderedMap
  // Create a new map by appending the keys in this map that don't
  // appear in `map` after the keys in `map`.
  append: /* @__PURE__ */ __name(function(map3) {
    map3 = OrderedMap.from(map3);
    if (!map3.size) return this;
    return new OrderedMap(this.subtract(map3).content.concat(map3.content));
  }, "append"),
  // :: (union<Object, OrderedMap>) → OrderedMap
  // Create a map containing all the keys in this map that don't
  // appear in `map`.
  subtract: /* @__PURE__ */ __name(function(map3) {
    var result = this;
    map3 = OrderedMap.from(map3);
    for (var i2 = 0; i2 < map3.content.length; i2 += 2)
      result = result.remove(map3.content[i2]);
    return result;
  }, "subtract"),
  // :: () → Object
  // Turn ordered map into a plain object.
  toObject: /* @__PURE__ */ __name(function() {
    var result = {};
    this.forEach(function(key, value3) {
      result[key] = value3;
    });
    return result;
  }, "toObject"),
  // :: number
  // The amount of keys in this map.
  get size() {
    return this.content.length >> 1;
  }
};
OrderedMap.from = function(value3) {
  if (value3 instanceof OrderedMap) return value3;
  var content3 = [];
  if (value3) for (var prop2 in value3) content3.push(prop2, value3[prop2]);
  return new OrderedMap(content3);
};
function findDiffStart(a2, b2, pos) {
  for (let i2 = 0; ; i2++) {
    if (i2 == a2.childCount || i2 == b2.childCount)
      return a2.childCount == b2.childCount ? null : pos;
    let childA = a2.child(i2), childB = b2.child(i2);
    if (childA == childB) {
      pos += childA.nodeSize;
      continue;
    }
    if (!childA.sameMarkup(childB))
      return pos;
    if (childA.isText && childA.text != childB.text) {
      for (let j2 = 0; childA.text[j2] == childB.text[j2]; j2++)
        pos++;
      return pos;
    }
    if (childA.content.size || childB.content.size) {
      let inner = findDiffStart(childA.content, childB.content, pos + 1);
      if (inner != null)
        return inner;
    }
    pos += childA.nodeSize;
  }
}
__name(findDiffStart, "findDiffStart");
function findDiffEnd(a2, b2, posA, posB) {
  for (let iA = a2.childCount, iB = b2.childCount; ; ) {
    if (iA == 0 || iB == 0)
      return iA == iB ? null : { a: posA, b: posB };
    let childA = a2.child(--iA), childB = b2.child(--iB), size = childA.nodeSize;
    if (childA == childB) {
      posA -= size;
      posB -= size;
      continue;
    }
    if (!childA.sameMarkup(childB))
      return { a: posA, b: posB };
    if (childA.isText && childA.text != childB.text) {
      let same = 0, minSize = Math.min(childA.text.length, childB.text.length);
      while (same < minSize && childA.text[childA.text.length - same - 1] == childB.text[childB.text.length - same - 1]) {
        same++;
        posA--;
        posB--;
      }
      return { a: posA, b: posB };
    }
    if (childA.content.size || childB.content.size) {
      let inner = findDiffEnd(childA.content, childB.content, posA - 1, posB - 1);
      if (inner)
        return inner;
    }
    posA -= size;
    posB -= size;
  }
}
__name(findDiffEnd, "findDiffEnd");
class Fragment {
  static {
    __name(this, "Fragment");
  }
  /**
  @internal
  */
  constructor(content3, size) {
    this.content = content3;
    this.size = size || 0;
    if (size == null)
      for (let i2 = 0; i2 < content3.length; i2++)
        this.size += content3[i2].nodeSize;
  }
  /**
  Invoke a callback for all descendant nodes between the given two
  positions (relative to start of this fragment). Doesn't descend
  into a node when the callback returns `false`.
  */
  nodesBetween(from2, to, f2, nodeStart = 0, parent) {
    for (let i2 = 0, pos = 0; pos < to; i2++) {
      let child = this.content[i2], end = pos + child.nodeSize;
      if (end > from2 && f2(child, nodeStart + pos, parent || null, i2) !== false && child.content.size) {
        let start2 = pos + 1;
        child.nodesBetween(Math.max(0, from2 - start2), Math.min(child.content.size, to - start2), f2, nodeStart + start2);
      }
      pos = end;
    }
  }
  /**
  Call the given callback for every descendant node. `pos` will be
  relative to the start of the fragment. The callback may return
  `false` to prevent traversal of a given node's children.
  */
  descendants(f2) {
    this.nodesBetween(0, this.size, f2);
  }
  /**
  Extract the text between `from` and `to`. See the same method on
  [`Node`](https://prosemirror.net/docs/ref/#model.Node.textBetween).
  */
  textBetween(from2, to, blockSeparator, leafText) {
    let text2 = "", first2 = true;
    this.nodesBetween(from2, to, (node3, pos) => {
      let nodeText = node3.isText ? node3.text.slice(Math.max(from2, pos) - pos, to - pos) : !node3.isLeaf ? "" : leafText ? typeof leafText === "function" ? leafText(node3) : leafText : node3.type.spec.leafText ? node3.type.spec.leafText(node3) : "";
      if (node3.isBlock && (node3.isLeaf && nodeText || node3.isTextblock) && blockSeparator) {
        if (first2)
          first2 = false;
        else
          text2 += blockSeparator;
      }
      text2 += nodeText;
    }, 0);
    return text2;
  }
  /**
  Create a new fragment containing the combined content of this
  fragment and the other.
  */
  append(other) {
    if (!other.size)
      return this;
    if (!this.size)
      return other;
    let last = this.lastChild, first2 = other.firstChild, content3 = this.content.slice(), i2 = 0;
    if (last.isText && last.sameMarkup(first2)) {
      content3[content3.length - 1] = last.withText(last.text + first2.text);
      i2 = 1;
    }
    for (; i2 < other.content.length; i2++)
      content3.push(other.content[i2]);
    return new Fragment(content3, this.size + other.size);
  }
  /**
  Cut out the sub-fragment between the two given positions.
  */
  cut(from2, to = this.size) {
    if (from2 == 0 && to == this.size)
      return this;
    let result = [], size = 0;
    if (to > from2)
      for (let i2 = 0, pos = 0; pos < to; i2++) {
        let child = this.content[i2], end = pos + child.nodeSize;
        if (end > from2) {
          if (pos < from2 || end > to) {
            if (child.isText)
              child = child.cut(Math.max(0, from2 - pos), Math.min(child.text.length, to - pos));
            else
              child = child.cut(Math.max(0, from2 - pos - 1), Math.min(child.content.size, to - pos - 1));
          }
          result.push(child);
          size += child.nodeSize;
        }
        pos = end;
      }
    return new Fragment(result, size);
  }
  /**
  @internal
  */
  cutByIndex(from2, to) {
    if (from2 == to)
      return Fragment.empty;
    if (from2 == 0 && to == this.content.length)
      return this;
    return new Fragment(this.content.slice(from2, to));
  }
  /**
  Create a new fragment in which the node at the given index is
  replaced by the given node.
  */
  replaceChild(index2, node3) {
    let current = this.content[index2];
    if (current == node3)
      return this;
    let copy2 = this.content.slice();
    let size = this.size + node3.nodeSize - current.nodeSize;
    copy2[index2] = node3;
    return new Fragment(copy2, size);
  }
  /**
  Create a new fragment by prepending the given node to this
  fragment.
  */
  addToStart(node3) {
    return new Fragment([node3].concat(this.content), this.size + node3.nodeSize);
  }
  /**
  Create a new fragment by appending the given node to this
  fragment.
  */
  addToEnd(node3) {
    return new Fragment(this.content.concat(node3), this.size + node3.nodeSize);
  }
  /**
  Compare this fragment to another one.
  */
  eq(other) {
    if (this.content.length != other.content.length)
      return false;
    for (let i2 = 0; i2 < this.content.length; i2++)
      if (!this.content[i2].eq(other.content[i2]))
        return false;
    return true;
  }
  /**
  The first child of the fragment, or `null` if it is empty.
  */
  get firstChild() {
    return this.content.length ? this.content[0] : null;
  }
  /**
  The last child of the fragment, or `null` if it is empty.
  */
  get lastChild() {
    return this.content.length ? this.content[this.content.length - 1] : null;
  }
  /**
  The number of child nodes in this fragment.
  */
  get childCount() {
    return this.content.length;
  }
  /**
  Get the child node at the given index. Raise an error when the
  index is out of range.
  */
  child(index2) {
    let found2 = this.content[index2];
    if (!found2)
      throw new RangeError("Index " + index2 + " out of range for " + this);
    return found2;
  }
  /**
  Get the child node at the given index, if it exists.
  */
  maybeChild(index2) {
    return this.content[index2] || null;
  }
  /**
  Call `f` for every child node, passing the node, its offset
  into this parent node, and its index.
  */
  forEach(f2) {
    for (let i2 = 0, p2 = 0; i2 < this.content.length; i2++) {
      let child = this.content[i2];
      f2(child, p2, i2);
      p2 += child.nodeSize;
    }
  }
  /**
  Find the first position at which this fragment and another
  fragment differ, or `null` if they are the same.
  */
  findDiffStart(other, pos = 0) {
    return findDiffStart(this, other, pos);
  }
  /**
  Find the first position, searching from the end, at which this
  fragment and the given fragment differ, or `null` if they are
  the same. Since this position will not be the same in both
  nodes, an object with two separate positions is returned.
  */
  findDiffEnd(other, pos = this.size, otherPos = other.size) {
    return findDiffEnd(this, other, pos, otherPos);
  }
  /**
  Find the index and inner offset corresponding to a given relative
  position in this fragment. The result object will be reused
  (overwritten) the next time the function is called. @internal
  */
  findIndex(pos, round = -1) {
    if (pos == 0)
      return retIndex(0, pos);
    if (pos == this.size)
      return retIndex(this.content.length, pos);
    if (pos > this.size || pos < 0)
      throw new RangeError(`Position ${pos} outside of fragment (${this})`);
    for (let i2 = 0, curPos = 0; ; i2++) {
      let cur = this.child(i2), end = curPos + cur.nodeSize;
      if (end >= pos) {
        if (end == pos || round > 0)
          return retIndex(i2 + 1, end);
        return retIndex(i2, curPos);
      }
      curPos = end;
    }
  }
  /**
  Return a debugging string that describes this fragment.
  */
  toString() {
    return "<" + this.toStringInner() + ">";
  }
  /**
  @internal
  */
  toStringInner() {
    return this.content.join(", ");
  }
  /**
  Create a JSON-serializeable representation of this fragment.
  */
  toJSON() {
    return this.content.length ? this.content.map((n2) => n2.toJSON()) : null;
  }
  /**
  Deserialize a fragment from its JSON representation.
  */
  static fromJSON(schema2, value3) {
    if (!value3)
      return Fragment.empty;
    if (!Array.isArray(value3))
      throw new RangeError("Invalid input for Fragment.fromJSON");
    return new Fragment(value3.map(schema2.nodeFromJSON));
  }
  /**
  Build a fragment from an array of nodes. Ensures that adjacent
  text nodes with the same marks are joined together.
  */
  static fromArray(array) {
    if (!array.length)
      return Fragment.empty;
    let joined, size = 0;
    for (let i2 = 0; i2 < array.length; i2++) {
      let node3 = array[i2];
      size += node3.nodeSize;
      if (i2 && node3.isText && array[i2 - 1].sameMarkup(node3)) {
        if (!joined)
          joined = array.slice(0, i2);
        joined[joined.length - 1] = node3.withText(joined[joined.length - 1].text + node3.text);
      } else if (joined) {
        joined.push(node3);
      }
    }
    return new Fragment(joined || array, size);
  }
  /**
  Create a fragment from something that can be interpreted as a
  set of nodes. For `null`, it returns the empty fragment. For a
  fragment, the fragment itself. For a node or array of nodes, a
  fragment containing those nodes.
  */
  static from(nodes) {
    if (!nodes)
      return Fragment.empty;
    if (nodes instanceof Fragment)
      return nodes;
    if (Array.isArray(nodes))
      return this.fromArray(nodes);
    if (nodes.attrs)
      return new Fragment([nodes], nodes.nodeSize);
    throw new RangeError("Can not convert " + nodes + " to a Fragment" + (nodes.nodesBetween ? " (looks like multiple versions of prosemirror-model were loaded)" : ""));
  }
}
Fragment.empty = new Fragment([], 0);
const found = { index: 0, offset: 0 };
function retIndex(index2, offset) {
  found.index = index2;
  found.offset = offset;
  return found;
}
__name(retIndex, "retIndex");
function compareDeep(a2, b2) {
  if (a2 === b2)
    return true;
  if (!(a2 && typeof a2 == "object") || !(b2 && typeof b2 == "object"))
    return false;
  let array = Array.isArray(a2);
  if (Array.isArray(b2) != array)
    return false;
  if (array) {
    if (a2.length != b2.length)
      return false;
    for (let i2 = 0; i2 < a2.length; i2++)
      if (!compareDeep(a2[i2], b2[i2]))
        return false;
  } else {
    for (let p2 in a2)
      if (!(p2 in b2) || !compareDeep(a2[p2], b2[p2]))
        return false;
    for (let p2 in b2)
      if (!(p2 in a2))
        return false;
  }
  return true;
}
__name(compareDeep, "compareDeep");
let Mark$1 = class Mark2 {
  static {
    __name(this, "Mark");
  }
  /**
  @internal
  */
  constructor(type, attrs7) {
    this.type = type;
    this.attrs = attrs7;
  }
  /**
  Given a set of marks, create a new set which contains this one as
  well, in the right position. If this mark is already in the set,
  the set itself is returned. If any marks that are set to be
  [exclusive](https://prosemirror.net/docs/ref/#model.MarkSpec.excludes) with this mark are present,
  those are replaced by this one.
  */
  addToSet(set3) {
    let copy2, placed = false;
    for (let i2 = 0; i2 < set3.length; i2++) {
      let other = set3[i2];
      if (this.eq(other))
        return set3;
      if (this.type.excludes(other.type)) {
        if (!copy2)
          copy2 = set3.slice(0, i2);
      } else if (other.type.excludes(this.type)) {
        return set3;
      } else {
        if (!placed && other.type.rank > this.type.rank) {
          if (!copy2)
            copy2 = set3.slice(0, i2);
          copy2.push(this);
          placed = true;
        }
        if (copy2)
          copy2.push(other);
      }
    }
    if (!copy2)
      copy2 = set3.slice();
    if (!placed)
      copy2.push(this);
    return copy2;
  }
  /**
  Remove this mark from the given set, returning a new set. If this
  mark is not in the set, the set itself is returned.
  */
  removeFromSet(set3) {
    for (let i2 = 0; i2 < set3.length; i2++)
      if (this.eq(set3[i2]))
        return set3.slice(0, i2).concat(set3.slice(i2 + 1));
    return set3;
  }
  /**
  Test whether this mark is in the given set of marks.
  */
  isInSet(set3) {
    for (let i2 = 0; i2 < set3.length; i2++)
      if (this.eq(set3[i2]))
        return true;
    return false;
  }
  /**
  Test whether this mark has the same type and attributes as
  another mark.
  */
  eq(other) {
    return this == other || this.type == other.type && compareDeep(this.attrs, other.attrs);
  }
  /**
  Convert this mark to a JSON-serializeable representation.
  */
  toJSON() {
    let obj = { type: this.type.name };
    for (let _2 in this.attrs) {
      obj.attrs = this.attrs;
      break;
    }
    return obj;
  }
  /**
  Deserialize a mark from JSON.
  */
  static fromJSON(schema2, json) {
    if (!json)
      throw new RangeError("Invalid input for Mark.fromJSON");
    let type = schema2.marks[json.type];
    if (!type)
      throw new RangeError(`There is no mark type ${json.type} in this schema`);
    let mark2 = type.create(json.attrs);
    type.checkAttrs(mark2.attrs);
    return mark2;
  }
  /**
  Test whether two sets of marks are identical.
  */
  static sameSet(a2, b2) {
    if (a2 == b2)
      return true;
    if (a2.length != b2.length)
      return false;
    for (let i2 = 0; i2 < a2.length; i2++)
      if (!a2[i2].eq(b2[i2]))
        return false;
    return true;
  }
  /**
  Create a properly sorted mark set from null, a single mark, or an
  unsorted array of marks.
  */
  static setFrom(marks) {
    if (!marks || Array.isArray(marks) && marks.length == 0)
      return Mark2.none;
    if (marks instanceof Mark2)
      return [marks];
    let copy2 = marks.slice();
    copy2.sort((a2, b2) => a2.type.rank - b2.type.rank);
    return copy2;
  }
};
Mark$1.none = [];
class ReplaceError extends Error {
  static {
    __name(this, "ReplaceError");
  }
}
class Slice {
  static {
    __name(this, "Slice");
  }
  /**
  Create a slice. When specifying a non-zero open depth, you must
  make sure that there are nodes of at least that depth at the
  appropriate side of the fragment—i.e. if the fragment is an
  empty paragraph node, `openStart` and `openEnd` can't be greater
  than 1.
  
  It is not necessary for the content of open nodes to conform to
  the schema's content constraints, though it should be a valid
  start/end/middle for such a node, depending on which sides are
  open.
  */
  constructor(content3, openStart, openEnd) {
    this.content = content3;
    this.openStart = openStart;
    this.openEnd = openEnd;
  }
  /**
  The size this slice would add when inserted into a document.
  */
  get size() {
    return this.content.size - this.openStart - this.openEnd;
  }
  /**
  @internal
  */
  insertAt(pos, fragment) {
    let content3 = insertInto(this.content, pos + this.openStart, fragment);
    return content3 && new Slice(content3, this.openStart, this.openEnd);
  }
  /**
  @internal
  */
  removeBetween(from2, to) {
    return new Slice(removeRange(this.content, from2 + this.openStart, to + this.openStart), this.openStart, this.openEnd);
  }
  /**
  Tests whether this slice is equal to another slice.
  */
  eq(other) {
    return this.content.eq(other.content) && this.openStart == other.openStart && this.openEnd == other.openEnd;
  }
  /**
  @internal
  */
  toString() {
    return this.content + "(" + this.openStart + "," + this.openEnd + ")";
  }
  /**
  Convert a slice to a JSON-serializable representation.
  */
  toJSON() {
    if (!this.content.size)
      return null;
    let json = { content: this.content.toJSON() };
    if (this.openStart > 0)
      json.openStart = this.openStart;
    if (this.openEnd > 0)
      json.openEnd = this.openEnd;
    return json;
  }
  /**
  Deserialize a slice from its JSON representation.
  */
  static fromJSON(schema2, json) {
    if (!json)
      return Slice.empty;
    let openStart = json.openStart || 0, openEnd = json.openEnd || 0;
    if (typeof openStart != "number" || typeof openEnd != "number")
      throw new RangeError("Invalid input for Slice.fromJSON");
    return new Slice(Fragment.fromJSON(schema2, json.content), openStart, openEnd);
  }
  /**
  Create a slice from a fragment by taking the maximum possible
  open value on both side of the fragment.
  */
  static maxOpen(fragment, openIsolating = true) {
    let openStart = 0, openEnd = 0;
    for (let n2 = fragment.firstChild; n2 && !n2.isLeaf && (openIsolating || !n2.type.spec.isolating); n2 = n2.firstChild)
      openStart++;
    for (let n2 = fragment.lastChild; n2 && !n2.isLeaf && (openIsolating || !n2.type.spec.isolating); n2 = n2.lastChild)
      openEnd++;
    return new Slice(fragment, openStart, openEnd);
  }
}
Slice.empty = new Slice(Fragment.empty, 0, 0);
function removeRange(content3, from2, to) {
  let { index: index2, offset } = content3.findIndex(from2), child = content3.maybeChild(index2);
  let { index: indexTo, offset: offsetTo } = content3.findIndex(to);
  if (offset == from2 || child.isText) {
    if (offsetTo != to && !content3.child(indexTo).isText)
      throw new RangeError("Removing non-flat range");
    return content3.cut(0, from2).append(content3.cut(to));
  }
  if (index2 != indexTo)
    throw new RangeError("Removing non-flat range");
  return content3.replaceChild(index2, child.copy(removeRange(child.content, from2 - offset - 1, to - offset - 1)));
}
__name(removeRange, "removeRange");
function insertInto(content3, dist3, insert2, parent) {
  let { index: index2, offset } = content3.findIndex(dist3), child = content3.maybeChild(index2);
  if (offset == dist3 || child.isText) {
    if (parent && !parent.canReplace(index2, index2, insert2))
      return null;
    return content3.cut(0, dist3).append(insert2).append(content3.cut(dist3));
  }
  let inner = insertInto(child.content, dist3 - offset - 1, insert2);
  return inner && content3.replaceChild(index2, child.copy(inner));
}
__name(insertInto, "insertInto");
function replace$1($from, $to, slice2) {
  if (slice2.openStart > $from.depth)
    throw new ReplaceError("Inserted content deeper than insertion position");
  if ($from.depth - slice2.openStart != $to.depth - slice2.openEnd)
    throw new ReplaceError("Inconsistent open depths");
  return replaceOuter($from, $to, slice2, 0);
}
__name(replace$1, "replace$1");
function replaceOuter($from, $to, slice2, depth) {
  let index2 = $from.index(depth), node3 = $from.node(depth);
  if (index2 == $to.index(depth) && depth < $from.depth - slice2.openStart) {
    let inner = replaceOuter($from, $to, slice2, depth + 1);
    return node3.copy(node3.content.replaceChild(index2, inner));
  } else if (!slice2.content.size) {
    return close(node3, replaceTwoWay($from, $to, depth));
  } else if (!slice2.openStart && !slice2.openEnd && $from.depth == depth && $to.depth == depth) {
    let parent = $from.parent, content3 = parent.content;
    return close(parent, content3.cut(0, $from.parentOffset).append(slice2.content).append(content3.cut($to.parentOffset)));
  } else {
    let { start: start2, end } = prepareSliceForReplace(slice2, $from);
    return close(node3, replaceThreeWay($from, start2, end, $to, depth));
  }
}
__name(replaceOuter, "replaceOuter");
function checkJoin(main, sub) {
  if (!sub.type.compatibleContent(main.type))
    throw new ReplaceError("Cannot join " + sub.type.name + " onto " + main.type.name);
}
__name(checkJoin, "checkJoin");
function joinable$1($before, $after, depth) {
  let node3 = $before.node(depth);
  checkJoin(node3, $after.node(depth));
  return node3;
}
__name(joinable$1, "joinable$1");
function addNode(child, target2) {
  let last = target2.length - 1;
  if (last >= 0 && child.isText && child.sameMarkup(target2[last]))
    target2[last] = child.withText(target2[last].text + child.text);
  else
    target2.push(child);
}
__name(addNode, "addNode");
function addRange($start, $end, depth, target2) {
  let node3 = ($end || $start).node(depth);
  let startIndex = 0, endIndex = $end ? $end.index(depth) : node3.childCount;
  if ($start) {
    startIndex = $start.index(depth);
    if ($start.depth > depth) {
      startIndex++;
    } else if ($start.textOffset) {
      addNode($start.nodeAfter, target2);
      startIndex++;
    }
  }
  for (let i2 = startIndex; i2 < endIndex; i2++)
    addNode(node3.child(i2), target2);
  if ($end && $end.depth == depth && $end.textOffset)
    addNode($end.nodeBefore, target2);
}
__name(addRange, "addRange");
function close(node3, content3) {
  node3.type.checkContent(content3);
  return node3.copy(content3);
}
__name(close, "close");
function replaceThreeWay($from, $start, $end, $to, depth) {
  let openStart = $from.depth > depth && joinable$1($from, $start, depth + 1);
  let openEnd = $to.depth > depth && joinable$1($end, $to, depth + 1);
  let content3 = [];
  addRange(null, $from, depth, content3);
  if (openStart && openEnd && $start.index(depth) == $end.index(depth)) {
    checkJoin(openStart, openEnd);
    addNode(close(openStart, replaceThreeWay($from, $start, $end, $to, depth + 1)), content3);
  } else {
    if (openStart)
      addNode(close(openStart, replaceTwoWay($from, $start, depth + 1)), content3);
    addRange($start, $end, depth, content3);
    if (openEnd)
      addNode(close(openEnd, replaceTwoWay($end, $to, depth + 1)), content3);
  }
  addRange($to, null, depth, content3);
  return new Fragment(content3);
}
__name(replaceThreeWay, "replaceThreeWay");
function replaceTwoWay($from, $to, depth) {
  let content3 = [];
  addRange(null, $from, depth, content3);
  if ($from.depth > depth) {
    let type = joinable$1($from, $to, depth + 1);
    addNode(close(type, replaceTwoWay($from, $to, depth + 1)), content3);
  }
  addRange($to, null, depth, content3);
  return new Fragment(content3);
}
__name(replaceTwoWay, "replaceTwoWay");
function prepareSliceForReplace(slice2, $along) {
  let extra = $along.depth - slice2.openStart, parent = $along.node(extra);
  let node3 = parent.copy(slice2.content);
  for (let i2 = extra - 1; i2 >= 0; i2--)
    node3 = $along.node(i2).copy(Fragment.from(node3));
  return {
    start: node3.resolveNoCache(slice2.openStart + extra),
    end: node3.resolveNoCache(node3.content.size - slice2.openEnd - extra)
  };
}
__name(prepareSliceForReplace, "prepareSliceForReplace");
class ResolvedPos {
  static {
    __name(this, "ResolvedPos");
  }
  /**
  @internal
  */
  constructor(pos, path, parentOffset) {
    this.pos = pos;
    this.path = path;
    this.parentOffset = parentOffset;
    this.depth = path.length / 3 - 1;
  }
  /**
  @internal
  */
  resolveDepth(val) {
    if (val == null)
      return this.depth;
    if (val < 0)
      return this.depth + val;
    return val;
  }
  /**
  The parent node that the position points into. Note that even if
  a position points into a text node, that node is not considered
  the parent—text nodes are ‘flat’ in this model, and have no content.
  */
  get parent() {
    return this.node(this.depth);
  }
  /**
  The root node in which the position was resolved.
  */
  get doc() {
    return this.node(0);
  }
  /**
  The ancestor node at the given level. `p.node(p.depth)` is the
  same as `p.parent`.
  */
  node(depth) {
    return this.path[this.resolveDepth(depth) * 3];
  }
  /**
  The index into the ancestor at the given level. If this points
  at the 3rd node in the 2nd paragraph on the top level, for
  example, `p.index(0)` is 1 and `p.index(1)` is 2.
  */
  index(depth) {
    return this.path[this.resolveDepth(depth) * 3 + 1];
  }
  /**
  The index pointing after this position into the ancestor at the
  given level.
  */
  indexAfter(depth) {
    depth = this.resolveDepth(depth);
    return this.index(depth) + (depth == this.depth && !this.textOffset ? 0 : 1);
  }
  /**
  The (absolute) position at the start of the node at the given
  level.
  */
  start(depth) {
    depth = this.resolveDepth(depth);
    return depth == 0 ? 0 : this.path[depth * 3 - 1] + 1;
  }
  /**
  The (absolute) position at the end of the node at the given
  level.
  */
  end(depth) {
    depth = this.resolveDepth(depth);
    return this.start(depth) + this.node(depth).content.size;
  }
  /**
  The (absolute) position directly before the wrapping node at the
  given level, or, when `depth` is `this.depth + 1`, the original
  position.
  */
  before(depth) {
    depth = this.resolveDepth(depth);
    if (!depth)
      throw new RangeError("There is no position before the top-level node");
    return depth == this.depth + 1 ? this.pos : this.path[depth * 3 - 1];
  }
  /**
  The (absolute) position directly after the wrapping node at the
  given level, or the original position when `depth` is `this.depth + 1`.
  */
  after(depth) {
    depth = this.resolveDepth(depth);
    if (!depth)
      throw new RangeError("There is no position after the top-level node");
    return depth == this.depth + 1 ? this.pos : this.path[depth * 3 - 1] + this.path[depth * 3].nodeSize;
  }
  /**
  When this position points into a text node, this returns the
  distance between the position and the start of the text node.
  Will be zero for positions that point between nodes.
  */
  get textOffset() {
    return this.pos - this.path[this.path.length - 1];
  }
  /**
  Get the node directly after the position, if any. If the position
  points into a text node, only the part of that node after the
  position is returned.
  */
  get nodeAfter() {
    let parent = this.parent, index2 = this.index(this.depth);
    if (index2 == parent.childCount)
      return null;
    let dOff = this.pos - this.path[this.path.length - 1], child = parent.child(index2);
    return dOff ? parent.child(index2).cut(dOff) : child;
  }
  /**
  Get the node directly before the position, if any. If the
  position points into a text node, only the part of that node
  before the position is returned.
  */
  get nodeBefore() {
    let index2 = this.index(this.depth);
    let dOff = this.pos - this.path[this.path.length - 1];
    if (dOff)
      return this.parent.child(index2).cut(0, dOff);
    return index2 == 0 ? null : this.parent.child(index2 - 1);
  }
  /**
  Get the position at the given index in the parent node at the
  given depth (which defaults to `this.depth`).
  */
  posAtIndex(index2, depth) {
    depth = this.resolveDepth(depth);
    let node3 = this.path[depth * 3], pos = depth == 0 ? 0 : this.path[depth * 3 - 1] + 1;
    for (let i2 = 0; i2 < index2; i2++)
      pos += node3.child(i2).nodeSize;
    return pos;
  }
  /**
  Get the marks at this position, factoring in the surrounding
  marks' [`inclusive`](https://prosemirror.net/docs/ref/#model.MarkSpec.inclusive) property. If the
  position is at the start of a non-empty node, the marks of the
  node after it (if any) are returned.
  */
  marks() {
    let parent = this.parent, index2 = this.index();
    if (parent.content.size == 0)
      return Mark$1.none;
    if (this.textOffset)
      return parent.child(index2).marks;
    let main = parent.maybeChild(index2 - 1), other = parent.maybeChild(index2);
    if (!main) {
      let tmp = main;
      main = other;
      other = tmp;
    }
    let marks = main.marks;
    for (var i2 = 0; i2 < marks.length; i2++)
      if (marks[i2].type.spec.inclusive === false && (!other || !marks[i2].isInSet(other.marks)))
        marks = marks[i2--].removeFromSet(marks);
    return marks;
  }
  /**
  Get the marks after the current position, if any, except those
  that are non-inclusive and not present at position `$end`. This
  is mostly useful for getting the set of marks to preserve after a
  deletion. Will return `null` if this position is at the end of
  its parent node or its parent node isn't a textblock (in which
  case no marks should be preserved).
  */
  marksAcross($end) {
    let after = this.parent.maybeChild(this.index());
    if (!after || !after.isInline)
      return null;
    let marks = after.marks, next2 = $end.parent.maybeChild($end.index());
    for (var i2 = 0; i2 < marks.length; i2++)
      if (marks[i2].type.spec.inclusive === false && (!next2 || !marks[i2].isInSet(next2.marks)))
        marks = marks[i2--].removeFromSet(marks);
    return marks;
  }
  /**
  The depth up to which this position and the given (non-resolved)
  position share the same parent nodes.
  */
  sharedDepth(pos) {
    for (let depth = this.depth; depth > 0; depth--)
      if (this.start(depth) <= pos && this.end(depth) >= pos)
        return depth;
    return 0;
  }
  /**
  Returns a range based on the place where this position and the
  given position diverge around block content. If both point into
  the same textblock, for example, a range around that textblock
  will be returned. If they point into different blocks, the range
  around those blocks in their shared ancestor is returned. You can
  pass in an optional predicate that will be called with a parent
  node to see if a range into that parent is acceptable.
  */
  blockRange(other = this, pred) {
    if (other.pos < this.pos)
      return other.blockRange(this);
    for (let d2 = this.depth - (this.parent.inlineContent || this.pos == other.pos ? 1 : 0); d2 >= 0; d2--)
      if (other.pos <= this.end(d2) && (!pred || pred(this.node(d2))))
        return new NodeRange(this, other, d2);
    return null;
  }
  /**
  Query whether the given position shares the same parent node.
  */
  sameParent(other) {
    return this.pos - this.parentOffset == other.pos - other.parentOffset;
  }
  /**
  Return the greater of this and the given position.
  */
  max(other) {
    return other.pos > this.pos ? other : this;
  }
  /**
  Return the smaller of this and the given position.
  */
  min(other) {
    return other.pos < this.pos ? other : this;
  }
  /**
  @internal
  */
  toString() {
    let str = "";
    for (let i2 = 1; i2 <= this.depth; i2++)
      str += (str ? "/" : "") + this.node(i2).type.name + "_" + this.index(i2 - 1);
    return str + ":" + this.parentOffset;
  }
  /**
  @internal
  */
  static resolve(doc2, pos) {
    if (!(pos >= 0 && pos <= doc2.content.size))
      throw new RangeError("Position " + pos + " out of range");
    let path = [];
    let start2 = 0, parentOffset = pos;
    for (let node3 = doc2; ; ) {
      let { index: index2, offset } = node3.content.findIndex(parentOffset);
      let rem = parentOffset - offset;
      path.push(node3, index2, start2 + offset);
      if (!rem)
        break;
      node3 = node3.child(index2);
      if (node3.isText)
        break;
      parentOffset = rem - 1;
      start2 += offset + 1;
    }
    return new ResolvedPos(pos, path, parentOffset);
  }
  /**
  @internal
  */
  static resolveCached(doc2, pos) {
    let cache2 = resolveCache.get(doc2);
    if (cache2) {
      for (let i2 = 0; i2 < cache2.elts.length; i2++) {
        let elt = cache2.elts[i2];
        if (elt.pos == pos)
          return elt;
      }
    } else {
      resolveCache.set(doc2, cache2 = new ResolveCache());
    }
    let result = cache2.elts[cache2.i] = ResolvedPos.resolve(doc2, pos);
    cache2.i = (cache2.i + 1) % resolveCacheSize;
    return result;
  }
}
class ResolveCache {
  static {
    __name(this, "ResolveCache");
  }
  constructor() {
    this.elts = [];
    this.i = 0;
  }
}
const resolveCacheSize = 12, resolveCache = /* @__PURE__ */ new WeakMap();
class NodeRange {
  static {
    __name(this, "NodeRange");
  }
  /**
  Construct a node range. `$from` and `$to` should point into the
  same node until at least the given `depth`, since a node range
  denotes an adjacent set of nodes in a single parent node.
  */
  constructor($from, $to, depth) {
    this.$from = $from;
    this.$to = $to;
    this.depth = depth;
  }
  /**
  The position at the start of the range.
  */
  get start() {
    return this.$from.before(this.depth + 1);
  }
  /**
  The position at the end of the range.
  */
  get end() {
    return this.$to.after(this.depth + 1);
  }
  /**
  The parent node that the range points into.
  */
  get parent() {
    return this.$from.node(this.depth);
  }
  /**
  The start index of the range in the parent node.
  */
  get startIndex() {
    return this.$from.index(this.depth);
  }
  /**
  The end index of the range in the parent node.
  */
  get endIndex() {
    return this.$to.indexAfter(this.depth);
  }
}
const emptyAttrs = /* @__PURE__ */ Object.create(null);
let Node$2 = class Node2 {
  static {
    __name(this, "Node");
  }
  /**
  @internal
  */
  constructor(type, attrs7, content3, marks = Mark$1.none) {
    this.type = type;
    this.attrs = attrs7;
    this.marks = marks;
    this.content = content3 || Fragment.empty;
  }
  /**
  The array of this node's child nodes.
  */
  get children() {
    return this.content.content;
  }
  /**
  The size of this node, as defined by the integer-based [indexing
  scheme](/docs/guide/#doc.indexing). For text nodes, this is the
  amount of characters. For other leaf nodes, it is one. For
  non-leaf nodes, it is the size of the content plus two (the
  start and end token).
  */
  get nodeSize() {
    return this.isLeaf ? 1 : 2 + this.content.size;
  }
  /**
  The number of children that the node has.
  */
  get childCount() {
    return this.content.childCount;
  }
  /**
  Get the child node at the given index. Raises an error when the
  index is out of range.
  */
  child(index2) {
    return this.content.child(index2);
  }
  /**
  Get the child node at the given index, if it exists.
  */
  maybeChild(index2) {
    return this.content.maybeChild(index2);
  }
  /**
  Call `f` for every child node, passing the node, its offset
  into this parent node, and its index.
  */
  forEach(f2) {
    this.content.forEach(f2);
  }
  /**
  Invoke a callback for all descendant nodes recursively between
  the given two positions that are relative to start of this
  node's content. The callback is invoked with the node, its
  position relative to the original node (method receiver),
  its parent node, and its child index. When the callback returns
  false for a given node, that node's children will not be
  recursed over. The last parameter can be used to specify a
  starting position to count from.
  */
  nodesBetween(from2, to, f2, startPos = 0) {
    this.content.nodesBetween(from2, to, f2, startPos, this);
  }
  /**
  Call the given callback for every descendant node. Doesn't
  descend into a node when the callback returns `false`.
  */
  descendants(f2) {
    this.nodesBetween(0, this.content.size, f2);
  }
  /**
  Concatenates all the text nodes found in this fragment and its
  children.
  */
  get textContent() {
    return this.isLeaf && this.type.spec.leafText ? this.type.spec.leafText(this) : this.textBetween(0, this.content.size, "");
  }
  /**
  Get all text between positions `from` and `to`. When
  `blockSeparator` is given, it will be inserted to separate text
  from different block nodes. If `leafText` is given, it'll be
  inserted for every non-text leaf node encountered, otherwise
  [`leafText`](https://prosemirror.net/docs/ref/#model.NodeSpec^leafText) will be used.
  */
  textBetween(from2, to, blockSeparator, leafText) {
    return this.content.textBetween(from2, to, blockSeparator, leafText);
  }
  /**
  Returns this node's first child, or `null` if there are no
  children.
  */
  get firstChild() {
    return this.content.firstChild;
  }
  /**
  Returns this node's last child, or `null` if there are no
  children.
  */
  get lastChild() {
    return this.content.lastChild;
  }
  /**
  Test whether two nodes represent the same piece of document.
  */
  eq(other) {
    return this == other || this.sameMarkup(other) && this.content.eq(other.content);
  }
  /**
  Compare the markup (type, attributes, and marks) of this node to
  those of another. Returns `true` if both have the same markup.
  */
  sameMarkup(other) {
    return this.hasMarkup(other.type, other.attrs, other.marks);
  }
  /**
  Check whether this node's markup correspond to the given type,
  attributes, and marks.
  */
  hasMarkup(type, attrs7, marks) {
    return this.type == type && compareDeep(this.attrs, attrs7 || type.defaultAttrs || emptyAttrs) && Mark$1.sameSet(this.marks, marks || Mark$1.none);
  }
  /**
  Create a new node with the same markup as this node, containing
  the given content (or empty, if no content is given).
  */
  copy(content3 = null) {
    if (content3 == this.content)
      return this;
    return new Node2(this.type, this.attrs, content3, this.marks);
  }
  /**
  Create a copy of this node, with the given set of marks instead
  of the node's own marks.
  */
  mark(marks) {
    return marks == this.marks ? this : new Node2(this.type, this.attrs, this.content, marks);
  }
  /**
  Create a copy of this node with only the content between the
  given positions. If `to` is not given, it defaults to the end of
  the node.
  */
  cut(from2, to = this.content.size) {
    if (from2 == 0 && to == this.content.size)
      return this;
    return this.copy(this.content.cut(from2, to));
  }
  /**
  Cut out the part of the document between the given positions, and
  return it as a `Slice` object.
  */
  slice(from2, to = this.content.size, includeParents = false) {
    if (from2 == to)
      return Slice.empty;
    let $from = this.resolve(from2), $to = this.resolve(to);
    let depth = includeParents ? 0 : $from.sharedDepth(to);
    let start2 = $from.start(depth), node3 = $from.node(depth);
    let content3 = node3.content.cut($from.pos - start2, $to.pos - start2);
    return new Slice(content3, $from.depth - depth, $to.depth - depth);
  }
  /**
  Replace the part of the document between the given positions with
  the given slice. The slice must 'fit', meaning its open sides
  must be able to connect to the surrounding content, and its
  content nodes must be valid children for the node they are placed
  into. If any of this is violated, an error of type
  [`ReplaceError`](https://prosemirror.net/docs/ref/#model.ReplaceError) is thrown.
  */
  replace(from2, to, slice2) {
    return replace$1(this.resolve(from2), this.resolve(to), slice2);
  }
  /**
  Find the node directly after the given position.
  */
  nodeAt(pos) {
    for (let node3 = this; ; ) {
      let { index: index2, offset } = node3.content.findIndex(pos);
      node3 = node3.maybeChild(index2);
      if (!node3)
        return null;
      if (offset == pos || node3.isText)
        return node3;
      pos -= offset + 1;
    }
  }
  /**
  Find the (direct) child node after the given offset, if any,
  and return it along with its index and offset relative to this
  node.
  */
  childAfter(pos) {
    let { index: index2, offset } = this.content.findIndex(pos);
    return { node: this.content.maybeChild(index2), index: index2, offset };
  }
  /**
  Find the (direct) child node before the given offset, if any,
  and return it along with its index and offset relative to this
  node.
  */
  childBefore(pos) {
    if (pos == 0)
      return { node: null, index: 0, offset: 0 };
    let { index: index2, offset } = this.content.findIndex(pos);
    if (offset < pos)
      return { node: this.content.child(index2), index: index2, offset };
    let node3 = this.content.child(index2 - 1);
    return { node: node3, index: index2 - 1, offset: offset - node3.nodeSize };
  }
  /**
  Resolve the given position in the document, returning an
  [object](https://prosemirror.net/docs/ref/#model.ResolvedPos) with information about its context.
  */
  resolve(pos) {
    return ResolvedPos.resolveCached(this, pos);
  }
  /**
  @internal
  */
  resolveNoCache(pos) {
    return ResolvedPos.resolve(this, pos);
  }
  /**
  Test whether a given mark or mark type occurs in this document
  between the two given positions.
  */
  rangeHasMark(from2, to, type) {
    let found2 = false;
    if (to > from2)
      this.nodesBetween(from2, to, (node3) => {
        if (type.isInSet(node3.marks))
          found2 = true;
        return !found2;
      });
    return found2;
  }
  /**
  True when this is a block (non-inline node)
  */
  get isBlock() {
    return this.type.isBlock;
  }
  /**
  True when this is a textblock node, a block node with inline
  content.
  */
  get isTextblock() {
    return this.type.isTextblock;
  }
  /**
  True when this node allows inline content.
  */
  get inlineContent() {
    return this.type.inlineContent;
  }
  /**
  True when this is an inline node (a text node or a node that can
  appear among text).
  */
  get isInline() {
    return this.type.isInline;
  }
  /**
  True when this is a text node.
  */
  get isText() {
    return this.type.isText;
  }
  /**
  True when this is a leaf node.
  */
  get isLeaf() {
    return this.type.isLeaf;
  }
  /**
  True when this is an atom, i.e. when it does not have directly
  editable content. This is usually the same as `isLeaf`, but can
  be configured with the [`atom` property](https://prosemirror.net/docs/ref/#model.NodeSpec.atom)
  on a node's spec (typically used when the node is displayed as
  an uneditable [node view](https://prosemirror.net/docs/ref/#view.NodeView)).
  */
  get isAtom() {
    return this.type.isAtom;
  }
  /**
  Return a string representation of this node for debugging
  purposes.
  */
  toString() {
    if (this.type.spec.toDebugString)
      return this.type.spec.toDebugString(this);
    let name2 = this.type.name;
    if (this.content.size)
      name2 += "(" + this.content.toStringInner() + ")";
    return wrapMarks(this.marks, name2);
  }
  /**
  Get the content match in this node at the given index.
  */
  contentMatchAt(index2) {
    let match2 = this.type.contentMatch.matchFragment(this.content, 0, index2);
    if (!match2)
      throw new Error("Called contentMatchAt on a node with invalid content");
    return match2;
  }
  /**
  Test whether replacing the range between `from` and `to` (by
  child index) with the given replacement fragment (which defaults
  to the empty fragment) would leave the node's content valid. You
  can optionally pass `start` and `end` indices into the
  replacement fragment.
  */
  canReplace(from2, to, replacement = Fragment.empty, start2 = 0, end = replacement.childCount) {
    let one = this.contentMatchAt(from2).matchFragment(replacement, start2, end);
    let two = one && one.matchFragment(this.content, to);
    if (!two || !two.validEnd)
      return false;
    for (let i2 = start2; i2 < end; i2++)
      if (!this.type.allowsMarks(replacement.child(i2).marks))
        return false;
    return true;
  }
  /**
  Test whether replacing the range `from` to `to` (by index) with
  a node of the given type would leave the node's content valid.
  */
  canReplaceWith(from2, to, type, marks) {
    if (marks && !this.type.allowsMarks(marks))
      return false;
    let start2 = this.contentMatchAt(from2).matchType(type);
    let end = start2 && start2.matchFragment(this.content, to);
    return end ? end.validEnd : false;
  }
  /**
  Test whether the given node's content could be appended to this
  node. If that node is empty, this will only return true if there
  is at least one node type that can appear in both nodes (to avoid
  merging completely incompatible nodes).
  */
  canAppend(other) {
    if (other.content.size)
      return this.canReplace(this.childCount, this.childCount, other.content);
    else
      return this.type.compatibleContent(other.type);
  }
  /**
  Check whether this node and its descendants conform to the
  schema, and raise an exception when they do not.
  */
  check() {
    this.type.checkContent(this.content);
    this.type.checkAttrs(this.attrs);
    let copy2 = Mark$1.none;
    for (let i2 = 0; i2 < this.marks.length; i2++) {
      let mark2 = this.marks[i2];
      mark2.type.checkAttrs(mark2.attrs);
      copy2 = mark2.addToSet(copy2);
    }
    if (!Mark$1.sameSet(copy2, this.marks))
      throw new RangeError(`Invalid collection of marks for node ${this.type.name}: ${this.marks.map((m2) => m2.type.name)}`);
    this.content.forEach((node3) => node3.check());
  }
  /**
  Return a JSON-serializeable representation of this node.
  */
  toJSON() {
    let obj = { type: this.type.name };
    for (let _2 in this.attrs) {
      obj.attrs = this.attrs;
      break;
    }
    if (this.content.size)
      obj.content = this.content.toJSON();
    if (this.marks.length)
      obj.marks = this.marks.map((n2) => n2.toJSON());
    return obj;
  }
  /**
  Deserialize a node from its JSON representation.
  */
  static fromJSON(schema2, json) {
    if (!json)
      throw new RangeError("Invalid input for Node.fromJSON");
    let marks = void 0;
    if (json.marks) {
      if (!Array.isArray(json.marks))
        throw new RangeError("Invalid mark data for Node.fromJSON");
      marks = json.marks.map(schema2.markFromJSON);
    }
    if (json.type == "text") {
      if (typeof json.text != "string")
        throw new RangeError("Invalid text node in JSON");
      return schema2.text(json.text, marks);
    }
    let content3 = Fragment.fromJSON(schema2, json.content);
    let node3 = schema2.nodeType(json.type).create(json.attrs, content3, marks);
    node3.type.checkAttrs(node3.attrs);
    return node3;
  }
};
Node$2.prototype.text = void 0;
class TextNode extends Node$2 {
  static {
    __name(this, "TextNode");
  }
  /**
  @internal
  */
  constructor(type, attrs7, content3, marks) {
    super(type, attrs7, null, marks);
    if (!content3)
      throw new RangeError("Empty text nodes are not allowed");
    this.text = content3;
  }
  toString() {
    if (this.type.spec.toDebugString)
      return this.type.spec.toDebugString(this);
    return wrapMarks(this.marks, JSON.stringify(this.text));
  }
  get textContent() {
    return this.text;
  }
  textBetween(from2, to) {
    return this.text.slice(from2, to);
  }
  get nodeSize() {
    return this.text.length;
  }
  mark(marks) {
    return marks == this.marks ? this : new TextNode(this.type, this.attrs, this.text, marks);
  }
  withText(text2) {
    if (text2 == this.text)
      return this;
    return new TextNode(this.type, this.attrs, text2, this.marks);
  }
  cut(from2 = 0, to = this.text.length) {
    if (from2 == 0 && to == this.text.length)
      return this;
    return this.withText(this.text.slice(from2, to));
  }
  eq(other) {
    return this.sameMarkup(other) && this.text == other.text;
  }
  toJSON() {
    let base2 = super.toJSON();
    base2.text = this.text;
    return base2;
  }
}
function wrapMarks(marks, str) {
  for (let i2 = marks.length - 1; i2 >= 0; i2--)
    str = marks[i2].type.name + "(" + str + ")";
  return str;
}
__name(wrapMarks, "wrapMarks");
class ContentMatch {
  static {
    __name(this, "ContentMatch");
  }
  /**
  @internal
  */
  constructor(validEnd) {
    this.validEnd = validEnd;
    this.next = [];
    this.wrapCache = [];
  }
  /**
  @internal
  */
  static parse(string, nodeTypes) {
    let stream = new TokenStream(string, nodeTypes);
    if (stream.next == null)
      return ContentMatch.empty;
    let expr = parseExpr(stream);
    if (stream.next)
      stream.err("Unexpected trailing text");
    let match2 = dfa(nfa(expr));
    checkForDeadEnds(match2, stream);
    return match2;
  }
  /**
  Match a node type, returning a match after that node if
  successful.
  */
  matchType(type) {
    for (let i2 = 0; i2 < this.next.length; i2++)
      if (this.next[i2].type == type)
        return this.next[i2].next;
    return null;
  }
  /**
  Try to match a fragment. Returns the resulting match when
  successful.
  */
  matchFragment(frag, start2 = 0, end = frag.childCount) {
    let cur = this;
    for (let i2 = start2; cur && i2 < end; i2++)
      cur = cur.matchType(frag.child(i2).type);
    return cur;
  }
  /**
  @internal
  */
  get inlineContent() {
    return this.next.length != 0 && this.next[0].type.isInline;
  }
  /**
  Get the first matching node type at this match position that can
  be generated.
  */
  get defaultType() {
    for (let i2 = 0; i2 < this.next.length; i2++) {
      let { type } = this.next[i2];
      if (!(type.isText || type.hasRequiredAttrs()))
        return type;
    }
    return null;
  }
  /**
  @internal
  */
  compatible(other) {
    for (let i2 = 0; i2 < this.next.length; i2++)
      for (let j2 = 0; j2 < other.next.length; j2++)
        if (this.next[i2].type == other.next[j2].type)
          return true;
    return false;
  }
  /**
  Try to match the given fragment, and if that fails, see if it can
  be made to match by inserting nodes in front of it. When
  successful, return a fragment of inserted nodes (which may be
  empty if nothing had to be inserted). When `toEnd` is true, only
  return a fragment if the resulting match goes to the end of the
  content expression.
  */
  fillBefore(after, toEnd = false, startIndex = 0) {
    let seen2 = [this];
    function search3(match2, types) {
      let finished = match2.matchFragment(after, startIndex);
      if (finished && (!toEnd || finished.validEnd))
        return Fragment.from(types.map((tp) => tp.createAndFill()));
      for (let i2 = 0; i2 < match2.next.length; i2++) {
        let { type, next: next2 } = match2.next[i2];
        if (!(type.isText || type.hasRequiredAttrs()) && seen2.indexOf(next2) == -1) {
          seen2.push(next2);
          let found2 = search3(next2, types.concat(type));
          if (found2)
            return found2;
        }
      }
      return null;
    }
    __name(search3, "search");
    return search3(this, []);
  }
  /**
  Find a set of wrapping node types that would allow a node of the
  given type to appear at this position. The result may be empty
  (when it fits directly) and will be null when no such wrapping
  exists.
  */
  findWrapping(target2) {
    for (let i2 = 0; i2 < this.wrapCache.length; i2 += 2)
      if (this.wrapCache[i2] == target2)
        return this.wrapCache[i2 + 1];
    let computed2 = this.computeWrapping(target2);
    this.wrapCache.push(target2, computed2);
    return computed2;
  }
  /**
  @internal
  */
  computeWrapping(target2) {
    let seen2 = /* @__PURE__ */ Object.create(null), active4 = [{ match: this, type: null, via: null }];
    while (active4.length) {
      let current = active4.shift(), match2 = current.match;
      if (match2.matchType(target2)) {
        let result = [];
        for (let obj = current; obj.type; obj = obj.via)
          result.push(obj.type);
        return result.reverse();
      }
      for (let i2 = 0; i2 < match2.next.length; i2++) {
        let { type, next: next2 } = match2.next[i2];
        if (!type.isLeaf && !type.hasRequiredAttrs() && !(type.name in seen2) && (!current.type || next2.validEnd)) {
          active4.push({ match: type.contentMatch, type, via: current });
          seen2[type.name] = true;
        }
      }
    }
    return null;
  }
  /**
  The number of outgoing edges this node has in the finite
  automaton that describes the content expression.
  */
  get edgeCount() {
    return this.next.length;
  }
  /**
  Get the _n_​th outgoing edge from this node in the finite
  automaton that describes the content expression.
  */
  edge(n2) {
    if (n2 >= this.next.length)
      throw new RangeError(`There's no ${n2}th edge in this content match`);
    return this.next[n2];
  }
  /**
  @internal
  */
  toString() {
    let seen2 = [];
    function scan(m2) {
      seen2.push(m2);
      for (let i2 = 0; i2 < m2.next.length; i2++)
        if (seen2.indexOf(m2.next[i2].next) == -1)
          scan(m2.next[i2].next);
    }
    __name(scan, "scan");
    scan(this);
    return seen2.map((m2, i2) => {
      let out = i2 + (m2.validEnd ? "*" : " ") + " ";
      for (let i3 = 0; i3 < m2.next.length; i3++)
        out += (i3 ? ", " : "") + m2.next[i3].type.name + "->" + seen2.indexOf(m2.next[i3].next);
      return out;
    }).join("\n");
  }
}
ContentMatch.empty = new ContentMatch(true);
class TokenStream {
  static {
    __name(this, "TokenStream");
  }
  constructor(string, nodeTypes) {
    this.string = string;
    this.nodeTypes = nodeTypes;
    this.inline = null;
    this.pos = 0;
    this.tokens = string.split(/\s*(?=\b|\W|$)/);
    if (this.tokens[this.tokens.length - 1] == "")
      this.tokens.pop();
    if (this.tokens[0] == "")
      this.tokens.shift();
  }
  get next() {
    return this.tokens[this.pos];
  }
  eat(tok) {
    return this.next == tok && (this.pos++ || true);
  }
  err(str) {
    throw new SyntaxError(str + " (in content expression '" + this.string + "')");
  }
}
function parseExpr(stream) {
  let exprs = [];
  do {
    exprs.push(parseExprSeq(stream));
  } while (stream.eat("|"));
  return exprs.length == 1 ? exprs[0] : { type: "choice", exprs };
}
__name(parseExpr, "parseExpr");
function parseExprSeq(stream) {
  let exprs = [];
  do {
    exprs.push(parseExprSubscript(stream));
  } while (stream.next && stream.next != ")" && stream.next != "|");
  return exprs.length == 1 ? exprs[0] : { type: "seq", exprs };
}
__name(parseExprSeq, "parseExprSeq");
function parseExprSubscript(stream) {
  let expr = parseExprAtom(stream);
  for (; ; ) {
    if (stream.eat("+"))
      expr = { type: "plus", expr };
    else if (stream.eat("*"))
      expr = { type: "star", expr };
    else if (stream.eat("?"))
      expr = { type: "opt", expr };
    else if (stream.eat("{"))
      expr = parseExprRange(stream, expr);
    else
      break;
  }
  return expr;
}
__name(parseExprSubscript, "parseExprSubscript");
function parseNum(stream) {
  if (/\D/.test(stream.next))
    stream.err("Expected number, got '" + stream.next + "'");
  let result = Number(stream.next);
  stream.pos++;
  return result;
}
__name(parseNum, "parseNum");
function parseExprRange(stream, expr) {
  let min = parseNum(stream), max = min;
  if (stream.eat(",")) {
    if (stream.next != "}")
      max = parseNum(stream);
    else
      max = -1;
  }
  if (!stream.eat("}"))
    stream.err("Unclosed braced range");
  return { type: "range", min, max, expr };
}
__name(parseExprRange, "parseExprRange");
function resolveName(stream, name2) {
  let types = stream.nodeTypes, type = types[name2];
  if (type)
    return [type];
  let result = [];
  for (let typeName in types) {
    let type2 = types[typeName];
    if (type2.isInGroup(name2))
      result.push(type2);
  }
  if (result.length == 0)
    stream.err("No node type or group '" + name2 + "' found");
  return result;
}
__name(resolveName, "resolveName");
function parseExprAtom(stream) {
  if (stream.eat("(")) {
    let expr = parseExpr(stream);
    if (!stream.eat(")"))
      stream.err("Missing closing paren");
    return expr;
  } else if (!/\W/.test(stream.next)) {
    let exprs = resolveName(stream, stream.next).map((type) => {
      if (stream.inline == null)
        stream.inline = type.isInline;
      else if (stream.inline != type.isInline)
        stream.err("Mixing inline and block content");
      return { type: "name", value: type };
    });
    stream.pos++;
    return exprs.length == 1 ? exprs[0] : { type: "choice", exprs };
  } else {
    stream.err("Unexpected token '" + stream.next + "'");
  }
}
__name(parseExprAtom, "parseExprAtom");
function nfa(expr) {
  let nfa2 = [[]];
  connect(compile2(expr, 0), node3());
  return nfa2;
  function node3() {
    return nfa2.push([]) - 1;
  }
  __name(node3, "node");
  function edge(from2, to, term) {
    let edge2 = { term, to };
    nfa2[from2].push(edge2);
    return edge2;
  }
  __name(edge, "edge");
  function connect(edges, to) {
    edges.forEach((edge2) => edge2.to = to);
  }
  __name(connect, "connect");
  function compile2(expr2, from2) {
    if (expr2.type == "choice") {
      return expr2.exprs.reduce((out, expr3) => out.concat(compile2(expr3, from2)), []);
    } else if (expr2.type == "seq") {
      for (let i2 = 0; ; i2++) {
        let next2 = compile2(expr2.exprs[i2], from2);
        if (i2 == expr2.exprs.length - 1)
          return next2;
        connect(next2, from2 = node3());
      }
    } else if (expr2.type == "star") {
      let loop = node3();
      edge(from2, loop);
      connect(compile2(expr2.expr, loop), loop);
      return [edge(loop)];
    } else if (expr2.type == "plus") {
      let loop = node3();
      connect(compile2(expr2.expr, from2), loop);
      connect(compile2(expr2.expr, loop), loop);
      return [edge(loop)];
    } else if (expr2.type == "opt") {
      return [edge(from2)].concat(compile2(expr2.expr, from2));
    } else if (expr2.type == "range") {
      let cur = from2;
      for (let i2 = 0; i2 < expr2.min; i2++) {
        let next2 = node3();
        connect(compile2(expr2.expr, cur), next2);
        cur = next2;
      }
      if (expr2.max == -1) {
        connect(compile2(expr2.expr, cur), cur);
      } else {
        for (let i2 = expr2.min; i2 < expr2.max; i2++) {
          let next2 = node3();
          edge(cur, next2);
          connect(compile2(expr2.expr, cur), next2);
          cur = next2;
        }
      }
      return [edge(cur)];
    } else if (expr2.type == "name") {
      return [edge(from2, void 0, expr2.value)];
    } else {
      throw new Error("Unknown expr type");
    }
  }
  __name(compile2, "compile");
}
__name(nfa, "nfa");
function cmp(a2, b2) {
  return b2 - a2;
}
__name(cmp, "cmp");
function nullFrom(nfa2, node3) {
  let result = [];
  scan(node3);
  return result.sort(cmp);
  function scan(node4) {
    let edges = nfa2[node4];
    if (edges.length == 1 && !edges[0].term)
      return scan(edges[0].to);
    result.push(node4);
    for (let i2 = 0; i2 < edges.length; i2++) {
      let { term, to } = edges[i2];
      if (!term && result.indexOf(to) == -1)
        scan(to);
    }
  }
  __name(scan, "scan");
}
__name(nullFrom, "nullFrom");
function dfa(nfa2) {
  let labeled = /* @__PURE__ */ Object.create(null);
  return explore(nullFrom(nfa2, 0));
  function explore(states) {
    let out = [];
    states.forEach((node3) => {
      nfa2[node3].forEach(({ term, to }) => {
        if (!term)
          return;
        let set3;
        for (let i2 = 0; i2 < out.length; i2++)
          if (out[i2][0] == term)
            set3 = out[i2][1];
        nullFrom(nfa2, to).forEach((node4) => {
          if (!set3)
            out.push([term, set3 = []]);
          if (set3.indexOf(node4) == -1)
            set3.push(node4);
        });
      });
    });
    let state = labeled[states.join(",")] = new ContentMatch(states.indexOf(nfa2.length - 1) > -1);
    for (let i2 = 0; i2 < out.length; i2++) {
      let states2 = out[i2][1].sort(cmp);
      state.next.push({ type: out[i2][0], next: labeled[states2.join(",")] || explore(states2) });
    }
    return state;
  }
  __name(explore, "explore");
}
__name(dfa, "dfa");
function checkForDeadEnds(match2, stream) {
  for (let i2 = 0, work = [match2]; i2 < work.length; i2++) {
    let state = work[i2], dead = !state.validEnd, nodes = [];
    for (let j2 = 0; j2 < state.next.length; j2++) {
      let { type, next: next2 } = state.next[j2];
      nodes.push(type.name);
      if (dead && !(type.isText || type.hasRequiredAttrs()))
        dead = false;
      if (work.indexOf(next2) == -1)
        work.push(next2);
    }
    if (dead)
      stream.err("Only non-generatable nodes (" + nodes.join(", ") + ") in a required position (see https://prosemirror.net/docs/guide/#generatable)");
  }
}
__name(checkForDeadEnds, "checkForDeadEnds");
function defaultAttrs(attrs7) {
  let defaults2 = /* @__PURE__ */ Object.create(null);
  for (let attrName in attrs7) {
    let attr = attrs7[attrName];
    if (!attr.hasDefault)
      return null;
    defaults2[attrName] = attr.default;
  }
  return defaults2;
}
__name(defaultAttrs, "defaultAttrs");
function computeAttrs(attrs7, value3) {
  let built = /* @__PURE__ */ Object.create(null);
  for (let name2 in attrs7) {
    let given = value3 && value3[name2];
    if (given === void 0) {
      let attr = attrs7[name2];
      if (attr.hasDefault)
        given = attr.default;
      else
        throw new RangeError("No value supplied for attribute " + name2);
    }
    built[name2] = given;
  }
  return built;
}
__name(computeAttrs, "computeAttrs");
function checkAttrs(attrs7, values, type, name2) {
  for (let name3 in values)
    if (!(name3 in attrs7))
      throw new RangeError(`Unsupported attribute ${name3} for ${type} of type ${name3}`);
  for (let name3 in attrs7) {
    let attr = attrs7[name3];
    if (attr.validate)
      attr.validate(values[name3]);
  }
}
__name(checkAttrs, "checkAttrs");
function initAttrs(typeName, attrs7) {
  let result = /* @__PURE__ */ Object.create(null);
  if (attrs7)
    for (let name2 in attrs7)
      result[name2] = new Attribute(typeName, name2, attrs7[name2]);
  return result;
}
__name(initAttrs, "initAttrs");
let NodeType$1 = class NodeType2 {
  static {
    __name(this, "NodeType");
  }
  /**
  @internal
  */
  constructor(name2, schema2, spec) {
    this.name = name2;
    this.schema = schema2;
    this.spec = spec;
    this.markSet = null;
    this.groups = spec.group ? spec.group.split(" ") : [];
    this.attrs = initAttrs(name2, spec.attrs);
    this.defaultAttrs = defaultAttrs(this.attrs);
    this.contentMatch = null;
    this.inlineContent = null;
    this.isBlock = !(spec.inline || name2 == "text");
    this.isText = name2 == "text";
  }
  /**
  True if this is an inline type.
  */
  get isInline() {
    return !this.isBlock;
  }
  /**
  True if this is a textblock type, a block that contains inline
  content.
  */
  get isTextblock() {
    return this.isBlock && this.inlineContent;
  }
  /**
  True for node types that allow no content.
  */
  get isLeaf() {
    return this.contentMatch == ContentMatch.empty;
  }
  /**
  True when this node is an atom, i.e. when it does not have
  directly editable content.
  */
  get isAtom() {
    return this.isLeaf || !!this.spec.atom;
  }
  /**
  Return true when this node type is part of the given
  [group](https://prosemirror.net/docs/ref/#model.NodeSpec.group).
  */
  isInGroup(group) {
    return this.groups.indexOf(group) > -1;
  }
  /**
  The node type's [whitespace](https://prosemirror.net/docs/ref/#model.NodeSpec.whitespace) option.
  */
  get whitespace() {
    return this.spec.whitespace || (this.spec.code ? "pre" : "normal");
  }
  /**
  Tells you whether this node type has any required attributes.
  */
  hasRequiredAttrs() {
    for (let n2 in this.attrs)
      if (this.attrs[n2].isRequired)
        return true;
    return false;
  }
  /**
  Indicates whether this node allows some of the same content as
  the given node type.
  */
  compatibleContent(other) {
    return this == other || this.contentMatch.compatible(other.contentMatch);
  }
  /**
  @internal
  */
  computeAttrs(attrs7) {
    if (!attrs7 && this.defaultAttrs)
      return this.defaultAttrs;
    else
      return computeAttrs(this.attrs, attrs7);
  }
  /**
  Create a `Node` of this type. The given attributes are
  checked and defaulted (you can pass `null` to use the type's
  defaults entirely, if no required attributes exist). `content`
  may be a `Fragment`, a node, an array of nodes, or
  `null`. Similarly `marks` may be `null` to default to the empty
  set of marks.
  */
  create(attrs7 = null, content3, marks) {
    if (this.isText)
      throw new Error("NodeType.create can't construct text nodes");
    return new Node$2(this, this.computeAttrs(attrs7), Fragment.from(content3), Mark$1.setFrom(marks));
  }
  /**
  Like [`create`](https://prosemirror.net/docs/ref/#model.NodeType.create), but check the given content
  against the node type's content restrictions, and throw an error
  if it doesn't match.
  */
  createChecked(attrs7 = null, content3, marks) {
    content3 = Fragment.from(content3);
    this.checkContent(content3);
    return new Node$2(this, this.computeAttrs(attrs7), content3, Mark$1.setFrom(marks));
  }
  /**
  Like [`create`](https://prosemirror.net/docs/ref/#model.NodeType.create), but see if it is
  necessary to add nodes to the start or end of the given fragment
  to make it fit the node. If no fitting wrapping can be found,
  return null. Note that, due to the fact that required nodes can
  always be created, this will always succeed if you pass null or
  `Fragment.empty` as content.
  */
  createAndFill(attrs7 = null, content3, marks) {
    attrs7 = this.computeAttrs(attrs7);
    content3 = Fragment.from(content3);
    if (content3.size) {
      let before = this.contentMatch.fillBefore(content3);
      if (!before)
        return null;
      content3 = before.append(content3);
    }
    let matched = this.contentMatch.matchFragment(content3);
    let after = matched && matched.fillBefore(Fragment.empty, true);
    if (!after)
      return null;
    return new Node$2(this, attrs7, content3.append(after), Mark$1.setFrom(marks));
  }
  /**
  Returns true if the given fragment is valid content for this node
  type.
  */
  validContent(content3) {
    let result = this.contentMatch.matchFragment(content3);
    if (!result || !result.validEnd)
      return false;
    for (let i2 = 0; i2 < content3.childCount; i2++)
      if (!this.allowsMarks(content3.child(i2).marks))
        return false;
    return true;
  }
  /**
  Throws a RangeError if the given fragment is not valid content for this
  node type.
  @internal
  */
  checkContent(content3) {
    if (!this.validContent(content3))
      throw new RangeError(`Invalid content for node ${this.name}: ${content3.toString().slice(0, 50)}`);
  }
  /**
  @internal
  */
  checkAttrs(attrs7) {
    checkAttrs(this.attrs, attrs7, "node", this.name);
  }
  /**
  Check whether the given mark type is allowed in this node.
  */
  allowsMarkType(markType) {
    return this.markSet == null || this.markSet.indexOf(markType) > -1;
  }
  /**
  Test whether the given set of marks are allowed in this node.
  */
  allowsMarks(marks) {
    if (this.markSet == null)
      return true;
    for (let i2 = 0; i2 < marks.length; i2++)
      if (!this.allowsMarkType(marks[i2].type))
        return false;
    return true;
  }
  /**
  Removes the marks that are not allowed in this node from the given set.
  */
  allowedMarks(marks) {
    if (this.markSet == null)
      return marks;
    let copy2;
    for (let i2 = 0; i2 < marks.length; i2++) {
      if (!this.allowsMarkType(marks[i2].type)) {
        if (!copy2)
          copy2 = marks.slice(0, i2);
      } else if (copy2) {
        copy2.push(marks[i2]);
      }
    }
    return !copy2 ? marks : copy2.length ? copy2 : Mark$1.none;
  }
  /**
  @internal
  */
  static compile(nodes, schema2) {
    let result = /* @__PURE__ */ Object.create(null);
    nodes.forEach((name2, spec) => result[name2] = new NodeType2(name2, schema2, spec));
    let topType = schema2.spec.topNode || "doc";
    if (!result[topType])
      throw new RangeError("Schema is missing its top node type ('" + topType + "')");
    if (!result.text)
      throw new RangeError("Every schema needs a 'text' type");
    for (let _2 in result.text.attrs)
      throw new RangeError("The text node type should not have attributes");
    return result;
  }
};
function validateType(typeName, attrName, type) {
  let types = type.split("|");
  return (value3) => {
    let name2 = value3 === null ? "null" : typeof value3;
    if (types.indexOf(name2) < 0)
      throw new RangeError(`Expected value of type ${types} for attribute ${attrName} on type ${typeName}, got ${name2}`);
  };
}
__name(validateType, "validateType");
class Attribute {
  static {
    __name(this, "Attribute");
  }
  constructor(typeName, attrName, options5) {
    this.hasDefault = Object.prototype.hasOwnProperty.call(options5, "default");
    this.default = options5.default;
    this.validate = typeof options5.validate == "string" ? validateType(typeName, attrName, options5.validate) : options5.validate;
  }
  get isRequired() {
    return !this.hasDefault;
  }
}
class MarkType {
  static {
    __name(this, "MarkType");
  }
  /**
  @internal
  */
  constructor(name2, rank, schema2, spec) {
    this.name = name2;
    this.rank = rank;
    this.schema = schema2;
    this.spec = spec;
    this.attrs = initAttrs(name2, spec.attrs);
    this.excluded = null;
    let defaults2 = defaultAttrs(this.attrs);
    this.instance = defaults2 ? new Mark$1(this, defaults2) : null;
  }
  /**
  Create a mark of this type. `attrs` may be `null` or an object
  containing only some of the mark's attributes. The others, if
  they have defaults, will be added.
  */
  create(attrs7 = null) {
    if (!attrs7 && this.instance)
      return this.instance;
    return new Mark$1(this, computeAttrs(this.attrs, attrs7));
  }
  /**
  @internal
  */
  static compile(marks, schema2) {
    let result = /* @__PURE__ */ Object.create(null), rank = 0;
    marks.forEach((name2, spec) => result[name2] = new MarkType(name2, rank++, schema2, spec));
    return result;
  }
  /**
  When there is a mark of this type in the given set, a new set
  without it is returned. Otherwise, the input set is returned.
  */
  removeFromSet(set3) {
    for (var i2 = 0; i2 < set3.length; i2++)
      if (set3[i2].type == this) {
        set3 = set3.slice(0, i2).concat(set3.slice(i2 + 1));
        i2--;
      }
    return set3;
  }
  /**
  Tests whether there is a mark of this type in the given set.
  */
  isInSet(set3) {
    for (let i2 = 0; i2 < set3.length; i2++)
      if (set3[i2].type == this)
        return set3[i2];
  }
  /**
  @internal
  */
  checkAttrs(attrs7) {
    checkAttrs(this.attrs, attrs7, "mark", this.name);
  }
  /**
  Queries whether a given mark type is
  [excluded](https://prosemirror.net/docs/ref/#model.MarkSpec.excludes) by this one.
  */
  excludes(other) {
    return this.excluded.indexOf(other) > -1;
  }
}
class Schema {
  static {
    __name(this, "Schema");
  }
  /**
  Construct a schema from a schema [specification](https://prosemirror.net/docs/ref/#model.SchemaSpec).
  */
  constructor(spec) {
    this.linebreakReplacement = null;
    this.cached = /* @__PURE__ */ Object.create(null);
    let instanceSpec = this.spec = {};
    for (let prop2 in spec)
      instanceSpec[prop2] = spec[prop2];
    instanceSpec.nodes = OrderedMap.from(spec.nodes), instanceSpec.marks = OrderedMap.from(spec.marks || {}), this.nodes = NodeType$1.compile(this.spec.nodes, this);
    this.marks = MarkType.compile(this.spec.marks, this);
    let contentExprCache = /* @__PURE__ */ Object.create(null);
    for (let prop2 in this.nodes) {
      if (prop2 in this.marks)
        throw new RangeError(prop2 + " can not be both a node and a mark");
      let type = this.nodes[prop2], contentExpr = type.spec.content || "", markExpr = type.spec.marks;
      type.contentMatch = contentExprCache[contentExpr] || (contentExprCache[contentExpr] = ContentMatch.parse(contentExpr, this.nodes));
      type.inlineContent = type.contentMatch.inlineContent;
      if (type.spec.linebreakReplacement) {
        if (this.linebreakReplacement)
          throw new RangeError("Multiple linebreak nodes defined");
        if (!type.isInline || !type.isLeaf)
          throw new RangeError("Linebreak replacement nodes must be inline leaf nodes");
        this.linebreakReplacement = type;
      }
      type.markSet = markExpr == "_" ? null : markExpr ? gatherMarks(this, markExpr.split(" ")) : markExpr == "" || !type.inlineContent ? [] : null;
    }
    for (let prop2 in this.marks) {
      let type = this.marks[prop2], excl = type.spec.excludes;
      type.excluded = excl == null ? [type] : excl == "" ? [] : gatherMarks(this, excl.split(" "));
    }
    this.nodeFromJSON = this.nodeFromJSON.bind(this);
    this.markFromJSON = this.markFromJSON.bind(this);
    this.topNodeType = this.nodes[this.spec.topNode || "doc"];
    this.cached.wrappings = /* @__PURE__ */ Object.create(null);
  }
  /**
  Create a node in this schema. The `type` may be a string or a
  `NodeType` instance. Attributes will be extended with defaults,
  `content` may be a `Fragment`, `null`, a `Node`, or an array of
  nodes.
  */
  node(type, attrs7 = null, content3, marks) {
    if (typeof type == "string")
      type = this.nodeType(type);
    else if (!(type instanceof NodeType$1))
      throw new RangeError("Invalid node type: " + type);
    else if (type.schema != this)
      throw new RangeError("Node type from different schema used (" + type.name + ")");
    return type.createChecked(attrs7, content3, marks);
  }
  /**
  Create a text node in the schema. Empty text nodes are not
  allowed.
  */
  text(text2, marks) {
    let type = this.nodes.text;
    return new TextNode(type, type.defaultAttrs, text2, Mark$1.setFrom(marks));
  }
  /**
  Create a mark with the given type and attributes.
  */
  mark(type, attrs7) {
    if (typeof type == "string")
      type = this.marks[type];
    return type.create(attrs7);
  }
  /**
  Deserialize a node from its JSON representation. This method is
  bound.
  */
  nodeFromJSON(json) {
    return Node$2.fromJSON(this, json);
  }
  /**
  Deserialize a mark from its JSON representation. This method is
  bound.
  */
  markFromJSON(json) {
    return Mark$1.fromJSON(this, json);
  }
  /**
  @internal
  */
  nodeType(name2) {
    let found2 = this.nodes[name2];
    if (!found2)
      throw new RangeError("Unknown node type: " + name2);
    return found2;
  }
}
function gatherMarks(schema2, marks) {
  let found2 = [];
  for (let i2 = 0; i2 < marks.length; i2++) {
    let name2 = marks[i2], mark2 = schema2.marks[name2], ok = mark2;
    if (mark2) {
      found2.push(mark2);
    } else {
      for (let prop2 in schema2.marks) {
        let mark3 = schema2.marks[prop2];
        if (name2 == "_" || mark3.spec.group && mark3.spec.group.split(" ").indexOf(name2) > -1)
          found2.push(ok = mark3);
      }
    }
    if (!ok)
      throw new SyntaxError("Unknown mark type: '" + marks[i2] + "'");
  }
  return found2;
}
__name(gatherMarks, "gatherMarks");
function isTagRule(rule) {
  return rule.tag != null;
}
__name(isTagRule, "isTagRule");
function isStyleRule(rule) {
  return rule.style != null;
}
__name(isStyleRule, "isStyleRule");
class DOMParser {
  static {
    __name(this, "DOMParser");
  }
  /**
  Create a parser that targets the given schema, using the given
  parsing rules.
  */
  constructor(schema2, rules) {
    this.schema = schema2;
    this.rules = rules;
    this.tags = [];
    this.styles = [];
    let matchedStyles = this.matchedStyles = [];
    rules.forEach((rule) => {
      if (isTagRule(rule)) {
        this.tags.push(rule);
      } else if (isStyleRule(rule)) {
        let prop2 = /[^=]*/.exec(rule.style)[0];
        if (matchedStyles.indexOf(prop2) < 0)
          matchedStyles.push(prop2);
        this.styles.push(rule);
      }
    });
    this.normalizeLists = !this.tags.some((r2) => {
      if (!/^(ul|ol)\b/.test(r2.tag) || !r2.node)
        return false;
      let node3 = schema2.nodes[r2.node];
      return node3.contentMatch.matchType(node3);
    });
  }
  /**
  Parse a document from the content of a DOM node.
  */
  parse(dom, options5 = {}) {
    let context = new ParseContext(this, options5, false);
    context.addAll(dom, Mark$1.none, options5.from, options5.to);
    return context.finish();
  }
  /**
  Parses the content of the given DOM node, like
  [`parse`](https://prosemirror.net/docs/ref/#model.DOMParser.parse), and takes the same set of
  options. But unlike that method, which produces a whole node,
  this one returns a slice that is open at the sides, meaning that
  the schema constraints aren't applied to the start of nodes to
  the left of the input and the end of nodes at the end.
  */
  parseSlice(dom, options5 = {}) {
    let context = new ParseContext(this, options5, true);
    context.addAll(dom, Mark$1.none, options5.from, options5.to);
    return Slice.maxOpen(context.finish());
  }
  /**
  @internal
  */
  matchTag(dom, context, after) {
    for (let i2 = after ? this.tags.indexOf(after) + 1 : 0; i2 < this.tags.length; i2++) {
      let rule = this.tags[i2];
      if (matches(dom, rule.tag) && (rule.namespace === void 0 || dom.namespaceURI == rule.namespace) && (!rule.context || context.matchesContext(rule.context))) {
        if (rule.getAttrs) {
          let result = rule.getAttrs(dom);
          if (result === false)
            continue;
          rule.attrs = result || void 0;
        }
        return rule;
      }
    }
  }
  /**
  @internal
  */
  matchStyle(prop2, value3, context, after) {
    for (let i2 = after ? this.styles.indexOf(after) + 1 : 0; i2 < this.styles.length; i2++) {
      let rule = this.styles[i2], style2 = rule.style;
      if (style2.indexOf(prop2) != 0 || rule.context && !context.matchesContext(rule.context) || // Test that the style string either precisely matches the prop,
      // or has an '=' sign after the prop, followed by the given
      // value.
      style2.length > prop2.length && (style2.charCodeAt(prop2.length) != 61 || style2.slice(prop2.length + 1) != value3))
        continue;
      if (rule.getAttrs) {
        let result = rule.getAttrs(value3);
        if (result === false)
          continue;
        rule.attrs = result || void 0;
      }
      return rule;
    }
  }
  /**
  @internal
  */
  static schemaRules(schema2) {
    let result = [];
    function insert2(rule) {
      let priority = rule.priority == null ? 50 : rule.priority, i2 = 0;
      for (; i2 < result.length; i2++) {
        let next2 = result[i2], nextPriority = next2.priority == null ? 50 : next2.priority;
        if (nextPriority < priority)
          break;
      }
      result.splice(i2, 0, rule);
    }
    __name(insert2, "insert");
    for (let name2 in schema2.marks) {
      let rules = schema2.marks[name2].spec.parseDOM;
      if (rules)
        rules.forEach((rule) => {
          insert2(rule = copy(rule));
          if (!(rule.mark || rule.ignore || rule.clearMark))
            rule.mark = name2;
        });
    }
    for (let name2 in schema2.nodes) {
      let rules = schema2.nodes[name2].spec.parseDOM;
      if (rules)
        rules.forEach((rule) => {
          insert2(rule = copy(rule));
          if (!(rule.node || rule.ignore || rule.mark))
            rule.node = name2;
        });
    }
    return result;
  }
  /**
  Construct a DOM parser using the parsing rules listed in a
  schema's [node specs](https://prosemirror.net/docs/ref/#model.NodeSpec.parseDOM), reordered by
  [priority](https://prosemirror.net/docs/ref/#model.ParseRule.priority).
  */
  static fromSchema(schema2) {
    return schema2.cached.domParser || (schema2.cached.domParser = new DOMParser(schema2, DOMParser.schemaRules(schema2)));
  }
}
const blockTags = {
  address: true,
  article: true,
  aside: true,
  blockquote: true,
  canvas: true,
  dd: true,
  div: true,
  dl: true,
  fieldset: true,
  figcaption: true,
  figure: true,
  footer: true,
  form: true,
  h1: true,
  h2: true,
  h3: true,
  h4: true,
  h5: true,
  h6: true,
  header: true,
  hgroup: true,
  hr: true,
  li: true,
  noscript: true,
  ol: true,
  output: true,
  p: true,
  pre: true,
  section: true,
  table: true,
  tfoot: true,
  ul: true
};
const ignoreTags = {
  head: true,
  noscript: true,
  object: true,
  script: true,
  style: true,
  title: true
};
const listTags = { ol: true, ul: true };
const OPT_PRESERVE_WS = 1, OPT_PRESERVE_WS_FULL = 2, OPT_OPEN_LEFT = 4;
function wsOptionsFor(type, preserveWhitespace, base2) {
  if (preserveWhitespace != null)
    return (preserveWhitespace ? OPT_PRESERVE_WS : 0) | (preserveWhitespace === "full" ? OPT_PRESERVE_WS_FULL : 0);
  return type && type.whitespace == "pre" ? OPT_PRESERVE_WS | OPT_PRESERVE_WS_FULL : base2 & ~OPT_OPEN_LEFT;
}
__name(wsOptionsFor, "wsOptionsFor");
class NodeContext {
  static {
    __name(this, "NodeContext");
  }
  constructor(type, attrs7, marks, solid, match2, options5) {
    this.type = type;
    this.attrs = attrs7;
    this.marks = marks;
    this.solid = solid;
    this.options = options5;
    this.content = [];
    this.activeMarks = Mark$1.none;
    this.match = match2 || (options5 & OPT_OPEN_LEFT ? null : type.contentMatch);
  }
  findWrapping(node3) {
    if (!this.match) {
      if (!this.type)
        return [];
      let fill2 = this.type.contentMatch.fillBefore(Fragment.from(node3));
      if (fill2) {
        this.match = this.type.contentMatch.matchFragment(fill2);
      } else {
        let start2 = this.type.contentMatch, wrap2;
        if (wrap2 = start2.findWrapping(node3.type)) {
          this.match = start2;
          return wrap2;
        } else {
          return null;
        }
      }
    }
    return this.match.findWrapping(node3.type);
  }
  finish(openEnd) {
    if (!(this.options & OPT_PRESERVE_WS)) {
      let last = this.content[this.content.length - 1], m2;
      if (last && last.isText && (m2 = /[ \t\r\n\u000c]+$/.exec(last.text))) {
        let text2 = last;
        if (last.text.length == m2[0].length)
          this.content.pop();
        else
          this.content[this.content.length - 1] = text2.withText(text2.text.slice(0, text2.text.length - m2[0].length));
      }
    }
    let content3 = Fragment.from(this.content);
    if (!openEnd && this.match)
      content3 = content3.append(this.match.fillBefore(Fragment.empty, true));
    return this.type ? this.type.create(this.attrs, content3, this.marks) : content3;
  }
  inlineContext(node3) {
    if (this.type)
      return this.type.inlineContent;
    if (this.content.length)
      return this.content[0].isInline;
    return node3.parentNode && !blockTags.hasOwnProperty(node3.parentNode.nodeName.toLowerCase());
  }
}
class ParseContext {
  static {
    __name(this, "ParseContext");
  }
  constructor(parser, options5, isOpen) {
    this.parser = parser;
    this.options = options5;
    this.isOpen = isOpen;
    this.open = 0;
    this.localPreserveWS = false;
    let topNode = options5.topNode, topContext;
    let topOptions = wsOptionsFor(null, options5.preserveWhitespace, 0) | (isOpen ? OPT_OPEN_LEFT : 0);
    if (topNode)
      topContext = new NodeContext(topNode.type, topNode.attrs, Mark$1.none, true, options5.topMatch || topNode.type.contentMatch, topOptions);
    else if (isOpen)
      topContext = new NodeContext(null, null, Mark$1.none, true, null, topOptions);
    else
      topContext = new NodeContext(parser.schema.topNodeType, null, Mark$1.none, true, null, topOptions);
    this.nodes = [topContext];
    this.find = options5.findPositions;
    this.needsBlock = false;
  }
  get top() {
    return this.nodes[this.open];
  }
  // Add a DOM node to the content. Text is inserted as text node,
  // otherwise, the node is passed to `addElement` or, if it has a
  // `style` attribute, `addElementWithStyles`.
  addDOM(dom, marks) {
    if (dom.nodeType == 3)
      this.addTextNode(dom, marks);
    else if (dom.nodeType == 1)
      this.addElement(dom, marks);
  }
  addTextNode(dom, marks) {
    let value3 = dom.nodeValue;
    let top = this.top, preserveWS = top.options & OPT_PRESERVE_WS_FULL ? "full" : this.localPreserveWS || (top.options & OPT_PRESERVE_WS) > 0;
    if (preserveWS === "full" || top.inlineContext(dom) || /[^ \t\r\n\u000c]/.test(value3)) {
      if (!preserveWS) {
        value3 = value3.replace(/[ \t\r\n\u000c]+/g, " ");
        if (/^[ \t\r\n\u000c]/.test(value3) && this.open == this.nodes.length - 1) {
          let nodeBefore = top.content[top.content.length - 1];
          let domNodeBefore = dom.previousSibling;
          if (!nodeBefore || domNodeBefore && domNodeBefore.nodeName == "BR" || nodeBefore.isText && /[ \t\r\n\u000c]$/.test(nodeBefore.text))
            value3 = value3.slice(1);
        }
      } else if (preserveWS !== "full") {
        value3 = value3.replace(/\r?\n|\r/g, " ");
      } else {
        value3 = value3.replace(/\r\n?/g, "\n");
      }
      if (value3)
        this.insertNode(this.parser.schema.text(value3), marks);
      this.findInText(dom);
    } else {
      this.findInside(dom);
    }
  }
  // Try to find a handler for the given tag and use that to parse. If
  // none is found, the element's content nodes are added directly.
  addElement(dom, marks, matchAfter) {
    let outerWS = this.localPreserveWS, top = this.top;
    if (dom.tagName == "PRE" || /pre/.test(dom.style && dom.style.whiteSpace))
      this.localPreserveWS = true;
    let name2 = dom.nodeName.toLowerCase(), ruleID;
    if (listTags.hasOwnProperty(name2) && this.parser.normalizeLists)
      normalizeList(dom);
    let rule = this.options.ruleFromNode && this.options.ruleFromNode(dom) || (ruleID = this.parser.matchTag(dom, this, matchAfter));
    out: if (rule ? rule.ignore : ignoreTags.hasOwnProperty(name2)) {
      this.findInside(dom);
      this.ignoreFallback(dom, marks);
    } else if (!rule || rule.skip || rule.closeParent) {
      if (rule && rule.closeParent)
        this.open = Math.max(0, this.open - 1);
      else if (rule && rule.skip.nodeType)
        dom = rule.skip;
      let sync, oldNeedsBlock = this.needsBlock;
      if (blockTags.hasOwnProperty(name2)) {
        if (top.content.length && top.content[0].isInline && this.open) {
          this.open--;
          top = this.top;
        }
        sync = true;
        if (!top.type)
          this.needsBlock = true;
      } else if (!dom.firstChild) {
        this.leafFallback(dom, marks);
        break out;
      }
      let innerMarks = rule && rule.skip ? marks : this.readStyles(dom, marks);
      if (innerMarks)
        this.addAll(dom, innerMarks);
      if (sync)
        this.sync(top);
      this.needsBlock = oldNeedsBlock;
    } else {
      let innerMarks = this.readStyles(dom, marks);
      if (innerMarks)
        this.addElementByRule(dom, rule, innerMarks, rule.consuming === false ? ruleID : void 0);
    }
    this.localPreserveWS = outerWS;
  }
  // Called for leaf DOM nodes that would otherwise be ignored
  leafFallback(dom, marks) {
    if (dom.nodeName == "BR" && this.top.type && this.top.type.inlineContent)
      this.addTextNode(dom.ownerDocument.createTextNode("\n"), marks);
  }
  // Called for ignored nodes
  ignoreFallback(dom, marks) {
    if (dom.nodeName == "BR" && (!this.top.type || !this.top.type.inlineContent))
      this.findPlace(this.parser.schema.text("-"), marks);
  }
  // Run any style parser associated with the node's styles. Either
  // return an updated array of marks, or null to indicate some of the
  // styles had a rule with `ignore` set.
  readStyles(dom, marks) {
    let styles = dom.style;
    if (styles && styles.length)
      for (let i2 = 0; i2 < this.parser.matchedStyles.length; i2++) {
        let name2 = this.parser.matchedStyles[i2], value3 = styles.getPropertyValue(name2);
        if (value3)
          for (let after = void 0; ; ) {
            let rule = this.parser.matchStyle(name2, value3, this, after);
            if (!rule)
              break;
            if (rule.ignore)
              return null;
            if (rule.clearMark)
              marks = marks.filter((m2) => !rule.clearMark(m2));
            else
              marks = marks.concat(this.parser.schema.marks[rule.mark].create(rule.attrs));
            if (rule.consuming === false)
              after = rule;
            else
              break;
          }
      }
    return marks;
  }
  // Look up a handler for the given node. If none are found, return
  // false. Otherwise, apply it, use its return value to drive the way
  // the node's content is wrapped, and return true.
  addElementByRule(dom, rule, marks, continueAfter) {
    let sync, nodeType;
    if (rule.node) {
      nodeType = this.parser.schema.nodes[rule.node];
      if (!nodeType.isLeaf) {
        let inner = this.enter(nodeType, rule.attrs || null, marks, rule.preserveWhitespace);
        if (inner) {
          sync = true;
          marks = inner;
        }
      } else if (!this.insertNode(nodeType.create(rule.attrs), marks)) {
        this.leafFallback(dom, marks);
      }
    } else {
      let markType = this.parser.schema.marks[rule.mark];
      marks = marks.concat(markType.create(rule.attrs));
    }
    let startIn = this.top;
    if (nodeType && nodeType.isLeaf) {
      this.findInside(dom);
    } else if (continueAfter) {
      this.addElement(dom, marks, continueAfter);
    } else if (rule.getContent) {
      this.findInside(dom);
      rule.getContent(dom, this.parser.schema).forEach((node3) => this.insertNode(node3, marks));
    } else {
      let contentDOM = dom;
      if (typeof rule.contentElement == "string")
        contentDOM = dom.querySelector(rule.contentElement);
      else if (typeof rule.contentElement == "function")
        contentDOM = rule.contentElement(dom);
      else if (rule.contentElement)
        contentDOM = rule.contentElement;
      this.findAround(dom, contentDOM, true);
      this.addAll(contentDOM, marks);
      this.findAround(dom, contentDOM, false);
    }
    if (sync && this.sync(startIn))
      this.open--;
  }
  // Add all child nodes between `startIndex` and `endIndex` (or the
  // whole node, if not given). If `sync` is passed, use it to
  // synchronize after every block element.
  addAll(parent, marks, startIndex, endIndex) {
    let index2 = startIndex || 0;
    for (let dom = startIndex ? parent.childNodes[startIndex] : parent.firstChild, end = endIndex == null ? null : parent.childNodes[endIndex]; dom != end; dom = dom.nextSibling, ++index2) {
      this.findAtPoint(parent, index2);
      this.addDOM(dom, marks);
    }
    this.findAtPoint(parent, index2);
  }
  // Try to find a way to fit the given node type into the current
  // context. May add intermediate wrappers and/or leave non-solid
  // nodes that we're in.
  findPlace(node3, marks) {
    let route, sync;
    for (let depth = this.open; depth >= 0; depth--) {
      let cx3 = this.nodes[depth];
      let found2 = cx3.findWrapping(node3);
      if (found2 && (!route || route.length > found2.length)) {
        route = found2;
        sync = cx3;
        if (!found2.length)
          break;
      }
      if (cx3.solid)
        break;
    }
    if (!route)
      return null;
    this.sync(sync);
    for (let i2 = 0; i2 < route.length; i2++)
      marks = this.enterInner(route[i2], null, marks, false);
    return marks;
  }
  // Try to insert the given node, adjusting the context when needed.
  insertNode(node3, marks) {
    if (node3.isInline && this.needsBlock && !this.top.type) {
      let block3 = this.textblockFromContext();
      if (block3)
        marks = this.enterInner(block3, null, marks);
    }
    let innerMarks = this.findPlace(node3, marks);
    if (innerMarks) {
      this.closeExtra();
      let top = this.top;
      if (top.match)
        top.match = top.match.matchType(node3.type);
      let nodeMarks = Mark$1.none;
      for (let m2 of innerMarks.concat(node3.marks))
        if (top.type ? top.type.allowsMarkType(m2.type) : markMayApply(m2.type, node3.type))
          nodeMarks = m2.addToSet(nodeMarks);
      top.content.push(node3.mark(nodeMarks));
      return true;
    }
    return false;
  }
  // Try to start a node of the given type, adjusting the context when
  // necessary.
  enter(type, attrs7, marks, preserveWS) {
    let innerMarks = this.findPlace(type.create(attrs7), marks);
    if (innerMarks)
      innerMarks = this.enterInner(type, attrs7, marks, true, preserveWS);
    return innerMarks;
  }
  // Open a node of the given type
  enterInner(type, attrs7, marks, solid = false, preserveWS) {
    this.closeExtra();
    let top = this.top;
    top.match = top.match && top.match.matchType(type);
    let options5 = wsOptionsFor(type, preserveWS, top.options);
    if (top.options & OPT_OPEN_LEFT && top.content.length == 0)
      options5 |= OPT_OPEN_LEFT;
    let applyMarks = Mark$1.none;
    marks = marks.filter((m2) => {
      if (top.type ? top.type.allowsMarkType(m2.type) : markMayApply(m2.type, type)) {
        applyMarks = m2.addToSet(applyMarks);
        return false;
      }
      return true;
    });
    this.nodes.push(new NodeContext(type, attrs7, applyMarks, solid, null, options5));
    this.open++;
    return marks;
  }
  // Make sure all nodes above this.open are finished and added to
  // their parents
  closeExtra(openEnd = false) {
    let i2 = this.nodes.length - 1;
    if (i2 > this.open) {
      for (; i2 > this.open; i2--)
        this.nodes[i2 - 1].content.push(this.nodes[i2].finish(openEnd));
      this.nodes.length = this.open + 1;
    }
  }
  finish() {
    this.open = 0;
    this.closeExtra(this.isOpen);
    return this.nodes[0].finish(!!(this.isOpen || this.options.topOpen));
  }
  sync(to) {
    for (let i2 = this.open; i2 >= 0; i2--) {
      if (this.nodes[i2] == to) {
        this.open = i2;
        return true;
      } else if (this.localPreserveWS) {
        this.nodes[i2].options |= OPT_PRESERVE_WS;
      }
    }
    return false;
  }
  get currentPos() {
    this.closeExtra();
    let pos = 0;
    for (let i2 = this.open; i2 >= 0; i2--) {
      let content3 = this.nodes[i2].content;
      for (let j2 = content3.length - 1; j2 >= 0; j2--)
        pos += content3[j2].nodeSize;
      if (i2)
        pos++;
    }
    return pos;
  }
  findAtPoint(parent, offset) {
    if (this.find)
      for (let i2 = 0; i2 < this.find.length; i2++) {
        if (this.find[i2].node == parent && this.find[i2].offset == offset)
          this.find[i2].pos = this.currentPos;
      }
  }
  findInside(parent) {
    if (this.find)
      for (let i2 = 0; i2 < this.find.length; i2++) {
        if (this.find[i2].pos == null && parent.nodeType == 1 && parent.contains(this.find[i2].node))
          this.find[i2].pos = this.currentPos;
      }
  }
  findAround(parent, content3, before) {
    if (parent != content3 && this.find)
      for (let i2 = 0; i2 < this.find.length; i2++) {
        if (this.find[i2].pos == null && parent.nodeType == 1 && parent.contains(this.find[i2].node)) {
          let pos = content3.compareDocumentPosition(this.find[i2].node);
          if (pos & (before ? 2 : 4))
            this.find[i2].pos = this.currentPos;
        }
      }
  }
  findInText(textNode) {
    if (this.find)
      for (let i2 = 0; i2 < this.find.length; i2++) {
        if (this.find[i2].node == textNode)
          this.find[i2].pos = this.currentPos - (textNode.nodeValue.length - this.find[i2].offset);
      }
  }
  // Determines whether the given context string matches this context.
  matchesContext(context) {
    if (context.indexOf("|") > -1)
      return context.split(/\s*\|\s*/).some(this.matchesContext, this);
    let parts2 = context.split("/");
    let option5 = this.options.context;
    let useRoot = !this.isOpen && (!option5 || option5.parent.type == this.nodes[0].type);
    let minDepth = -(option5 ? option5.depth + 1 : 0) + (useRoot ? 0 : 1);
    let match2 = /* @__PURE__ */ __name((i2, depth) => {
      for (; i2 >= 0; i2--) {
        let part = parts2[i2];
        if (part == "") {
          if (i2 == parts2.length - 1 || i2 == 0)
            continue;
          for (; depth >= minDepth; depth--)
            if (match2(i2 - 1, depth))
              return true;
          return false;
        } else {
          let next2 = depth > 0 || depth == 0 && useRoot ? this.nodes[depth].type : option5 && depth >= minDepth ? option5.node(depth - minDepth).type : null;
          if (!next2 || next2.name != part && !next2.isInGroup(part))
            return false;
          depth--;
        }
      }
      return true;
    }, "match");
    return match2(parts2.length - 1, this.open);
  }
  textblockFromContext() {
    let $context = this.options.context;
    if ($context)
      for (let d2 = $context.depth; d2 >= 0; d2--) {
        let deflt = $context.node(d2).contentMatchAt($context.indexAfter(d2)).defaultType;
        if (deflt && deflt.isTextblock && deflt.defaultAttrs)
          return deflt;
      }
    for (let name2 in this.parser.schema.nodes) {
      let type = this.parser.schema.nodes[name2];
      if (type.isTextblock && type.defaultAttrs)
        return type;
    }
  }
}
function normalizeList(dom) {
  for (let child = dom.firstChild, prevItem = null; child; child = child.nextSibling) {
    let name2 = child.nodeType == 1 ? child.nodeName.toLowerCase() : null;
    if (name2 && listTags.hasOwnProperty(name2) && prevItem) {
      prevItem.appendChild(child);
      child = prevItem;
    } else if (name2 == "li") {
      prevItem = child;
    } else if (name2) {
      prevItem = null;
    }
  }
}
__name(normalizeList, "normalizeList");
function matches(dom, selector) {
  return (dom.matches || dom.msMatchesSelector || dom.webkitMatchesSelector || dom.mozMatchesSelector).call(dom, selector);
}
__name(matches, "matches");
function copy(obj) {
  let copy2 = {};
  for (let prop2 in obj)
    copy2[prop2] = obj[prop2];
  return copy2;
}
__name(copy, "copy");
function markMayApply(markType, nodeType) {
  let nodes = nodeType.schema.nodes;
  for (let name2 in nodes) {
    let parent = nodes[name2];
    if (!parent.allowsMarkType(markType))
      continue;
    let seen2 = [], scan = /* @__PURE__ */ __name((match2) => {
      seen2.push(match2);
      for (let i2 = 0; i2 < match2.edgeCount; i2++) {
        let { type, next: next2 } = match2.edge(i2);
        if (type == nodeType)
          return true;
        if (seen2.indexOf(next2) < 0 && scan(next2))
          return true;
      }
    }, "scan");
    if (scan(parent.contentMatch))
      return true;
  }
}
__name(markMayApply, "markMayApply");
class DOMSerializer {
  static {
    __name(this, "DOMSerializer");
  }
  /**
  Create a serializer. `nodes` should map node names to functions
  that take a node and return a description of the corresponding
  DOM. `marks` does the same for mark names, but also gets an
  argument that tells it whether the mark's content is block or
  inline content (for typical use, it'll always be inline). A mark
  serializer may be `null` to indicate that marks of that type
  should not be serialized.
  */
  constructor(nodes, marks) {
    this.nodes = nodes;
    this.marks = marks;
  }
  /**
  Serialize the content of this fragment to a DOM fragment. When
  not in the browser, the `document` option, containing a DOM
  document, should be passed so that the serializer can create
  nodes.
  */
  serializeFragment(fragment, options5 = {}, target2) {
    if (!target2)
      target2 = doc$1(options5).createDocumentFragment();
    let top = target2, active4 = [];
    fragment.forEach((node3) => {
      if (active4.length || node3.marks.length) {
        let keep = 0, rendered = 0;
        while (keep < active4.length && rendered < node3.marks.length) {
          let next2 = node3.marks[rendered];
          if (!this.marks[next2.type.name]) {
            rendered++;
            continue;
          }
          if (!next2.eq(active4[keep][0]) || next2.type.spec.spanning === false)
            break;
          keep++;
          rendered++;
        }
        while (keep < active4.length)
          top = active4.pop()[1];
        while (rendered < node3.marks.length) {
          let add3 = node3.marks[rendered++];
          let markDOM = this.serializeMark(add3, node3.isInline, options5);
          if (markDOM) {
            active4.push([add3, top]);
            top.appendChild(markDOM.dom);
            top = markDOM.contentDOM || markDOM.dom;
          }
        }
      }
      top.appendChild(this.serializeNodeInner(node3, options5));
    });
    return target2;
  }
  /**
  @internal
  */
  serializeNodeInner(node3, options5) {
    let { dom, contentDOM } = renderSpec(doc$1(options5), this.nodes[node3.type.name](node3), null, node3.attrs);
    if (contentDOM) {
      if (node3.isLeaf)
        throw new RangeError("Content hole not allowed in a leaf node spec");
      this.serializeFragment(node3.content, options5, contentDOM);
    }
    return dom;
  }
  /**
  Serialize this node to a DOM node. This can be useful when you
  need to serialize a part of a document, as opposed to the whole
  document. To serialize a whole document, use
  [`serializeFragment`](https://prosemirror.net/docs/ref/#model.DOMSerializer.serializeFragment) on
  its [content](https://prosemirror.net/docs/ref/#model.Node.content).
  */
  serializeNode(node3, options5 = {}) {
    let dom = this.serializeNodeInner(node3, options5);
    for (let i2 = node3.marks.length - 1; i2 >= 0; i2--) {
      let wrap2 = this.serializeMark(node3.marks[i2], node3.isInline, options5);
      if (wrap2) {
        (wrap2.contentDOM || wrap2.dom).appendChild(dom);
        dom = wrap2.dom;
      }
    }
    return dom;
  }
  /**
  @internal
  */
  serializeMark(mark2, inline3, options5 = {}) {
    let toDOM = this.marks[mark2.type.name];
    return toDOM && renderSpec(doc$1(options5), toDOM(mark2, inline3), null, mark2.attrs);
  }
  static renderSpec(doc2, structure, xmlNS = null, blockArraysIn) {
    return renderSpec(doc2, structure, xmlNS, blockArraysIn);
  }
  /**
  Build a serializer using the [`toDOM`](https://prosemirror.net/docs/ref/#model.NodeSpec.toDOM)
  properties in a schema's node and mark specs.
  */
  static fromSchema(schema2) {
    return schema2.cached.domSerializer || (schema2.cached.domSerializer = new DOMSerializer(this.nodesFromSchema(schema2), this.marksFromSchema(schema2)));
  }
  /**
  Gather the serializers in a schema's node specs into an object.
  This can be useful as a base to build a custom serializer from.
  */
  static nodesFromSchema(schema2) {
    let result = gatherToDOM(schema2.nodes);
    if (!result.text)
      result.text = (node3) => node3.text;
    return result;
  }
  /**
  Gather the serializers in a schema's mark specs into an object.
  */
  static marksFromSchema(schema2) {
    return gatherToDOM(schema2.marks);
  }
}
function gatherToDOM(obj) {
  let result = {};
  for (let name2 in obj) {
    let toDOM = obj[name2].spec.toDOM;
    if (toDOM)
      result[name2] = toDOM;
  }
  return result;
}
__name(gatherToDOM, "gatherToDOM");
function doc$1(options5) {
  return options5.document || window.document;
}
__name(doc$1, "doc$1");
const suspiciousAttributeCache = /* @__PURE__ */ new WeakMap();
function suspiciousAttributes(attrs7) {
  let value3 = suspiciousAttributeCache.get(attrs7);
  if (value3 === void 0)
    suspiciousAttributeCache.set(attrs7, value3 = suspiciousAttributesInner(attrs7));
  return value3;
}
__name(suspiciousAttributes, "suspiciousAttributes");
function suspiciousAttributesInner(attrs7) {
  let result = null;
  function scan(value3) {
    if (value3 && typeof value3 == "object") {
      if (Array.isArray(value3)) {
        if (typeof value3[0] == "string") {
          if (!result)
            result = [];
          result.push(value3);
        } else {
          for (let i2 = 0; i2 < value3.length; i2++)
            scan(value3[i2]);
        }
      } else {
        for (let prop2 in value3)
          scan(value3[prop2]);
      }
    }
  }
  __name(scan, "scan");
  scan(attrs7);
  return result;
}
__name(suspiciousAttributesInner, "suspiciousAttributesInner");
function renderSpec(doc2, structure, xmlNS, blockArraysIn) {
  if (typeof structure == "string")
    return { dom: doc2.createTextNode(structure) };
  if (structure.nodeType != null)
    return { dom: structure };
  if (structure.dom && structure.dom.nodeType != null)
    return structure;
  let tagName = structure[0], suspicious;
  if (typeof tagName != "string")
    throw new RangeError("Invalid array passed to renderSpec");
  if (blockArraysIn && (suspicious = suspiciousAttributes(blockArraysIn)) && suspicious.indexOf(structure) > -1)
    throw new RangeError("Using an array from an attribute object as a DOM spec. This may be an attempted cross site scripting attack.");
  let space = tagName.indexOf(" ");
  if (space > 0) {
    xmlNS = tagName.slice(0, space);
    tagName = tagName.slice(space + 1);
  }
  let contentDOM;
  let dom = xmlNS ? doc2.createElementNS(xmlNS, tagName) : doc2.createElement(tagName);
  let attrs7 = structure[1], start2 = 1;
  if (attrs7 && typeof attrs7 == "object" && attrs7.nodeType == null && !Array.isArray(attrs7)) {
    start2 = 2;
    for (let name2 in attrs7)
      if (attrs7[name2] != null) {
        let space2 = name2.indexOf(" ");
        if (space2 > 0)
          dom.setAttributeNS(name2.slice(0, space2), name2.slice(space2 + 1), attrs7[name2]);
        else
          dom.setAttribute(name2, attrs7[name2]);
      }
  }
  for (let i2 = start2; i2 < structure.length; i2++) {
    let child = structure[i2];
    if (child === 0) {
      if (i2 < structure.length - 1 || i2 > start2)
        throw new RangeError("Content hole must be the only child of its parent node");
      return { dom, contentDOM: dom };
    } else {
      let { dom: inner, contentDOM: innerContent } = renderSpec(doc2, child, xmlNS, blockArraysIn);
      dom.appendChild(inner);
      if (innerContent) {
        if (contentDOM)
          throw new RangeError("Multiple content holes");
        contentDOM = innerContent;
      }
    }
  }
  return { dom, contentDOM };
}
__name(renderSpec, "renderSpec");
const lower16 = 65535;
const factor16 = Math.pow(2, 16);
function makeRecover(index2, offset) {
  return index2 + offset * factor16;
}
__name(makeRecover, "makeRecover");
function recoverIndex(value3) {
  return value3 & lower16;
}
__name(recoverIndex, "recoverIndex");
function recoverOffset(value3) {
  return (value3 - (value3 & lower16)) / factor16;
}
__name(recoverOffset, "recoverOffset");
const DEL_BEFORE = 1, DEL_AFTER = 2, DEL_ACROSS = 4, DEL_SIDE = 8;
class MapResult {
  static {
    __name(this, "MapResult");
  }
  /**
  @internal
  */
  constructor(pos, delInfo, recover) {
    this.pos = pos;
    this.delInfo = delInfo;
    this.recover = recover;
  }
  /**
  Tells you whether the position was deleted, that is, whether the
  step removed the token on the side queried (via the `assoc`)
  argument from the document.
  */
  get deleted() {
    return (this.delInfo & DEL_SIDE) > 0;
  }
  /**
  Tells you whether the token before the mapped position was deleted.
  */
  get deletedBefore() {
    return (this.delInfo & (DEL_BEFORE | DEL_ACROSS)) > 0;
  }
  /**
  True when the token after the mapped position was deleted.
  */
  get deletedAfter() {
    return (this.delInfo & (DEL_AFTER | DEL_ACROSS)) > 0;
  }
  /**
  Tells whether any of the steps mapped through deletes across the
  position (including both the token before and after the
  position).
  */
  get deletedAcross() {
    return (this.delInfo & DEL_ACROSS) > 0;
  }
}
class StepMap {
  static {
    __name(this, "StepMap");
  }
  /**
  Create a position map. The modifications to the document are
  represented as an array of numbers, in which each group of three
  represents a modified chunk as `[start, oldSize, newSize]`.
  */
  constructor(ranges, inverted = false) {
    this.ranges = ranges;
    this.inverted = inverted;
    if (!ranges.length && StepMap.empty)
      return StepMap.empty;
  }
  /**
  @internal
  */
  recover(value3) {
    let diff2 = 0, index2 = recoverIndex(value3);
    if (!this.inverted)
      for (let i2 = 0; i2 < index2; i2++)
        diff2 += this.ranges[i2 * 3 + 2] - this.ranges[i2 * 3 + 1];
    return this.ranges[index2 * 3] + diff2 + recoverOffset(value3);
  }
  mapResult(pos, assoc = 1) {
    return this._map(pos, assoc, false);
  }
  map(pos, assoc = 1) {
    return this._map(pos, assoc, true);
  }
  /**
  @internal
  */
  _map(pos, assoc, simple) {
    let diff2 = 0, oldIndex = this.inverted ? 2 : 1, newIndex = this.inverted ? 1 : 2;
    for (let i2 = 0; i2 < this.ranges.length; i2 += 3) {
      let start2 = this.ranges[i2] - (this.inverted ? diff2 : 0);
      if (start2 > pos)
        break;
      let oldSize = this.ranges[i2 + oldIndex], newSize = this.ranges[i2 + newIndex], end = start2 + oldSize;
      if (pos <= end) {
        let side = !oldSize ? assoc : pos == start2 ? -1 : pos == end ? 1 : assoc;
        let result = start2 + diff2 + (side < 0 ? 0 : newSize);
        if (simple)
          return result;
        let recover = pos == (assoc < 0 ? start2 : end) ? null : makeRecover(i2 / 3, pos - start2);
        let del2 = pos == start2 ? DEL_AFTER : pos == end ? DEL_BEFORE : DEL_ACROSS;
        if (assoc < 0 ? pos != start2 : pos != end)
          del2 |= DEL_SIDE;
        return new MapResult(result, del2, recover);
      }
      diff2 += newSize - oldSize;
    }
    return simple ? pos + diff2 : new MapResult(pos + diff2, 0, null);
  }
  /**
  @internal
  */
  touches(pos, recover) {
    let diff2 = 0, index2 = recoverIndex(recover);
    let oldIndex = this.inverted ? 2 : 1, newIndex = this.inverted ? 1 : 2;
    for (let i2 = 0; i2 < this.ranges.length; i2 += 3) {
      let start2 = this.ranges[i2] - (this.inverted ? diff2 : 0);
      if (start2 > pos)
        break;
      let oldSize = this.ranges[i2 + oldIndex], end = start2 + oldSize;
      if (pos <= end && i2 == index2 * 3)
        return true;
      diff2 += this.ranges[i2 + newIndex] - oldSize;
    }
    return false;
  }
  /**
  Calls the given function on each of the changed ranges included in
  this map.
  */
  forEach(f2) {
    let oldIndex = this.inverted ? 2 : 1, newIndex = this.inverted ? 1 : 2;
    for (let i2 = 0, diff2 = 0; i2 < this.ranges.length; i2 += 3) {
      let start2 = this.ranges[i2], oldStart = start2 - (this.inverted ? diff2 : 0), newStart = start2 + (this.inverted ? 0 : diff2);
      let oldSize = this.ranges[i2 + oldIndex], newSize = this.ranges[i2 + newIndex];
      f2(oldStart, oldStart + oldSize, newStart, newStart + newSize);
      diff2 += newSize - oldSize;
    }
  }
  /**
  Create an inverted version of this map. The result can be used to
  map positions in the post-step document to the pre-step document.
  */
  invert() {
    return new StepMap(this.ranges, !this.inverted);
  }
  /**
  @internal
  */
  toString() {
    return (this.inverted ? "-" : "") + JSON.stringify(this.ranges);
  }
  /**
  Create a map that moves all positions by offset `n` (which may be
  negative). This can be useful when applying steps meant for a
  sub-document to a larger document, or vice-versa.
  */
  static offset(n2) {
    return n2 == 0 ? StepMap.empty : new StepMap(n2 < 0 ? [0, -n2, 0] : [0, 0, n2]);
  }
}
StepMap.empty = new StepMap([]);
class Mapping {
  static {
    __name(this, "Mapping");
  }
  /**
  Create a new mapping with the given position maps.
  */
  constructor(maps = [], mirror2, from2 = 0, to = maps.length) {
    this.maps = maps;
    this.mirror = mirror2;
    this.from = from2;
    this.to = to;
  }
  /**
  Create a mapping that maps only through a part of this one.
  */
  slice(from2 = 0, to = this.maps.length) {
    return new Mapping(this.maps, this.mirror, from2, to);
  }
  /**
  @internal
  */
  copy() {
    return new Mapping(this.maps.slice(), this.mirror && this.mirror.slice(), this.from, this.to);
  }
  /**
  Add a step map to the end of this mapping. If `mirrors` is
  given, it should be the index of the step map that is the mirror
  image of this one.
  */
  appendMap(map3, mirrors) {
    this.to = this.maps.push(map3);
    if (mirrors != null)
      this.setMirror(this.maps.length - 1, mirrors);
  }
  /**
  Add all the step maps in a given mapping to this one (preserving
  mirroring information).
  */
  appendMapping(mapping) {
    for (let i2 = 0, startSize = this.maps.length; i2 < mapping.maps.length; i2++) {
      let mirr = mapping.getMirror(i2);
      this.appendMap(mapping.maps[i2], mirr != null && mirr < i2 ? startSize + mirr : void 0);
    }
  }
  /**
  Finds the offset of the step map that mirrors the map at the
  given offset, in this mapping (as per the second argument to
  `appendMap`).
  */
  getMirror(n2) {
    if (this.mirror) {
      for (let i2 = 0; i2 < this.mirror.length; i2++)
        if (this.mirror[i2] == n2)
          return this.mirror[i2 + (i2 % 2 ? -1 : 1)];
    }
  }
  /**
  @internal
  */
  setMirror(n2, m2) {
    if (!this.mirror)
      this.mirror = [];
    this.mirror.push(n2, m2);
  }
  /**
  Append the inverse of the given mapping to this one.
  */
  appendMappingInverted(mapping) {
    for (let i2 = mapping.maps.length - 1, totalSize = this.maps.length + mapping.maps.length; i2 >= 0; i2--) {
      let mirr = mapping.getMirror(i2);
      this.appendMap(mapping.maps[i2].invert(), mirr != null && mirr > i2 ? totalSize - mirr - 1 : void 0);
    }
  }
  /**
  Create an inverted version of this mapping.
  */
  invert() {
    let inverse = new Mapping();
    inverse.appendMappingInverted(this);
    return inverse;
  }
  /**
  Map a position through this mapping.
  */
  map(pos, assoc = 1) {
    if (this.mirror)
      return this._map(pos, assoc, true);
    for (let i2 = this.from; i2 < this.to; i2++)
      pos = this.maps[i2].map(pos, assoc);
    return pos;
  }
  /**
  Map a position through this mapping, returning a mapping
  result.
  */
  mapResult(pos, assoc = 1) {
    return this._map(pos, assoc, false);
  }
  /**
  @internal
  */
  _map(pos, assoc, simple) {
    let delInfo = 0;
    for (let i2 = this.from; i2 < this.to; i2++) {
      let map3 = this.maps[i2], result = map3.mapResult(pos, assoc);
      if (result.recover != null) {
        let corr = this.getMirror(i2);
        if (corr != null && corr > i2 && corr < this.to) {
          i2 = corr;
          pos = this.maps[corr].recover(result.recover);
          continue;
        }
      }
      delInfo |= result.delInfo;
      pos = result.pos;
    }
    return simple ? pos : new MapResult(pos, delInfo, null);
  }
}
const stepsByID = /* @__PURE__ */ Object.create(null);
class Step {
  static {
    __name(this, "Step");
  }
  /**
  Get the step map that represents the changes made by this step,
  and which can be used to transform between positions in the old
  and the new document.
  */
  getMap() {
    return StepMap.empty;
  }
  /**
  Try to merge this step with another one, to be applied directly
  after it. Returns the merged step when possible, null if the
  steps can't be merged.
  */
  merge(other) {
    return null;
  }
  /**
  Deserialize a step from its JSON representation. Will call
  through to the step class' own implementation of this method.
  */
  static fromJSON(schema2, json) {
    if (!json || !json.stepType)
      throw new RangeError("Invalid input for Step.fromJSON");
    let type = stepsByID[json.stepType];
    if (!type)
      throw new RangeError(`No step type ${json.stepType} defined`);
    return type.fromJSON(schema2, json);
  }
  /**
  To be able to serialize steps to JSON, each step needs a string
  ID to attach to its JSON representation. Use this method to
  register an ID for your step classes. Try to pick something
  that's unlikely to clash with steps from other modules.
  */
  static jsonID(id4, stepClass) {
    if (id4 in stepsByID)
      throw new RangeError("Duplicate use of step JSON ID " + id4);
    stepsByID[id4] = stepClass;
    stepClass.prototype.jsonID = id4;
    return stepClass;
  }
}
class StepResult {
  static {
    __name(this, "StepResult");
  }
  /**
  @internal
  */
  constructor(doc2, failed) {
    this.doc = doc2;
    this.failed = failed;
  }
  /**
  Create a successful step result.
  */
  static ok(doc2) {
    return new StepResult(doc2, null);
  }
  /**
  Create a failed step result.
  */
  static fail(message3) {
    return new StepResult(null, message3);
  }
  /**
  Call [`Node.replace`](https://prosemirror.net/docs/ref/#model.Node.replace) with the given
  arguments. Create a successful result if it succeeds, and a
  failed one if it throws a `ReplaceError`.
  */
  static fromReplace(doc2, from2, to, slice2) {
    try {
      return StepResult.ok(doc2.replace(from2, to, slice2));
    } catch (e2) {
      if (e2 instanceof ReplaceError)
        return StepResult.fail(e2.message);
      throw e2;
    }
  }
}
function mapFragment(fragment, f2, parent) {
  let mapped = [];
  for (let i2 = 0; i2 < fragment.childCount; i2++) {
    let child = fragment.child(i2);
    if (child.content.size)
      child = child.copy(mapFragment(child.content, f2, child));
    if (child.isInline)
      child = f2(child, parent, i2);
    mapped.push(child);
  }
  return Fragment.fromArray(mapped);
}
__name(mapFragment, "mapFragment");
class AddMarkStep extends Step {
  static {
    __name(this, "AddMarkStep");
  }
  /**
  Create a mark step.
  */
  constructor(from2, to, mark2) {
    super();
    this.from = from2;
    this.to = to;
    this.mark = mark2;
  }
  apply(doc2) {
    let oldSlice = doc2.slice(this.from, this.to), $from = doc2.resolve(this.from);
    let parent = $from.node($from.sharedDepth(this.to));
    let slice2 = new Slice(mapFragment(oldSlice.content, (node3, parent2) => {
      if (!node3.isAtom || !parent2.type.allowsMarkType(this.mark.type))
        return node3;
      return node3.mark(this.mark.addToSet(node3.marks));
    }, parent), oldSlice.openStart, oldSlice.openEnd);
    return StepResult.fromReplace(doc2, this.from, this.to, slice2);
  }
  invert() {
    return new RemoveMarkStep(this.from, this.to, this.mark);
  }
  map(mapping) {
    let from2 = mapping.mapResult(this.from, 1), to = mapping.mapResult(this.to, -1);
    if (from2.deleted && to.deleted || from2.pos >= to.pos)
      return null;
    return new AddMarkStep(from2.pos, to.pos, this.mark);
  }
  merge(other) {
    if (other instanceof AddMarkStep && other.mark.eq(this.mark) && this.from <= other.to && this.to >= other.from)
      return new AddMarkStep(Math.min(this.from, other.from), Math.max(this.to, other.to), this.mark);
    return null;
  }
  toJSON() {
    return {
      stepType: "addMark",
      mark: this.mark.toJSON(),
      from: this.from,
      to: this.to
    };
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.from != "number" || typeof json.to != "number")
      throw new RangeError("Invalid input for AddMarkStep.fromJSON");
    return new AddMarkStep(json.from, json.to, schema2.markFromJSON(json.mark));
  }
}
Step.jsonID("addMark", AddMarkStep);
class RemoveMarkStep extends Step {
  static {
    __name(this, "RemoveMarkStep");
  }
  /**
  Create a mark-removing step.
  */
  constructor(from2, to, mark2) {
    super();
    this.from = from2;
    this.to = to;
    this.mark = mark2;
  }
  apply(doc2) {
    let oldSlice = doc2.slice(this.from, this.to);
    let slice2 = new Slice(mapFragment(oldSlice.content, (node3) => {
      return node3.mark(this.mark.removeFromSet(node3.marks));
    }, doc2), oldSlice.openStart, oldSlice.openEnd);
    return StepResult.fromReplace(doc2, this.from, this.to, slice2);
  }
  invert() {
    return new AddMarkStep(this.from, this.to, this.mark);
  }
  map(mapping) {
    let from2 = mapping.mapResult(this.from, 1), to = mapping.mapResult(this.to, -1);
    if (from2.deleted && to.deleted || from2.pos >= to.pos)
      return null;
    return new RemoveMarkStep(from2.pos, to.pos, this.mark);
  }
  merge(other) {
    if (other instanceof RemoveMarkStep && other.mark.eq(this.mark) && this.from <= other.to && this.to >= other.from)
      return new RemoveMarkStep(Math.min(this.from, other.from), Math.max(this.to, other.to), this.mark);
    return null;
  }
  toJSON() {
    return {
      stepType: "removeMark",
      mark: this.mark.toJSON(),
      from: this.from,
      to: this.to
    };
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.from != "number" || typeof json.to != "number")
      throw new RangeError("Invalid input for RemoveMarkStep.fromJSON");
    return new RemoveMarkStep(json.from, json.to, schema2.markFromJSON(json.mark));
  }
}
Step.jsonID("removeMark", RemoveMarkStep);
class AddNodeMarkStep extends Step {
  static {
    __name(this, "AddNodeMarkStep");
  }
  /**
  Create a node mark step.
  */
  constructor(pos, mark2) {
    super();
    this.pos = pos;
    this.mark = mark2;
  }
  apply(doc2) {
    let node3 = doc2.nodeAt(this.pos);
    if (!node3)
      return StepResult.fail("No node at mark step's position");
    let updated17 = node3.type.create(node3.attrs, null, this.mark.addToSet(node3.marks));
    return StepResult.fromReplace(doc2, this.pos, this.pos + 1, new Slice(Fragment.from(updated17), 0, node3.isLeaf ? 0 : 1));
  }
  invert(doc2) {
    let node3 = doc2.nodeAt(this.pos);
    if (node3) {
      let newSet = this.mark.addToSet(node3.marks);
      if (newSet.length == node3.marks.length) {
        for (let i2 = 0; i2 < node3.marks.length; i2++)
          if (!node3.marks[i2].isInSet(newSet))
            return new AddNodeMarkStep(this.pos, node3.marks[i2]);
        return new AddNodeMarkStep(this.pos, this.mark);
      }
    }
    return new RemoveNodeMarkStep(this.pos, this.mark);
  }
  map(mapping) {
    let pos = mapping.mapResult(this.pos, 1);
    return pos.deletedAfter ? null : new AddNodeMarkStep(pos.pos, this.mark);
  }
  toJSON() {
    return { stepType: "addNodeMark", pos: this.pos, mark: this.mark.toJSON() };
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.pos != "number")
      throw new RangeError("Invalid input for AddNodeMarkStep.fromJSON");
    return new AddNodeMarkStep(json.pos, schema2.markFromJSON(json.mark));
  }
}
Step.jsonID("addNodeMark", AddNodeMarkStep);
class RemoveNodeMarkStep extends Step {
  static {
    __name(this, "RemoveNodeMarkStep");
  }
  /**
  Create a mark-removing step.
  */
  constructor(pos, mark2) {
    super();
    this.pos = pos;
    this.mark = mark2;
  }
  apply(doc2) {
    let node3 = doc2.nodeAt(this.pos);
    if (!node3)
      return StepResult.fail("No node at mark step's position");
    let updated17 = node3.type.create(node3.attrs, null, this.mark.removeFromSet(node3.marks));
    return StepResult.fromReplace(doc2, this.pos, this.pos + 1, new Slice(Fragment.from(updated17), 0, node3.isLeaf ? 0 : 1));
  }
  invert(doc2) {
    let node3 = doc2.nodeAt(this.pos);
    if (!node3 || !this.mark.isInSet(node3.marks))
      return this;
    return new AddNodeMarkStep(this.pos, this.mark);
  }
  map(mapping) {
    let pos = mapping.mapResult(this.pos, 1);
    return pos.deletedAfter ? null : new RemoveNodeMarkStep(pos.pos, this.mark);
  }
  toJSON() {
    return { stepType: "removeNodeMark", pos: this.pos, mark: this.mark.toJSON() };
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.pos != "number")
      throw new RangeError("Invalid input for RemoveNodeMarkStep.fromJSON");
    return new RemoveNodeMarkStep(json.pos, schema2.markFromJSON(json.mark));
  }
}
Step.jsonID("removeNodeMark", RemoveNodeMarkStep);
class ReplaceStep extends Step {
  static {
    __name(this, "ReplaceStep");
  }
  /**
  The given `slice` should fit the 'gap' between `from` and
  `to`—the depths must line up, and the surrounding nodes must be
  able to be joined with the open sides of the slice. When
  `structure` is true, the step will fail if the content between
  from and to is not just a sequence of closing and then opening
  tokens (this is to guard against rebased replace steps
  overwriting something they weren't supposed to).
  */
  constructor(from2, to, slice2, structure = false) {
    super();
    this.from = from2;
    this.to = to;
    this.slice = slice2;
    this.structure = structure;
  }
  apply(doc2) {
    if (this.structure && contentBetween(doc2, this.from, this.to))
      return StepResult.fail("Structure replace would overwrite content");
    return StepResult.fromReplace(doc2, this.from, this.to, this.slice);
  }
  getMap() {
    return new StepMap([this.from, this.to - this.from, this.slice.size]);
  }
  invert(doc2) {
    return new ReplaceStep(this.from, this.from + this.slice.size, doc2.slice(this.from, this.to));
  }
  map(mapping) {
    let from2 = mapping.mapResult(this.from, 1), to = mapping.mapResult(this.to, -1);
    if (from2.deletedAcross && to.deletedAcross)
      return null;
    return new ReplaceStep(from2.pos, Math.max(from2.pos, to.pos), this.slice);
  }
  merge(other) {
    if (!(other instanceof ReplaceStep) || other.structure || this.structure)
      return null;
    if (this.from + this.slice.size == other.from && !this.slice.openEnd && !other.slice.openStart) {
      let slice2 = this.slice.size + other.slice.size == 0 ? Slice.empty : new Slice(this.slice.content.append(other.slice.content), this.slice.openStart, other.slice.openEnd);
      return new ReplaceStep(this.from, this.to + (other.to - other.from), slice2, this.structure);
    } else if (other.to == this.from && !this.slice.openStart && !other.slice.openEnd) {
      let slice2 = this.slice.size + other.slice.size == 0 ? Slice.empty : new Slice(other.slice.content.append(this.slice.content), other.slice.openStart, this.slice.openEnd);
      return new ReplaceStep(other.from, this.to, slice2, this.structure);
    } else {
      return null;
    }
  }
  toJSON() {
    let json = { stepType: "replace", from: this.from, to: this.to };
    if (this.slice.size)
      json.slice = this.slice.toJSON();
    if (this.structure)
      json.structure = true;
    return json;
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.from != "number" || typeof json.to != "number")
      throw new RangeError("Invalid input for ReplaceStep.fromJSON");
    return new ReplaceStep(json.from, json.to, Slice.fromJSON(schema2, json.slice), !!json.structure);
  }
}
Step.jsonID("replace", ReplaceStep);
class ReplaceAroundStep extends Step {
  static {
    __name(this, "ReplaceAroundStep");
  }
  /**
  Create a replace-around step with the given range and gap.
  `insert` should be the point in the slice into which the content
  of the gap should be moved. `structure` has the same meaning as
  it has in the [`ReplaceStep`](https://prosemirror.net/docs/ref/#transform.ReplaceStep) class.
  */
  constructor(from2, to, gapFrom, gapTo, slice2, insert2, structure = false) {
    super();
    this.from = from2;
    this.to = to;
    this.gapFrom = gapFrom;
    this.gapTo = gapTo;
    this.slice = slice2;
    this.insert = insert2;
    this.structure = structure;
  }
  apply(doc2) {
    if (this.structure && (contentBetween(doc2, this.from, this.gapFrom) || contentBetween(doc2, this.gapTo, this.to)))
      return StepResult.fail("Structure gap-replace would overwrite content");
    let gap = doc2.slice(this.gapFrom, this.gapTo);
    if (gap.openStart || gap.openEnd)
      return StepResult.fail("Gap is not a flat range");
    let inserted = this.slice.insertAt(this.insert, gap.content);
    if (!inserted)
      return StepResult.fail("Content does not fit in gap");
    return StepResult.fromReplace(doc2, this.from, this.to, inserted);
  }
  getMap() {
    return new StepMap([
      this.from,
      this.gapFrom - this.from,
      this.insert,
      this.gapTo,
      this.to - this.gapTo,
      this.slice.size - this.insert
    ]);
  }
  invert(doc2) {
    let gap = this.gapTo - this.gapFrom;
    return new ReplaceAroundStep(this.from, this.from + this.slice.size + gap, this.from + this.insert, this.from + this.insert + gap, doc2.slice(this.from, this.to).removeBetween(this.gapFrom - this.from, this.gapTo - this.from), this.gapFrom - this.from, this.structure);
  }
  map(mapping) {
    let from2 = mapping.mapResult(this.from, 1), to = mapping.mapResult(this.to, -1);
    let gapFrom = this.from == this.gapFrom ? from2.pos : mapping.map(this.gapFrom, -1);
    let gapTo = this.to == this.gapTo ? to.pos : mapping.map(this.gapTo, 1);
    if (from2.deletedAcross && to.deletedAcross || gapFrom < from2.pos || gapTo > to.pos)
      return null;
    return new ReplaceAroundStep(from2.pos, to.pos, gapFrom, gapTo, this.slice, this.insert, this.structure);
  }
  toJSON() {
    let json = {
      stepType: "replaceAround",
      from: this.from,
      to: this.to,
      gapFrom: this.gapFrom,
      gapTo: this.gapTo,
      insert: this.insert
    };
    if (this.slice.size)
      json.slice = this.slice.toJSON();
    if (this.structure)
      json.structure = true;
    return json;
  }
  /**
  @internal
  */
  static fromJSON(schema2, json) {
    if (typeof json.from != "number" || typeof json.to != "number" || typeof json.gapFrom != "number" || typeof json.gapTo != "number" || typeof json.insert != "number")
      throw new RangeError("Invalid input for ReplaceAroundStep.fromJSON");
    return new ReplaceAroundStep(json.from, json.to, json.gapFrom, json.gapTo, Slice.fromJSON(schema2, json.slice), json.insert, !!json.structure);
  }
}
Step.jsonID("replaceAround", ReplaceAroundStep);
function contentBetween(doc2, from2, to) {
  let $from = doc2.resolve(from2), dist3 = to - from2, depth = $from.depth;
  while (dist3 > 0 && depth > 0 && $from.indexAfter(depth) == $from.node(depth).childCount) {
    depth--;
    dist3--;
  }
  if (dist3 > 0) {
    let next2 = $from.node(depth).maybeChild($from.indexAfter(depth));
    while (dist3 > 0) {
      if (!next2 || next2.isLeaf)
        return true;
      next2 = next2.firstChild;
      dist3--;
    }
  }
  return false;
}
__name(contentBetween, "contentBetween");
function addMark(tr2, from2, to, mark2) {
  let removed = [], added = [];
  let removing, adding;
  tr2.doc.nodesBetween(from2, to, (node3, pos, parent) => {
    if (!node3.isInline)
      return;
    let marks = node3.marks;
    if (!mark2.isInSet(marks) && parent.type.allowsMarkType(mark2.type)) {
      let start2 = Math.max(pos, from2), end = Math.min(pos + node3.nodeSize, to);
      let newSet = mark2.addToSet(marks);
      for (let i2 = 0; i2 < marks.length; i2++) {
        if (!marks[i2].isInSet(newSet)) {
          if (removing && removing.to == start2 && removing.mark.eq(marks[i2]))
            removing.to = end;
          else
            removed.push(removing = new RemoveMarkStep(start2, end, marks[i2]));
        }
      }
      if (adding && adding.to == start2)
        adding.to = end;
      else
        added.push(adding = new AddMarkStep(start2, end, mark2));
    }
  });
  removed.forEach((s2) => tr2.step(s2));
  added.forEach((s2) => tr2.step(s2));
}
__name(addMark, "addMark");
function removeMark(tr2, from2, to, mark2) {
  let matched = [], step2 = 0;
  tr2.doc.nodesBetween(from2, to, (node3, pos) => {
    if (!node3.isInline)
      return;
    step2++;
    let toRemove = null;
    if (mark2 instanceof MarkType) {
      let set3 = node3.marks, found2;
      while (found2 = mark2.isInSet(set3)) {
        (toRemove || (toRemove = [])).push(found2);
        set3 = found2.removeFromSet(set3);
      }
    } else if (mark2) {
      if (mark2.isInSet(node3.marks))
        toRemove = [mark2];
    } else {
      toRemove = node3.marks;
    }
    if (toRemove && toRemove.length) {
      let end = Math.min(pos + node3.nodeSize, to);
      for (let i2 = 0; i2 < toRemove.length; i2++) {
        let style2 = toRemove[i2], found2;
        for (let j2 = 0; j2 < matched.length; j2++) {
          let m2 = matched[j2];
          if (m2.step == step2 - 1 && style2.eq(matched[j2].style))
            found2 = m2;
        }
        if (found2) {
          found2.to = end;
          found2.step = step2;
        } else {
          matched.push({ style: style2, from: Math.max(pos, from2), to: end, step: step2 });
        }
      }
    }
  });
  matched.forEach((m2) => tr2.step(new RemoveMarkStep(m2.from, m2.to, m2.style)));
}
__name(removeMark, "removeMark");
function clearIncompatible(tr2, pos, parentType, match2 = parentType.contentMatch, clearNewlines = true) {
  let node3 = tr2.doc.nodeAt(pos);
  let replSteps = [], cur = pos + 1;
  for (let i2 = 0; i2 < node3.childCount; i2++) {
    let child = node3.child(i2), end = cur + child.nodeSize;
    let allowed = match2.matchType(child.type);
    if (!allowed) {
      replSteps.push(new ReplaceStep(cur, end, Slice.empty));
    } else {
      match2 = allowed;
      for (let j2 = 0; j2 < child.marks.length; j2++)
        if (!parentType.allowsMarkType(child.marks[j2].type))
          tr2.step(new RemoveMarkStep(cur, end, child.marks[j2]));
      if (clearNewlines && child.isText && parentType.whitespace != "pre") {
        let m2, newline2 = /\r?\n|\r/g, slice2;
        while (m2 = newline2.exec(child.text)) {
          if (!slice2)
            slice2 = new Slice(Fragment.from(parentType.schema.text(" ", parentType.allowedMarks(child.marks))), 0, 0);
          replSteps.push(new ReplaceStep(cur + m2.index, cur + m2.index + m2[0].length, slice2));
        }
      }
    }
    cur = end;
  }
  if (!match2.validEnd) {
    let fill2 = match2.fillBefore(Fragment.empty, true);
    tr2.replace(cur, cur, new Slice(fill2, 0, 0));
  }
  for (let i2 = replSteps.length - 1; i2 >= 0; i2--)
    tr2.step(replSteps[i2]);
}
__name(clearIncompatible, "clearIncompatible");
function canCut(node3, start2, end) {
  return (start2 == 0 || node3.canReplace(start2, node3.childCount)) && (end == node3.childCount || node3.canReplace(0, end));
}
__name(canCut, "canCut");
function liftTarget(range2) {
  let parent = range2.parent;
  let content3 = parent.content.cutByIndex(range2.startIndex, range2.endIndex);
  for (let depth = range2.depth; ; --depth) {
    let node3 = range2.$from.node(depth);
    let index2 = range2.$from.index(depth), endIndex = range2.$to.indexAfter(depth);
    if (depth < range2.depth && node3.canReplace(index2, endIndex, content3))
      return depth;
    if (depth == 0 || node3.type.spec.isolating || !canCut(node3, index2, endIndex))
      break;
  }
  return null;
}
__name(liftTarget, "liftTarget");
function lift$2(tr2, range2, target2) {
  let { $from, $to, depth } = range2;
  let gapStart = $from.before(depth + 1), gapEnd = $to.after(depth + 1);
  let start2 = gapStart, end = gapEnd;
  let before = Fragment.empty, openStart = 0;
  for (let d2 = depth, splitting = false; d2 > target2; d2--)
    if (splitting || $from.index(d2) > 0) {
      splitting = true;
      before = Fragment.from($from.node(d2).copy(before));
      openStart++;
    } else {
      start2--;
    }
  let after = Fragment.empty, openEnd = 0;
  for (let d2 = depth, splitting = false; d2 > target2; d2--)
    if (splitting || $to.after(d2 + 1) < $to.end(d2)) {
      splitting = true;
      after = Fragment.from($to.node(d2).copy(after));
      openEnd++;
    } else {
      end++;
    }
  tr2.step(new ReplaceAroundStep(start2, end, gapStart, gapEnd, new Slice(before.append(after), openStart, openEnd), before.size - openStart, true));
}
__name(lift$2, "lift$2");
function findWrapping(range2, nodeType, attrs7 = null, innerRange = range2) {
  let around = findWrappingOutside(range2, nodeType);
  let inner = around && findWrappingInside(innerRange, nodeType);
  if (!inner)
    return null;
  return around.map(withAttrs).concat({ type: nodeType, attrs: attrs7 }).concat(inner.map(withAttrs));
}
__name(findWrapping, "findWrapping");
function withAttrs(type) {
  return { type, attrs: null };
}
__name(withAttrs, "withAttrs");
function findWrappingOutside(range2, type) {
  let { parent, startIndex, endIndex } = range2;
  let around = parent.contentMatchAt(startIndex).findWrapping(type);
  if (!around)
    return null;
  let outer = around.length ? around[0] : type;
  return parent.canReplaceWith(startIndex, endIndex, outer) ? around : null;
}
__name(findWrappingOutside, "findWrappingOutside");
function findWrappingInside(range2, type) {
  let { parent, startIndex, endIndex } = range2;
  let inner = parent.child(startIndex);
  let inside = type.contentMatch.findWrapping(inner.type);
  if (!inside)
    return null;
  let lastType = inside.length ? inside[inside.length - 1] : type;
  let innerMatch = lastType.contentMatch;
  for (let i2 = startIndex; innerMatch && i2 < endIndex; i2++)
    innerMatch = innerMatch.matchType(parent.child(i2).type);
  if (!innerMatch || !innerMatch.validEnd)
    return null;
  return inside;
}
__name(findWrappingInside, "findWrappingInside");
function wrap(tr2, range2, wrappers) {
  let content3 = Fragment.empty;
  for (let i2 = wrappers.length - 1; i2 >= 0; i2--) {
    if (content3.size) {
      let match2 = wrappers[i2].type.contentMatch.matchFragment(content3);
      if (!match2 || !match2.validEnd)
        throw new RangeError("Wrapper type given to Transform.wrap does not form valid content of its parent wrapper");
    }
    content3 = Fragment.from(wrappers[i2].type.create(wrappers[i2].attrs, content3));
  }
  let start2 = range2.start, end = range2.end;
  tr2.step(new ReplaceAroundStep(start2, end, start2, end, new Slice(content3, 0, 0), wrappers.length, true));
}
__name(wrap, "wrap");
function setBlockType$1(tr2, from2, to, type, attrs7) {
  if (!type.isTextblock)
    throw new RangeError("Type given to setBlockType should be a textblock");
  let mapFrom = tr2.steps.length;
  tr2.doc.nodesBetween(from2, to, (node3, pos) => {
    let attrsHere = typeof attrs7 == "function" ? attrs7(node3) : attrs7;
    if (node3.isTextblock && !node3.hasMarkup(type, attrsHere) && canChangeType(tr2.doc, tr2.mapping.slice(mapFrom).map(pos), type)) {
      let convertNewlines = null;
      if (type.schema.linebreakReplacement) {
        let pre = type.whitespace == "pre", supportLinebreak = !!type.contentMatch.matchType(type.schema.linebreakReplacement);
        if (pre && !supportLinebreak)
          convertNewlines = false;
        else if (!pre && supportLinebreak)
          convertNewlines = true;
      }
      if (convertNewlines === false)
        replaceLinebreaks(tr2, node3, pos, mapFrom);
      clearIncompatible(tr2, tr2.mapping.slice(mapFrom).map(pos, 1), type, void 0, convertNewlines === null);
      let mapping = tr2.mapping.slice(mapFrom);
      let startM = mapping.map(pos, 1), endM = mapping.map(pos + node3.nodeSize, 1);
      tr2.step(new ReplaceAroundStep(startM, endM, startM + 1, endM - 1, new Slice(Fragment.from(type.create(attrsHere, null, node3.marks)), 0, 0), 1, true));
      if (convertNewlines === true)
        replaceNewlines(tr2, node3, pos, mapFrom);
      return false;
    }
  });
}
__name(setBlockType$1, "setBlockType$1");
function replaceNewlines(tr2, node3, pos, mapFrom) {
  node3.forEach((child, offset) => {
    if (child.isText) {
      let m2, newline2 = /\r?\n|\r/g;
      while (m2 = newline2.exec(child.text)) {
        let start2 = tr2.mapping.slice(mapFrom).map(pos + 1 + offset + m2.index);
        tr2.replaceWith(start2, start2 + 1, node3.type.schema.linebreakReplacement.create());
      }
    }
  });
}
__name(replaceNewlines, "replaceNewlines");
function replaceLinebreaks(tr2, node3, pos, mapFrom) {
  node3.forEach((child, offset) => {
    if (child.type == child.type.schema.linebreakReplacement) {
      let start2 = tr2.mapping.slice(mapFrom).map(pos + 1 + offset);
      tr2.replaceWith(start2, start2 + 1, node3.type.schema.text("\n"));
    }
  });
}
__name(replaceLinebreaks, "replaceLinebreaks");
function canChangeType(doc2, pos, type) {
  let $pos = doc2.resolve(pos), index2 = $pos.index();
  return $pos.parent.canReplaceWith(index2, index2 + 1, type);
}
__name(canChangeType, "canChangeType");
function setNodeMarkup(tr2, pos, type, attrs7, marks) {
  let node3 = tr2.doc.nodeAt(pos);
  if (!node3)
    throw new RangeError("No node at given position");
  if (!type)
    type = node3.type;
  let newNode = type.create(attrs7, null, marks || node3.marks);
  if (node3.isLeaf)
    return tr2.replaceWith(pos, pos + node3.nodeSize, newNode);
  if (!type.validContent(node3.content))
    throw new RangeError("Invalid content for node type " + type.name);
  tr2.step(new ReplaceAroundStep(pos, pos + node3.nodeSize, pos + 1, pos + node3.nodeSize - 1, new Slice(Fragment.from(newNode), 0, 0), 1, true));
}
__name(setNodeMarkup, "setNodeMarkup");
function canSplit(doc2, pos, depth = 1, typesAfter) {
  let $pos = doc2.resolve(pos), base2 = $pos.depth - depth;
  let innerType = typesAfter && typesAfter[typesAfter.length - 1] || $pos.parent;
  if (base2 < 0 || $pos.parent.type.spec.isolating || !$pos.parent.canReplace($pos.index(), $pos.parent.childCount) || !innerType.type.validContent($pos.parent.content.cutByIndex($pos.index(), $pos.parent.childCount)))
    return false;
  for (let d2 = $pos.depth - 1, i2 = depth - 2; d2 > base2; d2--, i2--) {
    let node3 = $pos.node(d2), index3 = $pos.index(d2);
    if (node3.type.spec.isolating)
      return false;
    let rest = node3.content.cutByIndex(index3, node3.childCount);
    let overrideChild = typesAfter && typesAfter[i2 + 1];
    if (overrideChild)
      rest = rest.replaceChild(0, overrideChild.type.create(overrideChild.attrs));
    let after = typesAfter && typesAfter[i2] || node3;
    if (!node3.canReplace(index3 + 1, node3.childCount) || !after.type.validContent(rest))
      return false;
  }
  let index2 = $pos.indexAfter(base2);
  let baseType = typesAfter && typesAfter[0];
  return $pos.node(base2).canReplaceWith(index2, index2, baseType ? baseType.type : $pos.node(base2 + 1).type);
}
__name(canSplit, "canSplit");
function split(tr2, pos, depth = 1, typesAfter) {
  let $pos = tr2.doc.resolve(pos), before = Fragment.empty, after = Fragment.empty;
  for (let d2 = $pos.depth, e2 = $pos.depth - depth, i2 = depth - 1; d2 > e2; d2--, i2--) {
    before = Fragment.from($pos.node(d2).copy(before));
    let typeAfter = typesAfter && typesAfter[i2];
    after = Fragment.from(typeAfter ? typeAfter.type.create(typeAfter.attrs, after) : $pos.node(d2).copy(after));
  }
  tr2.step(new ReplaceStep(pos, pos, new Slice(before.append(after), depth, depth), true));
}
__name(split, "split");
function canJoin(doc2, pos) {
  let $pos = doc2.resolve(pos), index2 = $pos.index();
  return joinable($pos.nodeBefore, $pos.nodeAfter) && $pos.parent.canReplace(index2, index2 + 1);
}
__name(canJoin, "canJoin");
function canAppendWithSubstitutedLinebreaks(a2, b2) {
  if (!b2.content.size)
    a2.type.compatibleContent(b2.type);
  let match2 = a2.contentMatchAt(a2.childCount);
  let { linebreakReplacement } = a2.type.schema;
  for (let i2 = 0; i2 < b2.childCount; i2++) {
    let child = b2.child(i2);
    let type = child.type == linebreakReplacement ? a2.type.schema.nodes.text : child.type;
    match2 = match2.matchType(type);
    if (!match2)
      return false;
    if (!a2.type.allowsMarks(child.marks))
      return false;
  }
  return match2.validEnd;
}
__name(canAppendWithSubstitutedLinebreaks, "canAppendWithSubstitutedLinebreaks");
function joinable(a2, b2) {
  return !!(a2 && b2 && !a2.isLeaf && canAppendWithSubstitutedLinebreaks(a2, b2));
}
__name(joinable, "joinable");
function joinPoint(doc2, pos, dir = -1) {
  let $pos = doc2.resolve(pos);
  for (let d2 = $pos.depth; ; d2--) {
    let before, after, index2 = $pos.index(d2);
    if (d2 == $pos.depth) {
      before = $pos.nodeBefore;
      after = $pos.nodeAfter;
    } else if (dir > 0) {
      before = $pos.node(d2 + 1);
      index2++;
      after = $pos.node(d2).maybeChild(index2);
    } else {
      before = $pos.node(d2).maybeChild(index2 - 1);
      after = $pos.node(d2 + 1);
    }
    if (before && !before.isTextblock && joinable(before, after) && $pos.node(d2).canReplace(index2, index2 + 1))
      return pos;
    if (d2 == 0)
      break;
    pos = dir < 0 ? $pos.before(d2) : $pos.after(d2);
  }
}
__name(joinPoint, "joinPoint");
function join(tr2, pos, depth) {
  let convertNewlines = null;
  let { linebreakReplacement } = tr2.doc.type.schema;
  let $before = tr2.doc.resolve(pos - depth), beforeType = $before.node().type;
  if (linebreakReplacement && beforeType.inlineContent) {
    let pre = beforeType.whitespace == "pre";
    let supportLinebreak = !!beforeType.contentMatch.matchType(linebreakReplacement);
    if (pre && !supportLinebreak)
      convertNewlines = false;
    else if (!pre && supportLinebreak)
      convertNewlines = true;
  }
  let mapFrom = tr2.steps.length;
  if (convertNewlines === false) {
    let $after = tr2.doc.resolve(pos + depth);
    replaceLinebreaks(tr2, $after.node(), $after.before(), mapFrom);
  }
  if (beforeType.inlineContent)
    clearIncompatible(tr2, pos + depth - 1, beforeType, $before.node().contentMatchAt($before.index()), convertNewlines == null);
  let mapping = tr2.mapping.slice(mapFrom), start2 = mapping.map(pos - depth);
  tr2.step(new ReplaceStep(start2, mapping.map(pos + depth, -1), Slice.empty, true));
  if (convertNewlines === true) {
    let $full = tr2.doc.resolve(start2);
    replaceNewlines(tr2, $full.node(), $full.before(), tr2.steps.length);
  }
  return tr2;
}
__name(join, "join");
function insertPoint(doc2, pos, nodeType) {
  let $pos = doc2.resolve(pos);
  if ($pos.parent.canReplaceWith($pos.index(), $pos.index(), nodeType))
    return pos;
  if ($pos.parentOffset == 0)
    for (let d2 = $pos.depth - 1; d2 >= 0; d2--) {
      let index2 = $pos.index(d2);
      if ($pos.node(d2).canReplaceWith(index2, index2, nodeType))
        return $pos.before(d2 + 1);
      if (index2 > 0)
        return null;
    }
  if ($pos.parentOffset == $pos.parent.content.size)
    for (let d2 = $pos.depth - 1; d2 >= 0; d2--) {
      let index2 = $pos.indexAfter(d2);
      if ($pos.node(d2).canReplaceWith(index2, index2, nodeType))
        return $pos.after(d2 + 1);
      if (index2 < $pos.node(d2).childCount)
        return null;
    }
  return null;
}
__name(insertPoint, "insertPoint");
function dropPoint(doc2, pos, slice2) {
  let $pos = doc2.resolve(pos);
  if (!slice2.content.size)
    return pos;
  let content3 = slice2.content;
  for (let i2 = 0; i2 < slice2.openStart; i2++)
    content3 = content3.firstChild.content;
  for (let pass = 1; pass <= (slice2.openStart == 0 && slice2.size ? 2 : 1); pass++) {
    for (let d2 = $pos.depth; d2 >= 0; d2--) {
      let bias = d2 == $pos.depth ? 0 : $pos.pos <= ($pos.start(d2 + 1) + $pos.end(d2 + 1)) / 2 ? -1 : 1;
      let insertPos = $pos.index(d2) + (bias > 0 ? 1 : 0);
      let parent = $pos.node(d2), fits = false;
      if (pass == 1) {
        fits = parent.canReplace(insertPos, insertPos, content3);
      } else {
        let wrapping = parent.contentMatchAt(insertPos).findWrapping(content3.firstChild.type);
        fits = wrapping && parent.canReplaceWith(insertPos, insertPos, wrapping[0]);
      }
      if (fits)
        return bias == 0 ? $pos.pos : bias < 0 ? $pos.before(d2 + 1) : $pos.after(d2 + 1);
    }
  }
  return null;
}
__name(dropPoint, "dropPoint");
function replaceStep(doc2, from2, to = from2, slice2 = Slice.empty) {
  if (from2 == to && !slice2.size)
    return null;
  let $from = doc2.resolve(from2), $to = doc2.resolve(to);
  if (fitsTrivially($from, $to, slice2))
    return new ReplaceStep(from2, to, slice2);
  return new Fitter($from, $to, slice2).fit();
}
__name(replaceStep, "replaceStep");
function fitsTrivially($from, $to, slice2) {
  return !slice2.openStart && !slice2.openEnd && $from.start() == $to.start() && $from.parent.canReplace($from.index(), $to.index(), slice2.content);
}
__name(fitsTrivially, "fitsTrivially");
class Fitter {
  static {
    __name(this, "Fitter");
  }
  constructor($from, $to, unplaced) {
    this.$from = $from;
    this.$to = $to;
    this.unplaced = unplaced;
    this.frontier = [];
    this.placed = Fragment.empty;
    for (let i2 = 0; i2 <= $from.depth; i2++) {
      let node3 = $from.node(i2);
      this.frontier.push({
        type: node3.type,
        match: node3.contentMatchAt($from.indexAfter(i2))
      });
    }
    for (let i2 = $from.depth; i2 > 0; i2--)
      this.placed = Fragment.from($from.node(i2).copy(this.placed));
  }
  get depth() {
    return this.frontier.length - 1;
  }
  fit() {
    while (this.unplaced.size) {
      let fit = this.findFittable();
      if (fit)
        this.placeNodes(fit);
      else
        this.openMore() || this.dropNode();
    }
    let moveInline = this.mustMoveInline(), placedSize = this.placed.size - this.depth - this.$from.depth;
    let $from = this.$from, $to = this.close(moveInline < 0 ? this.$to : $from.doc.resolve(moveInline));
    if (!$to)
      return null;
    let content3 = this.placed, openStart = $from.depth, openEnd = $to.depth;
    while (openStart && openEnd && content3.childCount == 1) {
      content3 = content3.firstChild.content;
      openStart--;
      openEnd--;
    }
    let slice2 = new Slice(content3, openStart, openEnd);
    if (moveInline > -1)
      return new ReplaceAroundStep($from.pos, moveInline, this.$to.pos, this.$to.end(), slice2, placedSize);
    if (slice2.size || $from.pos != this.$to.pos)
      return new ReplaceStep($from.pos, $to.pos, slice2);
    return null;
  }
  // Find a position on the start spine of `this.unplaced` that has
  // content that can be moved somewhere on the frontier. Returns two
  // depths, one for the slice and one for the frontier.
  findFittable() {
    let startDepth = this.unplaced.openStart;
    for (let cur = this.unplaced.content, d2 = 0, openEnd = this.unplaced.openEnd; d2 < startDepth; d2++) {
      let node3 = cur.firstChild;
      if (cur.childCount > 1)
        openEnd = 0;
      if (node3.type.spec.isolating && openEnd <= d2) {
        startDepth = d2;
        break;
      }
      cur = node3.content;
    }
    for (let pass = 1; pass <= 2; pass++) {
      for (let sliceDepth = pass == 1 ? startDepth : this.unplaced.openStart; sliceDepth >= 0; sliceDepth--) {
        let fragment, parent = null;
        if (sliceDepth) {
          parent = contentAt(this.unplaced.content, sliceDepth - 1).firstChild;
          fragment = parent.content;
        } else {
          fragment = this.unplaced.content;
        }
        let first2 = fragment.firstChild;
        for (let frontierDepth = this.depth; frontierDepth >= 0; frontierDepth--) {
          let { type, match: match2 } = this.frontier[frontierDepth], wrap2, inject2 = null;
          if (pass == 1 && (first2 ? match2.matchType(first2.type) || (inject2 = match2.fillBefore(Fragment.from(first2), false)) : parent && type.compatibleContent(parent.type)))
            return { sliceDepth, frontierDepth, parent, inject: inject2 };
          else if (pass == 2 && first2 && (wrap2 = match2.findWrapping(first2.type)))
            return { sliceDepth, frontierDepth, parent, wrap: wrap2 };
          if (parent && match2.matchType(parent.type))
            break;
        }
      }
    }
  }
  openMore() {
    let { content: content3, openStart, openEnd } = this.unplaced;
    let inner = contentAt(content3, openStart);
    if (!inner.childCount || inner.firstChild.isLeaf)
      return false;
    this.unplaced = new Slice(content3, openStart + 1, Math.max(openEnd, inner.size + openStart >= content3.size - openEnd ? openStart + 1 : 0));
    return true;
  }
  dropNode() {
    let { content: content3, openStart, openEnd } = this.unplaced;
    let inner = contentAt(content3, openStart);
    if (inner.childCount <= 1 && openStart > 0) {
      let openAtEnd = content3.size - openStart <= openStart + inner.size;
      this.unplaced = new Slice(dropFromFragment(content3, openStart - 1, 1), openStart - 1, openAtEnd ? openStart - 1 : openEnd);
    } else {
      this.unplaced = new Slice(dropFromFragment(content3, openStart, 1), openStart, openEnd);
    }
  }
  // Move content from the unplaced slice at `sliceDepth` to the
  // frontier node at `frontierDepth`. Close that frontier node when
  // applicable.
  placeNodes({ sliceDepth, frontierDepth, parent, inject: inject2, wrap: wrap2 }) {
    while (this.depth > frontierDepth)
      this.closeFrontierNode();
    if (wrap2)
      for (let i2 = 0; i2 < wrap2.length; i2++)
        this.openFrontierNode(wrap2[i2]);
    let slice2 = this.unplaced, fragment = parent ? parent.content : slice2.content;
    let openStart = slice2.openStart - sliceDepth;
    let taken = 0, add3 = [];
    let { match: match2, type } = this.frontier[frontierDepth];
    if (inject2) {
      for (let i2 = 0; i2 < inject2.childCount; i2++)
        add3.push(inject2.child(i2));
      match2 = match2.matchFragment(inject2);
    }
    let openEndCount = fragment.size + sliceDepth - (slice2.content.size - slice2.openEnd);
    while (taken < fragment.childCount) {
      let next2 = fragment.child(taken), matches2 = match2.matchType(next2.type);
      if (!matches2)
        break;
      taken++;
      if (taken > 1 || openStart == 0 || next2.content.size) {
        match2 = matches2;
        add3.push(closeNodeStart(next2.mark(type.allowedMarks(next2.marks)), taken == 1 ? openStart : 0, taken == fragment.childCount ? openEndCount : -1));
      }
    }
    let toEnd = taken == fragment.childCount;
    if (!toEnd)
      openEndCount = -1;
    this.placed = addToFragment(this.placed, frontierDepth, Fragment.from(add3));
    this.frontier[frontierDepth].match = match2;
    if (toEnd && openEndCount < 0 && parent && parent.type == this.frontier[this.depth].type && this.frontier.length > 1)
      this.closeFrontierNode();
    for (let i2 = 0, cur = fragment; i2 < openEndCount; i2++) {
      let node3 = cur.lastChild;
      this.frontier.push({ type: node3.type, match: node3.contentMatchAt(node3.childCount) });
      cur = node3.content;
    }
    this.unplaced = !toEnd ? new Slice(dropFromFragment(slice2.content, sliceDepth, taken), slice2.openStart, slice2.openEnd) : sliceDepth == 0 ? Slice.empty : new Slice(dropFromFragment(slice2.content, sliceDepth - 1, 1), sliceDepth - 1, openEndCount < 0 ? slice2.openEnd : sliceDepth - 1);
  }
  mustMoveInline() {
    if (!this.$to.parent.isTextblock)
      return -1;
    let top = this.frontier[this.depth], level;
    if (!top.type.isTextblock || !contentAfterFits(this.$to, this.$to.depth, top.type, top.match, false) || this.$to.depth == this.depth && (level = this.findCloseLevel(this.$to)) && level.depth == this.depth)
      return -1;
    let { depth } = this.$to, after = this.$to.after(depth);
    while (depth > 1 && after == this.$to.end(--depth))
      ++after;
    return after;
  }
  findCloseLevel($to) {
    scan: for (let i2 = Math.min(this.depth, $to.depth); i2 >= 0; i2--) {
      let { match: match2, type } = this.frontier[i2];
      let dropInner = i2 < $to.depth && $to.end(i2 + 1) == $to.pos + ($to.depth - (i2 + 1));
      let fit = contentAfterFits($to, i2, type, match2, dropInner);
      if (!fit)
        continue;
      for (let d2 = i2 - 1; d2 >= 0; d2--) {
        let { match: match3, type: type2 } = this.frontier[d2];
        let matches2 = contentAfterFits($to, d2, type2, match3, true);
        if (!matches2 || matches2.childCount)
          continue scan;
      }
      return { depth: i2, fit, move: dropInner ? $to.doc.resolve($to.after(i2 + 1)) : $to };
    }
  }
  close($to) {
    let close5 = this.findCloseLevel($to);
    if (!close5)
      return null;
    while (this.depth > close5.depth)
      this.closeFrontierNode();
    if (close5.fit.childCount)
      this.placed = addToFragment(this.placed, close5.depth, close5.fit);
    $to = close5.move;
    for (let d2 = close5.depth + 1; d2 <= $to.depth; d2++) {
      let node3 = $to.node(d2), add3 = node3.type.contentMatch.fillBefore(node3.content, true, $to.index(d2));
      this.openFrontierNode(node3.type, node3.attrs, add3);
    }
    return $to;
  }
  openFrontierNode(type, attrs7 = null, content3) {
    let top = this.frontier[this.depth];
    top.match = top.match.matchType(type);
    this.placed = addToFragment(this.placed, this.depth, Fragment.from(type.create(attrs7, content3)));
    this.frontier.push({ type, match: type.contentMatch });
  }
  closeFrontierNode() {
    let open2 = this.frontier.pop();
    let add3 = open2.match.fillBefore(Fragment.empty, true);
    if (add3.childCount)
      this.placed = addToFragment(this.placed, this.frontier.length, add3);
  }
}
function dropFromFragment(fragment, depth, count) {
  if (depth == 0)
    return fragment.cutByIndex(count, fragment.childCount);
  return fragment.replaceChild(0, fragment.firstChild.copy(dropFromFragment(fragment.firstChild.content, depth - 1, count)));
}
__name(dropFromFragment, "dropFromFragment");
function addToFragment(fragment, depth, content3) {
  if (depth == 0)
    return fragment.append(content3);
  return fragment.replaceChild(fragment.childCount - 1, fragment.lastChild.copy(addToFragment(fragment.lastChild.content, depth - 1, content3)));
}
__name(addToFragment, "addToFragment");
function contentAt(fragment, depth) {
  for (let i2 = 0; i2 < depth; i2++)
    fragment = fragment.firstChild.content;
  return fragment;
}
__name(contentAt, "contentAt");
function closeNodeStart(node3, openStart, openEnd) {
  if (openStart <= 0)
    return node3;
  let frag = node3.content;
  if (openStart > 1)
    frag = frag.replaceChild(0, closeNodeStart(frag.firstChild, openStart - 1, frag.childCount == 1 ? openEnd - 1 : 0));
  if (openStart > 0) {
    frag = node3.type.contentMatch.fillBefore(frag).append(frag);
    if (openEnd <= 0)
      frag = frag.append(node3.type.contentMatch.matchFragment(frag).fillBefore(Fragment.empty, true));
  }
  return node3.copy(frag);
}
__name(closeNodeStart, "closeNodeStart");
function contentAfterFits($to, depth, type, match2, open2) {
  let node3 = $to.node(depth), index2 = open2 ? $to.indexAfter(depth) : $to.index(depth);
  if (index2 == node3.childCount && !type.compatibleContent(node3.type))
    return null;
  let fit = match2.fillBefore(node3.content, true, index2);
  return fit && !invalidMarks(type, node3.content, index2) ? fit : null;
}
__name(contentAfterFits, "contentAfterFits");
function invalidMarks(type, fragment, start2) {
  for (let i2 = start2; i2 < fragment.childCount; i2++)
    if (!type.allowsMarks(fragment.child(i2).marks))
      return true;
  return false;
}
__name(invalidMarks, "invalidMarks");
function definesContent(type) {
  return type.spec.defining || type.spec.definingForContent;
}
__name(definesContent, "definesContent");
function replaceRange(tr2, from2, to, slice2) {
  if (!slice2.size)
    return tr2.deleteRange(from2, to);
  let $from = tr2.doc.resolve(from2), $to = tr2.doc.resolve(to);
  if (fitsTrivially($from, $to, slice2))
    return tr2.step(new ReplaceStep(from2, to, slice2));
  let targetDepths = coveredDepths($from, tr2.doc.resolve(to));
  if (targetDepths[targetDepths.length - 1] == 0)
    targetDepths.pop();
  let preferredTarget = -($from.depth + 1);
  targetDepths.unshift(preferredTarget);
  for (let d2 = $from.depth, pos = $from.pos - 1; d2 > 0; d2--, pos--) {
    let spec = $from.node(d2).type.spec;
    if (spec.defining || spec.definingAsContext || spec.isolating)
      break;
    if (targetDepths.indexOf(d2) > -1)
      preferredTarget = d2;
    else if ($from.before(d2) == pos)
      targetDepths.splice(1, 0, -d2);
  }
  let preferredTargetIndex = targetDepths.indexOf(preferredTarget);
  let leftNodes = [], preferredDepth = slice2.openStart;
  for (let content3 = slice2.content, i2 = 0; ; i2++) {
    let node3 = content3.firstChild;
    leftNodes.push(node3);
    if (i2 == slice2.openStart)
      break;
    content3 = node3.content;
  }
  for (let d2 = preferredDepth - 1; d2 >= 0; d2--) {
    let leftNode = leftNodes[d2], def2 = definesContent(leftNode.type);
    if (def2 && !leftNode.sameMarkup($from.node(Math.abs(preferredTarget) - 1)))
      preferredDepth = d2;
    else if (def2 || !leftNode.type.isTextblock)
      break;
  }
  for (let j2 = slice2.openStart; j2 >= 0; j2--) {
    let openDepth = (j2 + preferredDepth + 1) % (slice2.openStart + 1);
    let insert2 = leftNodes[openDepth];
    if (!insert2)
      continue;
    for (let i2 = 0; i2 < targetDepths.length; i2++) {
      let targetDepth = targetDepths[(i2 + preferredTargetIndex) % targetDepths.length], expand = true;
      if (targetDepth < 0) {
        expand = false;
        targetDepth = -targetDepth;
      }
      let parent = $from.node(targetDepth - 1), index2 = $from.index(targetDepth - 1);
      if (parent.canReplaceWith(index2, index2, insert2.type, insert2.marks))
        return tr2.replace($from.before(targetDepth), expand ? $to.after(targetDepth) : to, new Slice(closeFragment(slice2.content, 0, slice2.openStart, openDepth), openDepth, slice2.openEnd));
    }
  }
  let startSteps = tr2.steps.length;
  for (let i2 = targetDepths.length - 1; i2 >= 0; i2--) {
    tr2.replace(from2, to, slice2);
    if (tr2.steps.length > startSteps)
      break;
    let depth = targetDepths[i2];
    if (depth < 0)
      continue;
    from2 = $from.before(depth);
    to = $to.after(depth);
  }
}
__name(replaceRange, "replaceRange");
function closeFragment(fragment, depth, oldOpen, newOpen, parent) {
  if (depth < oldOpen) {
    let first2 = fragment.firstChild;
    fragment = fragment.replaceChild(0, first2.copy(closeFragment(first2.content, depth + 1, oldOpen, newOpen, first2)));
  }
  if (depth > newOpen) {
    let match2 = parent.contentMatchAt(0);
    let start2 = match2.fillBefore(fragment).append(fragment);
    fragment = start2.append(match2.matchFragment(start2).fillBefore(Fragment.empty, true));
  }
  return fragment;
}
__name(closeFragment, "closeFragment");
function replaceRangeWith(tr2, from2, to, node3) {
  if (!node3.isInline && from2 == to && tr2.doc.resolve(from2).parent.content.size) {
    let point = insertPoint(tr2.doc, from2, node3.type);
    if (point != null)
      from2 = to = point;
  }
  tr2.replaceRange(from2, to, new Slice(Fragment.from(node3), 0, 0));
}
__name(replaceRangeWith, "replaceRangeWith");
function deleteRange$1(tr2, from2, to) {
  let $from = tr2.doc.resolve(from2), $to = tr2.doc.resolve(to);
  let covered = coveredDepths($from, $to);
  for (let i2 = 0; i2 < covered.length; i2++) {
    let depth = covered[i2], last = i2 == covered.length - 1;
    if (last && depth == 0 || $from.node(depth).type.contentMatch.validEnd)
      return tr2.delete($from.start(depth), $to.end(depth));
    if (depth > 0 && (last || $from.node(depth - 1).canReplace($from.index(depth - 1), $to.indexAfter(depth - 1))))
      return tr2.delete($from.before(depth), $to.after(depth));
  }
  for (let d2 = 1; d2 <= $from.depth && d2 <= $to.depth; d2++) {
    if (from2 - $from.start(d2) == $from.depth - d2 && to > $from.end(d2) && $to.end(d2) - to != $to.depth - d2 && $from.start(d2 - 1) == $to.start(d2 - 1) && $from.node(d2 - 1).canReplace($from.index(d2 - 1), $to.index(d2 - 1)))
      return tr2.delete($from.before(d2), to);
  }
  tr2.delete(from2, to);
}
__name(deleteRange$1, "deleteRange$1");
function coveredDepths($from, $to) {
  let result = [], minDepth = Math.min($from.depth, $to.depth);
  for (let d2 = minDepth; d2 >= 0; d2--) {
    let start2 = $from.start(d2);
    if (start2 < $from.pos - ($from.depth - d2) || $to.end(d2) > $to.pos + ($to.depth - d2) || $from.node(d2).type.spec.isolating || $to.node(d2).type.spec.isolating)
      break;
    if (start2 == $to.start(d2) || d2 == $from.depth && d2 == $to.depth && $from.parent.inlineContent && $to.parent.inlineContent && d2 && $to.start(d2 - 1) == start2 - 1)
      result.push(d2);
  }
  return result;
}
__name(coveredDepths, "coveredDepths");
class AttrStep extends Step {
  static {
    __name(this, "AttrStep");
  }
  /**
  Construct an attribute step.
  */
  constructor(pos, attr, value3) {
    super();
    this.pos = pos;
    this.attr = attr;
    this.value = value3;
  }
  apply(doc2) {
    let node3 = doc2.nodeAt(this.pos);
    if (!node3)
      return StepResult.fail("No node at attribute step's position");
    let attrs7 = /* @__PURE__ */ Object.create(null);
    for (let name2 in node3.attrs)
      attrs7[name2] = node3.attrs[name2];
    attrs7[this.attr] = this.value;
    let updated17 = node3.type.create(attrs7, null, node3.marks);
    return StepResult.fromReplace(doc2, this.pos, this.pos + 1, new Slice(Fragment.from(updated17), 0, node3.isLeaf ? 0 : 1));
  }
  getMap() {
    return StepMap.empty;
  }
  invert(doc2) {
    return new AttrStep(this.pos, this.attr, doc2.nodeAt(this.pos).attrs[this.attr]);
  }
  map(mapping) {
    let pos = mapping.mapResult(this.pos, 1);
    return pos.deletedAfter ? null : new AttrStep(pos.pos, this.attr, this.value);
  }
  toJSON() {
    return { stepType: "attr", pos: this.pos, attr: this.attr, value: this.value };
  }
  static fromJSON(schema2, json) {
    if (typeof json.pos != "number" || typeof json.attr != "string")
      throw new RangeError("Invalid input for AttrStep.fromJSON");
    return new AttrStep(json.pos, json.attr, json.value);
  }
}
Step.jsonID("attr", AttrStep);
class DocAttrStep extends Step {
  static {
    __name(this, "DocAttrStep");
  }
  /**
  Construct an attribute step.
  */
  constructor(attr, value3) {
    super();
    this.attr = attr;
    this.value = value3;
  }
  apply(doc2) {
    let attrs7 = /* @__PURE__ */ Object.create(null);
    for (let name2 in doc2.attrs)
      attrs7[name2] = doc2.attrs[name2];
    attrs7[this.attr] = this.value;
    let updated17 = doc2.type.create(attrs7, doc2.content, doc2.marks);
    return StepResult.ok(updated17);
  }
  getMap() {
    return StepMap.empty;
  }
  invert(doc2) {
    return new DocAttrStep(this.attr, doc2.attrs[this.attr]);
  }
  map(mapping) {
    return this;
  }
  toJSON() {
    return { stepType: "docAttr", attr: this.attr, value: this.value };
  }
  static fromJSON(schema2, json) {
    if (typeof json.attr != "string")
      throw new RangeError("Invalid input for DocAttrStep.fromJSON");
    return new DocAttrStep(json.attr, json.value);
  }
}
Step.jsonID("docAttr", DocAttrStep);
let TransformError = class extends Error {
  static {
    __name(this, "TransformError");
  }
};
TransformError = /* @__PURE__ */ __name(function TransformError2(message3) {
  let err = Error.call(this, message3);
  err.__proto__ = TransformError2.prototype;
  return err;
}, "TransformError");
TransformError.prototype = Object.create(Error.prototype);
TransformError.prototype.constructor = TransformError;
TransformError.prototype.name = "TransformError";
class Transform {
  static {
    __name(this, "Transform");
  }
  /**
  Create a transform that starts with the given document.
  */
  constructor(doc2) {
    this.doc = doc2;
    this.steps = [];
    this.docs = [];
    this.mapping = new Mapping();
  }
  /**
  The starting document.
  */
  get before() {
    return this.docs.length ? this.docs[0] : this.doc;
  }
  /**
  Apply a new step in this transform, saving the result. Throws an
  error when the step fails.
  */
  step(step2) {
    let result = this.maybeStep(step2);
    if (result.failed)
      throw new TransformError(result.failed);
    return this;
  }
  /**
  Try to apply a step in this transformation, ignoring it if it
  fails. Returns the step result.
  */
  maybeStep(step2) {
    let result = step2.apply(this.doc);
    if (!result.failed)
      this.addStep(step2, result.doc);
    return result;
  }
  /**
  True when the document has been changed (when there are any
  steps).
  */
  get docChanged() {
    return this.steps.length > 0;
  }
  /**
  @internal
  */
  addStep(step2, doc2) {
    this.docs.push(this.doc);
    this.steps.push(step2);
    this.mapping.appendMap(step2.getMap());
    this.doc = doc2;
  }
  /**
  Replace the part of the document between `from` and `to` with the
  given `slice`.
  */
  replace(from2, to = from2, slice2 = Slice.empty) {
    let step2 = replaceStep(this.doc, from2, to, slice2);
    if (step2)
      this.step(step2);
    return this;
  }
  /**
  Replace the given range with the given content, which may be a
  fragment, node, or array of nodes.
  */
  replaceWith(from2, to, content3) {
    return this.replace(from2, to, new Slice(Fragment.from(content3), 0, 0));
  }
  /**
  Delete the content between the given positions.
  */
  delete(from2, to) {
    return this.replace(from2, to, Slice.empty);
  }
  /**
  Insert the given content at the given position.
  */
  insert(pos, content3) {
    return this.replaceWith(pos, pos, content3);
  }
  /**
  Replace a range of the document with a given slice, using
  `from`, `to`, and the slice's
  [`openStart`](https://prosemirror.net/docs/ref/#model.Slice.openStart) property as hints, rather
  than fixed start and end points. This method may grow the
  replaced area or close open nodes in the slice in order to get a
  fit that is more in line with WYSIWYG expectations, by dropping
  fully covered parent nodes of the replaced region when they are
  marked [non-defining as
  context](https://prosemirror.net/docs/ref/#model.NodeSpec.definingAsContext), or including an
  open parent node from the slice that _is_ marked as [defining
  its content](https://prosemirror.net/docs/ref/#model.NodeSpec.definingForContent).
  
  This is the method, for example, to handle paste. The similar
  [`replace`](https://prosemirror.net/docs/ref/#transform.Transform.replace) method is a more
  primitive tool which will _not_ move the start and end of its given
  range, and is useful in situations where you need more precise
  control over what happens.
  */
  replaceRange(from2, to, slice2) {
    replaceRange(this, from2, to, slice2);
    return this;
  }
  /**
  Replace the given range with a node, but use `from` and `to` as
  hints, rather than precise positions. When from and to are the same
  and are at the start or end of a parent node in which the given
  node doesn't fit, this method may _move_ them out towards a parent
  that does allow the given node to be placed. When the given range
  completely covers a parent node, this method may completely replace
  that parent node.
  */
  replaceRangeWith(from2, to, node3) {
    replaceRangeWith(this, from2, to, node3);
    return this;
  }
  /**
  Delete the given range, expanding it to cover fully covered
  parent nodes until a valid replace is found.
  */
  deleteRange(from2, to) {
    deleteRange$1(this, from2, to);
    return this;
  }
  /**
  Split the content in the given range off from its parent, if there
  is sibling content before or after it, and move it up the tree to
  the depth specified by `target`. You'll probably want to use
  [`liftTarget`](https://prosemirror.net/docs/ref/#transform.liftTarget) to compute `target`, to make
  sure the lift is valid.
  */
  lift(range2, target2) {
    lift$2(this, range2, target2);
    return this;
  }
  /**
  Join the blocks around the given position. If depth is 2, their
  last and first siblings are also joined, and so on.
  */
  join(pos, depth = 1) {
    join(this, pos, depth);
    return this;
  }
  /**
  Wrap the given [range](https://prosemirror.net/docs/ref/#model.NodeRange) in the given set of wrappers.
  The wrappers are assumed to be valid in this position, and should
  probably be computed with [`findWrapping`](https://prosemirror.net/docs/ref/#transform.findWrapping).
  */
  wrap(range2, wrappers) {
    wrap(this, range2, wrappers);
    return this;
  }
  /**
  Set the type of all textblocks (partly) between `from` and `to` to
  the given node type with the given attributes.
  */
  setBlockType(from2, to = from2, type, attrs7 = null) {
    setBlockType$1(this, from2, to, type, attrs7);
    return this;
  }
  /**
  Change the type, attributes, and/or marks of the node at `pos`.
  When `type` isn't given, the existing node type is preserved,
  */
  setNodeMarkup(pos, type, attrs7 = null, marks) {
    setNodeMarkup(this, pos, type, attrs7, marks);
    return this;
  }
  /**
  Set a single attribute on a given node to a new value.
  The `pos` addresses the document content. Use `setDocAttribute`
  to set attributes on the document itself.
  */
  setNodeAttribute(pos, attr, value3) {
    this.step(new AttrStep(pos, attr, value3));
    return this;
  }
  /**
  Set a single attribute on the document to a new value.
  */
  setDocAttribute(attr, value3) {
    this.step(new DocAttrStep(attr, value3));
    return this;
  }
  /**
  Add a mark to the node at position `pos`.
  */
  addNodeMark(pos, mark2) {
    this.step(new AddNodeMarkStep(pos, mark2));
    return this;
  }
  /**
  Remove a mark (or a mark of the given type) from the node at
  position `pos`.
  */
  removeNodeMark(pos, mark2) {
    if (!(mark2 instanceof Mark$1)) {
      let node3 = this.doc.nodeAt(pos);
      if (!node3)
        throw new RangeError("No node at position " + pos);
      mark2 = mark2.isInSet(node3.marks);
      if (!mark2)
        return this;
    }
    this.step(new RemoveNodeMarkStep(pos, mark2));
    return this;
  }
  /**
  Split the node at the given position, and optionally, if `depth` is
  greater than one, any number of nodes above that. By default, the
  parts split off will inherit the node type of the original node.
  This can be changed by passing an array of types and attributes to
  use after the split.
  */
  split(pos, depth = 1, typesAfter) {
    split(this, pos, depth, typesAfter);
    return this;
  }
  /**
  Add the given mark to the inline content between `from` and `to`.
  */
  addMark(from2, to, mark2) {
    addMark(this, from2, to, mark2);
    return this;
  }
  /**
  Remove marks from inline nodes between `from` and `to`. When
  `mark` is a single mark, remove precisely that mark. When it is
  a mark type, remove all marks of that type. When it is null,
  remove all marks of any type.
  */
  removeMark(from2, to, mark2) {
    removeMark(this, from2, to, mark2);
    return this;
  }
  /**
  Removes all marks and nodes from the content of the node at
  `pos` that don't match the given new parent node type. Accepts
  an optional starting [content match](https://prosemirror.net/docs/ref/#model.ContentMatch) as
  third argument.
  */
  clearIncompatible(pos, parentType, match2) {
    clearIncompatible(this, pos, parentType, match2);
    return this;
  }
}
const classesById = /* @__PURE__ */ Object.create(null);
class Selection {
  static {
    __name(this, "Selection");
  }
  /**
  Initialize a selection with the head and anchor and ranges. If no
  ranges are given, constructs a single range across `$anchor` and
  `$head`.
  */
  constructor($anchor, $head, ranges) {
    this.$anchor = $anchor;
    this.$head = $head;
    this.ranges = ranges || [new SelectionRange($anchor.min($head), $anchor.max($head))];
  }
  /**
  The selection's anchor, as an unresolved position.
  */
  get anchor() {
    return this.$anchor.pos;
  }
  /**
  The selection's head.
  */
  get head() {
    return this.$head.pos;
  }
  /**
  The lower bound of the selection's main range.
  */
  get from() {
    return this.$from.pos;
  }
  /**
  The upper bound of the selection's main range.
  */
  get to() {
    return this.$to.pos;
  }
  /**
  The resolved lower  bound of the selection's main range.
  */
  get $from() {
    return this.ranges[0].$from;
  }
  /**
  The resolved upper bound of the selection's main range.
  */
  get $to() {
    return this.ranges[0].$to;
  }
  /**
  Indicates whether the selection contains any content.
  */
  get empty() {
    let ranges = this.ranges;
    for (let i2 = 0; i2 < ranges.length; i2++)
      if (ranges[i2].$from.pos != ranges[i2].$to.pos)
        return false;
    return true;
  }
  /**
  Get the content of this selection as a slice.
  */
  content() {
    return this.$from.doc.slice(this.from, this.to, true);
  }
  /**
  Replace the selection with a slice or, if no slice is given,
  delete the selection. Will append to the given transaction.
  */
  replace(tr2, content3 = Slice.empty) {
    let lastNode = content3.content.lastChild, lastParent = null;
    for (let i2 = 0; i2 < content3.openEnd; i2++) {
      lastParent = lastNode;
      lastNode = lastNode.lastChild;
    }
    let mapFrom = tr2.steps.length, ranges = this.ranges;
    for (let i2 = 0; i2 < ranges.length; i2++) {
      let { $from, $to } = ranges[i2], mapping = tr2.mapping.slice(mapFrom);
      tr2.replaceRange(mapping.map($from.pos), mapping.map($to.pos), i2 ? Slice.empty : content3);
      if (i2 == 0)
        selectionToInsertionEnd$1(tr2, mapFrom, (lastNode ? lastNode.isInline : lastParent && lastParent.isTextblock) ? -1 : 1);
    }
  }
  /**
  Replace the selection with the given node, appending the changes
  to the given transaction.
  */
  replaceWith(tr2, node3) {
    let mapFrom = tr2.steps.length, ranges = this.ranges;
    for (let i2 = 0; i2 < ranges.length; i2++) {
      let { $from, $to } = ranges[i2], mapping = tr2.mapping.slice(mapFrom);
      let from2 = mapping.map($from.pos), to = mapping.map($to.pos);
      if (i2) {
        tr2.deleteRange(from2, to);
      } else {
        tr2.replaceRangeWith(from2, to, node3);
        selectionToInsertionEnd$1(tr2, mapFrom, node3.isInline ? -1 : 1);
      }
    }
  }
  /**
  Find a valid cursor or leaf node selection starting at the given
  position and searching back if `dir` is negative, and forward if
  positive. When `textOnly` is true, only consider cursor
  selections. Will return null when no valid selection position is
  found.
  */
  static findFrom($pos, dir, textOnly = false) {
    let inner = $pos.parent.inlineContent ? new TextSelection($pos) : findSelectionIn($pos.node(0), $pos.parent, $pos.pos, $pos.index(), dir, textOnly);
    if (inner)
      return inner;
    for (let depth = $pos.depth - 1; depth >= 0; depth--) {
      let found2 = dir < 0 ? findSelectionIn($pos.node(0), $pos.node(depth), $pos.before(depth + 1), $pos.index(depth), dir, textOnly) : findSelectionIn($pos.node(0), $pos.node(depth), $pos.after(depth + 1), $pos.index(depth) + 1, dir, textOnly);
      if (found2)
        return found2;
    }
    return null;
  }
  /**
  Find a valid cursor or leaf node selection near the given
  position. Searches forward first by default, but if `bias` is
  negative, it will search backwards first.
  */
  static near($pos, bias = 1) {
    return this.findFrom($pos, bias) || this.findFrom($pos, -bias) || new AllSelection($pos.node(0));
  }
  /**
  Find the cursor or leaf node selection closest to the start of
  the given document. Will return an
  [`AllSelection`](https://prosemirror.net/docs/ref/#state.AllSelection) if no valid position
  exists.
  */
  static atStart(doc2) {
    return findSelectionIn(doc2, doc2, 0, 0, 1) || new AllSelection(doc2);
  }
  /**
  Find the cursor or leaf node selection closest to the end of the
  given document.
  */
  static atEnd(doc2) {
    return findSelectionIn(doc2, doc2, doc2.content.size, doc2.childCount, -1) || new AllSelection(doc2);
  }
  /**
  Deserialize the JSON representation of a selection. Must be
  implemented for custom classes (as a static class method).
  */
  static fromJSON(doc2, json) {
    if (!json || !json.type)
      throw new RangeError("Invalid input for Selection.fromJSON");
    let cls = classesById[json.type];
    if (!cls)
      throw new RangeError(`No selection type ${json.type} defined`);
    return cls.fromJSON(doc2, json);
  }
  /**
  To be able to deserialize selections from JSON, custom selection
  classes must register themselves with an ID string, so that they
  can be disambiguated. Try to pick something that's unlikely to
  clash with classes from other modules.
  */
  static jsonID(id4, selectionClass) {
    if (id4 in classesById)
      throw new RangeError("Duplicate use of selection JSON ID " + id4);
    classesById[id4] = selectionClass;
    selectionClass.prototype.jsonID = id4;
    return selectionClass;
  }
  /**
  Get a [bookmark](https://prosemirror.net/docs/ref/#state.SelectionBookmark) for this selection,
  which is a value that can be mapped without having access to a
  current document, and later resolved to a real selection for a
  given document again. (This is used mostly by the history to
  track and restore old selections.) The default implementation of
  this method just converts the selection to a text selection and
  returns the bookmark for that.
  */
  getBookmark() {
    return TextSelection.between(this.$anchor, this.$head).getBookmark();
  }
}
Selection.prototype.visible = true;
class SelectionRange {
  static {
    __name(this, "SelectionRange");
  }
  /**
  Create a range.
  */
  constructor($from, $to) {
    this.$from = $from;
    this.$to = $to;
  }
}
let warnedAboutTextSelection = false;
function checkTextSelection($pos) {
  if (!warnedAboutTextSelection && !$pos.parent.inlineContent) {
    warnedAboutTextSelection = true;
    console["warn"]("TextSelection endpoint not pointing into a node with inline content (" + $pos.parent.type.name + ")");
  }
}
__name(checkTextSelection, "checkTextSelection");
class TextSelection extends Selection {
  static {
    __name(this, "TextSelection");
  }
  /**
  Construct a text selection between the given points.
  */
  constructor($anchor, $head = $anchor) {
    checkTextSelection($anchor);
    checkTextSelection($head);
    super($anchor, $head);
  }
  /**
  Returns a resolved position if this is a cursor selection (an
  empty text selection), and null otherwise.
  */
  get $cursor() {
    return this.$anchor.pos == this.$head.pos ? this.$head : null;
  }
  map(doc2, mapping) {
    let $head = doc2.resolve(mapping.map(this.head));
    if (!$head.parent.inlineContent)
      return Selection.near($head);
    let $anchor = doc2.resolve(mapping.map(this.anchor));
    return new TextSelection($anchor.parent.inlineContent ? $anchor : $head, $head);
  }
  replace(tr2, content3 = Slice.empty) {
    super.replace(tr2, content3);
    if (content3 == Slice.empty) {
      let marks = this.$from.marksAcross(this.$to);
      if (marks)
        tr2.ensureMarks(marks);
    }
  }
  eq(other) {
    return other instanceof TextSelection && other.anchor == this.anchor && other.head == this.head;
  }
  getBookmark() {
    return new TextBookmark(this.anchor, this.head);
  }
  toJSON() {
    return { type: "text", anchor: this.anchor, head: this.head };
  }
  /**
  @internal
  */
  static fromJSON(doc2, json) {
    if (typeof json.anchor != "number" || typeof json.head != "number")
      throw new RangeError("Invalid input for TextSelection.fromJSON");
    return new TextSelection(doc2.resolve(json.anchor), doc2.resolve(json.head));
  }
  /**
  Create a text selection from non-resolved positions.
  */
  static create(doc2, anchor, head = anchor) {
    let $anchor = doc2.resolve(anchor);
    return new this($anchor, head == anchor ? $anchor : doc2.resolve(head));
  }
  /**
  Return a text selection that spans the given positions or, if
  they aren't text positions, find a text selection near them.
  `bias` determines whether the method searches forward (default)
  or backwards (negative number) first. Will fall back to calling
  [`Selection.near`](https://prosemirror.net/docs/ref/#state.Selection^near) when the document
  doesn't contain a valid text position.
  */
  static between($anchor, $head, bias) {
    let dPos = $anchor.pos - $head.pos;
    if (!bias || dPos)
      bias = dPos >= 0 ? 1 : -1;
    if (!$head.parent.inlineContent) {
      let found2 = Selection.findFrom($head, bias, true) || Selection.findFrom($head, -bias, true);
      if (found2)
        $head = found2.$head;
      else
        return Selection.near($head, bias);
    }
    if (!$anchor.parent.inlineContent) {
      if (dPos == 0) {
        $anchor = $head;
      } else {
        $anchor = (Selection.findFrom($anchor, -bias, true) || Selection.findFrom($anchor, bias, true)).$anchor;
        if ($anchor.pos < $head.pos != dPos < 0)
          $anchor = $head;
      }
    }
    return new TextSelection($anchor, $head);
  }
}
Selection.jsonID("text", TextSelection);
class TextBookmark {
  static {
    __name(this, "TextBookmark");
  }
  constructor(anchor, head) {
    this.anchor = anchor;
    this.head = head;
  }
  map(mapping) {
    return new TextBookmark(mapping.map(this.anchor), mapping.map(this.head));
  }
  resolve(doc2) {
    return TextSelection.between(doc2.resolve(this.anchor), doc2.resolve(this.head));
  }
}
class NodeSelection extends Selection {
  static {
    __name(this, "NodeSelection");
  }
  /**
  Create a node selection. Does not verify the validity of its
  argument.
  */
  constructor($pos) {
    let node3 = $pos.nodeAfter;
    let $end = $pos.node(0).resolve($pos.pos + node3.nodeSize);
    super($pos, $end);
    this.node = node3;
  }
  map(doc2, mapping) {
    let { deleted, pos } = mapping.mapResult(this.anchor);
    let $pos = doc2.resolve(pos);
    if (deleted)
      return Selection.near($pos);
    return new NodeSelection($pos);
  }
  content() {
    return new Slice(Fragment.from(this.node), 0, 0);
  }
  eq(other) {
    return other instanceof NodeSelection && other.anchor == this.anchor;
  }
  toJSON() {
    return { type: "node", anchor: this.anchor };
  }
  getBookmark() {
    return new NodeBookmark(this.anchor);
  }
  /**
  @internal
  */
  static fromJSON(doc2, json) {
    if (typeof json.anchor != "number")
      throw new RangeError("Invalid input for NodeSelection.fromJSON");
    return new NodeSelection(doc2.resolve(json.anchor));
  }
  /**
  Create a node selection from non-resolved positions.
  */
  static create(doc2, from2) {
    return new NodeSelection(doc2.resolve(from2));
  }
  /**
  Determines whether the given node may be selected as a node
  selection.
  */
  static isSelectable(node3) {
    return !node3.isText && node3.type.spec.selectable !== false;
  }
}
NodeSelection.prototype.visible = false;
Selection.jsonID("node", NodeSelection);
class NodeBookmark {
  static {
    __name(this, "NodeBookmark");
  }
  constructor(anchor) {
    this.anchor = anchor;
  }
  map(mapping) {
    let { deleted, pos } = mapping.mapResult(this.anchor);
    return deleted ? new TextBookmark(pos, pos) : new NodeBookmark(pos);
  }
  resolve(doc2) {
    let $pos = doc2.resolve(this.anchor), node3 = $pos.nodeAfter;
    if (node3 && NodeSelection.isSelectable(node3))
      return new NodeSelection($pos);
    return Selection.near($pos);
  }
}
class AllSelection extends Selection {
  static {
    __name(this, "AllSelection");
  }
  /**
  Create an all-selection over the given document.
  */
  constructor(doc2) {
    super(doc2.resolve(0), doc2.resolve(doc2.content.size));
  }
  replace(tr2, content3 = Slice.empty) {
    if (content3 == Slice.empty) {
      tr2.delete(0, tr2.doc.content.size);
      let sel = Selection.atStart(tr2.doc);
      if (!sel.eq(tr2.selection))
        tr2.setSelection(sel);
    } else {
      super.replace(tr2, content3);
    }
  }
  toJSON() {
    return { type: "all" };
  }
  /**
  @internal
  */
  static fromJSON(doc2) {
    return new AllSelection(doc2);
  }
  map(doc2) {
    return new AllSelection(doc2);
  }
  eq(other) {
    return other instanceof AllSelection;
  }
  getBookmark() {
    return AllBookmark;
  }
}
Selection.jsonID("all", AllSelection);
const AllBookmark = {
  map() {
    return this;
  },
  resolve(doc2) {
    return new AllSelection(doc2);
  }
};
function findSelectionIn(doc2, node3, pos, index2, dir, text2 = false) {
  if (node3.inlineContent)
    return TextSelection.create(doc2, pos);
  for (let i2 = index2 - (dir > 0 ? 0 : 1); dir > 0 ? i2 < node3.childCount : i2 >= 0; i2 += dir) {
    let child = node3.child(i2);
    if (!child.isAtom) {
      let inner = findSelectionIn(doc2, child, pos + dir, dir < 0 ? child.childCount : 0, dir, text2);
      if (inner)
        return inner;
    } else if (!text2 && NodeSelection.isSelectable(child)) {
      return NodeSelection.create(doc2, pos - (dir < 0 ? child.nodeSize : 0));
    }
    pos += child.nodeSize * dir;
  }
  return null;
}
__name(findSelectionIn, "findSelectionIn");
function selectionToInsertionEnd$1(tr2, startLen, bias) {
  let last = tr2.steps.length - 1;
  if (last < startLen)
    return;
  let step2 = tr2.steps[last];
  if (!(step2 instanceof ReplaceStep || step2 instanceof ReplaceAroundStep))
    return;
  let map3 = tr2.mapping.maps[last], end;
  map3.forEach((_from, _to, _newFrom, newTo) => {
    if (end == null)
      end = newTo;
  });
  tr2.setSelection(Selection.near(tr2.doc.resolve(end), bias));
}
__name(selectionToInsertionEnd$1, "selectionToInsertionEnd$1");
const UPDATED_SEL = 1, UPDATED_MARKS = 2, UPDATED_SCROLL = 4;
class Transaction extends Transform {
  static {
    __name(this, "Transaction");
  }
  /**
  @internal
  */
  constructor(state) {
    super(state.doc);
    this.curSelectionFor = 0;
    this.updated = 0;
    this.meta = /* @__PURE__ */ Object.create(null);
    this.time = Date.now();
    this.curSelection = state.selection;
    this.storedMarks = state.storedMarks;
  }
  /**
  The transaction's current selection. This defaults to the editor
  selection [mapped](https://prosemirror.net/docs/ref/#state.Selection.map) through the steps in the
  transaction, but can be overwritten with
  [`setSelection`](https://prosemirror.net/docs/ref/#state.Transaction.setSelection).
  */
  get selection() {
    if (this.curSelectionFor < this.steps.length) {
      this.curSelection = this.curSelection.map(this.doc, this.mapping.slice(this.curSelectionFor));
      this.curSelectionFor = this.steps.length;
    }
    return this.curSelection;
  }
  /**
  Update the transaction's current selection. Will determine the
  selection that the editor gets when the transaction is applied.
  */
  setSelection(selection) {
    if (selection.$from.doc != this.doc)
      throw new RangeError("Selection passed to setSelection must point at the current document");
    this.curSelection = selection;
    this.curSelectionFor = this.steps.length;
    this.updated = (this.updated | UPDATED_SEL) & ~UPDATED_MARKS;
    this.storedMarks = null;
    return this;
  }
  /**
  Whether the selection was explicitly updated by this transaction.
  */
  get selectionSet() {
    return (this.updated & UPDATED_SEL) > 0;
  }
  /**
  Set the current stored marks.
  */
  setStoredMarks(marks) {
    this.storedMarks = marks;
    this.updated |= UPDATED_MARKS;
    return this;
  }
  /**
  Make sure the current stored marks or, if that is null, the marks
  at the selection, match the given set of marks. Does nothing if
  this is already the case.
  */
  ensureMarks(marks) {
    if (!Mark$1.sameSet(this.storedMarks || this.selection.$from.marks(), marks))
      this.setStoredMarks(marks);
    return this;
  }
  /**
  Add a mark to the set of stored marks.
  */
  addStoredMark(mark2) {
    return this.ensureMarks(mark2.addToSet(this.storedMarks || this.selection.$head.marks()));
  }
  /**
  Remove a mark or mark type from the set of stored marks.
  */
  removeStoredMark(mark2) {
    return this.ensureMarks(mark2.removeFromSet(this.storedMarks || this.selection.$head.marks()));
  }
  /**
  Whether the stored marks were explicitly set for this transaction.
  */
  get storedMarksSet() {
    return (this.updated & UPDATED_MARKS) > 0;
  }
  /**
  @internal
  */
  addStep(step2, doc2) {
    super.addStep(step2, doc2);
    this.updated = this.updated & ~UPDATED_MARKS;
    this.storedMarks = null;
  }
  /**
  Update the timestamp for the transaction.
  */
  setTime(time) {
    this.time = time;
    return this;
  }
  /**
  Replace the current selection with the given slice.
  */
  replaceSelection(slice2) {
    this.selection.replace(this, slice2);
    return this;
  }
  /**
  Replace the selection with the given node. When `inheritMarks` is
  true and the content is inline, it inherits the marks from the
  place where it is inserted.
  */
  replaceSelectionWith(node3, inheritMarks = true) {
    let selection = this.selection;
    if (inheritMarks)
      node3 = node3.mark(this.storedMarks || (selection.empty ? selection.$from.marks() : selection.$from.marksAcross(selection.$to) || Mark$1.none));
    selection.replaceWith(this, node3);
    return this;
  }
  /**
  Delete the selection.
  */
  deleteSelection() {
    this.selection.replace(this);
    return this;
  }
  /**
  Replace the given range, or the selection if no range is given,
  with a text node containing the given string.
  */
  insertText(text2, from2, to) {
    let schema2 = this.doc.type.schema;
    if (from2 == null) {
      if (!text2)
        return this.deleteSelection();
      return this.replaceSelectionWith(schema2.text(text2), true);
    } else {
      if (to == null)
        to = from2;
      to = to == null ? from2 : to;
      if (!text2)
        return this.deleteRange(from2, to);
      let marks = this.storedMarks;
      if (!marks) {
        let $from = this.doc.resolve(from2);
        marks = to == from2 ? $from.marks() : $from.marksAcross(this.doc.resolve(to));
      }
      this.replaceRangeWith(from2, to, schema2.text(text2, marks));
      if (!this.selection.empty)
        this.setSelection(Selection.near(this.selection.$to));
      return this;
    }
  }
  /**
  Store a metadata property in this transaction, keyed either by
  name or by plugin.
  */
  setMeta(key, value3) {
    this.meta[typeof key == "string" ? key : key.key] = value3;
    return this;
  }
  /**
  Retrieve a metadata property for a given name or plugin.
  */
  getMeta(key) {
    return this.meta[typeof key == "string" ? key : key.key];
  }
  /**
  Returns true if this transaction doesn't contain any metadata,
  and can thus safely be extended.
  */
  get isGeneric() {
    for (let _2 in this.meta)
      return false;
    return true;
  }
  /**
  Indicate that the editor should scroll the selection into view
  when updated to the state produced by this transaction.
  */
  scrollIntoView() {
    this.updated |= UPDATED_SCROLL;
    return this;
  }
  /**
  True when this transaction has had `scrollIntoView` called on it.
  */
  get scrolledIntoView() {
    return (this.updated & UPDATED_SCROLL) > 0;
  }
}
function bind$2(f2, self2) {
  return !self2 || !f2 ? f2 : f2.bind(self2);
}
__name(bind$2, "bind$2");
class FieldDesc {
  static {
    __name(this, "FieldDesc");
  }
  constructor(name2, desc, self2) {
    this.name = name2;
    this.init = bind$2(desc.init, self2);
    this.apply = bind$2(desc.apply, self2);
  }
}
const baseFields = [
  new FieldDesc("doc", {
    init(config2) {
      return config2.doc || config2.schema.topNodeType.createAndFill();
    },
    apply(tr2) {
      return tr2.doc;
    }
  }),
  new FieldDesc("selection", {
    init(config2, instance) {
      return config2.selection || Selection.atStart(instance.doc);
    },
    apply(tr2) {
      return tr2.selection;
    }
  }),
  new FieldDesc("storedMarks", {
    init(config2) {
      return config2.storedMarks || null;
    },
    apply(tr2, _marks, _old, state) {
      return state.selection.$cursor ? tr2.storedMarks : null;
    }
  }),
  new FieldDesc("scrollToSelection", {
    init() {
      return 0;
    },
    apply(tr2, prev2) {
      return tr2.scrolledIntoView ? prev2 + 1 : prev2;
    }
  })
];
class Configuration {
  static {
    __name(this, "Configuration");
  }
  constructor(schema2, plugins) {
    this.schema = schema2;
    this.plugins = [];
    this.pluginsByKey = /* @__PURE__ */ Object.create(null);
    this.fields = baseFields.slice();
    if (plugins)
      plugins.forEach((plugin) => {
        if (this.pluginsByKey[plugin.key])
          throw new RangeError("Adding different instances of a keyed plugin (" + plugin.key + ")");
        this.plugins.push(plugin);
        this.pluginsByKey[plugin.key] = plugin;
        if (plugin.spec.state)
          this.fields.push(new FieldDesc(plugin.key, plugin.spec.state, plugin));
      });
  }
}
class EditorState {
  static {
    __name(this, "EditorState");
  }
  /**
  @internal
  */
  constructor(config2) {
    this.config = config2;
  }
  /**
  The schema of the state's document.
  */
  get schema() {
    return this.config.schema;
  }
  /**
  The plugins that are active in this state.
  */
  get plugins() {
    return this.config.plugins;
  }
  /**
  Apply the given transaction to produce a new state.
  */
  apply(tr2) {
    return this.applyTransaction(tr2).state;
  }
  /**
  @internal
  */
  filterTransaction(tr2, ignore = -1) {
    for (let i2 = 0; i2 < this.config.plugins.length; i2++)
      if (i2 != ignore) {
        let plugin = this.config.plugins[i2];
        if (plugin.spec.filterTransaction && !plugin.spec.filterTransaction.call(plugin, tr2, this))
          return false;
      }
    return true;
  }
  /**
  Verbose variant of [`apply`](https://prosemirror.net/docs/ref/#state.EditorState.apply) that
  returns the precise transactions that were applied (which might
  be influenced by the [transaction
  hooks](https://prosemirror.net/docs/ref/#state.PluginSpec.filterTransaction) of
  plugins) along with the new state.
  */
  applyTransaction(rootTr) {
    if (!this.filterTransaction(rootTr))
      return { state: this, transactions: [] };
    let trs = [rootTr], newState = this.applyInner(rootTr), seen2 = null;
    for (; ; ) {
      let haveNew = false;
      for (let i2 = 0; i2 < this.config.plugins.length; i2++) {
        let plugin = this.config.plugins[i2];
        if (plugin.spec.appendTransaction) {
          let n2 = seen2 ? seen2[i2].n : 0, oldState = seen2 ? seen2[i2].state : this;
          let tr2 = n2 < trs.length && plugin.spec.appendTransaction.call(plugin, n2 ? trs.slice(n2) : trs, oldState, newState);
          if (tr2 && newState.filterTransaction(tr2, i2)) {
            tr2.setMeta("appendedTransaction", rootTr);
            if (!seen2) {
              seen2 = [];
              for (let j2 = 0; j2 < this.config.plugins.length; j2++)
                seen2.push(j2 < i2 ? { state: newState, n: trs.length } : { state: this, n: 0 });
            }
            trs.push(tr2);
            newState = newState.applyInner(tr2);
            haveNew = true;
          }
          if (seen2)
            seen2[i2] = { state: newState, n: trs.length };
        }
      }
      if (!haveNew)
        return { state: newState, transactions: trs };
    }
  }
  /**
  @internal
  */
  applyInner(tr2) {
    if (!tr2.before.eq(this.doc))
      throw new RangeError("Applying a mismatched transaction");
    let newInstance = new EditorState(this.config), fields = this.config.fields;
    for (let i2 = 0; i2 < fields.length; i2++) {
      let field2 = fields[i2];
      newInstance[field2.name] = field2.apply(tr2, this[field2.name], this, newInstance);
    }
    return newInstance;
  }
  /**
  Start a [transaction](https://prosemirror.net/docs/ref/#state.Transaction) from this state.
  */
  get tr() {
    return new Transaction(this);
  }
  /**
  Create a new state.
  */
  static create(config2) {
    let $config = new Configuration(config2.doc ? config2.doc.type.schema : config2.schema, config2.plugins);
    let instance = new EditorState($config);
    for (let i2 = 0; i2 < $config.fields.length; i2++)
      instance[$config.fields[i2].name] = $config.fields[i2].init(config2, instance);
    return instance;
  }
  /**
  Create a new state based on this one, but with an adjusted set
  of active plugins. State fields that exist in both sets of
  plugins are kept unchanged. Those that no longer exist are
  dropped, and those that are new are initialized using their
  [`init`](https://prosemirror.net/docs/ref/#state.StateField.init) method, passing in the new
  configuration object..
  */
  reconfigure(config2) {
    let $config = new Configuration(this.schema, config2.plugins);
    let fields = $config.fields, instance = new EditorState($config);
    for (let i2 = 0; i2 < fields.length; i2++) {
      let name2 = fields[i2].name;
      instance[name2] = this.hasOwnProperty(name2) ? this[name2] : fields[i2].init(config2, instance);
    }
    return instance;
  }
  /**
  Serialize this state to JSON. If you want to serialize the state
  of plugins, pass an object mapping property names to use in the
  resulting JSON object to plugin objects. The argument may also be
  a string or number, in which case it is ignored, to support the
  way `JSON.stringify` calls `toString` methods.
  */
  toJSON(pluginFields) {
    let result = { doc: this.doc.toJSON(), selection: this.selection.toJSON() };
    if (this.storedMarks)
      result.storedMarks = this.storedMarks.map((m2) => m2.toJSON());
    if (pluginFields && typeof pluginFields == "object")
      for (let prop2 in pluginFields) {
        if (prop2 == "doc" || prop2 == "selection")
          throw new RangeError("The JSON fields `doc` and `selection` are reserved");
        let plugin = pluginFields[prop2], state = plugin.spec.state;
        if (state && state.toJSON)
          result[prop2] = state.toJSON.call(plugin, this[plugin.key]);
      }
    return result;
  }
  /**
  Deserialize a JSON representation of a state. `config` should
  have at least a `schema` field, and should contain array of
  plugins to initialize the state with. `pluginFields` can be used
  to deserialize the state of plugins, by associating plugin
  instances with the property names they use in the JSON object.
  */
  static fromJSON(config2, json, pluginFields) {
    if (!json)
      throw new RangeError("Invalid input for EditorState.fromJSON");
    if (!config2.schema)
      throw new RangeError("Required config field 'schema' missing");
    let $config = new Configuration(config2.schema, config2.plugins);
    let instance = new EditorState($config);
    $config.fields.forEach((field2) => {
      if (field2.name == "doc") {
        instance.doc = Node$2.fromJSON(config2.schema, json.doc);
      } else if (field2.name == "selection") {
        instance.selection = Selection.fromJSON(instance.doc, json.selection);
      } else if (field2.name == "storedMarks") {
        if (json.storedMarks)
          instance.storedMarks = json.storedMarks.map(config2.schema.markFromJSON);
      } else {
        if (pluginFields)
          for (let prop2 in pluginFields) {
            let plugin = pluginFields[prop2], state = plugin.spec.state;
            if (plugin.key == field2.name && state && state.fromJSON && Object.prototype.hasOwnProperty.call(json, prop2)) {
              instance[field2.name] = state.fromJSON.call(plugin, config2, json[prop2], instance);
              return;
            }
          }
        instance[field2.name] = field2.init(config2, instance);
      }
    });
    return instance;
  }
}
function bindProps(obj, self2, target2) {
  for (let prop2 in obj) {
    let val = obj[prop2];
    if (val instanceof Function)
      val = val.bind(self2);
    else if (prop2 == "handleDOMEvents")
      val = bindProps(val, self2, {});
    target2[prop2] = val;
  }
  return target2;
}
__name(bindProps, "bindProps");
class Plugin {
  static {
    __name(this, "Plugin");
  }
  /**
  Create a plugin.
  */
  constructor(spec) {
    this.spec = spec;
    this.props = {};
    if (spec.props)
      bindProps(spec.props, this, this.props);
    this.key = spec.key ? spec.key.key : createKey("plugin");
  }
  /**
  Extract the plugin's state field from an editor state.
  */
  getState(state) {
    return state[this.key];
  }
}
const keys = /* @__PURE__ */ Object.create(null);
function createKey(name2) {
  if (name2 in keys)
    return name2 + "$" + ++keys[name2];
  keys[name2] = 0;
  return name2 + "$";
}
__name(createKey, "createKey");
class PluginKey {
  static {
    __name(this, "PluginKey");
  }
  /**
  Create a plugin key.
  */
  constructor(name2 = "key") {
    this.key = createKey(name2);
  }
  /**
  Get the active plugin with this key, if any, from an editor
  state.
  */
  get(state) {
    return state.config.pluginsByKey[this.key];
  }
  /**
  Get the plugin's state from an editor state.
  */
  getState(state) {
    return state[this.key];
  }
}
const domIndex = /* @__PURE__ */ __name(function(node3) {
  for (var index2 = 0; ; index2++) {
    node3 = node3.previousSibling;
    if (!node3)
      return index2;
  }
}, "domIndex");
const parentNode = /* @__PURE__ */ __name(function(node3) {
  let parent = node3.assignedSlot || node3.parentNode;
  return parent && parent.nodeType == 11 ? parent.host : parent;
}, "parentNode");
let reusedRange = null;
const textRange = /* @__PURE__ */ __name(function(node3, from2, to) {
  let range2 = reusedRange || (reusedRange = document.createRange());
  range2.setEnd(node3, to == null ? node3.nodeValue.length : to);
  range2.setStart(node3, from2 || 0);
  return range2;
}, "textRange");
const clearReusedRange = /* @__PURE__ */ __name(function() {
  reusedRange = null;
}, "clearReusedRange");
const isEquivalentPosition = /* @__PURE__ */ __name(function(node3, off, targetNode, targetOff) {
  return targetNode && (scanFor(node3, off, targetNode, targetOff, -1) || scanFor(node3, off, targetNode, targetOff, 1));
}, "isEquivalentPosition");
const atomElements = /^(img|br|input|textarea|hr)$/i;
function scanFor(node3, off, targetNode, targetOff, dir) {
  for (; ; ) {
    if (node3 == targetNode && off == targetOff)
      return true;
    if (off == (dir < 0 ? 0 : nodeSize(node3))) {
      let parent = node3.parentNode;
      if (!parent || parent.nodeType != 1 || hasBlockDesc(node3) || atomElements.test(node3.nodeName) || node3.contentEditable == "false")
        return false;
      off = domIndex(node3) + (dir < 0 ? 0 : 1);
      node3 = parent;
    } else if (node3.nodeType == 1) {
      node3 = node3.childNodes[off + (dir < 0 ? -1 : 0)];
      if (node3.contentEditable == "false")
        return false;
      off = dir < 0 ? nodeSize(node3) : 0;
    } else {
      return false;
    }
  }
}
__name(scanFor, "scanFor");
function nodeSize(node3) {
  return node3.nodeType == 3 ? node3.nodeValue.length : node3.childNodes.length;
}
__name(nodeSize, "nodeSize");
function textNodeBefore$1(node3, offset) {
  for (; ; ) {
    if (node3.nodeType == 3 && offset)
      return node3;
    if (node3.nodeType == 1 && offset > 0) {
      if (node3.contentEditable == "false")
        return null;
      node3 = node3.childNodes[offset - 1];
      offset = nodeSize(node3);
    } else if (node3.parentNode && !hasBlockDesc(node3)) {
      offset = domIndex(node3);
      node3 = node3.parentNode;
    } else {
      return null;
    }
  }
}
__name(textNodeBefore$1, "textNodeBefore$1");
function textNodeAfter$1(node3, offset) {
  for (; ; ) {
    if (node3.nodeType == 3 && offset < node3.nodeValue.length)
      return node3;
    if (node3.nodeType == 1 && offset < node3.childNodes.length) {
      if (node3.contentEditable == "false")
        return null;
      node3 = node3.childNodes[offset];
      offset = 0;
    } else if (node3.parentNode && !hasBlockDesc(node3)) {
      offset = domIndex(node3) + 1;
      node3 = node3.parentNode;
    } else {
      return null;
    }
  }
}
__name(textNodeAfter$1, "textNodeAfter$1");
function isOnEdge(node3, offset, parent) {
  for (let atStart = offset == 0, atEnd = offset == nodeSize(node3); atStart || atEnd; ) {
    if (node3 == parent)
      return true;
    let index2 = domIndex(node3);
    node3 = node3.parentNode;
    if (!node3)
      return false;
    atStart = atStart && index2 == 0;
    atEnd = atEnd && index2 == nodeSize(node3);
  }
}
__name(isOnEdge, "isOnEdge");
function hasBlockDesc(dom) {
  let desc;
  for (let cur = dom; cur; cur = cur.parentNode)
    if (desc = cur.pmViewDesc)
      break;
  return desc && desc.node && desc.node.isBlock && (desc.dom == dom || desc.contentDOM == dom);
}
__name(hasBlockDesc, "hasBlockDesc");
const selectionCollapsed = /* @__PURE__ */ __name(function(domSel) {
  return domSel.focusNode && isEquivalentPosition(domSel.focusNode, domSel.focusOffset, domSel.anchorNode, domSel.anchorOffset);
}, "selectionCollapsed");
function keyEvent(keyCode, key) {
  let event = document.createEvent("Event");
  event.initEvent("keydown", true, true);
  event.keyCode = keyCode;
  event.key = event.code = key;
  return event;
}
__name(keyEvent, "keyEvent");
function deepActiveElement(doc2) {
  let elt = doc2.activeElement;
  while (elt && elt.shadowRoot)
    elt = elt.shadowRoot.activeElement;
  return elt;
}
__name(deepActiveElement, "deepActiveElement");
function caretFromPoint(doc2, x2, y2) {
  if (doc2.caretPositionFromPoint) {
    try {
      let pos = doc2.caretPositionFromPoint(x2, y2);
      if (pos)
        return { node: pos.offsetNode, offset: Math.min(nodeSize(pos.offsetNode), pos.offset) };
    } catch (_2) {
    }
  }
  if (doc2.caretRangeFromPoint) {
    let range2 = doc2.caretRangeFromPoint(x2, y2);
    if (range2)
      return { node: range2.startContainer, offset: Math.min(nodeSize(range2.startContainer), range2.startOffset) };
  }
}
__name(caretFromPoint, "caretFromPoint");
const nav = typeof navigator != "undefined" ? navigator : null;
const doc = typeof document != "undefined" ? document : null;
const agent = nav && nav.userAgent || "";
const ie_edge = /Edge\/(\d+)/.exec(agent);
const ie_upto10 = /MSIE \d/.exec(agent);
const ie_11up = /Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(agent);
const ie$1 = !!(ie_upto10 || ie_11up || ie_edge);
const ie_version = ie_upto10 ? document.documentMode : ie_11up ? +ie_11up[1] : ie_edge ? +ie_edge[1] : 0;
const gecko = !ie$1 && /gecko\/(\d+)/i.test(agent);
gecko && +(/Firefox\/(\d+)/.exec(agent) || [0, 0])[1];
const _chrome = !ie$1 && /Chrome\/(\d+)/.exec(agent);
const chrome = !!_chrome;
const chrome_version = _chrome ? +_chrome[1] : 0;
const safari = !ie$1 && !!nav && /Apple Computer/.test(nav.vendor);
const ios = safari && (/Mobile\/\w+/.test(agent) || !!nav && nav.maxTouchPoints > 2);
const mac$3 = ios || (nav ? /Mac/.test(nav.platform) : false);
const windows = nav ? /Win/.test(nav.platform) : false;
const android = /Android \d/.test(agent);
const webkit = !!doc && "webkitFontSmoothing" in doc.documentElement.style;
const webkit_version = webkit ? +(/\bAppleWebKit\/(\d+)/.exec(navigator.userAgent) || [0, 0])[1] : 0;
function windowRect(doc2) {
  let vp = doc2.defaultView && doc2.defaultView.visualViewport;
  if (vp)
    return {
      left: 0,
      right: vp.width,
      top: 0,
      bottom: vp.height
    };
  return {
    left: 0,
    right: doc2.documentElement.clientWidth,
    top: 0,
    bottom: doc2.documentElement.clientHeight
  };
}
__name(windowRect, "windowRect");
function getSide(value3, side) {
  return typeof value3 == "number" ? value3 : value3[side];
}
__name(getSide, "getSide");
function clientRect(node3) {
  let rect = node3.getBoundingClientRect();
  let scaleX = rect.width / node3.offsetWidth || 1;
  let scaleY = rect.height / node3.offsetHeight || 1;
  return {
    left: rect.left,
    right: rect.left + node3.clientWidth * scaleX,
    top: rect.top,
    bottom: rect.top + node3.clientHeight * scaleY
  };
}
__name(clientRect, "clientRect");
function scrollRectIntoView(view, rect, startDOM) {
  let scrollThreshold = view.someProp("scrollThreshold") || 0, scrollMargin = view.someProp("scrollMargin") || 5;
  let doc2 = view.dom.ownerDocument;
  for (let parent = startDOM || view.dom; ; parent = parentNode(parent)) {
    if (!parent)
      break;
    if (parent.nodeType != 1)
      continue;
    let elt = parent;
    let atTop = elt == doc2.body;
    let bounding = atTop ? windowRect(doc2) : clientRect(elt);
    let moveX = 0, moveY = 0;
    if (rect.top < bounding.top + getSide(scrollThreshold, "top"))
      moveY = -(bounding.top - rect.top + getSide(scrollMargin, "top"));
    else if (rect.bottom > bounding.bottom - getSide(scrollThreshold, "bottom"))
      moveY = rect.bottom - rect.top > bounding.bottom - bounding.top ? rect.top + getSide(scrollMargin, "top") - bounding.top : rect.bottom - bounding.bottom + getSide(scrollMargin, "bottom");
    if (rect.left < bounding.left + getSide(scrollThreshold, "left"))
      moveX = -(bounding.left - rect.left + getSide(scrollMargin, "left"));
    else if (rect.right > bounding.right - getSide(scrollThreshold, "right"))
      moveX = rect.right - bounding.right + getSide(scrollMargin, "right");
    if (moveX || moveY) {
      if (atTop) {
        doc2.defaultView.scrollBy(moveX, moveY);
      } else {
        let startX = elt.scrollLeft, startY = elt.scrollTop;
        if (moveY)
          elt.scrollTop += moveY;
        if (moveX)
          elt.scrollLeft += moveX;
        let dX = elt.scrollLeft - startX, dY = elt.scrollTop - startY;
        rect = { left: rect.left - dX, top: rect.top - dY, right: rect.right - dX, bottom: rect.bottom - dY };
      }
    }
    if (atTop || /^(fixed|sticky)$/.test(getComputedStyle(parent).position))
      break;
  }
}
__name(scrollRectIntoView, "scrollRectIntoView");
function storeScrollPos(view) {
  let rect = view.dom.getBoundingClientRect(), startY = Math.max(0, rect.top);
  let refDOM, refTop;
  for (let x2 = (rect.left + rect.right) / 2, y2 = startY + 1; y2 < Math.min(innerHeight, rect.bottom); y2 += 5) {
    let dom = view.root.elementFromPoint(x2, y2);
    if (!dom || dom == view.dom || !view.dom.contains(dom))
      continue;
    let localRect = dom.getBoundingClientRect();
    if (localRect.top >= startY - 20) {
      refDOM = dom;
      refTop = localRect.top;
      break;
    }
  }
  return { refDOM, refTop, stack: scrollStack(view.dom) };
}
__name(storeScrollPos, "storeScrollPos");
function scrollStack(dom) {
  let stack2 = [], doc2 = dom.ownerDocument;
  for (let cur = dom; cur; cur = parentNode(cur)) {
    stack2.push({ dom: cur, top: cur.scrollTop, left: cur.scrollLeft });
    if (dom == doc2)
      break;
  }
  return stack2;
}
__name(scrollStack, "scrollStack");
function resetScrollPos({ refDOM, refTop, stack: stack2 }) {
  let newRefTop = refDOM ? refDOM.getBoundingClientRect().top : 0;
  restoreScrollStack(stack2, newRefTop == 0 ? 0 : newRefTop - refTop);
}
__name(resetScrollPos, "resetScrollPos");
function restoreScrollStack(stack2, dTop) {
  for (let i2 = 0; i2 < stack2.length; i2++) {
    let { dom, top, left } = stack2[i2];
    if (dom.scrollTop != top + dTop)
      dom.scrollTop = top + dTop;
    if (dom.scrollLeft != left)
      dom.scrollLeft = left;
  }
}
__name(restoreScrollStack, "restoreScrollStack");
let preventScrollSupported = null;
function focusPreventScroll(dom) {
  if (dom.setActive)
    return dom.setActive();
  if (preventScrollSupported)
    return dom.focus(preventScrollSupported);
  let stored = scrollStack(dom);
  dom.focus(preventScrollSupported == null ? {
    get preventScroll() {
      preventScrollSupported = { preventScroll: true };
      return true;
    }
  } : void 0);
  if (!preventScrollSupported) {
    preventScrollSupported = false;
    restoreScrollStack(stored, 0);
  }
}
__name(focusPreventScroll, "focusPreventScroll");
function findOffsetInNode(node3, coords) {
  let closest, dxClosest = 2e8, coordsClosest, offset = 0;
  let rowBot = coords.top, rowTop = coords.top;
  let firstBelow, coordsBelow;
  for (let child = node3.firstChild, childIndex = 0; child; child = child.nextSibling, childIndex++) {
    let rects;
    if (child.nodeType == 1)
      rects = child.getClientRects();
    else if (child.nodeType == 3)
      rects = textRange(child).getClientRects();
    else
      continue;
    for (let i2 = 0; i2 < rects.length; i2++) {
      let rect = rects[i2];
      if (rect.top <= rowBot && rect.bottom >= rowTop) {
        rowBot = Math.max(rect.bottom, rowBot);
        rowTop = Math.min(rect.top, rowTop);
        let dx = rect.left > coords.left ? rect.left - coords.left : rect.right < coords.left ? coords.left - rect.right : 0;
        if (dx < dxClosest) {
          closest = child;
          dxClosest = dx;
          coordsClosest = dx && closest.nodeType == 3 ? {
            left: rect.right < coords.left ? rect.right : rect.left,
            top: coords.top
          } : coords;
          if (child.nodeType == 1 && dx)
            offset = childIndex + (coords.left >= (rect.left + rect.right) / 2 ? 1 : 0);
          continue;
        }
      } else if (rect.top > coords.top && !firstBelow && rect.left <= coords.left && rect.right >= coords.left) {
        firstBelow = child;
        coordsBelow = { left: Math.max(rect.left, Math.min(rect.right, coords.left)), top: rect.top };
      }
      if (!closest && (coords.left >= rect.right && coords.top >= rect.top || coords.left >= rect.left && coords.top >= rect.bottom))
        offset = childIndex + 1;
    }
  }
  if (!closest && firstBelow) {
    closest = firstBelow;
    coordsClosest = coordsBelow;
    dxClosest = 0;
  }
  if (closest && closest.nodeType == 3)
    return findOffsetInText(closest, coordsClosest);
  if (!closest || dxClosest && closest.nodeType == 1)
    return { node: node3, offset };
  return findOffsetInNode(closest, coordsClosest);
}
__name(findOffsetInNode, "findOffsetInNode");
function findOffsetInText(node3, coords) {
  let len = node3.nodeValue.length;
  let range2 = document.createRange();
  for (let i2 = 0; i2 < len; i2++) {
    range2.setEnd(node3, i2 + 1);
    range2.setStart(node3, i2);
    let rect = singleRect(range2, 1);
    if (rect.top == rect.bottom)
      continue;
    if (inRect(coords, rect))
      return { node: node3, offset: i2 + (coords.left >= (rect.left + rect.right) / 2 ? 1 : 0) };
  }
  return { node: node3, offset: 0 };
}
__name(findOffsetInText, "findOffsetInText");
function inRect(coords, rect) {
  return coords.left >= rect.left - 1 && coords.left <= rect.right + 1 && coords.top >= rect.top - 1 && coords.top <= rect.bottom + 1;
}
__name(inRect, "inRect");
function targetKludge(dom, coords) {
  let parent = dom.parentNode;
  if (parent && /^li$/i.test(parent.nodeName) && coords.left < dom.getBoundingClientRect().left)
    return parent;
  return dom;
}
__name(targetKludge, "targetKludge");
function posFromElement(view, elt, coords) {
  let { node: node3, offset } = findOffsetInNode(elt, coords), bias = -1;
  if (node3.nodeType == 1 && !node3.firstChild) {
    let rect = node3.getBoundingClientRect();
    bias = rect.left != rect.right && coords.left > (rect.left + rect.right) / 2 ? 1 : -1;
  }
  return view.docView.posFromDOM(node3, offset, bias);
}
__name(posFromElement, "posFromElement");
function posFromCaret(view, node3, offset, coords) {
  let outsideBlock = -1;
  for (let cur = node3, sawBlock = false; ; ) {
    if (cur == view.dom)
      break;
    let desc = view.docView.nearestDesc(cur, true), rect;
    if (!desc)
      return null;
    if (desc.dom.nodeType == 1 && (desc.node.isBlock && desc.parent || !desc.contentDOM) && // Ignore elements with zero-size bounding rectangles
    ((rect = desc.dom.getBoundingClientRect()).width || rect.height)) {
      if (desc.node.isBlock && desc.parent) {
        if (!sawBlock && rect.left > coords.left || rect.top > coords.top)
          outsideBlock = desc.posBefore;
        else if (!sawBlock && rect.right < coords.left || rect.bottom < coords.top)
          outsideBlock = desc.posAfter;
        sawBlock = true;
      }
      if (!desc.contentDOM && outsideBlock < 0 && !desc.node.isText) {
        let before = desc.node.isBlock ? coords.top < (rect.top + rect.bottom) / 2 : coords.left < (rect.left + rect.right) / 2;
        return before ? desc.posBefore : desc.posAfter;
      }
    }
    cur = desc.dom.parentNode;
  }
  return outsideBlock > -1 ? outsideBlock : view.docView.posFromDOM(node3, offset, -1);
}
__name(posFromCaret, "posFromCaret");
function elementFromPoint(element, coords, box) {
  let len = element.childNodes.length;
  if (len && box.top < box.bottom) {
    for (let startI = Math.max(0, Math.min(len - 1, Math.floor(len * (coords.top - box.top) / (box.bottom - box.top)) - 2)), i2 = startI; ; ) {
      let child = element.childNodes[i2];
      if (child.nodeType == 1) {
        let rects = child.getClientRects();
        for (let j2 = 0; j2 < rects.length; j2++) {
          let rect = rects[j2];
          if (inRect(coords, rect))
            return elementFromPoint(child, coords, rect);
        }
      }
      if ((i2 = (i2 + 1) % len) == startI)
        break;
    }
  }
  return element;
}
__name(elementFromPoint, "elementFromPoint");
function posAtCoords(view, coords) {
  let doc2 = view.dom.ownerDocument, node3, offset = 0;
  let caret = caretFromPoint(doc2, coords.left, coords.top);
  if (caret)
    ({ node: node3, offset } = caret);
  let elt = (view.root.elementFromPoint ? view.root : doc2).elementFromPoint(coords.left, coords.top);
  let pos;
  if (!elt || !view.dom.contains(elt.nodeType != 1 ? elt.parentNode : elt)) {
    let box = view.dom.getBoundingClientRect();
    if (!inRect(coords, box))
      return null;
    elt = elementFromPoint(view.dom, coords, box);
    if (!elt)
      return null;
  }
  if (safari) {
    for (let p2 = elt; node3 && p2; p2 = parentNode(p2))
      if (p2.draggable)
        node3 = void 0;
  }
  elt = targetKludge(elt, coords);
  if (node3) {
    if (gecko && node3.nodeType == 1) {
      offset = Math.min(offset, node3.childNodes.length);
      if (offset < node3.childNodes.length) {
        let next2 = node3.childNodes[offset], box;
        if (next2.nodeName == "IMG" && (box = next2.getBoundingClientRect()).right <= coords.left && box.bottom > coords.top)
          offset++;
      }
    }
    let prev2;
    if (webkit && offset && node3.nodeType == 1 && (prev2 = node3.childNodes[offset - 1]).nodeType == 1 && prev2.contentEditable == "false" && prev2.getBoundingClientRect().top >= coords.top)
      offset--;
    if (node3 == view.dom && offset == node3.childNodes.length - 1 && node3.lastChild.nodeType == 1 && coords.top > node3.lastChild.getBoundingClientRect().bottom)
      pos = view.state.doc.content.size;
    else if (offset == 0 || node3.nodeType != 1 || node3.childNodes[offset - 1].nodeName != "BR")
      pos = posFromCaret(view, node3, offset, coords);
  }
  if (pos == null)
    pos = posFromElement(view, elt, coords);
  let desc = view.docView.nearestDesc(elt, true);
  return { pos, inside: desc ? desc.posAtStart - desc.border : -1 };
}
__name(posAtCoords, "posAtCoords");
function nonZero(rect) {
  return rect.top < rect.bottom || rect.left < rect.right;
}
__name(nonZero, "nonZero");
function singleRect(target2, bias) {
  let rects = target2.getClientRects();
  if (rects.length) {
    let first2 = rects[bias < 0 ? 0 : rects.length - 1];
    if (nonZero(first2))
      return first2;
  }
  return Array.prototype.find.call(rects, nonZero) || target2.getBoundingClientRect();
}
__name(singleRect, "singleRect");
const BIDI = /[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac]/;
function coordsAtPos(view, pos, side) {
  let { node: node3, offset, atom } = view.docView.domFromPos(pos, side < 0 ? -1 : 1);
  let supportEmptyRange = webkit || gecko;
  if (node3.nodeType == 3) {
    if (supportEmptyRange && (BIDI.test(node3.nodeValue) || (side < 0 ? !offset : offset == node3.nodeValue.length))) {
      let rect = singleRect(textRange(node3, offset, offset), side);
      if (gecko && offset && /\s/.test(node3.nodeValue[offset - 1]) && offset < node3.nodeValue.length) {
        let rectBefore = singleRect(textRange(node3, offset - 1, offset - 1), -1);
        if (rectBefore.top == rect.top) {
          let rectAfter = singleRect(textRange(node3, offset, offset + 1), -1);
          if (rectAfter.top != rect.top)
            return flattenV(rectAfter, rectAfter.left < rectBefore.left);
        }
      }
      return rect;
    } else {
      let from2 = offset, to = offset, takeSide = side < 0 ? 1 : -1;
      if (side < 0 && !offset) {
        to++;
        takeSide = -1;
      } else if (side >= 0 && offset == node3.nodeValue.length) {
        from2--;
        takeSide = 1;
      } else if (side < 0) {
        from2--;
      } else {
        to++;
      }
      return flattenV(singleRect(textRange(node3, from2, to), takeSide), takeSide < 0);
    }
  }
  let $dom = view.state.doc.resolve(pos - (atom || 0));
  if (!$dom.parent.inlineContent) {
    if (atom == null && offset && (side < 0 || offset == nodeSize(node3))) {
      let before = node3.childNodes[offset - 1];
      if (before.nodeType == 1)
        return flattenH(before.getBoundingClientRect(), false);
    }
    if (atom == null && offset < nodeSize(node3)) {
      let after = node3.childNodes[offset];
      if (after.nodeType == 1)
        return flattenH(after.getBoundingClientRect(), true);
    }
    return flattenH(node3.getBoundingClientRect(), side >= 0);
  }
  if (atom == null && offset && (side < 0 || offset == nodeSize(node3))) {
    let before = node3.childNodes[offset - 1];
    let target2 = before.nodeType == 3 ? textRange(before, nodeSize(before) - (supportEmptyRange ? 0 : 1)) : before.nodeType == 1 && (before.nodeName != "BR" || !before.nextSibling) ? before : null;
    if (target2)
      return flattenV(singleRect(target2, 1), false);
  }
  if (atom == null && offset < nodeSize(node3)) {
    let after = node3.childNodes[offset];
    while (after.pmViewDesc && after.pmViewDesc.ignoreForCoords)
      after = after.nextSibling;
    let target2 = !after ? null : after.nodeType == 3 ? textRange(after, 0, supportEmptyRange ? 0 : 1) : after.nodeType == 1 ? after : null;
    if (target2)
      return flattenV(singleRect(target2, -1), true);
  }
  return flattenV(singleRect(node3.nodeType == 3 ? textRange(node3) : node3, -side), side >= 0);
}
__name(coordsAtPos, "coordsAtPos");
function flattenV(rect, left) {
  if (rect.width == 0)
    return rect;
  let x2 = left ? rect.left : rect.right;
  return { top: rect.top, bottom: rect.bottom, left: x2, right: x2 };
}
__name(flattenV, "flattenV");
function flattenH(rect, top) {
  if (rect.height == 0)
    return rect;
  let y2 = top ? rect.top : rect.bottom;
  return { top: y2, bottom: y2, left: rect.left, right: rect.right };
}
__name(flattenH, "flattenH");
function withFlushedState(view, state, f2) {
  let viewState = view.state, active4 = view.root.activeElement;
  if (viewState != state)
    view.updateState(state);
  if (active4 != view.dom)
    view.focus();
  try {
    return f2();
  } finally {
    if (viewState != state)
      view.updateState(viewState);
    if (active4 != view.dom && active4)
      active4.focus();
  }
}
__name(withFlushedState, "withFlushedState");
function endOfTextblockVertical(view, state, dir) {
  let sel = state.selection;
  let $pos = dir == "up" ? sel.$from : sel.$to;
  return withFlushedState(view, state, () => {
    let { node: dom } = view.docView.domFromPos($pos.pos, dir == "up" ? -1 : 1);
    for (; ; ) {
      let nearest = view.docView.nearestDesc(dom, true);
      if (!nearest)
        break;
      if (nearest.node.isBlock) {
        dom = nearest.contentDOM || nearest.dom;
        break;
      }
      dom = nearest.dom.parentNode;
    }
    let coords = coordsAtPos(view, $pos.pos, 1);
    for (let child = dom.firstChild; child; child = child.nextSibling) {
      let boxes;
      if (child.nodeType == 1)
        boxes = child.getClientRects();
      else if (child.nodeType == 3)
        boxes = textRange(child, 0, child.nodeValue.length).getClientRects();
      else
        continue;
      for (let i2 = 0; i2 < boxes.length; i2++) {
        let box = boxes[i2];
        if (box.bottom > box.top + 1 && (dir == "up" ? coords.top - box.top > (box.bottom - coords.top) * 2 : box.bottom - coords.bottom > (coords.bottom - box.top) * 2))
          return false;
      }
    }
    return true;
  });
}
__name(endOfTextblockVertical, "endOfTextblockVertical");
const maybeRTL = /[\u0590-\u08ac]/;
function endOfTextblockHorizontal(view, state, dir) {
  let { $head } = state.selection;
  if (!$head.parent.isTextblock)
    return false;
  let offset = $head.parentOffset, atStart = !offset, atEnd = offset == $head.parent.content.size;
  let sel = view.domSelection();
  if (!sel)
    return $head.pos == $head.start() || $head.pos == $head.end();
  if (!maybeRTL.test($head.parent.textContent) || !sel.modify)
    return dir == "left" || dir == "backward" ? atStart : atEnd;
  return withFlushedState(view, state, () => {
    let { focusNode: oldNode, focusOffset: oldOff, anchorNode, anchorOffset } = view.domSelectionRange();
    let oldBidiLevel = sel.caretBidiLevel;
    sel.modify("move", dir, "character");
    let parentDOM = $head.depth ? view.docView.domAfterPos($head.before()) : view.dom;
    let { focusNode: newNode, focusOffset: newOff } = view.domSelectionRange();
    let result = newNode && !parentDOM.contains(newNode.nodeType == 1 ? newNode : newNode.parentNode) || oldNode == newNode && oldOff == newOff;
    try {
      sel.collapse(anchorNode, anchorOffset);
      if (oldNode && (oldNode != anchorNode || oldOff != anchorOffset) && sel.extend)
        sel.extend(oldNode, oldOff);
    } catch (_2) {
    }
    if (oldBidiLevel != null)
      sel.caretBidiLevel = oldBidiLevel;
    return result;
  });
}
__name(endOfTextblockHorizontal, "endOfTextblockHorizontal");
let cachedState = null;
let cachedDir = null;
let cachedResult = false;
function endOfTextblock(view, state, dir) {
  if (cachedState == state && cachedDir == dir)
    return cachedResult;
  cachedState = state;
  cachedDir = dir;
  return cachedResult = dir == "up" || dir == "down" ? endOfTextblockVertical(view, state, dir) : endOfTextblockHorizontal(view, state, dir);
}
__name(endOfTextblock, "endOfTextblock");
const NOT_DIRTY = 0, CHILD_DIRTY = 1, CONTENT_DIRTY = 2, NODE_DIRTY = 3;
class ViewDesc {
  static {
    __name(this, "ViewDesc");
  }
  constructor(parent, children, dom, contentDOM) {
    this.parent = parent;
    this.children = children;
    this.dom = dom;
    this.contentDOM = contentDOM;
    this.dirty = NOT_DIRTY;
    dom.pmViewDesc = this;
  }
  // Used to check whether a given description corresponds to a
  // widget/mark/node.
  matchesWidget(widget) {
    return false;
  }
  matchesMark(mark2) {
    return false;
  }
  matchesNode(node3, outerDeco, innerDeco) {
    return false;
  }
  matchesHack(nodeName) {
    return false;
  }
  // When parsing in-editor content (in domchange.js), we allow
  // descriptions to determine the parse rules that should be used to
  // parse them.
  parseRule() {
    return null;
  }
  // Used by the editor's event handler to ignore events that come
  // from certain descs.
  stopEvent(event) {
    return false;
  }
  // The size of the content represented by this desc.
  get size() {
    let size = 0;
    for (let i2 = 0; i2 < this.children.length; i2++)
      size += this.children[i2].size;
    return size;
  }
  // For block nodes, this represents the space taken up by their
  // start/end tokens.
  get border() {
    return 0;
  }
  destroy() {
    this.parent = void 0;
    if (this.dom.pmViewDesc == this)
      this.dom.pmViewDesc = void 0;
    for (let i2 = 0; i2 < this.children.length; i2++)
      this.children[i2].destroy();
  }
  posBeforeChild(child) {
    for (let i2 = 0, pos = this.posAtStart; ; i2++) {
      let cur = this.children[i2];
      if (cur == child)
        return pos;
      pos += cur.size;
    }
  }
  get posBefore() {
    return this.parent.posBeforeChild(this);
  }
  get posAtStart() {
    return this.parent ? this.parent.posBeforeChild(this) + this.border : 0;
  }
  get posAfter() {
    return this.posBefore + this.size;
  }
  get posAtEnd() {
    return this.posAtStart + this.size - 2 * this.border;
  }
  localPosFromDOM(dom, offset, bias) {
    if (this.contentDOM && this.contentDOM.contains(dom.nodeType == 1 ? dom : dom.parentNode)) {
      if (bias < 0) {
        let domBefore, desc;
        if (dom == this.contentDOM) {
          domBefore = dom.childNodes[offset - 1];
        } else {
          while (dom.parentNode != this.contentDOM)
            dom = dom.parentNode;
          domBefore = dom.previousSibling;
        }
        while (domBefore && !((desc = domBefore.pmViewDesc) && desc.parent == this))
          domBefore = domBefore.previousSibling;
        return domBefore ? this.posBeforeChild(desc) + desc.size : this.posAtStart;
      } else {
        let domAfter, desc;
        if (dom == this.contentDOM) {
          domAfter = dom.childNodes[offset];
        } else {
          while (dom.parentNode != this.contentDOM)
            dom = dom.parentNode;
          domAfter = dom.nextSibling;
        }
        while (domAfter && !((desc = domAfter.pmViewDesc) && desc.parent == this))
          domAfter = domAfter.nextSibling;
        return domAfter ? this.posBeforeChild(desc) : this.posAtEnd;
      }
    }
    let atEnd;
    if (dom == this.dom && this.contentDOM) {
      atEnd = offset > domIndex(this.contentDOM);
    } else if (this.contentDOM && this.contentDOM != this.dom && this.dom.contains(this.contentDOM)) {
      atEnd = dom.compareDocumentPosition(this.contentDOM) & 2;
    } else if (this.dom.firstChild) {
      if (offset == 0)
        for (let search3 = dom; ; search3 = search3.parentNode) {
          if (search3 == this.dom) {
            atEnd = false;
            break;
          }
          if (search3.previousSibling)
            break;
        }
      if (atEnd == null && offset == dom.childNodes.length)
        for (let search3 = dom; ; search3 = search3.parentNode) {
          if (search3 == this.dom) {
            atEnd = true;
            break;
          }
          if (search3.nextSibling)
            break;
        }
    }
    return (atEnd == null ? bias > 0 : atEnd) ? this.posAtEnd : this.posAtStart;
  }
  nearestDesc(dom, onlyNodes = false) {
    for (let first2 = true, cur = dom; cur; cur = cur.parentNode) {
      let desc = this.getDesc(cur), nodeDOM;
      if (desc && (!onlyNodes || desc.node)) {
        if (first2 && (nodeDOM = desc.nodeDOM) && !(nodeDOM.nodeType == 1 ? nodeDOM.contains(dom.nodeType == 1 ? dom : dom.parentNode) : nodeDOM == dom))
          first2 = false;
        else
          return desc;
      }
    }
  }
  getDesc(dom) {
    let desc = dom.pmViewDesc;
    for (let cur = desc; cur; cur = cur.parent)
      if (cur == this)
        return desc;
  }
  posFromDOM(dom, offset, bias) {
    for (let scan = dom; scan; scan = scan.parentNode) {
      let desc = this.getDesc(scan);
      if (desc)
        return desc.localPosFromDOM(dom, offset, bias);
    }
    return -1;
  }
  // Find the desc for the node after the given pos, if any. (When a
  // parent node overrode rendering, there might not be one.)
  descAt(pos) {
    for (let i2 = 0, offset = 0; i2 < this.children.length; i2++) {
      let child = this.children[i2], end = offset + child.size;
      if (offset == pos && end != offset) {
        while (!child.border && child.children.length)
          child = child.children[0];
        return child;
      }
      if (pos < end)
        return child.descAt(pos - offset - child.border);
      offset = end;
    }
  }
  domFromPos(pos, side) {
    if (!this.contentDOM)
      return { node: this.dom, offset: 0, atom: pos + 1 };
    let i2 = 0, offset = 0;
    for (let curPos = 0; i2 < this.children.length; i2++) {
      let child = this.children[i2], end = curPos + child.size;
      if (end > pos || child instanceof TrailingHackViewDesc) {
        offset = pos - curPos;
        break;
      }
      curPos = end;
    }
    if (offset)
      return this.children[i2].domFromPos(offset - this.children[i2].border, side);
    for (let prev2; i2 && !(prev2 = this.children[i2 - 1]).size && prev2 instanceof WidgetViewDesc && prev2.side >= 0; i2--) {
    }
    if (side <= 0) {
      let prev2, enter2 = true;
      for (; ; i2--, enter2 = false) {
        prev2 = i2 ? this.children[i2 - 1] : null;
        if (!prev2 || prev2.dom.parentNode == this.contentDOM)
          break;
      }
      if (prev2 && side && enter2 && !prev2.border && !prev2.domAtom)
        return prev2.domFromPos(prev2.size, side);
      return { node: this.contentDOM, offset: prev2 ? domIndex(prev2.dom) + 1 : 0 };
    } else {
      let next2, enter2 = true;
      for (; ; i2++, enter2 = false) {
        next2 = i2 < this.children.length ? this.children[i2] : null;
        if (!next2 || next2.dom.parentNode == this.contentDOM)
          break;
      }
      if (next2 && enter2 && !next2.border && !next2.domAtom)
        return next2.domFromPos(0, side);
      return { node: this.contentDOM, offset: next2 ? domIndex(next2.dom) : this.contentDOM.childNodes.length };
    }
  }
  // Used to find a DOM range in a single parent for a given changed
  // range.
  parseRange(from2, to, base2 = 0) {
    if (this.children.length == 0)
      return { node: this.contentDOM, from: from2, to, fromOffset: 0, toOffset: this.contentDOM.childNodes.length };
    let fromOffset = -1, toOffset = -1;
    for (let offset = base2, i2 = 0; ; i2++) {
      let child = this.children[i2], end = offset + child.size;
      if (fromOffset == -1 && from2 <= end) {
        let childBase = offset + child.border;
        if (from2 >= childBase && to <= end - child.border && child.node && child.contentDOM && this.contentDOM.contains(child.contentDOM))
          return child.parseRange(from2, to, childBase);
        from2 = offset;
        for (let j2 = i2; j2 > 0; j2--) {
          let prev2 = this.children[j2 - 1];
          if (prev2.size && prev2.dom.parentNode == this.contentDOM && !prev2.emptyChildAt(1)) {
            fromOffset = domIndex(prev2.dom) + 1;
            break;
          }
          from2 -= prev2.size;
        }
        if (fromOffset == -1)
          fromOffset = 0;
      }
      if (fromOffset > -1 && (end > to || i2 == this.children.length - 1)) {
        to = end;
        for (let j2 = i2 + 1; j2 < this.children.length; j2++) {
          let next2 = this.children[j2];
          if (next2.size && next2.dom.parentNode == this.contentDOM && !next2.emptyChildAt(-1)) {
            toOffset = domIndex(next2.dom);
            break;
          }
          to += next2.size;
        }
        if (toOffset == -1)
          toOffset = this.contentDOM.childNodes.length;
        break;
      }
      offset = end;
    }
    return { node: this.contentDOM, from: from2, to, fromOffset, toOffset };
  }
  emptyChildAt(side) {
    if (this.border || !this.contentDOM || !this.children.length)
      return false;
    let child = this.children[side < 0 ? 0 : this.children.length - 1];
    return child.size == 0 || child.emptyChildAt(side);
  }
  domAfterPos(pos) {
    let { node: node3, offset } = this.domFromPos(pos, 0);
    if (node3.nodeType != 1 || offset == node3.childNodes.length)
      throw new RangeError("No node after pos " + pos);
    return node3.childNodes[offset];
  }
  // View descs are responsible for setting any selection that falls
  // entirely inside of them, so that custom implementations can do
  // custom things with the selection. Note that this falls apart when
  // a selection starts in such a node and ends in another, in which
  // case we just use whatever domFromPos produces as a best effort.
  setSelection(anchor, head, view, force = false) {
    let from2 = Math.min(anchor, head), to = Math.max(anchor, head);
    for (let i2 = 0, offset = 0; i2 < this.children.length; i2++) {
      let child = this.children[i2], end = offset + child.size;
      if (from2 > offset && to < end)
        return child.setSelection(anchor - offset - child.border, head - offset - child.border, view, force);
      offset = end;
    }
    let anchorDOM = this.domFromPos(anchor, anchor ? -1 : 1);
    let headDOM = head == anchor ? anchorDOM : this.domFromPos(head, head ? -1 : 1);
    let domSel = view.root.getSelection();
    let selRange = view.domSelectionRange();
    let brKludge = false;
    if ((gecko || safari) && anchor == head) {
      let { node: node3, offset } = anchorDOM;
      if (node3.nodeType == 3) {
        brKludge = !!(offset && node3.nodeValue[offset - 1] == "\n");
        if (brKludge && offset == node3.nodeValue.length) {
          for (let scan = node3, after; scan; scan = scan.parentNode) {
            if (after = scan.nextSibling) {
              if (after.nodeName == "BR")
                anchorDOM = headDOM = { node: after.parentNode, offset: domIndex(after) + 1 };
              break;
            }
            let desc = scan.pmViewDesc;
            if (desc && desc.node && desc.node.isBlock)
              break;
          }
        }
      } else {
        let prev2 = node3.childNodes[offset - 1];
        brKludge = prev2 && (prev2.nodeName == "BR" || prev2.contentEditable == "false");
      }
    }
    if (gecko && selRange.focusNode && selRange.focusNode != headDOM.node && selRange.focusNode.nodeType == 1) {
      let after = selRange.focusNode.childNodes[selRange.focusOffset];
      if (after && after.contentEditable == "false")
        force = true;
    }
    if (!(force || brKludge && safari) && isEquivalentPosition(anchorDOM.node, anchorDOM.offset, selRange.anchorNode, selRange.anchorOffset) && isEquivalentPosition(headDOM.node, headDOM.offset, selRange.focusNode, selRange.focusOffset))
      return;
    let domSelExtended = false;
    if ((domSel.extend || anchor == head) && !brKludge) {
      domSel.collapse(anchorDOM.node, anchorDOM.offset);
      try {
        if (anchor != head)
          domSel.extend(headDOM.node, headDOM.offset);
        domSelExtended = true;
      } catch (_2) {
      }
    }
    if (!domSelExtended) {
      if (anchor > head) {
        let tmp = anchorDOM;
        anchorDOM = headDOM;
        headDOM = tmp;
      }
      let range2 = document.createRange();
      range2.setEnd(headDOM.node, headDOM.offset);
      range2.setStart(anchorDOM.node, anchorDOM.offset);
      domSel.removeAllRanges();
      domSel.addRange(range2);
    }
  }
  ignoreMutation(mutation) {
    return !this.contentDOM && mutation.type != "selection";
  }
  get contentLost() {
    return this.contentDOM && this.contentDOM != this.dom && !this.dom.contains(this.contentDOM);
  }
  // Remove a subtree of the element tree that has been touched
  // by a DOM change, so that the next update will redraw it.
  markDirty(from2, to) {
    for (let offset = 0, i2 = 0; i2 < this.children.length; i2++) {
      let child = this.children[i2], end = offset + child.size;
      if (offset == end ? from2 <= end && to >= offset : from2 < end && to > offset) {
        let startInside = offset + child.border, endInside = end - child.border;
        if (from2 >= startInside && to <= endInside) {
          this.dirty = from2 == offset || to == end ? CONTENT_DIRTY : CHILD_DIRTY;
          if (from2 == startInside && to == endInside && (child.contentLost || child.dom.parentNode != this.contentDOM))
            child.dirty = NODE_DIRTY;
          else
            child.markDirty(from2 - startInside, to - startInside);
          return;
        } else {
          child.dirty = child.dom == child.contentDOM && child.dom.parentNode == this.contentDOM && !child.children.length ? CONTENT_DIRTY : NODE_DIRTY;
        }
      }
      offset = end;
    }
    this.dirty = CONTENT_DIRTY;
  }
  markParentsDirty() {
    let level = 1;
    for (let node3 = this.parent; node3; node3 = node3.parent, level++) {
      let dirty = level == 1 ? CONTENT_DIRTY : CHILD_DIRTY;
      if (node3.dirty < dirty)
        node3.dirty = dirty;
    }
  }
  get domAtom() {
    return false;
  }
  get ignoreForCoords() {
    return false;
  }
  isText(text2) {
    return false;
  }
}
class WidgetViewDesc extends ViewDesc {
  static {
    __name(this, "WidgetViewDesc");
  }
  constructor(parent, widget, view, pos) {
    let self2, dom = widget.type.toDOM;
    if (typeof dom == "function")
      dom = dom(view, () => {
        if (!self2)
          return pos;
        if (self2.parent)
          return self2.parent.posBeforeChild(self2);
      });
    if (!widget.type.spec.raw) {
      if (dom.nodeType != 1) {
        let wrap2 = document.createElement("span");
        wrap2.appendChild(dom);
        dom = wrap2;
      }
      dom.contentEditable = "false";
      dom.classList.add("ProseMirror-widget");
    }
    super(parent, [], dom, null);
    this.widget = widget;
    this.widget = widget;
    self2 = this;
  }
  matchesWidget(widget) {
    return this.dirty == NOT_DIRTY && widget.type.eq(this.widget.type);
  }
  parseRule() {
    return { ignore: true };
  }
  stopEvent(event) {
    let stop2 = this.widget.spec.stopEvent;
    return stop2 ? stop2(event) : false;
  }
  ignoreMutation(mutation) {
    return mutation.type != "selection" || this.widget.spec.ignoreSelection;
  }
  destroy() {
    this.widget.type.destroy(this.dom);
    super.destroy();
  }
  get domAtom() {
    return true;
  }
  get side() {
    return this.widget.type.side;
  }
}
class CompositionViewDesc extends ViewDesc {
  static {
    __name(this, "CompositionViewDesc");
  }
  constructor(parent, dom, textDOM, text2) {
    super(parent, [], dom, null);
    this.textDOM = textDOM;
    this.text = text2;
  }
  get size() {
    return this.text.length;
  }
  localPosFromDOM(dom, offset) {
    if (dom != this.textDOM)
      return this.posAtStart + (offset ? this.size : 0);
    return this.posAtStart + offset;
  }
  domFromPos(pos) {
    return { node: this.textDOM, offset: pos };
  }
  ignoreMutation(mut) {
    return mut.type === "characterData" && mut.target.nodeValue == mut.oldValue;
  }
}
class MarkViewDesc extends ViewDesc {
  static {
    __name(this, "MarkViewDesc");
  }
  constructor(parent, mark2, dom, contentDOM, spec) {
    super(parent, [], dom, contentDOM);
    this.mark = mark2;
    this.spec = spec;
  }
  static create(parent, mark2, inline3, view) {
    let custom2 = view.nodeViews[mark2.type.name];
    let spec = custom2 && custom2(mark2, view, inline3);
    if (!spec || !spec.dom)
      spec = DOMSerializer.renderSpec(document, mark2.type.spec.toDOM(mark2, inline3), null, mark2.attrs);
    return new MarkViewDesc(parent, mark2, spec.dom, spec.contentDOM || spec.dom, spec);
  }
  parseRule() {
    if (this.dirty & NODE_DIRTY || this.mark.type.spec.reparseInView)
      return null;
    return { mark: this.mark.type.name, attrs: this.mark.attrs, contentElement: this.contentDOM };
  }
  matchesMark(mark2) {
    return this.dirty != NODE_DIRTY && this.mark.eq(mark2);
  }
  markDirty(from2, to) {
    super.markDirty(from2, to);
    if (this.dirty != NOT_DIRTY) {
      let parent = this.parent;
      while (!parent.node)
        parent = parent.parent;
      if (parent.dirty < this.dirty)
        parent.dirty = this.dirty;
      this.dirty = NOT_DIRTY;
    }
  }
  slice(from2, to, view) {
    let copy2 = MarkViewDesc.create(this.parent, this.mark, true, view);
    let nodes = this.children, size = this.size;
    if (to < size)
      nodes = replaceNodes(nodes, to, size, view);
    if (from2 > 0)
      nodes = replaceNodes(nodes, 0, from2, view);
    for (let i2 = 0; i2 < nodes.length; i2++)
      nodes[i2].parent = copy2;
    copy2.children = nodes;
    return copy2;
  }
  ignoreMutation(mutation) {
    return this.spec.ignoreMutation ? this.spec.ignoreMutation(mutation) : super.ignoreMutation(mutation);
  }
  destroy() {
    if (this.spec.destroy)
      this.spec.destroy();
    super.destroy();
  }
}
class NodeViewDesc extends ViewDesc {
  static {
    __name(this, "NodeViewDesc");
  }
  constructor(parent, node3, outerDeco, innerDeco, dom, contentDOM, nodeDOM, view, pos) {
    super(parent, [], dom, contentDOM);
    this.node = node3;
    this.outerDeco = outerDeco;
    this.innerDeco = innerDeco;
    this.nodeDOM = nodeDOM;
  }
  // By default, a node is rendered using the `toDOM` method from the
  // node type spec. But client code can use the `nodeViews` spec to
  // supply a custom node view, which can influence various aspects of
  // the way the node works.
  //
  // (Using subclassing for this was intentionally decided against,
  // since it'd require exposing a whole slew of finicky
  // implementation details to the user code that they probably will
  // never need.)
  static create(parent, node3, outerDeco, innerDeco, view, pos) {
    let custom2 = view.nodeViews[node3.type.name], descObj;
    let spec = custom2 && custom2(node3, view, () => {
      if (!descObj)
        return pos;
      if (descObj.parent)
        return descObj.parent.posBeforeChild(descObj);
    }, outerDeco, innerDeco);
    let dom = spec && spec.dom, contentDOM = spec && spec.contentDOM;
    if (node3.isText) {
      if (!dom)
        dom = document.createTextNode(node3.text);
      else if (dom.nodeType != 3)
        throw new RangeError("Text must be rendered as a DOM text node");
    } else if (!dom) {
      let spec2 = DOMSerializer.renderSpec(document, node3.type.spec.toDOM(node3), null, node3.attrs);
      ({ dom, contentDOM } = spec2);
    }
    if (!contentDOM && !node3.isText && dom.nodeName != "BR") {
      if (!dom.hasAttribute("contenteditable"))
        dom.contentEditable = "false";
      if (node3.type.spec.draggable)
        dom.draggable = true;
    }
    let nodeDOM = dom;
    dom = applyOuterDeco(dom, outerDeco, node3);
    if (spec)
      return descObj = new CustomNodeViewDesc(parent, node3, outerDeco, innerDeco, dom, contentDOM || null, nodeDOM, spec, view, pos + 1);
    else if (node3.isText)
      return new TextViewDesc(parent, node3, outerDeco, innerDeco, dom, nodeDOM, view);
    else
      return new NodeViewDesc(parent, node3, outerDeco, innerDeco, dom, contentDOM || null, nodeDOM, view, pos + 1);
  }
  parseRule() {
    if (this.node.type.spec.reparseInView)
      return null;
    let rule = { node: this.node.type.name, attrs: this.node.attrs };
    if (this.node.type.whitespace == "pre")
      rule.preserveWhitespace = "full";
    if (!this.contentDOM) {
      rule.getContent = () => this.node.content;
    } else if (!this.contentLost) {
      rule.contentElement = this.contentDOM;
    } else {
      for (let i2 = this.children.length - 1; i2 >= 0; i2--) {
        let child = this.children[i2];
        if (this.dom.contains(child.dom.parentNode)) {
          rule.contentElement = child.dom.parentNode;
          break;
        }
      }
      if (!rule.contentElement)
        rule.getContent = () => Fragment.empty;
    }
    return rule;
  }
  matchesNode(node3, outerDeco, innerDeco) {
    return this.dirty == NOT_DIRTY && node3.eq(this.node) && sameOuterDeco(outerDeco, this.outerDeco) && innerDeco.eq(this.innerDeco);
  }
  get size() {
    return this.node.nodeSize;
  }
  get border() {
    return this.node.isLeaf ? 0 : 1;
  }
  // Syncs `this.children` to match `this.node.content` and the local
  // decorations, possibly introducing nesting for marks. Then, in a
  // separate step, syncs the DOM inside `this.contentDOM` to
  // `this.children`.
  updateChildren(view, pos) {
    let inline3 = this.node.inlineContent, off = pos;
    let composition = view.composing ? this.localCompositionInfo(view, pos) : null;
    let localComposition = composition && composition.pos > -1 ? composition : null;
    let compositionInChild = composition && composition.pos < 0;
    let updater = new ViewTreeUpdater(this, localComposition && localComposition.node, view);
    iterDeco(this.node, this.innerDeco, (widget, i2, insideNode) => {
      if (widget.spec.marks)
        updater.syncToMarks(widget.spec.marks, inline3, view);
      else if (widget.type.side >= 0 && !insideNode)
        updater.syncToMarks(i2 == this.node.childCount ? Mark$1.none : this.node.child(i2).marks, inline3, view);
      updater.placeWidget(widget, view, off);
    }, (child, outerDeco, innerDeco, i2) => {
      updater.syncToMarks(child.marks, inline3, view);
      let compIndex;
      if (updater.findNodeMatch(child, outerDeco, innerDeco, i2)) ;
      else if (compositionInChild && view.state.selection.from > off && view.state.selection.to < off + child.nodeSize && (compIndex = updater.findIndexWithChild(composition.node)) > -1 && updater.updateNodeAt(child, outerDeco, innerDeco, compIndex, view)) ;
      else if (updater.updateNextNode(child, outerDeco, innerDeco, view, i2, off)) ;
      else {
        updater.addNode(child, outerDeco, innerDeco, view, off);
      }
      off += child.nodeSize;
    });
    updater.syncToMarks([], inline3, view);
    if (this.node.isTextblock)
      updater.addTextblockHacks();
    updater.destroyRest();
    if (updater.changed || this.dirty == CONTENT_DIRTY) {
      if (localComposition)
        this.protectLocalComposition(view, localComposition);
      renderDescs(this.contentDOM, this.children, view);
      if (ios)
        iosHacks(this.dom);
    }
  }
  localCompositionInfo(view, pos) {
    let { from: from2, to } = view.state.selection;
    if (!(view.state.selection instanceof TextSelection) || from2 < pos || to > pos + this.node.content.size)
      return null;
    let textNode = view.input.compositionNode;
    if (!textNode || !this.dom.contains(textNode.parentNode))
      return null;
    if (this.node.inlineContent) {
      let text2 = textNode.nodeValue;
      let textPos = findTextInFragment(this.node.content, text2, from2 - pos, to - pos);
      return textPos < 0 ? null : { node: textNode, pos: textPos, text: text2 };
    } else {
      return { node: textNode, pos: -1, text: "" };
    }
  }
  protectLocalComposition(view, { node: node3, pos, text: text2 }) {
    if (this.getDesc(node3))
      return;
    let topNode = node3;
    for (; ; topNode = topNode.parentNode) {
      if (topNode.parentNode == this.contentDOM)
        break;
      while (topNode.previousSibling)
        topNode.parentNode.removeChild(topNode.previousSibling);
      while (topNode.nextSibling)
        topNode.parentNode.removeChild(topNode.nextSibling);
      if (topNode.pmViewDesc)
        topNode.pmViewDesc = void 0;
    }
    let desc = new CompositionViewDesc(this, topNode, node3, text2);
    view.input.compositionNodes.push(desc);
    this.children = replaceNodes(this.children, pos, pos + text2.length, view, desc);
  }
  // If this desc must be updated to match the given node decoration,
  // do so and return true.
  update(node3, outerDeco, innerDeco, view) {
    if (this.dirty == NODE_DIRTY || !node3.sameMarkup(this.node))
      return false;
    this.updateInner(node3, outerDeco, innerDeco, view);
    return true;
  }
  updateInner(node3, outerDeco, innerDeco, view) {
    this.updateOuterDeco(outerDeco);
    this.node = node3;
    this.innerDeco = innerDeco;
    if (this.contentDOM)
      this.updateChildren(view, this.posAtStart);
    this.dirty = NOT_DIRTY;
  }
  updateOuterDeco(outerDeco) {
    if (sameOuterDeco(outerDeco, this.outerDeco))
      return;
    let needsWrap = this.nodeDOM.nodeType != 1;
    let oldDOM = this.dom;
    this.dom = patchOuterDeco(this.dom, this.nodeDOM, computeOuterDeco(this.outerDeco, this.node, needsWrap), computeOuterDeco(outerDeco, this.node, needsWrap));
    if (this.dom != oldDOM) {
      oldDOM.pmViewDesc = void 0;
      this.dom.pmViewDesc = this;
    }
    this.outerDeco = outerDeco;
  }
  // Mark this node as being the selected node.
  selectNode() {
    if (this.nodeDOM.nodeType == 1)
      this.nodeDOM.classList.add("ProseMirror-selectednode");
    if (this.contentDOM || !this.node.type.spec.draggable)
      this.dom.draggable = true;
  }
  // Remove selected node marking from this node.
  deselectNode() {
    if (this.nodeDOM.nodeType == 1) {
      this.nodeDOM.classList.remove("ProseMirror-selectednode");
      if (this.contentDOM || !this.node.type.spec.draggable)
        this.dom.removeAttribute("draggable");
    }
  }
  get domAtom() {
    return this.node.isAtom;
  }
}
function docViewDesc(doc2, outerDeco, innerDeco, dom, view) {
  applyOuterDeco(dom, outerDeco, doc2);
  let docView = new NodeViewDesc(void 0, doc2, outerDeco, innerDeco, dom, dom, dom, view, 0);
  if (docView.contentDOM)
    docView.updateChildren(view, 0);
  return docView;
}
__name(docViewDesc, "docViewDesc");
class TextViewDesc extends NodeViewDesc {
  static {
    __name(this, "TextViewDesc");
  }
  constructor(parent, node3, outerDeco, innerDeco, dom, nodeDOM, view) {
    super(parent, node3, outerDeco, innerDeco, dom, null, nodeDOM, view, 0);
  }
  parseRule() {
    let skip = this.nodeDOM.parentNode;
    while (skip && skip != this.dom && !skip.pmIsDeco)
      skip = skip.parentNode;
    return { skip: skip || true };
  }
  update(node3, outerDeco, innerDeco, view) {
    if (this.dirty == NODE_DIRTY || this.dirty != NOT_DIRTY && !this.inParent() || !node3.sameMarkup(this.node))
      return false;
    this.updateOuterDeco(outerDeco);
    if ((this.dirty != NOT_DIRTY || node3.text != this.node.text) && node3.text != this.nodeDOM.nodeValue) {
      this.nodeDOM.nodeValue = node3.text;
      if (view.trackWrites == this.nodeDOM)
        view.trackWrites = null;
    }
    this.node = node3;
    this.dirty = NOT_DIRTY;
    return true;
  }
  inParent() {
    let parentDOM = this.parent.contentDOM;
    for (let n2 = this.nodeDOM; n2; n2 = n2.parentNode)
      if (n2 == parentDOM)
        return true;
    return false;
  }
  domFromPos(pos) {
    return { node: this.nodeDOM, offset: pos };
  }
  localPosFromDOM(dom, offset, bias) {
    if (dom == this.nodeDOM)
      return this.posAtStart + Math.min(offset, this.node.text.length);
    return super.localPosFromDOM(dom, offset, bias);
  }
  ignoreMutation(mutation) {
    return mutation.type != "characterData" && mutation.type != "selection";
  }
  slice(from2, to, view) {
    let node3 = this.node.cut(from2, to), dom = document.createTextNode(node3.text);
    return new TextViewDesc(this.parent, node3, this.outerDeco, this.innerDeco, dom, dom, view);
  }
  markDirty(from2, to) {
    super.markDirty(from2, to);
    if (this.dom != this.nodeDOM && (from2 == 0 || to == this.nodeDOM.nodeValue.length))
      this.dirty = NODE_DIRTY;
  }
  get domAtom() {
    return false;
  }
  isText(text2) {
    return this.node.text == text2;
  }
}
class TrailingHackViewDesc extends ViewDesc {
  static {
    __name(this, "TrailingHackViewDesc");
  }
  parseRule() {
    return { ignore: true };
  }
  matchesHack(nodeName) {
    return this.dirty == NOT_DIRTY && this.dom.nodeName == nodeName;
  }
  get domAtom() {
    return true;
  }
  get ignoreForCoords() {
    return this.dom.nodeName == "IMG";
  }
}
class CustomNodeViewDesc extends NodeViewDesc {
  static {
    __name(this, "CustomNodeViewDesc");
  }
  constructor(parent, node3, outerDeco, innerDeco, dom, contentDOM, nodeDOM, spec, view, pos) {
    super(parent, node3, outerDeco, innerDeco, dom, contentDOM, nodeDOM, view, pos);
    this.spec = spec;
  }
  // A custom `update` method gets to decide whether the update goes
  // through. If it does, and there's a `contentDOM` node, our logic
  // updates the children.
  update(node3, outerDeco, innerDeco, view) {
    if (this.dirty == NODE_DIRTY)
      return false;
    if (this.spec.update && (this.node.type == node3.type || this.spec.multiType)) {
      let result = this.spec.update(node3, outerDeco, innerDeco);
      if (result)
        this.updateInner(node3, outerDeco, innerDeco, view);
      return result;
    } else if (!this.contentDOM && !node3.isLeaf) {
      return false;
    } else {
      return super.update(node3, outerDeco, innerDeco, view);
    }
  }
  selectNode() {
    this.spec.selectNode ? this.spec.selectNode() : super.selectNode();
  }
  deselectNode() {
    this.spec.deselectNode ? this.spec.deselectNode() : super.deselectNode();
  }
  setSelection(anchor, head, view, force) {
    this.spec.setSelection ? this.spec.setSelection(anchor, head, view.root) : super.setSelection(anchor, head, view, force);
  }
  destroy() {
    if (this.spec.destroy)
      this.spec.destroy();
    super.destroy();
  }
  stopEvent(event) {
    return this.spec.stopEvent ? this.spec.stopEvent(event) : false;
  }
  ignoreMutation(mutation) {
    return this.spec.ignoreMutation ? this.spec.ignoreMutation(mutation) : super.ignoreMutation(mutation);
  }
}
function renderDescs(parentDOM, descs, view) {
  let dom = parentDOM.firstChild, written = false;
  for (let i2 = 0; i2 < descs.length; i2++) {
    let desc = descs[i2], childDOM = desc.dom;
    if (childDOM.parentNode == parentDOM) {
      while (childDOM != dom) {
        dom = rm(dom);
        written = true;
      }
      dom = dom.nextSibling;
    } else {
      written = true;
      parentDOM.insertBefore(childDOM, dom);
    }
    if (desc instanceof MarkViewDesc) {
      let pos = dom ? dom.previousSibling : parentDOM.lastChild;
      renderDescs(desc.contentDOM, desc.children, view);
      dom = pos ? pos.nextSibling : parentDOM.firstChild;
    }
  }
  while (dom) {
    dom = rm(dom);
    written = true;
  }
  if (written && view.trackWrites == parentDOM)
    view.trackWrites = null;
}
__name(renderDescs, "renderDescs");
const OuterDecoLevel = /* @__PURE__ */ __name(function(nodeName) {
  if (nodeName)
    this.nodeName = nodeName;
}, "OuterDecoLevel");
OuterDecoLevel.prototype = /* @__PURE__ */ Object.create(null);
const noDeco = [new OuterDecoLevel()];
function computeOuterDeco(outerDeco, node3, needsWrap) {
  if (outerDeco.length == 0)
    return noDeco;
  let top = needsWrap ? noDeco[0] : new OuterDecoLevel(), result = [top];
  for (let i2 = 0; i2 < outerDeco.length; i2++) {
    let attrs7 = outerDeco[i2].type.attrs;
    if (!attrs7)
      continue;
    if (attrs7.nodeName)
      result.push(top = new OuterDecoLevel(attrs7.nodeName));
    for (let name2 in attrs7) {
      let val = attrs7[name2];
      if (val == null)
        continue;
      if (needsWrap && result.length == 1)
        result.push(top = new OuterDecoLevel(node3.isInline ? "span" : "div"));
      if (name2 == "class")
        top.class = (top.class ? top.class + " " : "") + val;
      else if (name2 == "style")
        top.style = (top.style ? top.style + ";" : "") + val;
      else if (name2 != "nodeName")
        top[name2] = val;
    }
  }
  return result;
}
__name(computeOuterDeco, "computeOuterDeco");
function patchOuterDeco(outerDOM, nodeDOM, prevComputed, curComputed) {
  if (prevComputed == noDeco && curComputed == noDeco)
    return nodeDOM;
  let curDOM = nodeDOM;
  for (let i2 = 0; i2 < curComputed.length; i2++) {
    let deco = curComputed[i2], prev2 = prevComputed[i2];
    if (i2) {
      let parent;
      if (prev2 && prev2.nodeName == deco.nodeName && curDOM != outerDOM && (parent = curDOM.parentNode) && parent.nodeName.toLowerCase() == deco.nodeName) {
        curDOM = parent;
      } else {
        parent = document.createElement(deco.nodeName);
        parent.pmIsDeco = true;
        parent.appendChild(curDOM);
        prev2 = noDeco[0];
        curDOM = parent;
      }
    }
    patchAttributes(curDOM, prev2 || noDeco[0], deco);
  }
  return curDOM;
}
__name(patchOuterDeco, "patchOuterDeco");
function patchAttributes(dom, prev2, cur) {
  for (let name2 in prev2)
    if (name2 != "class" && name2 != "style" && name2 != "nodeName" && !(name2 in cur))
      dom.removeAttribute(name2);
  for (let name2 in cur)
    if (name2 != "class" && name2 != "style" && name2 != "nodeName" && cur[name2] != prev2[name2])
      dom.setAttribute(name2, cur[name2]);
  if (prev2.class != cur.class) {
    let prevList = prev2.class ? prev2.class.split(" ").filter(Boolean) : [];
    let curList = cur.class ? cur.class.split(" ").filter(Boolean) : [];
    for (let i2 = 0; i2 < prevList.length; i2++)
      if (curList.indexOf(prevList[i2]) == -1)
        dom.classList.remove(prevList[i2]);
    for (let i2 = 0; i2 < curList.length; i2++)
      if (prevList.indexOf(curList[i2]) == -1)
        dom.classList.add(curList[i2]);
    if (dom.classList.length == 0)
      dom.removeAttribute("class");
  }
  if (prev2.style != cur.style) {
    if (prev2.style) {
      let prop2 = /\s*([\w\-\xa1-\uffff]+)\s*:(?:"(?:\\.|[^"])*"|'(?:\\.|[^'])*'|\(.*?\)|[^;])*/g, m2;
      while (m2 = prop2.exec(prev2.style))
        dom.style.removeProperty(m2[1]);
    }
    if (cur.style)
      dom.style.cssText += cur.style;
  }
}
__name(patchAttributes, "patchAttributes");
function applyOuterDeco(dom, deco, node3) {
  return patchOuterDeco(dom, dom, noDeco, computeOuterDeco(deco, node3, dom.nodeType != 1));
}
__name(applyOuterDeco, "applyOuterDeco");
function sameOuterDeco(a2, b2) {
  if (a2.length != b2.length)
    return false;
  for (let i2 = 0; i2 < a2.length; i2++)
    if (!a2[i2].type.eq(b2[i2].type))
      return false;
  return true;
}
__name(sameOuterDeco, "sameOuterDeco");
function rm(dom) {
  let next2 = dom.nextSibling;
  dom.parentNode.removeChild(dom);
  return next2;
}
__name(rm, "rm");
class ViewTreeUpdater {
  static {
    __name(this, "ViewTreeUpdater");
  }
  constructor(top, lock, view) {
    this.lock = lock;
    this.view = view;
    this.index = 0;
    this.stack = [];
    this.changed = false;
    this.top = top;
    this.preMatch = preMatch(top.node.content, top);
  }
  // Destroy and remove the children between the given indices in
  // `this.top`.
  destroyBetween(start2, end) {
    if (start2 == end)
      return;
    for (let i2 = start2; i2 < end; i2++)
      this.top.children[i2].destroy();
    this.top.children.splice(start2, end - start2);
    this.changed = true;
  }
  // Destroy all remaining children in `this.top`.
  destroyRest() {
    this.destroyBetween(this.index, this.top.children.length);
  }
  // Sync the current stack of mark descs with the given array of
  // marks, reusing existing mark descs when possible.
  syncToMarks(marks, inline3, view) {
    let keep = 0, depth = this.stack.length >> 1;
    let maxKeep = Math.min(depth, marks.length);
    while (keep < maxKeep && (keep == depth - 1 ? this.top : this.stack[keep + 1 << 1]).matchesMark(marks[keep]) && marks[keep].type.spec.spanning !== false)
      keep++;
    while (keep < depth) {
      this.destroyRest();
      this.top.dirty = NOT_DIRTY;
      this.index = this.stack.pop();
      this.top = this.stack.pop();
      depth--;
    }
    while (depth < marks.length) {
      this.stack.push(this.top, this.index + 1);
      let found2 = -1;
      for (let i2 = this.index; i2 < Math.min(this.index + 3, this.top.children.length); i2++) {
        let next2 = this.top.children[i2];
        if (next2.matchesMark(marks[depth]) && !this.isLocked(next2.dom)) {
          found2 = i2;
          break;
        }
      }
      if (found2 > -1) {
        if (found2 > this.index) {
          this.changed = true;
          this.destroyBetween(this.index, found2);
        }
        this.top = this.top.children[this.index];
      } else {
        let markDesc = MarkViewDesc.create(this.top, marks[depth], inline3, view);
        this.top.children.splice(this.index, 0, markDesc);
        this.top = markDesc;
        this.changed = true;
      }
      this.index = 0;
      depth++;
    }
  }
  // Try to find a node desc matching the given data. Skip over it and
  // return true when successful.
  findNodeMatch(node3, outerDeco, innerDeco, index2) {
    let found2 = -1, targetDesc;
    if (index2 >= this.preMatch.index && (targetDesc = this.preMatch.matches[index2 - this.preMatch.index]).parent == this.top && targetDesc.matchesNode(node3, outerDeco, innerDeco)) {
      found2 = this.top.children.indexOf(targetDesc, this.index);
    } else {
      for (let i2 = this.index, e2 = Math.min(this.top.children.length, i2 + 5); i2 < e2; i2++) {
        let child = this.top.children[i2];
        if (child.matchesNode(node3, outerDeco, innerDeco) && !this.preMatch.matched.has(child)) {
          found2 = i2;
          break;
        }
      }
    }
    if (found2 < 0)
      return false;
    this.destroyBetween(this.index, found2);
    this.index++;
    return true;
  }
  updateNodeAt(node3, outerDeco, innerDeco, index2, view) {
    let child = this.top.children[index2];
    if (child.dirty == NODE_DIRTY && child.dom == child.contentDOM)
      child.dirty = CONTENT_DIRTY;
    if (!child.update(node3, outerDeco, innerDeco, view))
      return false;
    this.destroyBetween(this.index, index2);
    this.index++;
    return true;
  }
  findIndexWithChild(domNode) {
    for (; ; ) {
      let parent = domNode.parentNode;
      if (!parent)
        return -1;
      if (parent == this.top.contentDOM) {
        let desc = domNode.pmViewDesc;
        if (desc)
          for (let i2 = this.index; i2 < this.top.children.length; i2++) {
            if (this.top.children[i2] == desc)
              return i2;
          }
        return -1;
      }
      domNode = parent;
    }
  }
  // Try to update the next node, if any, to the given data. Checks
  // pre-matches to avoid overwriting nodes that could still be used.
  updateNextNode(node3, outerDeco, innerDeco, view, index2, pos) {
    for (let i2 = this.index; i2 < this.top.children.length; i2++) {
      let next2 = this.top.children[i2];
      if (next2 instanceof NodeViewDesc) {
        let preMatch2 = this.preMatch.matched.get(next2);
        if (preMatch2 != null && preMatch2 != index2)
          return false;
        let nextDOM = next2.dom, updated17;
        let locked = this.isLocked(nextDOM) && !(node3.isText && next2.node && next2.node.isText && next2.nodeDOM.nodeValue == node3.text && next2.dirty != NODE_DIRTY && sameOuterDeco(outerDeco, next2.outerDeco));
        if (!locked && next2.update(node3, outerDeco, innerDeco, view)) {
          this.destroyBetween(this.index, i2);
          if (next2.dom != nextDOM)
            this.changed = true;
          this.index++;
          return true;
        } else if (!locked && (updated17 = this.recreateWrapper(next2, node3, outerDeco, innerDeco, view, pos))) {
          this.destroyBetween(this.index, i2);
          this.top.children[this.index] = updated17;
          if (updated17.contentDOM) {
            updated17.dirty = CONTENT_DIRTY;
            updated17.updateChildren(view, pos + 1);
            updated17.dirty = NOT_DIRTY;
          }
          this.changed = true;
          this.index++;
          return true;
        }
        break;
      }
    }
    return false;
  }
  // When a node with content is replaced by a different node with
  // identical content, move over its children.
  recreateWrapper(next2, node3, outerDeco, innerDeco, view, pos) {
    if (next2.dirty || node3.isAtom || !next2.children.length || !next2.node.content.eq(node3.content) || !sameOuterDeco(outerDeco, next2.outerDeco) || !innerDeco.eq(next2.innerDeco))
      return null;
    let wrapper = NodeViewDesc.create(this.top, node3, outerDeco, innerDeco, view, pos);
    if (wrapper.contentDOM) {
      wrapper.children = next2.children;
      next2.children = [];
      for (let ch of wrapper.children)
        ch.parent = wrapper;
    }
    next2.destroy();
    return wrapper;
  }
  // Insert the node as a newly created node desc.
  addNode(node3, outerDeco, innerDeco, view, pos) {
    let desc = NodeViewDesc.create(this.top, node3, outerDeco, innerDeco, view, pos);
    if (desc.contentDOM)
      desc.updateChildren(view, pos + 1);
    this.top.children.splice(this.index++, 0, desc);
    this.changed = true;
  }
  placeWidget(widget, view, pos) {
    let next2 = this.index < this.top.children.length ? this.top.children[this.index] : null;
    if (next2 && next2.matchesWidget(widget) && (widget == next2.widget || !next2.widget.type.toDOM.parentNode)) {
      this.index++;
    } else {
      let desc = new WidgetViewDesc(this.top, widget, view, pos);
      this.top.children.splice(this.index++, 0, desc);
      this.changed = true;
    }
  }
  // Make sure a textblock looks and behaves correctly in
  // contentEditable.
  addTextblockHacks() {
    let lastChild = this.top.children[this.index - 1], parent = this.top;
    while (lastChild instanceof MarkViewDesc) {
      parent = lastChild;
      lastChild = parent.children[parent.children.length - 1];
    }
    if (!lastChild || // Empty textblock
    !(lastChild instanceof TextViewDesc) || /\n$/.test(lastChild.node.text) || this.view.requiresGeckoHackNode && /\s$/.test(lastChild.node.text)) {
      if ((safari || chrome) && lastChild && lastChild.dom.contentEditable == "false")
        this.addHackNode("IMG", parent);
      this.addHackNode("BR", this.top);
    }
  }
  addHackNode(nodeName, parent) {
    if (parent == this.top && this.index < parent.children.length && parent.children[this.index].matchesHack(nodeName)) {
      this.index++;
    } else {
      let dom = document.createElement(nodeName);
      if (nodeName == "IMG") {
        dom.className = "ProseMirror-separator";
        dom.alt = "";
      }
      if (nodeName == "BR")
        dom.className = "ProseMirror-trailingBreak";
      let hack = new TrailingHackViewDesc(this.top, [], dom, null);
      if (parent != this.top)
        parent.children.push(hack);
      else
        parent.children.splice(this.index++, 0, hack);
      this.changed = true;
    }
  }
  isLocked(node3) {
    return this.lock && (node3 == this.lock || node3.nodeType == 1 && node3.contains(this.lock.parentNode));
  }
}
function preMatch(frag, parentDesc) {
  let curDesc = parentDesc, descI = curDesc.children.length;
  let fI = frag.childCount, matched = /* @__PURE__ */ new Map(), matches2 = [];
  outer: while (fI > 0) {
    let desc;
    for (; ; ) {
      if (descI) {
        let next2 = curDesc.children[descI - 1];
        if (next2 instanceof MarkViewDesc) {
          curDesc = next2;
          descI = next2.children.length;
        } else {
          desc = next2;
          descI--;
          break;
        }
      } else if (curDesc == parentDesc) {
        break outer;
      } else {
        descI = curDesc.parent.children.indexOf(curDesc);
        curDesc = curDesc.parent;
      }
    }
    let node3 = desc.node;
    if (!node3)
      continue;
    if (node3 != frag.child(fI - 1))
      break;
    --fI;
    matched.set(desc, fI);
    matches2.push(desc);
  }
  return { index: fI, matched, matches: matches2.reverse() };
}
__name(preMatch, "preMatch");
function compareSide(a2, b2) {
  return a2.type.side - b2.type.side;
}
__name(compareSide, "compareSide");
function iterDeco(parent, deco, onWidget, onNode) {
  let locals = deco.locals(parent), offset = 0;
  if (locals.length == 0) {
    for (let i2 = 0; i2 < parent.childCount; i2++) {
      let child = parent.child(i2);
      onNode(child, locals, deco.forChild(offset, child), i2);
      offset += child.nodeSize;
    }
    return;
  }
  let decoIndex = 0, active4 = [], restNode = null;
  for (let parentIndex = 0; ; ) {
    let widget, widgets;
    while (decoIndex < locals.length && locals[decoIndex].to == offset) {
      let next2 = locals[decoIndex++];
      if (next2.widget) {
        if (!widget)
          widget = next2;
        else
          (widgets || (widgets = [widget])).push(next2);
      }
    }
    if (widget) {
      if (widgets) {
        widgets.sort(compareSide);
        for (let i2 = 0; i2 < widgets.length; i2++)
          onWidget(widgets[i2], parentIndex, !!restNode);
      } else {
        onWidget(widget, parentIndex, !!restNode);
      }
    }
    let child, index2;
    if (restNode) {
      index2 = -1;
      child = restNode;
      restNode = null;
    } else if (parentIndex < parent.childCount) {
      index2 = parentIndex;
      child = parent.child(parentIndex++);
    } else {
      break;
    }
    for (let i2 = 0; i2 < active4.length; i2++)
      if (active4[i2].to <= offset)
        active4.splice(i2--, 1);
    while (decoIndex < locals.length && locals[decoIndex].from <= offset && locals[decoIndex].to > offset)
      active4.push(locals[decoIndex++]);
    let end = offset + child.nodeSize;
    if (child.isText) {
      let cutAt = end;
      if (decoIndex < locals.length && locals[decoIndex].from < cutAt)
        cutAt = locals[decoIndex].from;
      for (let i2 = 0; i2 < active4.length; i2++)
        if (active4[i2].to < cutAt)
          cutAt = active4[i2].to;
      if (cutAt < end) {
        restNode = child.cut(cutAt - offset);
        child = child.cut(0, cutAt - offset);
        end = cutAt;
        index2 = -1;
      }
    } else {
      while (decoIndex < locals.length && locals[decoIndex].to < end)
        decoIndex++;
    }
    let outerDeco = child.isInline && !child.isLeaf ? active4.filter((d2) => !d2.inline) : active4.slice();
    onNode(child, outerDeco, deco.forChild(offset, child), index2);
    offset = end;
  }
}
__name(iterDeco, "iterDeco");
function iosHacks(dom) {
  if (dom.nodeName == "UL" || dom.nodeName == "OL") {
    let oldCSS = dom.style.cssText;
    dom.style.cssText = oldCSS + "; list-style: square !important";
    window.getComputedStyle(dom).listStyle;
    dom.style.cssText = oldCSS;
  }
}
__name(iosHacks, "iosHacks");
function findTextInFragment(frag, text2, from2, to) {
  for (let i2 = 0, pos = 0; i2 < frag.childCount && pos <= to; ) {
    let child = frag.child(i2++), childStart = pos;
    pos += child.nodeSize;
    if (!child.isText)
      continue;
    let str = child.text;
    while (i2 < frag.childCount) {
      let next2 = frag.child(i2++);
      pos += next2.nodeSize;
      if (!next2.isText)
        break;
      str += next2.text;
    }
    if (pos >= from2) {
      if (pos >= to && str.slice(to - text2.length - childStart, to - childStart) == text2)
        return to - text2.length;
      let found2 = childStart < to ? str.lastIndexOf(text2, to - childStart - 1) : -1;
      if (found2 >= 0 && found2 + text2.length + childStart >= from2)
        return childStart + found2;
      if (from2 == to && str.length >= to + text2.length - childStart && str.slice(to - childStart, to - childStart + text2.length) == text2)
        return to;
    }
  }
  return -1;
}
__name(findTextInFragment, "findTextInFragment");
function replaceNodes(nodes, from2, to, view, replacement) {
  let result = [];
  for (let i2 = 0, off = 0; i2 < nodes.length; i2++) {
    let child = nodes[i2], start2 = off, end = off += child.size;
    if (start2 >= to || end <= from2) {
      result.push(child);
    } else {
      if (start2 < from2)
        result.push(child.slice(0, from2 - start2, view));
      if (replacement) {
        result.push(replacement);
        replacement = void 0;
      }
      if (end > to)
        result.push(child.slice(to - start2, child.size, view));
    }
  }
  return result;
}
__name(replaceNodes, "replaceNodes");
function selectionFromDOM(view, origin2 = null) {
  let domSel = view.domSelectionRange(), doc2 = view.state.doc;
  if (!domSel.focusNode)
    return null;
  let nearestDesc = view.docView.nearestDesc(domSel.focusNode), inWidget = nearestDesc && nearestDesc.size == 0;
  let head = view.docView.posFromDOM(domSel.focusNode, domSel.focusOffset, 1);
  if (head < 0)
    return null;
  let $head = doc2.resolve(head), anchor, selection;
  if (selectionCollapsed(domSel)) {
    anchor = head;
    while (nearestDesc && !nearestDesc.node)
      nearestDesc = nearestDesc.parent;
    let nearestDescNode = nearestDesc.node;
    if (nearestDesc && nearestDescNode.isAtom && NodeSelection.isSelectable(nearestDescNode) && nearestDesc.parent && !(nearestDescNode.isInline && isOnEdge(domSel.focusNode, domSel.focusOffset, nearestDesc.dom))) {
      let pos = nearestDesc.posBefore;
      selection = new NodeSelection(head == pos ? $head : doc2.resolve(pos));
    }
  } else {
    if (domSel instanceof view.dom.ownerDocument.defaultView.Selection && domSel.rangeCount > 1) {
      let min = head, max = head;
      for (let i2 = 0; i2 < domSel.rangeCount; i2++) {
        let range2 = domSel.getRangeAt(i2);
        min = Math.min(min, view.docView.posFromDOM(range2.startContainer, range2.startOffset, 1));
        max = Math.max(max, view.docView.posFromDOM(range2.endContainer, range2.endOffset, -1));
      }
      if (min < 0)
        return null;
      [anchor, head] = max == view.state.selection.anchor ? [max, min] : [min, max];
      $head = doc2.resolve(head);
    } else {
      anchor = view.docView.posFromDOM(domSel.anchorNode, domSel.anchorOffset, 1);
    }
    if (anchor < 0)
      return null;
  }
  let $anchor = doc2.resolve(anchor);
  if (!selection) {
    let bias = origin2 == "pointer" || view.state.selection.head < $head.pos && !inWidget ? 1 : -1;
    selection = selectionBetween(view, $anchor, $head, bias);
  }
  return selection;
}
__name(selectionFromDOM, "selectionFromDOM");
function editorOwnsSelection(view) {
  return view.editable ? view.hasFocus() : hasSelection(view) && document.activeElement && document.activeElement.contains(view.dom);
}
__name(editorOwnsSelection, "editorOwnsSelection");
function selectionToDOM(view, force = false) {
  let sel = view.state.selection;
  syncNodeSelection(view, sel);
  if (!editorOwnsSelection(view))
    return;
  if (!force && view.input.mouseDown && view.input.mouseDown.allowDefault && chrome) {
    let domSel = view.domSelectionRange(), curSel = view.domObserver.currentSelection;
    if (domSel.anchorNode && curSel.anchorNode && isEquivalentPosition(domSel.anchorNode, domSel.anchorOffset, curSel.anchorNode, curSel.anchorOffset)) {
      view.input.mouseDown.delayedSelectionSync = true;
      view.domObserver.setCurSelection();
      return;
    }
  }
  view.domObserver.disconnectSelection();
  if (view.cursorWrapper) {
    selectCursorWrapper(view);
  } else {
    let { anchor, head } = sel, resetEditableFrom, resetEditableTo;
    if (brokenSelectBetweenUneditable && !(sel instanceof TextSelection)) {
      if (!sel.$from.parent.inlineContent)
        resetEditableFrom = temporarilyEditableNear(view, sel.from);
      if (!sel.empty && !sel.$from.parent.inlineContent)
        resetEditableTo = temporarilyEditableNear(view, sel.to);
    }
    view.docView.setSelection(anchor, head, view, force);
    if (brokenSelectBetweenUneditable) {
      if (resetEditableFrom)
        resetEditable(resetEditableFrom);
      if (resetEditableTo)
        resetEditable(resetEditableTo);
    }
    if (sel.visible) {
      view.dom.classList.remove("ProseMirror-hideselection");
    } else {
      view.dom.classList.add("ProseMirror-hideselection");
      if ("onselectionchange" in document)
        removeClassOnSelectionChange(view);
    }
  }
  view.domObserver.setCurSelection();
  view.domObserver.connectSelection();
}
__name(selectionToDOM, "selectionToDOM");
const brokenSelectBetweenUneditable = safari || chrome && chrome_version < 63;
function temporarilyEditableNear(view, pos) {
  let { node: node3, offset } = view.docView.domFromPos(pos, 0);
  let after = offset < node3.childNodes.length ? node3.childNodes[offset] : null;
  let before = offset ? node3.childNodes[offset - 1] : null;
  if (safari && after && after.contentEditable == "false")
    return setEditable(after);
  if ((!after || after.contentEditable == "false") && (!before || before.contentEditable == "false")) {
    if (after)
      return setEditable(after);
    else if (before)
      return setEditable(before);
  }
}
__name(temporarilyEditableNear, "temporarilyEditableNear");
function setEditable(element) {
  element.contentEditable = "true";
  if (safari && element.draggable) {
    element.draggable = false;
    element.wasDraggable = true;
  }
  return element;
}
__name(setEditable, "setEditable");
function resetEditable(element) {
  element.contentEditable = "false";
  if (element.wasDraggable) {
    element.draggable = true;
    element.wasDraggable = null;
  }
}
__name(resetEditable, "resetEditable");
function removeClassOnSelectionChange(view) {
  let doc2 = view.dom.ownerDocument;
  doc2.removeEventListener("selectionchange", view.input.hideSelectionGuard);
  let domSel = view.domSelectionRange();
  let node3 = domSel.anchorNode, offset = domSel.anchorOffset;
  doc2.addEventListener("selectionchange", view.input.hideSelectionGuard = () => {
    if (domSel.anchorNode != node3 || domSel.anchorOffset != offset) {
      doc2.removeEventListener("selectionchange", view.input.hideSelectionGuard);
      setTimeout(() => {
        if (!editorOwnsSelection(view) || view.state.selection.visible)
          view.dom.classList.remove("ProseMirror-hideselection");
      }, 20);
    }
  });
}
__name(removeClassOnSelectionChange, "removeClassOnSelectionChange");
function selectCursorWrapper(view) {
  let domSel = view.domSelection(), range2 = document.createRange();
  if (!domSel)
    return;
  let node3 = view.cursorWrapper.dom, img = node3.nodeName == "IMG";
  if (img)
    range2.setStart(node3.parentNode, domIndex(node3) + 1);
  else
    range2.setStart(node3, 0);
  range2.collapse(true);
  domSel.removeAllRanges();
  domSel.addRange(range2);
  if (!img && !view.state.selection.visible && ie$1 && ie_version <= 11) {
    node3.disabled = true;
    node3.disabled = false;
  }
}
__name(selectCursorWrapper, "selectCursorWrapper");
function syncNodeSelection(view, sel) {
  if (sel instanceof NodeSelection) {
    let desc = view.docView.descAt(sel.from);
    if (desc != view.lastSelectedViewDesc) {
      clearNodeSelection(view);
      if (desc)
        desc.selectNode();
      view.lastSelectedViewDesc = desc;
    }
  } else {
    clearNodeSelection(view);
  }
}
__name(syncNodeSelection, "syncNodeSelection");
function clearNodeSelection(view) {
  if (view.lastSelectedViewDesc) {
    if (view.lastSelectedViewDesc.parent)
      view.lastSelectedViewDesc.deselectNode();
    view.lastSelectedViewDesc = void 0;
  }
}
__name(clearNodeSelection, "clearNodeSelection");
function selectionBetween(view, $anchor, $head, bias) {
  return view.someProp("createSelectionBetween", (f2) => f2(view, $anchor, $head)) || TextSelection.between($anchor, $head, bias);
}
__name(selectionBetween, "selectionBetween");
function hasFocusAndSelection(view) {
  if (view.editable && !view.hasFocus())
    return false;
  return hasSelection(view);
}
__name(hasFocusAndSelection, "hasFocusAndSelection");
function hasSelection(view) {
  let sel = view.domSelectionRange();
  if (!sel.anchorNode)
    return false;
  try {
    return view.dom.contains(sel.anchorNode.nodeType == 3 ? sel.anchorNode.parentNode : sel.anchorNode) && (view.editable || view.dom.contains(sel.focusNode.nodeType == 3 ? sel.focusNode.parentNode : sel.focusNode));
  } catch (_2) {
    return false;
  }
}
__name(hasSelection, "hasSelection");
function anchorInRightPlace(view) {
  let anchorDOM = view.docView.domFromPos(view.state.selection.anchor, 0);
  let domSel = view.domSelectionRange();
  return isEquivalentPosition(anchorDOM.node, anchorDOM.offset, domSel.anchorNode, domSel.anchorOffset);
}
__name(anchorInRightPlace, "anchorInRightPlace");
function moveSelectionBlock(state, dir) {
  let { $anchor, $head } = state.selection;
  let $side = dir > 0 ? $anchor.max($head) : $anchor.min($head);
  let $start = !$side.parent.inlineContent ? $side : $side.depth ? state.doc.resolve(dir > 0 ? $side.after() : $side.before()) : null;
  return $start && Selection.findFrom($start, dir);
}
__name(moveSelectionBlock, "moveSelectionBlock");
function apply(view, sel) {
  view.dispatch(view.state.tr.setSelection(sel).scrollIntoView());
  return true;
}
__name(apply, "apply");
function selectHorizontally(view, dir, mods) {
  let sel = view.state.selection;
  if (sel instanceof TextSelection) {
    if (mods.indexOf("s") > -1) {
      let { $head } = sel, node3 = $head.textOffset ? null : dir < 0 ? $head.nodeBefore : $head.nodeAfter;
      if (!node3 || node3.isText || !node3.isLeaf)
        return false;
      let $newHead = view.state.doc.resolve($head.pos + node3.nodeSize * (dir < 0 ? -1 : 1));
      return apply(view, new TextSelection(sel.$anchor, $newHead));
    } else if (!sel.empty) {
      return false;
    } else if (view.endOfTextblock(dir > 0 ? "forward" : "backward")) {
      let next2 = moveSelectionBlock(view.state, dir);
      if (next2 && next2 instanceof NodeSelection)
        return apply(view, next2);
      return false;
    } else if (!(mac$3 && mods.indexOf("m") > -1)) {
      let $head = sel.$head, node3 = $head.textOffset ? null : dir < 0 ? $head.nodeBefore : $head.nodeAfter, desc;
      if (!node3 || node3.isText)
        return false;
      let nodePos = dir < 0 ? $head.pos - node3.nodeSize : $head.pos;
      if (!(node3.isAtom || (desc = view.docView.descAt(nodePos)) && !desc.contentDOM))
        return false;
      if (NodeSelection.isSelectable(node3)) {
        return apply(view, new NodeSelection(dir < 0 ? view.state.doc.resolve($head.pos - node3.nodeSize) : $head));
      } else if (webkit) {
        return apply(view, new TextSelection(view.state.doc.resolve(dir < 0 ? nodePos : nodePos + node3.nodeSize)));
      } else {
        return false;
      }
    }
  } else if (sel instanceof NodeSelection && sel.node.isInline) {
    return apply(view, new TextSelection(dir > 0 ? sel.$to : sel.$from));
  } else {
    let next2 = moveSelectionBlock(view.state, dir);
    if (next2)
      return apply(view, next2);
    return false;
  }
}
__name(selectHorizontally, "selectHorizontally");
function nodeLen(node3) {
  return node3.nodeType == 3 ? node3.nodeValue.length : node3.childNodes.length;
}
__name(nodeLen, "nodeLen");
function isIgnorable(dom, dir) {
  let desc = dom.pmViewDesc;
  return desc && desc.size == 0 && (dir < 0 || dom.nextSibling || dom.nodeName != "BR");
}
__name(isIgnorable, "isIgnorable");
function skipIgnoredNodes(view, dir) {
  return dir < 0 ? skipIgnoredNodesBefore(view) : skipIgnoredNodesAfter(view);
}
__name(skipIgnoredNodes, "skipIgnoredNodes");
function skipIgnoredNodesBefore(view) {
  let sel = view.domSelectionRange();
  let node3 = sel.focusNode, offset = sel.focusOffset;
  if (!node3)
    return;
  let moveNode, moveOffset, force = false;
  if (gecko && node3.nodeType == 1 && offset < nodeLen(node3) && isIgnorable(node3.childNodes[offset], -1))
    force = true;
  for (; ; ) {
    if (offset > 0) {
      if (node3.nodeType != 1) {
        break;
      } else {
        let before = node3.childNodes[offset - 1];
        if (isIgnorable(before, -1)) {
          moveNode = node3;
          moveOffset = --offset;
        } else if (before.nodeType == 3) {
          node3 = before;
          offset = node3.nodeValue.length;
        } else
          break;
      }
    } else if (isBlockNode(node3)) {
      break;
    } else {
      let prev2 = node3.previousSibling;
      while (prev2 && isIgnorable(prev2, -1)) {
        moveNode = node3.parentNode;
        moveOffset = domIndex(prev2);
        prev2 = prev2.previousSibling;
      }
      if (!prev2) {
        node3 = node3.parentNode;
        if (node3 == view.dom)
          break;
        offset = 0;
      } else {
        node3 = prev2;
        offset = nodeLen(node3);
      }
    }
  }
  if (force)
    setSelFocus(view, node3, offset);
  else if (moveNode)
    setSelFocus(view, moveNode, moveOffset);
}
__name(skipIgnoredNodesBefore, "skipIgnoredNodesBefore");
function skipIgnoredNodesAfter(view) {
  let sel = view.domSelectionRange();
  let node3 = sel.focusNode, offset = sel.focusOffset;
  if (!node3)
    return;
  let len = nodeLen(node3);
  let moveNode, moveOffset;
  for (; ; ) {
    if (offset < len) {
      if (node3.nodeType != 1)
        break;
      let after = node3.childNodes[offset];
      if (isIgnorable(after, 1)) {
        moveNode = node3;
        moveOffset = ++offset;
      } else
        break;
    } else if (isBlockNode(node3)) {
      break;
    } else {
      let next2 = node3.nextSibling;
      while (next2 && isIgnorable(next2, 1)) {
        moveNode = next2.parentNode;
        moveOffset = domIndex(next2) + 1;
        next2 = next2.nextSibling;
      }
      if (!next2) {
        node3 = node3.parentNode;
        if (node3 == view.dom)
          break;
        offset = len = 0;
      } else {
        node3 = next2;
        offset = 0;
        len = nodeLen(node3);
      }
    }
  }
  if (moveNode)
    setSelFocus(view, moveNode, moveOffset);
}
__name(skipIgnoredNodesAfter, "skipIgnoredNodesAfter");
function isBlockNode(dom) {
  let desc = dom.pmViewDesc;
  return desc && desc.node && desc.node.isBlock;
}
__name(isBlockNode, "isBlockNode");
function textNodeAfter(node3, offset) {
  while (node3 && offset == node3.childNodes.length && !hasBlockDesc(node3)) {
    offset = domIndex(node3) + 1;
    node3 = node3.parentNode;
  }
  while (node3 && offset < node3.childNodes.length) {
    let next2 = node3.childNodes[offset];
    if (next2.nodeType == 3)
      return next2;
    if (next2.nodeType == 1 && next2.contentEditable == "false")
      break;
    node3 = next2;
    offset = 0;
  }
}
__name(textNodeAfter, "textNodeAfter");
function textNodeBefore(node3, offset) {
  while (node3 && !offset && !hasBlockDesc(node3)) {
    offset = domIndex(node3);
    node3 = node3.parentNode;
  }
  while (node3 && offset) {
    let next2 = node3.childNodes[offset - 1];
    if (next2.nodeType == 3)
      return next2;
    if (next2.nodeType == 1 && next2.contentEditable == "false")
      break;
    node3 = next2;
    offset = node3.childNodes.length;
  }
}
__name(textNodeBefore, "textNodeBefore");
function setSelFocus(view, node3, offset) {
  if (node3.nodeType != 3) {
    let before, after;
    if (after = textNodeAfter(node3, offset)) {
      node3 = after;
      offset = 0;
    } else if (before = textNodeBefore(node3, offset)) {
      node3 = before;
      offset = before.nodeValue.length;
    }
  }
  let sel = view.domSelection();
  if (!sel)
    return;
  if (selectionCollapsed(sel)) {
    let range2 = document.createRange();
    range2.setEnd(node3, offset);
    range2.setStart(node3, offset);
    sel.removeAllRanges();
    sel.addRange(range2);
  } else if (sel.extend) {
    sel.extend(node3, offset);
  }
  view.domObserver.setCurSelection();
  let { state } = view;
  setTimeout(() => {
    if (view.state == state)
      selectionToDOM(view);
  }, 50);
}
__name(setSelFocus, "setSelFocus");
function findDirection(view, pos) {
  let $pos = view.state.doc.resolve(pos);
  if (!(chrome || windows) && $pos.parent.inlineContent) {
    let coords = view.coordsAtPos(pos);
    if (pos > $pos.start()) {
      let before = view.coordsAtPos(pos - 1);
      let mid = (before.top + before.bottom) / 2;
      if (mid > coords.top && mid < coords.bottom && Math.abs(before.left - coords.left) > 1)
        return before.left < coords.left ? "ltr" : "rtl";
    }
    if (pos < $pos.end()) {
      let after = view.coordsAtPos(pos + 1);
      let mid = (after.top + after.bottom) / 2;
      if (mid > coords.top && mid < coords.bottom && Math.abs(after.left - coords.left) > 1)
        return after.left > coords.left ? "ltr" : "rtl";
    }
  }
  let computed2 = getComputedStyle(view.dom).direction;
  return computed2 == "rtl" ? "rtl" : "ltr";
}
__name(findDirection, "findDirection");
function selectVertically(view, dir, mods) {
  let sel = view.state.selection;
  if (sel instanceof TextSelection && !sel.empty || mods.indexOf("s") > -1)
    return false;
  if (mac$3 && mods.indexOf("m") > -1)
    return false;
  let { $from, $to } = sel;
  if (!$from.parent.inlineContent || view.endOfTextblock(dir < 0 ? "up" : "down")) {
    let next2 = moveSelectionBlock(view.state, dir);
    if (next2 && next2 instanceof NodeSelection)
      return apply(view, next2);
  }
  if (!$from.parent.inlineContent) {
    let side = dir < 0 ? $from : $to;
    let beyond = sel instanceof AllSelection ? Selection.near(side, dir) : Selection.findFrom(side, dir);
    return beyond ? apply(view, beyond) : false;
  }
  return false;
}
__name(selectVertically, "selectVertically");
function stopNativeHorizontalDelete(view, dir) {
  if (!(view.state.selection instanceof TextSelection))
    return true;
  let { $head, $anchor, empty: empty2 } = view.state.selection;
  if (!$head.sameParent($anchor))
    return true;
  if (!empty2)
    return false;
  if (view.endOfTextblock(dir > 0 ? "forward" : "backward"))
    return true;
  let nextNode = !$head.textOffset && (dir < 0 ? $head.nodeBefore : $head.nodeAfter);
  if (nextNode && !nextNode.isText) {
    let tr2 = view.state.tr;
    if (dir < 0)
      tr2.delete($head.pos - nextNode.nodeSize, $head.pos);
    else
      tr2.delete($head.pos, $head.pos + nextNode.nodeSize);
    view.dispatch(tr2);
    return true;
  }
  return false;
}
__name(stopNativeHorizontalDelete, "stopNativeHorizontalDelete");
function switchEditable(view, node3, state) {
  view.domObserver.stop();
  node3.contentEditable = state;
  view.domObserver.start();
}
__name(switchEditable, "switchEditable");
function safariDownArrowBug(view) {
  if (!safari || view.state.selection.$head.parentOffset > 0)
    return false;
  let { focusNode: focusNode2, focusOffset } = view.domSelectionRange();
  if (focusNode2 && focusNode2.nodeType == 1 && focusOffset == 0 && focusNode2.firstChild && focusNode2.firstChild.contentEditable == "false") {
    let child = focusNode2.firstChild;
    switchEditable(view, child, "true");
    setTimeout(() => switchEditable(view, child, "false"), 20);
  }
  return false;
}
__name(safariDownArrowBug, "safariDownArrowBug");
function getMods(event) {
  let result = "";
  if (event.ctrlKey)
    result += "c";
  if (event.metaKey)
    result += "m";
  if (event.altKey)
    result += "a";
  if (event.shiftKey)
    result += "s";
  return result;
}
__name(getMods, "getMods");
function captureKeyDown(view, event) {
  let code2 = event.keyCode, mods = getMods(event);
  if (code2 == 8 || mac$3 && code2 == 72 && mods == "c") {
    return stopNativeHorizontalDelete(view, -1) || skipIgnoredNodes(view, -1);
  } else if (code2 == 46 && !event.shiftKey || mac$3 && code2 == 68 && mods == "c") {
    return stopNativeHorizontalDelete(view, 1) || skipIgnoredNodes(view, 1);
  } else if (code2 == 13 || code2 == 27) {
    return true;
  } else if (code2 == 37 || mac$3 && code2 == 66 && mods == "c") {
    let dir = code2 == 37 ? findDirection(view, view.state.selection.from) == "ltr" ? -1 : 1 : -1;
    return selectHorizontally(view, dir, mods) || skipIgnoredNodes(view, dir);
  } else if (code2 == 39 || mac$3 && code2 == 70 && mods == "c") {
    let dir = code2 == 39 ? findDirection(view, view.state.selection.from) == "ltr" ? 1 : -1 : 1;
    return selectHorizontally(view, dir, mods) || skipIgnoredNodes(view, dir);
  } else if (code2 == 38 || mac$3 && code2 == 80 && mods == "c") {
    return selectVertically(view, -1, mods) || skipIgnoredNodes(view, -1);
  } else if (code2 == 40 || mac$3 && code2 == 78 && mods == "c") {
    return safariDownArrowBug(view) || selectVertically(view, 1, mods) || skipIgnoredNodes(view, 1);
  } else if (mods == (mac$3 ? "m" : "c") && (code2 == 66 || code2 == 73 || code2 == 89 || code2 == 90)) {
    return true;
  }
  return false;
}
__name(captureKeyDown, "captureKeyDown");
function serializeForClipboard(view, slice2) {
  view.someProp("transformCopied", (f2) => {
    slice2 = f2(slice2, view);
  });
  let context = [], { content: content3, openStart, openEnd } = slice2;
  while (openStart > 1 && openEnd > 1 && content3.childCount == 1 && content3.firstChild.childCount == 1) {
    openStart--;
    openEnd--;
    let node3 = content3.firstChild;
    context.push(node3.type.name, node3.attrs != node3.type.defaultAttrs ? node3.attrs : null);
    content3 = node3.content;
  }
  let serializer = view.someProp("clipboardSerializer") || DOMSerializer.fromSchema(view.state.schema);
  let doc2 = detachedDoc(), wrap2 = doc2.createElement("div");
  wrap2.appendChild(serializer.serializeFragment(content3, { document: doc2 }));
  let firstChild = wrap2.firstChild, needsWrap, wrappers = 0;
  while (firstChild && firstChild.nodeType == 1 && (needsWrap = wrapMap[firstChild.nodeName.toLowerCase()])) {
    for (let i2 = needsWrap.length - 1; i2 >= 0; i2--) {
      let wrapper = doc2.createElement(needsWrap[i2]);
      while (wrap2.firstChild)
        wrapper.appendChild(wrap2.firstChild);
      wrap2.appendChild(wrapper);
      wrappers++;
    }
    firstChild = wrap2.firstChild;
  }
  if (firstChild && firstChild.nodeType == 1)
    firstChild.setAttribute("data-pm-slice", `${openStart} ${openEnd}${wrappers ? ` -${wrappers}` : ""} ${JSON.stringify(context)}`);
  let text2 = view.someProp("clipboardTextSerializer", (f2) => f2(slice2, view)) || slice2.content.textBetween(0, slice2.content.size, "\n\n");
  return { dom: wrap2, text: text2, slice: slice2 };
}
__name(serializeForClipboard, "serializeForClipboard");
function parseFromClipboard(view, text2, html, plainText, $context) {
  let inCode = $context.parent.type.spec.code;
  let dom, slice2;
  if (!html && !text2)
    return null;
  let asText = text2 && (plainText || inCode || !html);
  if (asText) {
    view.someProp("transformPastedText", (f2) => {
      text2 = f2(text2, inCode || plainText, view);
    });
    if (inCode)
      return text2 ? new Slice(Fragment.from(view.state.schema.text(text2.replace(/\r\n?/g, "\n"))), 0, 0) : Slice.empty;
    let parsed = view.someProp("clipboardTextParser", (f2) => f2(text2, $context, plainText, view));
    if (parsed) {
      slice2 = parsed;
    } else {
      let marks = $context.marks();
      let { schema: schema2 } = view.state, serializer = DOMSerializer.fromSchema(schema2);
      dom = document.createElement("div");
      text2.split(/(?:\r\n?|\n)+/).forEach((block3) => {
        let p2 = dom.appendChild(document.createElement("p"));
        if (block3)
          p2.appendChild(serializer.serializeNode(schema2.text(block3, marks)));
      });
    }
  } else {
    view.someProp("transformPastedHTML", (f2) => {
      html = f2(html, view);
    });
    dom = readHTML(html);
    if (webkit)
      restoreReplacedSpaces(dom);
  }
  let contextNode = dom && dom.querySelector("[data-pm-slice]");
  let sliceData = contextNode && /^(\d+) (\d+)(?: -(\d+))? (.*)/.exec(contextNode.getAttribute("data-pm-slice") || "");
  if (sliceData && sliceData[3])
    for (let i2 = +sliceData[3]; i2 > 0; i2--) {
      let child = dom.firstChild;
      while (child && child.nodeType != 1)
        child = child.nextSibling;
      if (!child)
        break;
      dom = child;
    }
  if (!slice2) {
    let parser = view.someProp("clipboardParser") || view.someProp("domParser") || DOMParser.fromSchema(view.state.schema);
    slice2 = parser.parseSlice(dom, {
      preserveWhitespace: !!(asText || sliceData),
      context: $context,
      ruleFromNode(dom2) {
        if (dom2.nodeName == "BR" && !dom2.nextSibling && dom2.parentNode && !inlineParents.test(dom2.parentNode.nodeName))
          return { ignore: true };
        return null;
      }
    });
  }
  if (sliceData) {
    slice2 = addContext(closeSlice(slice2, +sliceData[1], +sliceData[2]), sliceData[4]);
  } else {
    slice2 = Slice.maxOpen(normalizeSiblings(slice2.content, $context), true);
    if (slice2.openStart || slice2.openEnd) {
      let openStart = 0, openEnd = 0;
      for (let node3 = slice2.content.firstChild; openStart < slice2.openStart && !node3.type.spec.isolating; openStart++, node3 = node3.firstChild) {
      }
      for (let node3 = slice2.content.lastChild; openEnd < slice2.openEnd && !node3.type.spec.isolating; openEnd++, node3 = node3.lastChild) {
      }
      slice2 = closeSlice(slice2, openStart, openEnd);
    }
  }
  view.someProp("transformPasted", (f2) => {
    slice2 = f2(slice2, view);
  });
  return slice2;
}
__name(parseFromClipboard, "parseFromClipboard");
const inlineParents = /^(a|abbr|acronym|b|cite|code|del|em|i|ins|kbd|label|output|q|ruby|s|samp|span|strong|sub|sup|time|u|tt|var)$/i;
function normalizeSiblings(fragment, $context) {
  if (fragment.childCount < 2)
    return fragment;
  for (let d2 = $context.depth; d2 >= 0; d2--) {
    let parent = $context.node(d2);
    let match2 = parent.contentMatchAt($context.index(d2));
    let lastWrap, result = [];
    fragment.forEach((node3) => {
      if (!result)
        return;
      let wrap2 = match2.findWrapping(node3.type), inLast;
      if (!wrap2)
        return result = null;
      if (inLast = result.length && lastWrap.length && addToSibling(wrap2, lastWrap, node3, result[result.length - 1], 0)) {
        result[result.length - 1] = inLast;
      } else {
        if (result.length)
          result[result.length - 1] = closeRight(result[result.length - 1], lastWrap.length);
        let wrapped = withWrappers(node3, wrap2);
        result.push(wrapped);
        match2 = match2.matchType(wrapped.type);
        lastWrap = wrap2;
      }
    });
    if (result)
      return Fragment.from(result);
  }
  return fragment;
}
__name(normalizeSiblings, "normalizeSiblings");
function withWrappers(node3, wrap2, from2 = 0) {
  for (let i2 = wrap2.length - 1; i2 >= from2; i2--)
    node3 = wrap2[i2].create(null, Fragment.from(node3));
  return node3;
}
__name(withWrappers, "withWrappers");
function addToSibling(wrap2, lastWrap, node3, sibling, depth) {
  if (depth < wrap2.length && depth < lastWrap.length && wrap2[depth] == lastWrap[depth]) {
    let inner = addToSibling(wrap2, lastWrap, node3, sibling.lastChild, depth + 1);
    if (inner)
      return sibling.copy(sibling.content.replaceChild(sibling.childCount - 1, inner));
    let match2 = sibling.contentMatchAt(sibling.childCount);
    if (match2.matchType(depth == wrap2.length - 1 ? node3.type : wrap2[depth + 1]))
      return sibling.copy(sibling.content.append(Fragment.from(withWrappers(node3, wrap2, depth + 1))));
  }
}
__name(addToSibling, "addToSibling");
function closeRight(node3, depth) {
  if (depth == 0)
    return node3;
  let fragment = node3.content.replaceChild(node3.childCount - 1, closeRight(node3.lastChild, depth - 1));
  let fill2 = node3.contentMatchAt(node3.childCount).fillBefore(Fragment.empty, true);
  return node3.copy(fragment.append(fill2));
}
__name(closeRight, "closeRight");
function closeRange(fragment, side, from2, to, depth, openEnd) {
  let node3 = side < 0 ? fragment.firstChild : fragment.lastChild, inner = node3.content;
  if (fragment.childCount > 1)
    openEnd = 0;
  if (depth < to - 1)
    inner = closeRange(inner, side, from2, to, depth + 1, openEnd);
  if (depth >= from2)
    inner = side < 0 ? node3.contentMatchAt(0).fillBefore(inner, openEnd <= depth).append(inner) : inner.append(node3.contentMatchAt(node3.childCount).fillBefore(Fragment.empty, true));
  return fragment.replaceChild(side < 0 ? 0 : fragment.childCount - 1, node3.copy(inner));
}
__name(closeRange, "closeRange");
function closeSlice(slice2, openStart, openEnd) {
  if (openStart < slice2.openStart)
    slice2 = new Slice(closeRange(slice2.content, -1, openStart, slice2.openStart, 0, slice2.openEnd), openStart, slice2.openEnd);
  if (openEnd < slice2.openEnd)
    slice2 = new Slice(closeRange(slice2.content, 1, openEnd, slice2.openEnd, 0, 0), slice2.openStart, openEnd);
  return slice2;
}
__name(closeSlice, "closeSlice");
const wrapMap = {
  thead: ["table"],
  tbody: ["table"],
  tfoot: ["table"],
  caption: ["table"],
  colgroup: ["table"],
  col: ["table", "colgroup"],
  tr: ["table", "tbody"],
  td: ["table", "tbody", "tr"],
  th: ["table", "tbody", "tr"]
};
let _detachedDoc = null;
function detachedDoc() {
  return _detachedDoc || (_detachedDoc = document.implementation.createHTMLDocument("title"));
}
__name(detachedDoc, "detachedDoc");
let _policy = null;
function maybeWrapTrusted(html) {
  let trustedTypes = window.trustedTypes;
  if (!trustedTypes)
    return html;
  if (!_policy)
    _policy = trustedTypes.createPolicy("ProseMirrorClipboard", { createHTML: /* @__PURE__ */ __name((s2) => s2, "createHTML") });
  return _policy.createHTML(html);
}
__name(maybeWrapTrusted, "maybeWrapTrusted");
function readHTML(html) {
  let metas = /^(\s*<meta [^>]*>)*/.exec(html);
  if (metas)
    html = html.slice(metas[0].length);
  let elt = detachedDoc().createElement("div");
  let firstTag = /<([a-z][^>\s]+)/i.exec(html), wrap2;
  if (wrap2 = firstTag && wrapMap[firstTag[1].toLowerCase()])
    html = wrap2.map((n2) => "<" + n2 + ">").join("") + html + wrap2.map((n2) => "</" + n2 + ">").reverse().join("");
  elt.innerHTML = maybeWrapTrusted(html);
  if (wrap2)
    for (let i2 = 0; i2 < wrap2.length; i2++)
      elt = elt.querySelector(wrap2[i2]) || elt;
  return elt;
}
__name(readHTML, "readHTML");
function restoreReplacedSpaces(dom) {
  let nodes = dom.querySelectorAll(chrome ? "span:not([class]):not([style])" : "span.Apple-converted-space");
  for (let i2 = 0; i2 < nodes.length; i2++) {
    let node3 = nodes[i2];
    if (node3.childNodes.length == 1 && node3.textContent == " " && node3.parentNode)
      node3.parentNode.replaceChild(dom.ownerDocument.createTextNode(" "), node3);
  }
}
__name(restoreReplacedSpaces, "restoreReplacedSpaces");
function addContext(slice2, context) {
  if (!slice2.size)
    return slice2;
  let schema2 = slice2.content.firstChild.type.schema, array;
  try {
    array = JSON.parse(context);
  } catch (e2) {
    return slice2;
  }
  let { content: content3, openStart, openEnd } = slice2;
  for (let i2 = array.length - 2; i2 >= 0; i2 -= 2) {
    let type = schema2.nodes[array[i2]];
    if (!type || type.hasRequiredAttrs())
      break;
    content3 = Fragment.from(type.create(array[i2 + 1], content3));
    openStart++;
    openEnd++;
  }
  return new Slice(content3, openStart, openEnd);
}
__name(addContext, "addContext");
const handlers = {};
const editHandlers = {};
const passiveHandlers = { touchstart: true, touchmove: true };
class InputState {
  static {
    __name(this, "InputState");
  }
  constructor() {
    this.shiftKey = false;
    this.mouseDown = null;
    this.lastKeyCode = null;
    this.lastKeyCodeTime = 0;
    this.lastClick = { time: 0, x: 0, y: 0, type: "" };
    this.lastSelectionOrigin = null;
    this.lastSelectionTime = 0;
    this.lastIOSEnter = 0;
    this.lastIOSEnterFallbackTimeout = -1;
    this.lastFocus = 0;
    this.lastTouch = 0;
    this.lastChromeDelete = 0;
    this.composing = false;
    this.compositionNode = null;
    this.composingTimeout = -1;
    this.compositionNodes = [];
    this.compositionEndedAt = -2e8;
    this.compositionID = 1;
    this.compositionPendingChanges = 0;
    this.domChangeCount = 0;
    this.eventHandlers = /* @__PURE__ */ Object.create(null);
    this.hideSelectionGuard = null;
  }
}
function initInput(view) {
  for (let event in handlers) {
    let handler14 = handlers[event];
    view.dom.addEventListener(event, view.input.eventHandlers[event] = (event2) => {
      if (eventBelongsToView(view, event2) && !runCustomHandler(view, event2) && (view.editable || !(event2.type in editHandlers)))
        handler14(view, event2);
    }, passiveHandlers[event] ? { passive: true } : void 0);
  }
  if (safari)
    view.dom.addEventListener("input", () => null);
  ensureListeners(view);
}
__name(initInput, "initInput");
function setSelectionOrigin(view, origin2) {
  view.input.lastSelectionOrigin = origin2;
  view.input.lastSelectionTime = Date.now();
}
__name(setSelectionOrigin, "setSelectionOrigin");
function destroyInput(view) {
  view.domObserver.stop();
  for (let type in view.input.eventHandlers)
    view.dom.removeEventListener(type, view.input.eventHandlers[type]);
  clearTimeout(view.input.composingTimeout);
  clearTimeout(view.input.lastIOSEnterFallbackTimeout);
}
__name(destroyInput, "destroyInput");
function ensureListeners(view) {
  view.someProp("handleDOMEvents", (currentHandlers) => {
    for (let type in currentHandlers)
      if (!view.input.eventHandlers[type])
        view.dom.addEventListener(type, view.input.eventHandlers[type] = (event) => runCustomHandler(view, event));
  });
}
__name(ensureListeners, "ensureListeners");
function runCustomHandler(view, event) {
  return view.someProp("handleDOMEvents", (handlers2) => {
    let handler14 = handlers2[event.type];
    return handler14 ? handler14(view, event) || event.defaultPrevented : false;
  });
}
__name(runCustomHandler, "runCustomHandler");
function eventBelongsToView(view, event) {
  if (!event.bubbles)
    return true;
  if (event.defaultPrevented)
    return false;
  for (let node3 = event.target; node3 != view.dom; node3 = node3.parentNode)
    if (!node3 || node3.nodeType == 11 || node3.pmViewDesc && node3.pmViewDesc.stopEvent(event))
      return false;
  return true;
}
__name(eventBelongsToView, "eventBelongsToView");
function dispatchEvent(view, event) {
  if (!runCustomHandler(view, event) && handlers[event.type] && (view.editable || !(event.type in editHandlers)))
    handlers[event.type](view, event);
}
__name(dispatchEvent, "dispatchEvent");
editHandlers.keydown = (view, _event) => {
  let event = _event;
  view.input.shiftKey = event.keyCode == 16 || event.shiftKey;
  if (inOrNearComposition(view, event))
    return;
  view.input.lastKeyCode = event.keyCode;
  view.input.lastKeyCodeTime = Date.now();
  if (android && chrome && event.keyCode == 13)
    return;
  if (event.keyCode != 229)
    view.domObserver.forceFlush();
  if (ios && event.keyCode == 13 && !event.ctrlKey && !event.altKey && !event.metaKey) {
    let now2 = Date.now();
    view.input.lastIOSEnter = now2;
    view.input.lastIOSEnterFallbackTimeout = setTimeout(() => {
      if (view.input.lastIOSEnter == now2) {
        view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(13, "Enter")));
        view.input.lastIOSEnter = 0;
      }
    }, 200);
  } else if (view.someProp("handleKeyDown", (f2) => f2(view, event)) || captureKeyDown(view, event)) {
    event.preventDefault();
  } else {
    setSelectionOrigin(view, "key");
  }
};
editHandlers.keyup = (view, event) => {
  if (event.keyCode == 16)
    view.input.shiftKey = false;
};
editHandlers.keypress = (view, _event) => {
  let event = _event;
  if (inOrNearComposition(view, event) || !event.charCode || event.ctrlKey && !event.altKey || mac$3 && event.metaKey)
    return;
  if (view.someProp("handleKeyPress", (f2) => f2(view, event))) {
    event.preventDefault();
    return;
  }
  let sel = view.state.selection;
  if (!(sel instanceof TextSelection) || !sel.$from.sameParent(sel.$to)) {
    let text2 = String.fromCharCode(event.charCode);
    if (!/[\r\n]/.test(text2) && !view.someProp("handleTextInput", (f2) => f2(view, sel.$from.pos, sel.$to.pos, text2)))
      view.dispatch(view.state.tr.insertText(text2).scrollIntoView());
    event.preventDefault();
  }
};
function eventCoords(event) {
  return { left: event.clientX, top: event.clientY };
}
__name(eventCoords, "eventCoords");
function isNear(event, click2) {
  let dx = click2.x - event.clientX, dy = click2.y - event.clientY;
  return dx * dx + dy * dy < 100;
}
__name(isNear, "isNear");
function runHandlerOnContext(view, propName, pos, inside, event) {
  if (inside == -1)
    return false;
  let $pos = view.state.doc.resolve(inside);
  for (let i2 = $pos.depth + 1; i2 > 0; i2--) {
    if (view.someProp(propName, (f2) => i2 > $pos.depth ? f2(view, pos, $pos.nodeAfter, $pos.before(i2), event, true) : f2(view, pos, $pos.node(i2), $pos.before(i2), event, false)))
      return true;
  }
  return false;
}
__name(runHandlerOnContext, "runHandlerOnContext");
function updateSelection(view, selection, origin2) {
  if (!view.focused)
    view.focus();
  if (view.state.selection.eq(selection))
    return;
  let tr2 = view.state.tr.setSelection(selection);
  if (origin2 == "pointer")
    tr2.setMeta("pointer", true);
  view.dispatch(tr2);
}
__name(updateSelection, "updateSelection");
function selectClickedLeaf(view, inside) {
  if (inside == -1)
    return false;
  let $pos = view.state.doc.resolve(inside), node3 = $pos.nodeAfter;
  if (node3 && node3.isAtom && NodeSelection.isSelectable(node3)) {
    updateSelection(view, new NodeSelection($pos), "pointer");
    return true;
  }
  return false;
}
__name(selectClickedLeaf, "selectClickedLeaf");
function selectClickedNode(view, inside) {
  if (inside == -1)
    return false;
  let sel = view.state.selection, selectedNode, selectAt;
  if (sel instanceof NodeSelection)
    selectedNode = sel.node;
  let $pos = view.state.doc.resolve(inside);
  for (let i2 = $pos.depth + 1; i2 > 0; i2--) {
    let node3 = i2 > $pos.depth ? $pos.nodeAfter : $pos.node(i2);
    if (NodeSelection.isSelectable(node3)) {
      if (selectedNode && sel.$from.depth > 0 && i2 >= sel.$from.depth && $pos.before(sel.$from.depth + 1) == sel.$from.pos)
        selectAt = $pos.before(sel.$from.depth);
      else
        selectAt = $pos.before(i2);
      break;
    }
  }
  if (selectAt != null) {
    updateSelection(view, NodeSelection.create(view.state.doc, selectAt), "pointer");
    return true;
  } else {
    return false;
  }
}
__name(selectClickedNode, "selectClickedNode");
function handleSingleClick(view, pos, inside, event, selectNode) {
  return runHandlerOnContext(view, "handleClickOn", pos, inside, event) || view.someProp("handleClick", (f2) => f2(view, pos, event)) || (selectNode ? selectClickedNode(view, inside) : selectClickedLeaf(view, inside));
}
__name(handleSingleClick, "handleSingleClick");
function handleDoubleClick(view, pos, inside, event) {
  return runHandlerOnContext(view, "handleDoubleClickOn", pos, inside, event) || view.someProp("handleDoubleClick", (f2) => f2(view, pos, event));
}
__name(handleDoubleClick, "handleDoubleClick");
function handleTripleClick$1(view, pos, inside, event) {
  return runHandlerOnContext(view, "handleTripleClickOn", pos, inside, event) || view.someProp("handleTripleClick", (f2) => f2(view, pos, event)) || defaultTripleClick(view, inside, event);
}
__name(handleTripleClick$1, "handleTripleClick$1");
function defaultTripleClick(view, inside, event) {
  if (event.button != 0)
    return false;
  let doc2 = view.state.doc;
  if (inside == -1) {
    if (doc2.inlineContent) {
      updateSelection(view, TextSelection.create(doc2, 0, doc2.content.size), "pointer");
      return true;
    }
    return false;
  }
  let $pos = doc2.resolve(inside);
  for (let i2 = $pos.depth + 1; i2 > 0; i2--) {
    let node3 = i2 > $pos.depth ? $pos.nodeAfter : $pos.node(i2);
    let nodePos = $pos.before(i2);
    if (node3.inlineContent)
      updateSelection(view, TextSelection.create(doc2, nodePos + 1, nodePos + 1 + node3.content.size), "pointer");
    else if (NodeSelection.isSelectable(node3))
      updateSelection(view, NodeSelection.create(doc2, nodePos), "pointer");
    else
      continue;
    return true;
  }
}
__name(defaultTripleClick, "defaultTripleClick");
function forceDOMFlush(view) {
  return endComposition(view);
}
__name(forceDOMFlush, "forceDOMFlush");
const selectNodeModifier = mac$3 ? "metaKey" : "ctrlKey";
handlers.mousedown = (view, _event) => {
  let event = _event;
  view.input.shiftKey = event.shiftKey;
  let flushed = forceDOMFlush(view);
  let now2 = Date.now(), type = "singleClick";
  if (now2 - view.input.lastClick.time < 500 && isNear(event, view.input.lastClick) && !event[selectNodeModifier]) {
    if (view.input.lastClick.type == "singleClick")
      type = "doubleClick";
    else if (view.input.lastClick.type == "doubleClick")
      type = "tripleClick";
  }
  view.input.lastClick = { time: now2, x: event.clientX, y: event.clientY, type };
  let pos = view.posAtCoords(eventCoords(event));
  if (!pos)
    return;
  if (type == "singleClick") {
    if (view.input.mouseDown)
      view.input.mouseDown.done();
    view.input.mouseDown = new MouseDown(view, pos, event, !!flushed);
  } else if ((type == "doubleClick" ? handleDoubleClick : handleTripleClick$1)(view, pos.pos, pos.inside, event)) {
    event.preventDefault();
  } else {
    setSelectionOrigin(view, "pointer");
  }
};
class MouseDown {
  static {
    __name(this, "MouseDown");
  }
  constructor(view, pos, event, flushed) {
    this.view = view;
    this.pos = pos;
    this.event = event;
    this.flushed = flushed;
    this.delayedSelectionSync = false;
    this.mightDrag = null;
    this.startDoc = view.state.doc;
    this.selectNode = !!event[selectNodeModifier];
    this.allowDefault = event.shiftKey;
    let targetNode, targetPos;
    if (pos.inside > -1) {
      targetNode = view.state.doc.nodeAt(pos.inside);
      targetPos = pos.inside;
    } else {
      let $pos = view.state.doc.resolve(pos.pos);
      targetNode = $pos.parent;
      targetPos = $pos.depth ? $pos.before() : 0;
    }
    const target2 = flushed ? null : event.target;
    const targetDesc = target2 ? view.docView.nearestDesc(target2, true) : null;
    this.target = targetDesc && targetDesc.dom.nodeType == 1 ? targetDesc.dom : null;
    let { selection } = view.state;
    if (event.button == 0 && targetNode.type.spec.draggable && targetNode.type.spec.selectable !== false || selection instanceof NodeSelection && selection.from <= targetPos && selection.to > targetPos)
      this.mightDrag = {
        node: targetNode,
        pos: targetPos,
        addAttr: !!(this.target && !this.target.draggable),
        setUneditable: !!(this.target && gecko && !this.target.hasAttribute("contentEditable"))
      };
    if (this.target && this.mightDrag && (this.mightDrag.addAttr || this.mightDrag.setUneditable)) {
      this.view.domObserver.stop();
      if (this.mightDrag.addAttr)
        this.target.draggable = true;
      if (this.mightDrag.setUneditable)
        setTimeout(() => {
          if (this.view.input.mouseDown == this)
            this.target.setAttribute("contentEditable", "false");
        }, 20);
      this.view.domObserver.start();
    }
    view.root.addEventListener("mouseup", this.up = this.up.bind(this));
    view.root.addEventListener("mousemove", this.move = this.move.bind(this));
    setSelectionOrigin(view, "pointer");
  }
  done() {
    this.view.root.removeEventListener("mouseup", this.up);
    this.view.root.removeEventListener("mousemove", this.move);
    if (this.mightDrag && this.target) {
      this.view.domObserver.stop();
      if (this.mightDrag.addAttr)
        this.target.removeAttribute("draggable");
      if (this.mightDrag.setUneditable)
        this.target.removeAttribute("contentEditable");
      this.view.domObserver.start();
    }
    if (this.delayedSelectionSync)
      setTimeout(() => selectionToDOM(this.view));
    this.view.input.mouseDown = null;
  }
  up(event) {
    this.done();
    if (!this.view.dom.contains(event.target))
      return;
    let pos = this.pos;
    if (this.view.state.doc != this.startDoc)
      pos = this.view.posAtCoords(eventCoords(event));
    this.updateAllowDefault(event);
    if (this.allowDefault || !pos) {
      setSelectionOrigin(this.view, "pointer");
    } else if (handleSingleClick(this.view, pos.pos, pos.inside, event, this.selectNode)) {
      event.preventDefault();
    } else if (event.button == 0 && (this.flushed || // Safari ignores clicks on draggable elements
    safari && this.mightDrag && !this.mightDrag.node.isAtom || // Chrome will sometimes treat a node selection as a
    // cursor, but still report that the node is selected
    // when asked through getSelection. You'll then get a
    // situation where clicking at the point where that
    // (hidden) cursor is doesn't change the selection, and
    // thus doesn't get a reaction from ProseMirror. This
    // works around that.
    chrome && !this.view.state.selection.visible && Math.min(Math.abs(pos.pos - this.view.state.selection.from), Math.abs(pos.pos - this.view.state.selection.to)) <= 2)) {
      updateSelection(this.view, Selection.near(this.view.state.doc.resolve(pos.pos)), "pointer");
      event.preventDefault();
    } else {
      setSelectionOrigin(this.view, "pointer");
    }
  }
  move(event) {
    this.updateAllowDefault(event);
    setSelectionOrigin(this.view, "pointer");
    if (event.buttons == 0)
      this.done();
  }
  updateAllowDefault(event) {
    if (!this.allowDefault && (Math.abs(this.event.x - event.clientX) > 4 || Math.abs(this.event.y - event.clientY) > 4))
      this.allowDefault = true;
  }
}
handlers.touchstart = (view) => {
  view.input.lastTouch = Date.now();
  forceDOMFlush(view);
  setSelectionOrigin(view, "pointer");
};
handlers.touchmove = (view) => {
  view.input.lastTouch = Date.now();
  setSelectionOrigin(view, "pointer");
};
handlers.contextmenu = (view) => forceDOMFlush(view);
function inOrNearComposition(view, event) {
  if (view.composing)
    return true;
  if (safari && Math.abs(event.timeStamp - view.input.compositionEndedAt) < 500) {
    view.input.compositionEndedAt = -2e8;
    return true;
  }
  return false;
}
__name(inOrNearComposition, "inOrNearComposition");
const timeoutComposition = android ? 5e3 : -1;
editHandlers.compositionstart = editHandlers.compositionupdate = (view) => {
  if (!view.composing) {
    view.domObserver.flush();
    let { state } = view, $pos = state.selection.$to;
    if (state.selection instanceof TextSelection && (state.storedMarks || !$pos.textOffset && $pos.parentOffset && $pos.nodeBefore.marks.some((m2) => m2.type.spec.inclusive === false))) {
      view.markCursor = view.state.storedMarks || $pos.marks();
      endComposition(view, true);
      view.markCursor = null;
    } else {
      endComposition(view, !state.selection.empty);
      if (gecko && state.selection.empty && $pos.parentOffset && !$pos.textOffset && $pos.nodeBefore.marks.length) {
        let sel = view.domSelectionRange();
        for (let node3 = sel.focusNode, offset = sel.focusOffset; node3 && node3.nodeType == 1 && offset != 0; ) {
          let before = offset < 0 ? node3.lastChild : node3.childNodes[offset - 1];
          if (!before)
            break;
          if (before.nodeType == 3) {
            let sel2 = view.domSelection();
            if (sel2)
              sel2.collapse(before, before.nodeValue.length);
            break;
          } else {
            node3 = before;
            offset = -1;
          }
        }
      }
    }
    view.input.composing = true;
  }
  scheduleComposeEnd(view, timeoutComposition);
};
editHandlers.compositionend = (view, event) => {
  if (view.composing) {
    view.input.composing = false;
    view.input.compositionEndedAt = event.timeStamp;
    view.input.compositionPendingChanges = view.domObserver.pendingRecords().length ? view.input.compositionID : 0;
    view.input.compositionNode = null;
    if (view.input.compositionPendingChanges)
      Promise.resolve().then(() => view.domObserver.flush());
    view.input.compositionID++;
    scheduleComposeEnd(view, 20);
  }
};
function scheduleComposeEnd(view, delay) {
  clearTimeout(view.input.composingTimeout);
  if (delay > -1)
    view.input.composingTimeout = setTimeout(() => endComposition(view), delay);
}
__name(scheduleComposeEnd, "scheduleComposeEnd");
function clearComposition(view) {
  if (view.composing) {
    view.input.composing = false;
    view.input.compositionEndedAt = timestampFromCustomEvent();
  }
  while (view.input.compositionNodes.length > 0)
    view.input.compositionNodes.pop().markParentsDirty();
}
__name(clearComposition, "clearComposition");
function findCompositionNode(view) {
  let sel = view.domSelectionRange();
  if (!sel.focusNode)
    return null;
  let textBefore = textNodeBefore$1(sel.focusNode, sel.focusOffset);
  let textAfter = textNodeAfter$1(sel.focusNode, sel.focusOffset);
  if (textBefore && textAfter && textBefore != textAfter) {
    let descAfter = textAfter.pmViewDesc, lastChanged = view.domObserver.lastChangedTextNode;
    if (textBefore == lastChanged || textAfter == lastChanged)
      return lastChanged;
    if (!descAfter || !descAfter.isText(textAfter.nodeValue)) {
      return textAfter;
    } else if (view.input.compositionNode == textAfter) {
      let descBefore = textBefore.pmViewDesc;
      if (!(!descBefore || !descBefore.isText(textBefore.nodeValue)))
        return textAfter;
    }
  }
  return textBefore || textAfter;
}
__name(findCompositionNode, "findCompositionNode");
function timestampFromCustomEvent() {
  let event = document.createEvent("Event");
  event.initEvent("event", true, true);
  return event.timeStamp;
}
__name(timestampFromCustomEvent, "timestampFromCustomEvent");
function endComposition(view, restarting = false) {
  if (android && view.domObserver.flushingSoon >= 0)
    return;
  view.domObserver.forceFlush();
  clearComposition(view);
  if (restarting || view.docView && view.docView.dirty) {
    let sel = selectionFromDOM(view);
    if (sel && !sel.eq(view.state.selection))
      view.dispatch(view.state.tr.setSelection(sel));
    else if ((view.markCursor || restarting) && !view.state.selection.empty)
      view.dispatch(view.state.tr.deleteSelection());
    else
      view.updateState(view.state);
    return true;
  }
  return false;
}
__name(endComposition, "endComposition");
function captureCopy(view, dom) {
  if (!view.dom.parentNode)
    return;
  let wrap2 = view.dom.parentNode.appendChild(document.createElement("div"));
  wrap2.appendChild(dom);
  wrap2.style.cssText = "position: fixed; left: -10000px; top: 10px";
  let sel = getSelection(), range2 = document.createRange();
  range2.selectNodeContents(dom);
  view.dom.blur();
  sel.removeAllRanges();
  sel.addRange(range2);
  setTimeout(() => {
    if (wrap2.parentNode)
      wrap2.parentNode.removeChild(wrap2);
    view.focus();
  }, 50);
}
__name(captureCopy, "captureCopy");
const brokenClipboardAPI = ie$1 && ie_version < 15 || ios && webkit_version < 604;
handlers.copy = editHandlers.cut = (view, _event) => {
  let event = _event;
  let sel = view.state.selection, cut2 = event.type == "cut";
  if (sel.empty)
    return;
  let data30 = brokenClipboardAPI ? null : event.clipboardData;
  let slice2 = sel.content(), { dom, text: text2 } = serializeForClipboard(view, slice2);
  if (data30) {
    event.preventDefault();
    data30.clearData();
    data30.setData("text/html", dom.innerHTML);
    data30.setData("text/plain", text2);
  } else {
    captureCopy(view, dom);
  }
  if (cut2)
    view.dispatch(view.state.tr.deleteSelection().scrollIntoView().setMeta("uiEvent", "cut"));
};
function sliceSingleNode(slice2) {
  return slice2.openStart == 0 && slice2.openEnd == 0 && slice2.content.childCount == 1 ? slice2.content.firstChild : null;
}
__name(sliceSingleNode, "sliceSingleNode");
function capturePaste(view, event) {
  if (!view.dom.parentNode)
    return;
  let plainText = view.input.shiftKey || view.state.selection.$from.parent.type.spec.code;
  let target2 = view.dom.parentNode.appendChild(document.createElement(plainText ? "textarea" : "div"));
  if (!plainText)
    target2.contentEditable = "true";
  target2.style.cssText = "position: fixed; left: -10000px; top: 10px";
  target2.focus();
  let plain = view.input.shiftKey && view.input.lastKeyCode != 45;
  setTimeout(() => {
    view.focus();
    if (target2.parentNode)
      target2.parentNode.removeChild(target2);
    if (plainText)
      doPaste(view, target2.value, null, plain, event);
    else
      doPaste(view, target2.textContent, target2.innerHTML, plain, event);
  }, 50);
}
__name(capturePaste, "capturePaste");
function doPaste(view, text2, html, preferPlain, event) {
  let slice2 = parseFromClipboard(view, text2, html, preferPlain, view.state.selection.$from);
  if (view.someProp("handlePaste", (f2) => f2(view, event, slice2 || Slice.empty)))
    return true;
  if (!slice2)
    return false;
  let singleNode = sliceSingleNode(slice2);
  let tr2 = singleNode ? view.state.tr.replaceSelectionWith(singleNode, preferPlain) : view.state.tr.replaceSelection(slice2);
  view.dispatch(tr2.scrollIntoView().setMeta("paste", true).setMeta("uiEvent", "paste"));
  return true;
}
__name(doPaste, "doPaste");
function getText$1(clipboardData) {
  let text2 = clipboardData.getData("text/plain") || clipboardData.getData("Text");
  if (text2)
    return text2;
  let uris = clipboardData.getData("text/uri-list");
  return uris ? uris.replace(/\r?\n/g, " ") : "";
}
__name(getText$1, "getText$1");
editHandlers.paste = (view, _event) => {
  let event = _event;
  if (view.composing && !android)
    return;
  let data30 = brokenClipboardAPI ? null : event.clipboardData;
  let plain = view.input.shiftKey && view.input.lastKeyCode != 45;
  if (data30 && doPaste(view, getText$1(data30), data30.getData("text/html"), plain, event))
    event.preventDefault();
  else
    capturePaste(view, event);
};
class Dragging {
  static {
    __name(this, "Dragging");
  }
  constructor(slice2, move, node3) {
    this.slice = slice2;
    this.move = move;
    this.node = node3;
  }
}
const dragCopyModifier = mac$3 ? "altKey" : "ctrlKey";
handlers.dragstart = (view, _event) => {
  let event = _event;
  let mouseDown = view.input.mouseDown;
  if (mouseDown)
    mouseDown.done();
  if (!event.dataTransfer)
    return;
  let sel = view.state.selection;
  let pos = sel.empty ? null : view.posAtCoords(eventCoords(event));
  let node3;
  if (pos && pos.pos >= sel.from && pos.pos <= (sel instanceof NodeSelection ? sel.to - 1 : sel.to)) ;
  else if (mouseDown && mouseDown.mightDrag) {
    node3 = NodeSelection.create(view.state.doc, mouseDown.mightDrag.pos);
  } else if (event.target && event.target.nodeType == 1) {
    let desc = view.docView.nearestDesc(event.target, true);
    if (desc && desc.node.type.spec.draggable && desc != view.docView)
      node3 = NodeSelection.create(view.state.doc, desc.posBefore);
  }
  let draggedSlice = (node3 || view.state.selection).content();
  let { dom, text: text2, slice: slice2 } = serializeForClipboard(view, draggedSlice);
  if (!event.dataTransfer.files.length || !chrome || chrome_version > 120)
    event.dataTransfer.clearData();
  event.dataTransfer.setData(brokenClipboardAPI ? "Text" : "text/html", dom.innerHTML);
  event.dataTransfer.effectAllowed = "copyMove";
  if (!brokenClipboardAPI)
    event.dataTransfer.setData("text/plain", text2);
  view.dragging = new Dragging(slice2, !event[dragCopyModifier], node3);
};
handlers.dragend = (view) => {
  let dragging = view.dragging;
  window.setTimeout(() => {
    if (view.dragging == dragging)
      view.dragging = null;
  }, 50);
};
editHandlers.dragover = editHandlers.dragenter = (_2, e2) => e2.preventDefault();
editHandlers.drop = (view, _event) => {
  let event = _event;
  let dragging = view.dragging;
  view.dragging = null;
  if (!event.dataTransfer)
    return;
  let eventPos = view.posAtCoords(eventCoords(event));
  if (!eventPos)
    return;
  let $mouse = view.state.doc.resolve(eventPos.pos);
  let slice2 = dragging && dragging.slice;
  if (slice2) {
    view.someProp("transformPasted", (f2) => {
      slice2 = f2(slice2, view);
    });
  } else {
    slice2 = parseFromClipboard(view, getText$1(event.dataTransfer), brokenClipboardAPI ? null : event.dataTransfer.getData("text/html"), false, $mouse);
  }
  let move = !!(dragging && !event[dragCopyModifier]);
  if (view.someProp("handleDrop", (f2) => f2(view, event, slice2 || Slice.empty, move))) {
    event.preventDefault();
    return;
  }
  if (!slice2)
    return;
  event.preventDefault();
  let insertPos = slice2 ? dropPoint(view.state.doc, $mouse.pos, slice2) : $mouse.pos;
  if (insertPos == null)
    insertPos = $mouse.pos;
  let tr2 = view.state.tr;
  if (move) {
    let { node: node3 } = dragging;
    if (node3)
      node3.replace(tr2);
    else
      tr2.deleteSelection();
  }
  let pos = tr2.mapping.map(insertPos);
  let isNode = slice2.openStart == 0 && slice2.openEnd == 0 && slice2.content.childCount == 1;
  let beforeInsert = tr2.doc;
  if (isNode)
    tr2.replaceRangeWith(pos, pos, slice2.content.firstChild);
  else
    tr2.replaceRange(pos, pos, slice2);
  if (tr2.doc.eq(beforeInsert))
    return;
  let $pos = tr2.doc.resolve(pos);
  if (isNode && NodeSelection.isSelectable(slice2.content.firstChild) && $pos.nodeAfter && $pos.nodeAfter.sameMarkup(slice2.content.firstChild)) {
    tr2.setSelection(new NodeSelection($pos));
  } else {
    let end = tr2.mapping.map(insertPos);
    tr2.mapping.maps[tr2.mapping.maps.length - 1].forEach((_from, _to, _newFrom, newTo) => end = newTo);
    tr2.setSelection(selectionBetween(view, $pos, tr2.doc.resolve(end)));
  }
  view.focus();
  view.dispatch(tr2.setMeta("uiEvent", "drop"));
};
handlers.focus = (view) => {
  view.input.lastFocus = Date.now();
  if (!view.focused) {
    view.domObserver.stop();
    view.dom.classList.add("ProseMirror-focused");
    view.domObserver.start();
    view.focused = true;
    setTimeout(() => {
      if (view.docView && view.hasFocus() && !view.domObserver.currentSelection.eq(view.domSelectionRange()))
        selectionToDOM(view);
    }, 20);
  }
};
handlers.blur = (view, _event) => {
  let event = _event;
  if (view.focused) {
    view.domObserver.stop();
    view.dom.classList.remove("ProseMirror-focused");
    view.domObserver.start();
    if (event.relatedTarget && view.dom.contains(event.relatedTarget))
      view.domObserver.currentSelection.clear();
    view.focused = false;
  }
};
handlers.beforeinput = (view, _event) => {
  let event = _event;
  if (chrome && android && event.inputType == "deleteContentBackward") {
    view.domObserver.flushSoon();
    let { domChangeCount } = view.input;
    setTimeout(() => {
      if (view.input.domChangeCount != domChangeCount)
        return;
      view.dom.blur();
      view.focus();
      if (view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(8, "Backspace"))))
        return;
      let { $cursor } = view.state.selection;
      if ($cursor && $cursor.pos > 0)
        view.dispatch(view.state.tr.delete($cursor.pos - 1, $cursor.pos).scrollIntoView());
    }, 50);
  }
};
for (let prop2 in editHandlers)
  handlers[prop2] = editHandlers[prop2];
function compareObjs(a2, b2) {
  if (a2 == b2)
    return true;
  for (let p2 in a2)
    if (a2[p2] !== b2[p2])
      return false;
  for (let p2 in b2)
    if (!(p2 in a2))
      return false;
  return true;
}
__name(compareObjs, "compareObjs");
class WidgetType {
  static {
    __name(this, "WidgetType");
  }
  constructor(toDOM, spec) {
    this.toDOM = toDOM;
    this.spec = spec || noSpec;
    this.side = this.spec.side || 0;
  }
  map(mapping, span, offset, oldOffset) {
    let { pos, deleted } = mapping.mapResult(span.from + oldOffset, this.side < 0 ? -1 : 1);
    return deleted ? null : new Decoration(pos - offset, pos - offset, this);
  }
  valid() {
    return true;
  }
  eq(other) {
    return this == other || other instanceof WidgetType && (this.spec.key && this.spec.key == other.spec.key || this.toDOM == other.toDOM && compareObjs(this.spec, other.spec));
  }
  destroy(node3) {
    if (this.spec.destroy)
      this.spec.destroy(node3);
  }
}
class InlineType {
  static {
    __name(this, "InlineType");
  }
  constructor(attrs7, spec) {
    this.attrs = attrs7;
    this.spec = spec || noSpec;
  }
  map(mapping, span, offset, oldOffset) {
    let from2 = mapping.map(span.from + oldOffset, this.spec.inclusiveStart ? -1 : 1) - offset;
    let to = mapping.map(span.to + oldOffset, this.spec.inclusiveEnd ? 1 : -1) - offset;
    return from2 >= to ? null : new Decoration(from2, to, this);
  }
  valid(_2, span) {
    return span.from < span.to;
  }
  eq(other) {
    return this == other || other instanceof InlineType && compareObjs(this.attrs, other.attrs) && compareObjs(this.spec, other.spec);
  }
  static is(span) {
    return span.type instanceof InlineType;
  }
  destroy() {
  }
}
class NodeType {
  static {
    __name(this, "NodeType");
  }
  constructor(attrs7, spec) {
    this.attrs = attrs7;
    this.spec = spec || noSpec;
  }
  map(mapping, span, offset, oldOffset) {
    let from2 = mapping.mapResult(span.from + oldOffset, 1);
    if (from2.deleted)
      return null;
    let to = mapping.mapResult(span.to + oldOffset, -1);
    if (to.deleted || to.pos <= from2.pos)
      return null;
    return new Decoration(from2.pos - offset, to.pos - offset, this);
  }
  valid(node3, span) {
    let { index: index2, offset } = node3.content.findIndex(span.from), child;
    return offset == span.from && !(child = node3.child(index2)).isText && offset + child.nodeSize == span.to;
  }
  eq(other) {
    return this == other || other instanceof NodeType && compareObjs(this.attrs, other.attrs) && compareObjs(this.spec, other.spec);
  }
  destroy() {
  }
}
class Decoration {
  static {
    __name(this, "Decoration");
  }
  /**
  @internal
  */
  constructor(from2, to, type) {
    this.from = from2;
    this.to = to;
    this.type = type;
  }
  /**
  @internal
  */
  copy(from2, to) {
    return new Decoration(from2, to, this.type);
  }
  /**
  @internal
  */
  eq(other, offset = 0) {
    return this.type.eq(other.type) && this.from + offset == other.from && this.to + offset == other.to;
  }
  /**
  @internal
  */
  map(mapping, offset, oldOffset) {
    return this.type.map(mapping, this, offset, oldOffset);
  }
  /**
  Creates a widget decoration, which is a DOM node that's shown in
  the document at the given position. It is recommended that you
  delay rendering the widget by passing a function that will be
  called when the widget is actually drawn in a view, but you can
  also directly pass a DOM node. `getPos` can be used to find the
  widget's current document position.
  */
  static widget(pos, toDOM, spec) {
    return new Decoration(pos, pos, new WidgetType(toDOM, spec));
  }
  /**
  Creates an inline decoration, which adds the given attributes to
  each inline node between `from` and `to`.
  */
  static inline(from2, to, attrs7, spec) {
    return new Decoration(from2, to, new InlineType(attrs7, spec));
  }
  /**
  Creates a node decoration. `from` and `to` should point precisely
  before and after a node in the document. That node, and only that
  node, will receive the given attributes.
  */
  static node(from2, to, attrs7, spec) {
    return new Decoration(from2, to, new NodeType(attrs7, spec));
  }
  /**
  The spec provided when creating this decoration. Can be useful
  if you've stored extra information in that object.
  */
  get spec() {
    return this.type.spec;
  }
  /**
  @internal
  */
  get inline() {
    return this.type instanceof InlineType;
  }
  /**
  @internal
  */
  get widget() {
    return this.type instanceof WidgetType;
  }
}
const none = [], noSpec = {};
class DecorationSet {
  static {
    __name(this, "DecorationSet");
  }
  /**
  @internal
  */
  constructor(local, children) {
    this.local = local.length ? local : none;
    this.children = children.length ? children : none;
  }
  /**
  Create a set of decorations, using the structure of the given
  document. This will consume (modify) the `decorations` array, so
  you must make a copy if you want need to preserve that.
  */
  static create(doc2, decorations) {
    return decorations.length ? buildTree(decorations, doc2, 0, noSpec) : empty;
  }
  /**
  Find all decorations in this set which touch the given range
  (including decorations that start or end directly at the
  boundaries) and match the given predicate on their spec. When
  `start` and `end` are omitted, all decorations in the set are
  considered. When `predicate` isn't given, all decorations are
  assumed to match.
  */
  find(start2, end, predicate) {
    let result = [];
    this.findInner(start2 == null ? 0 : start2, end == null ? 1e9 : end, result, 0, predicate);
    return result;
  }
  findInner(start2, end, result, offset, predicate) {
    for (let i2 = 0; i2 < this.local.length; i2++) {
      let span = this.local[i2];
      if (span.from <= end && span.to >= start2 && (!predicate || predicate(span.spec)))
        result.push(span.copy(span.from + offset, span.to + offset));
    }
    for (let i2 = 0; i2 < this.children.length; i2 += 3) {
      if (this.children[i2] < end && this.children[i2 + 1] > start2) {
        let childOff = this.children[i2] + 1;
        this.children[i2 + 2].findInner(start2 - childOff, end - childOff, result, offset + childOff, predicate);
      }
    }
  }
  /**
  Map the set of decorations in response to a change in the
  document.
  */
  map(mapping, doc2, options5) {
    if (this == empty || mapping.maps.length == 0)
      return this;
    return this.mapInner(mapping, doc2, 0, 0, options5 || noSpec);
  }
  /**
  @internal
  */
  mapInner(mapping, node3, offset, oldOffset, options5) {
    let newLocal;
    for (let i2 = 0; i2 < this.local.length; i2++) {
      let mapped = this.local[i2].map(mapping, offset, oldOffset);
      if (mapped && mapped.type.valid(node3, mapped))
        (newLocal || (newLocal = [])).push(mapped);
      else if (options5.onRemove)
        options5.onRemove(this.local[i2].spec);
    }
    if (this.children.length)
      return mapChildren(this.children, newLocal || [], mapping, node3, offset, oldOffset, options5);
    else
      return newLocal ? new DecorationSet(newLocal.sort(byPos), none) : empty;
  }
  /**
  Add the given array of decorations to the ones in the set,
  producing a new set. Consumes the `decorations` array. Needs
  access to the current document to create the appropriate tree
  structure.
  */
  add(doc2, decorations) {
    if (!decorations.length)
      return this;
    if (this == empty)
      return DecorationSet.create(doc2, decorations);
    return this.addInner(doc2, decorations, 0);
  }
  addInner(doc2, decorations, offset) {
    let children, childIndex = 0;
    doc2.forEach((childNode, childOffset) => {
      let baseOffset = childOffset + offset, found2;
      if (!(found2 = takeSpansForNode(decorations, childNode, baseOffset)))
        return;
      if (!children)
        children = this.children.slice();
      while (childIndex < children.length && children[childIndex] < childOffset)
        childIndex += 3;
      if (children[childIndex] == childOffset)
        children[childIndex + 2] = children[childIndex + 2].addInner(childNode, found2, baseOffset + 1);
      else
        children.splice(childIndex, 0, childOffset, childOffset + childNode.nodeSize, buildTree(found2, childNode, baseOffset + 1, noSpec));
      childIndex += 3;
    });
    let local = moveSpans(childIndex ? withoutNulls(decorations) : decorations, -offset);
    for (let i2 = 0; i2 < local.length; i2++)
      if (!local[i2].type.valid(doc2, local[i2]))
        local.splice(i2--, 1);
    return new DecorationSet(local.length ? this.local.concat(local).sort(byPos) : this.local, children || this.children);
  }
  /**
  Create a new set that contains the decorations in this set, minus
  the ones in the given array.
  */
  remove(decorations) {
    if (decorations.length == 0 || this == empty)
      return this;
    return this.removeInner(decorations, 0);
  }
  removeInner(decorations, offset) {
    let children = this.children, local = this.local;
    for (let i2 = 0; i2 < children.length; i2 += 3) {
      let found2;
      let from2 = children[i2] + offset, to = children[i2 + 1] + offset;
      for (let j2 = 0, span; j2 < decorations.length; j2++)
        if (span = decorations[j2]) {
          if (span.from > from2 && span.to < to) {
            decorations[j2] = null;
            (found2 || (found2 = [])).push(span);
          }
        }
      if (!found2)
        continue;
      if (children == this.children)
        children = this.children.slice();
      let removed = children[i2 + 2].removeInner(found2, from2 + 1);
      if (removed != empty) {
        children[i2 + 2] = removed;
      } else {
        children.splice(i2, 3);
        i2 -= 3;
      }
    }
    if (local.length) {
      for (let i2 = 0, span; i2 < decorations.length; i2++)
        if (span = decorations[i2]) {
          for (let j2 = 0; j2 < local.length; j2++)
            if (local[j2].eq(span, offset)) {
              if (local == this.local)
                local = this.local.slice();
              local.splice(j2--, 1);
            }
        }
    }
    if (children == this.children && local == this.local)
      return this;
    return local.length || children.length ? new DecorationSet(local, children) : empty;
  }
  forChild(offset, node3) {
    if (this == empty)
      return this;
    if (node3.isLeaf)
      return DecorationSet.empty;
    let child, local;
    for (let i2 = 0; i2 < this.children.length; i2 += 3)
      if (this.children[i2] >= offset) {
        if (this.children[i2] == offset)
          child = this.children[i2 + 2];
        break;
      }
    let start2 = offset + 1, end = start2 + node3.content.size;
    for (let i2 = 0; i2 < this.local.length; i2++) {
      let dec = this.local[i2];
      if (dec.from < end && dec.to > start2 && dec.type instanceof InlineType) {
        let from2 = Math.max(start2, dec.from) - start2, to = Math.min(end, dec.to) - start2;
        if (from2 < to)
          (local || (local = [])).push(dec.copy(from2, to));
      }
    }
    if (local) {
      let localSet = new DecorationSet(local.sort(byPos), none);
      return child ? new DecorationGroup([localSet, child]) : localSet;
    }
    return child || empty;
  }
  /**
  @internal
  */
  eq(other) {
    if (this == other)
      return true;
    if (!(other instanceof DecorationSet) || this.local.length != other.local.length || this.children.length != other.children.length)
      return false;
    for (let i2 = 0; i2 < this.local.length; i2++)
      if (!this.local[i2].eq(other.local[i2]))
        return false;
    for (let i2 = 0; i2 < this.children.length; i2 += 3)
      if (this.children[i2] != other.children[i2] || this.children[i2 + 1] != other.children[i2 + 1] || !this.children[i2 + 2].eq(other.children[i2 + 2]))
        return false;
    return true;
  }
  /**
  @internal
  */
  locals(node3) {
    return removeOverlap(this.localsInner(node3));
  }
  /**
  @internal
  */
  localsInner(node3) {
    if (this == empty)
      return none;
    if (node3.inlineContent || !this.local.some(InlineType.is))
      return this.local;
    let result = [];
    for (let i2 = 0; i2 < this.local.length; i2++) {
      if (!(this.local[i2].type instanceof InlineType))
        result.push(this.local[i2]);
    }
    return result;
  }
  forEachSet(f2) {
    f2(this);
  }
}
DecorationSet.empty = new DecorationSet([], []);
DecorationSet.removeOverlap = removeOverlap;
const empty = DecorationSet.empty;
class DecorationGroup {
  static {
    __name(this, "DecorationGroup");
  }
  constructor(members) {
    this.members = members;
  }
  map(mapping, doc2) {
    const mappedDecos = this.members.map((member) => member.map(mapping, doc2, noSpec));
    return DecorationGroup.from(mappedDecos);
  }
  forChild(offset, child) {
    if (child.isLeaf)
      return DecorationSet.empty;
    let found2 = [];
    for (let i2 = 0; i2 < this.members.length; i2++) {
      let result = this.members[i2].forChild(offset, child);
      if (result == empty)
        continue;
      if (result instanceof DecorationGroup)
        found2 = found2.concat(result.members);
      else
        found2.push(result);
    }
    return DecorationGroup.from(found2);
  }
  eq(other) {
    if (!(other instanceof DecorationGroup) || other.members.length != this.members.length)
      return false;
    for (let i2 = 0; i2 < this.members.length; i2++)
      if (!this.members[i2].eq(other.members[i2]))
        return false;
    return true;
  }
  locals(node3) {
    let result, sorted = true;
    for (let i2 = 0; i2 < this.members.length; i2++) {
      let locals = this.members[i2].localsInner(node3);
      if (!locals.length)
        continue;
      if (!result) {
        result = locals;
      } else {
        if (sorted) {
          result = result.slice();
          sorted = false;
        }
        for (let j2 = 0; j2 < locals.length; j2++)
          result.push(locals[j2]);
      }
    }
    return result ? removeOverlap(sorted ? result : result.sort(byPos)) : none;
  }
  // Create a group for the given array of decoration sets, or return
  // a single set when possible.
  static from(members) {
    switch (members.length) {
      case 0:
        return empty;
      case 1:
        return members[0];
      default:
        return new DecorationGroup(members.every((m2) => m2 instanceof DecorationSet) ? members : members.reduce((r2, m2) => r2.concat(m2 instanceof DecorationSet ? m2 : m2.members), []));
    }
  }
  forEachSet(f2) {
    for (let i2 = 0; i2 < this.members.length; i2++)
      this.members[i2].forEachSet(f2);
  }
}
function mapChildren(oldChildren, newLocal, mapping, node3, offset, oldOffset, options5) {
  let children = oldChildren.slice();
  for (let i2 = 0, baseOffset = oldOffset; i2 < mapping.maps.length; i2++) {
    let moved = 0;
    mapping.maps[i2].forEach((oldStart, oldEnd, newStart, newEnd) => {
      let dSize = newEnd - newStart - (oldEnd - oldStart);
      for (let i3 = 0; i3 < children.length; i3 += 3) {
        let end = children[i3 + 1];
        if (end < 0 || oldStart > end + baseOffset - moved)
          continue;
        let start2 = children[i3] + baseOffset - moved;
        if (oldEnd >= start2) {
          children[i3 + 1] = oldStart <= start2 ? -2 : -1;
        } else if (oldStart >= baseOffset && dSize) {
          children[i3] += dSize;
          children[i3 + 1] += dSize;
        }
      }
      moved += dSize;
    });
    baseOffset = mapping.maps[i2].map(baseOffset, -1);
  }
  let mustRebuild = false;
  for (let i2 = 0; i2 < children.length; i2 += 3)
    if (children[i2 + 1] < 0) {
      if (children[i2 + 1] == -2) {
        mustRebuild = true;
        children[i2 + 1] = -1;
        continue;
      }
      let from2 = mapping.map(oldChildren[i2] + oldOffset), fromLocal = from2 - offset;
      if (fromLocal < 0 || fromLocal >= node3.content.size) {
        mustRebuild = true;
        continue;
      }
      let to = mapping.map(oldChildren[i2 + 1] + oldOffset, -1), toLocal = to - offset;
      let { index: index2, offset: childOffset } = node3.content.findIndex(fromLocal);
      let childNode = node3.maybeChild(index2);
      if (childNode && childOffset == fromLocal && childOffset + childNode.nodeSize == toLocal) {
        let mapped = children[i2 + 2].mapInner(mapping, childNode, from2 + 1, oldChildren[i2] + oldOffset + 1, options5);
        if (mapped != empty) {
          children[i2] = fromLocal;
          children[i2 + 1] = toLocal;
          children[i2 + 2] = mapped;
        } else {
          children[i2 + 1] = -2;
          mustRebuild = true;
        }
      } else {
        mustRebuild = true;
      }
    }
  if (mustRebuild) {
    let decorations = mapAndGatherRemainingDecorations(children, oldChildren, newLocal, mapping, offset, oldOffset, options5);
    let built = buildTree(decorations, node3, 0, options5);
    newLocal = built.local;
    for (let i2 = 0; i2 < children.length; i2 += 3)
      if (children[i2 + 1] < 0) {
        children.splice(i2, 3);
        i2 -= 3;
      }
    for (let i2 = 0, j2 = 0; i2 < built.children.length; i2 += 3) {
      let from2 = built.children[i2];
      while (j2 < children.length && children[j2] < from2)
        j2 += 3;
      children.splice(j2, 0, built.children[i2], built.children[i2 + 1], built.children[i2 + 2]);
    }
  }
  return new DecorationSet(newLocal.sort(byPos), children);
}
__name(mapChildren, "mapChildren");
function moveSpans(spans, offset) {
  if (!offset || !spans.length)
    return spans;
  let result = [];
  for (let i2 = 0; i2 < spans.length; i2++) {
    let span = spans[i2];
    result.push(new Decoration(span.from + offset, span.to + offset, span.type));
  }
  return result;
}
__name(moveSpans, "moveSpans");
function mapAndGatherRemainingDecorations(children, oldChildren, decorations, mapping, offset, oldOffset, options5) {
  function gather(set3, oldOffset2) {
    for (let i2 = 0; i2 < set3.local.length; i2++) {
      let mapped = set3.local[i2].map(mapping, offset, oldOffset2);
      if (mapped)
        decorations.push(mapped);
      else if (options5.onRemove)
        options5.onRemove(set3.local[i2].spec);
    }
    for (let i2 = 0; i2 < set3.children.length; i2 += 3)
      gather(set3.children[i2 + 2], set3.children[i2] + oldOffset2 + 1);
  }
  __name(gather, "gather");
  for (let i2 = 0; i2 < children.length; i2 += 3)
    if (children[i2 + 1] == -1)
      gather(children[i2 + 2], oldChildren[i2] + oldOffset + 1);
  return decorations;
}
__name(mapAndGatherRemainingDecorations, "mapAndGatherRemainingDecorations");
function takeSpansForNode(spans, node3, offset) {
  if (node3.isLeaf)
    return null;
  let end = offset + node3.nodeSize, found2 = null;
  for (let i2 = 0, span; i2 < spans.length; i2++) {
    if ((span = spans[i2]) && span.from > offset && span.to < end) {
      (found2 || (found2 = [])).push(span);
      spans[i2] = null;
    }
  }
  return found2;
}
__name(takeSpansForNode, "takeSpansForNode");
function withoutNulls(array) {
  let result = [];
  for (let i2 = 0; i2 < array.length; i2++)
    if (array[i2] != null)
      result.push(array[i2]);
  return result;
}
__name(withoutNulls, "withoutNulls");
function buildTree(spans, node3, offset, options5) {
  let children = [], hasNulls = false;
  node3.forEach((childNode, localStart) => {
    let found2 = takeSpansForNode(spans, childNode, localStart + offset);
    if (found2) {
      hasNulls = true;
      let subtree = buildTree(found2, childNode, offset + localStart + 1, options5);
      if (subtree != empty)
        children.push(localStart, localStart + childNode.nodeSize, subtree);
    }
  });
  let locals = moveSpans(hasNulls ? withoutNulls(spans) : spans, -offset).sort(byPos);
  for (let i2 = 0; i2 < locals.length; i2++)
    if (!locals[i2].type.valid(node3, locals[i2])) {
      if (options5.onRemove)
        options5.onRemove(locals[i2].spec);
      locals.splice(i2--, 1);
    }
  return locals.length || children.length ? new DecorationSet(locals, children) : empty;
}
__name(buildTree, "buildTree");
function byPos(a2, b2) {
  return a2.from - b2.from || a2.to - b2.to;
}
__name(byPos, "byPos");
function removeOverlap(spans) {
  let working = spans;
  for (let i2 = 0; i2 < working.length - 1; i2++) {
    let span = working[i2];
    if (span.from != span.to)
      for (let j2 = i2 + 1; j2 < working.length; j2++) {
        let next2 = working[j2];
        if (next2.from == span.from) {
          if (next2.to != span.to) {
            if (working == spans)
              working = spans.slice();
            working[j2] = next2.copy(next2.from, span.to);
            insertAhead(working, j2 + 1, next2.copy(span.to, next2.to));
          }
          continue;
        } else {
          if (next2.from < span.to) {
            if (working == spans)
              working = spans.slice();
            working[i2] = span.copy(span.from, next2.from);
            insertAhead(working, j2, span.copy(next2.from, span.to));
          }
          break;
        }
      }
  }
  return working;
}
__name(removeOverlap, "removeOverlap");
function insertAhead(array, i2, deco) {
  while (i2 < array.length && byPos(deco, array[i2]) > 0)
    i2++;
  array.splice(i2, 0, deco);
}
__name(insertAhead, "insertAhead");
function viewDecorations(view) {
  let found2 = [];
  view.someProp("decorations", (f2) => {
    let result = f2(view.state);
    if (result && result != empty)
      found2.push(result);
  });
  if (view.cursorWrapper)
    found2.push(DecorationSet.create(view.state.doc, [view.cursorWrapper.deco]));
  return DecorationGroup.from(found2);
}
__name(viewDecorations, "viewDecorations");
const observeOptions = {
  childList: true,
  characterData: true,
  characterDataOldValue: true,
  attributes: true,
  attributeOldValue: true,
  subtree: true
};
const useCharData = ie$1 && ie_version <= 11;
class SelectionState {
  static {
    __name(this, "SelectionState");
  }
  constructor() {
    this.anchorNode = null;
    this.anchorOffset = 0;
    this.focusNode = null;
    this.focusOffset = 0;
  }
  set(sel) {
    this.anchorNode = sel.anchorNode;
    this.anchorOffset = sel.anchorOffset;
    this.focusNode = sel.focusNode;
    this.focusOffset = sel.focusOffset;
  }
  clear() {
    this.anchorNode = this.focusNode = null;
  }
  eq(sel) {
    return sel.anchorNode == this.anchorNode && sel.anchorOffset == this.anchorOffset && sel.focusNode == this.focusNode && sel.focusOffset == this.focusOffset;
  }
}
class DOMObserver {
  static {
    __name(this, "DOMObserver");
  }
  constructor(view, handleDOMChange) {
    this.view = view;
    this.handleDOMChange = handleDOMChange;
    this.queue = [];
    this.flushingSoon = -1;
    this.observer = null;
    this.currentSelection = new SelectionState();
    this.onCharData = null;
    this.suppressingSelectionUpdates = false;
    this.lastChangedTextNode = null;
    this.observer = window.MutationObserver && new window.MutationObserver((mutations) => {
      for (let i2 = 0; i2 < mutations.length; i2++)
        this.queue.push(mutations[i2]);
      if (ie$1 && ie_version <= 11 && mutations.some((m2) => m2.type == "childList" && m2.removedNodes.length || m2.type == "characterData" && m2.oldValue.length > m2.target.nodeValue.length))
        this.flushSoon();
      else
        this.flush();
    });
    if (useCharData) {
      this.onCharData = (e2) => {
        this.queue.push({ target: e2.target, type: "characterData", oldValue: e2.prevValue });
        this.flushSoon();
      };
    }
    this.onSelectionChange = this.onSelectionChange.bind(this);
  }
  flushSoon() {
    if (this.flushingSoon < 0)
      this.flushingSoon = window.setTimeout(() => {
        this.flushingSoon = -1;
        this.flush();
      }, 20);
  }
  forceFlush() {
    if (this.flushingSoon > -1) {
      window.clearTimeout(this.flushingSoon);
      this.flushingSoon = -1;
      this.flush();
    }
  }
  start() {
    if (this.observer) {
      this.observer.takeRecords();
      this.observer.observe(this.view.dom, observeOptions);
    }
    if (this.onCharData)
      this.view.dom.addEventListener("DOMCharacterDataModified", this.onCharData);
    this.connectSelection();
  }
  stop() {
    if (this.observer) {
      let take = this.observer.takeRecords();
      if (take.length) {
        for (let i2 = 0; i2 < take.length; i2++)
          this.queue.push(take[i2]);
        window.setTimeout(() => this.flush(), 20);
      }
      this.observer.disconnect();
    }
    if (this.onCharData)
      this.view.dom.removeEventListener("DOMCharacterDataModified", this.onCharData);
    this.disconnectSelection();
  }
  connectSelection() {
    this.view.dom.ownerDocument.addEventListener("selectionchange", this.onSelectionChange);
  }
  disconnectSelection() {
    this.view.dom.ownerDocument.removeEventListener("selectionchange", this.onSelectionChange);
  }
  suppressSelectionUpdates() {
    this.suppressingSelectionUpdates = true;
    setTimeout(() => this.suppressingSelectionUpdates = false, 50);
  }
  onSelectionChange() {
    if (!hasFocusAndSelection(this.view))
      return;
    if (this.suppressingSelectionUpdates)
      return selectionToDOM(this.view);
    if (ie$1 && ie_version <= 11 && !this.view.state.selection.empty) {
      let sel = this.view.domSelectionRange();
      if (sel.focusNode && isEquivalentPosition(sel.focusNode, sel.focusOffset, sel.anchorNode, sel.anchorOffset))
        return this.flushSoon();
    }
    this.flush();
  }
  setCurSelection() {
    this.currentSelection.set(this.view.domSelectionRange());
  }
  ignoreSelectionChange(sel) {
    if (!sel.focusNode)
      return true;
    let ancestors = /* @__PURE__ */ new Set(), container;
    for (let scan = sel.focusNode; scan; scan = parentNode(scan))
      ancestors.add(scan);
    for (let scan = sel.anchorNode; scan; scan = parentNode(scan))
      if (ancestors.has(scan)) {
        container = scan;
        break;
      }
    let desc = container && this.view.docView.nearestDesc(container);
    if (desc && desc.ignoreMutation({
      type: "selection",
      target: container.nodeType == 3 ? container.parentNode : container
    })) {
      this.setCurSelection();
      return true;
    }
  }
  pendingRecords() {
    if (this.observer)
      for (let mut of this.observer.takeRecords())
        this.queue.push(mut);
    return this.queue;
  }
  flush() {
    let { view } = this;
    if (!view.docView || this.flushingSoon > -1)
      return;
    let mutations = this.pendingRecords();
    if (mutations.length)
      this.queue = [];
    let sel = view.domSelectionRange();
    let newSel = !this.suppressingSelectionUpdates && !this.currentSelection.eq(sel) && hasFocusAndSelection(view) && !this.ignoreSelectionChange(sel);
    let from2 = -1, to = -1, typeOver = false, added = [];
    if (view.editable) {
      for (let i2 = 0; i2 < mutations.length; i2++) {
        let result = this.registerMutation(mutations[i2], added);
        if (result) {
          from2 = from2 < 0 ? result.from : Math.min(result.from, from2);
          to = to < 0 ? result.to : Math.max(result.to, to);
          if (result.typeOver)
            typeOver = true;
        }
      }
    }
    if (gecko && added.length) {
      let brs = added.filter((n2) => n2.nodeName == "BR");
      if (brs.length == 2) {
        let [a2, b2] = brs;
        if (a2.parentNode && a2.parentNode.parentNode == b2.parentNode)
          b2.remove();
        else
          a2.remove();
      } else {
        let { focusNode: focusNode2 } = this.currentSelection;
        for (let br of brs) {
          let parent = br.parentNode;
          if (parent && parent.nodeName == "LI" && (!focusNode2 || blockParent(view, focusNode2) != parent))
            br.remove();
        }
      }
    }
    let readSel = null;
    if (from2 < 0 && newSel && view.input.lastFocus > Date.now() - 200 && Math.max(view.input.lastTouch, view.input.lastClick.time) < Date.now() - 300 && selectionCollapsed(sel) && (readSel = selectionFromDOM(view)) && readSel.eq(Selection.near(view.state.doc.resolve(0), 1))) {
      view.input.lastFocus = 0;
      selectionToDOM(view);
      this.currentSelection.set(sel);
      view.scrollToSelection();
    } else if (from2 > -1 || newSel) {
      if (from2 > -1) {
        view.docView.markDirty(from2, to);
        checkCSS(view);
      }
      this.handleDOMChange(from2, to, typeOver, added);
      if (view.docView && view.docView.dirty)
        view.updateState(view.state);
      else if (!this.currentSelection.eq(sel))
        selectionToDOM(view);
      this.currentSelection.set(sel);
    }
  }
  registerMutation(mut, added) {
    if (added.indexOf(mut.target) > -1)
      return null;
    let desc = this.view.docView.nearestDesc(mut.target);
    if (mut.type == "attributes" && (desc == this.view.docView || mut.attributeName == "contenteditable" || // Firefox sometimes fires spurious events for null/empty styles
    mut.attributeName == "style" && !mut.oldValue && !mut.target.getAttribute("style")))
      return null;
    if (!desc || desc.ignoreMutation(mut))
      return null;
    if (mut.type == "childList") {
      for (let i2 = 0; i2 < mut.addedNodes.length; i2++) {
        let node3 = mut.addedNodes[i2];
        added.push(node3);
        if (node3.nodeType == 3)
          this.lastChangedTextNode = node3;
      }
      if (desc.contentDOM && desc.contentDOM != desc.dom && !desc.contentDOM.contains(mut.target))
        return { from: desc.posBefore, to: desc.posAfter };
      let prev2 = mut.previousSibling, next2 = mut.nextSibling;
      if (ie$1 && ie_version <= 11 && mut.addedNodes.length) {
        for (let i2 = 0; i2 < mut.addedNodes.length; i2++) {
          let { previousSibling, nextSibling } = mut.addedNodes[i2];
          if (!previousSibling || Array.prototype.indexOf.call(mut.addedNodes, previousSibling) < 0)
            prev2 = previousSibling;
          if (!nextSibling || Array.prototype.indexOf.call(mut.addedNodes, nextSibling) < 0)
            next2 = nextSibling;
        }
      }
      let fromOffset = prev2 && prev2.parentNode == mut.target ? domIndex(prev2) + 1 : 0;
      let from2 = desc.localPosFromDOM(mut.target, fromOffset, -1);
      let toOffset = next2 && next2.parentNode == mut.target ? domIndex(next2) : mut.target.childNodes.length;
      let to = desc.localPosFromDOM(mut.target, toOffset, 1);
      return { from: from2, to };
    } else if (mut.type == "attributes") {
      return { from: desc.posAtStart - desc.border, to: desc.posAtEnd + desc.border };
    } else {
      this.lastChangedTextNode = mut.target;
      return {
        from: desc.posAtStart,
        to: desc.posAtEnd,
        // An event was generated for a text change that didn't change
        // any text. Mark the dom change to fall back to assuming the
        // selection was typed over with an identical value if it can't
        // find another change.
        typeOver: mut.target.nodeValue == mut.oldValue
      };
    }
  }
}
let cssChecked = /* @__PURE__ */ new WeakMap();
let cssCheckWarned = false;
function checkCSS(view) {
  if (cssChecked.has(view))
    return;
  cssChecked.set(view, null);
  if (["normal", "nowrap", "pre-line"].indexOf(getComputedStyle(view.dom).whiteSpace) !== -1) {
    view.requiresGeckoHackNode = gecko;
    if (cssCheckWarned)
      return;
    console["warn"]("ProseMirror expects the CSS white-space property to be set, preferably to 'pre-wrap'. It is recommended to load style/prosemirror.css from the prosemirror-view package.");
    cssCheckWarned = true;
  }
}
__name(checkCSS, "checkCSS");
function rangeToSelectionRange(view, range2) {
  let anchorNode = range2.startContainer, anchorOffset = range2.startOffset;
  let focusNode2 = range2.endContainer, focusOffset = range2.endOffset;
  let currentAnchor = view.domAtPos(view.state.selection.anchor);
  if (isEquivalentPosition(currentAnchor.node, currentAnchor.offset, focusNode2, focusOffset))
    [anchorNode, anchorOffset, focusNode2, focusOffset] = [focusNode2, focusOffset, anchorNode, anchorOffset];
  return { anchorNode, anchorOffset, focusNode: focusNode2, focusOffset };
}
__name(rangeToSelectionRange, "rangeToSelectionRange");
function safariShadowSelectionRange(view, selection) {
  if (selection.getComposedRanges) {
    let range2 = selection.getComposedRanges(view.root)[0];
    if (range2)
      return rangeToSelectionRange(view, range2);
  }
  let found2;
  function read(event) {
    event.preventDefault();
    event.stopImmediatePropagation();
    found2 = event.getTargetRanges()[0];
  }
  __name(read, "read");
  view.dom.addEventListener("beforeinput", read, true);
  document.execCommand("indent");
  view.dom.removeEventListener("beforeinput", read, true);
  return found2 ? rangeToSelectionRange(view, found2) : null;
}
__name(safariShadowSelectionRange, "safariShadowSelectionRange");
function blockParent(view, node3) {
  for (let p2 = node3.parentNode; p2 && p2 != view.dom; p2 = p2.parentNode) {
    let desc = view.docView.nearestDesc(p2, true);
    if (desc && desc.node.isBlock)
      return p2;
  }
  return null;
}
__name(blockParent, "blockParent");
function parseBetween(view, from_, to_) {
  let { node: parent, fromOffset, toOffset, from: from2, to } = view.docView.parseRange(from_, to_);
  let domSel = view.domSelectionRange();
  let find2;
  let anchor = domSel.anchorNode;
  if (anchor && view.dom.contains(anchor.nodeType == 1 ? anchor : anchor.parentNode)) {
    find2 = [{ node: anchor, offset: domSel.anchorOffset }];
    if (!selectionCollapsed(domSel))
      find2.push({ node: domSel.focusNode, offset: domSel.focusOffset });
  }
  if (chrome && view.input.lastKeyCode === 8) {
    for (let off = toOffset; off > fromOffset; off--) {
      let node3 = parent.childNodes[off - 1], desc = node3.pmViewDesc;
      if (node3.nodeName == "BR" && !desc) {
        toOffset = off;
        break;
      }
      if (!desc || desc.size)
        break;
    }
  }
  let startDoc = view.state.doc;
  let parser = view.someProp("domParser") || DOMParser.fromSchema(view.state.schema);
  let $from = startDoc.resolve(from2);
  let sel = null, doc2 = parser.parse(parent, {
    topNode: $from.parent,
    topMatch: $from.parent.contentMatchAt($from.index()),
    topOpen: true,
    from: fromOffset,
    to: toOffset,
    preserveWhitespace: $from.parent.type.whitespace == "pre" ? "full" : true,
    findPositions: find2,
    ruleFromNode,
    context: $from
  });
  if (find2 && find2[0].pos != null) {
    let anchor2 = find2[0].pos, head = find2[1] && find2[1].pos;
    if (head == null)
      head = anchor2;
    sel = { anchor: anchor2 + from2, head: head + from2 };
  }
  return { doc: doc2, sel, from: from2, to };
}
__name(parseBetween, "parseBetween");
function ruleFromNode(dom) {
  let desc = dom.pmViewDesc;
  if (desc) {
    return desc.parseRule();
  } else if (dom.nodeName == "BR" && dom.parentNode) {
    if (safari && /^(ul|ol)$/i.test(dom.parentNode.nodeName)) {
      let skip = document.createElement("div");
      skip.appendChild(document.createElement("li"));
      return { skip };
    } else if (dom.parentNode.lastChild == dom || safari && /^(tr|table)$/i.test(dom.parentNode.nodeName)) {
      return { ignore: true };
    }
  } else if (dom.nodeName == "IMG" && dom.getAttribute("mark-placeholder")) {
    return { ignore: true };
  }
  return null;
}
__name(ruleFromNode, "ruleFromNode");
const isInline$1 = /^(a|abbr|acronym|b|bd[io]|big|br|button|cite|code|data(list)?|del|dfn|em|i|ins|kbd|label|map|mark|meter|output|q|ruby|s|samp|small|span|strong|su[bp]|time|u|tt|var)$/i;
function readDOMChange(view, from2, to, typeOver, addedNodes) {
  let compositionID = view.input.compositionPendingChanges || (view.composing ? view.input.compositionID : 0);
  view.input.compositionPendingChanges = 0;
  if (from2 < 0) {
    let origin2 = view.input.lastSelectionTime > Date.now() - 50 ? view.input.lastSelectionOrigin : null;
    let newSel = selectionFromDOM(view, origin2);
    if (newSel && !view.state.selection.eq(newSel)) {
      if (chrome && android && view.input.lastKeyCode === 13 && Date.now() - 100 < view.input.lastKeyCodeTime && view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(13, "Enter"))))
        return;
      let tr3 = view.state.tr.setSelection(newSel);
      if (origin2 == "pointer")
        tr3.setMeta("pointer", true);
      else if (origin2 == "key")
        tr3.scrollIntoView();
      if (compositionID)
        tr3.setMeta("composition", compositionID);
      view.dispatch(tr3);
    }
    return;
  }
  let $before = view.state.doc.resolve(from2);
  let shared = $before.sharedDepth(to);
  from2 = $before.before(shared + 1);
  to = view.state.doc.resolve(to).after(shared + 1);
  let sel = view.state.selection;
  let parse2 = parseBetween(view, from2, to);
  let doc2 = view.state.doc, compare2 = doc2.slice(parse2.from, parse2.to);
  let preferredPos, preferredSide;
  if (view.input.lastKeyCode === 8 && Date.now() - 100 < view.input.lastKeyCodeTime) {
    preferredPos = view.state.selection.to;
    preferredSide = "end";
  } else {
    preferredPos = view.state.selection.from;
    preferredSide = "start";
  }
  view.input.lastKeyCode = null;
  let change = findDiff(compare2.content, parse2.doc.content, parse2.from, preferredPos, preferredSide);
  if (change)
    view.input.domChangeCount++;
  if ((ios && view.input.lastIOSEnter > Date.now() - 225 || android) && addedNodes.some((n2) => n2.nodeType == 1 && !isInline$1.test(n2.nodeName)) && (!change || change.endA >= change.endB) && view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(13, "Enter")))) {
    view.input.lastIOSEnter = 0;
    return;
  }
  if (!change) {
    if (typeOver && sel instanceof TextSelection && !sel.empty && sel.$head.sameParent(sel.$anchor) && !view.composing && !(parse2.sel && parse2.sel.anchor != parse2.sel.head)) {
      change = { start: sel.from, endA: sel.to, endB: sel.to };
    } else {
      if (parse2.sel) {
        let sel2 = resolveSelection(view, view.state.doc, parse2.sel);
        if (sel2 && !sel2.eq(view.state.selection)) {
          let tr3 = view.state.tr.setSelection(sel2);
          if (compositionID)
            tr3.setMeta("composition", compositionID);
          view.dispatch(tr3);
        }
      }
      return;
    }
  }
  if (view.state.selection.from < view.state.selection.to && change.start == change.endB && view.state.selection instanceof TextSelection) {
    if (change.start > view.state.selection.from && change.start <= view.state.selection.from + 2 && view.state.selection.from >= parse2.from) {
      change.start = view.state.selection.from;
    } else if (change.endA < view.state.selection.to && change.endA >= view.state.selection.to - 2 && view.state.selection.to <= parse2.to) {
      change.endB += view.state.selection.to - change.endA;
      change.endA = view.state.selection.to;
    }
  }
  if (ie$1 && ie_version <= 11 && change.endB == change.start + 1 && change.endA == change.start && change.start > parse2.from && parse2.doc.textBetween(change.start - parse2.from - 1, change.start - parse2.from + 1) == "  ") {
    change.start--;
    change.endA--;
    change.endB--;
  }
  let $from = parse2.doc.resolveNoCache(change.start - parse2.from);
  let $to = parse2.doc.resolveNoCache(change.endB - parse2.from);
  let $fromA = doc2.resolve(change.start);
  let inlineChange = $from.sameParent($to) && $from.parent.inlineContent && $fromA.end() >= change.endA;
  let nextSel;
  if ((ios && view.input.lastIOSEnter > Date.now() - 225 && (!inlineChange || addedNodes.some((n2) => n2.nodeName == "DIV" || n2.nodeName == "P")) || !inlineChange && $from.pos < parse2.doc.content.size && !$from.sameParent($to) && (nextSel = Selection.findFrom(parse2.doc.resolve($from.pos + 1), 1, true)) && nextSel.head == $to.pos) && view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(13, "Enter")))) {
    view.input.lastIOSEnter = 0;
    return;
  }
  if (view.state.selection.anchor > change.start && looksLikeBackspace(doc2, change.start, change.endA, $from, $to) && view.someProp("handleKeyDown", (f2) => f2(view, keyEvent(8, "Backspace")))) {
    if (android && chrome)
      view.domObserver.suppressSelectionUpdates();
    return;
  }
  if (chrome && change.endB == change.start)
    view.input.lastChromeDelete = Date.now();
  if (android && !inlineChange && $from.start() != $to.start() && $to.parentOffset == 0 && $from.depth == $to.depth && parse2.sel && parse2.sel.anchor == parse2.sel.head && parse2.sel.head == change.endA) {
    change.endB -= 2;
    $to = parse2.doc.resolveNoCache(change.endB - parse2.from);
    setTimeout(() => {
      view.someProp("handleKeyDown", function(f2) {
        return f2(view, keyEvent(13, "Enter"));
      });
    }, 20);
  }
  let chFrom = change.start, chTo = change.endA;
  let tr2, storedMarks, markChange;
  if (inlineChange) {
    if ($from.pos == $to.pos) {
      if (ie$1 && ie_version <= 11 && $from.parentOffset == 0) {
        view.domObserver.suppressSelectionUpdates();
        setTimeout(() => selectionToDOM(view), 20);
      }
      tr2 = view.state.tr.delete(chFrom, chTo);
      storedMarks = doc2.resolve(change.start).marksAcross(doc2.resolve(change.endA));
    } else if (
      // Adding or removing a mark
      change.endA == change.endB && (markChange = isMarkChange($from.parent.content.cut($from.parentOffset, $to.parentOffset), $fromA.parent.content.cut($fromA.parentOffset, change.endA - $fromA.start())))
    ) {
      tr2 = view.state.tr;
      if (markChange.type == "add")
        tr2.addMark(chFrom, chTo, markChange.mark);
      else
        tr2.removeMark(chFrom, chTo, markChange.mark);
    } else if ($from.parent.child($from.index()).isText && $from.index() == $to.index() - ($to.textOffset ? 0 : 1)) {
      let text2 = $from.parent.textBetween($from.parentOffset, $to.parentOffset);
      if (view.someProp("handleTextInput", (f2) => f2(view, chFrom, chTo, text2)))
        return;
      tr2 = view.state.tr.insertText(text2, chFrom, chTo);
    }
  }
  if (!tr2)
    tr2 = view.state.tr.replace(chFrom, chTo, parse2.doc.slice(change.start - parse2.from, change.endB - parse2.from));
  if (parse2.sel) {
    let sel2 = resolveSelection(view, tr2.doc, parse2.sel);
    if (sel2 && !(chrome && view.composing && sel2.empty && (change.start != change.endB || view.input.lastChromeDelete < Date.now() - 100) && (sel2.head == chFrom || sel2.head == tr2.mapping.map(chTo) - 1) || ie$1 && sel2.empty && sel2.head == chFrom))
      tr2.setSelection(sel2);
  }
  if (storedMarks)
    tr2.ensureMarks(storedMarks);
  if (compositionID)
    tr2.setMeta("composition", compositionID);
  view.dispatch(tr2.scrollIntoView());
}
__name(readDOMChange, "readDOMChange");
function resolveSelection(view, doc2, parsedSel) {
  if (Math.max(parsedSel.anchor, parsedSel.head) > doc2.content.size)
    return null;
  return selectionBetween(view, doc2.resolve(parsedSel.anchor), doc2.resolve(parsedSel.head));
}
__name(resolveSelection, "resolveSelection");
function isMarkChange(cur, prev2) {
  let curMarks = cur.firstChild.marks, prevMarks = prev2.firstChild.marks;
  let added = curMarks, removed = prevMarks, type, mark2, update;
  for (let i2 = 0; i2 < prevMarks.length; i2++)
    added = prevMarks[i2].removeFromSet(added);
  for (let i2 = 0; i2 < curMarks.length; i2++)
    removed = curMarks[i2].removeFromSet(removed);
  if (added.length == 1 && removed.length == 0) {
    mark2 = added[0];
    type = "add";
    update = /* @__PURE__ */ __name((node3) => node3.mark(mark2.addToSet(node3.marks)), "update");
  } else if (added.length == 0 && removed.length == 1) {
    mark2 = removed[0];
    type = "remove";
    update = /* @__PURE__ */ __name((node3) => node3.mark(mark2.removeFromSet(node3.marks)), "update");
  } else {
    return null;
  }
  let updated17 = [];
  for (let i2 = 0; i2 < prev2.childCount; i2++)
    updated17.push(update(prev2.child(i2)));
  if (Fragment.from(updated17).eq(cur))
    return { mark: mark2, type };
}
__name(isMarkChange, "isMarkChange");
function looksLikeBackspace(old, start2, end, $newStart, $newEnd) {
  if (
    // The content must have shrunk
    end - start2 <= $newEnd.pos - $newStart.pos || // newEnd must point directly at or after the end of the block that newStart points into
    skipClosingAndOpening($newStart, true, false) < $newEnd.pos
  )
    return false;
  let $start = old.resolve(start2);
  if (!$newStart.parent.isTextblock) {
    let after = $start.nodeAfter;
    return after != null && end == start2 + after.nodeSize;
  }
  if ($start.parentOffset < $start.parent.content.size || !$start.parent.isTextblock)
    return false;
  let $next = old.resolve(skipClosingAndOpening($start, true, true));
  if (!$next.parent.isTextblock || $next.pos > end || skipClosingAndOpening($next, true, false) < end)
    return false;
  return $newStart.parent.content.cut($newStart.parentOffset).eq($next.parent.content);
}
__name(looksLikeBackspace, "looksLikeBackspace");
function skipClosingAndOpening($pos, fromEnd, mayOpen) {
  let depth = $pos.depth, end = fromEnd ? $pos.end() : $pos.pos;
  while (depth > 0 && (fromEnd || $pos.indexAfter(depth) == $pos.node(depth).childCount)) {
    depth--;
    end++;
    fromEnd = false;
  }
  if (mayOpen) {
    let next2 = $pos.node(depth).maybeChild($pos.indexAfter(depth));
    while (next2 && !next2.isLeaf) {
      next2 = next2.firstChild;
      end++;
    }
  }
  return end;
}
__name(skipClosingAndOpening, "skipClosingAndOpening");
function findDiff(a2, b2, pos, preferredPos, preferredSide) {
  let start2 = a2.findDiffStart(b2, pos);
  if (start2 == null)
    return null;
  let { a: endA, b: endB } = a2.findDiffEnd(b2, pos + a2.size, pos + b2.size);
  if (preferredSide == "end") {
    let adjust = Math.max(0, start2 - Math.min(endA, endB));
    preferredPos -= endA + adjust - start2;
  }
  if (endA < start2 && a2.size < b2.size) {
    let move = preferredPos <= start2 && preferredPos >= endA ? start2 - preferredPos : 0;
    start2 -= move;
    if (start2 && start2 < b2.size && isSurrogatePair(b2.textBetween(start2 - 1, start2 + 1)))
      start2 += move ? 1 : -1;
    endB = start2 + (endB - endA);
    endA = start2;
  } else if (endB < start2) {
    let move = preferredPos <= start2 && preferredPos >= endB ? start2 - preferredPos : 0;
    start2 -= move;
    if (start2 && start2 < a2.size && isSurrogatePair(a2.textBetween(start2 - 1, start2 + 1)))
      start2 += move ? 1 : -1;
    endA = start2 + (endA - endB);
    endB = start2;
  }
  return { start: start2, endA, endB };
}
__name(findDiff, "findDiff");
function isSurrogatePair(str) {
  if (str.length != 2)
    return false;
  let a2 = str.charCodeAt(0), b2 = str.charCodeAt(1);
  return a2 >= 56320 && a2 <= 57343 && b2 >= 55296 && b2 <= 56319;
}
__name(isSurrogatePair, "isSurrogatePair");
const __serializeForClipboard = serializeForClipboard;
const __parseFromClipboard = parseFromClipboard;
const __endComposition = endComposition;
class EditorView {
  static {
    __name(this, "EditorView");
  }
  /**
  Create a view. `place` may be a DOM node that the editor should
  be appended to, a function that will place it into the document,
  or an object whose `mount` property holds the node to use as the
  document container. If it is `null`, the editor will not be
  added to the document.
  */
  constructor(place, props) {
    this._root = null;
    this.focused = false;
    this.trackWrites = null;
    this.mounted = false;
    this.markCursor = null;
    this.cursorWrapper = null;
    this.lastSelectedViewDesc = void 0;
    this.input = new InputState();
    this.prevDirectPlugins = [];
    this.pluginViews = [];
    this.requiresGeckoHackNode = false;
    this.dragging = null;
    this._props = props;
    this.state = props.state;
    this.directPlugins = props.plugins || [];
    this.directPlugins.forEach(checkStateComponent);
    this.dispatch = this.dispatch.bind(this);
    this.dom = place && place.mount || document.createElement("div");
    if (place) {
      if (place.appendChild)
        place.appendChild(this.dom);
      else if (typeof place == "function")
        place(this.dom);
      else if (place.mount)
        this.mounted = true;
    }
    this.editable = getEditable(this);
    updateCursorWrapper(this);
    this.nodeViews = buildNodeViews(this);
    this.docView = docViewDesc(this.state.doc, computeDocDeco(this), viewDecorations(this), this.dom, this);
    this.domObserver = new DOMObserver(this, (from2, to, typeOver, added) => readDOMChange(this, from2, to, typeOver, added));
    this.domObserver.start();
    initInput(this);
    this.updatePluginViews();
  }
  /**
  Holds `true` when a
  [composition](https://w3c.github.io/uievents/#events-compositionevents)
  is active.
  */
  get composing() {
    return this.input.composing;
  }
  /**
  The view's current [props](https://prosemirror.net/docs/ref/#view.EditorProps).
  */
  get props() {
    if (this._props.state != this.state) {
      let prev2 = this._props;
      this._props = {};
      for (let name2 in prev2)
        this._props[name2] = prev2[name2];
      this._props.state = this.state;
    }
    return this._props;
  }
  /**
  Update the view's props. Will immediately cause an update to
  the DOM.
  */
  update(props) {
    if (props.handleDOMEvents != this._props.handleDOMEvents)
      ensureListeners(this);
    let prevProps = this._props;
    this._props = props;
    if (props.plugins) {
      props.plugins.forEach(checkStateComponent);
      this.directPlugins = props.plugins;
    }
    this.updateStateInner(props.state, prevProps);
  }
  /**
  Update the view by updating existing props object with the object
  given as argument. Equivalent to `view.update(Object.assign({},
  view.props, props))`.
  */
  setProps(props) {
    let updated17 = {};
    for (let name2 in this._props)
      updated17[name2] = this._props[name2];
    updated17.state = this.state;
    for (let name2 in props)
      updated17[name2] = props[name2];
    this.update(updated17);
  }
  /**
  Update the editor's `state` prop, without touching any of the
  other props.
  */
  updateState(state) {
    this.updateStateInner(state, this._props);
  }
  updateStateInner(state, prevProps) {
    var _a2;
    let prev2 = this.state, redraw = false, updateSel = false;
    if (state.storedMarks && this.composing) {
      clearComposition(this);
      updateSel = true;
    }
    this.state = state;
    let pluginsChanged = prev2.plugins != state.plugins || this._props.plugins != prevProps.plugins;
    if (pluginsChanged || this._props.plugins != prevProps.plugins || this._props.nodeViews != prevProps.nodeViews) {
      let nodeViews = buildNodeViews(this);
      if (changedNodeViews(nodeViews, this.nodeViews)) {
        this.nodeViews = nodeViews;
        redraw = true;
      }
    }
    if (pluginsChanged || prevProps.handleDOMEvents != this._props.handleDOMEvents) {
      ensureListeners(this);
    }
    this.editable = getEditable(this);
    updateCursorWrapper(this);
    let innerDeco = viewDecorations(this), outerDeco = computeDocDeco(this);
    let scroll = prev2.plugins != state.plugins && !prev2.doc.eq(state.doc) ? "reset" : state.scrollToSelection > prev2.scrollToSelection ? "to selection" : "preserve";
    let updateDoc = redraw || !this.docView.matchesNode(state.doc, outerDeco, innerDeco);
    if (updateDoc || !state.selection.eq(prev2.selection))
      updateSel = true;
    let oldScrollPos = scroll == "preserve" && updateSel && this.dom.style.overflowAnchor == null && storeScrollPos(this);
    if (updateSel) {
      this.domObserver.stop();
      let forceSelUpdate = updateDoc && (ie$1 || chrome) && !this.composing && !prev2.selection.empty && !state.selection.empty && selectionContextChanged(prev2.selection, state.selection);
      if (updateDoc) {
        let chromeKludge = chrome ? this.trackWrites = this.domSelectionRange().focusNode : null;
        if (this.composing)
          this.input.compositionNode = findCompositionNode(this);
        if (redraw || !this.docView.update(state.doc, outerDeco, innerDeco, this)) {
          this.docView.updateOuterDeco(outerDeco);
          this.docView.destroy();
          this.docView = docViewDesc(state.doc, outerDeco, innerDeco, this.dom, this);
        }
        if (chromeKludge && !this.trackWrites)
          forceSelUpdate = true;
      }
      if (forceSelUpdate || !(this.input.mouseDown && this.domObserver.currentSelection.eq(this.domSelectionRange()) && anchorInRightPlace(this))) {
        selectionToDOM(this, forceSelUpdate);
      } else {
        syncNodeSelection(this, state.selection);
        this.domObserver.setCurSelection();
      }
      this.domObserver.start();
    }
    this.updatePluginViews(prev2);
    if (((_a2 = this.dragging) === null || _a2 === void 0 ? void 0 : _a2.node) && !prev2.doc.eq(state.doc))
      this.updateDraggedNode(this.dragging, prev2);
    if (scroll == "reset") {
      this.dom.scrollTop = 0;
    } else if (scroll == "to selection") {
      this.scrollToSelection();
    } else if (oldScrollPos) {
      resetScrollPos(oldScrollPos);
    }
  }
  /**
  @internal
  */
  scrollToSelection() {
    let startDOM = this.domSelectionRange().focusNode;
    if (this.someProp("handleScrollToSelection", (f2) => f2(this))) ;
    else if (this.state.selection instanceof NodeSelection) {
      let target2 = this.docView.domAfterPos(this.state.selection.from);
      if (target2.nodeType == 1)
        scrollRectIntoView(this, target2.getBoundingClientRect(), startDOM);
    } else {
      scrollRectIntoView(this, this.coordsAtPos(this.state.selection.head, 1), startDOM);
    }
  }
  destroyPluginViews() {
    let view;
    while (view = this.pluginViews.pop())
      if (view.destroy)
        view.destroy();
  }
  updatePluginViews(prevState) {
    if (!prevState || prevState.plugins != this.state.plugins || this.directPlugins != this.prevDirectPlugins) {
      this.prevDirectPlugins = this.directPlugins;
      this.destroyPluginViews();
      for (let i2 = 0; i2 < this.directPlugins.length; i2++) {
        let plugin = this.directPlugins[i2];
        if (plugin.spec.view)
          this.pluginViews.push(plugin.spec.view(this));
      }
      for (let i2 = 0; i2 < this.state.plugins.length; i2++) {
        let plugin = this.state.plugins[i2];
        if (plugin.spec.view)
          this.pluginViews.push(plugin.spec.view(this));
      }
    } else {
      for (let i2 = 0; i2 < this.pluginViews.length; i2++) {
        let pluginView = this.pluginViews[i2];
        if (pluginView.update)
          pluginView.update(this, prevState);
      }
    }
  }
  updateDraggedNode(dragging, prev2) {
    let sel = dragging.node, found2 = -1;
    if (this.state.doc.nodeAt(sel.from) == sel.node) {
      found2 = sel.from;
    } else {
      let movedPos = sel.from + (this.state.doc.content.size - prev2.doc.content.size);
      let moved = movedPos > 0 && this.state.doc.nodeAt(movedPos);
      if (moved == sel.node)
        found2 = movedPos;
    }
    this.dragging = new Dragging(dragging.slice, dragging.move, found2 < 0 ? void 0 : NodeSelection.create(this.state.doc, found2));
  }
  someProp(propName, f2) {
    let prop2 = this._props && this._props[propName], value3;
    if (prop2 != null && (value3 = f2 ? f2(prop2) : prop2))
      return value3;
    for (let i2 = 0; i2 < this.directPlugins.length; i2++) {
      let prop3 = this.directPlugins[i2].props[propName];
      if (prop3 != null && (value3 = f2 ? f2(prop3) : prop3))
        return value3;
    }
    let plugins = this.state.plugins;
    if (plugins)
      for (let i2 = 0; i2 < plugins.length; i2++) {
        let prop3 = plugins[i2].props[propName];
        if (prop3 != null && (value3 = f2 ? f2(prop3) : prop3))
          return value3;
      }
  }
  /**
  Query whether the view has focus.
  */
  hasFocus() {
    if (ie$1) {
      let node3 = this.root.activeElement;
      if (node3 == this.dom)
        return true;
      if (!node3 || !this.dom.contains(node3))
        return false;
      while (node3 && this.dom != node3 && this.dom.contains(node3)) {
        if (node3.contentEditable == "false")
          return false;
        node3 = node3.parentElement;
      }
      return true;
    }
    return this.root.activeElement == this.dom;
  }
  /**
  Focus the editor.
  */
  focus() {
    this.domObserver.stop();
    if (this.editable)
      focusPreventScroll(this.dom);
    selectionToDOM(this);
    this.domObserver.start();
  }
  /**
  Get the document root in which the editor exists. This will
  usually be the top-level `document`, but might be a [shadow
  DOM](https://developer.mozilla.org/en-US/docs/Web/Web_Components/Shadow_DOM)
  root if the editor is inside one.
  */
  get root() {
    let cached = this._root;
    if (cached == null)
      for (let search3 = this.dom.parentNode; search3; search3 = search3.parentNode) {
        if (search3.nodeType == 9 || search3.nodeType == 11 && search3.host) {
          if (!search3.getSelection)
            Object.getPrototypeOf(search3).getSelection = () => search3.ownerDocument.getSelection();
          return this._root = search3;
        }
      }
    return cached || document;
  }
  /**
  When an existing editor view is moved to a new document or
  shadow tree, call this to make it recompute its root.
  */
  updateRoot() {
    this._root = null;
  }
  /**
  Given a pair of viewport coordinates, return the document
  position that corresponds to them. May return null if the given
  coordinates aren't inside of the editor. When an object is
  returned, its `pos` property is the position nearest to the
  coordinates, and its `inside` property holds the position of the
  inner node that the position falls inside of, or -1 if it is at
  the top level, not in any node.
  */
  posAtCoords(coords) {
    return posAtCoords(this, coords);
  }
  /**
  Returns the viewport rectangle at a given document position.
  `left` and `right` will be the same number, as this returns a
  flat cursor-ish rectangle. If the position is between two things
  that aren't directly adjacent, `side` determines which element
  is used. When < 0, the element before the position is used,
  otherwise the element after.
  */
  coordsAtPos(pos, side = 1) {
    return coordsAtPos(this, pos, side);
  }
  /**
  Find the DOM position that corresponds to the given document
  position. When `side` is negative, find the position as close as
  possible to the content before the position. When positive,
  prefer positions close to the content after the position. When
  zero, prefer as shallow a position as possible.
  
  Note that you should **not** mutate the editor's internal DOM,
  only inspect it (and even that is usually not necessary).
  */
  domAtPos(pos, side = 0) {
    return this.docView.domFromPos(pos, side);
  }
  /**
  Find the DOM node that represents the document node after the
  given position. May return `null` when the position doesn't point
  in front of a node or if the node is inside an opaque node view.
  
  This is intended to be able to call things like
  `getBoundingClientRect` on that DOM node. Do **not** mutate the
  editor DOM directly, or add styling this way, since that will be
  immediately overriden by the editor as it redraws the node.
  */
  nodeDOM(pos) {
    let desc = this.docView.descAt(pos);
    return desc ? desc.nodeDOM : null;
  }
  /**
  Find the document position that corresponds to a given DOM
  position. (Whenever possible, it is preferable to inspect the
  document structure directly, rather than poking around in the
  DOM, but sometimes—for example when interpreting an event
  target—you don't have a choice.)
  
  The `bias` parameter can be used to influence which side of a DOM
  node to use when the position is inside a leaf node.
  */
  posAtDOM(node3, offset, bias = -1) {
    let pos = this.docView.posFromDOM(node3, offset, bias);
    if (pos == null)
      throw new RangeError("DOM position not inside the editor");
    return pos;
  }
  /**
  Find out whether the selection is at the end of a textblock when
  moving in a given direction. When, for example, given `"left"`,
  it will return true if moving left from the current cursor
  position would leave that position's parent textblock. Will apply
  to the view's current state by default, but it is possible to
  pass a different state.
  */
  endOfTextblock(dir, state) {
    return endOfTextblock(this, state || this.state, dir);
  }
  /**
  Run the editor's paste logic with the given HTML string. The
  `event`, if given, will be passed to the
  [`handlePaste`](https://prosemirror.net/docs/ref/#view.EditorProps.handlePaste) hook.
  */
  pasteHTML(html, event) {
    return doPaste(this, "", html, false, event || new ClipboardEvent("paste"));
  }
  /**
  Run the editor's paste logic with the given plain-text input.
  */
  pasteText(text2, event) {
    return doPaste(this, text2, null, true, event || new ClipboardEvent("paste"));
  }
  /**
  Removes the editor from the DOM and destroys all [node
  views](https://prosemirror.net/docs/ref/#view.NodeView).
  */
  destroy() {
    if (!this.docView)
      return;
    destroyInput(this);
    this.destroyPluginViews();
    if (this.mounted) {
      this.docView.update(this.state.doc, [], viewDecorations(this), this);
      this.dom.textContent = "";
    } else if (this.dom.parentNode) {
      this.dom.parentNode.removeChild(this.dom);
    }
    this.docView.destroy();
    this.docView = null;
    clearReusedRange();
  }
  /**
  This is true when the view has been
  [destroyed](https://prosemirror.net/docs/ref/#view.EditorView.destroy) (and thus should not be
  used anymore).
  */
  get isDestroyed() {
    return this.docView == null;
  }
  /**
  Used for testing.
  */
  dispatchEvent(event) {
    return dispatchEvent(this, event);
  }
  /**
  Dispatch a transaction. Will call
  [`dispatchTransaction`](https://prosemirror.net/docs/ref/#view.DirectEditorProps.dispatchTransaction)
  when given, and otherwise defaults to applying the transaction to
  the current state and calling
  [`updateState`](https://prosemirror.net/docs/ref/#view.EditorView.updateState) with the result.
  This method is bound to the view instance, so that it can be
  easily passed around.
  */
  dispatch(tr2) {
    let dispatchTransaction = this._props.dispatchTransaction;
    if (dispatchTransaction)
      dispatchTransaction.call(this, tr2);
    else
      this.updateState(this.state.apply(tr2));
  }
  /**
  @internal
  */
  domSelectionRange() {
    let sel = this.domSelection();
    if (!sel)
      return { focusNode: null, focusOffset: 0, anchorNode: null, anchorOffset: 0 };
    return safari && this.root.nodeType === 11 && deepActiveElement(this.dom.ownerDocument) == this.dom && safariShadowSelectionRange(this, sel) || sel;
  }
  /**
  @internal
  */
  domSelection() {
    return this.root.getSelection();
  }
}
function computeDocDeco(view) {
  let attrs7 = /* @__PURE__ */ Object.create(null);
  attrs7.class = "ProseMirror";
  attrs7.contenteditable = String(view.editable);
  view.someProp("attributes", (value3) => {
    if (typeof value3 == "function")
      value3 = value3(view.state);
    if (value3)
      for (let attr in value3) {
        if (attr == "class")
          attrs7.class += " " + value3[attr];
        else if (attr == "style")
          attrs7.style = (attrs7.style ? attrs7.style + ";" : "") + value3[attr];
        else if (!attrs7[attr] && attr != "contenteditable" && attr != "nodeName")
          attrs7[attr] = String(value3[attr]);
      }
  });
  if (!attrs7.translate)
    attrs7.translate = "no";
  return [Decoration.node(0, view.state.doc.content.size, attrs7)];
}
__name(computeDocDeco, "computeDocDeco");
function updateCursorWrapper(view) {
  if (view.markCursor) {
    let dom = document.createElement("img");
    dom.className = "ProseMirror-separator";
    dom.setAttribute("mark-placeholder", "true");
    dom.setAttribute("alt", "");
    view.cursorWrapper = { dom, deco: Decoration.widget(view.state.selection.from, dom, { raw: true, marks: view.markCursor }) };
  } else {
    view.cursorWrapper = null;
  }
}
__name(updateCursorWrapper, "updateCursorWrapper");
function getEditable(view) {
  return !view.someProp("editable", (value3) => value3(view.state) === false);
}
__name(getEditable, "getEditable");
function selectionContextChanged(sel1, sel2) {
  let depth = Math.min(sel1.$anchor.sharedDepth(sel1.head), sel2.$anchor.sharedDepth(sel2.head));
  return sel1.$anchor.start(depth) != sel2.$anchor.start(depth);
}
__name(selectionContextChanged, "selectionContextChanged");
function buildNodeViews(view) {
  let result = /* @__PURE__ */ Object.create(null);
  function add3(obj) {
    for (let prop2 in obj)
      if (!Object.prototype.hasOwnProperty.call(result, prop2))
        result[prop2] = obj[prop2];
  }
  __name(add3, "add");
  view.someProp("nodeViews", add3);
  view.someProp("markViews", add3);
  return result;
}
__name(buildNodeViews, "buildNodeViews");
function changedNodeViews(a2, b2) {
  let nA = 0, nB = 0;
  for (let prop2 in a2) {
    if (a2[prop2] != b2[prop2])
      return true;
    nA++;
  }
  for (let _2 in b2)
    nB++;
  return nA != nB;
}
__name(changedNodeViews, "changedNodeViews");
function checkStateComponent(plugin) {
  if (plugin.spec.state || plugin.spec.filterTransaction || plugin.spec.appendTransaction)
    throw new RangeError("Plugins passed directly to the view must not have a state component");
}
__name(checkStateComponent, "checkStateComponent");
var base$1 = {
  8: "Backspace",
  9: "Tab",
  10: "Enter",
  12: "NumLock",
  13: "Enter",
  16: "Shift",
  17: "Control",
  18: "Alt",
  20: "CapsLock",
  27: "Escape",
  32: " ",
  33: "PageUp",
  34: "PageDown",
  35: "End",
  36: "Home",
  37: "ArrowLeft",
  38: "ArrowUp",
  39: "ArrowRight",
  40: "ArrowDown",
  44: "PrintScreen",
  45: "Insert",
  46: "Delete",
  59: ";",
  61: "=",
  91: "Meta",
  92: "Meta",
  106: "*",
  107: "+",
  108: ",",
  109: "-",
  110: ".",
  111: "/",
  144: "NumLock",
  145: "ScrollLock",
  160: "Shift",
  161: "Shift",
  162: "Control",
  163: "Control",
  164: "Alt",
  165: "Alt",
  173: "-",
  186: ";",
  187: "=",
  188: ",",
  189: "-",
  190: ".",
  191: "/",
  192: "`",
  219: "[",
  220: "\\",
  221: "]",
  222: "'"
};
var shift = {
  48: ")",
  49: "!",
  50: "@",
  51: "#",
  52: "$",
  53: "%",
  54: "^",
  55: "&",
  56: "*",
  57: "(",
  59: ":",
  61: "+",
  173: "_",
  186: ":",
  187: "+",
  188: "<",
  189: "_",
  190: ">",
  191: "?",
  192: "~",
  219: "{",
  220: "|",
  221: "}",
  222: '"'
};
var mac$2 = typeof navigator != "undefined" && /Mac/.test(navigator.platform);
var ie = typeof navigator != "undefined" && /MSIE \d|Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(navigator.userAgent);
for (var i = 0; i < 10; i++) base$1[48 + i] = base$1[96 + i] = String(i);
for (var i = 1; i <= 24; i++) base$1[i + 111] = "F" + i;
for (var i = 65; i <= 90; i++) {
  base$1[i] = String.fromCharCode(i + 32);
  shift[i] = String.fromCharCode(i);
}
for (var code$1 in base$1) if (!shift.hasOwnProperty(code$1)) shift[code$1] = base$1[code$1];
function keyName(event) {
  var ignoreKey = mac$2 && event.metaKey && event.shiftKey && !event.ctrlKey && !event.altKey || ie && event.shiftKey && event.key && event.key.length == 1 || event.key == "Unidentified";
  var name2 = !ignoreKey && event.key || (event.shiftKey ? shift : base$1)[event.keyCode] || event.key || "Unidentified";
  if (name2 == "Esc") name2 = "Escape";
  if (name2 == "Del") name2 = "Delete";
  if (name2 == "Left") name2 = "ArrowLeft";
  if (name2 == "Up") name2 = "ArrowUp";
  if (name2 == "Right") name2 = "ArrowRight";
  if (name2 == "Down") name2 = "ArrowDown";
  return name2;
}
__name(keyName, "keyName");
const mac$1 = typeof navigator != "undefined" ? /Mac|iP(hone|[oa]d)/.test(navigator.platform) : false;
function normalizeKeyName$1(name2) {
  let parts2 = name2.split(/-(?!$)/), result = parts2[parts2.length - 1];
  if (result == "Space")
    result = " ";
  let alt, ctrl, shift2, meta;
  for (let i2 = 0; i2 < parts2.length - 1; i2++) {
    let mod = parts2[i2];
    if (/^(cmd|meta|m)$/i.test(mod))
      meta = true;
    else if (/^a(lt)?$/i.test(mod))
      alt = true;
    else if (/^(c|ctrl|control)$/i.test(mod))
      ctrl = true;
    else if (/^s(hift)?$/i.test(mod))
      shift2 = true;
    else if (/^mod$/i.test(mod)) {
      if (mac$1)
        meta = true;
      else
        ctrl = true;
    } else
      throw new Error("Unrecognized modifier name: " + mod);
  }
  if (alt)
    result = "Alt-" + result;
  if (ctrl)
    result = "Ctrl-" + result;
  if (meta)
    result = "Meta-" + result;
  if (shift2)
    result = "Shift-" + result;
  return result;
}
__name(normalizeKeyName$1, "normalizeKeyName$1");
function normalize$1(map3) {
  let copy2 = /* @__PURE__ */ Object.create(null);
  for (let prop2 in map3)
    copy2[normalizeKeyName$1(prop2)] = map3[prop2];
  return copy2;
}
__name(normalize$1, "normalize$1");
function modifiers(name2, event, shift2 = true) {
  if (event.altKey)
    name2 = "Alt-" + name2;
  if (event.ctrlKey)
    name2 = "Ctrl-" + name2;
  if (event.metaKey)
    name2 = "Meta-" + name2;
  if (shift2 && event.shiftKey)
    name2 = "Shift-" + name2;
  return name2;
}
__name(modifiers, "modifiers");
function keymap(bindings) {
  return new Plugin({ props: { handleKeyDown: keydownHandler(bindings) } });
}
__name(keymap, "keymap");
function keydownHandler(bindings) {
  let map3 = normalize$1(bindings);
  return function(view, event) {
    let name2 = keyName(event), baseName, direct = map3[modifiers(name2, event)];
    if (direct && direct(view.state, view.dispatch, view))
      return true;
    if (name2.length == 1 && name2 != " ") {
      if (event.shiftKey) {
        let noShift = map3[modifiers(name2, event, false)];
        if (noShift && noShift(view.state, view.dispatch, view))
          return true;
      }
      if ((event.shiftKey || event.altKey || event.metaKey || name2.charCodeAt(0) > 127) && (baseName = base$1[event.keyCode]) && baseName != name2) {
        let fromCode = map3[modifiers(baseName, event)];
        if (fromCode && fromCode(view.state, view.dispatch, view))
          return true;
      }
    }
    return false;
  };
}
__name(keydownHandler, "keydownHandler");
const deleteSelection$1 = /* @__PURE__ */ __name((state, dispatch) => {
  if (state.selection.empty)
    return false;
  if (dispatch)
    dispatch(state.tr.deleteSelection().scrollIntoView());
  return true;
}, "deleteSelection$1");
function atBlockStart(state, view) {
  let { $cursor } = state.selection;
  if (!$cursor || (view ? !view.endOfTextblock("backward", state) : $cursor.parentOffset > 0))
    return null;
  return $cursor;
}
__name(atBlockStart, "atBlockStart");
const joinBackward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let $cursor = atBlockStart(state, view);
  if (!$cursor)
    return false;
  let $cut = findCutBefore($cursor);
  if (!$cut) {
    let range2 = $cursor.blockRange(), target2 = range2 && liftTarget(range2);
    if (target2 == null)
      return false;
    if (dispatch)
      dispatch(state.tr.lift(range2, target2).scrollIntoView());
    return true;
  }
  let before = $cut.nodeBefore;
  if (deleteBarrier(state, $cut, dispatch, -1))
    return true;
  if ($cursor.parent.content.size == 0 && (textblockAt(before, "end") || NodeSelection.isSelectable(before))) {
    for (let depth = $cursor.depth; ; depth--) {
      let delStep = replaceStep(state.doc, $cursor.before(depth), $cursor.after(depth), Slice.empty);
      if (delStep && delStep.slice.size < delStep.to - delStep.from) {
        if (dispatch) {
          let tr2 = state.tr.step(delStep);
          tr2.setSelection(textblockAt(before, "end") ? Selection.findFrom(tr2.doc.resolve(tr2.mapping.map($cut.pos, -1)), -1) : NodeSelection.create(tr2.doc, $cut.pos - before.nodeSize));
          dispatch(tr2.scrollIntoView());
        }
        return true;
      }
      if (depth == 1 || $cursor.node(depth - 1).childCount > 1)
        break;
    }
  }
  if (before.isAtom && $cut.depth == $cursor.depth - 1) {
    if (dispatch)
      dispatch(state.tr.delete($cut.pos - before.nodeSize, $cut.pos).scrollIntoView());
    return true;
  }
  return false;
}, "joinBackward$1");
const joinTextblockBackward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let $cursor = atBlockStart(state, view);
  if (!$cursor)
    return false;
  let $cut = findCutBefore($cursor);
  return $cut ? joinTextblocksAround(state, $cut, dispatch) : false;
}, "joinTextblockBackward$1");
const joinTextblockForward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let $cursor = atBlockEnd(state, view);
  if (!$cursor)
    return false;
  let $cut = findCutAfter($cursor);
  return $cut ? joinTextblocksAround(state, $cut, dispatch) : false;
}, "joinTextblockForward$1");
function joinTextblocksAround(state, $cut, dispatch) {
  let before = $cut.nodeBefore, beforeText = before, beforePos = $cut.pos - 1;
  for (; !beforeText.isTextblock; beforePos--) {
    if (beforeText.type.spec.isolating)
      return false;
    let child = beforeText.lastChild;
    if (!child)
      return false;
    beforeText = child;
  }
  let after = $cut.nodeAfter, afterText = after, afterPos = $cut.pos + 1;
  for (; !afterText.isTextblock; afterPos++) {
    if (afterText.type.spec.isolating)
      return false;
    let child = afterText.firstChild;
    if (!child)
      return false;
    afterText = child;
  }
  let step2 = replaceStep(state.doc, beforePos, afterPos, Slice.empty);
  if (!step2 || step2.from != beforePos || step2 instanceof ReplaceStep && step2.slice.size >= afterPos - beforePos)
    return false;
  if (dispatch) {
    let tr2 = state.tr.step(step2);
    tr2.setSelection(TextSelection.create(tr2.doc, beforePos));
    dispatch(tr2.scrollIntoView());
  }
  return true;
}
__name(joinTextblocksAround, "joinTextblocksAround");
function textblockAt(node3, side, only = false) {
  for (let scan = node3; scan; scan = side == "start" ? scan.firstChild : scan.lastChild) {
    if (scan.isTextblock)
      return true;
    if (only && scan.childCount != 1)
      return false;
  }
  return false;
}
__name(textblockAt, "textblockAt");
const selectNodeBackward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let { $head, empty: empty2 } = state.selection, $cut = $head;
  if (!empty2)
    return false;
  if ($head.parent.isTextblock) {
    if (view ? !view.endOfTextblock("backward", state) : $head.parentOffset > 0)
      return false;
    $cut = findCutBefore($head);
  }
  let node3 = $cut && $cut.nodeBefore;
  if (!node3 || !NodeSelection.isSelectable(node3))
    return false;
  if (dispatch)
    dispatch(state.tr.setSelection(NodeSelection.create(state.doc, $cut.pos - node3.nodeSize)).scrollIntoView());
  return true;
}, "selectNodeBackward$1");
function findCutBefore($pos) {
  if (!$pos.parent.type.spec.isolating)
    for (let i2 = $pos.depth - 1; i2 >= 0; i2--) {
      if ($pos.index(i2) > 0)
        return $pos.doc.resolve($pos.before(i2 + 1));
      if ($pos.node(i2).type.spec.isolating)
        break;
    }
  return null;
}
__name(findCutBefore, "findCutBefore");
function atBlockEnd(state, view) {
  let { $cursor } = state.selection;
  if (!$cursor || (view ? !view.endOfTextblock("forward", state) : $cursor.parentOffset < $cursor.parent.content.size))
    return null;
  return $cursor;
}
__name(atBlockEnd, "atBlockEnd");
const joinForward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let $cursor = atBlockEnd(state, view);
  if (!$cursor)
    return false;
  let $cut = findCutAfter($cursor);
  if (!$cut)
    return false;
  let after = $cut.nodeAfter;
  if (deleteBarrier(state, $cut, dispatch, 1))
    return true;
  if ($cursor.parent.content.size == 0 && (textblockAt(after, "start") || NodeSelection.isSelectable(after))) {
    let delStep = replaceStep(state.doc, $cursor.before(), $cursor.after(), Slice.empty);
    if (delStep && delStep.slice.size < delStep.to - delStep.from) {
      if (dispatch) {
        let tr2 = state.tr.step(delStep);
        tr2.setSelection(textblockAt(after, "start") ? Selection.findFrom(tr2.doc.resolve(tr2.mapping.map($cut.pos)), 1) : NodeSelection.create(tr2.doc, tr2.mapping.map($cut.pos)));
        dispatch(tr2.scrollIntoView());
      }
      return true;
    }
  }
  if (after.isAtom && $cut.depth == $cursor.depth - 1) {
    if (dispatch)
      dispatch(state.tr.delete($cut.pos, $cut.pos + after.nodeSize).scrollIntoView());
    return true;
  }
  return false;
}, "joinForward$1");
const selectNodeForward$1 = /* @__PURE__ */ __name((state, dispatch, view) => {
  let { $head, empty: empty2 } = state.selection, $cut = $head;
  if (!empty2)
    return false;
  if ($head.parent.isTextblock) {
    if (view ? !view.endOfTextblock("forward", state) : $head.parentOffset < $head.parent.content.size)
      return false;
    $cut = findCutAfter($head);
  }
  let node3 = $cut && $cut.nodeAfter;
  if (!node3 || !NodeSelection.isSelectable(node3))
    return false;
  if (dispatch)
    dispatch(state.tr.setSelection(NodeSelection.create(state.doc, $cut.pos)).scrollIntoView());
  return true;
}, "selectNodeForward$1");
function findCutAfter($pos) {
  if (!$pos.parent.type.spec.isolating)
    for (let i2 = $pos.depth - 1; i2 >= 0; i2--) {
      let parent = $pos.node(i2);
      if ($pos.index(i2) + 1 < parent.childCount)
        return $pos.doc.resolve($pos.after(i2 + 1));
      if (parent.type.spec.isolating)
        break;
    }
  return null;
}
__name(findCutAfter, "findCutAfter");
const joinUp$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let sel = state.selection, nodeSel = sel instanceof NodeSelection, point;
  if (nodeSel) {
    if (sel.node.isTextblock || !canJoin(state.doc, sel.from))
      return false;
    point = sel.from;
  } else {
    point = joinPoint(state.doc, sel.from, -1);
    if (point == null)
      return false;
  }
  if (dispatch) {
    let tr2 = state.tr.join(point);
    if (nodeSel)
      tr2.setSelection(NodeSelection.create(tr2.doc, point - state.doc.resolve(point).nodeBefore.nodeSize));
    dispatch(tr2.scrollIntoView());
  }
  return true;
}, "joinUp$1");
const joinDown$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let sel = state.selection, point;
  if (sel instanceof NodeSelection) {
    if (sel.node.isTextblock || !canJoin(state.doc, sel.to))
      return false;
    point = sel.to;
  } else {
    point = joinPoint(state.doc, sel.to, 1);
    if (point == null)
      return false;
  }
  if (dispatch)
    dispatch(state.tr.join(point).scrollIntoView());
  return true;
}, "joinDown$1");
const lift$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let { $from, $to } = state.selection;
  let range2 = $from.blockRange($to), target2 = range2 && liftTarget(range2);
  if (target2 == null)
    return false;
  if (dispatch)
    dispatch(state.tr.lift(range2, target2).scrollIntoView());
  return true;
}, "lift$1");
const newlineInCode$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let { $head, $anchor } = state.selection;
  if (!$head.parent.type.spec.code || !$head.sameParent($anchor))
    return false;
  if (dispatch)
    dispatch(state.tr.insertText("\n").scrollIntoView());
  return true;
}, "newlineInCode$1");
function defaultBlockAt$1(match2) {
  for (let i2 = 0; i2 < match2.edgeCount; i2++) {
    let { type } = match2.edge(i2);
    if (type.isTextblock && !type.hasRequiredAttrs())
      return type;
  }
  return null;
}
__name(defaultBlockAt$1, "defaultBlockAt$1");
const exitCode$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let { $head, $anchor } = state.selection;
  if (!$head.parent.type.spec.code || !$head.sameParent($anchor))
    return false;
  let above = $head.node(-1), after = $head.indexAfter(-1), type = defaultBlockAt$1(above.contentMatchAt(after));
  if (!type || !above.canReplaceWith(after, after, type))
    return false;
  if (dispatch) {
    let pos = $head.after(), tr2 = state.tr.replaceWith(pos, pos, type.createAndFill());
    tr2.setSelection(Selection.near(tr2.doc.resolve(pos), 1));
    dispatch(tr2.scrollIntoView());
  }
  return true;
}, "exitCode$1");
const createParagraphNear$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let sel = state.selection, { $from, $to } = sel;
  if (sel instanceof AllSelection || $from.parent.inlineContent || $to.parent.inlineContent)
    return false;
  let type = defaultBlockAt$1($to.parent.contentMatchAt($to.indexAfter()));
  if (!type || !type.isTextblock)
    return false;
  if (dispatch) {
    let side = (!$from.parentOffset && $to.index() < $to.parent.childCount ? $from : $to).pos;
    let tr2 = state.tr.insert(side, type.createAndFill());
    tr2.setSelection(TextSelection.create(tr2.doc, side + 1));
    dispatch(tr2.scrollIntoView());
  }
  return true;
}, "createParagraphNear$1");
const liftEmptyBlock$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let { $cursor } = state.selection;
  if (!$cursor || $cursor.parent.content.size)
    return false;
  if ($cursor.depth > 1 && $cursor.after() != $cursor.end(-1)) {
    let before = $cursor.before();
    if (canSplit(state.doc, before)) {
      if (dispatch)
        dispatch(state.tr.split(before).scrollIntoView());
      return true;
    }
  }
  let range2 = $cursor.blockRange(), target2 = range2 && liftTarget(range2);
  if (target2 == null)
    return false;
  if (dispatch)
    dispatch(state.tr.lift(range2, target2).scrollIntoView());
  return true;
}, "liftEmptyBlock$1");
function splitBlockAs(splitNode) {
  return (state, dispatch) => {
    let { $from, $to } = state.selection;
    if (state.selection instanceof NodeSelection && state.selection.node.isBlock) {
      if (!$from.parentOffset || !canSplit(state.doc, $from.pos))
        return false;
      if (dispatch)
        dispatch(state.tr.split($from.pos).scrollIntoView());
      return true;
    }
    if (!$from.depth)
      return false;
    let types = [];
    let splitDepth, deflt, atEnd = false, atStart = false;
    for (let d2 = $from.depth; ; d2--) {
      let node3 = $from.node(d2);
      if (node3.isBlock) {
        atEnd = $from.end(d2) == $from.pos + ($from.depth - d2);
        atStart = $from.start(d2) == $from.pos - ($from.depth - d2);
        deflt = defaultBlockAt$1($from.node(d2 - 1).contentMatchAt($from.indexAfter(d2 - 1)));
        let splitType = splitNode && splitNode($to.parent, atEnd, $from);
        types.unshift(splitType || (atEnd && deflt ? { type: deflt } : null));
        splitDepth = d2;
        break;
      } else {
        if (d2 == 1)
          return false;
        types.unshift(null);
      }
    }
    let tr2 = state.tr;
    if (state.selection instanceof TextSelection || state.selection instanceof AllSelection)
      tr2.deleteSelection();
    let splitPos = tr2.mapping.map($from.pos);
    let can = canSplit(tr2.doc, splitPos, types.length, types);
    if (!can) {
      types[0] = deflt ? { type: deflt } : null;
      can = canSplit(tr2.doc, splitPos, types.length, types);
    }
    tr2.split(splitPos, types.length, types);
    if (!atEnd && atStart && $from.node(splitDepth).type != deflt) {
      let first2 = tr2.mapping.map($from.before(splitDepth)), $first = tr2.doc.resolve(first2);
      if (deflt && $from.node(splitDepth - 1).canReplaceWith($first.index(), $first.index() + 1, deflt))
        tr2.setNodeMarkup(tr2.mapping.map($from.before(splitDepth)), deflt);
    }
    if (dispatch)
      dispatch(tr2.scrollIntoView());
    return true;
  };
}
__name(splitBlockAs, "splitBlockAs");
const splitBlock$1 = splitBlockAs();
const splitBlockKeepMarks = /* @__PURE__ */ __name((state, dispatch) => {
  return splitBlock$1(state, dispatch && ((tr2) => {
    let marks = state.storedMarks || state.selection.$to.parentOffset && state.selection.$from.marks();
    if (marks)
      tr2.ensureMarks(marks);
    dispatch(tr2);
  }));
}, "splitBlockKeepMarks");
const selectParentNode$1 = /* @__PURE__ */ __name((state, dispatch) => {
  let { $from, to } = state.selection, pos;
  let same = $from.sharedDepth(to);
  if (same == 0)
    return false;
  pos = $from.before(same);
  if (dispatch)
    dispatch(state.tr.setSelection(NodeSelection.create(state.doc, pos)));
  return true;
}, "selectParentNode$1");
const selectAll$1 = /* @__PURE__ */ __name((state, dispatch) => {
  if (dispatch)
    dispatch(state.tr.setSelection(new AllSelection(state.doc)));
  return true;
}, "selectAll$1");
function joinMaybeClear(state, $pos, dispatch) {
  let before = $pos.nodeBefore, after = $pos.nodeAfter, index2 = $pos.index();
  if (!before || !after || !before.type.compatibleContent(after.type))
    return false;
  if (!before.content.size && $pos.parent.canReplace(index2 - 1, index2)) {
    if (dispatch)
      dispatch(state.tr.delete($pos.pos - before.nodeSize, $pos.pos).scrollIntoView());
    return true;
  }
  if (!$pos.parent.canReplace(index2, index2 + 1) || !(after.isTextblock || canJoin(state.doc, $pos.pos)))
    return false;
  if (dispatch)
    dispatch(state.tr.join($pos.pos).scrollIntoView());
  return true;
}
__name(joinMaybeClear, "joinMaybeClear");
function deleteBarrier(state, $cut, dispatch, dir) {
  let before = $cut.nodeBefore, after = $cut.nodeAfter, conn, match2;
  let isolated = before.type.spec.isolating || after.type.spec.isolating;
  if (!isolated && joinMaybeClear(state, $cut, dispatch))
    return true;
  let canDelAfter = !isolated && $cut.parent.canReplace($cut.index(), $cut.index() + 1);
  if (canDelAfter && (conn = (match2 = before.contentMatchAt(before.childCount)).findWrapping(after.type)) && match2.matchType(conn[0] || after.type).validEnd) {
    if (dispatch) {
      let end = $cut.pos + after.nodeSize, wrap2 = Fragment.empty;
      for (let i2 = conn.length - 1; i2 >= 0; i2--)
        wrap2 = Fragment.from(conn[i2].create(null, wrap2));
      wrap2 = Fragment.from(before.copy(wrap2));
      let tr2 = state.tr.step(new ReplaceAroundStep($cut.pos - 1, end, $cut.pos, end, new Slice(wrap2, 1, 0), conn.length, true));
      let $joinAt = tr2.doc.resolve(end + 2 * conn.length);
      if ($joinAt.nodeAfter && $joinAt.nodeAfter.type == before.type && canJoin(tr2.doc, $joinAt.pos))
        tr2.join($joinAt.pos);
      dispatch(tr2.scrollIntoView());
    }
    return true;
  }
  let selAfter = after.type.spec.isolating || dir > 0 && isolated ? null : Selection.findFrom($cut, 1);
  let range2 = selAfter && selAfter.$from.blockRange(selAfter.$to), target2 = range2 && liftTarget(range2);
  if (target2 != null && target2 >= $cut.depth) {
    if (dispatch)
      dispatch(state.tr.lift(range2, target2).scrollIntoView());
    return true;
  }
  if (canDelAfter && textblockAt(after, "start", true) && textblockAt(before, "end")) {
    let at = before, wrap2 = [];
    for (; ; ) {
      wrap2.push(at);
      if (at.isTextblock)
        break;
      at = at.lastChild;
    }
    let afterText = after, afterDepth = 1;
    for (; !afterText.isTextblock; afterText = afterText.firstChild)
      afterDepth++;
    if (at.canReplace(at.childCount, at.childCount, afterText.content)) {
      if (dispatch) {
        let end = Fragment.empty;
        for (let i2 = wrap2.length - 1; i2 >= 0; i2--)
          end = Fragment.from(wrap2[i2].copy(end));
        let tr2 = state.tr.step(new ReplaceAroundStep($cut.pos - wrap2.length, $cut.pos + after.nodeSize, $cut.pos + afterDepth, $cut.pos + after.nodeSize - afterDepth, new Slice(end, wrap2.length, 0), 0, true));
        dispatch(tr2.scrollIntoView());
      }
      return true;
    }
  }
  return false;
}
__name(deleteBarrier, "deleteBarrier");
function selectTextblockSide(side) {
  return function(state, dispatch) {
    let sel = state.selection, $pos = side < 0 ? sel.$from : sel.$to;
    let depth = $pos.depth;
    while ($pos.node(depth).isInline) {
      if (!depth)
        return false;
      depth--;
    }
    if (!$pos.node(depth).isTextblock)
      return false;
    if (dispatch)
      dispatch(state.tr.setSelection(TextSelection.create(state.doc, side < 0 ? $pos.start(depth) : $pos.end(depth))));
    return true;
  };
}
__name(selectTextblockSide, "selectTextblockSide");
const selectTextblockStart$1 = selectTextblockSide(-1);
const selectTextblockEnd$1 = selectTextblockSide(1);
function wrapIn$1(nodeType, attrs7 = null) {
  return function(state, dispatch) {
    let { $from, $to } = state.selection;
    let range2 = $from.blockRange($to), wrapping = range2 && findWrapping(range2, nodeType, attrs7);
    if (!wrapping)
      return false;
    if (dispatch)
      dispatch(state.tr.wrap(range2, wrapping).scrollIntoView());
    return true;
  };
}
__name(wrapIn$1, "wrapIn$1");
function setBlockType(nodeType, attrs7 = null) {
  return function(state, dispatch) {
    let applicable = false;
    for (let i2 = 0; i2 < state.selection.ranges.length && !applicable; i2++) {
      let { $from: { pos: from2 }, $to: { pos: to } } = state.selection.ranges[i2];
      state.doc.nodesBetween(from2, to, (node3, pos) => {
        if (applicable)
          return false;
        if (!node3.isTextblock || node3.hasMarkup(nodeType, attrs7))
          return;
        if (node3.type == nodeType) {
          applicable = true;
        } else {
          let $pos = state.doc.resolve(pos), index2 = $pos.index();
          applicable = $pos.parent.canReplaceWith(index2, index2 + 1, nodeType);
        }
      });
    }
    if (!applicable)
      return false;
    if (dispatch) {
      let tr2 = state.tr;
      for (let i2 = 0; i2 < state.selection.ranges.length; i2++) {
        let { $from: { pos: from2 }, $to: { pos: to } } = state.selection.ranges[i2];
        tr2.setBlockType(from2, to, nodeType, attrs7);
      }
      dispatch(tr2.scrollIntoView());
    }
    return true;
  };
}
__name(setBlockType, "setBlockType");
function markApplies(doc2, ranges, type, enterAtoms) {
  for (let i2 = 0; i2 < ranges.length; i2++) {
    let { $from, $to } = ranges[i2];
    let can = $from.depth == 0 ? doc2.inlineContent && doc2.type.allowsMarkType(type) : false;
    doc2.nodesBetween($from.pos, $to.pos, (node3, pos) => {
      if (can || !enterAtoms && node3.isAtom && node3.isInline && pos >= $from.pos && pos + node3.nodeSize <= $to.pos)
        return false;
      can = node3.inlineContent && node3.type.allowsMarkType(type);
    });
    if (can)
      return true;
  }
  return false;
}
__name(markApplies, "markApplies");
function removeInlineAtoms(ranges) {
  let result = [];
  for (let i2 = 0; i2 < ranges.length; i2++) {
    let { $from, $to } = ranges[i2];
    $from.doc.nodesBetween($from.pos, $to.pos, (node3, pos) => {
      if (node3.isAtom && node3.content.size && node3.isInline && pos >= $from.pos && pos + node3.nodeSize <= $to.pos) {
        if (pos + 1 > $from.pos)
          result.push(new SelectionRange($from, $from.doc.resolve(pos + 1)));
        $from = $from.doc.resolve(pos + 1 + node3.content.size);
        return false;
      }
    });
    if ($from.pos < $to.pos)
      result.push(new SelectionRange($from, $to));
  }
  return result;
}
__name(removeInlineAtoms, "removeInlineAtoms");
function toggleMark$1(markType, attrs7 = null, options5) {
  let removeWhenPresent = (options5 && options5.removeWhenPresent) !== false;
  let enterAtoms = (options5 && options5.enterInlineAtoms) !== false;
  return function(state, dispatch) {
    let { empty: empty2, $cursor, ranges } = state.selection;
    if (empty2 && !$cursor || !markApplies(state.doc, ranges, markType, enterAtoms))
      return false;
    if (dispatch) {
      if ($cursor) {
        if (markType.isInSet(state.storedMarks || $cursor.marks()))
          dispatch(state.tr.removeStoredMark(markType));
        else
          dispatch(state.tr.addStoredMark(markType.create(attrs7)));
      } else {
        let add3, tr2 = state.tr;
        if (!enterAtoms)
          ranges = removeInlineAtoms(ranges);
        if (removeWhenPresent) {
          add3 = !ranges.some((r2) => state.doc.rangeHasMark(r2.$from.pos, r2.$to.pos, markType));
        } else {
          add3 = !ranges.every((r2) => {
            let missing = false;
            tr2.doc.nodesBetween(r2.$from.pos, r2.$to.pos, (node3, pos, parent) => {
              if (missing)
                return false;
              missing = !markType.isInSet(node3.marks) && !!parent && parent.type.allowsMarkType(markType) && !(node3.isText && /^\s*$/.test(node3.textBetween(Math.max(0, r2.$from.pos - pos), Math.min(node3.nodeSize, r2.$to.pos - pos))));
            });
            return !missing;
          });
        }
        for (let i2 = 0; i2 < ranges.length; i2++) {
          let { $from, $to } = ranges[i2];
          if (!add3) {
            tr2.removeMark($from.pos, $to.pos, markType);
          } else {
            let from2 = $from.pos, to = $to.pos, start2 = $from.nodeAfter, end = $to.nodeBefore;
            let spaceStart = start2 && start2.isText ? /^\s*/.exec(start2.text)[0].length : 0;
            let spaceEnd = end && end.isText ? /\s*$/.exec(end.text)[0].length : 0;
            if (from2 + spaceStart < to) {
              from2 += spaceStart;
              to -= spaceEnd;
            }
            tr2.addMark(from2, to, markType.create(attrs7));
          }
        }
        dispatch(tr2.scrollIntoView());
      }
    }
    return true;
  };
}
__name(toggleMark$1, "toggleMark$1");
function wrapDispatchForJoin(dispatch, isJoinable) {
  return (tr2) => {
    if (!tr2.isGeneric)
      return dispatch(tr2);
    let ranges = [];
    for (let i2 = 0; i2 < tr2.mapping.maps.length; i2++) {
      let map3 = tr2.mapping.maps[i2];
      for (let j2 = 0; j2 < ranges.length; j2++)
        ranges[j2] = map3.map(ranges[j2]);
      map3.forEach((_s, _e, from2, to) => ranges.push(from2, to));
    }
    let joinable2 = [];
    for (let i2 = 0; i2 < ranges.length; i2 += 2) {
      let from2 = ranges[i2], to = ranges[i2 + 1];
      let $from = tr2.doc.resolve(from2), depth = $from.sharedDepth(to), parent = $from.node(depth);
      for (let index2 = $from.indexAfter(depth), pos = $from.after(depth + 1); pos <= to; ++index2) {
        let after = parent.maybeChild(index2);
        if (!after)
          break;
        if (index2 && joinable2.indexOf(pos) == -1) {
          let before = parent.child(index2 - 1);
          if (before.type == after.type && isJoinable(before, after))
            joinable2.push(pos);
        }
        pos += after.nodeSize;
      }
    }
    joinable2.sort((a2, b2) => a2 - b2);
    for (let i2 = joinable2.length - 1; i2 >= 0; i2--) {
      if (canJoin(tr2.doc, joinable2[i2]))
        tr2.join(joinable2[i2]);
    }
    dispatch(tr2);
  };
}
__name(wrapDispatchForJoin, "wrapDispatchForJoin");
function autoJoin(command2, isJoinable) {
  let canJoin2 = Array.isArray(isJoinable) ? (node3) => isJoinable.indexOf(node3.type.name) > -1 : isJoinable;
  return (state, dispatch, view) => command2(state, dispatch && wrapDispatchForJoin(dispatch, canJoin2), view);
}
__name(autoJoin, "autoJoin");
function chainCommands(...commands2) {
  return function(state, dispatch, view) {
    for (let i2 = 0; i2 < commands2.length; i2++)
      if (commands2[i2](state, dispatch, view))
        return true;
    return false;
  };
}
__name(chainCommands, "chainCommands");
let backspace = chainCommands(deleteSelection$1, joinBackward$1, selectNodeBackward$1);
let del = chainCommands(deleteSelection$1, joinForward$1, selectNodeForward$1);
const pcBaseKeymap = {
  "Enter": chainCommands(newlineInCode$1, createParagraphNear$1, liftEmptyBlock$1, splitBlock$1),
  "Mod-Enter": exitCode$1,
  "Backspace": backspace,
  "Mod-Backspace": backspace,
  "Shift-Backspace": backspace,
  "Delete": del,
  "Mod-Delete": del,
  "Mod-a": selectAll$1
};
const macBaseKeymap = {
  "Ctrl-h": pcBaseKeymap["Backspace"],
  "Alt-Backspace": pcBaseKeymap["Mod-Backspace"],
  "Ctrl-d": pcBaseKeymap["Delete"],
  "Ctrl-Alt-Backspace": pcBaseKeymap["Mod-Delete"],
  "Alt-Delete": pcBaseKeymap["Mod-Delete"],
  "Alt-d": pcBaseKeymap["Mod-Delete"],
  "Ctrl-a": selectTextblockStart$1,
  "Ctrl-e": selectTextblockEnd$1
};
for (let key in pcBaseKeymap)
  macBaseKeymap[key] = pcBaseKeymap[key];
const mac = typeof navigator != "undefined" ? /Mac|iP(hone|[oa]d)/.test(navigator.platform) : typeof os != "undefined" && os.platform ? os.platform() == "darwin" : false;
const baseKeymap = mac ? macBaseKeymap : pcBaseKeymap;
const olDOM = ["ol", 0], ulDOM = ["ul", 0], liDOM = ["li", 0];
const orderedList = {
  attrs: { order: { default: 1, validate: "number" } },
  parseDOM: [{ tag: "ol", getAttrs(dom) {
    return { order: dom.hasAttribute("start") ? +dom.getAttribute("start") : 1 };
  } }],
  toDOM(node3) {
    return node3.attrs.order == 1 ? olDOM : ["ol", { start: node3.attrs.order }, 0];
  }
};
const bulletList = {
  parseDOM: [{ tag: "ul" }],
  toDOM() {
    return ulDOM;
  }
};
const listItem = {
  parseDOM: [{ tag: "li" }],
  toDOM() {
    return liDOM;
  },
  defining: true
};
function add(obj, props) {
  let copy2 = {};
  for (let prop2 in obj)
    copy2[prop2] = obj[prop2];
  for (let prop2 in props)
    copy2[prop2] = props[prop2];
  return copy2;
}
__name(add, "add");
function addListNodes(nodes, itemContent, listGroup) {
  return nodes.append({
    ordered_list: add(orderedList, { content: "list_item+", group: listGroup }),
    bullet_list: add(bulletList, { content: "list_item+", group: listGroup }),
    list_item: add(listItem, { content: itemContent })
  });
}
__name(addListNodes, "addListNodes");
function wrapInList$1(listType, attrs7 = null) {
  return function(state, dispatch) {
    let { $from, $to } = state.selection;
    let range2 = $from.blockRange($to);
    if (!range2)
      return false;
    let tr2 = dispatch ? state.tr : null;
    if (!wrapRangeInList(tr2, range2, listType, attrs7))
      return false;
    if (dispatch)
      dispatch(tr2.scrollIntoView());
    return true;
  };
}
__name(wrapInList$1, "wrapInList$1");
function wrapRangeInList(tr2, range2, listType, attrs7 = null) {
  let doJoin = false, outerRange = range2, doc2 = range2.$from.doc;
  if (range2.depth >= 2 && range2.$from.node(range2.depth - 1).type.compatibleContent(listType) && range2.startIndex == 0) {
    if (range2.$from.index(range2.depth - 1) == 0)
      return false;
    let $insert = doc2.resolve(range2.start - 2);
    outerRange = new NodeRange($insert, $insert, range2.depth);
    if (range2.endIndex < range2.parent.childCount)
      range2 = new NodeRange(range2.$from, doc2.resolve(range2.$to.end(range2.depth)), range2.depth);
    doJoin = true;
  }
  let wrap2 = findWrapping(outerRange, listType, attrs7, range2);
  if (!wrap2)
    return false;
  if (tr2)
    doWrapInList(tr2, range2, wrap2, doJoin, listType);
  return true;
}
__name(wrapRangeInList, "wrapRangeInList");
function doWrapInList(tr2, range2, wrappers, joinBefore, listType) {
  let content3 = Fragment.empty;
  for (let i2 = wrappers.length - 1; i2 >= 0; i2--)
    content3 = Fragment.from(wrappers[i2].type.create(wrappers[i2].attrs, content3));
  tr2.step(new ReplaceAroundStep(range2.start - (joinBefore ? 2 : 0), range2.end, range2.start, range2.end, new Slice(content3, 0, 0), wrappers.length, true));
  let found2 = 0;
  for (let i2 = 0; i2 < wrappers.length; i2++)
    if (wrappers[i2].type == listType)
      found2 = i2 + 1;
  let splitDepth = wrappers.length - found2;
  let splitPos = range2.start + wrappers.length - (joinBefore ? 2 : 0), parent = range2.parent;
  for (let i2 = range2.startIndex, e2 = range2.endIndex, first2 = true; i2 < e2; i2++, first2 = false) {
    if (!first2 && canSplit(tr2.doc, splitPos, splitDepth)) {
      tr2.split(splitPos, splitDepth);
      splitPos += 2 * splitDepth;
    }
    splitPos += parent.child(i2).nodeSize;
  }
  return tr2;
}
__name(doWrapInList, "doWrapInList");
function splitListItem$1(itemType, itemAttrs) {
  return function(state, dispatch) {
    let { $from, $to, node: node3 } = state.selection;
    if (node3 && node3.isBlock || $from.depth < 2 || !$from.sameParent($to))
      return false;
    let grandParent = $from.node(-1);
    if (grandParent.type != itemType)
      return false;
    if ($from.parent.content.size == 0 && $from.node(-1).childCount == $from.indexAfter(-1)) {
      if ($from.depth == 3 || $from.node(-3).type != itemType || $from.index(-2) != $from.node(-2).childCount - 1)
        return false;
      if (dispatch) {
        let wrap2 = Fragment.empty;
        let depthBefore = $from.index(-1) ? 1 : $from.index(-2) ? 2 : 3;
        for (let d2 = $from.depth - depthBefore; d2 >= $from.depth - 3; d2--)
          wrap2 = Fragment.from($from.node(d2).copy(wrap2));
        let depthAfter = $from.indexAfter(-1) < $from.node(-2).childCount ? 1 : $from.indexAfter(-2) < $from.node(-3).childCount ? 2 : 3;
        wrap2 = wrap2.append(Fragment.from(itemType.createAndFill()));
        let start2 = $from.before($from.depth - (depthBefore - 1));
        let tr3 = state.tr.replace(start2, $from.after(-depthAfter), new Slice(wrap2, 4 - depthBefore, 0));
        let sel = -1;
        tr3.doc.nodesBetween(start2, tr3.doc.content.size, (node4, pos) => {
          if (sel > -1)
            return false;
          if (node4.isTextblock && node4.content.size == 0)
            sel = pos + 1;
        });
        if (sel > -1)
          tr3.setSelection(Selection.near(tr3.doc.resolve(sel)));
        dispatch(tr3.scrollIntoView());
      }
      return true;
    }
    let nextType = $to.pos == $from.end() ? grandParent.contentMatchAt(0).defaultType : null;
    let tr2 = state.tr.delete($from.pos, $to.pos);
    let types = nextType ? [itemAttrs ? { type: itemType, attrs: itemAttrs } : null, { type: nextType }] : void 0;
    if (!canSplit(tr2.doc, $from.pos, 2, types))
      return false;
    if (dispatch)
      dispatch(tr2.split($from.pos, 2, types).scrollIntoView());
    return true;
  };
}
__name(splitListItem$1, "splitListItem$1");
function splitListItemKeepMarks(itemType, itemAttrs) {
  let split2 = splitListItem$1(itemType, itemAttrs);
  return (state, dispatch) => {
    return split2(state, dispatch && ((tr2) => {
      let marks = state.storedMarks || state.selection.$to.parentOffset && state.selection.$from.marks();
      if (marks)
        tr2.ensureMarks(marks);
      dispatch(tr2);
    }));
  };
}
__name(splitListItemKeepMarks, "splitListItemKeepMarks");
function liftListItem$1(itemType) {
  return function(state, dispatch) {
    let { $from, $to } = state.selection;
    let range2 = $from.blockRange($to, (node3) => node3.childCount > 0 && node3.firstChild.type == itemType);
    if (!range2)
      return false;
    if (!dispatch)
      return true;
    if ($from.node(range2.depth - 1).type == itemType)
      return liftToOuterList(state, dispatch, itemType, range2);
    else
      return liftOutOfList(state, dispatch, range2);
  };
}
__name(liftListItem$1, "liftListItem$1");
function liftToOuterList(state, dispatch, itemType, range2) {
  let tr2 = state.tr, end = range2.end, endOfList = range2.$to.end(range2.depth);
  if (end < endOfList) {
    tr2.step(new ReplaceAroundStep(end - 1, endOfList, end, endOfList, new Slice(Fragment.from(itemType.create(null, range2.parent.copy())), 1, 0), 1, true));
    range2 = new NodeRange(tr2.doc.resolve(range2.$from.pos), tr2.doc.resolve(endOfList), range2.depth);
  }
  const target2 = liftTarget(range2);
  if (target2 == null)
    return false;
  tr2.lift(range2, target2);
  let after = tr2.mapping.map(end, -1) - 1;
  if (canJoin(tr2.doc, after))
    tr2.join(after);
  dispatch(tr2.scrollIntoView());
  return true;
}
__name(liftToOuterList, "liftToOuterList");
function liftOutOfList(state, dispatch, range2) {
  let tr2 = state.tr, list2 = range2.parent;
  for (let pos = range2.end, i2 = range2.endIndex - 1, e2 = range2.startIndex; i2 > e2; i2--) {
    pos -= list2.child(i2).nodeSize;
    tr2.delete(pos - 1, pos + 1);
  }
  let $start = tr2.doc.resolve(range2.start), item3 = $start.nodeAfter;
  if (tr2.mapping.map(range2.end) != range2.start + $start.nodeAfter.nodeSize)
    return false;
  let atStart = range2.startIndex == 0, atEnd = range2.endIndex == list2.childCount;
  let parent = $start.node(-1), indexBefore = $start.index(-1);
  if (!parent.canReplace(indexBefore + (atStart ? 0 : 1), indexBefore + 1, item3.content.append(atEnd ? Fragment.empty : Fragment.from(list2))))
    return false;
  let start2 = $start.pos, end = start2 + item3.nodeSize;
  tr2.step(new ReplaceAroundStep(start2 - (atStart ? 1 : 0), end + (atEnd ? 1 : 0), start2 + 1, end - 1, new Slice((atStart ? Fragment.empty : Fragment.from(list2.copy(Fragment.empty))).append(atEnd ? Fragment.empty : Fragment.from(list2.copy(Fragment.empty))), atStart ? 0 : 1, atEnd ? 0 : 1), atStart ? 0 : 1));
  dispatch(tr2.scrollIntoView());
  return true;
}
__name(liftOutOfList, "liftOutOfList");
function sinkListItem$1(itemType) {
  return function(state, dispatch) {
    let { $from, $to } = state.selection;
    let range2 = $from.blockRange($to, (node3) => node3.childCount > 0 && node3.firstChild.type == itemType);
    if (!range2)
      return false;
    let startIndex = range2.startIndex;
    if (startIndex == 0)
      return false;
    let parent = range2.parent, nodeBefore = parent.child(startIndex - 1);
    if (nodeBefore.type != itemType)
      return false;
    if (dispatch) {
      let nestedBefore = nodeBefore.lastChild && nodeBefore.lastChild.type == parent.type;
      let inner = Fragment.from(nestedBefore ? itemType.create() : null);
      let slice2 = new Slice(Fragment.from(itemType.create(null, Fragment.from(parent.type.create(null, inner)))), nestedBefore ? 3 : 1, 0);
      let before = range2.start, after = range2.end;
      dispatch(state.tr.step(new ReplaceAroundStep(before - (nestedBefore ? 3 : 1), after, before, after, slice2, 1, true)).scrollIntoView());
    }
    return true;
  };
}
__name(sinkListItem$1, "sinkListItem$1");
function createChainableState(config2) {
  const { state, transaction } = config2;
  let { selection } = transaction;
  let { doc: doc2 } = transaction;
  let { storedMarks } = transaction;
  return {
    ...state,
    apply: state.apply.bind(state),
    applyTransaction: state.applyTransaction.bind(state),
    plugins: state.plugins,
    schema: state.schema,
    reconfigure: state.reconfigure.bind(state),
    toJSON: state.toJSON.bind(state),
    get storedMarks() {
      return storedMarks;
    },
    get selection() {
      return selection;
    },
    get doc() {
      return doc2;
    },
    get tr() {
      selection = transaction.selection;
      doc2 = transaction.doc;
      storedMarks = transaction.storedMarks;
      return transaction;
    }
  };
}
__name(createChainableState, "createChainableState");
class CommandManager {
  static {
    __name(this, "CommandManager");
  }
  constructor(props) {
    this.editor = props.editor;
    this.rawCommands = this.editor.extensionManager.commands;
    this.customState = props.state;
  }
  get hasCustomState() {
    return !!this.customState;
  }
  get state() {
    return this.customState || this.editor.state;
  }
  get commands() {
    const { rawCommands, editor, state } = this;
    const { view } = editor;
    const { tr: tr2 } = state;
    const props = this.buildProps(tr2);
    return Object.fromEntries(Object.entries(rawCommands).map(([name2, command2]) => {
      const method = /* @__PURE__ */ __name((...args) => {
        const callback = command2(...args)(props);
        if (!tr2.getMeta("preventDispatch") && !this.hasCustomState) {
          view.dispatch(tr2);
        }
        return callback;
      }, "method");
      return [name2, method];
    }));
  }
  get chain() {
    return () => this.createChain();
  }
  get can() {
    return () => this.createCan();
  }
  createChain(startTr, shouldDispatch = true) {
    const { rawCommands, editor, state } = this;
    const { view } = editor;
    const callbacks = [];
    const hasStartTransaction = !!startTr;
    const tr2 = startTr || state.tr;
    const run2 = /* @__PURE__ */ __name(() => {
      if (!hasStartTransaction && shouldDispatch && !tr2.getMeta("preventDispatch") && !this.hasCustomState) {
        view.dispatch(tr2);
      }
      return callbacks.every((callback) => callback === true);
    }, "run");
    const chain = {
      ...Object.fromEntries(Object.entries(rawCommands).map(([name2, command2]) => {
        const chainedCommand = /* @__PURE__ */ __name((...args) => {
          const props = this.buildProps(tr2, shouldDispatch);
          const callback = command2(...args)(props);
          callbacks.push(callback);
          return chain;
        }, "chainedCommand");
        return [name2, chainedCommand];
      })),
      run: run2
    };
    return chain;
  }
  createCan(startTr) {
    const { rawCommands, state } = this;
    const dispatch = false;
    const tr2 = startTr || state.tr;
    const props = this.buildProps(tr2, dispatch);
    const formattedCommands = Object.fromEntries(Object.entries(rawCommands).map(([name2, command2]) => {
      return [name2, (...args) => command2(...args)({ ...props, dispatch: void 0 })];
    }));
    return {
      ...formattedCommands,
      chain: /* @__PURE__ */ __name(() => this.createChain(tr2, dispatch), "chain")
    };
  }
  buildProps(tr2, shouldDispatch = true) {
    const { rawCommands, editor, state } = this;
    const { view } = editor;
    const props = {
      tr: tr2,
      editor,
      view,
      state: createChainableState({
        state,
        transaction: tr2
      }),
      dispatch: shouldDispatch ? () => void 0 : void 0,
      chain: /* @__PURE__ */ __name(() => this.createChain(tr2, shouldDispatch), "chain"),
      can: /* @__PURE__ */ __name(() => this.createCan(tr2), "can"),
      get commands() {
        return Object.fromEntries(Object.entries(rawCommands).map(([name2, command2]) => {
          return [name2, (...args) => command2(...args)(props)];
        }));
      }
    };
    return props;
  }
}
class EventEmitter {
  static {
    __name(this, "EventEmitter");
  }
  constructor() {
    this.callbacks = {};
  }
  on(event, fn) {
    if (!this.callbacks[event]) {
      this.callbacks[event] = [];
    }
    this.callbacks[event].push(fn);
    return this;
  }
  emit(event, ...args) {
    const callbacks = this.callbacks[event];
    if (callbacks) {
      callbacks.forEach((callback) => callback.apply(this, args));
    }
    return this;
  }
  off(event, fn) {
    const callbacks = this.callbacks[event];
    if (callbacks) {
      if (fn) {
        this.callbacks[event] = callbacks.filter((callback) => callback !== fn);
      } else {
        delete this.callbacks[event];
      }
    }
    return this;
  }
  once(event, fn) {
    const onceFn = /* @__PURE__ */ __name((...args) => {
      this.off(event, onceFn);
      fn.apply(this, args);
    }, "onceFn");
    return this.on(event, onceFn);
  }
  removeAllListeners() {
    this.callbacks = {};
  }
}
function getExtensionField(extension, field2, context) {
  if (extension.config[field2] === void 0 && extension.parent) {
    return getExtensionField(extension.parent, field2, context);
  }
  if (typeof extension.config[field2] === "function") {
    const value3 = extension.config[field2].bind({
      ...context,
      parent: extension.parent ? getExtensionField(extension.parent, field2, context) : null
    });
    return value3;
  }
  return extension.config[field2];
}
__name(getExtensionField, "getExtensionField");
function splitExtensions(extensions) {
  const baseExtensions = extensions.filter((extension) => extension.type === "extension");
  const nodeExtensions = extensions.filter((extension) => extension.type === "node");
  const markExtensions = extensions.filter((extension) => extension.type === "mark");
  return {
    baseExtensions,
    nodeExtensions,
    markExtensions
  };
}
__name(splitExtensions, "splitExtensions");
function getAttributesFromExtensions(extensions) {
  const extensionAttributes = [];
  const { nodeExtensions, markExtensions } = splitExtensions(extensions);
  const nodeAndMarkExtensions = [...nodeExtensions, ...markExtensions];
  const defaultAttribute = {
    default: null,
    rendered: true,
    renderHTML: null,
    parseHTML: null,
    keepOnSplit: true,
    isRequired: false
  };
  extensions.forEach((extension) => {
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage,
      extensions: nodeAndMarkExtensions
    };
    const addGlobalAttributes = getExtensionField(extension, "addGlobalAttributes", context);
    if (!addGlobalAttributes) {
      return;
    }
    const globalAttributes = addGlobalAttributes();
    globalAttributes.forEach((globalAttribute) => {
      globalAttribute.types.forEach((type) => {
        Object.entries(globalAttribute.attributes).forEach(([name2, attribute2]) => {
          extensionAttributes.push({
            type,
            name: name2,
            attribute: {
              ...defaultAttribute,
              ...attribute2
            }
          });
        });
      });
    });
  });
  nodeAndMarkExtensions.forEach((extension) => {
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage
    };
    const addAttributes = getExtensionField(extension, "addAttributes", context);
    if (!addAttributes) {
      return;
    }
    const attributes = addAttributes();
    Object.entries(attributes).forEach(([name2, attribute2]) => {
      const mergedAttr = {
        ...defaultAttribute,
        ...attribute2
      };
      if (typeof (mergedAttr === null || mergedAttr === void 0 ? void 0 : mergedAttr.default) === "function") {
        mergedAttr.default = mergedAttr.default();
      }
      if ((mergedAttr === null || mergedAttr === void 0 ? void 0 : mergedAttr.isRequired) && (mergedAttr === null || mergedAttr === void 0 ? void 0 : mergedAttr.default) === void 0) {
        delete mergedAttr.default;
      }
      extensionAttributes.push({
        type: extension.name,
        name: name2,
        attribute: mergedAttr
      });
    });
  });
  return extensionAttributes;
}
__name(getAttributesFromExtensions, "getAttributesFromExtensions");
function getNodeType(nameOrType, schema2) {
  if (typeof nameOrType === "string") {
    if (!schema2.nodes[nameOrType]) {
      throw Error(`There is no node type named '${nameOrType}'. Maybe you forgot to add the extension?`);
    }
    return schema2.nodes[nameOrType];
  }
  return nameOrType;
}
__name(getNodeType, "getNodeType");
function mergeAttributes(...objects) {
  return objects.filter((item3) => !!item3).reduce((items2, item3) => {
    const mergedAttributes = { ...items2 };
    Object.entries(item3).forEach(([key, value3]) => {
      const exists = mergedAttributes[key];
      if (!exists) {
        mergedAttributes[key] = value3;
        return;
      }
      if (key === "class") {
        const valueClasses = value3 ? value3.split(" ") : [];
        const existingClasses = mergedAttributes[key] ? mergedAttributes[key].split(" ") : [];
        const insertClasses = valueClasses.filter((valueClass) => !existingClasses.includes(valueClass));
        mergedAttributes[key] = [...existingClasses, ...insertClasses].join(" ");
      } else if (key === "style") {
        const newStyles = value3 ? value3.split(";").map((style2) => style2.trim()).filter(Boolean) : [];
        const existingStyles = mergedAttributes[key] ? mergedAttributes[key].split(";").map((style2) => style2.trim()).filter(Boolean) : [];
        const styleMap = /* @__PURE__ */ new Map();
        existingStyles.forEach((style2) => {
          const [property, val] = style2.split(":").map((part) => part.trim());
          styleMap.set(property, val);
        });
        newStyles.forEach((style2) => {
          const [property, val] = style2.split(":").map((part) => part.trim());
          styleMap.set(property, val);
        });
        mergedAttributes[key] = Array.from(styleMap.entries()).map(([property, val]) => `${property}: ${val}`).join("; ");
      } else {
        mergedAttributes[key] = value3;
      }
    });
    return mergedAttributes;
  }, {});
}
__name(mergeAttributes, "mergeAttributes");
function getRenderedAttributes(nodeOrMark, extensionAttributes) {
  return extensionAttributes.filter((attribute2) => attribute2.type === nodeOrMark.type.name).filter((item3) => item3.attribute.rendered).map((item3) => {
    if (!item3.attribute.renderHTML) {
      return {
        [item3.name]: nodeOrMark.attrs[item3.name]
      };
    }
    return item3.attribute.renderHTML(nodeOrMark.attrs) || {};
  }).reduce((attributes, attribute2) => mergeAttributes(attributes, attribute2), {});
}
__name(getRenderedAttributes, "getRenderedAttributes");
function isFunction$1(value3) {
  return typeof value3 === "function";
}
__name(isFunction$1, "isFunction$1");
function callOrReturn(value3, context = void 0, ...props) {
  if (isFunction$1(value3)) {
    if (context) {
      return value3.bind(context)(...props);
    }
    return value3(...props);
  }
  return value3;
}
__name(callOrReturn, "callOrReturn");
function isEmptyObject(value3 = {}) {
  return Object.keys(value3).length === 0 && value3.constructor === Object;
}
__name(isEmptyObject, "isEmptyObject");
function fromString(value3) {
  if (typeof value3 !== "string") {
    return value3;
  }
  if (value3.match(/^[+-]?(?:\d*\.)?\d+$/)) {
    return Number(value3);
  }
  if (value3 === "true") {
    return true;
  }
  if (value3 === "false") {
    return false;
  }
  return value3;
}
__name(fromString, "fromString");
function injectExtensionAttributesToParseRule(parseRule, extensionAttributes) {
  if ("style" in parseRule) {
    return parseRule;
  }
  return {
    ...parseRule,
    getAttrs: /* @__PURE__ */ __name((node3) => {
      const oldAttributes = parseRule.getAttrs ? parseRule.getAttrs(node3) : parseRule.attrs;
      if (oldAttributes === false) {
        return false;
      }
      const newAttributes = extensionAttributes.reduce((items2, item3) => {
        const value3 = item3.attribute.parseHTML ? item3.attribute.parseHTML(node3) : fromString(node3.getAttribute(item3.name));
        if (value3 === null || value3 === void 0) {
          return items2;
        }
        return {
          ...items2,
          [item3.name]: value3
        };
      }, {});
      return { ...oldAttributes, ...newAttributes };
    }, "getAttrs")
  };
}
__name(injectExtensionAttributesToParseRule, "injectExtensionAttributesToParseRule");
function cleanUpSchemaItem(data30) {
  return Object.fromEntries(
    // @ts-ignore
    Object.entries(data30).filter(([key, value3]) => {
      if (key === "attrs" && isEmptyObject(value3)) {
        return false;
      }
      return value3 !== null && value3 !== void 0;
    })
  );
}
__name(cleanUpSchemaItem, "cleanUpSchemaItem");
function getSchemaByResolvedExtensions(extensions, editor) {
  var _a2;
  const allAttributes = getAttributesFromExtensions(extensions);
  const { nodeExtensions, markExtensions } = splitExtensions(extensions);
  const topNode = (_a2 = nodeExtensions.find((extension) => getExtensionField(extension, "topNode"))) === null || _a2 === void 0 ? void 0 : _a2.name;
  const nodes = Object.fromEntries(nodeExtensions.map((extension) => {
    const extensionAttributes = allAttributes.filter((attribute2) => attribute2.type === extension.name);
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage,
      editor
    };
    const extraNodeFields = extensions.reduce((fields, e2) => {
      const extendNodeSchema = getExtensionField(e2, "extendNodeSchema", context);
      return {
        ...fields,
        ...extendNodeSchema ? extendNodeSchema(extension) : {}
      };
    }, {});
    const schema2 = cleanUpSchemaItem({
      ...extraNodeFields,
      content: callOrReturn(getExtensionField(extension, "content", context)),
      marks: callOrReturn(getExtensionField(extension, "marks", context)),
      group: callOrReturn(getExtensionField(extension, "group", context)),
      inline: callOrReturn(getExtensionField(extension, "inline", context)),
      atom: callOrReturn(getExtensionField(extension, "atom", context)),
      selectable: callOrReturn(getExtensionField(extension, "selectable", context)),
      draggable: callOrReturn(getExtensionField(extension, "draggable", context)),
      code: callOrReturn(getExtensionField(extension, "code", context)),
      whitespace: callOrReturn(getExtensionField(extension, "whitespace", context)),
      linebreakReplacement: callOrReturn(getExtensionField(extension, "linebreakReplacement", context)),
      defining: callOrReturn(getExtensionField(extension, "defining", context)),
      isolating: callOrReturn(getExtensionField(extension, "isolating", context)),
      attrs: Object.fromEntries(extensionAttributes.map((extensionAttribute) => {
        var _a3;
        return [extensionAttribute.name, { default: (_a3 = extensionAttribute === null || extensionAttribute === void 0 ? void 0 : extensionAttribute.attribute) === null || _a3 === void 0 ? void 0 : _a3.default }];
      }))
    });
    const parseHTML = callOrReturn(getExtensionField(extension, "parseHTML", context));
    if (parseHTML) {
      schema2.parseDOM = parseHTML.map((parseRule) => injectExtensionAttributesToParseRule(parseRule, extensionAttributes));
    }
    const renderHTML = getExtensionField(extension, "renderHTML", context);
    if (renderHTML) {
      schema2.toDOM = (node3) => renderHTML({
        node: node3,
        HTMLAttributes: getRenderedAttributes(node3, extensionAttributes)
      });
    }
    const renderText = getExtensionField(extension, "renderText", context);
    if (renderText) {
      schema2.toText = renderText;
    }
    return [extension.name, schema2];
  }));
  const marks = Object.fromEntries(markExtensions.map((extension) => {
    const extensionAttributes = allAttributes.filter((attribute2) => attribute2.type === extension.name);
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage,
      editor
    };
    const extraMarkFields = extensions.reduce((fields, e2) => {
      const extendMarkSchema = getExtensionField(e2, "extendMarkSchema", context);
      return {
        ...fields,
        ...extendMarkSchema ? extendMarkSchema(extension) : {}
      };
    }, {});
    const schema2 = cleanUpSchemaItem({
      ...extraMarkFields,
      inclusive: callOrReturn(getExtensionField(extension, "inclusive", context)),
      excludes: callOrReturn(getExtensionField(extension, "excludes", context)),
      group: callOrReturn(getExtensionField(extension, "group", context)),
      spanning: callOrReturn(getExtensionField(extension, "spanning", context)),
      code: callOrReturn(getExtensionField(extension, "code", context)),
      attrs: Object.fromEntries(extensionAttributes.map((extensionAttribute) => {
        var _a3;
        return [extensionAttribute.name, { default: (_a3 = extensionAttribute === null || extensionAttribute === void 0 ? void 0 : extensionAttribute.attribute) === null || _a3 === void 0 ? void 0 : _a3.default }];
      }))
    });
    const parseHTML = callOrReturn(getExtensionField(extension, "parseHTML", context));
    if (parseHTML) {
      schema2.parseDOM = parseHTML.map((parseRule) => injectExtensionAttributesToParseRule(parseRule, extensionAttributes));
    }
    const renderHTML = getExtensionField(extension, "renderHTML", context);
    if (renderHTML) {
      schema2.toDOM = (mark2) => renderHTML({
        mark: mark2,
        HTMLAttributes: getRenderedAttributes(mark2, extensionAttributes)
      });
    }
    return [extension.name, schema2];
  }));
  return new Schema({
    topNode,
    nodes,
    marks
  });
}
__name(getSchemaByResolvedExtensions, "getSchemaByResolvedExtensions");
function getSchemaTypeByName(name2, schema2) {
  return schema2.nodes[name2] || schema2.marks[name2] || null;
}
__name(getSchemaTypeByName, "getSchemaTypeByName");
function isExtensionRulesEnabled(extension, enabled) {
  if (Array.isArray(enabled)) {
    return enabled.some((enabledExtension) => {
      const name2 = typeof enabledExtension === "string" ? enabledExtension : enabledExtension.name;
      return name2 === extension.name;
    });
  }
  return enabled;
}
__name(isExtensionRulesEnabled, "isExtensionRulesEnabled");
function getHTMLFromFragment(fragment, schema2) {
  const documentFragment = DOMSerializer.fromSchema(schema2).serializeFragment(fragment);
  const temporaryDocument = document.implementation.createHTMLDocument();
  const container = temporaryDocument.createElement("div");
  container.appendChild(documentFragment);
  return container.innerHTML;
}
__name(getHTMLFromFragment, "getHTMLFromFragment");
const getTextContentFromNodes = /* @__PURE__ */ __name(($from, maxMatch = 500) => {
  let textBefore = "";
  const sliceEndPos = $from.parentOffset;
  $from.parent.nodesBetween(Math.max(0, sliceEndPos - maxMatch), sliceEndPos, (node3, pos, parent, index2) => {
    var _a2, _b;
    const chunk = ((_b = (_a2 = node3.type.spec).toText) === null || _b === void 0 ? void 0 : _b.call(_a2, {
      node: node3,
      pos,
      parent,
      index: index2
    })) || node3.textContent || "%leaf%";
    textBefore += node3.isAtom && !node3.isText ? chunk : chunk.slice(0, Math.max(0, sliceEndPos - pos));
  });
  return textBefore;
}, "getTextContentFromNodes");
function isRegExp$1(value3) {
  return Object.prototype.toString.call(value3) === "[object RegExp]";
}
__name(isRegExp$1, "isRegExp$1");
class InputRule {
  static {
    __name(this, "InputRule");
  }
  constructor(config2) {
    this.find = config2.find;
    this.handler = config2.handler;
  }
}
const inputRuleMatcherHandler = /* @__PURE__ */ __name((text2, find2) => {
  if (isRegExp$1(find2)) {
    return find2.exec(text2);
  }
  const inputRuleMatch = find2(text2);
  if (!inputRuleMatch) {
    return null;
  }
  const result = [inputRuleMatch.text];
  result.index = inputRuleMatch.index;
  result.input = text2;
  result.data = inputRuleMatch.data;
  if (inputRuleMatch.replaceWith) {
    if (!inputRuleMatch.text.includes(inputRuleMatch.replaceWith)) {
      console.warn('[tiptap warn]: "inputRuleMatch.replaceWith" must be part of "inputRuleMatch.text".');
    }
    result.push(inputRuleMatch.replaceWith);
  }
  return result;
}, "inputRuleMatcherHandler");
function run$1$1(config2) {
  var _a2;
  const { editor, from: from2, to, text: text2, rules, plugin } = config2;
  const { view } = editor;
  if (view.composing) {
    return false;
  }
  const $from = view.state.doc.resolve(from2);
  if (
    // check for code node
    $from.parent.type.spec.code || !!((_a2 = $from.nodeBefore || $from.nodeAfter) === null || _a2 === void 0 ? void 0 : _a2.marks.find((mark2) => mark2.type.spec.code))
  ) {
    return false;
  }
  let matched = false;
  const textBefore = getTextContentFromNodes($from) + text2;
  rules.forEach((rule) => {
    if (matched) {
      return;
    }
    const match2 = inputRuleMatcherHandler(textBefore, rule.find);
    if (!match2) {
      return;
    }
    const tr2 = view.state.tr;
    const state = createChainableState({
      state: view.state,
      transaction: tr2
    });
    const range2 = {
      from: from2 - (match2[0].length - text2.length),
      to
    };
    const { commands: commands2, chain, can } = new CommandManager({
      editor,
      state
    });
    const handler14 = rule.handler({
      state,
      range: range2,
      match: match2,
      commands: commands2,
      chain,
      can
    });
    if (handler14 === null || !tr2.steps.length) {
      return;
    }
    tr2.setMeta(plugin, {
      transform: tr2,
      from: from2,
      to,
      text: text2
    });
    view.dispatch(tr2);
    matched = true;
  });
  return matched;
}
__name(run$1$1, "run$1$1");
function inputRulesPlugin(props) {
  const { editor, rules } = props;
  const plugin = new Plugin({
    state: {
      init() {
        return null;
      },
      apply(tr2, prev2, state) {
        const stored = tr2.getMeta(plugin);
        if (stored) {
          return stored;
        }
        const simulatedInputMeta = tr2.getMeta("applyInputRules");
        const isSimulatedInput = !!simulatedInputMeta;
        if (isSimulatedInput) {
          setTimeout(() => {
            let { text: text2 } = simulatedInputMeta;
            if (typeof text2 === "string") {
              text2 = text2;
            } else {
              text2 = getHTMLFromFragment(Fragment.from(text2), state.schema);
            }
            const { from: from2 } = simulatedInputMeta;
            const to = from2 + text2.length;
            run$1$1({
              editor,
              from: from2,
              to,
              text: text2,
              rules,
              plugin
            });
          });
        }
        return tr2.selectionSet || tr2.docChanged ? null : prev2;
      }
    },
    props: {
      handleTextInput(view, from2, to, text2) {
        return run$1$1({
          editor,
          from: from2,
          to,
          text: text2,
          rules,
          plugin
        });
      },
      handleDOMEvents: {
        compositionend: /* @__PURE__ */ __name((view) => {
          setTimeout(() => {
            const { $cursor } = view.state.selection;
            if ($cursor) {
              run$1$1({
                editor,
                from: $cursor.pos,
                to: $cursor.pos,
                text: "",
                rules,
                plugin
              });
            }
          });
          return false;
        }, "compositionend")
      },
      // add support for input rules to trigger on enter
      // this is useful for example for code blocks
      handleKeyDown(view, event) {
        if (event.key !== "Enter") {
          return false;
        }
        const { $cursor } = view.state.selection;
        if ($cursor) {
          return run$1$1({
            editor,
            from: $cursor.pos,
            to: $cursor.pos,
            text: "\n",
            rules,
            plugin
          });
        }
        return false;
      }
    },
    // @ts-ignore
    isInputRules: true
  });
  return plugin;
}
__name(inputRulesPlugin, "inputRulesPlugin");
function getType(value3) {
  return Object.prototype.toString.call(value3).slice(8, -1);
}
__name(getType, "getType");
function isPlainObject(value3) {
  if (getType(value3) !== "Object") {
    return false;
  }
  return value3.constructor === Object && Object.getPrototypeOf(value3) === Object.prototype;
}
__name(isPlainObject, "isPlainObject");
function mergeDeep(target2, source) {
  const output = { ...target2 };
  if (isPlainObject(target2) && isPlainObject(source)) {
    Object.keys(source).forEach((key) => {
      if (isPlainObject(source[key]) && isPlainObject(target2[key])) {
        output[key] = mergeDeep(target2[key], source[key]);
      } else {
        output[key] = source[key];
      }
    });
  }
  return output;
}
__name(mergeDeep, "mergeDeep");
class Mark {
  static {
    __name(this, "Mark");
  }
  constructor(config2 = {}) {
    this.type = "mark";
    this.name = "mark";
    this.parent = null;
    this.child = null;
    this.config = {
      name: this.name,
      defaultOptions: {}
    };
    this.config = {
      ...this.config,
      ...config2
    };
    this.name = this.config.name;
    if (config2.defaultOptions && Object.keys(config2.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${this.name}".`);
    }
    this.options = this.config.defaultOptions;
    if (this.config.addOptions) {
      this.options = callOrReturn(getExtensionField(this, "addOptions", {
        name: this.name
      }));
    }
    this.storage = callOrReturn(getExtensionField(this, "addStorage", {
      name: this.name,
      options: this.options
    })) || {};
  }
  static create(config2 = {}) {
    return new Mark(config2);
  }
  configure(options5 = {}) {
    const extension = this.extend({
      ...this.config,
      addOptions: /* @__PURE__ */ __name(() => {
        return mergeDeep(this.options, options5);
      }, "addOptions")
    });
    extension.name = this.name;
    extension.parent = this.parent;
    return extension;
  }
  extend(extendedConfig = {}) {
    const extension = new Mark(extendedConfig);
    extension.parent = this;
    this.child = extension;
    extension.name = extendedConfig.name ? extendedConfig.name : extension.parent.name;
    if (extendedConfig.defaultOptions && Object.keys(extendedConfig.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${extension.name}".`);
    }
    extension.options = callOrReturn(getExtensionField(extension, "addOptions", {
      name: extension.name
    }));
    extension.storage = callOrReturn(getExtensionField(extension, "addStorage", {
      name: extension.name,
      options: extension.options
    }));
    return extension;
  }
  static handleExit({ editor, mark: mark2 }) {
    const { tr: tr2 } = editor.state;
    const currentPos = editor.state.selection.$from;
    const isAtEnd = currentPos.pos === currentPos.end();
    if (isAtEnd) {
      const currentMarks = currentPos.marks();
      const isInMark = !!currentMarks.find((m2) => (m2 === null || m2 === void 0 ? void 0 : m2.type.name) === mark2.name);
      if (!isInMark) {
        return false;
      }
      const removeMark2 = currentMarks.find((m2) => (m2 === null || m2 === void 0 ? void 0 : m2.type.name) === mark2.name);
      if (removeMark2) {
        tr2.removeStoredMark(removeMark2);
      }
      tr2.insertText(" ", currentPos.pos);
      editor.view.dispatch(tr2);
      return true;
    }
    return false;
  }
}
function isNumber$1(value3) {
  return typeof value3 === "number";
}
__name(isNumber$1, "isNumber$1");
class PasteRule {
  static {
    __name(this, "PasteRule");
  }
  constructor(config2) {
    this.find = config2.find;
    this.handler = config2.handler;
  }
}
const pasteRuleMatcherHandler = /* @__PURE__ */ __name((text2, find2, event) => {
  if (isRegExp$1(find2)) {
    return [...text2.matchAll(find2)];
  }
  const matches2 = find2(text2, event);
  if (!matches2) {
    return [];
  }
  return matches2.map((pasteRuleMatch) => {
    const result = [pasteRuleMatch.text];
    result.index = pasteRuleMatch.index;
    result.input = text2;
    result.data = pasteRuleMatch.data;
    if (pasteRuleMatch.replaceWith) {
      if (!pasteRuleMatch.text.includes(pasteRuleMatch.replaceWith)) {
        console.warn('[tiptap warn]: "pasteRuleMatch.replaceWith" must be part of "pasteRuleMatch.text".');
      }
      result.push(pasteRuleMatch.replaceWith);
    }
    return result;
  });
}, "pasteRuleMatcherHandler");
function run$2(config2) {
  const { editor, state, from: from2, to, rule, pasteEvent, dropEvent } = config2;
  const { commands: commands2, chain, can } = new CommandManager({
    editor,
    state
  });
  const handlers2 = [];
  state.doc.nodesBetween(from2, to, (node3, pos) => {
    if (!node3.isTextblock || node3.type.spec.code) {
      return;
    }
    const resolvedFrom = Math.max(from2, pos);
    const resolvedTo = Math.min(to, pos + node3.content.size);
    const textToMatch = node3.textBetween(resolvedFrom - pos, resolvedTo - pos, void 0, "￼");
    const matches2 = pasteRuleMatcherHandler(textToMatch, rule.find, pasteEvent);
    matches2.forEach((match2) => {
      if (match2.index === void 0) {
        return;
      }
      const start2 = resolvedFrom + match2.index + 1;
      const end = start2 + match2[0].length;
      const range2 = {
        from: state.tr.mapping.map(start2),
        to: state.tr.mapping.map(end)
      };
      const handler14 = rule.handler({
        state,
        range: range2,
        match: match2,
        commands: commands2,
        chain,
        can,
        pasteEvent,
        dropEvent
      });
      handlers2.push(handler14);
    });
  });
  const success = handlers2.every((handler14) => handler14 !== null);
  return success;
}
__name(run$2, "run$2");
const createClipboardPasteEvent = /* @__PURE__ */ __name((text2) => {
  var _a2;
  const event = new ClipboardEvent("paste", {
    clipboardData: new DataTransfer()
  });
  (_a2 = event.clipboardData) === null || _a2 === void 0 ? void 0 : _a2.setData("text/html", text2);
  return event;
}, "createClipboardPasteEvent");
function pasteRulesPlugin(props) {
  const { editor, rules } = props;
  let dragSourceElement = null;
  let isPastedFromProseMirror = false;
  let isDroppedFromProseMirror = false;
  let pasteEvent = typeof ClipboardEvent !== "undefined" ? new ClipboardEvent("paste") : null;
  let dropEvent;
  try {
    dropEvent = typeof DragEvent !== "undefined" ? new DragEvent("drop") : null;
  } catch (e2) {
    dropEvent = null;
  }
  const processEvent = /* @__PURE__ */ __name(({ state, from: from2, to, rule, pasteEvt }) => {
    const tr2 = state.tr;
    const chainableState = createChainableState({
      state,
      transaction: tr2
    });
    const handler14 = run$2({
      editor,
      state: chainableState,
      from: Math.max(from2 - 1, 0),
      to: to.b - 1,
      rule,
      pasteEvent: pasteEvt,
      dropEvent
    });
    if (!handler14 || !tr2.steps.length) {
      return;
    }
    try {
      dropEvent = typeof DragEvent !== "undefined" ? new DragEvent("drop") : null;
    } catch (e2) {
      dropEvent = null;
    }
    pasteEvent = typeof ClipboardEvent !== "undefined" ? new ClipboardEvent("paste") : null;
    return tr2;
  }, "processEvent");
  const plugins = rules.map((rule) => {
    return new Plugin({
      // we register a global drag handler to track the current drag source element
      view(view) {
        const handleDragstart = /* @__PURE__ */ __name((event) => {
          var _a2;
          dragSourceElement = ((_a2 = view.dom.parentElement) === null || _a2 === void 0 ? void 0 : _a2.contains(event.target)) ? view.dom.parentElement : null;
        }, "handleDragstart");
        window.addEventListener("dragstart", handleDragstart);
        return {
          destroy() {
            window.removeEventListener("dragstart", handleDragstart);
          }
        };
      },
      props: {
        handleDOMEvents: {
          drop: /* @__PURE__ */ __name((view, event) => {
            isDroppedFromProseMirror = dragSourceElement === view.dom.parentElement;
            dropEvent = event;
            return false;
          }, "drop"),
          paste: /* @__PURE__ */ __name((_view, event) => {
            var _a2;
            const html = (_a2 = event.clipboardData) === null || _a2 === void 0 ? void 0 : _a2.getData("text/html");
            pasteEvent = event;
            isPastedFromProseMirror = !!(html === null || html === void 0 ? void 0 : html.includes("data-pm-slice"));
            return false;
          }, "paste")
        }
      },
      appendTransaction: /* @__PURE__ */ __name((transactions, oldState, state) => {
        const transaction = transactions[0];
        const isPaste = transaction.getMeta("uiEvent") === "paste" && !isPastedFromProseMirror;
        const isDrop = transaction.getMeta("uiEvent") === "drop" && !isDroppedFromProseMirror;
        const simulatedPasteMeta = transaction.getMeta("applyPasteRules");
        const isSimulatedPaste = !!simulatedPasteMeta;
        if (!isPaste && !isDrop && !isSimulatedPaste) {
          return;
        }
        if (isSimulatedPaste) {
          let { text: text2 } = simulatedPasteMeta;
          if (typeof text2 === "string") {
            text2 = text2;
          } else {
            text2 = getHTMLFromFragment(Fragment.from(text2), state.schema);
          }
          const { from: from3 } = simulatedPasteMeta;
          const to2 = from3 + text2.length;
          const pasteEvt = createClipboardPasteEvent(text2);
          return processEvent({
            rule,
            state,
            from: from3,
            to: { b: to2 },
            pasteEvt
          });
        }
        const from2 = oldState.doc.content.findDiffStart(state.doc.content);
        const to = oldState.doc.content.findDiffEnd(state.doc.content);
        if (!isNumber$1(from2) || !to || from2 === to.b) {
          return;
        }
        return processEvent({
          rule,
          state,
          from: from2,
          to,
          pasteEvt: pasteEvent
        });
      }, "appendTransaction")
    });
  });
  return plugins;
}
__name(pasteRulesPlugin, "pasteRulesPlugin");
function findDuplicates(items2) {
  const filtered = items2.filter((el, index2) => items2.indexOf(el) !== index2);
  return Array.from(new Set(filtered));
}
__name(findDuplicates, "findDuplicates");
class ExtensionManager {
  static {
    __name(this, "ExtensionManager");
  }
  constructor(extensions, editor) {
    this.splittableMarks = [];
    this.editor = editor;
    this.extensions = ExtensionManager.resolve(extensions);
    this.schema = getSchemaByResolvedExtensions(this.extensions, editor);
    this.setupExtensions();
  }
  /**
   * Returns a flattened and sorted extension list while
   * also checking for duplicated extensions and warns the user.
   * @param extensions An array of Tiptap extensions
   * @returns An flattened and sorted array of Tiptap extensions
   */
  static resolve(extensions) {
    const resolvedExtensions = ExtensionManager.sort(ExtensionManager.flatten(extensions));
    const duplicatedNames = findDuplicates(resolvedExtensions.map((extension) => extension.name));
    if (duplicatedNames.length) {
      console.warn(`[tiptap warn]: Duplicate extension names found: [${duplicatedNames.map((item3) => `'${item3}'`).join(", ")}]. This can lead to issues.`);
    }
    return resolvedExtensions;
  }
  /**
   * Create a flattened array of extensions by traversing the `addExtensions` field.
   * @param extensions An array of Tiptap extensions
   * @returns A flattened array of Tiptap extensions
   */
  static flatten(extensions) {
    return extensions.map((extension) => {
      const context = {
        name: extension.name,
        options: extension.options,
        storage: extension.storage
      };
      const addExtensions = getExtensionField(extension, "addExtensions", context);
      if (addExtensions) {
        return [extension, ...this.flatten(addExtensions())];
      }
      return extension;
    }).flat(10);
  }
  /**
   * Sort extensions by priority.
   * @param extensions An array of Tiptap extensions
   * @returns A sorted array of Tiptap extensions by priority
   */
  static sort(extensions) {
    const defaultPriority = 100;
    return extensions.sort((a2, b2) => {
      const priorityA = getExtensionField(a2, "priority") || defaultPriority;
      const priorityB = getExtensionField(b2, "priority") || defaultPriority;
      if (priorityA > priorityB) {
        return -1;
      }
      if (priorityA < priorityB) {
        return 1;
      }
      return 0;
    });
  }
  /**
   * Get all commands from the extensions.
   * @returns An object with all commands where the key is the command name and the value is the command function
   */
  get commands() {
    return this.extensions.reduce((commands2, extension) => {
      const context = {
        name: extension.name,
        options: extension.options,
        storage: extension.storage,
        editor: this.editor,
        type: getSchemaTypeByName(extension.name, this.schema)
      };
      const addCommands = getExtensionField(extension, "addCommands", context);
      if (!addCommands) {
        return commands2;
      }
      return {
        ...commands2,
        ...addCommands()
      };
    }, {});
  }
  /**
   * Get all registered Prosemirror plugins from the extensions.
   * @returns An array of Prosemirror plugins
   */
  get plugins() {
    const { editor } = this;
    const extensions = ExtensionManager.sort([...this.extensions].reverse());
    const inputRules = [];
    const pasteRules = [];
    const allPlugins = extensions.map((extension) => {
      const context = {
        name: extension.name,
        options: extension.options,
        storage: extension.storage,
        editor,
        type: getSchemaTypeByName(extension.name, this.schema)
      };
      const plugins = [];
      const addKeyboardShortcuts = getExtensionField(extension, "addKeyboardShortcuts", context);
      let defaultBindings = {};
      if (extension.type === "mark" && getExtensionField(extension, "exitable", context)) {
        defaultBindings.ArrowRight = () => Mark.handleExit({ editor, mark: extension });
      }
      if (addKeyboardShortcuts) {
        const bindings = Object.fromEntries(Object.entries(addKeyboardShortcuts()).map(([shortcut, method]) => {
          return [shortcut, () => method({ editor })];
        }));
        defaultBindings = { ...defaultBindings, ...bindings };
      }
      const keyMapPlugin = keymap(defaultBindings);
      plugins.push(keyMapPlugin);
      const addInputRules = getExtensionField(extension, "addInputRules", context);
      if (isExtensionRulesEnabled(extension, editor.options.enableInputRules) && addInputRules) {
        inputRules.push(...addInputRules());
      }
      const addPasteRules = getExtensionField(extension, "addPasteRules", context);
      if (isExtensionRulesEnabled(extension, editor.options.enablePasteRules) && addPasteRules) {
        pasteRules.push(...addPasteRules());
      }
      const addProseMirrorPlugins = getExtensionField(extension, "addProseMirrorPlugins", context);
      if (addProseMirrorPlugins) {
        const proseMirrorPlugins = addProseMirrorPlugins();
        plugins.push(...proseMirrorPlugins);
      }
      return plugins;
    }).flat();
    return [
      inputRulesPlugin({
        editor,
        rules: inputRules
      }),
      ...pasteRulesPlugin({
        editor,
        rules: pasteRules
      }),
      ...allPlugins
    ];
  }
  /**
   * Get all attributes from the extensions.
   * @returns An array of attributes
   */
  get attributes() {
    return getAttributesFromExtensions(this.extensions);
  }
  /**
   * Get all node views from the extensions.
   * @returns An object with all node views where the key is the node name and the value is the node view function
   */
  get nodeViews() {
    const { editor } = this;
    const { nodeExtensions } = splitExtensions(this.extensions);
    return Object.fromEntries(nodeExtensions.filter((extension) => !!getExtensionField(extension, "addNodeView")).map((extension) => {
      const extensionAttributes = this.attributes.filter((attribute2) => attribute2.type === extension.name);
      const context = {
        name: extension.name,
        options: extension.options,
        storage: extension.storage,
        editor,
        type: getNodeType(extension.name, this.schema)
      };
      const addNodeView = getExtensionField(extension, "addNodeView", context);
      if (!addNodeView) {
        return [];
      }
      const nodeview = /* @__PURE__ */ __name((node3, view, getPos, decorations, innerDecorations) => {
        const HTMLAttributes = getRenderedAttributes(node3, extensionAttributes);
        return addNodeView()({
          // pass-through
          node: node3,
          view,
          getPos,
          decorations,
          innerDecorations,
          // tiptap-specific
          editor,
          extension,
          HTMLAttributes
        });
      }, "nodeview");
      return [extension.name, nodeview];
    }));
  }
  /**
   * Go through all extensions, create extension storages & setup marks
   * & bind editor event listener.
   */
  setupExtensions() {
    this.extensions.forEach((extension) => {
      var _a2;
      this.editor.extensionStorage[extension.name] = extension.storage;
      const context = {
        name: extension.name,
        options: extension.options,
        storage: extension.storage,
        editor: this.editor,
        type: getSchemaTypeByName(extension.name, this.schema)
      };
      if (extension.type === "mark") {
        const keepOnSplit = (_a2 = callOrReturn(getExtensionField(extension, "keepOnSplit", context))) !== null && _a2 !== void 0 ? _a2 : true;
        if (keepOnSplit) {
          this.splittableMarks.push(extension.name);
        }
      }
      const onBeforeCreate = getExtensionField(extension, "onBeforeCreate", context);
      const onCreate = getExtensionField(extension, "onCreate", context);
      const onUpdate = getExtensionField(extension, "onUpdate", context);
      const onSelectionUpdate = getExtensionField(extension, "onSelectionUpdate", context);
      const onTransaction = getExtensionField(extension, "onTransaction", context);
      const onFocus10 = getExtensionField(extension, "onFocus", context);
      const onBlur12 = getExtensionField(extension, "onBlur", context);
      const onDestroy = getExtensionField(extension, "onDestroy", context);
      if (onBeforeCreate) {
        this.editor.on("beforeCreate", onBeforeCreate);
      }
      if (onCreate) {
        this.editor.on("create", onCreate);
      }
      if (onUpdate) {
        this.editor.on("update", onUpdate);
      }
      if (onSelectionUpdate) {
        this.editor.on("selectionUpdate", onSelectionUpdate);
      }
      if (onTransaction) {
        this.editor.on("transaction", onTransaction);
      }
      if (onFocus10) {
        this.editor.on("focus", onFocus10);
      }
      if (onBlur12) {
        this.editor.on("blur", onBlur12);
      }
      if (onDestroy) {
        this.editor.on("destroy", onDestroy);
      }
    });
  }
}
class Extension {
  static {
    __name(this, "Extension");
  }
  constructor(config2 = {}) {
    this.type = "extension";
    this.name = "extension";
    this.parent = null;
    this.child = null;
    this.config = {
      name: this.name,
      defaultOptions: {}
    };
    this.config = {
      ...this.config,
      ...config2
    };
    this.name = this.config.name;
    if (config2.defaultOptions && Object.keys(config2.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${this.name}".`);
    }
    this.options = this.config.defaultOptions;
    if (this.config.addOptions) {
      this.options = callOrReturn(getExtensionField(this, "addOptions", {
        name: this.name
      }));
    }
    this.storage = callOrReturn(getExtensionField(this, "addStorage", {
      name: this.name,
      options: this.options
    })) || {};
  }
  static create(config2 = {}) {
    return new Extension(config2);
  }
  configure(options5 = {}) {
    const extension = this.extend({
      ...this.config,
      addOptions: /* @__PURE__ */ __name(() => {
        return mergeDeep(this.options, options5);
      }, "addOptions")
    });
    extension.name = this.name;
    extension.parent = this.parent;
    return extension;
  }
  extend(extendedConfig = {}) {
    const extension = new Extension({ ...this.config, ...extendedConfig });
    extension.parent = this;
    this.child = extension;
    extension.name = extendedConfig.name ? extendedConfig.name : extension.parent.name;
    if (extendedConfig.defaultOptions && Object.keys(extendedConfig.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${extension.name}".`);
    }
    extension.options = callOrReturn(getExtensionField(extension, "addOptions", {
      name: extension.name
    }));
    extension.storage = callOrReturn(getExtensionField(extension, "addStorage", {
      name: extension.name,
      options: extension.options
    }));
    return extension;
  }
}
function getTextBetween(startNode, range2, options5) {
  const { from: from2, to } = range2;
  const { blockSeparator = "\n\n", textSerializers = {} } = options5 || {};
  let text2 = "";
  startNode.nodesBetween(from2, to, (node3, pos, parent, index2) => {
    var _a2;
    if (node3.isBlock && pos > from2) {
      text2 += blockSeparator;
    }
    const textSerializer = textSerializers === null || textSerializers === void 0 ? void 0 : textSerializers[node3.type.name];
    if (textSerializer) {
      if (parent) {
        text2 += textSerializer({
          node: node3,
          pos,
          parent,
          index: index2,
          range: range2
        });
      }
      return false;
    }
    if (node3.isText) {
      text2 += (_a2 = node3 === null || node3 === void 0 ? void 0 : node3.text) === null || _a2 === void 0 ? void 0 : _a2.slice(Math.max(from2, pos) - pos, to - pos);
    }
  });
  return text2;
}
__name(getTextBetween, "getTextBetween");
function getTextSerializersFromSchema(schema2) {
  return Object.fromEntries(Object.entries(schema2.nodes).filter(([, node3]) => node3.spec.toText).map(([name2, node3]) => [name2, node3.spec.toText]));
}
__name(getTextSerializersFromSchema, "getTextSerializersFromSchema");
const ClipboardTextSerializer = Extension.create({
  name: "clipboardTextSerializer",
  addOptions() {
    return {
      blockSeparator: void 0
    };
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        key: new PluginKey("clipboardTextSerializer"),
        props: {
          clipboardTextSerializer: /* @__PURE__ */ __name(() => {
            const { editor } = this;
            const { state, schema: schema2 } = editor;
            const { doc: doc2, selection } = state;
            const { ranges } = selection;
            const from2 = Math.min(...ranges.map((range3) => range3.$from.pos));
            const to = Math.max(...ranges.map((range3) => range3.$to.pos));
            const textSerializers = getTextSerializersFromSchema(schema2);
            const range2 = { from: from2, to };
            return getTextBetween(doc2, range2, {
              ...this.options.blockSeparator !== void 0 ? { blockSeparator: this.options.blockSeparator } : {},
              textSerializers
            });
          }, "clipboardTextSerializer")
        }
      })
    ];
  }
});
const blur = /* @__PURE__ */ __name(() => ({ editor, view }) => {
  requestAnimationFrame(() => {
    var _a2;
    if (!editor.isDestroyed) {
      view.dom.blur();
      (_a2 = window === null || window === void 0 ? void 0 : window.getSelection()) === null || _a2 === void 0 ? void 0 : _a2.removeAllRanges();
    }
  });
  return true;
}, "blur");
const clearContent = /* @__PURE__ */ __name((emitUpdate = false) => ({ commands: commands2 }) => {
  return commands2.setContent("", emitUpdate);
}, "clearContent");
const clearNodes = /* @__PURE__ */ __name(() => ({ state, tr: tr2, dispatch }) => {
  const { selection } = tr2;
  const { ranges } = selection;
  if (!dispatch) {
    return true;
  }
  ranges.forEach(({ $from, $to }) => {
    state.doc.nodesBetween($from.pos, $to.pos, (node3, pos) => {
      if (node3.type.isText) {
        return;
      }
      const { doc: doc2, mapping } = tr2;
      const $mappedFrom = doc2.resolve(mapping.map(pos));
      const $mappedTo = doc2.resolve(mapping.map(pos + node3.nodeSize));
      const nodeRange = $mappedFrom.blockRange($mappedTo);
      if (!nodeRange) {
        return;
      }
      const targetLiftDepth = liftTarget(nodeRange);
      if (node3.type.isTextblock) {
        const { defaultType } = $mappedFrom.parent.contentMatchAt($mappedFrom.index());
        tr2.setNodeMarkup(nodeRange.start, defaultType);
      }
      if (targetLiftDepth || targetLiftDepth === 0) {
        tr2.lift(nodeRange, targetLiftDepth);
      }
    });
  });
  return true;
}, "clearNodes");
const command = /* @__PURE__ */ __name((fn) => (props) => {
  return fn(props);
}, "command");
const createParagraphNear = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return createParagraphNear$1(state, dispatch);
}, "createParagraphNear");
const cut = /* @__PURE__ */ __name((originRange, targetPos) => ({ editor, tr: tr2 }) => {
  const { state } = editor;
  const contentSlice = state.doc.slice(originRange.from, originRange.to);
  tr2.deleteRange(originRange.from, originRange.to);
  const newPos = tr2.mapping.map(targetPos);
  tr2.insert(newPos, contentSlice.content);
  tr2.setSelection(new TextSelection(tr2.doc.resolve(newPos - 1)));
  return true;
}, "cut");
const deleteCurrentNode = /* @__PURE__ */ __name(() => ({ tr: tr2, dispatch }) => {
  const { selection } = tr2;
  const currentNode = selection.$anchor.node();
  if (currentNode.content.size > 0) {
    return false;
  }
  const $pos = tr2.selection.$anchor;
  for (let depth = $pos.depth; depth > 0; depth -= 1) {
    const node3 = $pos.node(depth);
    if (node3.type === currentNode.type) {
      if (dispatch) {
        const from2 = $pos.before(depth);
        const to = $pos.after(depth);
        tr2.delete(from2, to).scrollIntoView();
      }
      return true;
    }
  }
  return false;
}, "deleteCurrentNode");
const deleteNode = /* @__PURE__ */ __name((typeOrName) => ({ tr: tr2, state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  const $pos = tr2.selection.$anchor;
  for (let depth = $pos.depth; depth > 0; depth -= 1) {
    const node3 = $pos.node(depth);
    if (node3.type === type) {
      if (dispatch) {
        const from2 = $pos.before(depth);
        const to = $pos.after(depth);
        tr2.delete(from2, to).scrollIntoView();
      }
      return true;
    }
  }
  return false;
}, "deleteNode");
const deleteRange = /* @__PURE__ */ __name((range2) => ({ tr: tr2, dispatch }) => {
  const { from: from2, to } = range2;
  if (dispatch) {
    tr2.delete(from2, to);
  }
  return true;
}, "deleteRange");
const deleteSelection = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return deleteSelection$1(state, dispatch);
}, "deleteSelection");
const enter = /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
  return commands2.keyboardShortcut("Enter");
}, "enter");
const exitCode = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return exitCode$1(state, dispatch);
}, "exitCode");
function objectIncludes(object1, object2, options5 = { strict: true }) {
  const keys2 = Object.keys(object2);
  if (!keys2.length) {
    return true;
  }
  return keys2.every((key) => {
    if (options5.strict) {
      return object2[key] === object1[key];
    }
    if (isRegExp$1(object2[key])) {
      return object2[key].test(object1[key]);
    }
    return object2[key] === object1[key];
  });
}
__name(objectIncludes, "objectIncludes");
function findMarkInSet(marks, type, attributes = {}) {
  return marks.find((item3) => {
    return item3.type === type && objectIncludes(
      // Only check equality for the attributes that are provided
      Object.fromEntries(Object.keys(attributes).map((k2) => [k2, item3.attrs[k2]])),
      attributes
    );
  });
}
__name(findMarkInSet, "findMarkInSet");
function isMarkInSet(marks, type, attributes = {}) {
  return !!findMarkInSet(marks, type, attributes);
}
__name(isMarkInSet, "isMarkInSet");
function getMarkRange($pos, type, attributes) {
  var _a2;
  if (!$pos || !type) {
    return;
  }
  let start2 = $pos.parent.childAfter($pos.parentOffset);
  if (!start2.node || !start2.node.marks.some((mark3) => mark3.type === type)) {
    start2 = $pos.parent.childBefore($pos.parentOffset);
  }
  if (!start2.node || !start2.node.marks.some((mark3) => mark3.type === type)) {
    return;
  }
  attributes = attributes || ((_a2 = start2.node.marks[0]) === null || _a2 === void 0 ? void 0 : _a2.attrs);
  const mark2 = findMarkInSet([...start2.node.marks], type, attributes);
  if (!mark2) {
    return;
  }
  let startIndex = start2.index;
  let startPos = $pos.start() + start2.offset;
  let endIndex = startIndex + 1;
  let endPos = startPos + start2.node.nodeSize;
  while (startIndex > 0 && isMarkInSet([...$pos.parent.child(startIndex - 1).marks], type, attributes)) {
    startIndex -= 1;
    startPos -= $pos.parent.child(startIndex).nodeSize;
  }
  while (endIndex < $pos.parent.childCount && isMarkInSet([...$pos.parent.child(endIndex).marks], type, attributes)) {
    endPos += $pos.parent.child(endIndex).nodeSize;
    endIndex += 1;
  }
  return {
    from: startPos,
    to: endPos
  };
}
__name(getMarkRange, "getMarkRange");
function getMarkType(nameOrType, schema2) {
  if (typeof nameOrType === "string") {
    if (!schema2.marks[nameOrType]) {
      throw Error(`There is no mark type named '${nameOrType}'. Maybe you forgot to add the extension?`);
    }
    return schema2.marks[nameOrType];
  }
  return nameOrType;
}
__name(getMarkType, "getMarkType");
const extendMarkRange = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ tr: tr2, state, dispatch }) => {
  const type = getMarkType(typeOrName, state.schema);
  const { doc: doc2, selection } = tr2;
  const { $from, from: from2, to } = selection;
  if (dispatch) {
    const range2 = getMarkRange($from, type, attributes);
    if (range2 && range2.from <= from2 && range2.to >= to) {
      const newSelection = TextSelection.create(doc2, range2.from, range2.to);
      tr2.setSelection(newSelection);
    }
  }
  return true;
}, "extendMarkRange");
const first = /* @__PURE__ */ __name((commands2) => (props) => {
  const items2 = typeof commands2 === "function" ? commands2(props) : commands2;
  for (let i2 = 0; i2 < items2.length; i2 += 1) {
    if (items2[i2](props)) {
      return true;
    }
  }
  return false;
}, "first");
function isTextSelection(value3) {
  return value3 instanceof TextSelection;
}
__name(isTextSelection, "isTextSelection");
function minMax(value3 = 0, min = 0, max = 0) {
  return Math.min(Math.max(value3, min), max);
}
__name(minMax, "minMax");
function resolveFocusPosition(doc2, position3 = null) {
  if (!position3) {
    return null;
  }
  const selectionAtStart = Selection.atStart(doc2);
  const selectionAtEnd = Selection.atEnd(doc2);
  if (position3 === "start" || position3 === true) {
    return selectionAtStart;
  }
  if (position3 === "end") {
    return selectionAtEnd;
  }
  const minPos = selectionAtStart.from;
  const maxPos = selectionAtEnd.to;
  if (position3 === "all") {
    return TextSelection.create(doc2, minMax(0, minPos, maxPos), minMax(doc2.content.size, minPos, maxPos));
  }
  return TextSelection.create(doc2, minMax(position3, minPos, maxPos), minMax(position3, minPos, maxPos));
}
__name(resolveFocusPosition, "resolveFocusPosition");
function isiOS() {
  return [
    "iPad Simulator",
    "iPhone Simulator",
    "iPod Simulator",
    "iPad",
    "iPhone",
    "iPod"
  ].includes(navigator.platform) || navigator.userAgent.includes("Mac") && "ontouchend" in document;
}
__name(isiOS, "isiOS");
const focus = /* @__PURE__ */ __name((position3 = null, options5 = {}) => ({ editor, view, tr: tr2, dispatch }) => {
  options5 = {
    scrollIntoView: true,
    ...options5
  };
  const delayedFocus = /* @__PURE__ */ __name(() => {
    if (isiOS()) {
      view.dom.focus();
    }
    requestAnimationFrame(() => {
      if (!editor.isDestroyed) {
        view.focus();
        if (options5 === null || options5 === void 0 ? void 0 : options5.scrollIntoView) {
          editor.commands.scrollIntoView();
        }
      }
    });
  }, "delayedFocus");
  if (view.hasFocus() && position3 === null || position3 === false) {
    return true;
  }
  if (dispatch && position3 === null && !isTextSelection(editor.state.selection)) {
    delayedFocus();
    return true;
  }
  const selection = resolveFocusPosition(tr2.doc, position3) || editor.state.selection;
  const isSameSelection = editor.state.selection.eq(selection);
  if (dispatch) {
    if (!isSameSelection) {
      tr2.setSelection(selection);
    }
    if (isSameSelection && tr2.storedMarks) {
      tr2.setStoredMarks(tr2.storedMarks);
    }
    delayedFocus();
  }
  return true;
}, "focus");
const forEach = /* @__PURE__ */ __name((items2, fn) => (props) => {
  return items2.every((item3, index2) => fn(item3, { ...props, index: index2 }));
}, "forEach");
const insertContent = /* @__PURE__ */ __name((value3, options5) => ({ tr: tr2, commands: commands2 }) => {
  return commands2.insertContentAt({ from: tr2.selection.from, to: tr2.selection.to }, value3, options5);
}, "insertContent");
const removeWhitespaces = /* @__PURE__ */ __name((node3) => {
  const children = node3.childNodes;
  for (let i2 = children.length - 1; i2 >= 0; i2 -= 1) {
    const child = children[i2];
    if (child.nodeType === 3 && child.nodeValue && /^(\n\s\s|\n)$/.test(child.nodeValue)) {
      node3.removeChild(child);
    } else if (child.nodeType === 1) {
      removeWhitespaces(child);
    }
  }
  return node3;
}, "removeWhitespaces");
function elementFromString$1(value3) {
  const wrappedValue = `<body>${value3}</body>`;
  const html = new window.DOMParser().parseFromString(wrappedValue, "text/html").body;
  return removeWhitespaces(html);
}
__name(elementFromString$1, "elementFromString$1");
function createNodeFromContent(content3, schema2, options5) {
  if (content3 instanceof Node$2 || content3 instanceof Fragment) {
    return content3;
  }
  options5 = {
    slice: true,
    parseOptions: {},
    ...options5
  };
  const isJSONContent = typeof content3 === "object" && content3 !== null;
  const isTextContent = typeof content3 === "string";
  if (isJSONContent) {
    try {
      const isArrayContent = Array.isArray(content3) && content3.length > 0;
      if (isArrayContent) {
        return Fragment.fromArray(content3.map((item3) => schema2.nodeFromJSON(item3)));
      }
      const node3 = schema2.nodeFromJSON(content3);
      if (options5.errorOnInvalidContent) {
        node3.check();
      }
      return node3;
    } catch (error2) {
      if (options5.errorOnInvalidContent) {
        throw new Error("[tiptap error]: Invalid JSON content", { cause: error2 });
      }
      console.warn("[tiptap warn]: Invalid content.", "Passed value:", content3, "Error:", error2);
      return createNodeFromContent("", schema2, options5);
    }
  }
  if (isTextContent) {
    if (options5.errorOnInvalidContent) {
      let hasInvalidContent = false;
      let invalidContent = "";
      const contentCheckSchema = new Schema({
        topNode: schema2.spec.topNode,
        marks: schema2.spec.marks,
        // Prosemirror's schemas are executed such that: the last to execute, matches last
        // This means that we can add a catch-all node at the end of the schema to catch any content that we don't know how to handle
        nodes: schema2.spec.nodes.append({
          __tiptap__private__unknown__catch__all__node: {
            content: "inline*",
            group: "block",
            parseDOM: [
              {
                tag: "*",
                getAttrs: /* @__PURE__ */ __name((e2) => {
                  hasInvalidContent = true;
                  invalidContent = typeof e2 === "string" ? e2 : e2.outerHTML;
                  return null;
                }, "getAttrs")
              }
            ]
          }
        })
      });
      if (options5.slice) {
        DOMParser.fromSchema(contentCheckSchema).parseSlice(elementFromString$1(content3), options5.parseOptions);
      } else {
        DOMParser.fromSchema(contentCheckSchema).parse(elementFromString$1(content3), options5.parseOptions);
      }
      if (options5.errorOnInvalidContent && hasInvalidContent) {
        throw new Error("[tiptap error]: Invalid HTML content", { cause: new Error(`Invalid element found: ${invalidContent}`) });
      }
    }
    const parser = DOMParser.fromSchema(schema2);
    if (options5.slice) {
      return parser.parseSlice(elementFromString$1(content3), options5.parseOptions).content;
    }
    return parser.parse(elementFromString$1(content3), options5.parseOptions);
  }
  return createNodeFromContent("", schema2, options5);
}
__name(createNodeFromContent, "createNodeFromContent");
function selectionToInsertionEnd(tr2, startLen, bias) {
  const last = tr2.steps.length - 1;
  if (last < startLen) {
    return;
  }
  const step2 = tr2.steps[last];
  if (!(step2 instanceof ReplaceStep || step2 instanceof ReplaceAroundStep)) {
    return;
  }
  const map3 = tr2.mapping.maps[last];
  let end = 0;
  map3.forEach((_from, _to, _newFrom, newTo) => {
    if (end === 0) {
      end = newTo;
    }
  });
  tr2.setSelection(Selection.near(tr2.doc.resolve(end), bias));
}
__name(selectionToInsertionEnd, "selectionToInsertionEnd");
const isFragment = /* @__PURE__ */ __name((nodeOrFragment) => {
  return !("type" in nodeOrFragment);
}, "isFragment");
const insertContentAt = /* @__PURE__ */ __name((position3, value3, options5) => ({ tr: tr2, dispatch, editor }) => {
  var _a2;
  if (dispatch) {
    options5 = {
      parseOptions: editor.options.parseOptions,
      updateSelection: true,
      applyInputRules: false,
      applyPasteRules: false,
      ...options5
    };
    let content3;
    try {
      content3 = createNodeFromContent(value3, editor.schema, {
        parseOptions: {
          preserveWhitespace: "full",
          ...options5.parseOptions
        },
        errorOnInvalidContent: (_a2 = options5.errorOnInvalidContent) !== null && _a2 !== void 0 ? _a2 : editor.options.enableContentCheck
      });
    } catch (e2) {
      editor.emit("contentError", {
        editor,
        error: e2,
        disableCollaboration: /* @__PURE__ */ __name(() => {
          if (editor.storage.collaboration) {
            editor.storage.collaboration.isDisabled = true;
          }
        }, "disableCollaboration")
      });
      return false;
    }
    let { from: from2, to } = typeof position3 === "number" ? { from: position3, to: position3 } : { from: position3.from, to: position3.to };
    let isOnlyTextContent = true;
    let isOnlyBlockContent = true;
    const nodes = isFragment(content3) ? content3 : [content3];
    nodes.forEach((node3) => {
      node3.check();
      isOnlyTextContent = isOnlyTextContent ? node3.isText && node3.marks.length === 0 : false;
      isOnlyBlockContent = isOnlyBlockContent ? node3.isBlock : false;
    });
    if (from2 === to && isOnlyBlockContent) {
      const { parent } = tr2.doc.resolve(from2);
      const isEmptyTextBlock = parent.isTextblock && !parent.type.spec.code && !parent.childCount;
      if (isEmptyTextBlock) {
        from2 -= 1;
        to += 1;
      }
    }
    let newContent;
    if (isOnlyTextContent) {
      if (Array.isArray(value3)) {
        newContent = value3.map((v2) => v2.text || "").join("");
      } else if (value3 instanceof Fragment) {
        let text2 = "";
        value3.forEach((node3) => {
          if (node3.text) {
            text2 += node3.text;
          }
        });
        newContent = text2;
      } else if (typeof value3 === "object" && !!value3 && !!value3.text) {
        newContent = value3.text;
      } else {
        newContent = value3;
      }
      tr2.insertText(newContent, from2, to);
    } else {
      newContent = content3;
      tr2.replaceWith(from2, to, newContent);
    }
    if (options5.updateSelection) {
      selectionToInsertionEnd(tr2, tr2.steps.length - 1, -1);
    }
    if (options5.applyInputRules) {
      tr2.setMeta("applyInputRules", { from: from2, text: newContent });
    }
    if (options5.applyPasteRules) {
      tr2.setMeta("applyPasteRules", { from: from2, text: newContent });
    }
  }
  return true;
}, "insertContentAt");
const joinUp = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinUp$1(state, dispatch);
}, "joinUp");
const joinDown = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinDown$1(state, dispatch);
}, "joinDown");
const joinBackward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinBackward$1(state, dispatch);
}, "joinBackward");
const joinForward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinForward$1(state, dispatch);
}, "joinForward");
const joinItemBackward = /* @__PURE__ */ __name(() => ({ state, dispatch, tr: tr2 }) => {
  try {
    const point = joinPoint(state.doc, state.selection.$from.pos, -1);
    if (point === null || point === void 0) {
      return false;
    }
    tr2.join(point, 2);
    if (dispatch) {
      dispatch(tr2);
    }
    return true;
  } catch (e2) {
    return false;
  }
}, "joinItemBackward");
const joinItemForward = /* @__PURE__ */ __name(() => ({ state, dispatch, tr: tr2 }) => {
  try {
    const point = joinPoint(state.doc, state.selection.$from.pos, 1);
    if (point === null || point === void 0) {
      return false;
    }
    tr2.join(point, 2);
    if (dispatch) {
      dispatch(tr2);
    }
    return true;
  } catch (e2) {
    return false;
  }
}, "joinItemForward");
const joinTextblockBackward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinTextblockBackward$1(state, dispatch);
}, "joinTextblockBackward");
const joinTextblockForward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return joinTextblockForward$1(state, dispatch);
}, "joinTextblockForward");
function isMacOS() {
  return typeof navigator !== "undefined" ? /Mac/.test(navigator.platform) : false;
}
__name(isMacOS, "isMacOS");
function normalizeKeyName(name2) {
  const parts2 = name2.split(/-(?!$)/);
  let result = parts2[parts2.length - 1];
  if (result === "Space") {
    result = " ";
  }
  let alt;
  let ctrl;
  let shift2;
  let meta;
  for (let i2 = 0; i2 < parts2.length - 1; i2 += 1) {
    const mod = parts2[i2];
    if (/^(cmd|meta|m)$/i.test(mod)) {
      meta = true;
    } else if (/^a(lt)?$/i.test(mod)) {
      alt = true;
    } else if (/^(c|ctrl|control)$/i.test(mod)) {
      ctrl = true;
    } else if (/^s(hift)?$/i.test(mod)) {
      shift2 = true;
    } else if (/^mod$/i.test(mod)) {
      if (isiOS() || isMacOS()) {
        meta = true;
      } else {
        ctrl = true;
      }
    } else {
      throw new Error(`Unrecognized modifier name: ${mod}`);
    }
  }
  if (alt) {
    result = `Alt-${result}`;
  }
  if (ctrl) {
    result = `Ctrl-${result}`;
  }
  if (meta) {
    result = `Meta-${result}`;
  }
  if (shift2) {
    result = `Shift-${result}`;
  }
  return result;
}
__name(normalizeKeyName, "normalizeKeyName");
const keyboardShortcut = /* @__PURE__ */ __name((name2) => ({ editor, view, tr: tr2, dispatch }) => {
  const keys2 = normalizeKeyName(name2).split(/-(?!$)/);
  const key = keys2.find((item3) => !["Alt", "Ctrl", "Meta", "Shift"].includes(item3));
  const event = new KeyboardEvent("keydown", {
    key: key === "Space" ? " " : key,
    altKey: keys2.includes("Alt"),
    ctrlKey: keys2.includes("Ctrl"),
    metaKey: keys2.includes("Meta"),
    shiftKey: keys2.includes("Shift"),
    bubbles: true,
    cancelable: true
  });
  const capturedTransaction = editor.captureTransaction(() => {
    view.someProp("handleKeyDown", (f2) => f2(view, event));
  });
  capturedTransaction === null || capturedTransaction === void 0 ? void 0 : capturedTransaction.steps.forEach((step2) => {
    const newStep = step2.map(tr2.mapping);
    if (newStep && dispatch) {
      tr2.maybeStep(newStep);
    }
  });
  return true;
}, "keyboardShortcut");
function isNodeActive(state, typeOrName, attributes = {}) {
  const { from: from2, to, empty: empty2 } = state.selection;
  const type = typeOrName ? getNodeType(typeOrName, state.schema) : null;
  const nodeRanges = [];
  state.doc.nodesBetween(from2, to, (node3, pos) => {
    if (node3.isText) {
      return;
    }
    const relativeFrom = Math.max(from2, pos);
    const relativeTo = Math.min(to, pos + node3.nodeSize);
    nodeRanges.push({
      node: node3,
      from: relativeFrom,
      to: relativeTo
    });
  });
  const selectionRange = to - from2;
  const matchedNodeRanges = nodeRanges.filter((nodeRange) => {
    if (!type) {
      return true;
    }
    return type.name === nodeRange.node.type.name;
  }).filter((nodeRange) => objectIncludes(nodeRange.node.attrs, attributes, { strict: false }));
  if (empty2) {
    return !!matchedNodeRanges.length;
  }
  const range2 = matchedNodeRanges.reduce((sum, nodeRange) => sum + nodeRange.to - nodeRange.from, 0);
  return range2 >= selectionRange;
}
__name(isNodeActive, "isNodeActive");
const lift = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  const isActive2 = isNodeActive(state, type, attributes);
  if (!isActive2) {
    return false;
  }
  return lift$1(state, dispatch);
}, "lift");
const liftEmptyBlock = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return liftEmptyBlock$1(state, dispatch);
}, "liftEmptyBlock");
const liftListItem = /* @__PURE__ */ __name((typeOrName) => ({ state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  return liftListItem$1(type)(state, dispatch);
}, "liftListItem");
const newlineInCode = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return newlineInCode$1(state, dispatch);
}, "newlineInCode");
function getSchemaTypeNameByName(name2, schema2) {
  if (schema2.nodes[name2]) {
    return "node";
  }
  if (schema2.marks[name2]) {
    return "mark";
  }
  return null;
}
__name(getSchemaTypeNameByName, "getSchemaTypeNameByName");
function deleteProps(obj, propOrProps) {
  const props = typeof propOrProps === "string" ? [propOrProps] : propOrProps;
  return Object.keys(obj).reduce((newObj, prop2) => {
    if (!props.includes(prop2)) {
      newObj[prop2] = obj[prop2];
    }
    return newObj;
  }, {});
}
__name(deleteProps, "deleteProps");
const resetAttributes = /* @__PURE__ */ __name((typeOrName, attributes) => ({ tr: tr2, state, dispatch }) => {
  let nodeType = null;
  let markType = null;
  const schemaType = getSchemaTypeNameByName(typeof typeOrName === "string" ? typeOrName : typeOrName.name, state.schema);
  if (!schemaType) {
    return false;
  }
  if (schemaType === "node") {
    nodeType = getNodeType(typeOrName, state.schema);
  }
  if (schemaType === "mark") {
    markType = getMarkType(typeOrName, state.schema);
  }
  if (dispatch) {
    tr2.selection.ranges.forEach((range2) => {
      state.doc.nodesBetween(range2.$from.pos, range2.$to.pos, (node3, pos) => {
        if (nodeType && nodeType === node3.type) {
          tr2.setNodeMarkup(pos, void 0, deleteProps(node3.attrs, attributes));
        }
        if (markType && node3.marks.length) {
          node3.marks.forEach((mark2) => {
            if (markType === mark2.type) {
              tr2.addMark(pos, pos + node3.nodeSize, markType.create(deleteProps(mark2.attrs, attributes)));
            }
          });
        }
      });
    });
  }
  return true;
}, "resetAttributes");
const scrollIntoView = /* @__PURE__ */ __name(() => ({ tr: tr2, dispatch }) => {
  if (dispatch) {
    tr2.scrollIntoView();
  }
  return true;
}, "scrollIntoView");
const selectAll = /* @__PURE__ */ __name(() => ({ tr: tr2, commands: commands2 }) => {
  return commands2.setTextSelection({
    from: 0,
    to: tr2.doc.content.size
  });
}, "selectAll");
const selectNodeBackward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return selectNodeBackward$1(state, dispatch);
}, "selectNodeBackward");
const selectNodeForward = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return selectNodeForward$1(state, dispatch);
}, "selectNodeForward");
const selectParentNode = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return selectParentNode$1(state, dispatch);
}, "selectParentNode");
const selectTextblockEnd = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return selectTextblockEnd$1(state, dispatch);
}, "selectTextblockEnd");
const selectTextblockStart = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  return selectTextblockStart$1(state, dispatch);
}, "selectTextblockStart");
function createDocument(content3, schema2, parseOptions = {}, options5 = {}) {
  return createNodeFromContent(content3, schema2, {
    slice: false,
    parseOptions,
    errorOnInvalidContent: options5.errorOnInvalidContent
  });
}
__name(createDocument, "createDocument");
const setContent = /* @__PURE__ */ __name((content3, emitUpdate = false, parseOptions = {}, options5 = {}) => ({ editor, tr: tr2, dispatch, commands: commands2 }) => {
  var _a2, _b;
  const { doc: doc2 } = tr2;
  if (parseOptions.preserveWhitespace !== "full") {
    const document2 = createDocument(content3, editor.schema, parseOptions, {
      errorOnInvalidContent: (_a2 = options5.errorOnInvalidContent) !== null && _a2 !== void 0 ? _a2 : editor.options.enableContentCheck
    });
    if (dispatch) {
      tr2.replaceWith(0, doc2.content.size, document2).setMeta("preventUpdate", !emitUpdate);
    }
    return true;
  }
  if (dispatch) {
    tr2.setMeta("preventUpdate", !emitUpdate);
  }
  return commands2.insertContentAt({ from: 0, to: doc2.content.size }, content3, {
    parseOptions,
    errorOnInvalidContent: (_b = options5.errorOnInvalidContent) !== null && _b !== void 0 ? _b : editor.options.enableContentCheck
  });
}, "setContent");
function getMarkAttributes(state, typeOrName) {
  const type = getMarkType(typeOrName, state.schema);
  const { from: from2, to, empty: empty2 } = state.selection;
  const marks = [];
  if (empty2) {
    if (state.storedMarks) {
      marks.push(...state.storedMarks);
    }
    marks.push(...state.selection.$head.marks());
  } else {
    state.doc.nodesBetween(from2, to, (node3) => {
      marks.push(...node3.marks);
    });
  }
  const mark2 = marks.find((markItem) => markItem.type.name === type.name);
  if (!mark2) {
    return {};
  }
  return { ...mark2.attrs };
}
__name(getMarkAttributes, "getMarkAttributes");
function combineTransactionSteps(oldDoc, transactions) {
  const transform2 = new Transform(oldDoc);
  transactions.forEach((transaction) => {
    transaction.steps.forEach((step2) => {
      transform2.step(step2);
    });
  });
  return transform2;
}
__name(combineTransactionSteps, "combineTransactionSteps");
function defaultBlockAt(match2) {
  for (let i2 = 0; i2 < match2.edgeCount; i2 += 1) {
    const { type } = match2.edge(i2);
    if (type.isTextblock && !type.hasRequiredAttrs()) {
      return type;
    }
  }
  return null;
}
__name(defaultBlockAt, "defaultBlockAt");
function findChildren(node3, predicate) {
  const nodesWithPos = [];
  node3.descendants((child, pos) => {
    if (predicate(child)) {
      nodesWithPos.push({
        node: child,
        pos
      });
    }
  });
  return nodesWithPos;
}
__name(findChildren, "findChildren");
function findChildrenInRange(node3, range2, predicate) {
  const nodesWithPos = [];
  node3.nodesBetween(range2.from, range2.to, (child, pos) => {
    if (predicate(child)) {
      nodesWithPos.push({
        node: child,
        pos
      });
    }
  });
  return nodesWithPos;
}
__name(findChildrenInRange, "findChildrenInRange");
function findParentNodeClosestToPos($pos, predicate) {
  for (let i2 = $pos.depth; i2 > 0; i2 -= 1) {
    const node3 = $pos.node(i2);
    if (predicate(node3)) {
      return {
        pos: i2 > 0 ? $pos.before(i2) : 0,
        start: $pos.start(i2),
        depth: i2,
        node: node3
      };
    }
  }
}
__name(findParentNodeClosestToPos, "findParentNodeClosestToPos");
function findParentNode(predicate) {
  return (selection) => findParentNodeClosestToPos(selection.$from, predicate);
}
__name(findParentNode, "findParentNode");
function getSchema(extensions, editor) {
  const resolvedExtensions = ExtensionManager.resolve(extensions);
  return getSchemaByResolvedExtensions(resolvedExtensions, editor);
}
__name(getSchema, "getSchema");
function generateHTML(doc2, extensions) {
  const schema2 = getSchema(extensions);
  const contentNode = Node$2.fromJSON(schema2, doc2);
  return getHTMLFromFragment(contentNode.content, schema2);
}
__name(generateHTML, "generateHTML");
function generateJSON(html, extensions) {
  const schema2 = getSchema(extensions);
  const dom = elementFromString$1(html);
  return DOMParser.fromSchema(schema2).parse(dom).toJSON();
}
__name(generateJSON, "generateJSON");
function getText(node3, options5) {
  const range2 = {
    from: 0,
    to: node3.content.size
  };
  return getTextBetween(node3, range2, options5);
}
__name(getText, "getText");
function generateText(doc2, extensions, options5) {
  const { blockSeparator = "\n\n", textSerializers = {} } = options5 || {};
  const schema2 = getSchema(extensions);
  const contentNode = Node$2.fromJSON(schema2, doc2);
  return getText(contentNode, {
    blockSeparator,
    textSerializers: {
      ...getTextSerializersFromSchema(schema2),
      ...textSerializers
    }
  });
}
__name(generateText, "generateText");
function getNodeAttributes(state, typeOrName) {
  const type = getNodeType(typeOrName, state.schema);
  const { from: from2, to } = state.selection;
  const nodes = [];
  state.doc.nodesBetween(from2, to, (node4) => {
    nodes.push(node4);
  });
  const node3 = nodes.reverse().find((nodeItem) => nodeItem.type.name === type.name);
  if (!node3) {
    return {};
  }
  return { ...node3.attrs };
}
__name(getNodeAttributes, "getNodeAttributes");
function getAttributes(state, typeOrName) {
  const schemaType = getSchemaTypeNameByName(typeof typeOrName === "string" ? typeOrName : typeOrName.name, state.schema);
  if (schemaType === "node") {
    return getNodeAttributes(state, typeOrName);
  }
  if (schemaType === "mark") {
    return getMarkAttributes(state, typeOrName);
  }
  return {};
}
__name(getAttributes, "getAttributes");
function removeDuplicates(array, by = JSON.stringify) {
  const seen2 = {};
  return array.filter((item3) => {
    const key = by(item3);
    return Object.prototype.hasOwnProperty.call(seen2, key) ? false : seen2[key] = true;
  });
}
__name(removeDuplicates, "removeDuplicates");
function simplifyChangedRanges(changes) {
  const uniqueChanges = removeDuplicates(changes);
  return uniqueChanges.length === 1 ? uniqueChanges : uniqueChanges.filter((change, index2) => {
    const rest = uniqueChanges.filter((_2, i2) => i2 !== index2);
    return !rest.some((otherChange) => {
      return change.oldRange.from >= otherChange.oldRange.from && change.oldRange.to <= otherChange.oldRange.to && change.newRange.from >= otherChange.newRange.from && change.newRange.to <= otherChange.newRange.to;
    });
  });
}
__name(simplifyChangedRanges, "simplifyChangedRanges");
function getChangedRanges(transform2) {
  const { mapping, steps } = transform2;
  const changes = [];
  mapping.maps.forEach((stepMap, index2) => {
    const ranges = [];
    if (!stepMap.ranges.length) {
      const { from: from2, to } = steps[index2];
      if (from2 === void 0 || to === void 0) {
        return;
      }
      ranges.push({ from: from2, to });
    } else {
      stepMap.forEach((from2, to) => {
        ranges.push({ from: from2, to });
      });
    }
    ranges.forEach(({ from: from2, to }) => {
      const newStart = mapping.slice(index2).map(from2, -1);
      const newEnd = mapping.slice(index2).map(to);
      const oldStart = mapping.invert().map(newStart, -1);
      const oldEnd = mapping.invert().map(newEnd);
      changes.push({
        oldRange: {
          from: oldStart,
          to: oldEnd
        },
        newRange: {
          from: newStart,
          to: newEnd
        }
      });
    });
  });
  return simplifyChangedRanges(changes);
}
__name(getChangedRanges, "getChangedRanges");
function getDebugJSON(node3, startOffset = 0) {
  const isTopNode = node3.type === node3.type.schema.topNodeType;
  const increment2 = isTopNode ? 0 : 1;
  const from2 = startOffset;
  const to = from2 + node3.nodeSize;
  const marks = node3.marks.map((mark2) => {
    const output2 = {
      type: mark2.type.name
    };
    if (Object.keys(mark2.attrs).length) {
      output2.attrs = { ...mark2.attrs };
    }
    return output2;
  });
  const attrs7 = { ...node3.attrs };
  const output = {
    type: node3.type.name,
    from: from2,
    to
  };
  if (Object.keys(attrs7).length) {
    output.attrs = attrs7;
  }
  if (marks.length) {
    output.marks = marks;
  }
  if (node3.content.childCount) {
    output.content = [];
    node3.forEach((child, offset) => {
      var _a2;
      (_a2 = output.content) === null || _a2 === void 0 ? void 0 : _a2.push(getDebugJSON(child, startOffset + offset + increment2));
    });
  }
  if (node3.text) {
    output.text = node3.text;
  }
  return output;
}
__name(getDebugJSON, "getDebugJSON");
function getMarksBetween(from2, to, doc2) {
  const marks = [];
  if (from2 === to) {
    doc2.resolve(from2).marks().forEach((mark2) => {
      const $pos = doc2.resolve(from2);
      const range2 = getMarkRange($pos, mark2.type);
      if (!range2) {
        return;
      }
      marks.push({
        mark: mark2,
        ...range2
      });
    });
  } else {
    doc2.nodesBetween(from2, to, (node3, pos) => {
      if (!node3 || (node3 === null || node3 === void 0 ? void 0 : node3.nodeSize) === void 0) {
        return;
      }
      marks.push(...node3.marks.map((mark2) => ({
        from: pos,
        to: pos + node3.nodeSize,
        mark: mark2
      })));
    });
  }
  return marks;
}
__name(getMarksBetween, "getMarksBetween");
const getNodeAtPosition = /* @__PURE__ */ __name((state, typeOrName, pos, maxDepth = 20) => {
  const $pos = state.doc.resolve(pos);
  let currentDepth = maxDepth;
  let node3 = null;
  while (currentDepth > 0 && node3 === null) {
    const currentNode = $pos.node(currentDepth);
    if ((currentNode === null || currentNode === void 0 ? void 0 : currentNode.type.name) === typeOrName) {
      node3 = currentNode;
    } else {
      currentDepth -= 1;
    }
  }
  return [node3, currentDepth];
}, "getNodeAtPosition");
function getSplittedAttributes(extensionAttributes, typeName, attributes) {
  return Object.fromEntries(Object.entries(attributes).filter(([name2]) => {
    const extensionAttribute = extensionAttributes.find((item3) => {
      return item3.type === typeName && item3.name === name2;
    });
    if (!extensionAttribute) {
      return false;
    }
    return extensionAttribute.attribute.keepOnSplit;
  }));
}
__name(getSplittedAttributes, "getSplittedAttributes");
function isMarkActive(state, typeOrName, attributes = {}) {
  const { empty: empty2, ranges } = state.selection;
  const type = typeOrName ? getMarkType(typeOrName, state.schema) : null;
  if (empty2) {
    return !!(state.storedMarks || state.selection.$from.marks()).filter((mark2) => {
      if (!type) {
        return true;
      }
      return type.name === mark2.type.name;
    }).find((mark2) => objectIncludes(mark2.attrs, attributes, { strict: false }));
  }
  let selectionRange = 0;
  const markRanges = [];
  ranges.forEach(({ $from, $to }) => {
    const from2 = $from.pos;
    const to = $to.pos;
    state.doc.nodesBetween(from2, to, (node3, pos) => {
      if (!node3.isText && !node3.marks.length) {
        return;
      }
      const relativeFrom = Math.max(from2, pos);
      const relativeTo = Math.min(to, pos + node3.nodeSize);
      const range3 = relativeTo - relativeFrom;
      selectionRange += range3;
      markRanges.push(...node3.marks.map((mark2) => ({
        mark: mark2,
        from: relativeFrom,
        to: relativeTo
      })));
    });
  });
  if (selectionRange === 0) {
    return false;
  }
  const matchedRange = markRanges.filter((markRange) => {
    if (!type) {
      return true;
    }
    return type.name === markRange.mark.type.name;
  }).filter((markRange) => objectIncludes(markRange.mark.attrs, attributes, { strict: false })).reduce((sum, markRange) => sum + markRange.to - markRange.from, 0);
  const excludedRange = markRanges.filter((markRange) => {
    if (!type) {
      return true;
    }
    return markRange.mark.type !== type && markRange.mark.type.excludes(type);
  }).reduce((sum, markRange) => sum + markRange.to - markRange.from, 0);
  const range2 = matchedRange > 0 ? matchedRange + excludedRange : matchedRange;
  return range2 >= selectionRange;
}
__name(isMarkActive, "isMarkActive");
function isActive(state, name2, attributes = {}) {
  if (!name2) {
    return isNodeActive(state, null, attributes) || isMarkActive(state, null, attributes);
  }
  const schemaType = getSchemaTypeNameByName(name2, state.schema);
  if (schemaType === "node") {
    return isNodeActive(state, name2, attributes);
  }
  if (schemaType === "mark") {
    return isMarkActive(state, name2, attributes);
  }
  return false;
}
__name(isActive, "isActive");
const isAtEndOfNode = /* @__PURE__ */ __name((state, nodeType) => {
  const { $from, $to, $anchor } = state.selection;
  if (nodeType) {
    const parentNode2 = findParentNode((node3) => node3.type.name === nodeType)(state.selection);
    if (!parentNode2) {
      return false;
    }
    const $parentPos = state.doc.resolve(parentNode2.pos + 1);
    if ($anchor.pos + 1 === $parentPos.end()) {
      return true;
    }
    return false;
  }
  if ($to.parentOffset < $to.parent.nodeSize - 2 || $from.pos !== $to.pos) {
    return false;
  }
  return true;
}, "isAtEndOfNode");
const isAtStartOfNode = /* @__PURE__ */ __name((state) => {
  const { $from, $to } = state.selection;
  if ($from.parentOffset > 0 || $from.pos !== $to.pos) {
    return false;
  }
  return true;
}, "isAtStartOfNode");
function isList(name2, extensions) {
  const { nodeExtensions } = splitExtensions(extensions);
  const extension = nodeExtensions.find((item3) => item3.name === name2);
  if (!extension) {
    return false;
  }
  const context = {
    name: extension.name,
    options: extension.options,
    storage: extension.storage
  };
  const group = callOrReturn(getExtensionField(extension, "group", context));
  if (typeof group !== "string") {
    return false;
  }
  return group.split(" ").includes("list");
}
__name(isList, "isList");
function isNodeEmpty(node3, { checkChildren = true, ignoreWhitespace = false } = {}) {
  var _a2;
  if (ignoreWhitespace) {
    if (node3.type.name === "hardBreak") {
      return true;
    }
    if (node3.isText) {
      return /^\s*$/m.test((_a2 = node3.text) !== null && _a2 !== void 0 ? _a2 : "");
    }
  }
  if (node3.isText) {
    return !node3.text;
  }
  if (node3.isAtom || node3.isLeaf) {
    return false;
  }
  if (node3.content.childCount === 0) {
    return true;
  }
  if (checkChildren) {
    let isContentEmpty = true;
    node3.content.forEach((childNode) => {
      if (isContentEmpty === false) {
        return;
      }
      if (!isNodeEmpty(childNode, { ignoreWhitespace, checkChildren })) {
        isContentEmpty = false;
      }
    });
    return isContentEmpty;
  }
  return false;
}
__name(isNodeEmpty, "isNodeEmpty");
function isNodeSelection(value3) {
  return value3 instanceof NodeSelection;
}
__name(isNodeSelection, "isNodeSelection");
function posToDOMRect(view, from2, to) {
  const minPos = 0;
  const maxPos = view.state.doc.content.size;
  const resolvedFrom = minMax(from2, minPos, maxPos);
  const resolvedEnd = minMax(to, minPos, maxPos);
  const start2 = view.coordsAtPos(resolvedFrom);
  const end = view.coordsAtPos(resolvedEnd, -1);
  const top = Math.min(start2.top, end.top);
  const bottom = Math.max(start2.bottom, end.bottom);
  const left = Math.min(start2.left, end.left);
  const right = Math.max(start2.right, end.right);
  const width2 = right - left;
  const height = bottom - top;
  const x2 = left;
  const y2 = top;
  const data30 = {
    top,
    bottom,
    left,
    right,
    width: width2,
    height,
    x: x2,
    y: y2
  };
  return {
    ...data30,
    toJSON: /* @__PURE__ */ __name(() => data30, "toJSON")
  };
}
__name(posToDOMRect, "posToDOMRect");
function canSetMark(state, tr2, newMarkType) {
  var _a2;
  const { selection } = tr2;
  let cursor = null;
  if (isTextSelection(selection)) {
    cursor = selection.$cursor;
  }
  if (cursor) {
    const currentMarks = (_a2 = state.storedMarks) !== null && _a2 !== void 0 ? _a2 : cursor.marks();
    return !!newMarkType.isInSet(currentMarks) || !currentMarks.some((mark2) => mark2.type.excludes(newMarkType));
  }
  const { ranges } = selection;
  return ranges.some(({ $from, $to }) => {
    let someNodeSupportsMark = $from.depth === 0 ? state.doc.inlineContent && state.doc.type.allowsMarkType(newMarkType) : false;
    state.doc.nodesBetween($from.pos, $to.pos, (node3, _pos, parent) => {
      if (someNodeSupportsMark) {
        return false;
      }
      if (node3.isInline) {
        const parentAllowsMarkType = !parent || parent.type.allowsMarkType(newMarkType);
        const currentMarksAllowMarkType = !!newMarkType.isInSet(node3.marks) || !node3.marks.some((otherMark) => otherMark.type.excludes(newMarkType));
        someNodeSupportsMark = parentAllowsMarkType && currentMarksAllowMarkType;
      }
      return !someNodeSupportsMark;
    });
    return someNodeSupportsMark;
  });
}
__name(canSetMark, "canSetMark");
const setMark = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ tr: tr2, state, dispatch }) => {
  const { selection } = tr2;
  const { empty: empty2, ranges } = selection;
  const type = getMarkType(typeOrName, state.schema);
  if (dispatch) {
    if (empty2) {
      const oldAttributes = getMarkAttributes(state, type);
      tr2.addStoredMark(type.create({
        ...oldAttributes,
        ...attributes
      }));
    } else {
      ranges.forEach((range2) => {
        const from2 = range2.$from.pos;
        const to = range2.$to.pos;
        state.doc.nodesBetween(from2, to, (node3, pos) => {
          const trimmedFrom = Math.max(pos, from2);
          const trimmedTo = Math.min(pos + node3.nodeSize, to);
          const someHasMark = node3.marks.find((mark2) => mark2.type === type);
          if (someHasMark) {
            node3.marks.forEach((mark2) => {
              if (type === mark2.type) {
                tr2.addMark(trimmedFrom, trimmedTo, type.create({
                  ...mark2.attrs,
                  ...attributes
                }));
              }
            });
          } else {
            tr2.addMark(trimmedFrom, trimmedTo, type.create(attributes));
          }
        });
      });
    }
  }
  return canSetMark(state, tr2, type);
}, "setMark");
const setMeta = /* @__PURE__ */ __name((key, value3) => ({ tr: tr2 }) => {
  tr2.setMeta(key, value3);
  return true;
}, "setMeta");
const setNode = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ state, dispatch, chain }) => {
  const type = getNodeType(typeOrName, state.schema);
  let attributesToCopy;
  if (state.selection.$anchor.sameParent(state.selection.$head)) {
    attributesToCopy = state.selection.$anchor.parent.attrs;
  }
  if (!type.isTextblock) {
    console.warn('[tiptap warn]: Currently "setNode()" only supports text block nodes.');
    return false;
  }
  return chain().command(({ commands: commands2 }) => {
    const canSetBlock = setBlockType(type, { ...attributesToCopy, ...attributes })(state);
    if (canSetBlock) {
      return true;
    }
    return commands2.clearNodes();
  }).command(({ state: updatedState }) => {
    return setBlockType(type, { ...attributesToCopy, ...attributes })(updatedState, dispatch);
  }).run();
}, "setNode");
const setNodeSelection = /* @__PURE__ */ __name((position3) => ({ tr: tr2, dispatch }) => {
  if (dispatch) {
    const { doc: doc2 } = tr2;
    const from2 = minMax(position3, 0, doc2.content.size);
    const selection = NodeSelection.create(doc2, from2);
    tr2.setSelection(selection);
  }
  return true;
}, "setNodeSelection");
const setTextSelection = /* @__PURE__ */ __name((position3) => ({ tr: tr2, dispatch }) => {
  if (dispatch) {
    const { doc: doc2 } = tr2;
    const { from: from2, to } = typeof position3 === "number" ? { from: position3, to: position3 } : position3;
    const minPos = TextSelection.atStart(doc2).from;
    const maxPos = TextSelection.atEnd(doc2).to;
    const resolvedFrom = minMax(from2, minPos, maxPos);
    const resolvedEnd = minMax(to, minPos, maxPos);
    const selection = TextSelection.create(doc2, resolvedFrom, resolvedEnd);
    tr2.setSelection(selection);
  }
  return true;
}, "setTextSelection");
const sinkListItem = /* @__PURE__ */ __name((typeOrName) => ({ state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  return sinkListItem$1(type)(state, dispatch);
}, "sinkListItem");
function ensureMarks(state, splittableMarks) {
  const marks = state.storedMarks || state.selection.$to.parentOffset && state.selection.$from.marks();
  if (marks) {
    const filteredMarks = marks.filter((mark2) => splittableMarks === null || splittableMarks === void 0 ? void 0 : splittableMarks.includes(mark2.type.name));
    state.tr.ensureMarks(filteredMarks);
  }
}
__name(ensureMarks, "ensureMarks");
const splitBlock = /* @__PURE__ */ __name(({ keepMarks = true } = {}) => ({ tr: tr2, state, dispatch, editor }) => {
  const { selection, doc: doc2 } = tr2;
  const { $from, $to } = selection;
  const extensionAttributes = editor.extensionManager.attributes;
  const newAttributes = getSplittedAttributes(extensionAttributes, $from.node().type.name, $from.node().attrs);
  if (selection instanceof NodeSelection && selection.node.isBlock) {
    if (!$from.parentOffset || !canSplit(doc2, $from.pos)) {
      return false;
    }
    if (dispatch) {
      if (keepMarks) {
        ensureMarks(state, editor.extensionManager.splittableMarks);
      }
      tr2.split($from.pos).scrollIntoView();
    }
    return true;
  }
  if (!$from.parent.isBlock) {
    return false;
  }
  const atEnd = $to.parentOffset === $to.parent.content.size;
  const deflt = $from.depth === 0 ? void 0 : defaultBlockAt($from.node(-1).contentMatchAt($from.indexAfter(-1)));
  let types = atEnd && deflt ? [
    {
      type: deflt,
      attrs: newAttributes
    }
  ] : void 0;
  let can = canSplit(tr2.doc, tr2.mapping.map($from.pos), 1, types);
  if (!types && !can && canSplit(tr2.doc, tr2.mapping.map($from.pos), 1, deflt ? [{ type: deflt }] : void 0)) {
    can = true;
    types = deflt ? [
      {
        type: deflt,
        attrs: newAttributes
      }
    ] : void 0;
  }
  if (dispatch) {
    if (can) {
      if (selection instanceof TextSelection) {
        tr2.deleteSelection();
      }
      tr2.split(tr2.mapping.map($from.pos), 1, types);
      if (deflt && !atEnd && !$from.parentOffset && $from.parent.type !== deflt) {
        const first2 = tr2.mapping.map($from.before());
        const $first = tr2.doc.resolve(first2);
        if ($from.node(-1).canReplaceWith($first.index(), $first.index() + 1, deflt)) {
          tr2.setNodeMarkup(tr2.mapping.map($from.before()), deflt);
        }
      }
    }
    if (keepMarks) {
      ensureMarks(state, editor.extensionManager.splittableMarks);
    }
    tr2.scrollIntoView();
  }
  return can;
}, "splitBlock");
const splitListItem = /* @__PURE__ */ __name((typeOrName, overrideAttrs = {}) => ({ tr: tr2, state, dispatch, editor }) => {
  var _a2;
  const type = getNodeType(typeOrName, state.schema);
  const { $from, $to } = state.selection;
  const node3 = state.selection.node;
  if (node3 && node3.isBlock || $from.depth < 2 || !$from.sameParent($to)) {
    return false;
  }
  const grandParent = $from.node(-1);
  if (grandParent.type !== type) {
    return false;
  }
  const extensionAttributes = editor.extensionManager.attributes;
  if ($from.parent.content.size === 0 && $from.node(-1).childCount === $from.indexAfter(-1)) {
    if ($from.depth === 2 || $from.node(-3).type !== type || $from.index(-2) !== $from.node(-2).childCount - 1) {
      return false;
    }
    if (dispatch) {
      let wrap2 = Fragment.empty;
      const depthBefore = $from.index(-1) ? 1 : $from.index(-2) ? 2 : 3;
      for (let d2 = $from.depth - depthBefore; d2 >= $from.depth - 3; d2 -= 1) {
        wrap2 = Fragment.from($from.node(d2).copy(wrap2));
      }
      const depthAfter = $from.indexAfter(-1) < $from.node(-2).childCount ? 1 : $from.indexAfter(-2) < $from.node(-3).childCount ? 2 : 3;
      const newNextTypeAttributes2 = {
        ...getSplittedAttributes(extensionAttributes, $from.node().type.name, $from.node().attrs),
        ...overrideAttrs
      };
      const nextType2 = ((_a2 = type.contentMatch.defaultType) === null || _a2 === void 0 ? void 0 : _a2.createAndFill(newNextTypeAttributes2)) || void 0;
      wrap2 = wrap2.append(Fragment.from(type.createAndFill(null, nextType2) || void 0));
      const start2 = $from.before($from.depth - (depthBefore - 1));
      tr2.replace(start2, $from.after(-depthAfter), new Slice(wrap2, 4 - depthBefore, 0));
      let sel = -1;
      tr2.doc.nodesBetween(start2, tr2.doc.content.size, (n2, pos) => {
        if (sel > -1) {
          return false;
        }
        if (n2.isTextblock && n2.content.size === 0) {
          sel = pos + 1;
        }
      });
      if (sel > -1) {
        tr2.setSelection(TextSelection.near(tr2.doc.resolve(sel)));
      }
      tr2.scrollIntoView();
    }
    return true;
  }
  const nextType = $to.pos === $from.end() ? grandParent.contentMatchAt(0).defaultType : null;
  const newTypeAttributes = {
    ...getSplittedAttributes(extensionAttributes, grandParent.type.name, grandParent.attrs),
    ...overrideAttrs
  };
  const newNextTypeAttributes = {
    ...getSplittedAttributes(extensionAttributes, $from.node().type.name, $from.node().attrs),
    ...overrideAttrs
  };
  tr2.delete($from.pos, $to.pos);
  const types = nextType ? [
    { type, attrs: newTypeAttributes },
    { type: nextType, attrs: newNextTypeAttributes }
  ] : [{ type, attrs: newTypeAttributes }];
  if (!canSplit(tr2.doc, $from.pos, 2)) {
    return false;
  }
  if (dispatch) {
    const { selection, storedMarks } = state;
    const { splittableMarks } = editor.extensionManager;
    const marks = storedMarks || selection.$to.parentOffset && selection.$from.marks();
    tr2.split($from.pos, 2, types).scrollIntoView();
    if (!marks || !dispatch) {
      return true;
    }
    const filteredMarks = marks.filter((mark2) => splittableMarks.includes(mark2.type.name));
    tr2.ensureMarks(filteredMarks);
  }
  return true;
}, "splitListItem");
const joinListBackwards = /* @__PURE__ */ __name((tr2, listType) => {
  const list2 = findParentNode((node3) => node3.type === listType)(tr2.selection);
  if (!list2) {
    return true;
  }
  const before = tr2.doc.resolve(Math.max(0, list2.pos - 1)).before(list2.depth);
  if (before === void 0) {
    return true;
  }
  const nodeBefore = tr2.doc.nodeAt(before);
  const canJoinBackwards = list2.node.type === (nodeBefore === null || nodeBefore === void 0 ? void 0 : nodeBefore.type) && canJoin(tr2.doc, list2.pos);
  if (!canJoinBackwards) {
    return true;
  }
  tr2.join(list2.pos);
  return true;
}, "joinListBackwards");
const joinListForwards = /* @__PURE__ */ __name((tr2, listType) => {
  const list2 = findParentNode((node3) => node3.type === listType)(tr2.selection);
  if (!list2) {
    return true;
  }
  const after = tr2.doc.resolve(list2.start).after(list2.depth);
  if (after === void 0) {
    return true;
  }
  const nodeAfter = tr2.doc.nodeAt(after);
  const canJoinForwards = list2.node.type === (nodeAfter === null || nodeAfter === void 0 ? void 0 : nodeAfter.type) && canJoin(tr2.doc, after);
  if (!canJoinForwards) {
    return true;
  }
  tr2.join(after);
  return true;
}, "joinListForwards");
const toggleList = /* @__PURE__ */ __name((listTypeOrName, itemTypeOrName, keepMarks, attributes = {}) => ({ editor, tr: tr2, state, dispatch, chain, commands: commands2, can }) => {
  const { extensions, splittableMarks } = editor.extensionManager;
  const listType = getNodeType(listTypeOrName, state.schema);
  const itemType = getNodeType(itemTypeOrName, state.schema);
  const { selection, storedMarks } = state;
  const { $from, $to } = selection;
  const range2 = $from.blockRange($to);
  const marks = storedMarks || selection.$to.parentOffset && selection.$from.marks();
  if (!range2) {
    return false;
  }
  const parentList = findParentNode((node3) => isList(node3.type.name, extensions))(selection);
  if (range2.depth >= 1 && parentList && range2.depth - parentList.depth <= 1) {
    if (parentList.node.type === listType) {
      return commands2.liftListItem(itemType);
    }
    if (isList(parentList.node.type.name, extensions) && listType.validContent(parentList.node.content) && dispatch) {
      return chain().command(() => {
        tr2.setNodeMarkup(parentList.pos, listType);
        return true;
      }).command(() => joinListBackwards(tr2, listType)).command(() => joinListForwards(tr2, listType)).run();
    }
  }
  if (!keepMarks || !marks || !dispatch) {
    return chain().command(() => {
      const canWrapInList = can().wrapInList(listType, attributes);
      if (canWrapInList) {
        return true;
      }
      return commands2.clearNodes();
    }).wrapInList(listType, attributes).command(() => joinListBackwards(tr2, listType)).command(() => joinListForwards(tr2, listType)).run();
  }
  return chain().command(() => {
    const canWrapInList = can().wrapInList(listType, attributes);
    const filteredMarks = marks.filter((mark2) => splittableMarks.includes(mark2.type.name));
    tr2.ensureMarks(filteredMarks);
    if (canWrapInList) {
      return true;
    }
    return commands2.clearNodes();
  }).wrapInList(listType, attributes).command(() => joinListBackwards(tr2, listType)).command(() => joinListForwards(tr2, listType)).run();
}, "toggleList");
const toggleMark = /* @__PURE__ */ __name((typeOrName, attributes = {}, options5 = {}) => ({ state, commands: commands2 }) => {
  const { extendEmptyMarkRange = false } = options5;
  const type = getMarkType(typeOrName, state.schema);
  const isActive2 = isMarkActive(state, type, attributes);
  if (isActive2) {
    return commands2.unsetMark(type, { extendEmptyMarkRange });
  }
  return commands2.setMark(type, attributes);
}, "toggleMark");
const toggleNode = /* @__PURE__ */ __name((typeOrName, toggleTypeOrName, attributes = {}) => ({ state, commands: commands2 }) => {
  const type = getNodeType(typeOrName, state.schema);
  const toggleType = getNodeType(toggleTypeOrName, state.schema);
  const isActive2 = isNodeActive(state, type, attributes);
  let attributesToCopy;
  if (state.selection.$anchor.sameParent(state.selection.$head)) {
    attributesToCopy = state.selection.$anchor.parent.attrs;
  }
  if (isActive2) {
    return commands2.setNode(toggleType, attributesToCopy);
  }
  return commands2.setNode(type, { ...attributesToCopy, ...attributes });
}, "toggleNode");
const toggleWrap = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ state, commands: commands2 }) => {
  const type = getNodeType(typeOrName, state.schema);
  const isActive2 = isNodeActive(state, type, attributes);
  if (isActive2) {
    return commands2.lift(type);
  }
  return commands2.wrapIn(type, attributes);
}, "toggleWrap");
const undoInputRule = /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
  const plugins = state.plugins;
  for (let i2 = 0; i2 < plugins.length; i2 += 1) {
    const plugin = plugins[i2];
    let undoable;
    if (plugin.spec.isInputRules && (undoable = plugin.getState(state))) {
      if (dispatch) {
        const tr2 = state.tr;
        const toUndo = undoable.transform;
        for (let j2 = toUndo.steps.length - 1; j2 >= 0; j2 -= 1) {
          tr2.step(toUndo.steps[j2].invert(toUndo.docs[j2]));
        }
        if (undoable.text) {
          const marks = tr2.doc.resolve(undoable.from).marks();
          tr2.replaceWith(undoable.from, undoable.to, state.schema.text(undoable.text, marks));
        } else {
          tr2.delete(undoable.from, undoable.to);
        }
      }
      return true;
    }
  }
  return false;
}, "undoInputRule");
const unsetAllMarks = /* @__PURE__ */ __name(() => ({ tr: tr2, dispatch }) => {
  const { selection } = tr2;
  const { empty: empty2, ranges } = selection;
  if (empty2) {
    return true;
  }
  if (dispatch) {
    ranges.forEach((range2) => {
      tr2.removeMark(range2.$from.pos, range2.$to.pos);
    });
  }
  return true;
}, "unsetAllMarks");
const unsetMark = /* @__PURE__ */ __name((typeOrName, options5 = {}) => ({ tr: tr2, state, dispatch }) => {
  var _a2;
  const { extendEmptyMarkRange = false } = options5;
  const { selection } = tr2;
  const type = getMarkType(typeOrName, state.schema);
  const { $from, empty: empty2, ranges } = selection;
  if (!dispatch) {
    return true;
  }
  if (empty2 && extendEmptyMarkRange) {
    let { from: from2, to } = selection;
    const attrs7 = (_a2 = $from.marks().find((mark2) => mark2.type === type)) === null || _a2 === void 0 ? void 0 : _a2.attrs;
    const range2 = getMarkRange($from, type, attrs7);
    if (range2) {
      from2 = range2.from;
      to = range2.to;
    }
    tr2.removeMark(from2, to, type);
  } else {
    ranges.forEach((range2) => {
      tr2.removeMark(range2.$from.pos, range2.$to.pos, type);
    });
  }
  tr2.removeStoredMark(type);
  return true;
}, "unsetMark");
const updateAttributes = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ tr: tr2, state, dispatch }) => {
  let nodeType = null;
  let markType = null;
  const schemaType = getSchemaTypeNameByName(typeof typeOrName === "string" ? typeOrName : typeOrName.name, state.schema);
  if (!schemaType) {
    return false;
  }
  if (schemaType === "node") {
    nodeType = getNodeType(typeOrName, state.schema);
  }
  if (schemaType === "mark") {
    markType = getMarkType(typeOrName, state.schema);
  }
  if (dispatch) {
    tr2.selection.ranges.forEach((range2) => {
      const from2 = range2.$from.pos;
      const to = range2.$to.pos;
      let lastPos;
      let lastNode;
      let trimmedFrom;
      let trimmedTo;
      if (tr2.selection.empty) {
        state.doc.nodesBetween(from2, to, (node3, pos) => {
          if (nodeType && nodeType === node3.type) {
            trimmedFrom = Math.max(pos, from2);
            trimmedTo = Math.min(pos + node3.nodeSize, to);
            lastPos = pos;
            lastNode = node3;
          }
        });
      } else {
        state.doc.nodesBetween(from2, to, (node3, pos) => {
          if (pos < from2 && nodeType && nodeType === node3.type) {
            trimmedFrom = Math.max(pos, from2);
            trimmedTo = Math.min(pos + node3.nodeSize, to);
            lastPos = pos;
            lastNode = node3;
          }
          if (pos >= from2 && pos <= to) {
            if (nodeType && nodeType === node3.type) {
              tr2.setNodeMarkup(pos, void 0, {
                ...node3.attrs,
                ...attributes
              });
            }
            if (markType && node3.marks.length) {
              node3.marks.forEach((mark2) => {
                if (markType === mark2.type) {
                  const trimmedFrom2 = Math.max(pos, from2);
                  const trimmedTo2 = Math.min(pos + node3.nodeSize, to);
                  tr2.addMark(trimmedFrom2, trimmedTo2, markType.create({
                    ...mark2.attrs,
                    ...attributes
                  }));
                }
              });
            }
          }
        });
      }
      if (lastNode) {
        if (lastPos !== void 0) {
          tr2.setNodeMarkup(lastPos, void 0, {
            ...lastNode.attrs,
            ...attributes
          });
        }
        if (markType && lastNode.marks.length) {
          lastNode.marks.forEach((mark2) => {
            if (markType === mark2.type) {
              tr2.addMark(trimmedFrom, trimmedTo, markType.create({
                ...mark2.attrs,
                ...attributes
              }));
            }
          });
        }
      }
    });
  }
  return true;
}, "updateAttributes");
const wrapIn = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  return wrapIn$1(type, attributes)(state, dispatch);
}, "wrapIn");
const wrapInList = /* @__PURE__ */ __name((typeOrName, attributes = {}) => ({ state, dispatch }) => {
  const type = getNodeType(typeOrName, state.schema);
  return wrapInList$1(type, attributes)(state, dispatch);
}, "wrapInList");
var commands = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  blur,
  clearContent,
  clearNodes,
  command,
  createParagraphNear,
  cut,
  deleteCurrentNode,
  deleteNode,
  deleteRange,
  deleteSelection,
  enter,
  exitCode,
  extendMarkRange,
  first,
  focus,
  forEach,
  insertContent,
  insertContentAt,
  joinBackward,
  joinDown,
  joinForward,
  joinItemBackward,
  joinItemForward,
  joinTextblockBackward,
  joinTextblockForward,
  joinUp,
  keyboardShortcut,
  lift,
  liftEmptyBlock,
  liftListItem,
  newlineInCode,
  resetAttributes,
  scrollIntoView,
  selectAll,
  selectNodeBackward,
  selectNodeForward,
  selectParentNode,
  selectTextblockEnd,
  selectTextblockStart,
  setContent,
  setMark,
  setMeta,
  setNode,
  setNodeSelection,
  setTextSelection,
  sinkListItem,
  splitBlock,
  splitListItem,
  toggleList,
  toggleMark,
  toggleNode,
  toggleWrap,
  undoInputRule,
  unsetAllMarks,
  unsetMark,
  updateAttributes,
  wrapIn,
  wrapInList
});
const Commands = Extension.create({
  name: "commands",
  addCommands() {
    return {
      ...commands
    };
  }
});
const Drop = Extension.create({
  name: "drop",
  addProseMirrorPlugins() {
    return [
      new Plugin({
        key: new PluginKey("tiptapDrop"),
        props: {
          handleDrop: /* @__PURE__ */ __name((_2, e2, slice2, moved) => {
            this.editor.emit("drop", {
              editor: this.editor,
              event: e2,
              slice: slice2,
              moved
            });
          }, "handleDrop")
        }
      })
    ];
  }
});
const Editable = Extension.create({
  name: "editable",
  addProseMirrorPlugins() {
    return [
      new Plugin({
        key: new PluginKey("editable"),
        props: {
          editable: /* @__PURE__ */ __name(() => this.editor.options.editable, "editable")
        }
      })
    ];
  }
});
const FocusEvents = Extension.create({
  name: "focusEvents",
  addProseMirrorPlugins() {
    const { editor } = this;
    return [
      new Plugin({
        key: new PluginKey("focusEvents"),
        props: {
          handleDOMEvents: {
            focus: /* @__PURE__ */ __name((view, event) => {
              editor.isFocused = true;
              const transaction = editor.state.tr.setMeta("focus", { event }).setMeta("addToHistory", false);
              view.dispatch(transaction);
              return false;
            }, "focus"),
            blur: /* @__PURE__ */ __name((view, event) => {
              editor.isFocused = false;
              const transaction = editor.state.tr.setMeta("blur", { event }).setMeta("addToHistory", false);
              view.dispatch(transaction);
              return false;
            }, "blur")
          }
        }
      })
    ];
  }
});
const Keymap = Extension.create({
  name: "keymap",
  addKeyboardShortcuts() {
    const handleBackspace = /* @__PURE__ */ __name(() => this.editor.commands.first(({ commands: commands2 }) => [
      () => commands2.undoInputRule(),
      // maybe convert first text block node to default node
      () => commands2.command(({ tr: tr2 }) => {
        const { selection, doc: doc2 } = tr2;
        const { empty: empty2, $anchor } = selection;
        const { pos, parent } = $anchor;
        const $parentPos = $anchor.parent.isTextblock && pos > 0 ? tr2.doc.resolve(pos - 1) : $anchor;
        const parentIsIsolating = $parentPos.parent.type.spec.isolating;
        const parentPos = $anchor.pos - $anchor.parentOffset;
        const isAtStart = parentIsIsolating && $parentPos.parent.childCount === 1 ? parentPos === $anchor.pos : Selection.atStart(doc2).from === pos;
        if (!empty2 || !parent.type.isTextblock || parent.textContent.length || !isAtStart || isAtStart && $anchor.parent.type.name === "paragraph") {
          return false;
        }
        return commands2.clearNodes();
      }),
      () => commands2.deleteSelection(),
      () => commands2.joinBackward(),
      () => commands2.selectNodeBackward()
    ]), "handleBackspace");
    const handleDelete = /* @__PURE__ */ __name(() => this.editor.commands.first(({ commands: commands2 }) => [
      () => commands2.deleteSelection(),
      () => commands2.deleteCurrentNode(),
      () => commands2.joinForward(),
      () => commands2.selectNodeForward()
    ]), "handleDelete");
    const handleEnter = /* @__PURE__ */ __name(() => this.editor.commands.first(({ commands: commands2 }) => [
      () => commands2.newlineInCode(),
      () => commands2.createParagraphNear(),
      () => commands2.liftEmptyBlock(),
      () => commands2.splitBlock()
    ]), "handleEnter");
    const baseKeymap2 = {
      Enter: handleEnter,
      "Mod-Enter": /* @__PURE__ */ __name(() => this.editor.commands.exitCode(), "Mod-Enter"),
      Backspace: handleBackspace,
      "Mod-Backspace": handleBackspace,
      "Shift-Backspace": handleBackspace,
      Delete: handleDelete,
      "Mod-Delete": handleDelete,
      "Mod-a": /* @__PURE__ */ __name(() => this.editor.commands.selectAll(), "Mod-a")
    };
    const pcKeymap = {
      ...baseKeymap2
    };
    const macKeymap = {
      ...baseKeymap2,
      "Ctrl-h": handleBackspace,
      "Alt-Backspace": handleBackspace,
      "Ctrl-d": handleDelete,
      "Ctrl-Alt-Backspace": handleDelete,
      "Alt-Delete": handleDelete,
      "Alt-d": handleDelete,
      "Ctrl-a": /* @__PURE__ */ __name(() => this.editor.commands.selectTextblockStart(), "Ctrl-a"),
      "Ctrl-e": /* @__PURE__ */ __name(() => this.editor.commands.selectTextblockEnd(), "Ctrl-e")
    };
    if (isiOS() || isMacOS()) {
      return macKeymap;
    }
    return pcKeymap;
  },
  addProseMirrorPlugins() {
    return [
      // With this plugin we check if the whole document was selected and deleted.
      // In this case we will additionally call `clearNodes()` to convert e.g. a heading
      // to a paragraph if necessary.
      // This is an alternative to ProseMirror's `AllSelection`, which doesn’t work well
      // with many other commands.
      new Plugin({
        key: new PluginKey("clearDocument"),
        appendTransaction: /* @__PURE__ */ __name((transactions, oldState, newState) => {
          const docChanges = transactions.some((transaction) => transaction.docChanged) && !oldState.doc.eq(newState.doc);
          const ignoreTr = transactions.some((transaction) => transaction.getMeta("preventClearDocument"));
          if (!docChanges || ignoreTr) {
            return;
          }
          const { empty: empty2, from: from2, to } = oldState.selection;
          const allFrom = Selection.atStart(oldState.doc).from;
          const allEnd = Selection.atEnd(oldState.doc).to;
          const allWasSelected = from2 === allFrom && to === allEnd;
          if (empty2 || !allWasSelected) {
            return;
          }
          const isEmpty3 = isNodeEmpty(newState.doc);
          if (!isEmpty3) {
            return;
          }
          const tr2 = newState.tr;
          const state = createChainableState({
            state: newState,
            transaction: tr2
          });
          const { commands: commands2 } = new CommandManager({
            editor: this.editor,
            state
          });
          commands2.clearNodes();
          if (!tr2.steps.length) {
            return;
          }
          return tr2;
        }, "appendTransaction")
      })
    ];
  }
});
const Paste = Extension.create({
  name: "paste",
  addProseMirrorPlugins() {
    return [
      new Plugin({
        key: new PluginKey("tiptapPaste"),
        props: {
          handlePaste: /* @__PURE__ */ __name((_view, e2, slice2) => {
            this.editor.emit("paste", {
              editor: this.editor,
              event: e2,
              slice: slice2
            });
          }, "handlePaste")
        }
      })
    ];
  }
});
const Tabindex = Extension.create({
  name: "tabindex",
  addProseMirrorPlugins() {
    return [
      new Plugin({
        key: new PluginKey("tabindex"),
        props: {
          attributes: /* @__PURE__ */ __name(() => this.editor.isEditable ? { tabindex: "0" } : {}, "attributes")
        }
      })
    ];
  }
});
var index$1 = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  ClipboardTextSerializer,
  Commands,
  Drop,
  Editable,
  FocusEvents,
  Keymap,
  Paste,
  Tabindex
});
class NodePos {
  static {
    __name(this, "NodePos");
  }
  get name() {
    return this.node.type.name;
  }
  constructor(pos, editor, isBlock = false, node3 = null) {
    this.currentNode = null;
    this.actualDepth = null;
    this.isBlock = isBlock;
    this.resolvedPos = pos;
    this.editor = editor;
    this.currentNode = node3;
  }
  get node() {
    return this.currentNode || this.resolvedPos.node();
  }
  get element() {
    return this.editor.view.domAtPos(this.pos).node;
  }
  get depth() {
    var _a2;
    return (_a2 = this.actualDepth) !== null && _a2 !== void 0 ? _a2 : this.resolvedPos.depth;
  }
  get pos() {
    return this.resolvedPos.pos;
  }
  get content() {
    return this.node.content;
  }
  set content(content3) {
    let from2 = this.from;
    let to = this.to;
    if (this.isBlock) {
      if (this.content.size === 0) {
        console.error(`You can’t set content on a block node. Tried to set content on ${this.name} at ${this.pos}`);
        return;
      }
      from2 = this.from + 1;
      to = this.to - 1;
    }
    this.editor.commands.insertContentAt({ from: from2, to }, content3);
  }
  get attributes() {
    return this.node.attrs;
  }
  get textContent() {
    return this.node.textContent;
  }
  get size() {
    return this.node.nodeSize;
  }
  get from() {
    if (this.isBlock) {
      return this.pos;
    }
    return this.resolvedPos.start(this.resolvedPos.depth);
  }
  get range() {
    return {
      from: this.from,
      to: this.to
    };
  }
  get to() {
    if (this.isBlock) {
      return this.pos + this.size;
    }
    return this.resolvedPos.end(this.resolvedPos.depth) + (this.node.isText ? 0 : 1);
  }
  get parent() {
    if (this.depth === 0) {
      return null;
    }
    const parentPos = this.resolvedPos.start(this.resolvedPos.depth - 1);
    const $pos = this.resolvedPos.doc.resolve(parentPos);
    return new NodePos($pos, this.editor);
  }
  get before() {
    let $pos = this.resolvedPos.doc.resolve(this.from - (this.isBlock ? 1 : 2));
    if ($pos.depth !== this.depth) {
      $pos = this.resolvedPos.doc.resolve(this.from - 3);
    }
    return new NodePos($pos, this.editor);
  }
  get after() {
    let $pos = this.resolvedPos.doc.resolve(this.to + (this.isBlock ? 2 : 1));
    if ($pos.depth !== this.depth) {
      $pos = this.resolvedPos.doc.resolve(this.to + 3);
    }
    return new NodePos($pos, this.editor);
  }
  get children() {
    const children = [];
    this.node.content.forEach((node3, offset) => {
      const isBlock = node3.isBlock && !node3.isTextblock;
      const isNonTextAtom = node3.isAtom && !node3.isText;
      const targetPos = this.pos + offset + (isNonTextAtom ? 0 : 1);
      const $pos = this.resolvedPos.doc.resolve(targetPos);
      if (!isBlock && $pos.depth <= this.depth) {
        return;
      }
      const childNodePos = new NodePos($pos, this.editor, isBlock, isBlock ? node3 : null);
      if (isBlock) {
        childNodePos.actualDepth = this.depth + 1;
      }
      children.push(new NodePos($pos, this.editor, isBlock, isBlock ? node3 : null));
    });
    return children;
  }
  get firstChild() {
    return this.children[0] || null;
  }
  get lastChild() {
    const children = this.children;
    return children[children.length - 1] || null;
  }
  closest(selector, attributes = {}) {
    let node3 = null;
    let currentNode = this.parent;
    while (currentNode && !node3) {
      if (currentNode.node.type.name === selector) {
        if (Object.keys(attributes).length > 0) {
          const nodeAttributes = currentNode.node.attrs;
          const attrKeys = Object.keys(attributes);
          for (let index2 = 0; index2 < attrKeys.length; index2 += 1) {
            const key = attrKeys[index2];
            if (nodeAttributes[key] !== attributes[key]) {
              break;
            }
          }
        } else {
          node3 = currentNode;
        }
      }
      currentNode = currentNode.parent;
    }
    return node3;
  }
  querySelector(selector, attributes = {}) {
    return this.querySelectorAll(selector, attributes, true)[0] || null;
  }
  querySelectorAll(selector, attributes = {}, firstItemOnly = false) {
    let nodes = [];
    if (!this.children || this.children.length === 0) {
      return nodes;
    }
    const attrKeys = Object.keys(attributes);
    this.children.forEach((childPos) => {
      if (firstItemOnly && nodes.length > 0) {
        return;
      }
      if (childPos.node.type.name === selector) {
        const doesAllAttributesMatch = attrKeys.every((key) => attributes[key] === childPos.node.attrs[key]);
        if (doesAllAttributesMatch) {
          nodes.push(childPos);
        }
      }
      if (firstItemOnly && nodes.length > 0) {
        return;
      }
      nodes = nodes.concat(childPos.querySelectorAll(selector, attributes, firstItemOnly));
    });
    return nodes;
  }
  setAttribute(attributes) {
    const { tr: tr2 } = this.editor.state;
    tr2.setNodeMarkup(this.from, void 0, {
      ...this.node.attrs,
      ...attributes
    });
    this.editor.view.dispatch(tr2);
  }
}
const style = `.ProseMirror {
  position: relative;
}

.ProseMirror {
  word-wrap: break-word;
  white-space: pre-wrap;
  white-space: break-spaces;
  -webkit-font-variant-ligatures: none;
  font-variant-ligatures: none;
  font-feature-settings: "liga" 0; /* the above doesn't seem to work in Edge */
}

.ProseMirror [contenteditable="false"] {
  white-space: normal;
}

.ProseMirror [contenteditable="false"] [contenteditable="true"] {
  white-space: pre-wrap;
}

.ProseMirror pre {
  white-space: pre-wrap;
}

img.ProseMirror-separator {
  display: inline !important;
  border: none !important;
  margin: 0 !important;
  width: 0 !important;
  height: 0 !important;
}

.ProseMirror-gapcursor {
  display: none;
  pointer-events: none;
  position: absolute;
  margin: 0;
}

.ProseMirror-gapcursor:after {
  content: "";
  display: block;
  position: absolute;
  top: -2px;
  width: 20px;
  border-top: 1px solid black;
  animation: ProseMirror-cursor-blink 1.1s steps(2, start) infinite;
}

@keyframes ProseMirror-cursor-blink {
  to {
    visibility: hidden;
  }
}

.ProseMirror-hideselection *::selection {
  background: transparent;
}

.ProseMirror-hideselection *::-moz-selection {
  background: transparent;
}

.ProseMirror-hideselection * {
  caret-color: transparent;
}

.ProseMirror-focused .ProseMirror-gapcursor {
  display: block;
}

.tippy-box[data-animation=fade][data-state=hidden] {
  opacity: 0
}`;
function createStyleTag(style2, nonce, suffix2) {
  const tiptapStyleTag = document.querySelector(`style[data-tiptap-style${suffix2 ? `-${suffix2}` : ""}]`);
  if (tiptapStyleTag !== null) {
    return tiptapStyleTag;
  }
  const styleNode = document.createElement("style");
  if (nonce) {
    styleNode.setAttribute("nonce", nonce);
  }
  styleNode.setAttribute(`data-tiptap-style${suffix2 ? `-${suffix2}` : ""}`, "");
  styleNode.innerHTML = style2;
  document.getElementsByTagName("head")[0].appendChild(styleNode);
  return styleNode;
}
__name(createStyleTag, "createStyleTag");
class Editor extends EventEmitter {
  static {
    __name(this, "Editor");
  }
  constructor(options5 = {}) {
    super();
    this.isFocused = false;
    this.isInitialized = false;
    this.extensionStorage = {};
    this.options = {
      element: document.createElement("div"),
      content: "",
      injectCSS: true,
      injectNonce: void 0,
      extensions: [],
      autofocus: false,
      editable: true,
      editorProps: {},
      parseOptions: {},
      coreExtensionOptions: {},
      enableInputRules: true,
      enablePasteRules: true,
      enableCoreExtensions: true,
      enableContentCheck: false,
      onBeforeCreate: /* @__PURE__ */ __name(() => null, "onBeforeCreate"),
      onCreate: /* @__PURE__ */ __name(() => null, "onCreate"),
      onUpdate: /* @__PURE__ */ __name(() => null, "onUpdate"),
      onSelectionUpdate: /* @__PURE__ */ __name(() => null, "onSelectionUpdate"),
      onTransaction: /* @__PURE__ */ __name(() => null, "onTransaction"),
      onFocus: /* @__PURE__ */ __name(() => null, "onFocus"),
      onBlur: /* @__PURE__ */ __name(() => null, "onBlur"),
      onDestroy: /* @__PURE__ */ __name(() => null, "onDestroy"),
      onContentError: /* @__PURE__ */ __name(({ error: error2 }) => {
        throw error2;
      }, "onContentError"),
      onPaste: /* @__PURE__ */ __name(() => null, "onPaste"),
      onDrop: /* @__PURE__ */ __name(() => null, "onDrop")
    };
    this.isCapturingTransaction = false;
    this.capturedTransaction = null;
    this.setOptions(options5);
    this.createExtensionManager();
    this.createCommandManager();
    this.createSchema();
    this.on("beforeCreate", this.options.onBeforeCreate);
    this.emit("beforeCreate", { editor: this });
    this.on("contentError", this.options.onContentError);
    this.createView();
    this.injectCSS();
    this.on("create", this.options.onCreate);
    this.on("update", this.options.onUpdate);
    this.on("selectionUpdate", this.options.onSelectionUpdate);
    this.on("transaction", this.options.onTransaction);
    this.on("focus", this.options.onFocus);
    this.on("blur", this.options.onBlur);
    this.on("destroy", this.options.onDestroy);
    this.on("drop", ({ event, slice: slice2, moved }) => this.options.onDrop(event, slice2, moved));
    this.on("paste", ({ event, slice: slice2 }) => this.options.onPaste(event, slice2));
    window.setTimeout(() => {
      if (this.isDestroyed) {
        return;
      }
      this.commands.focus(this.options.autofocus);
      this.emit("create", { editor: this });
      this.isInitialized = true;
    }, 0);
  }
  /**
   * Returns the editor storage.
   */
  get storage() {
    return this.extensionStorage;
  }
  /**
   * An object of all registered commands.
   */
  get commands() {
    return this.commandManager.commands;
  }
  /**
   * Create a command chain to call multiple commands at once.
   */
  chain() {
    return this.commandManager.chain();
  }
  /**
   * Check if a command or a command chain can be executed. Without executing it.
   */
  can() {
    return this.commandManager.can();
  }
  /**
   * Inject CSS styles.
   */
  injectCSS() {
    if (this.options.injectCSS && document) {
      this.css = createStyleTag(style, this.options.injectNonce);
    }
  }
  /**
   * Update editor options.
   *
   * @param options A list of options
   */
  setOptions(options5 = {}) {
    this.options = {
      ...this.options,
      ...options5
    };
    if (!this.view || !this.state || this.isDestroyed) {
      return;
    }
    if (this.options.editorProps) {
      this.view.setProps(this.options.editorProps);
    }
    this.view.updateState(this.state);
  }
  /**
   * Update editable state of the editor.
   */
  setEditable(editable, emitUpdate = true) {
    this.setOptions({ editable });
    if (emitUpdate) {
      this.emit("update", { editor: this, transaction: this.state.tr });
    }
  }
  /**
   * Returns whether the editor is editable.
   */
  get isEditable() {
    return this.options.editable && this.view && this.view.editable;
  }
  /**
   * Returns the editor state.
   */
  get state() {
    return this.view.state;
  }
  /**
   * Register a ProseMirror plugin.
   *
   * @param plugin A ProseMirror plugin
   * @param handlePlugins Control how to merge the plugin into the existing plugins.
   * @returns The new editor state
   */
  registerPlugin(plugin, handlePlugins) {
    const plugins = isFunction$1(handlePlugins) ? handlePlugins(plugin, [...this.state.plugins]) : [...this.state.plugins, plugin];
    const state = this.state.reconfigure({ plugins });
    this.view.updateState(state);
    return state;
  }
  /**
   * Unregister a ProseMirror plugin.
   *
   * @param nameOrPluginKeyToRemove The plugins name
   * @returns The new editor state or undefined if the editor is destroyed
   */
  unregisterPlugin(nameOrPluginKeyToRemove) {
    if (this.isDestroyed) {
      return void 0;
    }
    const prevPlugins = this.state.plugins;
    let plugins = prevPlugins;
    [].concat(nameOrPluginKeyToRemove).forEach((nameOrPluginKey) => {
      const name2 = typeof nameOrPluginKey === "string" ? `${nameOrPluginKey}$` : nameOrPluginKey.key;
      plugins = prevPlugins.filter((plugin) => !plugin.key.startsWith(name2));
    });
    if (prevPlugins.length === plugins.length) {
      return void 0;
    }
    const state = this.state.reconfigure({
      plugins
    });
    this.view.updateState(state);
    return state;
  }
  /**
   * Creates an extension manager.
   */
  createExtensionManager() {
    var _a2, _b;
    const coreExtensions = this.options.enableCoreExtensions ? [
      Editable,
      ClipboardTextSerializer.configure({
        blockSeparator: (_b = (_a2 = this.options.coreExtensionOptions) === null || _a2 === void 0 ? void 0 : _a2.clipboardTextSerializer) === null || _b === void 0 ? void 0 : _b.blockSeparator
      }),
      Commands,
      FocusEvents,
      Keymap,
      Tabindex,
      Drop,
      Paste
    ].filter((ext) => {
      if (typeof this.options.enableCoreExtensions === "object") {
        return this.options.enableCoreExtensions[ext.name] !== false;
      }
      return true;
    }) : [];
    const allExtensions = [...coreExtensions, ...this.options.extensions].filter((extension) => {
      return ["extension", "node", "mark"].includes(extension === null || extension === void 0 ? void 0 : extension.type);
    });
    this.extensionManager = new ExtensionManager(allExtensions, this);
  }
  /**
   * Creates an command manager.
   */
  createCommandManager() {
    this.commandManager = new CommandManager({
      editor: this
    });
  }
  /**
   * Creates a ProseMirror schema.
   */
  createSchema() {
    this.schema = this.extensionManager.schema;
  }
  /**
   * Creates a ProseMirror view.
   */
  createView() {
    var _a2;
    let doc2;
    try {
      doc2 = createDocument(this.options.content, this.schema, this.options.parseOptions, { errorOnInvalidContent: this.options.enableContentCheck });
    } catch (e2) {
      if (!(e2 instanceof Error) || !["[tiptap error]: Invalid JSON content", "[tiptap error]: Invalid HTML content"].includes(e2.message)) {
        throw e2;
      }
      this.emit("contentError", {
        editor: this,
        error: e2,
        disableCollaboration: /* @__PURE__ */ __name(() => {
          if (this.storage.collaboration) {
            this.storage.collaboration.isDisabled = true;
          }
          this.options.extensions = this.options.extensions.filter((extension) => extension.name !== "collaboration");
          this.createExtensionManager();
        }, "disableCollaboration")
      });
      doc2 = createDocument(this.options.content, this.schema, this.options.parseOptions, { errorOnInvalidContent: false });
    }
    const selection = resolveFocusPosition(doc2, this.options.autofocus);
    this.view = new EditorView(this.options.element, {
      ...this.options.editorProps,
      attributes: {
        // add `role="textbox"` to the editor element
        role: "textbox",
        ...(_a2 = this.options.editorProps) === null || _a2 === void 0 ? void 0 : _a2.attributes
      },
      dispatchTransaction: this.dispatchTransaction.bind(this),
      state: EditorState.create({
        doc: doc2,
        selection: selection || void 0
      })
    });
    const newState = this.state.reconfigure({
      plugins: this.extensionManager.plugins
    });
    this.view.updateState(newState);
    this.createNodeViews();
    this.prependClass();
    const dom = this.view.dom;
    dom.editor = this;
  }
  /**
   * Creates all node views.
   */
  createNodeViews() {
    if (this.view.isDestroyed) {
      return;
    }
    this.view.setProps({
      nodeViews: this.extensionManager.nodeViews
    });
  }
  /**
   * Prepend class name to element.
   */
  prependClass() {
    this.view.dom.className = `tiptap ${this.view.dom.className}`;
  }
  captureTransaction(fn) {
    this.isCapturingTransaction = true;
    fn();
    this.isCapturingTransaction = false;
    const tr2 = this.capturedTransaction;
    this.capturedTransaction = null;
    return tr2;
  }
  /**
   * The callback over which to send transactions (state updates) produced by the view.
   *
   * @param transaction An editor state transaction
   */
  dispatchTransaction(transaction) {
    if (this.view.isDestroyed) {
      return;
    }
    if (this.isCapturingTransaction) {
      if (!this.capturedTransaction) {
        this.capturedTransaction = transaction;
        return;
      }
      transaction.steps.forEach((step2) => {
        var _a2;
        return (_a2 = this.capturedTransaction) === null || _a2 === void 0 ? void 0 : _a2.step(step2);
      });
      return;
    }
    const state = this.state.apply(transaction);
    const selectionHasChanged = !this.state.selection.eq(state.selection);
    this.emit("beforeTransaction", {
      editor: this,
      transaction,
      nextState: state
    });
    this.view.updateState(state);
    this.emit("transaction", {
      editor: this,
      transaction
    });
    if (selectionHasChanged) {
      this.emit("selectionUpdate", {
        editor: this,
        transaction
      });
    }
    const focus5 = transaction.getMeta("focus");
    const blur2 = transaction.getMeta("blur");
    if (focus5) {
      this.emit("focus", {
        editor: this,
        event: focus5.event,
        transaction
      });
    }
    if (blur2) {
      this.emit("blur", {
        editor: this,
        event: blur2.event,
        transaction
      });
    }
    if (!transaction.docChanged || transaction.getMeta("preventUpdate")) {
      return;
    }
    this.emit("update", {
      editor: this,
      transaction
    });
  }
  /**
   * Get attributes of the currently selected node or mark.
   */
  getAttributes(nameOrType) {
    return getAttributes(this.state, nameOrType);
  }
  isActive(nameOrAttributes, attributesOrUndefined) {
    const name2 = typeof nameOrAttributes === "string" ? nameOrAttributes : null;
    const attributes = typeof nameOrAttributes === "string" ? attributesOrUndefined : nameOrAttributes;
    return isActive(this.state, name2, attributes);
  }
  /**
   * Get the document as JSON.
   */
  getJSON() {
    return this.state.doc.toJSON();
  }
  /**
   * Get the document as HTML.
   */
  getHTML() {
    return getHTMLFromFragment(this.state.doc.content, this.schema);
  }
  /**
   * Get the document as text.
   */
  getText(options5) {
    const { blockSeparator = "\n\n", textSerializers = {} } = options5 || {};
    return getText(this.state.doc, {
      blockSeparator,
      textSerializers: {
        ...getTextSerializersFromSchema(this.schema),
        ...textSerializers
      }
    });
  }
  /**
   * Check if there is no content.
   */
  get isEmpty() {
    return isNodeEmpty(this.state.doc);
  }
  /**
   * Get the number of characters for the current document.
   *
   * @deprecated
   */
  getCharacterCount() {
    console.warn('[tiptap warn]: "editor.getCharacterCount()" is deprecated. Please use "editor.storage.characterCount.characters()" instead.');
    return this.state.doc.content.size - 2;
  }
  /**
   * Destroy the editor.
   */
  destroy() {
    this.emit("destroy");
    if (this.view) {
      const dom = this.view.dom;
      if (dom && dom.editor) {
        delete dom.editor;
      }
      this.view.destroy();
    }
    this.removeAllListeners();
  }
  /**
   * Check if the editor is already destroyed.
   */
  get isDestroyed() {
    var _a2;
    return !((_a2 = this.view) === null || _a2 === void 0 ? void 0 : _a2.docView);
  }
  $node(selector, attributes) {
    var _a2;
    return ((_a2 = this.$doc) === null || _a2 === void 0 ? void 0 : _a2.querySelector(selector, attributes)) || null;
  }
  $nodes(selector, attributes) {
    var _a2;
    return ((_a2 = this.$doc) === null || _a2 === void 0 ? void 0 : _a2.querySelectorAll(selector, attributes)) || null;
  }
  $pos(pos) {
    const $pos = this.state.doc.resolve(pos);
    return new NodePos($pos, this);
  }
  get $doc() {
    return this.$pos(0);
  }
}
function markInputRule(config2) {
  return new InputRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2 }) => {
      const attributes = callOrReturn(config2.getAttributes, void 0, match2);
      if (attributes === false || attributes === null) {
        return null;
      }
      const { tr: tr2 } = state;
      const captureGroup = match2[match2.length - 1];
      const fullMatch = match2[0];
      if (captureGroup) {
        const startSpaces = fullMatch.search(/\S/);
        const textStart = range2.from + fullMatch.indexOf(captureGroup);
        const textEnd = textStart + captureGroup.length;
        const excludedMarks = getMarksBetween(range2.from, range2.to, state.doc).filter((item3) => {
          const excluded = item3.mark.type.excluded;
          return excluded.find((type) => type === config2.type && type !== item3.mark.type);
        }).filter((item3) => item3.to > textStart);
        if (excludedMarks.length) {
          return null;
        }
        if (textEnd < range2.to) {
          tr2.delete(textEnd, range2.to);
        }
        if (textStart > range2.from) {
          tr2.delete(range2.from + startSpaces, textStart);
        }
        const markEnd = range2.from + startSpaces + captureGroup.length;
        tr2.addMark(range2.from + startSpaces, markEnd, config2.type.create(attributes || {}));
        tr2.removeStoredMark(config2.type);
      }
    }, "handler")
  });
}
__name(markInputRule, "markInputRule");
function nodeInputRule(config2) {
  return new InputRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2 }) => {
      const attributes = callOrReturn(config2.getAttributes, void 0, match2) || {};
      const { tr: tr2 } = state;
      const start2 = range2.from;
      let end = range2.to;
      const newNode = config2.type.create(attributes);
      if (match2[1]) {
        const offset = match2[0].lastIndexOf(match2[1]);
        let matchStart = start2 + offset;
        if (matchStart > end) {
          matchStart = end;
        } else {
          end = matchStart + match2[1].length;
        }
        const lastChar = match2[0][match2[0].length - 1];
        tr2.insertText(lastChar, start2 + match2[0].length - 1);
        tr2.replaceWith(matchStart, end, newNode);
      } else if (match2[0]) {
        const insertionStart = config2.type.isInline ? start2 : start2 - 1;
        tr2.insert(insertionStart, config2.type.create(attributes)).delete(tr2.mapping.map(start2), tr2.mapping.map(end));
      }
      tr2.scrollIntoView();
    }, "handler")
  });
}
__name(nodeInputRule, "nodeInputRule");
function textblockTypeInputRule(config2) {
  return new InputRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2 }) => {
      const $start = state.doc.resolve(range2.from);
      const attributes = callOrReturn(config2.getAttributes, void 0, match2) || {};
      if (!$start.node(-1).canReplaceWith($start.index(-1), $start.indexAfter(-1), config2.type)) {
        return null;
      }
      state.tr.delete(range2.from, range2.to).setBlockType(range2.from, range2.from, config2.type, attributes);
    }, "handler")
  });
}
__name(textblockTypeInputRule, "textblockTypeInputRule");
function textInputRule(config2) {
  return new InputRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2 }) => {
      let insert2 = config2.replace;
      let start2 = range2.from;
      const end = range2.to;
      if (match2[1]) {
        const offset = match2[0].lastIndexOf(match2[1]);
        insert2 += match2[0].slice(offset + match2[1].length);
        start2 += offset;
        const cutOff = start2 - end;
        if (cutOff > 0) {
          insert2 = match2[0].slice(offset - cutOff, offset) + insert2;
          start2 = end;
        }
      }
      state.tr.insertText(insert2, start2, end);
    }, "handler")
  });
}
__name(textInputRule, "textInputRule");
function wrappingInputRule(config2) {
  return new InputRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2, chain }) => {
      const attributes = callOrReturn(config2.getAttributes, void 0, match2) || {};
      const tr2 = state.tr.delete(range2.from, range2.to);
      const $start = tr2.doc.resolve(range2.from);
      const blockRange = $start.blockRange();
      const wrapping = blockRange && findWrapping(blockRange, config2.type, attributes);
      if (!wrapping) {
        return null;
      }
      tr2.wrap(blockRange, wrapping);
      if (config2.keepMarks && config2.editor) {
        const { selection, storedMarks } = state;
        const { splittableMarks } = config2.editor.extensionManager;
        const marks = storedMarks || selection.$to.parentOffset && selection.$from.marks();
        if (marks) {
          const filteredMarks = marks.filter((mark2) => splittableMarks.includes(mark2.type.name));
          tr2.ensureMarks(filteredMarks);
        }
      }
      if (config2.keepAttributes) {
        const nodeType = config2.type.name === "bulletList" || config2.type.name === "orderedList" ? "listItem" : "taskList";
        chain().updateAttributes(nodeType, attributes).run();
      }
      const before = tr2.doc.resolve(range2.from - 1).nodeBefore;
      if (before && before.type === config2.type && canJoin(tr2.doc, range2.from - 1) && (!config2.joinPredicate || config2.joinPredicate(match2, before))) {
        tr2.join(range2.from - 1);
      }
    }, "handler")
  });
}
__name(wrappingInputRule, "wrappingInputRule");
let Node$1 = class Node3 {
  static {
    __name(this, "Node");
  }
  constructor(config2 = {}) {
    this.type = "node";
    this.name = "node";
    this.parent = null;
    this.child = null;
    this.config = {
      name: this.name,
      defaultOptions: {}
    };
    this.config = {
      ...this.config,
      ...config2
    };
    this.name = this.config.name;
    if (config2.defaultOptions && Object.keys(config2.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${this.name}".`);
    }
    this.options = this.config.defaultOptions;
    if (this.config.addOptions) {
      this.options = callOrReturn(getExtensionField(this, "addOptions", {
        name: this.name
      }));
    }
    this.storage = callOrReturn(getExtensionField(this, "addStorage", {
      name: this.name,
      options: this.options
    })) || {};
  }
  static create(config2 = {}) {
    return new Node3(config2);
  }
  configure(options5 = {}) {
    const extension = this.extend({
      ...this.config,
      addOptions: /* @__PURE__ */ __name(() => {
        return mergeDeep(this.options, options5);
      }, "addOptions")
    });
    extension.name = this.name;
    extension.parent = this.parent;
    return extension;
  }
  extend(extendedConfig = {}) {
    const extension = new Node3(extendedConfig);
    extension.parent = this;
    this.child = extension;
    extension.name = extendedConfig.name ? extendedConfig.name : extension.parent.name;
    if (extendedConfig.defaultOptions && Object.keys(extendedConfig.defaultOptions).length > 0) {
      console.warn(`[tiptap warn]: BREAKING CHANGE: "defaultOptions" is deprecated. Please use "addOptions" instead. Found in extension: "${extension.name}".`);
    }
    extension.options = callOrReturn(getExtensionField(extension, "addOptions", {
      name: extension.name
    }));
    extension.storage = callOrReturn(getExtensionField(extension, "addStorage", {
      name: extension.name,
      options: extension.options
    }));
    return extension;
  }
};
function isAndroid$1() {
  return navigator.platform === "Android" || /android/i.test(navigator.userAgent);
}
__name(isAndroid$1, "isAndroid$1");
class NodeView {
  static {
    __name(this, "NodeView");
  }
  constructor(component, props, options5) {
    this.isDragging = false;
    this.component = component;
    this.editor = props.editor;
    this.options = {
      stopEvent: null,
      ignoreMutation: null,
      ...options5
    };
    this.extension = props.extension;
    this.node = props.node;
    this.decorations = props.decorations;
    this.innerDecorations = props.innerDecorations;
    this.view = props.view;
    this.HTMLAttributes = props.HTMLAttributes;
    this.getPos = props.getPos;
    this.mount();
  }
  mount() {
    return;
  }
  get dom() {
    return this.editor.view.dom;
  }
  get contentDOM() {
    return null;
  }
  onDragStart(event) {
    var _a2, _b, _c, _d, _e, _f, _g;
    const { view } = this.editor;
    const target2 = event.target;
    const dragHandle = target2.nodeType === 3 ? (_a2 = target2.parentElement) === null || _a2 === void 0 ? void 0 : _a2.closest("[data-drag-handle]") : target2.closest("[data-drag-handle]");
    if (!this.dom || ((_b = this.contentDOM) === null || _b === void 0 ? void 0 : _b.contains(target2)) || !dragHandle) {
      return;
    }
    let x2 = 0;
    let y2 = 0;
    if (this.dom !== dragHandle) {
      const domBox = this.dom.getBoundingClientRect();
      const handleBox = dragHandle.getBoundingClientRect();
      const offsetX = (_c = event.offsetX) !== null && _c !== void 0 ? _c : (_d = event.nativeEvent) === null || _d === void 0 ? void 0 : _d.offsetX;
      const offsetY = (_e = event.offsetY) !== null && _e !== void 0 ? _e : (_f = event.nativeEvent) === null || _f === void 0 ? void 0 : _f.offsetY;
      x2 = handleBox.x - domBox.x + offsetX;
      y2 = handleBox.y - domBox.y + offsetY;
    }
    (_g = event.dataTransfer) === null || _g === void 0 ? void 0 : _g.setDragImage(this.dom, x2, y2);
    const pos = this.getPos();
    if (typeof pos !== "number") {
      return;
    }
    const selection = NodeSelection.create(view.state.doc, pos);
    const transaction = view.state.tr.setSelection(selection);
    view.dispatch(transaction);
  }
  stopEvent(event) {
    var _a2;
    if (!this.dom) {
      return false;
    }
    if (typeof this.options.stopEvent === "function") {
      return this.options.stopEvent({ event });
    }
    const target2 = event.target;
    const isInElement = this.dom.contains(target2) && !((_a2 = this.contentDOM) === null || _a2 === void 0 ? void 0 : _a2.contains(target2));
    if (!isInElement) {
      return false;
    }
    const isDragEvent = event.type.startsWith("drag");
    const isDropEvent = event.type === "drop";
    const isInput = ["INPUT", "BUTTON", "SELECT", "TEXTAREA"].includes(target2.tagName) || target2.isContentEditable;
    if (isInput && !isDropEvent && !isDragEvent) {
      return true;
    }
    const { isEditable } = this.editor;
    const { isDragging } = this;
    const isDraggable = !!this.node.type.spec.draggable;
    const isSelectable = NodeSelection.isSelectable(this.node);
    const isCopyEvent = event.type === "copy";
    const isPasteEvent = event.type === "paste";
    const isCutEvent = event.type === "cut";
    const isClickEvent = event.type === "mousedown";
    if (!isDraggable && isSelectable && isDragEvent) {
      event.preventDefault();
    }
    if (isDraggable && isDragEvent && !isDragging) {
      event.preventDefault();
      return false;
    }
    if (isDraggable && isEditable && !isDragging && isClickEvent) {
      const dragHandle = target2.closest("[data-drag-handle]");
      const isValidDragHandle = dragHandle && (this.dom === dragHandle || this.dom.contains(dragHandle));
      if (isValidDragHandle) {
        this.isDragging = true;
        document.addEventListener("dragend", () => {
          this.isDragging = false;
        }, { once: true });
        document.addEventListener("drop", () => {
          this.isDragging = false;
        }, { once: true });
        document.addEventListener("mouseup", () => {
          this.isDragging = false;
        }, { once: true });
      }
    }
    if (isDragging || isDropEvent || isCopyEvent || isPasteEvent || isCutEvent || isClickEvent && isSelectable) {
      return false;
    }
    return true;
  }
  /**
   * Called when a DOM [mutation](https://developer.mozilla.org/en-US/docs/Web/API/MutationObserver) or a selection change happens within the view.
   * @return `false` if the editor should re-read the selection or re-parse the range around the mutation
   * @return `true` if it can safely be ignored.
   */
  ignoreMutation(mutation) {
    if (!this.dom || !this.contentDOM) {
      return true;
    }
    if (typeof this.options.ignoreMutation === "function") {
      return this.options.ignoreMutation({ mutation });
    }
    if (this.node.isLeaf || this.node.isAtom) {
      return true;
    }
    if (mutation.type === "selection") {
      return false;
    }
    if (this.dom.contains(mutation.target) && mutation.type === "childList" && (isiOS() || isAndroid$1()) && this.editor.isFocused) {
      const changedNodes = [
        ...Array.from(mutation.addedNodes),
        ...Array.from(mutation.removedNodes)
      ];
      if (changedNodes.every((node3) => node3.isContentEditable)) {
        return false;
      }
    }
    if (this.contentDOM === mutation.target && mutation.type === "attributes") {
      return true;
    }
    if (this.contentDOM.contains(mutation.target)) {
      return false;
    }
    return true;
  }
  /**
   * Update the attributes of the prosemirror node.
   */
  updateAttributes(attributes) {
    this.editor.commands.command(({ tr: tr2 }) => {
      const pos = this.getPos();
      if (typeof pos !== "number") {
        return false;
      }
      tr2.setNodeMarkup(pos, void 0, {
        ...this.node.attrs,
        ...attributes
      });
      return true;
    });
  }
  /**
   * Delete the node.
   */
  deleteNode() {
    const from2 = this.getPos();
    if (typeof from2 !== "number") {
      return;
    }
    const to = from2 + this.node.nodeSize;
    this.editor.commands.deleteRange({ from: from2, to });
  }
}
function markPasteRule(config2) {
  return new PasteRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2, pasteEvent }) => {
      const attributes = callOrReturn(config2.getAttributes, void 0, match2, pasteEvent);
      if (attributes === false || attributes === null) {
        return null;
      }
      const { tr: tr2 } = state;
      const captureGroup = match2[match2.length - 1];
      const fullMatch = match2[0];
      let markEnd = range2.to;
      if (captureGroup) {
        const startSpaces = fullMatch.search(/\S/);
        const textStart = range2.from + fullMatch.indexOf(captureGroup);
        const textEnd = textStart + captureGroup.length;
        const excludedMarks = getMarksBetween(range2.from, range2.to, state.doc).filter((item3) => {
          const excluded = item3.mark.type.excluded;
          return excluded.find((type) => type === config2.type && type !== item3.mark.type);
        }).filter((item3) => item3.to > textStart);
        if (excludedMarks.length) {
          return null;
        }
        if (textEnd < range2.to) {
          tr2.delete(textEnd, range2.to);
        }
        if (textStart > range2.from) {
          tr2.delete(range2.from + startSpaces, textStart);
        }
        markEnd = range2.from + startSpaces + captureGroup.length;
        tr2.addMark(range2.from + startSpaces, markEnd, config2.type.create(attributes || {}));
        tr2.removeStoredMark(config2.type);
      }
    }, "handler")
  });
}
__name(markPasteRule, "markPasteRule");
function escapeForRegEx(string) {
  return string.replace(/[-/\\^$*+?.()|[\]{}]/g, "\\$&");
}
__name(escapeForRegEx, "escapeForRegEx");
function isString$2(value3) {
  return typeof value3 === "string";
}
__name(isString$2, "isString$2");
function nodePasteRule(config2) {
  return new PasteRule({
    find: config2.find,
    handler({ match: match2, chain, range: range2, pasteEvent }) {
      const attributes = callOrReturn(config2.getAttributes, void 0, match2, pasteEvent);
      const content3 = callOrReturn(config2.getContent, void 0, attributes);
      if (attributes === false || attributes === null) {
        return null;
      }
      const node3 = { type: config2.type.name, attrs: attributes };
      if (content3) {
        node3.content = content3;
      }
      if (match2.input) {
        chain().deleteRange(range2).insertContentAt(range2.from, node3);
      }
    }
  });
}
__name(nodePasteRule, "nodePasteRule");
function textPasteRule(config2) {
  return new PasteRule({
    find: config2.find,
    handler: /* @__PURE__ */ __name(({ state, range: range2, match: match2 }) => {
      let insert2 = config2.replace;
      let start2 = range2.from;
      const end = range2.to;
      if (match2[1]) {
        const offset = match2[0].lastIndexOf(match2[1]);
        insert2 += match2[0].slice(offset + match2[1].length);
        start2 += offset;
        const cutOff = start2 - end;
        if (cutOff > 0) {
          insert2 = match2[0].slice(offset - cutOff, offset) + insert2;
          start2 = end;
        }
      }
      state.tr.insertText(insert2, start2, end);
    }, "handler")
  });
}
__name(textPasteRule, "textPasteRule");
class Tracker {
  static {
    __name(this, "Tracker");
  }
  constructor(transaction) {
    this.transaction = transaction;
    this.currentStep = this.transaction.steps.length;
  }
  map(position3) {
    let deleted = false;
    const mappedPosition = this.transaction.steps.slice(this.currentStep).reduce((newPosition, step2) => {
      const mapResult = step2.getMap().mapResult(newPosition);
      if (mapResult.deleted) {
        deleted = true;
      }
      return mapResult.pos;
    }, position3);
    return {
      position: mappedPosition,
      deleted
    };
  }
}
const encodedTlds = " ögensberater2ung14sicherung10t2g1i0ajes4deo3g1king4llas4n1p1rgin4sa1ion4va1o3laanderen9n1odka3lvo3te1ing3o2yage5u2wales2mart4ter4ng0gou5tch0es6eather0channel12bcam3er2site5d0ding5ibo2r3f1hoswho6ien2ki2lliamhill9n0dows4e1ners6me2olterskluwer11odside6rk0s2ld3w2s1tc1f3xbox3erox4ihuan4n2xx2yz3yachts4hoo3maxun5ndex5e1odobashi7ga2kohama6u0tube6t1un3za0ppos4ra3ero3ip2m1one3uerich6w2";
const encodedUtlds = "ελ1υ2бг1ел3дети4ею2католик6ом3мкд2он1сква6онлайн5рг3рус2ф2сайт3рб3укр3қаз3հայ3ישראל5קום3ابوظبي5رامكو5لاردن4بحرين5جزائر5سعودية6عليان5مغرب5مارات5یران5بارت2زار4يتك3ھارت5تونس4سودان3رية5شبكة4عراق2ب2مان4فلسطين6قطر3كاثوليك6وم3مصر2ليسيا5وريتانيا7قع4همراه5پاکستان7ڀارت4कॉम3नेट3भारत0म्3ोत5संगठन5বাংলা5ভারত2ৰত4ਭਾਰਤ4ભારત4ଭାରତ4இந்தியா6லங்கை6சிங்கப்பூர்11భారత్5ಭಾರತ4ഭാരതം5ලංකා4คอม3ไทย3ລາວ3გე2みんな3アマゾン4クラウド4グーグル4コム2ストア3セール3ファッション6ポイント4世界2中信1国1國1文网3亚马逊3企业2佛山2信息2健康2八卦2公司1益2台湾1灣2商城1店1标2嘉里0大酒店5在线2大拿2天主教3娱乐2家電2广东2微博2慈善2我爱你3手机2招聘2政务1府2新加坡2闻2时尚2書籍2机构2淡马锡3游戏2澳門2点看2移动2组织机构4网址1店1站1络2联通2谷歌2购物2通販2集团2電訊盈科4飞利浦3食品2餐厅2香格里拉3港2닷넷1컴2삼성2한국2";
const assign$2 = /* @__PURE__ */ __name((target2, properties) => {
  for (const key in properties) {
    target2[key] = properties[key];
  }
  return target2;
}, "assign$2");
const numeric = "numeric";
const ascii = "ascii";
const alpha = "alpha";
const asciinumeric = "asciinumeric";
const alphanumeric = "alphanumeric";
const domain = "domain";
const emoji = "emoji";
const scheme = "scheme";
const slashscheme = "slashscheme";
const whitespace = "whitespace";
function registerGroup(name2, groups) {
  if (!(name2 in groups)) {
    groups[name2] = [];
  }
  return groups[name2];
}
__name(registerGroup, "registerGroup");
function addToGroups(t2, flags, groups) {
  if (flags[numeric]) {
    flags[asciinumeric] = true;
    flags[alphanumeric] = true;
  }
  if (flags[ascii]) {
    flags[asciinumeric] = true;
    flags[alpha] = true;
  }
  if (flags[asciinumeric]) {
    flags[alphanumeric] = true;
  }
  if (flags[alpha]) {
    flags[alphanumeric] = true;
  }
  if (flags[alphanumeric]) {
    flags[domain] = true;
  }
  if (flags[emoji]) {
    flags[domain] = true;
  }
  for (const k2 in flags) {
    const group = registerGroup(k2, groups);
    if (group.indexOf(t2) < 0) {
      group.push(t2);
    }
  }
}
__name(addToGroups, "addToGroups");
function flagsForToken(t2, groups) {
  const result = {};
  for (const c2 in groups) {
    if (groups[c2].indexOf(t2) >= 0) {
      result[c2] = true;
    }
  }
  return result;
}
__name(flagsForToken, "flagsForToken");
function State(token = null) {
  this.j = {};
  this.jr = [];
  this.jd = null;
  this.t = token;
}
__name(State, "State");
State.groups = {};
State.prototype = {
  accepts() {
    return !!this.t;
  },
  /**
   * Follow an existing transition from the given input to the next state.
   * Does not mutate.
   * @param {string} input character or token type to transition on
   * @returns {?State<T>} the next state, if any
   */
  go(input) {
    const state = this;
    const nextState = state.j[input];
    if (nextState) {
      return nextState;
    }
    for (let i2 = 0; i2 < state.jr.length; i2++) {
      const regex2 = state.jr[i2][0];
      const nextState2 = state.jr[i2][1];
      if (nextState2 && regex2.test(input)) {
        return nextState2;
      }
    }
    return state.jd;
  },
  /**
   * Whether the state has a transition for the given input. Set the second
   * argument to true to only look for an exact match (and not a default or
   * regular-expression-based transition)
   * @param {string} input
   * @param {boolean} exactOnly
   */
  has(input, exactOnly = false) {
    return exactOnly ? input in this.j : !!this.go(input);
  },
  /**
   * Short for "transition all"; create a transition from the array of items
   * in the given list to the same final resulting state.
   * @param {string | string[]} inputs Group of inputs to transition on
   * @param {Transition<T> | State<T>} [next] Transition options
   * @param {Flags} [flags] Collections flags to add token to
   * @param {Collections<T>} [groups] Master list of token groups
   */
  ta(inputs, next2, flags, groups) {
    for (let i2 = 0; i2 < inputs.length; i2++) {
      this.tt(inputs[i2], next2, flags, groups);
    }
  },
  /**
   * Short for "take regexp transition"; defines a transition for this state
   * when it encounters a token which matches the given regular expression
   * @param {RegExp} regexp Regular expression transition (populate first)
   * @param {T | State<T>} [next] Transition options
   * @param {Flags} [flags] Collections flags to add token to
   * @param {Collections<T>} [groups] Master list of token groups
   * @returns {State<T>} taken after the given input
   */
  tr(regexp2, next2, flags, groups) {
    groups = groups || State.groups;
    let nextState;
    if (next2 && next2.j) {
      nextState = next2;
    } else {
      nextState = new State(next2);
      if (flags && groups) {
        addToGroups(next2, flags, groups);
      }
    }
    this.jr.push([regexp2, nextState]);
    return nextState;
  },
  /**
   * Short for "take transitions", will take as many sequential transitions as
   * the length of the given input and returns the
   * resulting final state.
   * @param {string | string[]} input
   * @param {T | State<T>} [next] Transition options
   * @param {Flags} [flags] Collections flags to add token to
   * @param {Collections<T>} [groups] Master list of token groups
   * @returns {State<T>} taken after the given input
   */
  ts(input, next2, flags, groups) {
    let state = this;
    const len = input.length;
    if (!len) {
      return state;
    }
    for (let i2 = 0; i2 < len - 1; i2++) {
      state = state.tt(input[i2]);
    }
    return state.tt(input[len - 1], next2, flags, groups);
  },
  /**
   * Short for "take transition", this is a method for building/working with
   * state machines.
   *
   * If a state already exists for the given input, returns it.
   *
   * If a token is specified, that state will emit that token when reached by
   * the linkify engine.
   *
   * If no state exists, it will be initialized with some default transitions
   * that resemble existing default transitions.
   *
   * If a state is given for the second argument, that state will be
   * transitioned to on the given input regardless of what that input
   * previously did.
   *
   * Specify a token group flags to define groups that this token belongs to.
   * The token will be added to corresponding entires in the given groups
   * object.
   *
   * @param {string} input character, token type to transition on
   * @param {T | State<T>} [next] Transition options
   * @param {Flags} [flags] Collections flags to add token to
   * @param {Collections<T>} [groups] Master list of groups
   * @returns {State<T>} taken after the given input
   */
  tt(input, next2, flags, groups) {
    groups = groups || State.groups;
    const state = this;
    if (next2 && next2.j) {
      state.j[input] = next2;
      return next2;
    }
    const t2 = next2;
    let nextState, templateState = state.go(input);
    if (templateState) {
      nextState = new State();
      assign$2(nextState.j, templateState.j);
      nextState.jr.push.apply(nextState.jr, templateState.jr);
      nextState.jd = templateState.jd;
      nextState.t = templateState.t;
    } else {
      nextState = new State();
    }
    if (t2) {
      if (groups) {
        if (nextState.t && typeof nextState.t === "string") {
          const allFlags = assign$2(flagsForToken(nextState.t, groups), flags);
          addToGroups(t2, allFlags, groups);
        } else if (flags) {
          addToGroups(t2, flags, groups);
        }
      }
      nextState.t = t2;
    }
    state.j[input] = nextState;
    return nextState;
  }
};
const ta = /* @__PURE__ */ __name((state, input, next2, flags, groups) => state.ta(input, next2, flags, groups), "ta");
const tr = /* @__PURE__ */ __name((state, regexp2, next2, flags, groups) => state.tr(regexp2, next2, flags, groups), "tr");
const ts = /* @__PURE__ */ __name((state, input, next2, flags, groups) => state.ts(input, next2, flags, groups), "ts");
const tt = /* @__PURE__ */ __name((state, input, next2, flags, groups) => state.tt(input, next2, flags, groups), "tt");
const WORD = "WORD";
const UWORD = "UWORD";
const ASCIINUMERICAL = "ASCIINUMERICAL";
const ALPHANUMERICAL = "ALPHANUMERICAL";
const LOCALHOST = "LOCALHOST";
const TLD = "TLD";
const UTLD = "UTLD";
const SCHEME = "SCHEME";
const SLASH_SCHEME = "SLASH_SCHEME";
const NUM = "NUM";
const WS = "WS";
const NL = "NL";
const OPENBRACE = "OPENBRACE";
const CLOSEBRACE = "CLOSEBRACE";
const OPENBRACKET = "OPENBRACKET";
const CLOSEBRACKET = "CLOSEBRACKET";
const OPENPAREN = "OPENPAREN";
const CLOSEPAREN = "CLOSEPAREN";
const OPENANGLEBRACKET = "OPENANGLEBRACKET";
const CLOSEANGLEBRACKET = "CLOSEANGLEBRACKET";
const FULLWIDTHLEFTPAREN = "FULLWIDTHLEFTPAREN";
const FULLWIDTHRIGHTPAREN = "FULLWIDTHRIGHTPAREN";
const LEFTCORNERBRACKET = "LEFTCORNERBRACKET";
const RIGHTCORNERBRACKET = "RIGHTCORNERBRACKET";
const LEFTWHITECORNERBRACKET = "LEFTWHITECORNERBRACKET";
const RIGHTWHITECORNERBRACKET = "RIGHTWHITECORNERBRACKET";
const FULLWIDTHLESSTHAN = "FULLWIDTHLESSTHAN";
const FULLWIDTHGREATERTHAN = "FULLWIDTHGREATERTHAN";
const AMPERSAND = "AMPERSAND";
const APOSTROPHE$1 = "APOSTROPHE";
const ASTERISK = "ASTERISK";
const AT = "AT";
const BACKSLASH = "BACKSLASH";
const BACKTICK = "BACKTICK";
const CARET = "CARET";
const COLON = "COLON";
const COMMA = "COMMA";
const DOLLAR = "DOLLAR";
const DOT = "DOT";
const EQUALS = "EQUALS";
const EXCLAMATION = "EXCLAMATION";
const HYPHEN = "HYPHEN";
const PERCENT = "PERCENT";
const PIPE = "PIPE";
const PLUS = "PLUS";
const POUND = "POUND";
const QUERY = "QUERY";
const QUOTE = "QUOTE";
const FULLWIDTHMIDDLEDOT = "FULLWIDTHMIDDLEDOT";
const SEMI = "SEMI";
const SLASH = "SLASH";
const TILDE = "TILDE";
const UNDERSCORE = "UNDERSCORE";
const EMOJI$1 = "EMOJI";
const SYM = "SYM";
var tk = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  WORD,
  UWORD,
  ASCIINUMERICAL,
  ALPHANUMERICAL,
  LOCALHOST,
  TLD,
  UTLD,
  SCHEME,
  SLASH_SCHEME,
  NUM,
  WS,
  NL,
  OPENBRACE,
  CLOSEBRACE,
  OPENBRACKET,
  CLOSEBRACKET,
  OPENPAREN,
  CLOSEPAREN,
  OPENANGLEBRACKET,
  CLOSEANGLEBRACKET,
  FULLWIDTHLEFTPAREN,
  FULLWIDTHRIGHTPAREN,
  LEFTCORNERBRACKET,
  RIGHTCORNERBRACKET,
  LEFTWHITECORNERBRACKET,
  RIGHTWHITECORNERBRACKET,
  FULLWIDTHLESSTHAN,
  FULLWIDTHGREATERTHAN,
  AMPERSAND,
  APOSTROPHE: APOSTROPHE$1,
  ASTERISK,
  AT,
  BACKSLASH,
  BACKTICK,
  CARET,
  COLON,
  COMMA,
  DOLLAR,
  DOT,
  EQUALS,
  EXCLAMATION,
  HYPHEN,
  PERCENT,
  PIPE,
  PLUS,
  POUND,
  QUERY,
  QUOTE,
  FULLWIDTHMIDDLEDOT,
  SEMI,
  SLASH,
  TILDE,
  UNDERSCORE,
  EMOJI: EMOJI$1,
  SYM
});
const ASCII_LETTER = /[a-z]/;
const LETTER = /\p{L}/u;
const EMOJI = /\p{Emoji}/u;
const EMOJI_VARIATION$1 = /\ufe0f/;
const DIGIT = /\d/;
const SPACE = /\s/;
var regexp = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  ASCII_LETTER,
  LETTER,
  EMOJI,
  EMOJI_VARIATION: EMOJI_VARIATION$1,
  DIGIT,
  SPACE
});
const CR = "\r";
const LF = "\n";
const EMOJI_VARIATION = "️";
const EMOJI_JOINER = "‍";
const OBJECT_REPLACEMENT = "￼";
let tlds = null, utlds = null;
function init$2(customSchemes = []) {
  const groups = {};
  State.groups = groups;
  const Start = new State();
  if (tlds == null) {
    tlds = decodeTlds(encodedTlds);
  }
  if (utlds == null) {
    utlds = decodeTlds(encodedUtlds);
  }
  tt(Start, "'", APOSTROPHE$1);
  tt(Start, "{", OPENBRACE);
  tt(Start, "}", CLOSEBRACE);
  tt(Start, "[", OPENBRACKET);
  tt(Start, "]", CLOSEBRACKET);
  tt(Start, "(", OPENPAREN);
  tt(Start, ")", CLOSEPAREN);
  tt(Start, "<", OPENANGLEBRACKET);
  tt(Start, ">", CLOSEANGLEBRACKET);
  tt(Start, "（", FULLWIDTHLEFTPAREN);
  tt(Start, "）", FULLWIDTHRIGHTPAREN);
  tt(Start, "「", LEFTCORNERBRACKET);
  tt(Start, "」", RIGHTCORNERBRACKET);
  tt(Start, "『", LEFTWHITECORNERBRACKET);
  tt(Start, "』", RIGHTWHITECORNERBRACKET);
  tt(Start, "＜", FULLWIDTHLESSTHAN);
  tt(Start, "＞", FULLWIDTHGREATERTHAN);
  tt(Start, "&", AMPERSAND);
  tt(Start, "*", ASTERISK);
  tt(Start, "@", AT);
  tt(Start, "`", BACKTICK);
  tt(Start, "^", CARET);
  tt(Start, ":", COLON);
  tt(Start, ",", COMMA);
  tt(Start, "$", DOLLAR);
  tt(Start, ".", DOT);
  tt(Start, "=", EQUALS);
  tt(Start, "!", EXCLAMATION);
  tt(Start, "-", HYPHEN);
  tt(Start, "%", PERCENT);
  tt(Start, "|", PIPE);
  tt(Start, "+", PLUS);
  tt(Start, "#", POUND);
  tt(Start, "?", QUERY);
  tt(Start, '"', QUOTE);
  tt(Start, "/", SLASH);
  tt(Start, ";", SEMI);
  tt(Start, "~", TILDE);
  tt(Start, "_", UNDERSCORE);
  tt(Start, "\\", BACKSLASH);
  tt(Start, "・", FULLWIDTHMIDDLEDOT);
  const Num = tr(Start, DIGIT, NUM, {
    [numeric]: true
  });
  tr(Num, DIGIT, Num);
  const Asciinumeric = tr(Num, ASCII_LETTER, ASCIINUMERICAL, {
    [asciinumeric]: true
  });
  const Alphanumeric = tr(Num, LETTER, ALPHANUMERICAL, {
    [alphanumeric]: true
  });
  const Word = tr(Start, ASCII_LETTER, WORD, {
    [ascii]: true
  });
  tr(Word, DIGIT, Asciinumeric);
  tr(Word, ASCII_LETTER, Word);
  tr(Asciinumeric, DIGIT, Asciinumeric);
  tr(Asciinumeric, ASCII_LETTER, Asciinumeric);
  const UWord = tr(Start, LETTER, UWORD, {
    [alpha]: true
  });
  tr(UWord, ASCII_LETTER);
  tr(UWord, DIGIT, Alphanumeric);
  tr(UWord, LETTER, UWord);
  tr(Alphanumeric, DIGIT, Alphanumeric);
  tr(Alphanumeric, ASCII_LETTER);
  tr(Alphanumeric, LETTER, Alphanumeric);
  const Nl2 = tt(Start, LF, NL, {
    [whitespace]: true
  });
  const Cr = tt(Start, CR, WS, {
    [whitespace]: true
  });
  const Ws = tr(Start, SPACE, WS, {
    [whitespace]: true
  });
  tt(Start, OBJECT_REPLACEMENT, Ws);
  tt(Cr, LF, Nl2);
  tt(Cr, OBJECT_REPLACEMENT, Ws);
  tr(Cr, SPACE, Ws);
  tt(Ws, CR);
  tt(Ws, LF);
  tr(Ws, SPACE, Ws);
  tt(Ws, OBJECT_REPLACEMENT, Ws);
  const Emoji = tr(Start, EMOJI, EMOJI$1, {
    [emoji]: true
  });
  tt(Emoji, "#");
  tr(Emoji, EMOJI, Emoji);
  tt(Emoji, EMOJI_VARIATION, Emoji);
  const EmojiJoiner = tt(Emoji, EMOJI_JOINER);
  tt(EmojiJoiner, "#");
  tr(EmojiJoiner, EMOJI, Emoji);
  const wordjr = [[ASCII_LETTER, Word], [DIGIT, Asciinumeric]];
  const uwordjr = [[ASCII_LETTER, null], [LETTER, UWord], [DIGIT, Alphanumeric]];
  for (let i2 = 0; i2 < tlds.length; i2++) {
    fastts(Start, tlds[i2], TLD, WORD, wordjr);
  }
  for (let i2 = 0; i2 < utlds.length; i2++) {
    fastts(Start, utlds[i2], UTLD, UWORD, uwordjr);
  }
  addToGroups(TLD, {
    tld: true,
    ascii: true
  }, groups);
  addToGroups(UTLD, {
    utld: true,
    alpha: true
  }, groups);
  fastts(Start, "file", SCHEME, WORD, wordjr);
  fastts(Start, "mailto", SCHEME, WORD, wordjr);
  fastts(Start, "http", SLASH_SCHEME, WORD, wordjr);
  fastts(Start, "https", SLASH_SCHEME, WORD, wordjr);
  fastts(Start, "ftp", SLASH_SCHEME, WORD, wordjr);
  fastts(Start, "ftps", SLASH_SCHEME, WORD, wordjr);
  addToGroups(SCHEME, {
    scheme: true,
    ascii: true
  }, groups);
  addToGroups(SLASH_SCHEME, {
    slashscheme: true,
    ascii: true
  }, groups);
  customSchemes = customSchemes.sort((a2, b2) => a2[0] > b2[0] ? 1 : -1);
  for (let i2 = 0; i2 < customSchemes.length; i2++) {
    const sch = customSchemes[i2][0];
    const optionalSlashSlash = customSchemes[i2][1];
    const flags = optionalSlashSlash ? {
      [scheme]: true
    } : {
      [slashscheme]: true
    };
    if (sch.indexOf("-") >= 0) {
      flags[domain] = true;
    } else if (!ASCII_LETTER.test(sch)) {
      flags[numeric] = true;
    } else if (DIGIT.test(sch)) {
      flags[asciinumeric] = true;
    } else {
      flags[ascii] = true;
    }
    ts(Start, sch, sch, flags);
  }
  ts(Start, "localhost", LOCALHOST, {
    ascii: true
  });
  Start.jd = new State(SYM);
  return {
    start: Start,
    tokens: assign$2({
      groups
    }, tk)
  };
}
__name(init$2, "init$2");
function run$1(start2, str) {
  const iterable = stringToArray(str.replace(/[A-Z]/g, (c2) => c2.toLowerCase()));
  const charCount = iterable.length;
  const tokens = [];
  let cursor = 0;
  let charCursor = 0;
  while (charCursor < charCount) {
    let state = start2;
    let nextState = null;
    let tokenLength = 0;
    let latestAccepting = null;
    let sinceAccepts = -1;
    let charsSinceAccepts = -1;
    while (charCursor < charCount && (nextState = state.go(iterable[charCursor]))) {
      state = nextState;
      if (state.accepts()) {
        sinceAccepts = 0;
        charsSinceAccepts = 0;
        latestAccepting = state;
      } else if (sinceAccepts >= 0) {
        sinceAccepts += iterable[charCursor].length;
        charsSinceAccepts++;
      }
      tokenLength += iterable[charCursor].length;
      cursor += iterable[charCursor].length;
      charCursor++;
    }
    cursor -= sinceAccepts;
    charCursor -= charsSinceAccepts;
    tokenLength -= sinceAccepts;
    tokens.push({
      t: latestAccepting.t,
      // token type/name
      v: str.slice(cursor - tokenLength, cursor),
      // string value
      s: cursor - tokenLength,
      // start index
      e: cursor
      // end index (excluding)
    });
  }
  return tokens;
}
__name(run$1, "run$1");
function stringToArray(str) {
  const result = [];
  const len = str.length;
  let index2 = 0;
  while (index2 < len) {
    let first2 = str.charCodeAt(index2);
    let second;
    let char = first2 < 55296 || first2 > 56319 || index2 + 1 === len || (second = str.charCodeAt(index2 + 1)) < 56320 || second > 57343 ? str[index2] : str.slice(index2, index2 + 2);
    result.push(char);
    index2 += char.length;
  }
  return result;
}
__name(stringToArray, "stringToArray");
function fastts(state, input, t2, defaultt, jr) {
  let next2;
  const len = input.length;
  for (let i2 = 0; i2 < len - 1; i2++) {
    const char = input[i2];
    if (state.j[char]) {
      next2 = state.j[char];
    } else {
      next2 = new State(defaultt);
      next2.jr = jr.slice();
      state.j[char] = next2;
    }
    state = next2;
  }
  next2 = new State(t2);
  next2.jr = jr.slice();
  state.j[input[len - 1]] = next2;
  return next2;
}
__name(fastts, "fastts");
function decodeTlds(encoded) {
  const words = [];
  const stack2 = [];
  let i2 = 0;
  let digits = "0123456789";
  while (i2 < encoded.length) {
    let popDigitCount = 0;
    while (digits.indexOf(encoded[i2 + popDigitCount]) >= 0) {
      popDigitCount++;
    }
    if (popDigitCount > 0) {
      words.push(stack2.join(""));
      for (let popCount = parseInt(encoded.substring(i2, i2 + popDigitCount), 10); popCount > 0; popCount--) {
        stack2.pop();
      }
      i2 += popDigitCount;
    } else {
      stack2.push(encoded[i2]);
      i2++;
    }
  }
  return words;
}
__name(decodeTlds, "decodeTlds");
const defaults = {
  defaultProtocol: "http",
  events: null,
  format: noop,
  formatHref: noop,
  nl2br: false,
  tagName: "a",
  target: null,
  rel: null,
  validate: true,
  truncate: Infinity,
  className: null,
  attributes: null,
  ignoreTags: [],
  render: null
};
function Options(opts, defaultRender = null) {
  let o2 = assign$2({}, defaults);
  if (opts) {
    o2 = assign$2(o2, opts instanceof Options ? opts.o : opts);
  }
  const ignoredTags = o2.ignoreTags;
  const uppercaseIgnoredTags = [];
  for (let i2 = 0; i2 < ignoredTags.length; i2++) {
    uppercaseIgnoredTags.push(ignoredTags[i2].toUpperCase());
  }
  this.o = o2;
  if (defaultRender) {
    this.defaultRender = defaultRender;
  }
  this.ignoreTags = uppercaseIgnoredTags;
}
__name(Options, "Options");
Options.prototype = {
  o: defaults,
  /**
   * @type string[]
   */
  ignoreTags: [],
  /**
   * @param {IntermediateRepresentation} ir
   * @returns {any}
   */
  defaultRender(ir) {
    return ir;
  },
  /**
   * Returns true or false based on whether a token should be displayed as a
   * link based on the user options.
   * @param {MultiToken} token
   * @returns {boolean}
   */
  check(token) {
    return this.get("validate", token.toString(), token);
  },
  // Private methods
  /**
   * Resolve an option's value based on the value of the option and the given
   * params. If operator and token are specified and the target option is
   * callable, automatically calls the function with the given argument.
   * @template {keyof Opts} K
   * @param {K} key Name of option to use
   * @param {string} [operator] will be passed to the target option if it's a
   * function. If not specified, RAW function value gets returned
   * @param {MultiToken} [token] The token from linkify.tokenize
   * @returns {Opts[K] | any}
   */
  get(key, operator, token) {
    const isCallable = operator != null;
    let option5 = this.o[key];
    if (!option5) {
      return option5;
    }
    if (typeof option5 === "object") {
      option5 = token.t in option5 ? option5[token.t] : defaults[key];
      if (typeof option5 === "function" && isCallable) {
        option5 = option5(operator, token);
      }
    } else if (typeof option5 === "function" && isCallable) {
      option5 = option5(operator, token.t, token);
    }
    return option5;
  },
  /**
   * @template {keyof Opts} L
   * @param {L} key Name of options object to use
   * @param {string} [operator]
   * @param {MultiToken} [token]
   * @returns {Opts[L] | any}
   */
  getObj(key, operator, token) {
    let obj = this.o[key];
    if (typeof obj === "function" && operator != null) {
      obj = obj(operator, token.t, token);
    }
    return obj;
  },
  /**
   * Convert the given token to a rendered element that may be added to the
   * calling-interface's DOM
   * @param {MultiToken} token Token to render to an HTML element
   * @returns {any} Render result; e.g., HTML string, DOM element, React
   *   Component, etc.
   */
  render(token) {
    const ir = token.render(this);
    const renderFn = this.get("render", null, token) || this.defaultRender;
    return renderFn(ir, token.t, token);
  }
};
function noop(val) {
  return val;
}
__name(noop, "noop");
var options = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  defaults,
  Options,
  assign: assign$2
});
function MultiToken(value3, tokens) {
  this.t = "token";
  this.v = value3;
  this.tk = tokens;
}
__name(MultiToken, "MultiToken");
MultiToken.prototype = {
  isLink: false,
  /**
   * Return the string this token represents.
   * @return {string}
   */
  toString() {
    return this.v;
  },
  /**
   * What should the value for this token be in the `href` HTML attribute?
   * Returns the `.toString` value by default.
   * @param {string} [scheme]
   * @return {string}
   */
  toHref(scheme2) {
    return this.toString();
  },
  /**
   * @param {Options} options Formatting options
   * @returns {string}
   */
  toFormattedString(options5) {
    const val = this.toString();
    const truncate2 = options5.get("truncate", val, this);
    const formatted = options5.get("format", val, this);
    return truncate2 && formatted.length > truncate2 ? formatted.substring(0, truncate2) + "…" : formatted;
  },
  /**
   *
   * @param {Options} options
   * @returns {string}
   */
  toFormattedHref(options5) {
    return options5.get("formatHref", this.toHref(options5.get("defaultProtocol")), this);
  },
  /**
   * The start index of this token in the original input string
   * @returns {number}
   */
  startIndex() {
    return this.tk[0].s;
  },
  /**
   * The end index of this token in the original input string (up to this
   * index but not including it)
   * @returns {number}
   */
  endIndex() {
    return this.tk[this.tk.length - 1].e;
  },
  /**
  	Returns an object  of relevant values for this token, which includes keys
  	* type - Kind of token ('url', 'email', etc.)
  	* value - Original text
  	* href - The value that should be added to the anchor tag's href
  		attribute
  		@method toObject
  	@param {string} [protocol] `'http'` by default
  */
  toObject(protocol = defaults.defaultProtocol) {
    return {
      type: this.t,
      value: this.toString(),
      isLink: this.isLink,
      href: this.toHref(protocol),
      start: this.startIndex(),
      end: this.endIndex()
    };
  },
  /**
   *
   * @param {Options} options Formatting option
   */
  toFormattedObject(options5) {
    return {
      type: this.t,
      value: this.toFormattedString(options5),
      isLink: this.isLink,
      href: this.toFormattedHref(options5),
      start: this.startIndex(),
      end: this.endIndex()
    };
  },
  /**
   * Whether this token should be rendered as a link according to the given options
   * @param {Options} options
   * @returns {boolean}
   */
  validate(options5) {
    return options5.get("validate", this.toString(), this);
  },
  /**
   * Return an object that represents how this link should be rendered.
   * @param {Options} options Formattinng options
   */
  render(options5) {
    const token = this;
    const href = this.toHref(options5.get("defaultProtocol"));
    const formattedHref = options5.get("formatHref", href, this);
    const tagName = options5.get("tagName", href, token);
    const content3 = this.toFormattedString(options5);
    const attributes = {};
    const className = options5.get("className", href, token);
    const target2 = options5.get("target", href, token);
    const rel = options5.get("rel", href, token);
    const attrs7 = options5.getObj("attributes", href, token);
    const eventListeners = options5.getObj("events", href, token);
    attributes.href = formattedHref;
    if (className) {
      attributes.class = className;
    }
    if (target2) {
      attributes.target = target2;
    }
    if (rel) {
      attributes.rel = rel;
    }
    if (attrs7) {
      assign$2(attributes, attrs7);
    }
    return {
      tagName,
      attributes,
      content: content3,
      eventListeners
    };
  }
};
function createTokenClass(type, props) {
  class Token2 extends MultiToken {
    static {
      __name(this, "Token");
    }
    constructor(value3, tokens) {
      super(value3, tokens);
      this.t = type;
    }
  }
  for (const p2 in props) {
    Token2.prototype[p2] = props[p2];
  }
  Token2.t = type;
  return Token2;
}
__name(createTokenClass, "createTokenClass");
const Email = createTokenClass("email", {
  isLink: true,
  toHref() {
    return "mailto:" + this.toString();
  }
});
const Text$3 = createTokenClass("text");
const Nl = createTokenClass("nl");
const Url$1 = createTokenClass("url", {
  isLink: true,
  /**
  	Lowercases relevant parts of the domain and adds the protocol if
  	required. Note that this will not escape unsafe HTML characters in the
  	URL.
  		@param {string} [scheme] default scheme (e.g., 'https')
  	@return {string} the full href
  */
  toHref(scheme2 = defaults.defaultProtocol) {
    return this.hasProtocol() ? this.v : `${scheme2}://${this.v}`;
  },
  /**
   * Check whether this URL token has a protocol
   * @return {boolean}
   */
  hasProtocol() {
    const tokens = this.tk;
    return tokens.length >= 2 && tokens[0].t !== LOCALHOST && tokens[1].t === COLON;
  }
});
var multi = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  MultiToken,
  Base: MultiToken,
  createTokenClass,
  Email,
  Text: Text$3,
  Nl,
  Url: Url$1
});
const makeState = /* @__PURE__ */ __name((arg) => new State(arg), "makeState");
function init$1({
  groups
}) {
  const qsAccepting = groups.domain.concat([AMPERSAND, ASTERISK, AT, BACKSLASH, BACKTICK, CARET, DOLLAR, EQUALS, HYPHEN, NUM, PERCENT, PIPE, PLUS, POUND, SLASH, SYM, TILDE, UNDERSCORE]);
  const qsNonAccepting = [COLON, COMMA, DOT, EXCLAMATION, PERCENT, QUERY, QUOTE, SEMI, OPENANGLEBRACKET, CLOSEANGLEBRACKET, OPENBRACE, CLOSEBRACE, CLOSEBRACKET, OPENBRACKET, OPENPAREN, CLOSEPAREN, FULLWIDTHLEFTPAREN, FULLWIDTHRIGHTPAREN, LEFTCORNERBRACKET, RIGHTCORNERBRACKET, LEFTWHITECORNERBRACKET, RIGHTWHITECORNERBRACKET, FULLWIDTHLESSTHAN, FULLWIDTHGREATERTHAN];
  const localpartAccepting = [AMPERSAND, APOSTROPHE$1, ASTERISK, BACKSLASH, BACKTICK, CARET, DOLLAR, EQUALS, HYPHEN, OPENBRACE, CLOSEBRACE, PERCENT, PIPE, PLUS, POUND, QUERY, SLASH, SYM, TILDE, UNDERSCORE];
  const Start = makeState();
  const Localpart = tt(Start, TILDE);
  ta(Localpart, localpartAccepting, Localpart);
  ta(Localpart, groups.domain, Localpart);
  const Domain = makeState(), Scheme = makeState(), SlashScheme = makeState();
  ta(Start, groups.domain, Domain);
  ta(Start, groups.scheme, Scheme);
  ta(Start, groups.slashscheme, SlashScheme);
  ta(Domain, localpartAccepting, Localpart);
  ta(Domain, groups.domain, Domain);
  const LocalpartAt = tt(Domain, AT);
  tt(Localpart, AT, LocalpartAt);
  tt(Scheme, AT, LocalpartAt);
  tt(SlashScheme, AT, LocalpartAt);
  const LocalpartDot = tt(Localpart, DOT);
  ta(LocalpartDot, localpartAccepting, Localpart);
  ta(LocalpartDot, groups.domain, Localpart);
  const EmailDomain = makeState();
  ta(LocalpartAt, groups.domain, EmailDomain);
  ta(EmailDomain, groups.domain, EmailDomain);
  const EmailDomainDot = tt(EmailDomain, DOT);
  ta(EmailDomainDot, groups.domain, EmailDomain);
  const Email$1 = makeState(Email);
  ta(EmailDomainDot, groups.tld, Email$1);
  ta(EmailDomainDot, groups.utld, Email$1);
  tt(LocalpartAt, LOCALHOST, Email$1);
  const EmailDomainHyphen = tt(EmailDomain, HYPHEN);
  tt(EmailDomainHyphen, HYPHEN, EmailDomainHyphen);
  ta(EmailDomainHyphen, groups.domain, EmailDomain);
  ta(Email$1, groups.domain, EmailDomain);
  tt(Email$1, DOT, EmailDomainDot);
  tt(Email$1, HYPHEN, EmailDomainHyphen);
  const EmailColon = tt(Email$1, COLON);
  ta(EmailColon, groups.numeric, Email);
  const DomainHyphen = tt(Domain, HYPHEN);
  const DomainDot = tt(Domain, DOT);
  tt(DomainHyphen, HYPHEN, DomainHyphen);
  ta(DomainHyphen, groups.domain, Domain);
  ta(DomainDot, localpartAccepting, Localpart);
  ta(DomainDot, groups.domain, Domain);
  const DomainDotTld = makeState(Url$1);
  ta(DomainDot, groups.tld, DomainDotTld);
  ta(DomainDot, groups.utld, DomainDotTld);
  ta(DomainDotTld, groups.domain, Domain);
  ta(DomainDotTld, localpartAccepting, Localpart);
  tt(DomainDotTld, DOT, DomainDot);
  tt(DomainDotTld, HYPHEN, DomainHyphen);
  tt(DomainDotTld, AT, LocalpartAt);
  const DomainDotTldColon = tt(DomainDotTld, COLON);
  const DomainDotTldColonPort = makeState(Url$1);
  ta(DomainDotTldColon, groups.numeric, DomainDotTldColonPort);
  const Url$1$1 = makeState(Url$1);
  const UrlNonaccept = makeState();
  ta(Url$1$1, qsAccepting, Url$1$1);
  ta(Url$1$1, qsNonAccepting, UrlNonaccept);
  ta(UrlNonaccept, qsAccepting, Url$1$1);
  ta(UrlNonaccept, qsNonAccepting, UrlNonaccept);
  tt(DomainDotTld, SLASH, Url$1$1);
  tt(DomainDotTldColonPort, SLASH, Url$1$1);
  const SchemeColon = tt(Scheme, COLON);
  const SlashSchemeColon = tt(SlashScheme, COLON);
  const SlashSchemeColonSlash = tt(SlashSchemeColon, SLASH);
  const UriPrefix = tt(SlashSchemeColonSlash, SLASH);
  ta(Scheme, groups.domain, Domain);
  tt(Scheme, DOT, DomainDot);
  tt(Scheme, HYPHEN, DomainHyphen);
  ta(SlashScheme, groups.domain, Domain);
  tt(SlashScheme, DOT, DomainDot);
  tt(SlashScheme, HYPHEN, DomainHyphen);
  ta(SchemeColon, groups.domain, Url$1$1);
  tt(SchemeColon, SLASH, Url$1$1);
  tt(SchemeColon, QUERY, Url$1$1);
  ta(UriPrefix, groups.domain, Url$1$1);
  ta(UriPrefix, qsAccepting, Url$1$1);
  tt(UriPrefix, SLASH, Url$1$1);
  const bracketPairs = [
    [OPENBRACE, CLOSEBRACE],
    // {}
    [OPENBRACKET, CLOSEBRACKET],
    // []
    [OPENPAREN, CLOSEPAREN],
    // ()
    [OPENANGLEBRACKET, CLOSEANGLEBRACKET],
    // <>
    [FULLWIDTHLEFTPAREN, FULLWIDTHRIGHTPAREN],
    // （）
    [LEFTCORNERBRACKET, RIGHTCORNERBRACKET],
    // 「」
    [LEFTWHITECORNERBRACKET, RIGHTWHITECORNERBRACKET],
    // 『』
    [FULLWIDTHLESSTHAN, FULLWIDTHGREATERTHAN]
    // ＜＞
  ];
  for (let i2 = 0; i2 < bracketPairs.length; i2++) {
    const [OPEN, CLOSE] = bracketPairs[i2];
    const UrlOpen = tt(Url$1$1, OPEN);
    tt(UrlNonaccept, OPEN, UrlOpen);
    tt(UrlOpen, CLOSE, Url$1$1);
    const UrlOpenQ = makeState(Url$1);
    ta(UrlOpen, qsAccepting, UrlOpenQ);
    const UrlOpenSyms = makeState();
    ta(UrlOpen, qsNonAccepting);
    ta(UrlOpenQ, qsAccepting, UrlOpenQ);
    ta(UrlOpenQ, qsNonAccepting, UrlOpenSyms);
    ta(UrlOpenSyms, qsAccepting, UrlOpenQ);
    ta(UrlOpenSyms, qsNonAccepting, UrlOpenSyms);
    tt(UrlOpenQ, CLOSE, Url$1$1);
    tt(UrlOpenSyms, CLOSE, Url$1$1);
  }
  tt(Start, LOCALHOST, DomainDotTld);
  tt(Start, NL, Nl);
  return {
    start: Start,
    tokens: tk
  };
}
__name(init$1, "init$1");
function run(start2, input, tokens) {
  let len = tokens.length;
  let cursor = 0;
  let multis = [];
  let textTokens = [];
  while (cursor < len) {
    let state = start2;
    let secondState = null;
    let nextState = null;
    let multiLength = 0;
    let latestAccepting = null;
    let sinceAccepts = -1;
    while (cursor < len && !(secondState = state.go(tokens[cursor].t))) {
      textTokens.push(tokens[cursor++]);
    }
    while (cursor < len && (nextState = secondState || state.go(tokens[cursor].t))) {
      secondState = null;
      state = nextState;
      if (state.accepts()) {
        sinceAccepts = 0;
        latestAccepting = state;
      } else if (sinceAccepts >= 0) {
        sinceAccepts++;
      }
      cursor++;
      multiLength++;
    }
    if (sinceAccepts < 0) {
      cursor -= multiLength;
      if (cursor < len) {
        textTokens.push(tokens[cursor]);
        cursor++;
      }
    } else {
      if (textTokens.length > 0) {
        multis.push(initMultiToken(Text$3, input, textTokens));
        textTokens = [];
      }
      cursor -= sinceAccepts;
      multiLength -= sinceAccepts;
      const Multi = latestAccepting.t;
      const subtokens = tokens.slice(cursor - multiLength, cursor);
      multis.push(initMultiToken(Multi, input, subtokens));
    }
  }
  if (textTokens.length > 0) {
    multis.push(initMultiToken(Text$3, input, textTokens));
  }
  return multis;
}
__name(run, "run");
function initMultiToken(Multi, input, tokens) {
  const startIdx = tokens[0].s;
  const endIdx = tokens[tokens.length - 1].e;
  const value3 = input.slice(startIdx, endIdx);
  return new Multi(value3, tokens);
}
__name(initMultiToken, "initMultiToken");
const warn = typeof console !== "undefined" && console && console.warn || (() => {
});
const warnAdvice = "until manual call of linkify.init(). Register all schemes and plugins before invoking linkify the first time.";
const INIT = {
  scanner: null,
  parser: null,
  tokenQueue: [],
  pluginQueue: [],
  customSchemes: [],
  initialized: false
};
function reset() {
  State.groups = {};
  INIT.scanner = null;
  INIT.parser = null;
  INIT.tokenQueue = [];
  INIT.pluginQueue = [];
  INIT.customSchemes = [];
  INIT.initialized = false;
  return INIT;
}
__name(reset, "reset");
function registerTokenPlugin(name2, plugin) {
  if (typeof plugin !== "function") {
    throw new Error(`linkifyjs: Invalid token plugin ${plugin} (expects function)`);
  }
  for (let i2 = 0; i2 < INIT.tokenQueue.length; i2++) {
    if (name2 === INIT.tokenQueue[i2][0]) {
      warn(`linkifyjs: token plugin "${name2}" already registered - will be overwritten`);
      INIT.tokenQueue[i2] = [name2, plugin];
      return;
    }
  }
  INIT.tokenQueue.push([name2, plugin]);
  if (INIT.initialized) {
    warn(`linkifyjs: already initialized - will not register token plugin "${name2}" ${warnAdvice}`);
  }
}
__name(registerTokenPlugin, "registerTokenPlugin");
function registerPlugin(name2, plugin) {
  if (typeof plugin !== "function") {
    throw new Error(`linkifyjs: Invalid plugin ${plugin} (expects function)`);
  }
  for (let i2 = 0; i2 < INIT.pluginQueue.length; i2++) {
    if (name2 === INIT.pluginQueue[i2][0]) {
      warn(`linkifyjs: plugin "${name2}" already registered - will be overwritten`);
      INIT.pluginQueue[i2] = [name2, plugin];
      return;
    }
  }
  INIT.pluginQueue.push([name2, plugin]);
  if (INIT.initialized) {
    warn(`linkifyjs: already initialized - will not register plugin "${name2}" ${warnAdvice}`);
  }
}
__name(registerPlugin, "registerPlugin");
function registerCustomProtocol(scheme2, optionalSlashSlash = false) {
  if (INIT.initialized) {
    warn(`linkifyjs: already initialized - will not register custom scheme "${scheme2}" ${warnAdvice}`);
  }
  if (!/^[0-9a-z]+(-[0-9a-z]+)*$/.test(scheme2)) {
    throw new Error(`linkifyjs: incorrect scheme format.
1. Must only contain digits, lowercase ASCII letters or "-"
2. Cannot start or end with "-"
3. "-" cannot repeat`);
  }
  INIT.customSchemes.push([scheme2, optionalSlashSlash]);
}
__name(registerCustomProtocol, "registerCustomProtocol");
function init() {
  INIT.scanner = init$2(INIT.customSchemes);
  for (let i2 = 0; i2 < INIT.tokenQueue.length; i2++) {
    INIT.tokenQueue[i2][1]({
      scanner: INIT.scanner
    });
  }
  INIT.parser = init$1(INIT.scanner.tokens);
  for (let i2 = 0; i2 < INIT.pluginQueue.length; i2++) {
    INIT.pluginQueue[i2][1]({
      scanner: INIT.scanner,
      parser: INIT.parser
    });
  }
  INIT.initialized = true;
  return INIT;
}
__name(init, "init");
function tokenize(str) {
  if (!INIT.initialized) {
    init();
  }
  return run(INIT.parser.start, str, run$1(INIT.scanner.start, str));
}
__name(tokenize, "tokenize");
tokenize.scan = run$1;
function find(str, type = null, opts = null) {
  if (type && typeof type === "object") {
    if (opts) {
      throw Error(`linkifyjs: Invalid link type ${type}; must be a string`);
    }
    opts = type;
    type = null;
  }
  const options5 = new Options(opts);
  const tokens = tokenize(str);
  const filtered = [];
  for (let i2 = 0; i2 < tokens.length; i2++) {
    const token = tokens[i2];
    if (token.isLink && (!type || token.t === type) && options5.check(token)) {
      filtered.push(token.toFormattedObject(options5));
    }
  }
  return filtered;
}
__name(find, "find");
function test(str, type = null) {
  const tokens = tokenize(str);
  return tokens.length === 1 && tokens[0].isLink && (!type || tokens[0].t === type);
}
__name(test, "test");
function isValidLinkStructure(tokens) {
  if (tokens.length === 1) {
    return tokens[0].isLink;
  }
  if (tokens.length === 3 && tokens[1].isLink) {
    return ["()", "[]"].includes(tokens[0].value + tokens[2].value);
  }
  return false;
}
__name(isValidLinkStructure, "isValidLinkStructure");
function autolink$1(options5) {
  return new Plugin({
    key: new PluginKey("autolink"),
    appendTransaction: /* @__PURE__ */ __name((transactions, oldState, newState) => {
      const docChanges = transactions.some((transaction) => transaction.docChanged) && !oldState.doc.eq(newState.doc);
      const preventAutolink = transactions.some((transaction) => transaction.getMeta("preventAutolink"));
      if (!docChanges || preventAutolink) {
        return;
      }
      const { tr: tr2 } = newState;
      const transform2 = combineTransactionSteps(oldState.doc, [...transactions]);
      const changes = getChangedRanges(transform2);
      changes.forEach(({ newRange }) => {
        const nodesInChangedRanges = findChildrenInRange(newState.doc, newRange, (node3) => node3.isTextblock);
        let textBlock;
        let textBeforeWhitespace;
        if (nodesInChangedRanges.length > 1) {
          textBlock = nodesInChangedRanges[0];
          textBeforeWhitespace = newState.doc.textBetween(textBlock.pos, textBlock.pos + textBlock.node.nodeSize, void 0, " ");
        } else if (nodesInChangedRanges.length && newState.doc.textBetween(newRange.from, newRange.to, " ", " ").endsWith(" ")) {
          textBlock = nodesInChangedRanges[0];
          textBeforeWhitespace = newState.doc.textBetween(textBlock.pos, newRange.to, void 0, " ");
        }
        if (textBlock && textBeforeWhitespace) {
          const wordsBeforeWhitespace = textBeforeWhitespace.split(" ").filter((s2) => s2 !== "");
          if (wordsBeforeWhitespace.length <= 0) {
            return false;
          }
          const lastWordBeforeSpace = wordsBeforeWhitespace[wordsBeforeWhitespace.length - 1];
          const lastWordAndBlockOffset = textBlock.pos + textBeforeWhitespace.lastIndexOf(lastWordBeforeSpace);
          if (!lastWordBeforeSpace) {
            return false;
          }
          const linksBeforeSpace = tokenize(lastWordBeforeSpace).map((t2) => t2.toObject(options5.defaultProtocol));
          if (!isValidLinkStructure(linksBeforeSpace)) {
            return false;
          }
          linksBeforeSpace.filter((link2) => link2.isLink).map((link2) => ({
            ...link2,
            from: lastWordAndBlockOffset + link2.start + 1,
            to: lastWordAndBlockOffset + link2.end + 1
          })).filter((link2) => {
            if (!newState.schema.marks.code) {
              return true;
            }
            return !newState.doc.rangeHasMark(link2.from, link2.to, newState.schema.marks.code);
          }).filter((link2) => options5.validate(link2.value)).filter((link2) => options5.shouldAutoLink(link2.value)).forEach((link2) => {
            if (getMarksBetween(link2.from, link2.to, newState.doc).some((item3) => item3.mark.type === options5.type)) {
              return;
            }
            tr2.addMark(link2.from, link2.to, options5.type.create({
              href: link2.href
            }));
          });
        }
      });
      if (!tr2.steps.length) {
        return;
      }
      return tr2;
    }, "appendTransaction")
  });
}
__name(autolink$1, "autolink$1");
function clickHandler(options5) {
  return new Plugin({
    key: new PluginKey("handleClickLink"),
    props: {
      handleClick: /* @__PURE__ */ __name((view, pos, event) => {
        var _a2, _b;
        if (event.button !== 0) {
          return false;
        }
        if (!view.editable) {
          return false;
        }
        let a2 = event.target;
        const els = [];
        while (a2.nodeName !== "DIV") {
          els.push(a2);
          a2 = a2.parentNode;
        }
        if (!els.find((value3) => value3.nodeName === "A")) {
          return false;
        }
        const attrs7 = getAttributes(view.state, options5.type.name);
        const link2 = event.target;
        const href = (_a2 = link2 === null || link2 === void 0 ? void 0 : link2.href) !== null && _a2 !== void 0 ? _a2 : attrs7.href;
        const target2 = (_b = link2 === null || link2 === void 0 ? void 0 : link2.target) !== null && _b !== void 0 ? _b : attrs7.target;
        if (link2 && href) {
          window.open(href, target2);
          return true;
        }
        return false;
      }, "handleClick")
    }
  });
}
__name(clickHandler, "clickHandler");
function pasteHandler(options5) {
  return new Plugin({
    key: new PluginKey("handlePasteLink"),
    props: {
      handlePaste: /* @__PURE__ */ __name((view, event, slice2) => {
        const { state } = view;
        const { selection } = state;
        const { empty: empty2 } = selection;
        if (empty2) {
          return false;
        }
        let textContent = "";
        slice2.content.forEach((node3) => {
          textContent += node3.textContent;
        });
        const link2 = find(textContent, { defaultProtocol: options5.defaultProtocol }).find((item3) => item3.isLink && item3.value === textContent);
        if (!textContent || !link2) {
          return false;
        }
        options5.editor.commands.setMark(options5.type, {
          href: link2.href
        });
        return true;
      }, "handlePaste")
    }
  });
}
__name(pasteHandler, "pasteHandler");
const pasteRegex$2 = /https?:\/\/(?:www\.)?[-a-zA-Z0-9@:%._+~#=]{1,256}\.[a-zA-Z]{2,}\b(?:[-a-zA-Z0-9@:%._+~#=?!&/]*)(?:[-a-zA-Z0-9@:%._+~#=?!&/]*)/gi;
const ATTR_WHITESPACE = /[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g;
function isAllowedUri(uri, protocols) {
  const allowedProtocols = [
    "http",
    "https",
    "ftp",
    "ftps",
    "mailto",
    "tel",
    "callto",
    "sms",
    "cid",
    "xmpp"
  ];
  if (protocols) {
    protocols.forEach((protocol) => {
      const nextProtocol = typeof protocol === "string" ? protocol : protocol.scheme;
      if (nextProtocol) {
        allowedProtocols.push(nextProtocol);
      }
    });
  }
  return !uri || uri.replace(ATTR_WHITESPACE, "").match(new RegExp(
    // eslint-disable-next-line no-useless-escape
    `^(?:(?:${allowedProtocols.join("|")}):|[^a-z]|[a-z+.-]+(?:[^a-z+.-:]|$))`,
    "i"
  ));
}
__name(isAllowedUri, "isAllowedUri");
const Link$2 = Mark.create({
  name: "link",
  priority: 1e3,
  keepOnSplit: false,
  exitable: true,
  onCreate() {
    if (this.options.validate && !this.options.shouldAutoLink) {
      this.options.shouldAutoLink = this.options.validate;
      console.warn("The `validate` option is deprecated. Rename to the `shouldAutoLink` option instead.");
    }
    this.options.protocols.forEach((protocol) => {
      if (typeof protocol === "string") {
        registerCustomProtocol(protocol);
        return;
      }
      registerCustomProtocol(protocol.scheme, protocol.optionalSlashes);
    });
  },
  onDestroy() {
    reset();
  },
  inclusive() {
    return this.options.autolink;
  },
  addOptions() {
    return {
      openOnClick: true,
      linkOnPaste: true,
      autolink: true,
      protocols: [],
      defaultProtocol: "http",
      HTMLAttributes: {
        target: "_blank",
        rel: "noopener noreferrer nofollow",
        class: null
      },
      isAllowedUri: /* @__PURE__ */ __name((url, ctx) => !!isAllowedUri(url, ctx.protocols), "isAllowedUri"),
      validate: /* @__PURE__ */ __name((url) => !!url, "validate"),
      shouldAutoLink: /* @__PURE__ */ __name((url) => !!url, "shouldAutoLink")
    };
  },
  addAttributes() {
    return {
      href: {
        default: null,
        parseHTML(element) {
          return element.getAttribute("href");
        }
      },
      target: {
        default: this.options.HTMLAttributes.target
      },
      rel: {
        default: this.options.HTMLAttributes.rel
      },
      class: {
        default: this.options.HTMLAttributes.class
      }
    };
  },
  parseHTML() {
    return [
      {
        tag: "a[href]",
        getAttrs: /* @__PURE__ */ __name((dom) => {
          const href = dom.getAttribute("href");
          if (!href || !this.options.isAllowedUri(href, {
            defaultValidate: /* @__PURE__ */ __name((url) => !!isAllowedUri(url, this.options.protocols), "defaultValidate"),
            protocols: this.options.protocols,
            defaultProtocol: this.options.defaultProtocol
          })) {
            return false;
          }
          return null;
        }, "getAttrs")
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    if (!this.options.isAllowedUri(HTMLAttributes.href, {
      defaultValidate: /* @__PURE__ */ __name((href) => !!isAllowedUri(href, this.options.protocols), "defaultValidate"),
      protocols: this.options.protocols,
      defaultProtocol: this.options.defaultProtocol
    })) {
      return [
        "a",
        mergeAttributes(this.options.HTMLAttributes, { ...HTMLAttributes, href: "" }),
        0
      ];
    }
    return ["a", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setLink: /* @__PURE__ */ __name((attributes) => ({ chain }) => {
        const { href } = attributes;
        if (!this.options.isAllowedUri(href, {
          defaultValidate: /* @__PURE__ */ __name((url) => !!isAllowedUri(url, this.options.protocols), "defaultValidate"),
          protocols: this.options.protocols,
          defaultProtocol: this.options.defaultProtocol
        })) {
          return false;
        }
        return chain().setMark(this.name, attributes).setMeta("preventAutolink", true).run();
      }, "setLink"),
      toggleLink: /* @__PURE__ */ __name((attributes) => ({ chain }) => {
        const { href } = attributes;
        if (!this.options.isAllowedUri(href, {
          defaultValidate: /* @__PURE__ */ __name((url) => !!isAllowedUri(url, this.options.protocols), "defaultValidate"),
          protocols: this.options.protocols,
          defaultProtocol: this.options.defaultProtocol
        })) {
          return false;
        }
        return chain().toggleMark(this.name, attributes, { extendEmptyMarkRange: true }).setMeta("preventAutolink", true).run();
      }, "toggleLink"),
      unsetLink: /* @__PURE__ */ __name(() => ({ chain }) => {
        return chain().unsetMark(this.name, { extendEmptyMarkRange: true }).setMeta("preventAutolink", true).run();
      }, "unsetLink")
    };
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: /* @__PURE__ */ __name((text2) => {
          const foundLinks = [];
          if (text2) {
            const { protocols, defaultProtocol } = this.options;
            const links = find(text2).filter((item3) => item3.isLink && this.options.isAllowedUri(item3.value, {
              defaultValidate: /* @__PURE__ */ __name((href) => !!isAllowedUri(href, protocols), "defaultValidate"),
              protocols,
              defaultProtocol
            }));
            if (links.length) {
              links.forEach((link2) => foundLinks.push({
                text: link2.value,
                data: {
                  href: link2.href
                },
                index: link2.start
              }));
            }
          }
          return foundLinks;
        }, "find"),
        type: this.type,
        getAttributes: /* @__PURE__ */ __name((match2) => {
          var _a2;
          return {
            href: (_a2 = match2.data) === null || _a2 === void 0 ? void 0 : _a2.href
          };
        }, "getAttributes")
      })
    ];
  },
  addProseMirrorPlugins() {
    const plugins = [];
    const { protocols, defaultProtocol } = this.options;
    if (this.options.autolink) {
      plugins.push(autolink$1({
        type: this.type,
        defaultProtocol: this.options.defaultProtocol,
        validate: /* @__PURE__ */ __name((url) => this.options.isAllowedUri(url, {
          defaultValidate: /* @__PURE__ */ __name((href) => !!isAllowedUri(href, protocols), "defaultValidate"),
          protocols,
          defaultProtocol
        }), "validate"),
        shouldAutoLink: this.options.shouldAutoLink
      }));
    }
    if (this.options.openOnClick === true) {
      plugins.push(clickHandler({
        type: this.type
      }));
    }
    if (this.options.linkOnPaste) {
      plugins.push(pasteHandler({
        editor: this.editor,
        defaultProtocol: this.options.defaultProtocol,
        type: this.type
      }));
    }
    return plugins;
  }
});
var readFromCache;
var addToCache;
if (typeof WeakMap != "undefined") {
  let cache2 = /* @__PURE__ */ new WeakMap();
  readFromCache = /* @__PURE__ */ __name((key) => cache2.get(key), "readFromCache");
  addToCache = /* @__PURE__ */ __name((key, value3) => {
    cache2.set(key, value3);
    return value3;
  }, "addToCache");
} else {
  const cache2 = [];
  const cacheSize = 10;
  let cachePos = 0;
  readFromCache = /* @__PURE__ */ __name((key) => {
    for (let i2 = 0; i2 < cache2.length; i2 += 2)
      if (cache2[i2] == key)
        return cache2[i2 + 1];
  }, "readFromCache");
  addToCache = /* @__PURE__ */ __name((key, value3) => {
    if (cachePos == cacheSize)
      cachePos = 0;
    cache2[cachePos++] = key;
    return cache2[cachePos++] = value3;
  }, "addToCache");
}
var TableMap = class {
  static {
    __name(this, "TableMap");
  }
  constructor(width2, height, map3, problems) {
    this.width = width2;
    this.height = height;
    this.map = map3;
    this.problems = problems;
  }
  // Find the dimensions of the cell at the given position.
  findCell(pos) {
    for (let i2 = 0; i2 < this.map.length; i2++) {
      const curPos = this.map[i2];
      if (curPos != pos)
        continue;
      const left = i2 % this.width;
      const top = i2 / this.width | 0;
      let right = left + 1;
      let bottom = top + 1;
      for (let j2 = 1; right < this.width && this.map[i2 + j2] == curPos; j2++) {
        right++;
      }
      for (let j2 = 1; bottom < this.height && this.map[i2 + this.width * j2] == curPos; j2++) {
        bottom++;
      }
      return { left, top, right, bottom };
    }
    throw new RangeError(`No cell with offset ${pos} found`);
  }
  // Find the left side of the cell at the given position.
  colCount(pos) {
    for (let i2 = 0; i2 < this.map.length; i2++) {
      if (this.map[i2] == pos) {
        return i2 % this.width;
      }
    }
    throw new RangeError(`No cell with offset ${pos} found`);
  }
  // Find the next cell in the given direction, starting from the cell
  // at `pos`, if any.
  nextCell(pos, axis, dir) {
    const { left, right, top, bottom } = this.findCell(pos);
    if (axis == "horiz") {
      if (dir < 0 ? left == 0 : right == this.width)
        return null;
      return this.map[top * this.width + (dir < 0 ? left - 1 : right)];
    } else {
      if (dir < 0 ? top == 0 : bottom == this.height)
        return null;
      return this.map[left + this.width * (dir < 0 ? top - 1 : bottom)];
    }
  }
  // Get the rectangle spanning the two given cells.
  rectBetween(a2, b2) {
    const {
      left: leftA,
      right: rightA,
      top: topA,
      bottom: bottomA
    } = this.findCell(a2);
    const {
      left: leftB,
      right: rightB,
      top: topB,
      bottom: bottomB
    } = this.findCell(b2);
    return {
      left: Math.min(leftA, leftB),
      top: Math.min(topA, topB),
      right: Math.max(rightA, rightB),
      bottom: Math.max(bottomA, bottomB)
    };
  }
  // Return the position of all cells that have the top left corner in
  // the given rectangle.
  cellsInRect(rect) {
    const result = [];
    const seen2 = {};
    for (let row = rect.top; row < rect.bottom; row++) {
      for (let col = rect.left; col < rect.right; col++) {
        const index2 = row * this.width + col;
        const pos = this.map[index2];
        if (seen2[pos])
          continue;
        seen2[pos] = true;
        if (col == rect.left && col && this.map[index2 - 1] == pos || row == rect.top && row && this.map[index2 - this.width] == pos) {
          continue;
        }
        result.push(pos);
      }
    }
    return result;
  }
  // Return the position at which the cell at the given row and column
  // starts, or would start, if a cell started there.
  positionAt(row, col, table2) {
    for (let i2 = 0, rowStart = 0; ; i2++) {
      const rowEnd = rowStart + table2.child(i2).nodeSize;
      if (i2 == row) {
        let index2 = col + row * this.width;
        const rowEndIndex = (row + 1) * this.width;
        while (index2 < rowEndIndex && this.map[index2] < rowStart)
          index2++;
        return index2 == rowEndIndex ? rowEnd - 1 : this.map[index2];
      }
      rowStart = rowEnd;
    }
  }
  // Find the table map for the given table node.
  static get(table2) {
    return readFromCache(table2) || addToCache(table2, computeMap(table2));
  }
};
function computeMap(table2) {
  if (table2.type.spec.tableRole != "table")
    throw new RangeError("Not a table node: " + table2.type.name);
  const width2 = findWidth(table2), height = table2.childCount;
  const map3 = [];
  let mapPos = 0;
  let problems = null;
  const colWidths = [];
  for (let i2 = 0, e2 = width2 * height; i2 < e2; i2++)
    map3[i2] = 0;
  for (let row = 0, pos = 0; row < height; row++) {
    const rowNode = table2.child(row);
    pos++;
    for (let i2 = 0; ; i2++) {
      while (mapPos < map3.length && map3[mapPos] != 0)
        mapPos++;
      if (i2 == rowNode.childCount)
        break;
      const cellNode = rowNode.child(i2);
      const { colspan, rowspan, colwidth } = cellNode.attrs;
      for (let h2 = 0; h2 < rowspan; h2++) {
        if (h2 + row >= height) {
          (problems || (problems = [])).push({
            type: "overlong_rowspan",
            pos,
            n: rowspan - h2
          });
          break;
        }
        const start2 = mapPos + h2 * width2;
        for (let w2 = 0; w2 < colspan; w2++) {
          if (map3[start2 + w2] == 0)
            map3[start2 + w2] = pos;
          else
            (problems || (problems = [])).push({
              type: "collision",
              row,
              pos,
              n: colspan - w2
            });
          const colW = colwidth && colwidth[w2];
          if (colW) {
            const widthIndex = (start2 + w2) % width2 * 2, prev2 = colWidths[widthIndex];
            if (prev2 == null || prev2 != colW && colWidths[widthIndex + 1] == 1) {
              colWidths[widthIndex] = colW;
              colWidths[widthIndex + 1] = 1;
            } else if (prev2 == colW) {
              colWidths[widthIndex + 1]++;
            }
          }
        }
      }
      mapPos += colspan;
      pos += cellNode.nodeSize;
    }
    const expectedPos = (row + 1) * width2;
    let missing = 0;
    while (mapPos < expectedPos)
      if (map3[mapPos++] == 0)
        missing++;
    if (missing)
      (problems || (problems = [])).push({ type: "missing", row, n: missing });
    pos++;
  }
  const tableMap = new TableMap(width2, height, map3, problems);
  let badWidths = false;
  for (let i2 = 0; !badWidths && i2 < colWidths.length; i2 += 2)
    if (colWidths[i2] != null && colWidths[i2 + 1] < height)
      badWidths = true;
  if (badWidths)
    findBadColWidths(tableMap, colWidths, table2);
  return tableMap;
}
__name(computeMap, "computeMap");
function findWidth(table2) {
  let width2 = -1;
  let hasRowSpan = false;
  for (let row = 0; row < table2.childCount; row++) {
    const rowNode = table2.child(row);
    let rowWidth = 0;
    if (hasRowSpan)
      for (let j2 = 0; j2 < row; j2++) {
        const prevRow = table2.child(j2);
        for (let i2 = 0; i2 < prevRow.childCount; i2++) {
          const cell = prevRow.child(i2);
          if (j2 + cell.attrs.rowspan > row)
            rowWidth += cell.attrs.colspan;
        }
      }
    for (let i2 = 0; i2 < rowNode.childCount; i2++) {
      const cell = rowNode.child(i2);
      rowWidth += cell.attrs.colspan;
      if (cell.attrs.rowspan > 1)
        hasRowSpan = true;
    }
    if (width2 == -1)
      width2 = rowWidth;
    else if (width2 != rowWidth)
      width2 = Math.max(width2, rowWidth);
  }
  return width2;
}
__name(findWidth, "findWidth");
function findBadColWidths(map3, colWidths, table2) {
  if (!map3.problems)
    map3.problems = [];
  const seen2 = {};
  for (let i2 = 0; i2 < map3.map.length; i2++) {
    const pos = map3.map[i2];
    if (seen2[pos])
      continue;
    seen2[pos] = true;
    const node3 = table2.nodeAt(pos);
    if (!node3) {
      throw new RangeError(`No cell with offset ${pos} found`);
    }
    let updated17 = null;
    const attrs7 = node3.attrs;
    for (let j2 = 0; j2 < attrs7.colspan; j2++) {
      const col = (i2 + j2) % map3.width;
      const colWidth = colWidths[col * 2];
      if (colWidth != null && (!attrs7.colwidth || attrs7.colwidth[j2] != colWidth))
        (updated17 || (updated17 = freshColWidth(attrs7)))[j2] = colWidth;
    }
    if (updated17)
      map3.problems.unshift({
        type: "colwidth mismatch",
        pos,
        colwidth: updated17
      });
  }
}
__name(findBadColWidths, "findBadColWidths");
function freshColWidth(attrs7) {
  if (attrs7.colwidth)
    return attrs7.colwidth.slice();
  const result = [];
  for (let i2 = 0; i2 < attrs7.colspan; i2++)
    result.push(0);
  return result;
}
__name(freshColWidth, "freshColWidth");
function getCellAttrs(dom, extraAttrs) {
  if (typeof dom === "string") {
    return {};
  }
  const widthAttr = dom.getAttribute("data-colwidth");
  const widths = widthAttr && /^\d+(,\d+)*$/.test(widthAttr) ? widthAttr.split(",").map((s2) => Number(s2)) : null;
  const colspan = Number(dom.getAttribute("colspan") || 1);
  const result = {
    colspan,
    rowspan: Number(dom.getAttribute("rowspan") || 1),
    colwidth: widths && widths.length == colspan ? widths : null
  };
  for (const prop2 in extraAttrs) {
    const getter = extraAttrs[prop2].getFromDOM;
    const value3 = getter && getter(dom);
    if (value3 != null) {
      result[prop2] = value3;
    }
  }
  return result;
}
__name(getCellAttrs, "getCellAttrs");
function setCellAttrs(node3, extraAttrs) {
  const attrs7 = {};
  if (node3.attrs.colspan != 1)
    attrs7.colspan = node3.attrs.colspan;
  if (node3.attrs.rowspan != 1)
    attrs7.rowspan = node3.attrs.rowspan;
  if (node3.attrs.colwidth)
    attrs7["data-colwidth"] = node3.attrs.colwidth.join(",");
  for (const prop2 in extraAttrs) {
    const setter = extraAttrs[prop2].setDOMAttr;
    if (setter)
      setter(node3.attrs[prop2], attrs7);
  }
  return attrs7;
}
__name(setCellAttrs, "setCellAttrs");
function tableNodes(options5) {
  const extraAttrs = options5.cellAttributes || {};
  const cellAttrs = {
    colspan: { default: 1 },
    rowspan: { default: 1 },
    colwidth: { default: null }
  };
  for (const prop2 in extraAttrs)
    cellAttrs[prop2] = { default: extraAttrs[prop2].default };
  return {
    table: {
      content: "table_row+",
      tableRole: "table",
      isolating: true,
      group: options5.tableGroup,
      parseDOM: [{ tag: "table" }],
      toDOM() {
        return ["table", ["tbody", 0]];
      }
    },
    table_row: {
      content: "(table_cell | table_header)*",
      tableRole: "row",
      parseDOM: [{ tag: "tr" }],
      toDOM() {
        return ["tr", 0];
      }
    },
    table_cell: {
      content: options5.cellContent,
      attrs: cellAttrs,
      tableRole: "cell",
      isolating: true,
      parseDOM: [
        { tag: "td", getAttrs: /* @__PURE__ */ __name((dom) => getCellAttrs(dom, extraAttrs), "getAttrs") }
      ],
      toDOM(node3) {
        return ["td", setCellAttrs(node3, extraAttrs), 0];
      }
    },
    table_header: {
      content: options5.cellContent,
      attrs: cellAttrs,
      tableRole: "header_cell",
      isolating: true,
      parseDOM: [
        { tag: "th", getAttrs: /* @__PURE__ */ __name((dom) => getCellAttrs(dom, extraAttrs), "getAttrs") }
      ],
      toDOM(node3) {
        return ["th", setCellAttrs(node3, extraAttrs), 0];
      }
    }
  };
}
__name(tableNodes, "tableNodes");
function tableNodeTypes(schema2) {
  let result = schema2.cached.tableNodeTypes;
  if (!result) {
    result = schema2.cached.tableNodeTypes = {};
    for (const name2 in schema2.nodes) {
      const type = schema2.nodes[name2], role = type.spec.tableRole;
      if (role)
        result[role] = type;
    }
  }
  return result;
}
__name(tableNodeTypes, "tableNodeTypes");
var tableEditingKey = new PluginKey("selectingCells");
function cellAround($pos) {
  for (let d2 = $pos.depth - 1; d2 > 0; d2--)
    if ($pos.node(d2).type.spec.tableRole == "row")
      return $pos.node(0).resolve($pos.before(d2 + 1));
  return null;
}
__name(cellAround, "cellAround");
function cellWrapping($pos) {
  for (let d2 = $pos.depth; d2 > 0; d2--) {
    const role = $pos.node(d2).type.spec.tableRole;
    if (role === "cell" || role === "header_cell")
      return $pos.node(d2);
  }
  return null;
}
__name(cellWrapping, "cellWrapping");
function isInTable(state) {
  const $head = state.selection.$head;
  for (let d2 = $head.depth; d2 > 0; d2--)
    if ($head.node(d2).type.spec.tableRole == "row")
      return true;
  return false;
}
__name(isInTable, "isInTable");
function selectionCell(state) {
  const sel = state.selection;
  if ("$anchorCell" in sel && sel.$anchorCell) {
    return sel.$anchorCell.pos > sel.$headCell.pos ? sel.$anchorCell : sel.$headCell;
  } else if ("node" in sel && sel.node && sel.node.type.spec.tableRole == "cell") {
    return sel.$anchor;
  }
  const $cell = cellAround(sel.$head) || cellNear(sel.$head);
  if ($cell) {
    return $cell;
  }
  throw new RangeError(`No cell found around position ${sel.head}`);
}
__name(selectionCell, "selectionCell");
function cellNear($pos) {
  for (let after = $pos.nodeAfter, pos = $pos.pos; after; after = after.firstChild, pos++) {
    const role = after.type.spec.tableRole;
    if (role == "cell" || role == "header_cell")
      return $pos.doc.resolve(pos);
  }
  for (let before = $pos.nodeBefore, pos = $pos.pos; before; before = before.lastChild, pos--) {
    const role = before.type.spec.tableRole;
    if (role == "cell" || role == "header_cell")
      return $pos.doc.resolve(pos - before.nodeSize);
  }
}
__name(cellNear, "cellNear");
function pointsAtCell($pos) {
  return $pos.parent.type.spec.tableRole == "row" && !!$pos.nodeAfter;
}
__name(pointsAtCell, "pointsAtCell");
function moveCellForward($pos) {
  return $pos.node(0).resolve($pos.pos + $pos.nodeAfter.nodeSize);
}
__name(moveCellForward, "moveCellForward");
function inSameTable($cellA, $cellB) {
  return $cellA.depth == $cellB.depth && $cellA.pos >= $cellB.start(-1) && $cellA.pos <= $cellB.end(-1);
}
__name(inSameTable, "inSameTable");
function findCell($pos) {
  return TableMap.get($pos.node(-1)).findCell($pos.pos - $pos.start(-1));
}
__name(findCell, "findCell");
function colCount($pos) {
  return TableMap.get($pos.node(-1)).colCount($pos.pos - $pos.start(-1));
}
__name(colCount, "colCount");
function nextCell($pos, axis, dir) {
  const table2 = $pos.node(-1);
  const map3 = TableMap.get(table2);
  const tableStart = $pos.start(-1);
  const moved = map3.nextCell($pos.pos - tableStart, axis, dir);
  return moved == null ? null : $pos.node(0).resolve(tableStart + moved);
}
__name(nextCell, "nextCell");
function removeColSpan(attrs7, pos, n2 = 1) {
  const result = { ...attrs7, colspan: attrs7.colspan - n2 };
  if (result.colwidth) {
    result.colwidth = result.colwidth.slice();
    result.colwidth.splice(pos, n2);
    if (!result.colwidth.some((w2) => w2 > 0))
      result.colwidth = null;
  }
  return result;
}
__name(removeColSpan, "removeColSpan");
function addColSpan(attrs7, pos, n2 = 1) {
  const result = { ...attrs7, colspan: attrs7.colspan + n2 };
  if (result.colwidth) {
    result.colwidth = result.colwidth.slice();
    for (let i2 = 0; i2 < n2; i2++)
      result.colwidth.splice(pos, 0, 0);
  }
  return result;
}
__name(addColSpan, "addColSpan");
function columnIsHeader(map3, table2, col) {
  const headerCell = tableNodeTypes(table2.type.schema).header_cell;
  for (let row = 0; row < map3.height; row++)
    if (table2.nodeAt(map3.map[col + row * map3.width]).type != headerCell)
      return false;
  return true;
}
__name(columnIsHeader, "columnIsHeader");
var CellSelection = class _CellSelection extends Selection {
  static {
    __name(this, "_CellSelection");
  }
  // A table selection is identified by its anchor and head cells. The
  // positions given to this constructor should point _before_ two
  // cells in the same table. They may be the same, to select a single
  // cell.
  constructor($anchorCell, $headCell = $anchorCell) {
    const table2 = $anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = $anchorCell.start(-1);
    const rect = map3.rectBetween(
      $anchorCell.pos - tableStart,
      $headCell.pos - tableStart
    );
    const doc2 = $anchorCell.node(0);
    const cells = map3.cellsInRect(rect).filter((p2) => p2 != $headCell.pos - tableStart);
    cells.unshift($headCell.pos - tableStart);
    const ranges = cells.map((pos) => {
      const cell = table2.nodeAt(pos);
      if (!cell) {
        throw RangeError(`No cell with offset ${pos} found`);
      }
      const from2 = tableStart + pos + 1;
      return new SelectionRange(
        doc2.resolve(from2),
        doc2.resolve(from2 + cell.content.size)
      );
    });
    super(ranges[0].$from, ranges[0].$to, ranges);
    this.$anchorCell = $anchorCell;
    this.$headCell = $headCell;
  }
  map(doc2, mapping) {
    const $anchorCell = doc2.resolve(mapping.map(this.$anchorCell.pos));
    const $headCell = doc2.resolve(mapping.map(this.$headCell.pos));
    if (pointsAtCell($anchorCell) && pointsAtCell($headCell) && inSameTable($anchorCell, $headCell)) {
      const tableChanged = this.$anchorCell.node(-1) != $anchorCell.node(-1);
      if (tableChanged && this.isRowSelection())
        return _CellSelection.rowSelection($anchorCell, $headCell);
      else if (tableChanged && this.isColSelection())
        return _CellSelection.colSelection($anchorCell, $headCell);
      else
        return new _CellSelection($anchorCell, $headCell);
    }
    return TextSelection.between($anchorCell, $headCell);
  }
  // Returns a rectangular slice of table rows containing the selected
  // cells.
  content() {
    const table2 = this.$anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = this.$anchorCell.start(-1);
    const rect = map3.rectBetween(
      this.$anchorCell.pos - tableStart,
      this.$headCell.pos - tableStart
    );
    const seen2 = {};
    const rows = [];
    for (let row = rect.top; row < rect.bottom; row++) {
      const rowContent = [];
      for (let index2 = row * map3.width + rect.left, col = rect.left; col < rect.right; col++, index2++) {
        const pos = map3.map[index2];
        if (seen2[pos])
          continue;
        seen2[pos] = true;
        const cellRect = map3.findCell(pos);
        let cell = table2.nodeAt(pos);
        if (!cell) {
          throw RangeError(`No cell with offset ${pos} found`);
        }
        const extraLeft = rect.left - cellRect.left;
        const extraRight = cellRect.right - rect.right;
        if (extraLeft > 0 || extraRight > 0) {
          let attrs7 = cell.attrs;
          if (extraLeft > 0) {
            attrs7 = removeColSpan(attrs7, 0, extraLeft);
          }
          if (extraRight > 0) {
            attrs7 = removeColSpan(
              attrs7,
              attrs7.colspan - extraRight,
              extraRight
            );
          }
          if (cellRect.left < rect.left) {
            cell = cell.type.createAndFill(attrs7);
            if (!cell) {
              throw RangeError(
                `Could not create cell with attrs ${JSON.stringify(attrs7)}`
              );
            }
          } else {
            cell = cell.type.create(attrs7, cell.content);
          }
        }
        if (cellRect.top < rect.top || cellRect.bottom > rect.bottom) {
          const attrs7 = {
            ...cell.attrs,
            rowspan: Math.min(cellRect.bottom, rect.bottom) - Math.max(cellRect.top, rect.top)
          };
          if (cellRect.top < rect.top) {
            cell = cell.type.createAndFill(attrs7);
          } else {
            cell = cell.type.create(attrs7, cell.content);
          }
        }
        rowContent.push(cell);
      }
      rows.push(table2.child(row).copy(Fragment.from(rowContent)));
    }
    const fragment = this.isColSelection() && this.isRowSelection() ? table2 : rows;
    return new Slice(Fragment.from(fragment), 1, 1);
  }
  replace(tr2, content3 = Slice.empty) {
    const mapFrom = tr2.steps.length, ranges = this.ranges;
    for (let i2 = 0; i2 < ranges.length; i2++) {
      const { $from, $to } = ranges[i2], mapping = tr2.mapping.slice(mapFrom);
      tr2.replace(
        mapping.map($from.pos),
        mapping.map($to.pos),
        i2 ? Slice.empty : content3
      );
    }
    const sel = Selection.findFrom(
      tr2.doc.resolve(tr2.mapping.slice(mapFrom).map(this.to)),
      -1
    );
    if (sel)
      tr2.setSelection(sel);
  }
  replaceWith(tr2, node3) {
    this.replace(tr2, new Slice(Fragment.from(node3), 0, 0));
  }
  forEachCell(f2) {
    const table2 = this.$anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = this.$anchorCell.start(-1);
    const cells = map3.cellsInRect(
      map3.rectBetween(
        this.$anchorCell.pos - tableStart,
        this.$headCell.pos - tableStart
      )
    );
    for (let i2 = 0; i2 < cells.length; i2++) {
      f2(table2.nodeAt(cells[i2]), tableStart + cells[i2]);
    }
  }
  // True if this selection goes all the way from the top to the
  // bottom of the table.
  isColSelection() {
    const anchorTop = this.$anchorCell.index(-1);
    const headTop = this.$headCell.index(-1);
    if (Math.min(anchorTop, headTop) > 0)
      return false;
    const anchorBottom = anchorTop + this.$anchorCell.nodeAfter.attrs.rowspan;
    const headBottom = headTop + this.$headCell.nodeAfter.attrs.rowspan;
    return Math.max(anchorBottom, headBottom) == this.$headCell.node(-1).childCount;
  }
  // Returns the smallest column selection that covers the given anchor
  // and head cell.
  static colSelection($anchorCell, $headCell = $anchorCell) {
    const table2 = $anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = $anchorCell.start(-1);
    const anchorRect = map3.findCell($anchorCell.pos - tableStart);
    const headRect = map3.findCell($headCell.pos - tableStart);
    const doc2 = $anchorCell.node(0);
    if (anchorRect.top <= headRect.top) {
      if (anchorRect.top > 0)
        $anchorCell = doc2.resolve(tableStart + map3.map[anchorRect.left]);
      if (headRect.bottom < map3.height)
        $headCell = doc2.resolve(
          tableStart + map3.map[map3.width * (map3.height - 1) + headRect.right - 1]
        );
    } else {
      if (headRect.top > 0)
        $headCell = doc2.resolve(tableStart + map3.map[headRect.left]);
      if (anchorRect.bottom < map3.height)
        $anchorCell = doc2.resolve(
          tableStart + map3.map[map3.width * (map3.height - 1) + anchorRect.right - 1]
        );
    }
    return new _CellSelection($anchorCell, $headCell);
  }
  // True if this selection goes all the way from the left to the
  // right of the table.
  isRowSelection() {
    const table2 = this.$anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = this.$anchorCell.start(-1);
    const anchorLeft = map3.colCount(this.$anchorCell.pos - tableStart);
    const headLeft = map3.colCount(this.$headCell.pos - tableStart);
    if (Math.min(anchorLeft, headLeft) > 0)
      return false;
    const anchorRight = anchorLeft + this.$anchorCell.nodeAfter.attrs.colspan;
    const headRight = headLeft + this.$headCell.nodeAfter.attrs.colspan;
    return Math.max(anchorRight, headRight) == map3.width;
  }
  eq(other) {
    return other instanceof _CellSelection && other.$anchorCell.pos == this.$anchorCell.pos && other.$headCell.pos == this.$headCell.pos;
  }
  // Returns the smallest row selection that covers the given anchor
  // and head cell.
  static rowSelection($anchorCell, $headCell = $anchorCell) {
    const table2 = $anchorCell.node(-1);
    const map3 = TableMap.get(table2);
    const tableStart = $anchorCell.start(-1);
    const anchorRect = map3.findCell($anchorCell.pos - tableStart);
    const headRect = map3.findCell($headCell.pos - tableStart);
    const doc2 = $anchorCell.node(0);
    if (anchorRect.left <= headRect.left) {
      if (anchorRect.left > 0)
        $anchorCell = doc2.resolve(
          tableStart + map3.map[anchorRect.top * map3.width]
        );
      if (headRect.right < map3.width)
        $headCell = doc2.resolve(
          tableStart + map3.map[map3.width * (headRect.top + 1) - 1]
        );
    } else {
      if (headRect.left > 0)
        $headCell = doc2.resolve(tableStart + map3.map[headRect.top * map3.width]);
      if (anchorRect.right < map3.width)
        $anchorCell = doc2.resolve(
          tableStart + map3.map[map3.width * (anchorRect.top + 1) - 1]
        );
    }
    return new _CellSelection($anchorCell, $headCell);
  }
  toJSON() {
    return {
      type: "cell",
      anchor: this.$anchorCell.pos,
      head: this.$headCell.pos
    };
  }
  static fromJSON(doc2, json) {
    return new _CellSelection(doc2.resolve(json.anchor), doc2.resolve(json.head));
  }
  static create(doc2, anchorCell, headCell = anchorCell) {
    return new _CellSelection(doc2.resolve(anchorCell), doc2.resolve(headCell));
  }
  getBookmark() {
    return new CellBookmark(this.$anchorCell.pos, this.$headCell.pos);
  }
};
CellSelection.prototype.visible = false;
Selection.jsonID("cell", CellSelection);
var CellBookmark = class _CellBookmark {
  static {
    __name(this, "_CellBookmark");
  }
  constructor(anchor, head) {
    this.anchor = anchor;
    this.head = head;
  }
  map(mapping) {
    return new _CellBookmark(mapping.map(this.anchor), mapping.map(this.head));
  }
  resolve(doc2) {
    const $anchorCell = doc2.resolve(this.anchor), $headCell = doc2.resolve(this.head);
    if ($anchorCell.parent.type.spec.tableRole == "row" && $headCell.parent.type.spec.tableRole == "row" && $anchorCell.index() < $anchorCell.parent.childCount && $headCell.index() < $headCell.parent.childCount && inSameTable($anchorCell, $headCell))
      return new CellSelection($anchorCell, $headCell);
    else
      return Selection.near($headCell, 1);
  }
};
function drawCellSelection(state) {
  if (!(state.selection instanceof CellSelection))
    return null;
  const cells = [];
  state.selection.forEachCell((node3, pos) => {
    cells.push(
      Decoration.node(pos, pos + node3.nodeSize, { class: "selectedCell" })
    );
  });
  return DecorationSet.create(state.doc, cells);
}
__name(drawCellSelection, "drawCellSelection");
function isCellBoundarySelection({ $from, $to }) {
  if ($from.pos == $to.pos || $from.pos < $to.pos - 6)
    return false;
  let afterFrom = $from.pos;
  let beforeTo = $to.pos;
  let depth = $from.depth;
  for (; depth >= 0; depth--, afterFrom++)
    if ($from.after(depth + 1) < $from.end(depth))
      break;
  for (let d2 = $to.depth; d2 >= 0; d2--, beforeTo--)
    if ($to.before(d2 + 1) > $to.start(d2))
      break;
  return afterFrom == beforeTo && /row|table/.test($from.node(depth).type.spec.tableRole);
}
__name(isCellBoundarySelection, "isCellBoundarySelection");
function isTextSelectionAcrossCells({ $from, $to }) {
  let fromCellBoundaryNode;
  let toCellBoundaryNode;
  for (let i2 = $from.depth; i2 > 0; i2--) {
    const node3 = $from.node(i2);
    if (node3.type.spec.tableRole === "cell" || node3.type.spec.tableRole === "header_cell") {
      fromCellBoundaryNode = node3;
      break;
    }
  }
  for (let i2 = $to.depth; i2 > 0; i2--) {
    const node3 = $to.node(i2);
    if (node3.type.spec.tableRole === "cell" || node3.type.spec.tableRole === "header_cell") {
      toCellBoundaryNode = node3;
      break;
    }
  }
  return fromCellBoundaryNode !== toCellBoundaryNode && $to.parentOffset === 0;
}
__name(isTextSelectionAcrossCells, "isTextSelectionAcrossCells");
function normalizeSelection(state, tr2, allowTableNodeSelection) {
  const sel = (tr2 || state).selection;
  const doc2 = (tr2 || state).doc;
  let normalize3;
  let role;
  if (sel instanceof NodeSelection && (role = sel.node.type.spec.tableRole)) {
    if (role == "cell" || role == "header_cell") {
      normalize3 = CellSelection.create(doc2, sel.from);
    } else if (role == "row") {
      const $cell = doc2.resolve(sel.from + 1);
      normalize3 = CellSelection.rowSelection($cell, $cell);
    } else if (!allowTableNodeSelection) {
      const map3 = TableMap.get(sel.node);
      const start2 = sel.from + 1;
      const lastCell = start2 + map3.map[map3.width * map3.height - 1];
      normalize3 = CellSelection.create(doc2, start2 + 1, lastCell);
    }
  } else if (sel instanceof TextSelection && isCellBoundarySelection(sel)) {
    normalize3 = TextSelection.create(doc2, sel.from);
  } else if (sel instanceof TextSelection && isTextSelectionAcrossCells(sel)) {
    normalize3 = TextSelection.create(doc2, sel.$from.start(), sel.$from.end());
  }
  if (normalize3)
    (tr2 || (tr2 = state.tr)).setSelection(normalize3);
  return tr2;
}
__name(normalizeSelection, "normalizeSelection");
var fixTablesKey = new PluginKey("fix-tables");
function changedDescendants(old, cur, offset, f2) {
  const oldSize = old.childCount, curSize = cur.childCount;
  outer:
    for (let i2 = 0, j2 = 0; i2 < curSize; i2++) {
      const child = cur.child(i2);
      for (let scan = j2, e2 = Math.min(oldSize, i2 + 3); scan < e2; scan++) {
        if (old.child(scan) == child) {
          j2 = scan + 1;
          offset += child.nodeSize;
          continue outer;
        }
      }
      f2(child, offset);
      if (j2 < oldSize && old.child(j2).sameMarkup(child))
        changedDescendants(old.child(j2), child, offset + 1, f2);
      else
        child.nodesBetween(0, child.content.size, f2, offset + 1);
      offset += child.nodeSize;
    }
}
__name(changedDescendants, "changedDescendants");
function fixTables(state, oldState) {
  let tr2;
  const check = /* @__PURE__ */ __name((node3, pos) => {
    if (node3.type.spec.tableRole == "table")
      tr2 = fixTable(state, node3, pos, tr2);
  }, "check");
  if (!oldState)
    state.doc.descendants(check);
  else if (oldState.doc != state.doc)
    changedDescendants(oldState.doc, state.doc, 0, check);
  return tr2;
}
__name(fixTables, "fixTables");
function fixTable(state, table2, tablePos, tr2) {
  const map3 = TableMap.get(table2);
  if (!map3.problems)
    return tr2;
  if (!tr2)
    tr2 = state.tr;
  const mustAdd = [];
  for (let i2 = 0; i2 < map3.height; i2++)
    mustAdd.push(0);
  for (let i2 = 0; i2 < map3.problems.length; i2++) {
    const prob = map3.problems[i2];
    if (prob.type == "collision") {
      const cell = table2.nodeAt(prob.pos);
      if (!cell)
        continue;
      const attrs7 = cell.attrs;
      for (let j2 = 0; j2 < attrs7.rowspan; j2++)
        mustAdd[prob.row + j2] += prob.n;
      tr2.setNodeMarkup(
        tr2.mapping.map(tablePos + 1 + prob.pos),
        null,
        removeColSpan(attrs7, attrs7.colspan - prob.n, prob.n)
      );
    } else if (prob.type == "missing") {
      mustAdd[prob.row] += prob.n;
    } else if (prob.type == "overlong_rowspan") {
      const cell = table2.nodeAt(prob.pos);
      if (!cell)
        continue;
      tr2.setNodeMarkup(tr2.mapping.map(tablePos + 1 + prob.pos), null, {
        ...cell.attrs,
        rowspan: cell.attrs.rowspan - prob.n
      });
    } else if (prob.type == "colwidth mismatch") {
      const cell = table2.nodeAt(prob.pos);
      if (!cell)
        continue;
      tr2.setNodeMarkup(tr2.mapping.map(tablePos + 1 + prob.pos), null, {
        ...cell.attrs,
        colwidth: prob.colwidth
      });
    }
  }
  let first2, last;
  for (let i2 = 0; i2 < mustAdd.length; i2++)
    if (mustAdd[i2]) {
      if (first2 == null)
        first2 = i2;
      last = i2;
    }
  for (let i2 = 0, pos = tablePos + 1; i2 < map3.height; i2++) {
    const row = table2.child(i2);
    const end = pos + row.nodeSize;
    const add3 = mustAdd[i2];
    if (add3 > 0) {
      let role = "cell";
      if (row.firstChild) {
        role = row.firstChild.type.spec.tableRole;
      }
      const nodes = [];
      for (let j2 = 0; j2 < add3; j2++) {
        const node3 = tableNodeTypes(state.schema)[role].createAndFill();
        if (node3)
          nodes.push(node3);
      }
      const side = (i2 == 0 || first2 == i2 - 1) && last == i2 ? pos + 1 : end - 1;
      tr2.insert(tr2.mapping.map(side), nodes);
    }
    pos = end;
  }
  return tr2.setMeta(fixTablesKey, { fixTables: true });
}
__name(fixTable, "fixTable");
function selectedRect(state) {
  const sel = state.selection;
  const $pos = selectionCell(state);
  const table2 = $pos.node(-1);
  const tableStart = $pos.start(-1);
  const map3 = TableMap.get(table2);
  const rect = sel instanceof CellSelection ? map3.rectBetween(
    sel.$anchorCell.pos - tableStart,
    sel.$headCell.pos - tableStart
  ) : map3.findCell($pos.pos - tableStart);
  return { ...rect, tableStart, map: map3, table: table2 };
}
__name(selectedRect, "selectedRect");
function addColumn(tr2, { map: map3, tableStart, table: table2 }, col) {
  let refColumn = col > 0 ? -1 : 0;
  if (columnIsHeader(map3, table2, col + refColumn)) {
    refColumn = col == 0 || col == map3.width ? null : 0;
  }
  for (let row = 0; row < map3.height; row++) {
    const index2 = row * map3.width + col;
    if (col > 0 && col < map3.width && map3.map[index2 - 1] == map3.map[index2]) {
      const pos = map3.map[index2];
      const cell = table2.nodeAt(pos);
      tr2.setNodeMarkup(
        tr2.mapping.map(tableStart + pos),
        null,
        addColSpan(cell.attrs, col - map3.colCount(pos))
      );
      row += cell.attrs.rowspan - 1;
    } else {
      const type = refColumn == null ? tableNodeTypes(table2.type.schema).cell : table2.nodeAt(map3.map[index2 + refColumn]).type;
      const pos = map3.positionAt(row, col, table2);
      tr2.insert(tr2.mapping.map(tableStart + pos), type.createAndFill());
    }
  }
  return tr2;
}
__name(addColumn, "addColumn");
function addColumnBefore(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state);
    dispatch(addColumn(state.tr, rect, rect.left));
  }
  return true;
}
__name(addColumnBefore, "addColumnBefore");
function addColumnAfter(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state);
    dispatch(addColumn(state.tr, rect, rect.right));
  }
  return true;
}
__name(addColumnAfter, "addColumnAfter");
function removeColumn(tr2, { map: map3, table: table2, tableStart }, col) {
  const mapStart = tr2.mapping.maps.length;
  for (let row = 0; row < map3.height; ) {
    const index2 = row * map3.width + col;
    const pos = map3.map[index2];
    const cell = table2.nodeAt(pos);
    const attrs7 = cell.attrs;
    if (col > 0 && map3.map[index2 - 1] == pos || col < map3.width - 1 && map3.map[index2 + 1] == pos) {
      tr2.setNodeMarkup(
        tr2.mapping.slice(mapStart).map(tableStart + pos),
        null,
        removeColSpan(attrs7, col - map3.colCount(pos))
      );
    } else {
      const start2 = tr2.mapping.slice(mapStart).map(tableStart + pos);
      tr2.delete(start2, start2 + cell.nodeSize);
    }
    row += attrs7.rowspan;
  }
}
__name(removeColumn, "removeColumn");
function deleteColumn(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state);
    const tr2 = state.tr;
    if (rect.left == 0 && rect.right == rect.map.width)
      return false;
    for (let i2 = rect.right - 1; ; i2--) {
      removeColumn(tr2, rect, i2);
      if (i2 == rect.left)
        break;
      const table2 = rect.tableStart ? tr2.doc.nodeAt(rect.tableStart - 1) : tr2.doc;
      if (!table2) {
        throw RangeError("No table found");
      }
      rect.table = table2;
      rect.map = TableMap.get(table2);
    }
    dispatch(tr2);
  }
  return true;
}
__name(deleteColumn, "deleteColumn");
function rowIsHeader(map3, table2, row) {
  var _a2;
  const headerCell = tableNodeTypes(table2.type.schema).header_cell;
  for (let col = 0; col < map3.width; col++)
    if (((_a2 = table2.nodeAt(map3.map[col + row * map3.width])) == null ? void 0 : _a2.type) != headerCell)
      return false;
  return true;
}
__name(rowIsHeader, "rowIsHeader");
function addRow(tr2, { map: map3, tableStart, table: table2 }, row) {
  var _a2;
  let rowPos = tableStart;
  for (let i2 = 0; i2 < row; i2++)
    rowPos += table2.child(i2).nodeSize;
  const cells = [];
  let refRow = row > 0 ? -1 : 0;
  if (rowIsHeader(map3, table2, row + refRow))
    refRow = row == 0 || row == map3.height ? null : 0;
  for (let col = 0, index2 = map3.width * row; col < map3.width; col++, index2++) {
    if (row > 0 && row < map3.height && map3.map[index2] == map3.map[index2 - map3.width]) {
      const pos = map3.map[index2];
      const attrs7 = table2.nodeAt(pos).attrs;
      tr2.setNodeMarkup(tableStart + pos, null, {
        ...attrs7,
        rowspan: attrs7.rowspan + 1
      });
      col += attrs7.colspan - 1;
    } else {
      const type = refRow == null ? tableNodeTypes(table2.type.schema).cell : (_a2 = table2.nodeAt(map3.map[index2 + refRow * map3.width])) == null ? void 0 : _a2.type;
      const node3 = type == null ? void 0 : type.createAndFill();
      if (node3)
        cells.push(node3);
    }
  }
  tr2.insert(rowPos, tableNodeTypes(table2.type.schema).row.create(null, cells));
  return tr2;
}
__name(addRow, "addRow");
function addRowBefore(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state);
    dispatch(addRow(state.tr, rect, rect.top));
  }
  return true;
}
__name(addRowBefore, "addRowBefore");
function addRowAfter(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state);
    dispatch(addRow(state.tr, rect, rect.bottom));
  }
  return true;
}
__name(addRowAfter, "addRowAfter");
function removeRow(tr2, { map: map3, table: table2, tableStart }, row) {
  let rowPos = 0;
  for (let i2 = 0; i2 < row; i2++)
    rowPos += table2.child(i2).nodeSize;
  const nextRow = rowPos + table2.child(row).nodeSize;
  const mapFrom = tr2.mapping.maps.length;
  tr2.delete(rowPos + tableStart, nextRow + tableStart);
  const seen2 = /* @__PURE__ */ new Set();
  for (let col = 0, index2 = row * map3.width; col < map3.width; col++, index2++) {
    const pos = map3.map[index2];
    if (seen2.has(pos))
      continue;
    seen2.add(pos);
    if (row > 0 && pos == map3.map[index2 - map3.width]) {
      const attrs7 = table2.nodeAt(pos).attrs;
      tr2.setNodeMarkup(tr2.mapping.slice(mapFrom).map(pos + tableStart), null, {
        ...attrs7,
        rowspan: attrs7.rowspan - 1
      });
      col += attrs7.colspan - 1;
    } else if (row < map3.height && pos == map3.map[index2 + map3.width]) {
      const cell = table2.nodeAt(pos);
      const attrs7 = cell.attrs;
      const copy2 = cell.type.create(
        { ...attrs7, rowspan: cell.attrs.rowspan - 1 },
        cell.content
      );
      const newPos = map3.positionAt(row + 1, col, table2);
      tr2.insert(tr2.mapping.slice(mapFrom).map(tableStart + newPos), copy2);
      col += attrs7.colspan - 1;
    }
  }
}
__name(removeRow, "removeRow");
function deleteRow(state, dispatch) {
  if (!isInTable(state))
    return false;
  if (dispatch) {
    const rect = selectedRect(state), tr2 = state.tr;
    if (rect.top == 0 && rect.bottom == rect.map.height)
      return false;
    for (let i2 = rect.bottom - 1; ; i2--) {
      removeRow(tr2, rect, i2);
      if (i2 == rect.top)
        break;
      const table2 = rect.tableStart ? tr2.doc.nodeAt(rect.tableStart - 1) : tr2.doc;
      if (!table2) {
        throw RangeError("No table found");
      }
      rect.table = table2;
      rect.map = TableMap.get(rect.table);
    }
    dispatch(tr2);
  }
  return true;
}
__name(deleteRow, "deleteRow");
function isEmpty(cell) {
  const c2 = cell.content;
  return c2.childCount == 1 && c2.child(0).isTextblock && c2.child(0).childCount == 0;
}
__name(isEmpty, "isEmpty");
function cellsOverlapRectangle({ width: width2, height, map: map3 }, rect) {
  let indexTop = rect.top * width2 + rect.left, indexLeft = indexTop;
  let indexBottom = (rect.bottom - 1) * width2 + rect.left, indexRight = indexTop + (rect.right - rect.left - 1);
  for (let i2 = rect.top; i2 < rect.bottom; i2++) {
    if (rect.left > 0 && map3[indexLeft] == map3[indexLeft - 1] || rect.right < width2 && map3[indexRight] == map3[indexRight + 1])
      return true;
    indexLeft += width2;
    indexRight += width2;
  }
  for (let i2 = rect.left; i2 < rect.right; i2++) {
    if (rect.top > 0 && map3[indexTop] == map3[indexTop - width2] || rect.bottom < height && map3[indexBottom] == map3[indexBottom + width2])
      return true;
    indexTop++;
    indexBottom++;
  }
  return false;
}
__name(cellsOverlapRectangle, "cellsOverlapRectangle");
function mergeCells(state, dispatch) {
  const sel = state.selection;
  if (!(sel instanceof CellSelection) || sel.$anchorCell.pos == sel.$headCell.pos)
    return false;
  const rect = selectedRect(state), { map: map3 } = rect;
  if (cellsOverlapRectangle(map3, rect))
    return false;
  if (dispatch) {
    const tr2 = state.tr;
    const seen2 = {};
    let content3 = Fragment.empty;
    let mergedPos;
    let mergedCell;
    for (let row = rect.top; row < rect.bottom; row++) {
      for (let col = rect.left; col < rect.right; col++) {
        const cellPos = map3.map[row * map3.width + col];
        const cell = rect.table.nodeAt(cellPos);
        if (seen2[cellPos] || !cell)
          continue;
        seen2[cellPos] = true;
        if (mergedPos == null) {
          mergedPos = cellPos;
          mergedCell = cell;
        } else {
          if (!isEmpty(cell))
            content3 = content3.append(cell.content);
          const mapped = tr2.mapping.map(cellPos + rect.tableStart);
          tr2.delete(mapped, mapped + cell.nodeSize);
        }
      }
    }
    if (mergedPos == null || mergedCell == null) {
      return true;
    }
    tr2.setNodeMarkup(mergedPos + rect.tableStart, null, {
      ...addColSpan(
        mergedCell.attrs,
        mergedCell.attrs.colspan,
        rect.right - rect.left - mergedCell.attrs.colspan
      ),
      rowspan: rect.bottom - rect.top
    });
    if (content3.size) {
      const end = mergedPos + 1 + mergedCell.content.size;
      const start2 = isEmpty(mergedCell) ? mergedPos + 1 : end;
      tr2.replaceWith(start2 + rect.tableStart, end + rect.tableStart, content3);
    }
    tr2.setSelection(
      new CellSelection(tr2.doc.resolve(mergedPos + rect.tableStart))
    );
    dispatch(tr2);
  }
  return true;
}
__name(mergeCells, "mergeCells");
function splitCell(state, dispatch) {
  const nodeTypes = tableNodeTypes(state.schema);
  return splitCellWithType(({ node: node3 }) => {
    return nodeTypes[node3.type.spec.tableRole];
  })(state, dispatch);
}
__name(splitCell, "splitCell");
function splitCellWithType(getCellType) {
  return (state, dispatch) => {
    var _a2;
    const sel = state.selection;
    let cellNode;
    let cellPos;
    if (!(sel instanceof CellSelection)) {
      cellNode = cellWrapping(sel.$from);
      if (!cellNode)
        return false;
      cellPos = (_a2 = cellAround(sel.$from)) == null ? void 0 : _a2.pos;
    } else {
      if (sel.$anchorCell.pos != sel.$headCell.pos)
        return false;
      cellNode = sel.$anchorCell.nodeAfter;
      cellPos = sel.$anchorCell.pos;
    }
    if (cellNode == null || cellPos == null) {
      return false;
    }
    if (cellNode.attrs.colspan == 1 && cellNode.attrs.rowspan == 1) {
      return false;
    }
    if (dispatch) {
      let baseAttrs = cellNode.attrs;
      const attrs7 = [];
      const colwidth = baseAttrs.colwidth;
      if (baseAttrs.rowspan > 1)
        baseAttrs = { ...baseAttrs, rowspan: 1 };
      if (baseAttrs.colspan > 1)
        baseAttrs = { ...baseAttrs, colspan: 1 };
      const rect = selectedRect(state), tr2 = state.tr;
      for (let i2 = 0; i2 < rect.right - rect.left; i2++)
        attrs7.push(
          colwidth ? {
            ...baseAttrs,
            colwidth: colwidth && colwidth[i2] ? [colwidth[i2]] : null
          } : baseAttrs
        );
      let lastCell;
      for (let row = rect.top; row < rect.bottom; row++) {
        let pos = rect.map.positionAt(row, rect.left, rect.table);
        if (row == rect.top)
          pos += cellNode.nodeSize;
        for (let col = rect.left, i2 = 0; col < rect.right; col++, i2++) {
          if (col == rect.left && row == rect.top)
            continue;
          tr2.insert(
            lastCell = tr2.mapping.map(pos + rect.tableStart, 1),
            getCellType({ node: cellNode, row, col }).createAndFill(attrs7[i2])
          );
        }
      }
      tr2.setNodeMarkup(
        cellPos,
        getCellType({ node: cellNode, row: rect.top, col: rect.left }),
        attrs7[0]
      );
      if (sel instanceof CellSelection)
        tr2.setSelection(
          new CellSelection(
            tr2.doc.resolve(sel.$anchorCell.pos),
            lastCell ? tr2.doc.resolve(lastCell) : void 0
          )
        );
      dispatch(tr2);
    }
    return true;
  };
}
__name(splitCellWithType, "splitCellWithType");
function setCellAttr(name2, value3) {
  return function(state, dispatch) {
    if (!isInTable(state))
      return false;
    const $cell = selectionCell(state);
    if ($cell.nodeAfter.attrs[name2] === value3)
      return false;
    if (dispatch) {
      const tr2 = state.tr;
      if (state.selection instanceof CellSelection)
        state.selection.forEachCell((node3, pos) => {
          if (node3.attrs[name2] !== value3)
            tr2.setNodeMarkup(pos, null, {
              ...node3.attrs,
              [name2]: value3
            });
        });
      else
        tr2.setNodeMarkup($cell.pos, null, {
          ...$cell.nodeAfter.attrs,
          [name2]: value3
        });
      dispatch(tr2);
    }
    return true;
  };
}
__name(setCellAttr, "setCellAttr");
function deprecated_toggleHeader(type) {
  return function(state, dispatch) {
    if (!isInTable(state))
      return false;
    if (dispatch) {
      const types = tableNodeTypes(state.schema);
      const rect = selectedRect(state), tr2 = state.tr;
      const cells = rect.map.cellsInRect(
        type == "column" ? {
          left: rect.left,
          top: 0,
          right: rect.right,
          bottom: rect.map.height
        } : type == "row" ? {
          left: 0,
          top: rect.top,
          right: rect.map.width,
          bottom: rect.bottom
        } : rect
      );
      const nodes = cells.map((pos) => rect.table.nodeAt(pos));
      for (let i2 = 0; i2 < cells.length; i2++)
        if (nodes[i2].type == types.header_cell)
          tr2.setNodeMarkup(
            rect.tableStart + cells[i2],
            types.cell,
            nodes[i2].attrs
          );
      if (tr2.steps.length == 0)
        for (let i2 = 0; i2 < cells.length; i2++)
          tr2.setNodeMarkup(
            rect.tableStart + cells[i2],
            types.header_cell,
            nodes[i2].attrs
          );
      dispatch(tr2);
    }
    return true;
  };
}
__name(deprecated_toggleHeader, "deprecated_toggleHeader");
function isHeaderEnabledByType(type, rect, types) {
  const cellPositions = rect.map.cellsInRect({
    left: 0,
    top: 0,
    right: type == "row" ? rect.map.width : 1,
    bottom: type == "column" ? rect.map.height : 1
  });
  for (let i2 = 0; i2 < cellPositions.length; i2++) {
    const cell = rect.table.nodeAt(cellPositions[i2]);
    if (cell && cell.type !== types.header_cell) {
      return false;
    }
  }
  return true;
}
__name(isHeaderEnabledByType, "isHeaderEnabledByType");
function toggleHeader(type, options5) {
  options5 = options5 || { useDeprecatedLogic: false };
  if (options5.useDeprecatedLogic)
    return deprecated_toggleHeader(type);
  return function(state, dispatch) {
    if (!isInTable(state))
      return false;
    if (dispatch) {
      const types = tableNodeTypes(state.schema);
      const rect = selectedRect(state), tr2 = state.tr;
      const isHeaderRowEnabled = isHeaderEnabledByType("row", rect, types);
      const isHeaderColumnEnabled = isHeaderEnabledByType(
        "column",
        rect,
        types
      );
      const isHeaderEnabled = type === "column" ? isHeaderRowEnabled : type === "row" ? isHeaderColumnEnabled : false;
      const selectionStartsAt = isHeaderEnabled ? 1 : 0;
      const cellsRect = type == "column" ? {
        left: 0,
        top: selectionStartsAt,
        right: 1,
        bottom: rect.map.height
      } : type == "row" ? {
        left: selectionStartsAt,
        top: 0,
        right: rect.map.width,
        bottom: 1
      } : rect;
      const newType = type == "column" ? isHeaderColumnEnabled ? types.cell : types.header_cell : type == "row" ? isHeaderRowEnabled ? types.cell : types.header_cell : types.cell;
      rect.map.cellsInRect(cellsRect).forEach((relativeCellPos) => {
        const cellPos = relativeCellPos + rect.tableStart;
        const cell = tr2.doc.nodeAt(cellPos);
        if (cell) {
          tr2.setNodeMarkup(cellPos, newType, cell.attrs);
        }
      });
      dispatch(tr2);
    }
    return true;
  };
}
__name(toggleHeader, "toggleHeader");
var toggleHeaderRow = toggleHeader("row", {
  useDeprecatedLogic: true
});
var toggleHeaderColumn = toggleHeader("column", {
  useDeprecatedLogic: true
});
var toggleHeaderCell = toggleHeader("cell", {
  useDeprecatedLogic: true
});
function findNextCell($cell, dir) {
  if (dir < 0) {
    const before = $cell.nodeBefore;
    if (before)
      return $cell.pos - before.nodeSize;
    for (let row = $cell.index(-1) - 1, rowEnd = $cell.before(); row >= 0; row--) {
      const rowNode = $cell.node(-1).child(row);
      const lastChild = rowNode.lastChild;
      if (lastChild) {
        return rowEnd - 1 - lastChild.nodeSize;
      }
      rowEnd -= rowNode.nodeSize;
    }
  } else {
    if ($cell.index() < $cell.parent.childCount - 1) {
      return $cell.pos + $cell.nodeAfter.nodeSize;
    }
    const table2 = $cell.node(-1);
    for (let row = $cell.indexAfter(-1), rowStart = $cell.after(); row < table2.childCount; row++) {
      const rowNode = table2.child(row);
      if (rowNode.childCount)
        return rowStart + 1;
      rowStart += rowNode.nodeSize;
    }
  }
  return null;
}
__name(findNextCell, "findNextCell");
function goToNextCell(direction) {
  return function(state, dispatch) {
    if (!isInTable(state))
      return false;
    const cell = findNextCell(selectionCell(state), direction);
    if (cell == null)
      return false;
    if (dispatch) {
      const $cell = state.doc.resolve(cell);
      dispatch(
        state.tr.setSelection(TextSelection.between($cell, moveCellForward($cell))).scrollIntoView()
      );
    }
    return true;
  };
}
__name(goToNextCell, "goToNextCell");
function deleteTable(state, dispatch) {
  const $pos = state.selection.$anchor;
  for (let d2 = $pos.depth; d2 > 0; d2--) {
    const node3 = $pos.node(d2);
    if (node3.type.spec.tableRole == "table") {
      if (dispatch)
        dispatch(
          state.tr.delete($pos.before(d2), $pos.after(d2)).scrollIntoView()
        );
      return true;
    }
  }
  return false;
}
__name(deleteTable, "deleteTable");
function deleteCellSelection(state, dispatch) {
  const sel = state.selection;
  if (!(sel instanceof CellSelection))
    return false;
  if (dispatch) {
    const tr2 = state.tr;
    const baseContent = tableNodeTypes(state.schema).cell.createAndFill().content;
    sel.forEachCell((cell, pos) => {
      if (!cell.content.eq(baseContent))
        tr2.replace(
          tr2.mapping.map(pos + 1),
          tr2.mapping.map(pos + cell.nodeSize - 1),
          new Slice(baseContent, 0, 0)
        );
    });
    if (tr2.docChanged)
      dispatch(tr2);
  }
  return true;
}
__name(deleteCellSelection, "deleteCellSelection");
function pastedCells(slice2) {
  if (!slice2.size)
    return null;
  let { content: content3, openStart, openEnd } = slice2;
  while (content3.childCount == 1 && (openStart > 0 && openEnd > 0 || content3.child(0).type.spec.tableRole == "table")) {
    openStart--;
    openEnd--;
    content3 = content3.child(0).content;
  }
  const first2 = content3.child(0);
  const role = first2.type.spec.tableRole;
  const schema2 = first2.type.schema, rows = [];
  if (role == "row") {
    for (let i2 = 0; i2 < content3.childCount; i2++) {
      let cells = content3.child(i2).content;
      const left = i2 ? 0 : Math.max(0, openStart - 1);
      const right = i2 < content3.childCount - 1 ? 0 : Math.max(0, openEnd - 1);
      if (left || right)
        cells = fitSlice(
          tableNodeTypes(schema2).row,
          new Slice(cells, left, right)
        ).content;
      rows.push(cells);
    }
  } else if (role == "cell" || role == "header_cell") {
    rows.push(
      openStart || openEnd ? fitSlice(
        tableNodeTypes(schema2).row,
        new Slice(content3, openStart, openEnd)
      ).content : content3
    );
  } else {
    return null;
  }
  return ensureRectangular(schema2, rows);
}
__name(pastedCells, "pastedCells");
function ensureRectangular(schema2, rows) {
  const widths = [];
  for (let i2 = 0; i2 < rows.length; i2++) {
    const row = rows[i2];
    for (let j2 = row.childCount - 1; j2 >= 0; j2--) {
      const { rowspan, colspan } = row.child(j2).attrs;
      for (let r2 = i2; r2 < i2 + rowspan; r2++)
        widths[r2] = (widths[r2] || 0) + colspan;
    }
  }
  let width2 = 0;
  for (let r2 = 0; r2 < widths.length; r2++)
    width2 = Math.max(width2, widths[r2]);
  for (let r2 = 0; r2 < widths.length; r2++) {
    if (r2 >= rows.length)
      rows.push(Fragment.empty);
    if (widths[r2] < width2) {
      const empty2 = tableNodeTypes(schema2).cell.createAndFill();
      const cells = [];
      for (let i2 = widths[r2]; i2 < width2; i2++) {
        cells.push(empty2);
      }
      rows[r2] = rows[r2].append(Fragment.from(cells));
    }
  }
  return { height: rows.length, width: width2, rows };
}
__name(ensureRectangular, "ensureRectangular");
function fitSlice(nodeType, slice2) {
  const node3 = nodeType.createAndFill();
  const tr2 = new Transform(node3).replace(0, node3.content.size, slice2);
  return tr2.doc;
}
__name(fitSlice, "fitSlice");
function clipCells({ width: width2, height, rows }, newWidth, newHeight) {
  if (width2 != newWidth) {
    const added = [];
    const newRows = [];
    for (let row = 0; row < rows.length; row++) {
      const frag = rows[row], cells = [];
      for (let col = added[row] || 0, i2 = 0; col < newWidth; i2++) {
        let cell = frag.child(i2 % frag.childCount);
        if (col + cell.attrs.colspan > newWidth)
          cell = cell.type.createChecked(
            removeColSpan(
              cell.attrs,
              cell.attrs.colspan,
              col + cell.attrs.colspan - newWidth
            ),
            cell.content
          );
        cells.push(cell);
        col += cell.attrs.colspan;
        for (let j2 = 1; j2 < cell.attrs.rowspan; j2++)
          added[row + j2] = (added[row + j2] || 0) + cell.attrs.colspan;
      }
      newRows.push(Fragment.from(cells));
    }
    rows = newRows;
    width2 = newWidth;
  }
  if (height != newHeight) {
    const newRows = [];
    for (let row = 0, i2 = 0; row < newHeight; row++, i2++) {
      const cells = [], source = rows[i2 % height];
      for (let j2 = 0; j2 < source.childCount; j2++) {
        let cell = source.child(j2);
        if (row + cell.attrs.rowspan > newHeight)
          cell = cell.type.create(
            {
              ...cell.attrs,
              rowspan: Math.max(1, newHeight - cell.attrs.rowspan)
            },
            cell.content
          );
        cells.push(cell);
      }
      newRows.push(Fragment.from(cells));
    }
    rows = newRows;
    height = newHeight;
  }
  return { width: width2, height, rows };
}
__name(clipCells, "clipCells");
function growTable(tr2, map3, table2, start2, width2, height, mapFrom) {
  const schema2 = tr2.doc.type.schema;
  const types = tableNodeTypes(schema2);
  let empty2;
  let emptyHead;
  if (width2 > map3.width) {
    for (let row = 0, rowEnd = 0; row < map3.height; row++) {
      const rowNode = table2.child(row);
      rowEnd += rowNode.nodeSize;
      const cells = [];
      let add3;
      if (rowNode.lastChild == null || rowNode.lastChild.type == types.cell)
        add3 = empty2 || (empty2 = types.cell.createAndFill());
      else
        add3 = emptyHead || (emptyHead = types.header_cell.createAndFill());
      for (let i2 = map3.width; i2 < width2; i2++)
        cells.push(add3);
      tr2.insert(tr2.mapping.slice(mapFrom).map(rowEnd - 1 + start2), cells);
    }
  }
  if (height > map3.height) {
    const cells = [];
    for (let i2 = 0, start22 = (map3.height - 1) * map3.width; i2 < Math.max(map3.width, width2); i2++) {
      const header3 = i2 >= map3.width ? false : table2.nodeAt(map3.map[start22 + i2]).type == types.header_cell;
      cells.push(
        header3 ? emptyHead || (emptyHead = types.header_cell.createAndFill()) : empty2 || (empty2 = types.cell.createAndFill())
      );
    }
    const emptyRow = types.row.create(null, Fragment.from(cells)), rows = [];
    for (let i2 = map3.height; i2 < height; i2++)
      rows.push(emptyRow);
    tr2.insert(tr2.mapping.slice(mapFrom).map(start2 + table2.nodeSize - 2), rows);
  }
  return !!(empty2 || emptyHead);
}
__name(growTable, "growTable");
function isolateHorizontal(tr2, map3, table2, start2, left, right, top, mapFrom) {
  if (top == 0 || top == map3.height)
    return false;
  let found2 = false;
  for (let col = left; col < right; col++) {
    const index2 = top * map3.width + col, pos = map3.map[index2];
    if (map3.map[index2 - map3.width] == pos) {
      found2 = true;
      const cell = table2.nodeAt(pos);
      const { top: cellTop, left: cellLeft } = map3.findCell(pos);
      tr2.setNodeMarkup(tr2.mapping.slice(mapFrom).map(pos + start2), null, {
        ...cell.attrs,
        rowspan: top - cellTop
      });
      tr2.insert(
        tr2.mapping.slice(mapFrom).map(map3.positionAt(top, cellLeft, table2)),
        cell.type.createAndFill({
          ...cell.attrs,
          rowspan: cellTop + cell.attrs.rowspan - top
        })
      );
      col += cell.attrs.colspan - 1;
    }
  }
  return found2;
}
__name(isolateHorizontal, "isolateHorizontal");
function isolateVertical(tr2, map3, table2, start2, top, bottom, left, mapFrom) {
  if (left == 0 || left == map3.width)
    return false;
  let found2 = false;
  for (let row = top; row < bottom; row++) {
    const index2 = row * map3.width + left, pos = map3.map[index2];
    if (map3.map[index2 - 1] == pos) {
      found2 = true;
      const cell = table2.nodeAt(pos);
      const cellLeft = map3.colCount(pos);
      const updatePos = tr2.mapping.slice(mapFrom).map(pos + start2);
      tr2.setNodeMarkup(
        updatePos,
        null,
        removeColSpan(
          cell.attrs,
          left - cellLeft,
          cell.attrs.colspan - (left - cellLeft)
        )
      );
      tr2.insert(
        updatePos + cell.nodeSize,
        cell.type.createAndFill(
          removeColSpan(cell.attrs, 0, left - cellLeft)
        )
      );
      row += cell.attrs.rowspan - 1;
    }
  }
  return found2;
}
__name(isolateVertical, "isolateVertical");
function insertCells(state, dispatch, tableStart, rect, cells) {
  let table2 = tableStart ? state.doc.nodeAt(tableStart - 1) : state.doc;
  if (!table2) {
    throw new Error("No table found");
  }
  let map3 = TableMap.get(table2);
  const { top, left } = rect;
  const right = left + cells.width, bottom = top + cells.height;
  const tr2 = state.tr;
  let mapFrom = 0;
  function recomp() {
    table2 = tableStart ? tr2.doc.nodeAt(tableStart - 1) : tr2.doc;
    if (!table2) {
      throw new Error("No table found");
    }
    map3 = TableMap.get(table2);
    mapFrom = tr2.mapping.maps.length;
  }
  __name(recomp, "recomp");
  if (growTable(tr2, map3, table2, tableStart, right, bottom, mapFrom))
    recomp();
  if (isolateHorizontal(tr2, map3, table2, tableStart, left, right, top, mapFrom))
    recomp();
  if (isolateHorizontal(tr2, map3, table2, tableStart, left, right, bottom, mapFrom))
    recomp();
  if (isolateVertical(tr2, map3, table2, tableStart, top, bottom, left, mapFrom))
    recomp();
  if (isolateVertical(tr2, map3, table2, tableStart, top, bottom, right, mapFrom))
    recomp();
  for (let row = top; row < bottom; row++) {
    const from2 = map3.positionAt(row, left, table2), to = map3.positionAt(row, right, table2);
    tr2.replace(
      tr2.mapping.slice(mapFrom).map(from2 + tableStart),
      tr2.mapping.slice(mapFrom).map(to + tableStart),
      new Slice(cells.rows[row - top], 0, 0)
    );
  }
  recomp();
  tr2.setSelection(
    new CellSelection(
      tr2.doc.resolve(tableStart + map3.positionAt(top, left, table2)),
      tr2.doc.resolve(tableStart + map3.positionAt(bottom - 1, right - 1, table2))
    )
  );
  dispatch(tr2);
}
__name(insertCells, "insertCells");
var handleKeyDown$1 = keydownHandler({
  ArrowLeft: arrow$1("horiz", -1),
  ArrowRight: arrow$1("horiz", 1),
  ArrowUp: arrow$1("vert", -1),
  ArrowDown: arrow$1("vert", 1),
  "Shift-ArrowLeft": shiftArrow("horiz", -1),
  "Shift-ArrowRight": shiftArrow("horiz", 1),
  "Shift-ArrowUp": shiftArrow("vert", -1),
  "Shift-ArrowDown": shiftArrow("vert", 1),
  Backspace: deleteCellSelection,
  "Mod-Backspace": deleteCellSelection,
  Delete: deleteCellSelection,
  "Mod-Delete": deleteCellSelection
});
function maybeSetSelection(state, dispatch, selection) {
  if (selection.eq(state.selection))
    return false;
  if (dispatch)
    dispatch(state.tr.setSelection(selection).scrollIntoView());
  return true;
}
__name(maybeSetSelection, "maybeSetSelection");
function arrow$1(axis, dir) {
  return (state, dispatch, view) => {
    if (!view)
      return false;
    const sel = state.selection;
    if (sel instanceof CellSelection) {
      return maybeSetSelection(
        state,
        dispatch,
        Selection.near(sel.$headCell, dir)
      );
    }
    if (axis != "horiz" && !sel.empty)
      return false;
    const end = atEndOfCell(view, axis, dir);
    if (end == null)
      return false;
    if (axis == "horiz") {
      return maybeSetSelection(
        state,
        dispatch,
        Selection.near(state.doc.resolve(sel.head + dir), dir)
      );
    } else {
      const $cell = state.doc.resolve(end);
      const $next = nextCell($cell, axis, dir);
      let newSel;
      if ($next)
        newSel = Selection.near($next, 1);
      else if (dir < 0)
        newSel = Selection.near(state.doc.resolve($cell.before(-1)), -1);
      else
        newSel = Selection.near(state.doc.resolve($cell.after(-1)), 1);
      return maybeSetSelection(state, dispatch, newSel);
    }
  };
}
__name(arrow$1, "arrow$1");
function shiftArrow(axis, dir) {
  return (state, dispatch, view) => {
    if (!view)
      return false;
    const sel = state.selection;
    let cellSel;
    if (sel instanceof CellSelection) {
      cellSel = sel;
    } else {
      const end = atEndOfCell(view, axis, dir);
      if (end == null)
        return false;
      cellSel = new CellSelection(state.doc.resolve(end));
    }
    const $head = nextCell(cellSel.$headCell, axis, dir);
    if (!$head)
      return false;
    return maybeSetSelection(
      state,
      dispatch,
      new CellSelection(cellSel.$anchorCell, $head)
    );
  };
}
__name(shiftArrow, "shiftArrow");
function handleTripleClick(view, pos) {
  const doc2 = view.state.doc, $cell = cellAround(doc2.resolve(pos));
  if (!$cell)
    return false;
  view.dispatch(view.state.tr.setSelection(new CellSelection($cell)));
  return true;
}
__name(handleTripleClick, "handleTripleClick");
function handlePaste(view, _2, slice2) {
  if (!isInTable(view.state))
    return false;
  let cells = pastedCells(slice2);
  const sel = view.state.selection;
  if (sel instanceof CellSelection) {
    if (!cells)
      cells = {
        width: 1,
        height: 1,
        rows: [
          Fragment.from(
            fitSlice(tableNodeTypes(view.state.schema).cell, slice2)
          )
        ]
      };
    const table2 = sel.$anchorCell.node(-1);
    const start2 = sel.$anchorCell.start(-1);
    const rect = TableMap.get(table2).rectBetween(
      sel.$anchorCell.pos - start2,
      sel.$headCell.pos - start2
    );
    cells = clipCells(cells, rect.right - rect.left, rect.bottom - rect.top);
    insertCells(view.state, view.dispatch, start2, rect, cells);
    return true;
  } else if (cells) {
    const $cell = selectionCell(view.state);
    const start2 = $cell.start(-1);
    insertCells(
      view.state,
      view.dispatch,
      start2,
      TableMap.get($cell.node(-1)).findCell($cell.pos - start2),
      cells
    );
    return true;
  } else {
    return false;
  }
}
__name(handlePaste, "handlePaste");
function handleMouseDown(view, startEvent) {
  var _a2;
  if (startEvent.ctrlKey || startEvent.metaKey)
    return;
  const startDOMCell = domInCell(view, startEvent.target);
  let $anchor;
  if (startEvent.shiftKey && view.state.selection instanceof CellSelection) {
    setCellSelection(view.state.selection.$anchorCell, startEvent);
    startEvent.preventDefault();
  } else if (startEvent.shiftKey && startDOMCell && ($anchor = cellAround(view.state.selection.$anchor)) != null && ((_a2 = cellUnderMouse(view, startEvent)) == null ? void 0 : _a2.pos) != $anchor.pos) {
    setCellSelection($anchor, startEvent);
    startEvent.preventDefault();
  } else if (!startDOMCell) {
    return;
  }
  function setCellSelection($anchor2, event) {
    let $head = cellUnderMouse(view, event);
    const starting = tableEditingKey.getState(view.state) == null;
    if (!$head || !inSameTable($anchor2, $head)) {
      if (starting)
        $head = $anchor2;
      else
        return;
    }
    const selection = new CellSelection($anchor2, $head);
    if (starting || !view.state.selection.eq(selection)) {
      const tr2 = view.state.tr.setSelection(selection);
      if (starting)
        tr2.setMeta(tableEditingKey, $anchor2.pos);
      view.dispatch(tr2);
    }
  }
  __name(setCellSelection, "setCellSelection");
  function stop2() {
    view.root.removeEventListener("mouseup", stop2);
    view.root.removeEventListener("dragstart", stop2);
    view.root.removeEventListener("mousemove", move);
    if (tableEditingKey.getState(view.state) != null)
      view.dispatch(view.state.tr.setMeta(tableEditingKey, -1));
  }
  __name(stop2, "stop");
  function move(_event) {
    const event = _event;
    const anchor = tableEditingKey.getState(view.state);
    let $anchor2;
    if (anchor != null) {
      $anchor2 = view.state.doc.resolve(anchor);
    } else if (domInCell(view, event.target) != startDOMCell) {
      $anchor2 = cellUnderMouse(view, startEvent);
      if (!$anchor2)
        return stop2();
    }
    if ($anchor2)
      setCellSelection($anchor2, event);
  }
  __name(move, "move");
  view.root.addEventListener("mouseup", stop2);
  view.root.addEventListener("dragstart", stop2);
  view.root.addEventListener("mousemove", move);
}
__name(handleMouseDown, "handleMouseDown");
function atEndOfCell(view, axis, dir) {
  if (!(view.state.selection instanceof TextSelection))
    return null;
  const { $head } = view.state.selection;
  for (let d2 = $head.depth - 1; d2 >= 0; d2--) {
    const parent = $head.node(d2), index2 = dir < 0 ? $head.index(d2) : $head.indexAfter(d2);
    if (index2 != (dir < 0 ? 0 : parent.childCount))
      return null;
    if (parent.type.spec.tableRole == "cell" || parent.type.spec.tableRole == "header_cell") {
      const cellPos = $head.before(d2);
      const dirStr = axis == "vert" ? dir > 0 ? "down" : "up" : dir > 0 ? "right" : "left";
      return view.endOfTextblock(dirStr) ? cellPos : null;
    }
  }
  return null;
}
__name(atEndOfCell, "atEndOfCell");
function domInCell(view, dom) {
  for (; dom && dom != view.dom; dom = dom.parentNode) {
    if (dom.nodeName == "TD" || dom.nodeName == "TH") {
      return dom;
    }
  }
  return null;
}
__name(domInCell, "domInCell");
function cellUnderMouse(view, event) {
  const mousePos = view.posAtCoords({
    left: event.clientX,
    top: event.clientY
  });
  if (!mousePos)
    return null;
  return mousePos ? cellAround(view.state.doc.resolve(mousePos.pos)) : null;
}
__name(cellUnderMouse, "cellUnderMouse");
var TableView$1 = class TableView2 {
  static {
    __name(this, "TableView");
  }
  constructor(node3, defaultCellMinWidth) {
    this.node = node3;
    this.defaultCellMinWidth = defaultCellMinWidth;
    this.dom = document.createElement("div");
    this.dom.className = "tableWrapper";
    this.table = this.dom.appendChild(document.createElement("table"));
    this.table.style.setProperty(
      "--default-cell-min-width",
      `${defaultCellMinWidth}px`
    );
    this.colgroup = this.table.appendChild(document.createElement("colgroup"));
    updateColumnsOnResize(node3, this.colgroup, this.table, defaultCellMinWidth);
    this.contentDOM = this.table.appendChild(document.createElement("tbody"));
  }
  update(node3) {
    if (node3.type != this.node.type)
      return false;
    this.node = node3;
    updateColumnsOnResize(
      node3,
      this.colgroup,
      this.table,
      this.defaultCellMinWidth
    );
    return true;
  }
  ignoreMutation(record2) {
    return record2.type == "attributes" && (record2.target == this.table || this.colgroup.contains(record2.target));
  }
};
function updateColumnsOnResize(node3, colgroup, table2, defaultCellMinWidth, overrideCol, overrideValue) {
  var _a2;
  let totalWidth = 0;
  let fixedWidth = true;
  let nextDOM = colgroup.firstChild;
  const row = node3.firstChild;
  if (!row)
    return;
  for (let i2 = 0, col = 0; i2 < row.childCount; i2++) {
    const { colspan, colwidth } = row.child(i2).attrs;
    for (let j2 = 0; j2 < colspan; j2++, col++) {
      const hasWidth = overrideCol == col ? overrideValue : colwidth && colwidth[j2];
      const cssWidth = hasWidth ? hasWidth + "px" : "";
      totalWidth += hasWidth || defaultCellMinWidth;
      if (!hasWidth)
        fixedWidth = false;
      if (!nextDOM) {
        const col2 = document.createElement("col");
        col2.style.width = cssWidth;
        colgroup.appendChild(col2);
      } else {
        if (nextDOM.style.width != cssWidth) {
          nextDOM.style.width = cssWidth;
        }
        nextDOM = nextDOM.nextSibling;
      }
    }
  }
  while (nextDOM) {
    const after = nextDOM.nextSibling;
    (_a2 = nextDOM.parentNode) == null ? void 0 : _a2.removeChild(nextDOM);
    nextDOM = after;
  }
  if (fixedWidth) {
    table2.style.width = totalWidth + "px";
    table2.style.minWidth = "";
  } else {
    table2.style.width = "";
    table2.style.minWidth = totalWidth + "px";
  }
}
__name(updateColumnsOnResize, "updateColumnsOnResize");
var columnResizingPluginKey = new PluginKey(
  "tableColumnResizing"
);
function columnResizing({
  handleWidth = 5,
  cellMinWidth = 25,
  defaultCellMinWidth = 100,
  View = TableView$1,
  lastColumnResizable = true
} = {}) {
  const plugin = new Plugin({
    key: columnResizingPluginKey,
    state: {
      init(_2, state) {
        var _a2, _b;
        const nodeViews = (_b = (_a2 = plugin.spec) == null ? void 0 : _a2.props) == null ? void 0 : _b.nodeViews;
        const tableName = tableNodeTypes(state.schema).table.name;
        if (View && nodeViews) {
          nodeViews[tableName] = (node3, view) => {
            return new View(node3, defaultCellMinWidth, view);
          };
        }
        return new ResizeState(-1, false);
      },
      apply(tr2, prev2) {
        return prev2.apply(tr2);
      }
    },
    props: {
      attributes: /* @__PURE__ */ __name((state) => {
        const pluginState = columnResizingPluginKey.getState(state);
        return pluginState && pluginState.activeHandle > -1 ? { class: "resize-cursor" } : {};
      }, "attributes"),
      handleDOMEvents: {
        mousemove: /* @__PURE__ */ __name((view, event) => {
          handleMouseMove(view, event, handleWidth, lastColumnResizable);
        }, "mousemove"),
        mouseleave: /* @__PURE__ */ __name((view) => {
          handleMouseLeave(view);
        }, "mouseleave"),
        mousedown: /* @__PURE__ */ __name((view, event) => {
          handleMouseDown2(view, event, cellMinWidth, defaultCellMinWidth);
        }, "mousedown")
      },
      decorations: /* @__PURE__ */ __name((state) => {
        const pluginState = columnResizingPluginKey.getState(state);
        if (pluginState && pluginState.activeHandle > -1) {
          return handleDecorations(state, pluginState.activeHandle);
        }
      }, "decorations"),
      nodeViews: {}
    }
  });
  return plugin;
}
__name(columnResizing, "columnResizing");
var ResizeState = class _ResizeState {
  static {
    __name(this, "_ResizeState");
  }
  constructor(activeHandle, dragging) {
    this.activeHandle = activeHandle;
    this.dragging = dragging;
  }
  apply(tr2) {
    const state = this;
    const action = tr2.getMeta(columnResizingPluginKey);
    if (action && action.setHandle != null)
      return new _ResizeState(action.setHandle, false);
    if (action && action.setDragging !== void 0)
      return new _ResizeState(state.activeHandle, action.setDragging);
    if (state.activeHandle > -1 && tr2.docChanged) {
      let handle = tr2.mapping.map(state.activeHandle, -1);
      if (!pointsAtCell(tr2.doc.resolve(handle))) {
        handle = -1;
      }
      return new _ResizeState(handle, state.dragging);
    }
    return state;
  }
};
function handleMouseMove(view, event, handleWidth, lastColumnResizable) {
  const pluginState = columnResizingPluginKey.getState(view.state);
  if (!pluginState)
    return;
  if (!pluginState.dragging) {
    const target2 = domCellAround(event.target);
    let cell = -1;
    if (target2) {
      const { left, right } = target2.getBoundingClientRect();
      if (event.clientX - left <= handleWidth)
        cell = edgeCell(view, event, "left", handleWidth);
      else if (right - event.clientX <= handleWidth)
        cell = edgeCell(view, event, "right", handleWidth);
    }
    if (cell != pluginState.activeHandle) {
      if (!lastColumnResizable && cell !== -1) {
        const $cell = view.state.doc.resolve(cell);
        const table2 = $cell.node(-1);
        const map3 = TableMap.get(table2);
        const tableStart = $cell.start(-1);
        const col = map3.colCount($cell.pos - tableStart) + $cell.nodeAfter.attrs.colspan - 1;
        if (col == map3.width - 1) {
          return;
        }
      }
      updateHandle(view, cell);
    }
  }
}
__name(handleMouseMove, "handleMouseMove");
function handleMouseLeave(view) {
  const pluginState = columnResizingPluginKey.getState(view.state);
  if (pluginState && pluginState.activeHandle > -1 && !pluginState.dragging)
    updateHandle(view, -1);
}
__name(handleMouseLeave, "handleMouseLeave");
function handleMouseDown2(view, event, cellMinWidth, defaultCellMinWidth) {
  var _a2;
  const win = (_a2 = view.dom.ownerDocument.defaultView) != null ? _a2 : window;
  const pluginState = columnResizingPluginKey.getState(view.state);
  if (!pluginState || pluginState.activeHandle == -1 || pluginState.dragging)
    return false;
  const cell = view.state.doc.nodeAt(pluginState.activeHandle);
  const width2 = currentColWidth(view, pluginState.activeHandle, cell.attrs);
  view.dispatch(
    view.state.tr.setMeta(columnResizingPluginKey, {
      setDragging: { startX: event.clientX, startWidth: width2 }
    })
  );
  function finish(event2) {
    win.removeEventListener("mouseup", finish);
    win.removeEventListener("mousemove", move);
    const pluginState2 = columnResizingPluginKey.getState(view.state);
    if (pluginState2 == null ? void 0 : pluginState2.dragging) {
      updateColumnWidth(
        view,
        pluginState2.activeHandle,
        draggedWidth(pluginState2.dragging, event2, cellMinWidth)
      );
      view.dispatch(
        view.state.tr.setMeta(columnResizingPluginKey, { setDragging: null })
      );
    }
  }
  __name(finish, "finish");
  function move(event2) {
    if (!event2.which)
      return finish(event2);
    const pluginState2 = columnResizingPluginKey.getState(view.state);
    if (!pluginState2)
      return;
    if (pluginState2.dragging) {
      const dragged = draggedWidth(pluginState2.dragging, event2, cellMinWidth);
      displayColumnWidth(
        view,
        pluginState2.activeHandle,
        dragged,
        defaultCellMinWidth
      );
    }
  }
  __name(move, "move");
  displayColumnWidth(
    view,
    pluginState.activeHandle,
    width2,
    defaultCellMinWidth
  );
  win.addEventListener("mouseup", finish);
  win.addEventListener("mousemove", move);
  event.preventDefault();
  return true;
}
__name(handleMouseDown2, "handleMouseDown2");
function currentColWidth(view, cellPos, { colspan, colwidth }) {
  const width2 = colwidth && colwidth[colwidth.length - 1];
  if (width2)
    return width2;
  const dom = view.domAtPos(cellPos);
  const node3 = dom.node.childNodes[dom.offset];
  let domWidth = node3.offsetWidth, parts2 = colspan;
  if (colwidth) {
    for (let i2 = 0; i2 < colspan; i2++)
      if (colwidth[i2]) {
        domWidth -= colwidth[i2];
        parts2--;
      }
  }
  return domWidth / parts2;
}
__name(currentColWidth, "currentColWidth");
function domCellAround(target2) {
  while (target2 && target2.nodeName != "TD" && target2.nodeName != "TH")
    target2 = target2.classList && target2.classList.contains("ProseMirror") ? null : target2.parentNode;
  return target2;
}
__name(domCellAround, "domCellAround");
function edgeCell(view, event, side, handleWidth) {
  const offset = side == "right" ? -handleWidth : handleWidth;
  const found2 = view.posAtCoords({
    left: event.clientX + offset,
    top: event.clientY
  });
  if (!found2)
    return -1;
  const { pos } = found2;
  const $cell = cellAround(view.state.doc.resolve(pos));
  if (!$cell)
    return -1;
  if (side == "right")
    return $cell.pos;
  const map3 = TableMap.get($cell.node(-1)), start2 = $cell.start(-1);
  const index2 = map3.map.indexOf($cell.pos - start2);
  return index2 % map3.width == 0 ? -1 : start2 + map3.map[index2 - 1];
}
__name(edgeCell, "edgeCell");
function draggedWidth(dragging, event, resizeMinWidth) {
  const offset = event.clientX - dragging.startX;
  return Math.max(resizeMinWidth, dragging.startWidth + offset);
}
__name(draggedWidth, "draggedWidth");
function updateHandle(view, value3) {
  view.dispatch(
    view.state.tr.setMeta(columnResizingPluginKey, { setHandle: value3 })
  );
}
__name(updateHandle, "updateHandle");
function updateColumnWidth(view, cell, width2) {
  const $cell = view.state.doc.resolve(cell);
  const table2 = $cell.node(-1), map3 = TableMap.get(table2), start2 = $cell.start(-1);
  const col = map3.colCount($cell.pos - start2) + $cell.nodeAfter.attrs.colspan - 1;
  const tr2 = view.state.tr;
  for (let row = 0; row < map3.height; row++) {
    const mapIndex = row * map3.width + col;
    if (row && map3.map[mapIndex] == map3.map[mapIndex - map3.width])
      continue;
    const pos = map3.map[mapIndex];
    const attrs7 = table2.nodeAt(pos).attrs;
    const index2 = attrs7.colspan == 1 ? 0 : col - map3.colCount(pos);
    if (attrs7.colwidth && attrs7.colwidth[index2] == width2)
      continue;
    const colwidth = attrs7.colwidth ? attrs7.colwidth.slice() : zeroes(attrs7.colspan);
    colwidth[index2] = width2;
    tr2.setNodeMarkup(start2 + pos, null, { ...attrs7, colwidth });
  }
  if (tr2.docChanged)
    view.dispatch(tr2);
}
__name(updateColumnWidth, "updateColumnWidth");
function displayColumnWidth(view, cell, width2, defaultCellMinWidth) {
  const $cell = view.state.doc.resolve(cell);
  const table2 = $cell.node(-1), start2 = $cell.start(-1);
  const col = TableMap.get(table2).colCount($cell.pos - start2) + $cell.nodeAfter.attrs.colspan - 1;
  let dom = view.domAtPos($cell.start(-1)).node;
  while (dom && dom.nodeName != "TABLE") {
    dom = dom.parentNode;
  }
  if (!dom)
    return;
  updateColumnsOnResize(
    table2,
    dom.firstChild,
    dom,
    defaultCellMinWidth,
    col,
    width2
  );
}
__name(displayColumnWidth, "displayColumnWidth");
function zeroes(n2) {
  return Array(n2).fill(0);
}
__name(zeroes, "zeroes");
function handleDecorations(state, cell) {
  var _a2;
  const decorations = [];
  const $cell = state.doc.resolve(cell);
  const table2 = $cell.node(-1);
  if (!table2) {
    return DecorationSet.empty;
  }
  const map3 = TableMap.get(table2);
  const start2 = $cell.start(-1);
  const col = map3.colCount($cell.pos - start2) + $cell.nodeAfter.attrs.colspan - 1;
  for (let row = 0; row < map3.height; row++) {
    const index2 = col + row * map3.width;
    if ((col == map3.width - 1 || map3.map[index2] != map3.map[index2 + 1]) && (row == 0 || map3.map[index2] != map3.map[index2 - map3.width])) {
      const cellPos = map3.map[index2];
      const pos = start2 + cellPos + table2.nodeAt(cellPos).nodeSize - 1;
      const dom = document.createElement("div");
      dom.className = "column-resize-handle";
      if ((_a2 = columnResizingPluginKey.getState(state)) == null ? void 0 : _a2.dragging) {
        decorations.push(
          Decoration.node(
            start2 + cellPos,
            start2 + cellPos + table2.nodeAt(cellPos).nodeSize,
            {
              class: "column-resize-dragging"
            }
          )
        );
      }
      decorations.push(Decoration.widget(pos, dom));
    }
  }
  return DecorationSet.create(state.doc, decorations);
}
__name(handleDecorations, "handleDecorations");
function tableEditing({
  allowTableNodeSelection = false
} = {}) {
  return new Plugin({
    key: tableEditingKey,
    // This piece of state is used to remember when a mouse-drag
    // cell-selection is happening, so that it can continue even as
    // transactions (which might move its anchor cell) come in.
    state: {
      init() {
        return null;
      },
      apply(tr2, cur) {
        const set3 = tr2.getMeta(tableEditingKey);
        if (set3 != null)
          return set3 == -1 ? null : set3;
        if (cur == null || !tr2.docChanged)
          return cur;
        const { deleted, pos } = tr2.mapping.mapResult(cur);
        return deleted ? null : pos;
      }
    },
    props: {
      decorations: drawCellSelection,
      handleDOMEvents: {
        mousedown: handleMouseDown
      },
      createSelectionBetween(view) {
        return tableEditingKey.getState(view.state) != null ? view.state.selection : null;
      },
      handleTripleClick,
      handleKeyDown: handleKeyDown$1,
      handlePaste
    },
    appendTransaction(_2, oldState, state) {
      return normalizeSelection(
        state,
        fixTables(state, oldState),
        allowTableNodeSelection
      );
    }
  });
}
__name(tableEditing, "tableEditing");
function getColStyleDeclaration(minWidth, width2) {
  if (width2) {
    return ["width", `${Math.max(width2, minWidth)}px`];
  }
  return ["min-width", `${minWidth}px`];
}
__name(getColStyleDeclaration, "getColStyleDeclaration");
function updateColumns(node3, colgroup, table2, cellMinWidth, overrideCol, overrideValue) {
  var _a2;
  let totalWidth = 0;
  let fixedWidth = true;
  let nextDOM = colgroup.firstChild;
  const row = node3.firstChild;
  if (row !== null) {
    for (let i2 = 0, col = 0; i2 < row.childCount; i2 += 1) {
      const { colspan, colwidth } = row.child(i2).attrs;
      for (let j2 = 0; j2 < colspan; j2 += 1, col += 1) {
        const hasWidth = overrideCol === col ? overrideValue : colwidth && colwidth[j2];
        const cssWidth = hasWidth ? `${hasWidth}px` : "";
        totalWidth += hasWidth || cellMinWidth;
        if (!hasWidth) {
          fixedWidth = false;
        }
        if (!nextDOM) {
          const colElement = document.createElement("col");
          const [propertyKey, propertyValue] = getColStyleDeclaration(cellMinWidth, hasWidth);
          colElement.style.setProperty(propertyKey, propertyValue);
          colgroup.appendChild(colElement);
        } else {
          if (nextDOM.style.width !== cssWidth) {
            const [propertyKey, propertyValue] = getColStyleDeclaration(cellMinWidth, hasWidth);
            nextDOM.style.setProperty(propertyKey, propertyValue);
          }
          nextDOM = nextDOM.nextSibling;
        }
      }
    }
  }
  while (nextDOM) {
    const after = nextDOM.nextSibling;
    (_a2 = nextDOM.parentNode) === null || _a2 === void 0 ? void 0 : _a2.removeChild(nextDOM);
    nextDOM = after;
  }
  if (fixedWidth) {
    table2.style.width = `${totalWidth}px`;
    table2.style.minWidth = "";
  } else {
    table2.style.width = "";
    table2.style.minWidth = `${totalWidth}px`;
  }
}
__name(updateColumns, "updateColumns");
class TableView {
  static {
    __name(this, "TableView");
  }
  constructor(node3, cellMinWidth) {
    this.node = node3;
    this.cellMinWidth = cellMinWidth;
    this.dom = document.createElement("div");
    this.dom.className = "tableWrapper";
    this.table = this.dom.appendChild(document.createElement("table"));
    this.colgroup = this.table.appendChild(document.createElement("colgroup"));
    updateColumns(node3, this.colgroup, this.table, cellMinWidth);
    this.contentDOM = this.table.appendChild(document.createElement("tbody"));
  }
  update(node3) {
    if (node3.type !== this.node.type) {
      return false;
    }
    this.node = node3;
    updateColumns(node3, this.colgroup, this.table, this.cellMinWidth);
    return true;
  }
  ignoreMutation(mutation) {
    return mutation.type === "attributes" && (mutation.target === this.table || this.colgroup.contains(mutation.target));
  }
}
function createColGroup(node3, cellMinWidth, overrideCol, overrideValue) {
  let totalWidth = 0;
  let fixedWidth = true;
  const cols = [];
  const row = node3.firstChild;
  if (!row) {
    return {};
  }
  for (let i2 = 0, col = 0; i2 < row.childCount; i2 += 1) {
    const { colspan, colwidth } = row.child(i2).attrs;
    for (let j2 = 0; j2 < colspan; j2 += 1, col += 1) {
      const hasWidth = overrideCol === col ? overrideValue : colwidth && colwidth[j2];
      totalWidth += hasWidth || cellMinWidth;
      if (!hasWidth) {
        fixedWidth = false;
      }
      const [property, value3] = getColStyleDeclaration(cellMinWidth, hasWidth);
      cols.push([
        "col",
        { style: `${property}: ${value3}` }
      ]);
    }
  }
  const tableWidth = fixedWidth ? `${totalWidth}px` : "";
  const tableMinWidth = fixedWidth ? "" : `${totalWidth}px`;
  const colgroup = ["colgroup", {}, ...cols];
  return { colgroup, tableWidth, tableMinWidth };
}
__name(createColGroup, "createColGroup");
function createCell(cellType, cellContent) {
  if (cellContent) {
    return cellType.createChecked(null, cellContent);
  }
  return cellType.createAndFill();
}
__name(createCell, "createCell");
function getTableNodeTypes(schema2) {
  if (schema2.cached.tableNodeTypes) {
    return schema2.cached.tableNodeTypes;
  }
  const roles = {};
  Object.keys(schema2.nodes).forEach((type) => {
    const nodeType = schema2.nodes[type];
    if (nodeType.spec.tableRole) {
      roles[nodeType.spec.tableRole] = nodeType;
    }
  });
  schema2.cached.tableNodeTypes = roles;
  return roles;
}
__name(getTableNodeTypes, "getTableNodeTypes");
function createTable(schema2, rowsCount, colsCount, withHeaderRow, cellContent) {
  const types = getTableNodeTypes(schema2);
  const headerCells = [];
  const cells = [];
  for (let index2 = 0; index2 < colsCount; index2 += 1) {
    const cell = createCell(types.cell, cellContent);
    if (cell) {
      cells.push(cell);
    }
    if (withHeaderRow) {
      const headerCell = createCell(types.header_cell, cellContent);
      if (headerCell) {
        headerCells.push(headerCell);
      }
    }
  }
  const rows = [];
  for (let index2 = 0; index2 < rowsCount; index2 += 1) {
    rows.push(types.row.createChecked(null, withHeaderRow && index2 === 0 ? headerCells : cells));
  }
  return types.table.createChecked(null, rows);
}
__name(createTable, "createTable");
function isCellSelection(value3) {
  return value3 instanceof CellSelection;
}
__name(isCellSelection, "isCellSelection");
const deleteTableWhenAllCellsSelected = /* @__PURE__ */ __name(({ editor }) => {
  const { selection } = editor.state;
  if (!isCellSelection(selection)) {
    return false;
  }
  let cellCount = 0;
  const table2 = findParentNodeClosestToPos(selection.ranges[0].$from, (node3) => {
    return node3.type.name === "table";
  });
  table2 === null || table2 === void 0 ? void 0 : table2.node.descendants((node3) => {
    if (node3.type.name === "table") {
      return false;
    }
    if (["tableCell", "tableHeader"].includes(node3.type.name)) {
      cellCount += 1;
    }
  });
  const allCellsSelected = cellCount === selection.ranges.length;
  if (!allCellsSelected) {
    return false;
  }
  editor.commands.deleteTable();
  return true;
}, "deleteTableWhenAllCellsSelected");
const Table$2 = Node$1.create({
  name: "table",
  // @ts-ignore
  addOptions() {
    return {
      HTMLAttributes: {},
      resizable: false,
      handleWidth: 5,
      cellMinWidth: 25,
      // TODO: fix
      View: TableView,
      lastColumnResizable: true,
      allowTableNodeSelection: false
    };
  },
  content: "tableRow+",
  tableRole: "table",
  isolating: true,
  group: "block",
  parseHTML() {
    return [{ tag: "table" }];
  },
  renderHTML({ node: node3, HTMLAttributes }) {
    const { colgroup, tableWidth, tableMinWidth } = createColGroup(node3, this.options.cellMinWidth);
    const table2 = [
      "table",
      mergeAttributes(this.options.HTMLAttributes, HTMLAttributes, {
        style: tableWidth ? `width: ${tableWidth}` : `min-width: ${tableMinWidth}`
      }),
      colgroup,
      ["tbody", 0]
    ];
    return table2;
  },
  addCommands() {
    return {
      insertTable: /* @__PURE__ */ __name(({ rows = 3, cols = 3, withHeaderRow = true } = {}) => ({ tr: tr2, dispatch, editor }) => {
        const node3 = createTable(editor.schema, rows, cols, withHeaderRow);
        if (dispatch) {
          const offset = tr2.selection.from + 1;
          tr2.replaceSelectionWith(node3).scrollIntoView().setSelection(TextSelection.near(tr2.doc.resolve(offset)));
        }
        return true;
      }, "insertTable"),
      addColumnBefore: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return addColumnBefore(state, dispatch);
      }, "addColumnBefore"),
      addColumnAfter: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return addColumnAfter(state, dispatch);
      }, "addColumnAfter"),
      deleteColumn: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return deleteColumn(state, dispatch);
      }, "deleteColumn"),
      addRowBefore: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return addRowBefore(state, dispatch);
      }, "addRowBefore"),
      addRowAfter: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return addRowAfter(state, dispatch);
      }, "addRowAfter"),
      deleteRow: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return deleteRow(state, dispatch);
      }, "deleteRow"),
      deleteTable: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return deleteTable(state, dispatch);
      }, "deleteTable"),
      mergeCells: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return mergeCells(state, dispatch);
      }, "mergeCells"),
      splitCell: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return splitCell(state, dispatch);
      }, "splitCell"),
      toggleHeaderColumn: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return toggleHeader("column")(state, dispatch);
      }, "toggleHeaderColumn"),
      toggleHeaderRow: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return toggleHeader("row")(state, dispatch);
      }, "toggleHeaderRow"),
      toggleHeaderCell: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return toggleHeaderCell(state, dispatch);
      }, "toggleHeaderCell"),
      mergeOrSplit: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        if (mergeCells(state, dispatch)) {
          return true;
        }
        return splitCell(state, dispatch);
      }, "mergeOrSplit"),
      setCellAttribute: /* @__PURE__ */ __name((name2, value3) => ({ state, dispatch }) => {
        return setCellAttr(name2, value3)(state, dispatch);
      }, "setCellAttribute"),
      goToNextCell: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return goToNextCell(1)(state, dispatch);
      }, "goToNextCell"),
      goToPreviousCell: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return goToNextCell(-1)(state, dispatch);
      }, "goToPreviousCell"),
      fixTables: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        if (dispatch) {
          fixTables(state);
        }
        return true;
      }, "fixTables"),
      setCellSelection: /* @__PURE__ */ __name((position3) => ({ tr: tr2, dispatch }) => {
        if (dispatch) {
          const selection = CellSelection.create(tr2.doc, position3.anchorCell, position3.headCell);
          tr2.setSelection(selection);
        }
        return true;
      }, "setCellSelection")
    };
  },
  addKeyboardShortcuts() {
    return {
      Tab: /* @__PURE__ */ __name(() => {
        if (this.editor.commands.goToNextCell()) {
          return true;
        }
        if (!this.editor.can().addRowAfter()) {
          return false;
        }
        return this.editor.chain().addRowAfter().goToNextCell().run();
      }, "Tab"),
      "Shift-Tab": /* @__PURE__ */ __name(() => this.editor.commands.goToPreviousCell(), "Shift-Tab"),
      Backspace: deleteTableWhenAllCellsSelected,
      "Mod-Backspace": deleteTableWhenAllCellsSelected,
      Delete: deleteTableWhenAllCellsSelected,
      "Mod-Delete": deleteTableWhenAllCellsSelected
    };
  },
  addProseMirrorPlugins() {
    const isResizable = this.options.resizable && this.editor.isEditable;
    return [
      ...isResizable ? [
        columnResizing({
          handleWidth: this.options.handleWidth,
          cellMinWidth: this.options.cellMinWidth,
          defaultCellMinWidth: this.options.cellMinWidth,
          View: this.options.View,
          lastColumnResizable: this.options.lastColumnResizable
        })
      ] : [],
      tableEditing({
        allowTableNodeSelection: this.options.allowTableNodeSelection
      })
    ];
  },
  extendNodeSchema(extension) {
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage
    };
    return {
      tableRole: callOrReturn(getExtensionField(extension, "tableRole", context))
    };
  }
});
const TableCell = Node$1.create({
  name: "tableCell",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  content: "block+",
  addAttributes() {
    return {
      colspan: {
        default: 1
      },
      rowspan: {
        default: 1
      },
      colwidth: {
        default: null,
        parseHTML: /* @__PURE__ */ __name((element) => {
          const colwidth = element.getAttribute("colwidth");
          const value3 = colwidth ? colwidth.split(",").map((width2) => parseInt(width2, 10)) : null;
          return value3;
        }, "parseHTML")
      }
    };
  },
  tableRole: "cell",
  isolating: true,
  parseHTML() {
    return [
      { tag: "td" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["td", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  }
});
const TableHeader = Node$1.create({
  name: "tableHeader",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  content: "block+",
  addAttributes() {
    return {
      colspan: {
        default: 1
      },
      rowspan: {
        default: 1
      },
      colwidth: {
        default: null,
        parseHTML: /* @__PURE__ */ __name((element) => {
          const colwidth = element.getAttribute("colwidth");
          const value3 = colwidth ? colwidth.split(",").map((width2) => parseInt(width2, 10)) : null;
          return value3;
        }, "parseHTML")
      }
    };
  },
  tableRole: "header_cell",
  isolating: true,
  parseHTML() {
    return [
      { tag: "th" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["th", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  }
});
const TableRow = Node$1.create({
  name: "tableRow",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  content: "(tableCell | tableHeader)*",
  tableRole: "row",
  parseHTML() {
    return [
      { tag: "tr" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["tr", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  }
});
const inputRegex$4 = /^\s*>\s$/;
const Blockquote$2 = Node$1.create({
  name: "blockquote",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  content: "block+",
  group: "block",
  defining: true,
  parseHTML() {
    return [
      { tag: "blockquote" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["blockquote", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setBlockquote: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.wrapIn(this.name);
      }, "setBlockquote"),
      toggleBlockquote: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.toggleWrap(this.name);
      }, "toggleBlockquote"),
      unsetBlockquote: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.lift(this.name);
      }, "unsetBlockquote")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Shift-b": /* @__PURE__ */ __name(() => this.editor.commands.toggleBlockquote(), "Mod-Shift-b")
    };
  },
  addInputRules() {
    return [
      wrappingInputRule({
        find: inputRegex$4,
        type: this.type
      })
    ];
  }
});
const starInputRegex$1 = /(?:^|\s)(\*\*(?!\s+\*\*)((?:[^*]+))\*\*(?!\s+\*\*))$/;
const starPasteRegex$1 = /(?:^|\s)(\*\*(?!\s+\*\*)((?:[^*]+))\*\*(?!\s+\*\*))/g;
const underscoreInputRegex$1 = /(?:^|\s)(__(?!\s+__)((?:[^_]+))__(?!\s+__))$/;
const underscorePasteRegex$1 = /(?:^|\s)(__(?!\s+__)((?:[^_]+))__(?!\s+__))/g;
const Bold$2 = Mark.create({
  name: "bold",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  parseHTML() {
    return [
      {
        tag: "strong"
      },
      {
        tag: "b",
        getAttrs: /* @__PURE__ */ __name((node3) => node3.style.fontWeight !== "normal" && null, "getAttrs")
      },
      {
        style: "font-weight=400",
        clearMark: /* @__PURE__ */ __name((mark2) => mark2.type.name === this.name, "clearMark")
      },
      {
        style: "font-weight",
        getAttrs: /* @__PURE__ */ __name((value3) => /^(bold(er)?|[5-9]\d{2,})$/.test(value3) && null, "getAttrs")
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["strong", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setBold: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.setMark(this.name);
      }, "setBold"),
      toggleBold: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.toggleMark(this.name);
      }, "toggleBold"),
      unsetBold: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.unsetMark(this.name);
      }, "unsetBold")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-b": /* @__PURE__ */ __name(() => this.editor.commands.toggleBold(), "Mod-b"),
      "Mod-B": /* @__PURE__ */ __name(() => this.editor.commands.toggleBold(), "Mod-B")
    };
  },
  addInputRules() {
    return [
      markInputRule({
        find: starInputRegex$1,
        type: this.type
      }),
      markInputRule({
        find: underscoreInputRegex$1,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: starPasteRegex$1,
        type: this.type
      }),
      markPasteRule({
        find: underscorePasteRegex$1,
        type: this.type
      })
    ];
  }
});
const ListItemName$1 = "listItem";
const TextStyleName$1 = "textStyle";
const inputRegex$3 = /^\s*([-+*])\s$/;
const BulletList$2 = Node$1.create({
  name: "bulletList",
  addOptions() {
    return {
      itemTypeName: "listItem",
      HTMLAttributes: {},
      keepMarks: false,
      keepAttributes: false
    };
  },
  group: "block list",
  content() {
    return `${this.options.itemTypeName}+`;
  },
  parseHTML() {
    return [
      { tag: "ul" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["ul", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      toggleBulletList: /* @__PURE__ */ __name(() => ({ commands: commands2, chain }) => {
        if (this.options.keepAttributes) {
          return chain().toggleList(this.name, this.options.itemTypeName, this.options.keepMarks).updateAttributes(ListItemName$1, this.editor.getAttributes(TextStyleName$1)).run();
        }
        return commands2.toggleList(this.name, this.options.itemTypeName, this.options.keepMarks);
      }, "toggleBulletList")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Shift-8": /* @__PURE__ */ __name(() => this.editor.commands.toggleBulletList(), "Mod-Shift-8")
    };
  },
  addInputRules() {
    let inputRule = wrappingInputRule({
      find: inputRegex$3,
      type: this.type
    });
    if (this.options.keepMarks || this.options.keepAttributes) {
      inputRule = wrappingInputRule({
        find: inputRegex$3,
        type: this.type,
        keepMarks: this.options.keepMarks,
        keepAttributes: this.options.keepAttributes,
        getAttributes: /* @__PURE__ */ __name(() => {
          return this.editor.getAttributes(TextStyleName$1);
        }, "getAttributes"),
        editor: this.editor
      });
    }
    return [
      inputRule
    ];
  }
});
const inputRegex$2 = /(?<!`)`([^`]+)`(?!`)/;
const pasteRegex$1 = /(?<!`)`([^`]+)`(?!`)/g;
const Code$2 = Mark.create({
  name: "code",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  excludes: "_",
  code: true,
  exitable: true,
  parseHTML() {
    return [
      { tag: "code" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["code", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setCode: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.setMark(this.name);
      }, "setCode"),
      toggleCode: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.toggleMark(this.name);
      }, "toggleCode"),
      unsetCode: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.unsetMark(this.name);
      }, "unsetCode")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-e": /* @__PURE__ */ __name(() => this.editor.commands.toggleCode(), "Mod-e")
    };
  },
  addInputRules() {
    return [
      markInputRule({
        find: inputRegex$2,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: pasteRegex$1,
        type: this.type
      })
    ];
  }
});
const backtickInputRegex = /^```([a-z]+)?[\s\n]$/;
const tildeInputRegex = /^~~~([a-z]+)?[\s\n]$/;
const CodeBlock$2 = Node$1.create({
  name: "codeBlock",
  addOptions() {
    return {
      languageClassPrefix: "language-",
      exitOnTripleEnter: true,
      exitOnArrowDown: true,
      defaultLanguage: null,
      HTMLAttributes: {}
    };
  },
  content: "text*",
  marks: "",
  group: "block",
  code: true,
  defining: true,
  addAttributes() {
    return {
      language: {
        default: this.options.defaultLanguage,
        parseHTML: /* @__PURE__ */ __name((element) => {
          var _a2;
          const { languageClassPrefix } = this.options;
          const classNames2 = [...((_a2 = element.firstElementChild) === null || _a2 === void 0 ? void 0 : _a2.classList) || []];
          const languages = classNames2.filter((className) => className.startsWith(languageClassPrefix)).map((className) => className.replace(languageClassPrefix, ""));
          const language = languages[0];
          if (!language) {
            return null;
          }
          return language;
        }, "parseHTML"),
        rendered: false
      }
    };
  },
  parseHTML() {
    return [
      {
        tag: "pre",
        preserveWhitespace: "full"
      }
    ];
  },
  renderHTML({ node: node3, HTMLAttributes }) {
    return [
      "pre",
      mergeAttributes(this.options.HTMLAttributes, HTMLAttributes),
      [
        "code",
        {
          class: node3.attrs.language ? this.options.languageClassPrefix + node3.attrs.language : null
        },
        0
      ]
    ];
  },
  addCommands() {
    return {
      setCodeBlock: /* @__PURE__ */ __name((attributes) => ({ commands: commands2 }) => {
        return commands2.setNode(this.name, attributes);
      }, "setCodeBlock"),
      toggleCodeBlock: /* @__PURE__ */ __name((attributes) => ({ commands: commands2 }) => {
        return commands2.toggleNode(this.name, "paragraph", attributes);
      }, "toggleCodeBlock")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Alt-c": /* @__PURE__ */ __name(() => this.editor.commands.toggleCodeBlock(), "Mod-Alt-c"),
      // remove code block when at start of document or code block is empty
      Backspace: /* @__PURE__ */ __name(() => {
        const { empty: empty2, $anchor } = this.editor.state.selection;
        const isAtStart = $anchor.pos === 1;
        if (!empty2 || $anchor.parent.type.name !== this.name) {
          return false;
        }
        if (isAtStart || !$anchor.parent.textContent.length) {
          return this.editor.commands.clearNodes();
        }
        return false;
      }, "Backspace"),
      // exit node on triple enter
      Enter: /* @__PURE__ */ __name(({ editor }) => {
        if (!this.options.exitOnTripleEnter) {
          return false;
        }
        const { state } = editor;
        const { selection } = state;
        const { $from, empty: empty2 } = selection;
        if (!empty2 || $from.parent.type !== this.type) {
          return false;
        }
        const isAtEnd = $from.parentOffset === $from.parent.nodeSize - 2;
        const endsWithDoubleNewline = $from.parent.textContent.endsWith("\n\n");
        if (!isAtEnd || !endsWithDoubleNewline) {
          return false;
        }
        return editor.chain().command(({ tr: tr2 }) => {
          tr2.delete($from.pos - 2, $from.pos);
          return true;
        }).exitCode().run();
      }, "Enter"),
      // exit node on arrow down
      ArrowDown: /* @__PURE__ */ __name(({ editor }) => {
        if (!this.options.exitOnArrowDown) {
          return false;
        }
        const { state } = editor;
        const { selection, doc: doc2 } = state;
        const { $from, empty: empty2 } = selection;
        if (!empty2 || $from.parent.type !== this.type) {
          return false;
        }
        const isAtEnd = $from.parentOffset === $from.parent.nodeSize - 2;
        if (!isAtEnd) {
          return false;
        }
        const after = $from.after();
        if (after === void 0) {
          return false;
        }
        const nodeAfter = doc2.nodeAt(after);
        if (nodeAfter) {
          return editor.commands.command(({ tr: tr2 }) => {
            tr2.setSelection(Selection.near(doc2.resolve(after)));
            return true;
          });
        }
        return editor.commands.exitCode();
      }, "ArrowDown")
    };
  },
  addInputRules() {
    return [
      textblockTypeInputRule({
        find: backtickInputRegex,
        type: this.type,
        getAttributes: /* @__PURE__ */ __name((match2) => ({
          language: match2[1]
        }), "getAttributes")
      }),
      textblockTypeInputRule({
        find: tildeInputRegex,
        type: this.type,
        getAttributes: /* @__PURE__ */ __name((match2) => ({
          language: match2[1]
        }), "getAttributes")
      })
    ];
  },
  addProseMirrorPlugins() {
    return [
      // this plugin creates a code block for pasted content from VS Code
      // we can also detect the copied code language
      new Plugin({
        key: new PluginKey("codeBlockVSCodeHandler"),
        props: {
          handlePaste: /* @__PURE__ */ __name((view, event) => {
            if (!event.clipboardData) {
              return false;
            }
            if (this.editor.isActive(this.type.name)) {
              return false;
            }
            const text2 = event.clipboardData.getData("text/plain");
            const vscode = event.clipboardData.getData("vscode-editor-data");
            const vscodeData = vscode ? JSON.parse(vscode) : void 0;
            const language = vscodeData === null || vscodeData === void 0 ? void 0 : vscodeData.mode;
            if (!text2 || !language) {
              return false;
            }
            const { tr: tr2, schema: schema2 } = view.state;
            const textNode = schema2.text(text2.replace(/\r\n?/g, "\n"));
            tr2.replaceSelectionWith(this.type.create({ language }, textNode));
            if (tr2.selection.$from.parent.type !== this.type) {
              tr2.setSelection(TextSelection.near(tr2.doc.resolve(Math.max(0, tr2.selection.from - 2))));
            }
            tr2.setMeta("paste", true);
            view.dispatch(tr2);
            return true;
          }, "handlePaste")
        }
      })
    ];
  }
});
const Document$1 = Node$1.create({
  name: "doc",
  topNode: true,
  content: "block+"
});
function dropCursor(options5 = {}) {
  return new Plugin({
    view(editorView) {
      return new DropCursorView(editorView, options5);
    }
  });
}
__name(dropCursor, "dropCursor");
class DropCursorView {
  static {
    __name(this, "DropCursorView");
  }
  constructor(editorView, options5) {
    var _a2;
    this.editorView = editorView;
    this.cursorPos = null;
    this.element = null;
    this.timeout = -1;
    this.width = (_a2 = options5.width) !== null && _a2 !== void 0 ? _a2 : 1;
    this.color = options5.color === false ? void 0 : options5.color || "black";
    this.class = options5.class;
    this.handlers = ["dragover", "dragend", "drop", "dragleave"].map((name2) => {
      let handler14 = /* @__PURE__ */ __name((e2) => {
        this[name2](e2);
      }, "handler");
      editorView.dom.addEventListener(name2, handler14);
      return { name: name2, handler: handler14 };
    });
  }
  destroy() {
    this.handlers.forEach(({ name: name2, handler: handler14 }) => this.editorView.dom.removeEventListener(name2, handler14));
  }
  update(editorView, prevState) {
    if (this.cursorPos != null && prevState.doc != editorView.state.doc) {
      if (this.cursorPos > editorView.state.doc.content.size)
        this.setCursor(null);
      else
        this.updateOverlay();
    }
  }
  setCursor(pos) {
    if (pos == this.cursorPos)
      return;
    this.cursorPos = pos;
    if (pos == null) {
      this.element.parentNode.removeChild(this.element);
      this.element = null;
    } else {
      this.updateOverlay();
    }
  }
  updateOverlay() {
    let $pos = this.editorView.state.doc.resolve(this.cursorPos);
    let isBlock = !$pos.parent.inlineContent, rect;
    if (isBlock) {
      let before = $pos.nodeBefore, after = $pos.nodeAfter;
      if (before || after) {
        let node3 = this.editorView.nodeDOM(this.cursorPos - (before ? before.nodeSize : 0));
        if (node3) {
          let nodeRect = node3.getBoundingClientRect();
          let top = before ? nodeRect.bottom : nodeRect.top;
          if (before && after)
            top = (top + this.editorView.nodeDOM(this.cursorPos).getBoundingClientRect().top) / 2;
          rect = { left: nodeRect.left, right: nodeRect.right, top: top - this.width / 2, bottom: top + this.width / 2 };
        }
      }
    }
    if (!rect) {
      let coords = this.editorView.coordsAtPos(this.cursorPos);
      rect = { left: coords.left - this.width / 2, right: coords.left + this.width / 2, top: coords.top, bottom: coords.bottom };
    }
    let parent = this.editorView.dom.offsetParent;
    if (!this.element) {
      this.element = parent.appendChild(document.createElement("div"));
      if (this.class)
        this.element.className = this.class;
      this.element.style.cssText = "position: absolute; z-index: 50; pointer-events: none;";
      if (this.color) {
        this.element.style.backgroundColor = this.color;
      }
    }
    this.element.classList.toggle("prosemirror-dropcursor-block", isBlock);
    this.element.classList.toggle("prosemirror-dropcursor-inline", !isBlock);
    let parentLeft, parentTop;
    if (!parent || parent == document.body && getComputedStyle(parent).position == "static") {
      parentLeft = -pageXOffset;
      parentTop = -pageYOffset;
    } else {
      let rect2 = parent.getBoundingClientRect();
      parentLeft = rect2.left - parent.scrollLeft;
      parentTop = rect2.top - parent.scrollTop;
    }
    this.element.style.left = rect.left - parentLeft + "px";
    this.element.style.top = rect.top - parentTop + "px";
    this.element.style.width = rect.right - rect.left + "px";
    this.element.style.height = rect.bottom - rect.top + "px";
  }
  scheduleRemoval(timeout) {
    clearTimeout(this.timeout);
    this.timeout = setTimeout(() => this.setCursor(null), timeout);
  }
  dragover(event) {
    if (!this.editorView.editable)
      return;
    let pos = this.editorView.posAtCoords({ left: event.clientX, top: event.clientY });
    let node3 = pos && pos.inside >= 0 && this.editorView.state.doc.nodeAt(pos.inside);
    let disableDropCursor = node3 && node3.type.spec.disableDropCursor;
    let disabled3 = typeof disableDropCursor == "function" ? disableDropCursor(this.editorView, pos, event) : disableDropCursor;
    if (pos && !disabled3) {
      let target2 = pos.pos;
      if (this.editorView.dragging && this.editorView.dragging.slice) {
        let point = dropPoint(this.editorView.state.doc, target2, this.editorView.dragging.slice);
        if (point != null)
          target2 = point;
      }
      this.setCursor(target2);
      this.scheduleRemoval(5e3);
    }
  }
  dragend() {
    this.scheduleRemoval(20);
  }
  drop() {
    this.scheduleRemoval(20);
  }
  dragleave(event) {
    if (event.target == this.editorView.dom || !this.editorView.dom.contains(event.relatedTarget))
      this.setCursor(null);
  }
}
const Dropcursor = Extension.create({
  name: "dropCursor",
  addOptions() {
    return {
      color: "currentColor",
      width: 1,
      class: void 0
    };
  },
  addProseMirrorPlugins() {
    return [
      dropCursor(this.options)
    ];
  }
});
class GapCursor extends Selection {
  static {
    __name(this, "GapCursor");
  }
  /**
  Create a gap cursor.
  */
  constructor($pos) {
    super($pos, $pos);
  }
  map(doc2, mapping) {
    let $pos = doc2.resolve(mapping.map(this.head));
    return GapCursor.valid($pos) ? new GapCursor($pos) : Selection.near($pos);
  }
  content() {
    return Slice.empty;
  }
  eq(other) {
    return other instanceof GapCursor && other.head == this.head;
  }
  toJSON() {
    return { type: "gapcursor", pos: this.head };
  }
  /**
  @internal
  */
  static fromJSON(doc2, json) {
    if (typeof json.pos != "number")
      throw new RangeError("Invalid input for GapCursor.fromJSON");
    return new GapCursor(doc2.resolve(json.pos));
  }
  /**
  @internal
  */
  getBookmark() {
    return new GapBookmark(this.anchor);
  }
  /**
  @internal
  */
  static valid($pos) {
    let parent = $pos.parent;
    if (parent.isTextblock || !closedBefore($pos) || !closedAfter($pos))
      return false;
    let override = parent.type.spec.allowGapCursor;
    if (override != null)
      return override;
    let deflt = parent.contentMatchAt($pos.index()).defaultType;
    return deflt && deflt.isTextblock;
  }
  /**
  @internal
  */
  static findGapCursorFrom($pos, dir, mustMove = false) {
    search: for (; ; ) {
      if (!mustMove && GapCursor.valid($pos))
        return $pos;
      let pos = $pos.pos, next2 = null;
      for (let d2 = $pos.depth; ; d2--) {
        let parent = $pos.node(d2);
        if (dir > 0 ? $pos.indexAfter(d2) < parent.childCount : $pos.index(d2) > 0) {
          next2 = parent.child(dir > 0 ? $pos.indexAfter(d2) : $pos.index(d2) - 1);
          break;
        } else if (d2 == 0) {
          return null;
        }
        pos += dir;
        let $cur = $pos.doc.resolve(pos);
        if (GapCursor.valid($cur))
          return $cur;
      }
      for (; ; ) {
        let inside = dir > 0 ? next2.firstChild : next2.lastChild;
        if (!inside) {
          if (next2.isAtom && !next2.isText && !NodeSelection.isSelectable(next2)) {
            $pos = $pos.doc.resolve(pos + next2.nodeSize * dir);
            mustMove = false;
            continue search;
          }
          break;
        }
        next2 = inside;
        pos += dir;
        let $cur = $pos.doc.resolve(pos);
        if (GapCursor.valid($cur))
          return $cur;
      }
      return null;
    }
  }
}
GapCursor.prototype.visible = false;
GapCursor.findFrom = GapCursor.findGapCursorFrom;
Selection.jsonID("gapcursor", GapCursor);
class GapBookmark {
  static {
    __name(this, "GapBookmark");
  }
  constructor(pos) {
    this.pos = pos;
  }
  map(mapping) {
    return new GapBookmark(mapping.map(this.pos));
  }
  resolve(doc2) {
    let $pos = doc2.resolve(this.pos);
    return GapCursor.valid($pos) ? new GapCursor($pos) : Selection.near($pos);
  }
}
function closedBefore($pos) {
  for (let d2 = $pos.depth; d2 >= 0; d2--) {
    let index2 = $pos.index(d2), parent = $pos.node(d2);
    if (index2 == 0) {
      if (parent.type.spec.isolating)
        return true;
      continue;
    }
    for (let before = parent.child(index2 - 1); ; before = before.lastChild) {
      if (before.childCount == 0 && !before.inlineContent || before.isAtom || before.type.spec.isolating)
        return true;
      if (before.inlineContent)
        return false;
    }
  }
  return true;
}
__name(closedBefore, "closedBefore");
function closedAfter($pos) {
  for (let d2 = $pos.depth; d2 >= 0; d2--) {
    let index2 = $pos.indexAfter(d2), parent = $pos.node(d2);
    if (index2 == parent.childCount) {
      if (parent.type.spec.isolating)
        return true;
      continue;
    }
    for (let after = parent.child(index2); ; after = after.firstChild) {
      if (after.childCount == 0 && !after.inlineContent || after.isAtom || after.type.spec.isolating)
        return true;
      if (after.inlineContent)
        return false;
    }
  }
  return true;
}
__name(closedAfter, "closedAfter");
function gapCursor() {
  return new Plugin({
    props: {
      decorations: drawGapCursor,
      createSelectionBetween(_view, $anchor, $head) {
        return $anchor.pos == $head.pos && GapCursor.valid($head) ? new GapCursor($head) : null;
      },
      handleClick,
      handleKeyDown,
      handleDOMEvents: { beforeinput }
    }
  });
}
__name(gapCursor, "gapCursor");
const handleKeyDown = keydownHandler({
  "ArrowLeft": arrow("horiz", -1),
  "ArrowRight": arrow("horiz", 1),
  "ArrowUp": arrow("vert", -1),
  "ArrowDown": arrow("vert", 1)
});
function arrow(axis, dir) {
  const dirStr = axis == "vert" ? dir > 0 ? "down" : "up" : dir > 0 ? "right" : "left";
  return function(state, dispatch, view) {
    let sel = state.selection;
    let $start = dir > 0 ? sel.$to : sel.$from, mustMove = sel.empty;
    if (sel instanceof TextSelection) {
      if (!view.endOfTextblock(dirStr) || $start.depth == 0)
        return false;
      mustMove = false;
      $start = state.doc.resolve(dir > 0 ? $start.after() : $start.before());
    }
    let $found = GapCursor.findGapCursorFrom($start, dir, mustMove);
    if (!$found)
      return false;
    if (dispatch)
      dispatch(state.tr.setSelection(new GapCursor($found)));
    return true;
  };
}
__name(arrow, "arrow");
function handleClick(view, pos, event) {
  if (!view || !view.editable)
    return false;
  let $pos = view.state.doc.resolve(pos);
  if (!GapCursor.valid($pos))
    return false;
  let clickPos = view.posAtCoords({ left: event.clientX, top: event.clientY });
  if (clickPos && clickPos.inside > -1 && NodeSelection.isSelectable(view.state.doc.nodeAt(clickPos.inside)))
    return false;
  view.dispatch(view.state.tr.setSelection(new GapCursor($pos)));
  return true;
}
__name(handleClick, "handleClick");
function beforeinput(view, event) {
  if (event.inputType != "insertCompositionText" || !(view.state.selection instanceof GapCursor))
    return false;
  let { $from } = view.state.selection;
  let insert2 = $from.parent.contentMatchAt($from.index()).findWrapping(view.state.schema.nodes.text);
  if (!insert2)
    return false;
  let frag = Fragment.empty;
  for (let i2 = insert2.length - 1; i2 >= 0; i2--)
    frag = Fragment.from(insert2[i2].createAndFill(null, frag));
  let tr2 = view.state.tr.replace($from.pos, $from.pos, new Slice(frag, 0, 0));
  tr2.setSelection(TextSelection.near(tr2.doc.resolve($from.pos + 1)));
  view.dispatch(tr2);
  return false;
}
__name(beforeinput, "beforeinput");
function drawGapCursor(state) {
  if (!(state.selection instanceof GapCursor))
    return null;
  let node3 = document.createElement("div");
  node3.className = "ProseMirror-gapcursor";
  return DecorationSet.create(state.doc, [Decoration.widget(state.selection.head, node3, { key: "gapcursor" })]);
}
__name(drawGapCursor, "drawGapCursor");
const Gapcursor = Extension.create({
  name: "gapCursor",
  addProseMirrorPlugins() {
    return [
      gapCursor()
    ];
  },
  extendNodeSchema(extension) {
    var _a2;
    const context = {
      name: extension.name,
      options: extension.options,
      storage: extension.storage
    };
    return {
      allowGapCursor: (_a2 = callOrReturn(getExtensionField(extension, "allowGapCursor", context))) !== null && _a2 !== void 0 ? _a2 : null
    };
  }
});
const HardBreak$2 = Node$1.create({
  name: "hardBreak",
  addOptions() {
    return {
      keepMarks: true,
      HTMLAttributes: {}
    };
  },
  inline: true,
  group: "inline",
  selectable: false,
  linebreakReplacement: true,
  parseHTML() {
    return [
      { tag: "br" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["br", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes)];
  },
  renderText() {
    return "\n";
  },
  addCommands() {
    return {
      setHardBreak: /* @__PURE__ */ __name(() => ({ commands: commands2, chain, state, editor }) => {
        return commands2.first([
          () => commands2.exitCode(),
          () => commands2.command(() => {
            const { selection, storedMarks } = state;
            if (selection.$from.parent.type.spec.isolating) {
              return false;
            }
            const { keepMarks } = this.options;
            const { splittableMarks } = editor.extensionManager;
            const marks = storedMarks || selection.$to.parentOffset && selection.$from.marks();
            return chain().insertContent({ type: this.name }).command(({ tr: tr2, dispatch }) => {
              if (dispatch && marks && keepMarks) {
                const filteredMarks = marks.filter((mark2) => splittableMarks.includes(mark2.type.name));
                tr2.ensureMarks(filteredMarks);
              }
              return true;
            }).run();
          })
        ]);
      }, "setHardBreak")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Enter": /* @__PURE__ */ __name(() => this.editor.commands.setHardBreak(), "Mod-Enter"),
      "Shift-Enter": /* @__PURE__ */ __name(() => this.editor.commands.setHardBreak(), "Shift-Enter")
    };
  }
});
const Heading$2 = Node$1.create({
  name: "heading",
  addOptions() {
    return {
      levels: [1, 2, 3, 4, 5, 6],
      HTMLAttributes: {}
    };
  },
  content: "inline*",
  group: "block",
  defining: true,
  addAttributes() {
    return {
      level: {
        default: 1,
        rendered: false
      }
    };
  },
  parseHTML() {
    return this.options.levels.map((level) => ({
      tag: `h${level}`,
      attrs: { level }
    }));
  },
  renderHTML({ node: node3, HTMLAttributes }) {
    const hasLevel = this.options.levels.includes(node3.attrs.level);
    const level = hasLevel ? node3.attrs.level : this.options.levels[0];
    return [`h${level}`, mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setHeading: /* @__PURE__ */ __name((attributes) => ({ commands: commands2 }) => {
        if (!this.options.levels.includes(attributes.level)) {
          return false;
        }
        return commands2.setNode(this.name, attributes);
      }, "setHeading"),
      toggleHeading: /* @__PURE__ */ __name((attributes) => ({ commands: commands2 }) => {
        if (!this.options.levels.includes(attributes.level)) {
          return false;
        }
        return commands2.toggleNode(this.name, "paragraph", attributes);
      }, "toggleHeading")
    };
  },
  addKeyboardShortcuts() {
    return this.options.levels.reduce((items2, level) => ({
      ...items2,
      ...{
        [`Mod-Alt-${level}`]: () => this.editor.commands.toggleHeading({ level })
      }
    }), {});
  },
  addInputRules() {
    return this.options.levels.map((level) => {
      return textblockTypeInputRule({
        find: new RegExp(`^(#{1,${level}})\\s$`),
        type: this.type,
        getAttributes: {
          level
        }
      });
    });
  }
});
var GOOD_LEAF_SIZE = 200;
var RopeSequence = /* @__PURE__ */ __name(function RopeSequence2() {
}, "RopeSequence");
RopeSequence.prototype.append = /* @__PURE__ */ __name(function append2(other) {
  if (!other.length) {
    return this;
  }
  other = RopeSequence.from(other);
  return !this.length && other || other.length < GOOD_LEAF_SIZE && this.leafAppend(other) || this.length < GOOD_LEAF_SIZE && other.leafPrepend(this) || this.appendInner(other);
}, "append");
RopeSequence.prototype.prepend = /* @__PURE__ */ __name(function prepend(other) {
  if (!other.length) {
    return this;
  }
  return RopeSequence.from(other).append(this);
}, "prepend");
RopeSequence.prototype.appendInner = /* @__PURE__ */ __name(function appendInner(other) {
  return new Append(this, other);
}, "appendInner");
RopeSequence.prototype.slice = /* @__PURE__ */ __name(function slice(from2, to) {
  if (from2 === void 0) from2 = 0;
  if (to === void 0) to = this.length;
  if (from2 >= to) {
    return RopeSequence.empty;
  }
  return this.sliceInner(Math.max(0, from2), Math.min(this.length, to));
}, "slice");
RopeSequence.prototype.get = /* @__PURE__ */ __name(function get2(i2) {
  if (i2 < 0 || i2 >= this.length) {
    return void 0;
  }
  return this.getInner(i2);
}, "get");
RopeSequence.prototype.forEach = /* @__PURE__ */ __name(function forEach2(f2, from2, to) {
  if (from2 === void 0) from2 = 0;
  if (to === void 0) to = this.length;
  if (from2 <= to) {
    this.forEachInner(f2, from2, to, 0);
  } else {
    this.forEachInvertedInner(f2, from2, to, 0);
  }
}, "forEach");
RopeSequence.prototype.map = /* @__PURE__ */ __name(function map2(f2, from2, to) {
  if (from2 === void 0) from2 = 0;
  if (to === void 0) to = this.length;
  var result = [];
  this.forEach(function(elt, i2) {
    return result.push(f2(elt, i2));
  }, from2, to);
  return result;
}, "map");
RopeSequence.from = /* @__PURE__ */ __name(function from(values) {
  if (values instanceof RopeSequence) {
    return values;
  }
  return values && values.length ? new Leaf(values) : RopeSequence.empty;
}, "from");
var Leaf = /* @__PURE__ */ function(RopeSequence3) {
  function Leaf2(values) {
    RopeSequence3.call(this);
    this.values = values;
  }
  __name(Leaf2, "Leaf");
  if (RopeSequence3) Leaf2.__proto__ = RopeSequence3;
  Leaf2.prototype = Object.create(RopeSequence3 && RopeSequence3.prototype);
  Leaf2.prototype.constructor = Leaf2;
  var prototypeAccessors = { length: { configurable: true }, depth: { configurable: true } };
  Leaf2.prototype.flatten = /* @__PURE__ */ __name(function flatten2() {
    return this.values;
  }, "flatten");
  Leaf2.prototype.sliceInner = /* @__PURE__ */ __name(function sliceInner(from2, to) {
    if (from2 == 0 && to == this.length) {
      return this;
    }
    return new Leaf2(this.values.slice(from2, to));
  }, "sliceInner");
  Leaf2.prototype.getInner = /* @__PURE__ */ __name(function getInner(i2) {
    return this.values[i2];
  }, "getInner");
  Leaf2.prototype.forEachInner = /* @__PURE__ */ __name(function forEachInner(f2, from2, to, start2) {
    for (var i2 = from2; i2 < to; i2++) {
      if (f2(this.values[i2], start2 + i2) === false) {
        return false;
      }
    }
  }, "forEachInner");
  Leaf2.prototype.forEachInvertedInner = /* @__PURE__ */ __name(function forEachInvertedInner(f2, from2, to, start2) {
    for (var i2 = from2 - 1; i2 >= to; i2--) {
      if (f2(this.values[i2], start2 + i2) === false) {
        return false;
      }
    }
  }, "forEachInvertedInner");
  Leaf2.prototype.leafAppend = /* @__PURE__ */ __name(function leafAppend(other) {
    if (this.length + other.length <= GOOD_LEAF_SIZE) {
      return new Leaf2(this.values.concat(other.flatten()));
    }
  }, "leafAppend");
  Leaf2.prototype.leafPrepend = /* @__PURE__ */ __name(function leafPrepend(other) {
    if (this.length + other.length <= GOOD_LEAF_SIZE) {
      return new Leaf2(other.flatten().concat(this.values));
    }
  }, "leafPrepend");
  prototypeAccessors.length.get = function() {
    return this.values.length;
  };
  prototypeAccessors.depth.get = function() {
    return 0;
  };
  Object.defineProperties(Leaf2.prototype, prototypeAccessors);
  return Leaf2;
}(RopeSequence);
RopeSequence.empty = new Leaf([]);
var Append = /* @__PURE__ */ function(RopeSequence3) {
  function Append2(left, right) {
    RopeSequence3.call(this);
    this.left = left;
    this.right = right;
    this.length = left.length + right.length;
    this.depth = Math.max(left.depth, right.depth) + 1;
  }
  __name(Append2, "Append");
  if (RopeSequence3) Append2.__proto__ = RopeSequence3;
  Append2.prototype = Object.create(RopeSequence3 && RopeSequence3.prototype);
  Append2.prototype.constructor = Append2;
  Append2.prototype.flatten = /* @__PURE__ */ __name(function flatten2() {
    return this.left.flatten().concat(this.right.flatten());
  }, "flatten");
  Append2.prototype.getInner = /* @__PURE__ */ __name(function getInner(i2) {
    return i2 < this.left.length ? this.left.get(i2) : this.right.get(i2 - this.left.length);
  }, "getInner");
  Append2.prototype.forEachInner = /* @__PURE__ */ __name(function forEachInner(f2, from2, to, start2) {
    var leftLen = this.left.length;
    if (from2 < leftLen && this.left.forEachInner(f2, from2, Math.min(to, leftLen), start2) === false) {
      return false;
    }
    if (to > leftLen && this.right.forEachInner(f2, Math.max(from2 - leftLen, 0), Math.min(this.length, to) - leftLen, start2 + leftLen) === false) {
      return false;
    }
  }, "forEachInner");
  Append2.prototype.forEachInvertedInner = /* @__PURE__ */ __name(function forEachInvertedInner(f2, from2, to, start2) {
    var leftLen = this.left.length;
    if (from2 > leftLen && this.right.forEachInvertedInner(f2, from2 - leftLen, Math.max(to, leftLen) - leftLen, start2 + leftLen) === false) {
      return false;
    }
    if (to < leftLen && this.left.forEachInvertedInner(f2, Math.min(from2, leftLen), to, start2) === false) {
      return false;
    }
  }, "forEachInvertedInner");
  Append2.prototype.sliceInner = /* @__PURE__ */ __name(function sliceInner(from2, to) {
    if (from2 == 0 && to == this.length) {
      return this;
    }
    var leftLen = this.left.length;
    if (to <= leftLen) {
      return this.left.slice(from2, to);
    }
    if (from2 >= leftLen) {
      return this.right.slice(from2 - leftLen, to - leftLen);
    }
    return this.left.slice(from2, leftLen).append(this.right.slice(0, to - leftLen));
  }, "sliceInner");
  Append2.prototype.leafAppend = /* @__PURE__ */ __name(function leafAppend(other) {
    var inner = this.right.leafAppend(other);
    if (inner) {
      return new Append2(this.left, inner);
    }
  }, "leafAppend");
  Append2.prototype.leafPrepend = /* @__PURE__ */ __name(function leafPrepend(other) {
    var inner = this.left.leafPrepend(other);
    if (inner) {
      return new Append2(inner, this.right);
    }
  }, "leafPrepend");
  Append2.prototype.appendInner = /* @__PURE__ */ __name(function appendInner2(other) {
    if (this.left.depth >= Math.max(this.right.depth, other.depth) + 1) {
      return new Append2(this.left, new Append2(this.right, other));
    }
    return new Append2(this, other);
  }, "appendInner");
  return Append2;
}(RopeSequence);
const max_empty_items = 500;
class Branch {
  static {
    __name(this, "Branch");
  }
  constructor(items2, eventCount) {
    this.items = items2;
    this.eventCount = eventCount;
  }
  // Pop the latest event off the branch's history and apply it
  // to a document transform.
  popEvent(state, preserveItems) {
    if (this.eventCount == 0)
      return null;
    let end = this.items.length;
    for (; ; end--) {
      let next2 = this.items.get(end - 1);
      if (next2.selection) {
        --end;
        break;
      }
    }
    let remap, mapFrom;
    if (preserveItems) {
      remap = this.remapping(end, this.items.length);
      mapFrom = remap.maps.length;
    }
    let transform2 = state.tr;
    let selection, remaining;
    let addAfter = [], addBefore = [];
    this.items.forEach((item3, i2) => {
      if (!item3.step) {
        if (!remap) {
          remap = this.remapping(end, i2 + 1);
          mapFrom = remap.maps.length;
        }
        mapFrom--;
        addBefore.push(item3);
        return;
      }
      if (remap) {
        addBefore.push(new Item(item3.map));
        let step2 = item3.step.map(remap.slice(mapFrom)), map3;
        if (step2 && transform2.maybeStep(step2).doc) {
          map3 = transform2.mapping.maps[transform2.mapping.maps.length - 1];
          addAfter.push(new Item(map3, void 0, void 0, addAfter.length + addBefore.length));
        }
        mapFrom--;
        if (map3)
          remap.appendMap(map3, mapFrom);
      } else {
        transform2.maybeStep(item3.step);
      }
      if (item3.selection) {
        selection = remap ? item3.selection.map(remap.slice(mapFrom)) : item3.selection;
        remaining = new Branch(this.items.slice(0, end).append(addBefore.reverse().concat(addAfter)), this.eventCount - 1);
        return false;
      }
    }, this.items.length, 0);
    return { remaining, transform: transform2, selection };
  }
  // Create a new branch with the given transform added.
  addTransform(transform2, selection, histOptions, preserveItems) {
    let newItems = [], eventCount = this.eventCount;
    let oldItems = this.items, lastItem = !preserveItems && oldItems.length ? oldItems.get(oldItems.length - 1) : null;
    for (let i2 = 0; i2 < transform2.steps.length; i2++) {
      let step2 = transform2.steps[i2].invert(transform2.docs[i2]);
      let item3 = new Item(transform2.mapping.maps[i2], step2, selection), merged;
      if (merged = lastItem && lastItem.merge(item3)) {
        item3 = merged;
        if (i2)
          newItems.pop();
        else
          oldItems = oldItems.slice(0, oldItems.length - 1);
      }
      newItems.push(item3);
      if (selection) {
        eventCount++;
        selection = void 0;
      }
      if (!preserveItems)
        lastItem = item3;
    }
    let overflow = eventCount - histOptions.depth;
    if (overflow > DEPTH_OVERFLOW) {
      oldItems = cutOffEvents(oldItems, overflow);
      eventCount -= overflow;
    }
    return new Branch(oldItems.append(newItems), eventCount);
  }
  remapping(from2, to) {
    let maps = new Mapping();
    this.items.forEach((item3, i2) => {
      let mirrorPos = item3.mirrorOffset != null && i2 - item3.mirrorOffset >= from2 ? maps.maps.length - item3.mirrorOffset : void 0;
      maps.appendMap(item3.map, mirrorPos);
    }, from2, to);
    return maps;
  }
  addMaps(array) {
    if (this.eventCount == 0)
      return this;
    return new Branch(this.items.append(array.map((map3) => new Item(map3))), this.eventCount);
  }
  // When the collab module receives remote changes, the history has
  // to know about those, so that it can adjust the steps that were
  // rebased on top of the remote changes, and include the position
  // maps for the remote changes in its array of items.
  rebased(rebasedTransform, rebasedCount) {
    if (!this.eventCount)
      return this;
    let rebasedItems = [], start2 = Math.max(0, this.items.length - rebasedCount);
    let mapping = rebasedTransform.mapping;
    let newUntil = rebasedTransform.steps.length;
    let eventCount = this.eventCount;
    this.items.forEach((item3) => {
      if (item3.selection)
        eventCount--;
    }, start2);
    let iRebased = rebasedCount;
    this.items.forEach((item3) => {
      let pos = mapping.getMirror(--iRebased);
      if (pos == null)
        return;
      newUntil = Math.min(newUntil, pos);
      let map3 = mapping.maps[pos];
      if (item3.step) {
        let step2 = rebasedTransform.steps[pos].invert(rebasedTransform.docs[pos]);
        let selection = item3.selection && item3.selection.map(mapping.slice(iRebased + 1, pos));
        if (selection)
          eventCount++;
        rebasedItems.push(new Item(map3, step2, selection));
      } else {
        rebasedItems.push(new Item(map3));
      }
    }, start2);
    let newMaps = [];
    for (let i2 = rebasedCount; i2 < newUntil; i2++)
      newMaps.push(new Item(mapping.maps[i2]));
    let items2 = this.items.slice(0, start2).append(newMaps).append(rebasedItems);
    let branch = new Branch(items2, eventCount);
    if (branch.emptyItemCount() > max_empty_items)
      branch = branch.compress(this.items.length - rebasedItems.length);
    return branch;
  }
  emptyItemCount() {
    let count = 0;
    this.items.forEach((item3) => {
      if (!item3.step)
        count++;
    });
    return count;
  }
  // Compressing a branch means rewriting it to push the air (map-only
  // items) out. During collaboration, these naturally accumulate
  // because each remote change adds one. The `upto` argument is used
  // to ensure that only the items below a given level are compressed,
  // because `rebased` relies on a clean, untouched set of items in
  // order to associate old items with rebased steps.
  compress(upto = this.items.length) {
    let remap = this.remapping(0, upto), mapFrom = remap.maps.length;
    let items2 = [], events2 = 0;
    this.items.forEach((item3, i2) => {
      if (i2 >= upto) {
        items2.push(item3);
        if (item3.selection)
          events2++;
      } else if (item3.step) {
        let step2 = item3.step.map(remap.slice(mapFrom)), map3 = step2 && step2.getMap();
        mapFrom--;
        if (map3)
          remap.appendMap(map3, mapFrom);
        if (step2) {
          let selection = item3.selection && item3.selection.map(remap.slice(mapFrom));
          if (selection)
            events2++;
          let newItem = new Item(map3.invert(), step2, selection), merged, last = items2.length - 1;
          if (merged = items2.length && items2[last].merge(newItem))
            items2[last] = merged;
          else
            items2.push(newItem);
        }
      } else if (item3.map) {
        mapFrom--;
      }
    }, this.items.length, 0);
    return new Branch(RopeSequence.from(items2.reverse()), events2);
  }
}
Branch.empty = new Branch(RopeSequence.empty, 0);
function cutOffEvents(items2, n2) {
  let cutPoint;
  items2.forEach((item3, i2) => {
    if (item3.selection && n2-- == 0) {
      cutPoint = i2;
      return false;
    }
  });
  return items2.slice(cutPoint);
}
__name(cutOffEvents, "cutOffEvents");
class Item {
  static {
    __name(this, "Item");
  }
  constructor(map3, step2, selection, mirrorOffset) {
    this.map = map3;
    this.step = step2;
    this.selection = selection;
    this.mirrorOffset = mirrorOffset;
  }
  merge(other) {
    if (this.step && other.step && !other.selection) {
      let step2 = other.step.merge(this.step);
      if (step2)
        return new Item(step2.getMap().invert(), step2, this.selection);
    }
  }
}
class HistoryState {
  static {
    __name(this, "HistoryState");
  }
  constructor(done, undone, prevRanges, prevTime, prevComposition) {
    this.done = done;
    this.undone = undone;
    this.prevRanges = prevRanges;
    this.prevTime = prevTime;
    this.prevComposition = prevComposition;
  }
}
const DEPTH_OVERFLOW = 20;
function applyTransaction(history2, state, tr2, options5) {
  let historyTr = tr2.getMeta(historyKey), rebased;
  if (historyTr)
    return historyTr.historyState;
  if (tr2.getMeta(closeHistoryKey))
    history2 = new HistoryState(history2.done, history2.undone, null, 0, -1);
  let appended = tr2.getMeta("appendedTransaction");
  if (tr2.steps.length == 0) {
    return history2;
  } else if (appended && appended.getMeta(historyKey)) {
    if (appended.getMeta(historyKey).redo)
      return new HistoryState(history2.done.addTransform(tr2, void 0, options5, mustPreserveItems(state)), history2.undone, rangesFor(tr2.mapping.maps), history2.prevTime, history2.prevComposition);
    else
      return new HistoryState(history2.done, history2.undone.addTransform(tr2, void 0, options5, mustPreserveItems(state)), null, history2.prevTime, history2.prevComposition);
  } else if (tr2.getMeta("addToHistory") !== false && !(appended && appended.getMeta("addToHistory") === false)) {
    let composition = tr2.getMeta("composition");
    let newGroup = history2.prevTime == 0 || !appended && history2.prevComposition != composition && (history2.prevTime < (tr2.time || 0) - options5.newGroupDelay || !isAdjacentTo(tr2, history2.prevRanges));
    let prevRanges = appended ? mapRanges(history2.prevRanges, tr2.mapping) : rangesFor(tr2.mapping.maps);
    return new HistoryState(history2.done.addTransform(tr2, newGroup ? state.selection.getBookmark() : void 0, options5, mustPreserveItems(state)), Branch.empty, prevRanges, tr2.time, composition == null ? history2.prevComposition : composition);
  } else if (rebased = tr2.getMeta("rebased")) {
    return new HistoryState(history2.done.rebased(tr2, rebased), history2.undone.rebased(tr2, rebased), mapRanges(history2.prevRanges, tr2.mapping), history2.prevTime, history2.prevComposition);
  } else {
    return new HistoryState(history2.done.addMaps(tr2.mapping.maps), history2.undone.addMaps(tr2.mapping.maps), mapRanges(history2.prevRanges, tr2.mapping), history2.prevTime, history2.prevComposition);
  }
}
__name(applyTransaction, "applyTransaction");
function isAdjacentTo(transform2, prevRanges) {
  if (!prevRanges)
    return false;
  if (!transform2.docChanged)
    return true;
  let adjacent = false;
  transform2.mapping.maps[0].forEach((start2, end) => {
    for (let i2 = 0; i2 < prevRanges.length; i2 += 2)
      if (start2 <= prevRanges[i2 + 1] && end >= prevRanges[i2])
        adjacent = true;
  });
  return adjacent;
}
__name(isAdjacentTo, "isAdjacentTo");
function rangesFor(maps) {
  let result = [];
  for (let i2 = maps.length - 1; i2 >= 0 && result.length == 0; i2--)
    maps[i2].forEach((_from, _to, from2, to) => result.push(from2, to));
  return result;
}
__name(rangesFor, "rangesFor");
function mapRanges(ranges, mapping) {
  if (!ranges)
    return null;
  let result = [];
  for (let i2 = 0; i2 < ranges.length; i2 += 2) {
    let from2 = mapping.map(ranges[i2], 1), to = mapping.map(ranges[i2 + 1], -1);
    if (from2 <= to)
      result.push(from2, to);
  }
  return result;
}
__name(mapRanges, "mapRanges");
function histTransaction(history2, state, redo2) {
  let preserveItems = mustPreserveItems(state);
  let histOptions = historyKey.get(state).spec.config;
  let pop = (redo2 ? history2.undone : history2.done).popEvent(state, preserveItems);
  if (!pop)
    return null;
  let selection = pop.selection.resolve(pop.transform.doc);
  let added = (redo2 ? history2.done : history2.undone).addTransform(pop.transform, state.selection.getBookmark(), histOptions, preserveItems);
  let newHist = new HistoryState(redo2 ? added : pop.remaining, redo2 ? pop.remaining : added, null, 0, -1);
  return pop.transform.setSelection(selection).setMeta(historyKey, { redo: redo2, historyState: newHist });
}
__name(histTransaction, "histTransaction");
let cachedPreserveItems = false, cachedPreserveItemsPlugins = null;
function mustPreserveItems(state) {
  let plugins = state.plugins;
  if (cachedPreserveItemsPlugins != plugins) {
    cachedPreserveItems = false;
    cachedPreserveItemsPlugins = plugins;
    for (let i2 = 0; i2 < plugins.length; i2++)
      if (plugins[i2].spec.historyPreserveItems) {
        cachedPreserveItems = true;
        break;
      }
  }
  return cachedPreserveItems;
}
__name(mustPreserveItems, "mustPreserveItems");
function closeHistory(tr2) {
  return tr2.setMeta(closeHistoryKey, true);
}
__name(closeHistory, "closeHistory");
const historyKey = new PluginKey("history");
const closeHistoryKey = new PluginKey("closeHistory");
function history$1(config2 = {}) {
  config2 = {
    depth: config2.depth || 100,
    newGroupDelay: config2.newGroupDelay || 500
  };
  return new Plugin({
    key: historyKey,
    state: {
      init() {
        return new HistoryState(Branch.empty, Branch.empty, null, 0, -1);
      },
      apply(tr2, hist, state) {
        return applyTransaction(hist, state, tr2, config2);
      }
    },
    config: config2,
    props: {
      handleDOMEvents: {
        beforeinput(view, e2) {
          let inputType = e2.inputType;
          let command2 = inputType == "historyUndo" ? undo : inputType == "historyRedo" ? redo : null;
          if (!command2)
            return false;
          e2.preventDefault();
          return command2(view.state, view.dispatch);
        }
      }
    }
  });
}
__name(history$1, "history$1");
function buildCommand(redo2, scroll) {
  return (state, dispatch) => {
    let hist = historyKey.getState(state);
    if (!hist || (redo2 ? hist.undone : hist.done).eventCount == 0)
      return false;
    if (dispatch) {
      let tr2 = histTransaction(hist, state, redo2);
      if (tr2)
        dispatch(scroll ? tr2.scrollIntoView() : tr2);
    }
    return true;
  };
}
__name(buildCommand, "buildCommand");
const undo = buildCommand(false, true);
const redo = buildCommand(true, true);
const undoNoScroll = buildCommand(false, false);
const redoNoScroll = buildCommand(true, false);
function undoDepth(state) {
  let hist = historyKey.getState(state);
  return hist ? hist.done.eventCount : 0;
}
__name(undoDepth, "undoDepth");
function redoDepth(state) {
  let hist = historyKey.getState(state);
  return hist ? hist.undone.eventCount : 0;
}
__name(redoDepth, "redoDepth");
const History = Extension.create({
  name: "history",
  addOptions() {
    return {
      depth: 100,
      newGroupDelay: 500
    };
  },
  addCommands() {
    return {
      undo: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return undo(state, dispatch);
      }, "undo"),
      redo: /* @__PURE__ */ __name(() => ({ state, dispatch }) => {
        return redo(state, dispatch);
      }, "redo")
    };
  },
  addProseMirrorPlugins() {
    return [
      history$1(this.options)
    ];
  },
  addKeyboardShortcuts() {
    return {
      "Mod-z": /* @__PURE__ */ __name(() => this.editor.commands.undo(), "Mod-z"),
      "Shift-Mod-z": /* @__PURE__ */ __name(() => this.editor.commands.redo(), "Shift-Mod-z"),
      "Mod-y": /* @__PURE__ */ __name(() => this.editor.commands.redo(), "Mod-y"),
      // Russian keyboard layouts
      "Mod-я": /* @__PURE__ */ __name(() => this.editor.commands.undo(), "Mod-я"),
      "Shift-Mod-я": /* @__PURE__ */ __name(() => this.editor.commands.redo(), "Shift-Mod-я")
    };
  }
});
const HorizontalRule$2 = Node$1.create({
  name: "horizontalRule",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  group: "block",
  parseHTML() {
    return [{ tag: "hr" }];
  },
  renderHTML({ HTMLAttributes }) {
    return ["hr", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes)];
  },
  addCommands() {
    return {
      setHorizontalRule: /* @__PURE__ */ __name(() => ({ chain, state }) => {
        const { selection } = state;
        const { $from: $originFrom, $to: $originTo } = selection;
        const currentChain = chain();
        if ($originFrom.parentOffset === 0) {
          currentChain.insertContentAt({
            from: Math.max($originFrom.pos - 1, 0),
            to: $originTo.pos
          }, {
            type: this.name
          });
        } else if (isNodeSelection(selection)) {
          currentChain.insertContentAt($originTo.pos, {
            type: this.name
          });
        } else {
          currentChain.insertContent({ type: this.name });
        }
        return currentChain.command(({ tr: tr2, dispatch }) => {
          var _a2;
          if (dispatch) {
            const { $to } = tr2.selection;
            const posAfter = $to.end();
            if ($to.nodeAfter) {
              if ($to.nodeAfter.isTextblock) {
                tr2.setSelection(TextSelection.create(tr2.doc, $to.pos + 1));
              } else if ($to.nodeAfter.isBlock) {
                tr2.setSelection(NodeSelection.create(tr2.doc, $to.pos));
              } else {
                tr2.setSelection(TextSelection.create(tr2.doc, $to.pos));
              }
            } else {
              const node3 = (_a2 = $to.parent.type.contentMatch.defaultType) === null || _a2 === void 0 ? void 0 : _a2.create();
              if (node3) {
                tr2.insert(posAfter, node3);
                tr2.setSelection(TextSelection.create(tr2.doc, posAfter + 1));
              }
            }
            tr2.scrollIntoView();
          }
          return true;
        }).run();
      }, "setHorizontalRule")
    };
  },
  addInputRules() {
    return [
      nodeInputRule({
        find: /^(?:---|—-|___\s|\*\*\*\s)$/,
        type: this.type
      })
    ];
  }
});
const starInputRegex = /(?:^|\s)(\*(?!\s+\*)((?:[^*]+))\*(?!\s+\*))$/;
const starPasteRegex = /(?:^|\s)(\*(?!\s+\*)((?:[^*]+))\*(?!\s+\*))/g;
const underscoreInputRegex = /(?:^|\s)(_(?!\s+_)((?:[^_]+))_(?!\s+_))$/;
const underscorePasteRegex = /(?:^|\s)(_(?!\s+_)((?:[^_]+))_(?!\s+_))/g;
const Italic$2 = Mark.create({
  name: "italic",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  parseHTML() {
    return [
      {
        tag: "em"
      },
      {
        tag: "i",
        getAttrs: /* @__PURE__ */ __name((node3) => node3.style.fontStyle !== "normal" && null, "getAttrs")
      },
      {
        style: "font-style=normal",
        clearMark: /* @__PURE__ */ __name((mark2) => mark2.type.name === this.name, "clearMark")
      },
      {
        style: "font-style=italic"
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["em", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setItalic: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.setMark(this.name);
      }, "setItalic"),
      toggleItalic: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.toggleMark(this.name);
      }, "toggleItalic"),
      unsetItalic: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.unsetMark(this.name);
      }, "unsetItalic")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-i": /* @__PURE__ */ __name(() => this.editor.commands.toggleItalic(), "Mod-i"),
      "Mod-I": /* @__PURE__ */ __name(() => this.editor.commands.toggleItalic(), "Mod-I")
    };
  },
  addInputRules() {
    return [
      markInputRule({
        find: starInputRegex,
        type: this.type
      }),
      markInputRule({
        find: underscoreInputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: starPasteRegex,
        type: this.type
      }),
      markPasteRule({
        find: underscorePasteRegex,
        type: this.type
      })
    ];
  }
});
const ListItem$2 = Node$1.create({
  name: "listItem",
  addOptions() {
    return {
      HTMLAttributes: {},
      bulletListTypeName: "bulletList",
      orderedListTypeName: "orderedList"
    };
  },
  content: "paragraph block*",
  defining: true,
  parseHTML() {
    return [
      {
        tag: "li"
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["li", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addKeyboardShortcuts() {
    return {
      Enter: /* @__PURE__ */ __name(() => this.editor.commands.splitListItem(this.name), "Enter"),
      Tab: /* @__PURE__ */ __name(() => this.editor.commands.sinkListItem(this.name), "Tab"),
      "Shift-Tab": /* @__PURE__ */ __name(() => this.editor.commands.liftListItem(this.name), "Shift-Tab")
    };
  }
});
const ListItemName = "listItem";
const TextStyleName = "textStyle";
const inputRegex$1 = /^(\d+)\.\s$/;
const OrderedList$2 = Node$1.create({
  name: "orderedList",
  addOptions() {
    return {
      itemTypeName: "listItem",
      HTMLAttributes: {},
      keepMarks: false,
      keepAttributes: false
    };
  },
  group: "block list",
  content() {
    return `${this.options.itemTypeName}+`;
  },
  addAttributes() {
    return {
      start: {
        default: 1,
        parseHTML: /* @__PURE__ */ __name((element) => {
          return element.hasAttribute("start") ? parseInt(element.getAttribute("start") || "", 10) : 1;
        }, "parseHTML")
      },
      type: {
        default: void 0,
        parseHTML: /* @__PURE__ */ __name((element) => element.getAttribute("type"), "parseHTML")
      }
    };
  },
  parseHTML() {
    return [
      {
        tag: "ol"
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    const { start: start2, ...attributesWithoutStart } = HTMLAttributes;
    return start2 === 1 ? ["ol", mergeAttributes(this.options.HTMLAttributes, attributesWithoutStart), 0] : ["ol", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      toggleOrderedList: /* @__PURE__ */ __name(() => ({ commands: commands2, chain }) => {
        if (this.options.keepAttributes) {
          return chain().toggleList(this.name, this.options.itemTypeName, this.options.keepMarks).updateAttributes(ListItemName, this.editor.getAttributes(TextStyleName)).run();
        }
        return commands2.toggleList(this.name, this.options.itemTypeName, this.options.keepMarks);
      }, "toggleOrderedList")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Shift-7": /* @__PURE__ */ __name(() => this.editor.commands.toggleOrderedList(), "Mod-Shift-7")
    };
  },
  addInputRules() {
    let inputRule = wrappingInputRule({
      find: inputRegex$1,
      type: this.type,
      getAttributes: /* @__PURE__ */ __name((match2) => ({ start: +match2[1] }), "getAttributes"),
      joinPredicate: /* @__PURE__ */ __name((match2, node3) => node3.childCount + node3.attrs.start === +match2[1], "joinPredicate")
    });
    if (this.options.keepMarks || this.options.keepAttributes) {
      inputRule = wrappingInputRule({
        find: inputRegex$1,
        type: this.type,
        keepMarks: this.options.keepMarks,
        keepAttributes: this.options.keepAttributes,
        getAttributes: /* @__PURE__ */ __name((match2) => ({ start: +match2[1], ...this.editor.getAttributes(TextStyleName) }), "getAttributes"),
        joinPredicate: /* @__PURE__ */ __name((match2, node3) => node3.childCount + node3.attrs.start === +match2[1], "joinPredicate"),
        editor: this.editor
      });
    }
    return [
      inputRule
    ];
  }
});
const Paragraph$2 = Node$1.create({
  name: "paragraph",
  priority: 1e3,
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  group: "block",
  content: "inline*",
  parseHTML() {
    return [
      { tag: "p" }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["p", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setParagraph: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.setNode(this.name);
      }, "setParagraph")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Alt-0": /* @__PURE__ */ __name(() => this.editor.commands.setParagraph(), "Mod-Alt-0")
    };
  }
});
const inputRegex = /(?:^|\s)(~~(?!\s+~~)((?:[^~]+))~~(?!\s+~~))$/;
const pasteRegex = /(?:^|\s)(~~(?!\s+~~)((?:[^~]+))~~(?!\s+~~))/g;
const Strike$2 = Mark.create({
  name: "strike",
  addOptions() {
    return {
      HTMLAttributes: {}
    };
  },
  parseHTML() {
    return [
      {
        tag: "s"
      },
      {
        tag: "del"
      },
      {
        tag: "strike"
      },
      {
        style: "text-decoration",
        consuming: false,
        getAttrs: /* @__PURE__ */ __name((style2) => style2.includes("line-through") ? {} : false, "getAttrs")
      }
    ];
  },
  renderHTML({ HTMLAttributes }) {
    return ["s", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  addCommands() {
    return {
      setStrike: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.setMark(this.name);
      }, "setStrike"),
      toggleStrike: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.toggleMark(this.name);
      }, "toggleStrike"),
      unsetStrike: /* @__PURE__ */ __name(() => ({ commands: commands2 }) => {
        return commands2.unsetMark(this.name);
      }, "unsetStrike")
    };
  },
  addKeyboardShortcuts() {
    return {
      "Mod-Shift-s": /* @__PURE__ */ __name(() => this.editor.commands.toggleStrike(), "Mod-Shift-s")
    };
  },
  addInputRules() {
    return [
      markInputRule({
        find: inputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: pasteRegex,
        type: this.type
      })
    ];
  }
});
const Text$2 = Node$1.create({
  name: "text",
  group: "inline"
});
const StarterKit = Extension.create({
  name: "starterKit",
  addExtensions() {
    var _a2, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t;
    const extensions = [];
    if (this.options.bold !== false) {
      extensions.push(Bold$2.configure((_a2 = this.options) === null || _a2 === void 0 ? void 0 : _a2.bold));
    }
    if (this.options.blockquote !== false) {
      extensions.push(Blockquote$2.configure((_b = this.options) === null || _b === void 0 ? void 0 : _b.blockquote));
    }
    if (this.options.bulletList !== false) {
      extensions.push(BulletList$2.configure((_c = this.options) === null || _c === void 0 ? void 0 : _c.bulletList));
    }
    if (this.options.code !== false) {
      extensions.push(Code$2.configure((_d = this.options) === null || _d === void 0 ? void 0 : _d.code));
    }
    if (this.options.codeBlock !== false) {
      extensions.push(CodeBlock$2.configure((_e = this.options) === null || _e === void 0 ? void 0 : _e.codeBlock));
    }
    if (this.options.document !== false) {
      extensions.push(Document$1.configure((_f = this.options) === null || _f === void 0 ? void 0 : _f.document));
    }
    if (this.options.dropcursor !== false) {
      extensions.push(Dropcursor.configure((_g = this.options) === null || _g === void 0 ? void 0 : _g.dropcursor));
    }
    if (this.options.gapcursor !== false) {
      extensions.push(Gapcursor.configure((_h = this.options) === null || _h === void 0 ? void 0 : _h.gapcursor));
    }
    if (this.options.hardBreak !== false) {
      extensions.push(HardBreak$2.configure((_j = this.options) === null || _j === void 0 ? void 0 : _j.hardBreak));
    }
    if (this.options.heading !== false) {
      extensions.push(Heading$2.configure((_k = this.options) === null || _k === void 0 ? void 0 : _k.heading));
    }
    if (this.options.history !== false) {
      extensions.push(History.configure((_l = this.options) === null || _l === void 0 ? void 0 : _l.history));
    }
    if (this.options.horizontalRule !== false) {
      extensions.push(HorizontalRule$2.configure((_m = this.options) === null || _m === void 0 ? void 0 : _m.horizontalRule));
    }
    if (this.options.italic !== false) {
      extensions.push(Italic$2.configure((_o = this.options) === null || _o === void 0 ? void 0 : _o.italic));
    }
    if (this.options.listItem !== false) {
      extensions.push(ListItem$2.configure((_p = this.options) === null || _p === void 0 ? void 0 : _p.listItem));
    }
    if (this.options.orderedList !== false) {
      extensions.push(OrderedList$2.configure((_q = this.options) === null || _q === void 0 ? void 0 : _q.orderedList));
    }
    if (this.options.paragraph !== false) {
      extensions.push(Paragraph$2.configure((_r = this.options) === null || _r === void 0 ? void 0 : _r.paragraph));
    }
    if (this.options.strike !== false) {
      extensions.push(Strike$2.configure((_s = this.options) === null || _s === void 0 ? void 0 : _s.strike));
    }
    if (this.options.text !== false) {
      extensions.push(Text$2.configure((_t = this.options) === null || _t === void 0 ? void 0 : _t.text));
    }
    return extensions;
  }
});
const decodeCache = {};
function getDecodeCache(exclude) {
  let cache2 = decodeCache[exclude];
  if (cache2) {
    return cache2;
  }
  cache2 = decodeCache[exclude] = [];
  for (let i2 = 0; i2 < 128; i2++) {
    const ch = String.fromCharCode(i2);
    cache2.push(ch);
  }
  for (let i2 = 0; i2 < exclude.length; i2++) {
    const ch = exclude.charCodeAt(i2);
    cache2[ch] = "%" + ("0" + ch.toString(16).toUpperCase()).slice(-2);
  }
  return cache2;
}
__name(getDecodeCache, "getDecodeCache");
function decode$2(string, exclude) {
  if (typeof exclude !== "string") {
    exclude = decode$2.defaultChars;
  }
  const cache2 = getDecodeCache(exclude);
  return string.replace(/(%[a-f0-9]{2})+/gi, function(seq) {
    let result = "";
    for (let i2 = 0, l2 = seq.length; i2 < l2; i2 += 3) {
      const b1 = parseInt(seq.slice(i2 + 1, i2 + 3), 16);
      if (b1 < 128) {
        result += cache2[b1];
        continue;
      }
      if ((b1 & 224) === 192 && i2 + 3 < l2) {
        const b2 = parseInt(seq.slice(i2 + 4, i2 + 6), 16);
        if ((b2 & 192) === 128) {
          const chr = b1 << 6 & 1984 | b2 & 63;
          if (chr < 128) {
            result += "��";
          } else {
            result += String.fromCharCode(chr);
          }
          i2 += 3;
          continue;
        }
      }
      if ((b1 & 240) === 224 && i2 + 6 < l2) {
        const b2 = parseInt(seq.slice(i2 + 4, i2 + 6), 16);
        const b3 = parseInt(seq.slice(i2 + 7, i2 + 9), 16);
        if ((b2 & 192) === 128 && (b3 & 192) === 128) {
          const chr = b1 << 12 & 61440 | b2 << 6 & 4032 | b3 & 63;
          if (chr < 2048 || chr >= 55296 && chr <= 57343) {
            result += "���";
          } else {
            result += String.fromCharCode(chr);
          }
          i2 += 6;
          continue;
        }
      }
      if ((b1 & 248) === 240 && i2 + 9 < l2) {
        const b2 = parseInt(seq.slice(i2 + 4, i2 + 6), 16);
        const b3 = parseInt(seq.slice(i2 + 7, i2 + 9), 16);
        const b4 = parseInt(seq.slice(i2 + 10, i2 + 12), 16);
        if ((b2 & 192) === 128 && (b3 & 192) === 128 && (b4 & 192) === 128) {
          let chr = b1 << 18 & 1835008 | b2 << 12 & 258048 | b3 << 6 & 4032 | b4 & 63;
          if (chr < 65536 || chr > 1114111) {
            result += "����";
          } else {
            chr -= 65536;
            result += String.fromCharCode(55296 + (chr >> 10), 56320 + (chr & 1023));
          }
          i2 += 9;
          continue;
        }
      }
      result += "�";
    }
    return result;
  });
}
__name(decode$2, "decode$2");
decode$2.defaultChars = ";/?:@&=+$,#";
decode$2.componentChars = "";
const encodeCache = {};
function getEncodeCache(exclude) {
  let cache2 = encodeCache[exclude];
  if (cache2) {
    return cache2;
  }
  cache2 = encodeCache[exclude] = [];
  for (let i2 = 0; i2 < 128; i2++) {
    const ch = String.fromCharCode(i2);
    if (/^[0-9a-z]$/i.test(ch)) {
      cache2.push(ch);
    } else {
      cache2.push("%" + ("0" + i2.toString(16).toUpperCase()).slice(-2));
    }
  }
  for (let i2 = 0; i2 < exclude.length; i2++) {
    cache2[exclude.charCodeAt(i2)] = exclude[i2];
  }
  return cache2;
}
__name(getEncodeCache, "getEncodeCache");
function encode$2(string, exclude, keepEscaped) {
  if (typeof exclude !== "string") {
    keepEscaped = exclude;
    exclude = encode$2.defaultChars;
  }
  if (typeof keepEscaped === "undefined") {
    keepEscaped = true;
  }
  const cache2 = getEncodeCache(exclude);
  let result = "";
  for (let i2 = 0, l2 = string.length; i2 < l2; i2++) {
    const code2 = string.charCodeAt(i2);
    if (keepEscaped && code2 === 37 && i2 + 2 < l2) {
      if (/^[0-9a-f]{2}$/i.test(string.slice(i2 + 1, i2 + 3))) {
        result += string.slice(i2, i2 + 3);
        i2 += 2;
        continue;
      }
    }
    if (code2 < 128) {
      result += cache2[code2];
      continue;
    }
    if (code2 >= 55296 && code2 <= 57343) {
      if (code2 >= 55296 && code2 <= 56319 && i2 + 1 < l2) {
        const nextCode = string.charCodeAt(i2 + 1);
        if (nextCode >= 56320 && nextCode <= 57343) {
          result += encodeURIComponent(string[i2] + string[i2 + 1]);
          i2++;
          continue;
        }
      }
      result += "%EF%BF%BD";
      continue;
    }
    result += encodeURIComponent(string[i2]);
  }
  return result;
}
__name(encode$2, "encode$2");
encode$2.defaultChars = ";/?:@&=+$,-_.!~*'()#";
encode$2.componentChars = "-_.!~*'()";
function format(url) {
  let result = "";
  result += url.protocol || "";
  result += url.slashes ? "//" : "";
  result += url.auth ? url.auth + "@" : "";
  if (url.hostname && url.hostname.indexOf(":") !== -1) {
    result += "[" + url.hostname + "]";
  } else {
    result += url.hostname || "";
  }
  result += url.port ? ":" + url.port : "";
  result += url.pathname || "";
  result += url.search || "";
  result += url.hash || "";
  return result;
}
__name(format, "format");
;
function Url() {
  this.protocol = null;
  this.slashes = null;
  this.auth = null;
  this.port = null;
  this.hostname = null;
  this.hash = null;
  this.search = null;
  this.pathname = null;
}
__name(Url, "Url");
const protocolPattern = /^([a-z0-9.+-]+:)/i;
const portPattern = /:[0-9]*$/;
const simplePathPattern = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/;
const delims = ["<", ">", '"', "`", " ", "\r", "\n", "	"];
const unwise = ["{", "}", "|", "\\", "^", "`"].concat(delims);
const autoEscape = ["'"].concat(unwise);
const nonHostChars = ["%", "/", "?", ";", "#"].concat(autoEscape);
const hostEndingChars = ["/", "?", "#"];
const hostnameMaxLen = 255;
const hostnamePartPattern = /^[+a-z0-9A-Z_-]{0,63}$/;
const hostnamePartStart = /^([+a-z0-9A-Z_-]{0,63})(.*)$/;
const hostlessProtocol = {
  javascript: true,
  "javascript:": true
};
const slashedProtocol = {
  http: true,
  https: true,
  ftp: true,
  gopher: true,
  file: true,
  "http:": true,
  "https:": true,
  "ftp:": true,
  "gopher:": true,
  "file:": true
};
function urlParse(url, slashesDenoteHost) {
  if (url && url instanceof Url) return url;
  const u2 = new Url();
  u2.parse(url, slashesDenoteHost);
  return u2;
}
__name(urlParse, "urlParse");
Url.prototype.parse = function(url, slashesDenoteHost) {
  let lowerProto, hec, slashes;
  let rest = url;
  rest = rest.trim();
  if (!slashesDenoteHost && url.split("#").length === 1) {
    const simplePath = simplePathPattern.exec(rest);
    if (simplePath) {
      this.pathname = simplePath[1];
      if (simplePath[2]) {
        this.search = simplePath[2];
      }
      return this;
    }
  }
  let proto = protocolPattern.exec(rest);
  if (proto) {
    proto = proto[0];
    lowerProto = proto.toLowerCase();
    this.protocol = proto;
    rest = rest.substr(proto.length);
  }
  if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
    slashes = rest.substr(0, 2) === "//";
    if (slashes && !(proto && hostlessProtocol[proto])) {
      rest = rest.substr(2);
      this.slashes = true;
    }
  }
  if (!hostlessProtocol[proto] && (slashes || proto && !slashedProtocol[proto])) {
    let hostEnd = -1;
    for (let i2 = 0; i2 < hostEndingChars.length; i2++) {
      hec = rest.indexOf(hostEndingChars[i2]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd)) {
        hostEnd = hec;
      }
    }
    let auth, atSign;
    if (hostEnd === -1) {
      atSign = rest.lastIndexOf("@");
    } else {
      atSign = rest.lastIndexOf("@", hostEnd);
    }
    if (atSign !== -1) {
      auth = rest.slice(0, atSign);
      rest = rest.slice(atSign + 1);
      this.auth = auth;
    }
    hostEnd = -1;
    for (let i2 = 0; i2 < nonHostChars.length; i2++) {
      hec = rest.indexOf(nonHostChars[i2]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd)) {
        hostEnd = hec;
      }
    }
    if (hostEnd === -1) {
      hostEnd = rest.length;
    }
    if (rest[hostEnd - 1] === ":") {
      hostEnd--;
    }
    const host = rest.slice(0, hostEnd);
    rest = rest.slice(hostEnd);
    this.parseHost(host);
    this.hostname = this.hostname || "";
    const ipv6Hostname = this.hostname[0] === "[" && this.hostname[this.hostname.length - 1] === "]";
    if (!ipv6Hostname) {
      const hostparts = this.hostname.split(/\./);
      for (let i2 = 0, l2 = hostparts.length; i2 < l2; i2++) {
        const part = hostparts[i2];
        if (!part) {
          continue;
        }
        if (!part.match(hostnamePartPattern)) {
          let newpart = "";
          for (let j2 = 0, k2 = part.length; j2 < k2; j2++) {
            if (part.charCodeAt(j2) > 127) {
              newpart += "x";
            } else {
              newpart += part[j2];
            }
          }
          if (!newpart.match(hostnamePartPattern)) {
            const validParts = hostparts.slice(0, i2);
            const notHost = hostparts.slice(i2 + 1);
            const bit = part.match(hostnamePartStart);
            if (bit) {
              validParts.push(bit[1]);
              notHost.unshift(bit[2]);
            }
            if (notHost.length) {
              rest = notHost.join(".") + rest;
            }
            this.hostname = validParts.join(".");
            break;
          }
        }
      }
    }
    if (this.hostname.length > hostnameMaxLen) {
      this.hostname = "";
    }
    if (ipv6Hostname) {
      this.hostname = this.hostname.substr(1, this.hostname.length - 2);
    }
  }
  const hash = rest.indexOf("#");
  if (hash !== -1) {
    this.hash = rest.substr(hash);
    rest = rest.slice(0, hash);
  }
  const qm = rest.indexOf("?");
  if (qm !== -1) {
    this.search = rest.substr(qm);
    rest = rest.slice(0, qm);
  }
  if (rest) {
    this.pathname = rest;
  }
  if (slashedProtocol[lowerProto] && this.hostname && !this.pathname) {
    this.pathname = "";
  }
  return this;
};
Url.prototype.parseHost = function(host) {
  let port = portPattern.exec(host);
  if (port) {
    port = port[0];
    if (port !== ":") {
      this.port = port.substr(1);
    }
    host = host.substr(0, host.length - port.length);
  }
  if (host) {
    this.hostname = host;
  }
};
const mdurl = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  decode: decode$2,
  encode: encode$2,
  format,
  parse: urlParse
}, Symbol.toStringTag, { value: "Module" }));
const Any = /[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/;
const Cc = /[\0-\x1F\x7F-\x9F]/;
const regex$1 = /[\xAD\u0600-\u0605\u061C\u06DD\u070F\u0890\u0891\u08E2\u180E\u200B-\u200F\u202A-\u202E\u2060-\u2064\u2066-\u206F\uFEFF\uFFF9-\uFFFB]|\uD804[\uDCBD\uDCCD]|\uD80D[\uDC30-\uDC3F]|\uD82F[\uDCA0-\uDCA3]|\uD834[\uDD73-\uDD7A]|\uDB40[\uDC01\uDC20-\uDC7F]/;
const P = /[!-#%-\*,-\/:;\?@\[-\]_\{\}\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061D-\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C77\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1B7D\u1B7E\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4F\u2E52-\u2E5D\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]|\uD800[\uDD00-\uDD02\uDF9F\uDFD0]|\uD801\uDD6F|\uD802[\uDC57\uDD1F\uDD3F\uDE50-\uDE58\uDE7F\uDEF0-\uDEF6\uDF39-\uDF3F\uDF99-\uDF9C]|\uD803[\uDEAD\uDF55-\uDF59\uDF86-\uDF89]|\uD804[\uDC47-\uDC4D\uDCBB\uDCBC\uDCBE-\uDCC1\uDD40-\uDD43\uDD74\uDD75\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDDF\uDE38-\uDE3D\uDEA9]|\uD805[\uDC4B-\uDC4F\uDC5A\uDC5B\uDC5D\uDCC6\uDDC1-\uDDD7\uDE41-\uDE43\uDE60-\uDE6C\uDEB9\uDF3C-\uDF3E]|\uD806[\uDC3B\uDD44-\uDD46\uDDE2\uDE3F-\uDE46\uDE9A-\uDE9C\uDE9E-\uDEA2\uDF00-\uDF09]|\uD807[\uDC41-\uDC45\uDC70\uDC71\uDEF7\uDEF8\uDF43-\uDF4F\uDFFF]|\uD809[\uDC70-\uDC74]|\uD80B[\uDFF1\uDFF2]|\uD81A[\uDE6E\uDE6F\uDEF5\uDF37-\uDF3B\uDF44]|\uD81B[\uDE97-\uDE9A\uDFE2]|\uD82F\uDC9F|\uD836[\uDE87-\uDE8B]|\uD83A[\uDD5E\uDD5F]/;
const regex = /[\$\+<->\^`\|~\xA2-\xA6\xA8\xA9\xAC\xAE-\xB1\xB4\xB8\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0384\u0385\u03F6\u0482\u058D-\u058F\u0606-\u0608\u060B\u060E\u060F\u06DE\u06E9\u06FD\u06FE\u07F6\u07FE\u07FF\u0888\u09F2\u09F3\u09FA\u09FB\u0AF1\u0B70\u0BF3-\u0BFA\u0C7F\u0D4F\u0D79\u0E3F\u0F01-\u0F03\u0F13\u0F15-\u0F17\u0F1A-\u0F1F\u0F34\u0F36\u0F38\u0FBE-\u0FC5\u0FC7-\u0FCC\u0FCE\u0FCF\u0FD5-\u0FD8\u109E\u109F\u1390-\u1399\u166D\u17DB\u1940\u19DE-\u19FF\u1B61-\u1B6A\u1B74-\u1B7C\u1FBD\u1FBF-\u1FC1\u1FCD-\u1FCF\u1FDD-\u1FDF\u1FED-\u1FEF\u1FFD\u1FFE\u2044\u2052\u207A-\u207C\u208A-\u208C\u20A0-\u20C0\u2100\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F\u218A\u218B\u2190-\u2307\u230C-\u2328\u232B-\u2426\u2440-\u244A\u249C-\u24E9\u2500-\u2767\u2794-\u27C4\u27C7-\u27E5\u27F0-\u2982\u2999-\u29D7\u29DC-\u29FB\u29FE-\u2B73\u2B76-\u2B95\u2B97-\u2BFF\u2CE5-\u2CEA\u2E50\u2E51\u2E80-\u2E99\u2E9B-\u2EF3\u2F00-\u2FD5\u2FF0-\u2FFF\u3004\u3012\u3013\u3020\u3036\u3037\u303E\u303F\u309B\u309C\u3190\u3191\u3196-\u319F\u31C0-\u31E3\u31EF\u3200-\u321E\u322A-\u3247\u3250\u3260-\u327F\u328A-\u32B0\u32C0-\u33FF\u4DC0-\u4DFF\uA490-\uA4C6\uA700-\uA716\uA720\uA721\uA789\uA78A\uA828-\uA82B\uA836-\uA839\uAA77-\uAA79\uAB5B\uAB6A\uAB6B\uFB29\uFBB2-\uFBC2\uFD40-\uFD4F\uFDCF\uFDFC-\uFDFF\uFE62\uFE64-\uFE66\uFE69\uFF04\uFF0B\uFF1C-\uFF1E\uFF3E\uFF40\uFF5C\uFF5E\uFFE0-\uFFE6\uFFE8-\uFFEE\uFFFC\uFFFD]|\uD800[\uDD37-\uDD3F\uDD79-\uDD89\uDD8C-\uDD8E\uDD90-\uDD9C\uDDA0\uDDD0-\uDDFC]|\uD802[\uDC77\uDC78\uDEC8]|\uD805\uDF3F|\uD807[\uDFD5-\uDFF1]|\uD81A[\uDF3C-\uDF3F\uDF45]|\uD82F\uDC9C|\uD833[\uDF50-\uDFC3]|\uD834[\uDC00-\uDCF5\uDD00-\uDD26\uDD29-\uDD64\uDD6A-\uDD6C\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDDEA\uDE00-\uDE41\uDE45\uDF00-\uDF56]|\uD835[\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85\uDE86]|\uD838[\uDD4F\uDEFF]|\uD83B[\uDCAC\uDCB0\uDD2E\uDEF0\uDEF1]|\uD83C[\uDC00-\uDC2B\uDC30-\uDC93\uDCA0-\uDCAE\uDCB1-\uDCBF\uDCC1-\uDCCF\uDCD1-\uDCF5\uDD0D-\uDDAD\uDDE6-\uDE02\uDE10-\uDE3B\uDE40-\uDE48\uDE50\uDE51\uDE60-\uDE65\uDF00-\uDFFF]|\uD83D[\uDC00-\uDED7\uDEDC-\uDEEC\uDEF0-\uDEFC\uDF00-\uDF76\uDF7B-\uDFD9\uDFE0-\uDFEB\uDFF0]|\uD83E[\uDC00-\uDC0B\uDC10-\uDC47\uDC50-\uDC59\uDC60-\uDC87\uDC90-\uDCAD\uDCB0\uDCB1\uDD00-\uDE53\uDE60-\uDE6D\uDE70-\uDE7C\uDE80-\uDE88\uDE90-\uDEBD\uDEBF-\uDEC5\uDECE-\uDEDB\uDEE0-\uDEE8\uDEF0-\uDEF8\uDF00-\uDF92\uDF94-\uDFCA]/;
const Z = /[ \xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/;
const ucmicro = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  Any,
  Cc,
  Cf: regex$1,
  P,
  S: regex,
  Z
}, Symbol.toStringTag, { value: "Module" }));
const htmlDecodeTree = new Uint16Array(
  // prettier-ignore
  'ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map((c2) => c2.charCodeAt(0))
);
const xmlDecodeTree = new Uint16Array(
  // prettier-ignore
  "Ȁaglq	\x1Bɭ\0\0p;䀦os;䀧t;䀾t;䀼uot;䀢".split("").map((c2) => c2.charCodeAt(0))
);
var _a;
const decodeMap = /* @__PURE__ */ new Map([
  [0, 65533],
  // C1 Unicode control character reference replacements
  [128, 8364],
  [130, 8218],
  [131, 402],
  [132, 8222],
  [133, 8230],
  [134, 8224],
  [135, 8225],
  [136, 710],
  [137, 8240],
  [138, 352],
  [139, 8249],
  [140, 338],
  [142, 381],
  [145, 8216],
  [146, 8217],
  [147, 8220],
  [148, 8221],
  [149, 8226],
  [150, 8211],
  [151, 8212],
  [152, 732],
  [153, 8482],
  [154, 353],
  [155, 8250],
  [156, 339],
  [158, 382],
  [159, 376]
]);
const fromCodePoint$1 = (
  // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition, node/no-unsupported-features/es-builtins
  (_a = String.fromCodePoint) !== null && _a !== void 0 ? _a : function(codePoint) {
    let output = "";
    if (codePoint > 65535) {
      codePoint -= 65536;
      output += String.fromCharCode(codePoint >>> 10 & 1023 | 55296);
      codePoint = 56320 | codePoint & 1023;
    }
    output += String.fromCharCode(codePoint);
    return output;
  }
);
function replaceCodePoint(codePoint) {
  var _a2;
  if (codePoint >= 55296 && codePoint <= 57343 || codePoint > 1114111) {
    return 65533;
  }
  return (_a2 = decodeMap.get(codePoint)) !== null && _a2 !== void 0 ? _a2 : codePoint;
}
__name(replaceCodePoint, "replaceCodePoint");
function decodeCodePoint(codePoint) {
  return fromCodePoint$1(replaceCodePoint(codePoint));
}
__name(decodeCodePoint, "decodeCodePoint");
var CharCodes;
(function(CharCodes2) {
  CharCodes2[CharCodes2["NUM"] = 35] = "NUM";
  CharCodes2[CharCodes2["SEMI"] = 59] = "SEMI";
  CharCodes2[CharCodes2["EQUALS"] = 61] = "EQUALS";
  CharCodes2[CharCodes2["ZERO"] = 48] = "ZERO";
  CharCodes2[CharCodes2["NINE"] = 57] = "NINE";
  CharCodes2[CharCodes2["LOWER_A"] = 97] = "LOWER_A";
  CharCodes2[CharCodes2["LOWER_F"] = 102] = "LOWER_F";
  CharCodes2[CharCodes2["LOWER_X"] = 120] = "LOWER_X";
  CharCodes2[CharCodes2["LOWER_Z"] = 122] = "LOWER_Z";
  CharCodes2[CharCodes2["UPPER_A"] = 65] = "UPPER_A";
  CharCodes2[CharCodes2["UPPER_F"] = 70] = "UPPER_F";
  CharCodes2[CharCodes2["UPPER_Z"] = 90] = "UPPER_Z";
})(CharCodes || (CharCodes = {}));
const TO_LOWER_BIT = 32;
var BinTrieFlags;
(function(BinTrieFlags2) {
  BinTrieFlags2[BinTrieFlags2["VALUE_LENGTH"] = 49152] = "VALUE_LENGTH";
  BinTrieFlags2[BinTrieFlags2["BRANCH_LENGTH"] = 16256] = "BRANCH_LENGTH";
  BinTrieFlags2[BinTrieFlags2["JUMP_TABLE"] = 127] = "JUMP_TABLE";
})(BinTrieFlags || (BinTrieFlags = {}));
function isNumber(code2) {
  return code2 >= CharCodes.ZERO && code2 <= CharCodes.NINE;
}
__name(isNumber, "isNumber");
function isHexadecimalCharacter(code2) {
  return code2 >= CharCodes.UPPER_A && code2 <= CharCodes.UPPER_F || code2 >= CharCodes.LOWER_A && code2 <= CharCodes.LOWER_F;
}
__name(isHexadecimalCharacter, "isHexadecimalCharacter");
function isAsciiAlphaNumeric(code2) {
  return code2 >= CharCodes.UPPER_A && code2 <= CharCodes.UPPER_Z || code2 >= CharCodes.LOWER_A && code2 <= CharCodes.LOWER_Z || isNumber(code2);
}
__name(isAsciiAlphaNumeric, "isAsciiAlphaNumeric");
function isEntityInAttributeInvalidEnd(code2) {
  return code2 === CharCodes.EQUALS || isAsciiAlphaNumeric(code2);
}
__name(isEntityInAttributeInvalidEnd, "isEntityInAttributeInvalidEnd");
var EntityDecoderState;
(function(EntityDecoderState2) {
  EntityDecoderState2[EntityDecoderState2["EntityStart"] = 0] = "EntityStart";
  EntityDecoderState2[EntityDecoderState2["NumericStart"] = 1] = "NumericStart";
  EntityDecoderState2[EntityDecoderState2["NumericDecimal"] = 2] = "NumericDecimal";
  EntityDecoderState2[EntityDecoderState2["NumericHex"] = 3] = "NumericHex";
  EntityDecoderState2[EntityDecoderState2["NamedEntity"] = 4] = "NamedEntity";
})(EntityDecoderState || (EntityDecoderState = {}));
var DecodingMode;
(function(DecodingMode2) {
  DecodingMode2[DecodingMode2["Legacy"] = 0] = "Legacy";
  DecodingMode2[DecodingMode2["Strict"] = 1] = "Strict";
  DecodingMode2[DecodingMode2["Attribute"] = 2] = "Attribute";
})(DecodingMode || (DecodingMode = {}));
class EntityDecoder {
  static {
    __name(this, "EntityDecoder");
  }
  constructor(decodeTree, emitCodePoint, errors2) {
    this.decodeTree = decodeTree;
    this.emitCodePoint = emitCodePoint;
    this.errors = errors2;
    this.state = EntityDecoderState.EntityStart;
    this.consumed = 1;
    this.result = 0;
    this.treeIndex = 0;
    this.excess = 1;
    this.decodeMode = DecodingMode.Strict;
  }
  /** Resets the instance to make it reusable. */
  startEntity(decodeMode) {
    this.decodeMode = decodeMode;
    this.state = EntityDecoderState.EntityStart;
    this.result = 0;
    this.treeIndex = 0;
    this.excess = 1;
    this.consumed = 1;
  }
  /**
   * Write an entity to the decoder. This can be called multiple times with partial entities.
   * If the entity is incomplete, the decoder will return -1.
   *
   * Mirrors the implementation of `getDecoder`, but with the ability to stop decoding if the
   * entity is incomplete, and resume when the next string is written.
   *
   * @param string The string containing the entity (or a continuation of the entity).
   * @param offset The offset at which the entity begins. Should be 0 if this is not the first call.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  write(str, offset) {
    switch (this.state) {
      case EntityDecoderState.EntityStart: {
        if (str.charCodeAt(offset) === CharCodes.NUM) {
          this.state = EntityDecoderState.NumericStart;
          this.consumed += 1;
          return this.stateNumericStart(str, offset + 1);
        }
        this.state = EntityDecoderState.NamedEntity;
        return this.stateNamedEntity(str, offset);
      }
      case EntityDecoderState.NumericStart: {
        return this.stateNumericStart(str, offset);
      }
      case EntityDecoderState.NumericDecimal: {
        return this.stateNumericDecimal(str, offset);
      }
      case EntityDecoderState.NumericHex: {
        return this.stateNumericHex(str, offset);
      }
      case EntityDecoderState.NamedEntity: {
        return this.stateNamedEntity(str, offset);
      }
    }
  }
  /**
   * Switches between the numeric decimal and hexadecimal states.
   *
   * Equivalent to the `Numeric character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericStart(str, offset) {
    if (offset >= str.length) {
      return -1;
    }
    if ((str.charCodeAt(offset) | TO_LOWER_BIT) === CharCodes.LOWER_X) {
      this.state = EntityDecoderState.NumericHex;
      this.consumed += 1;
      return this.stateNumericHex(str, offset + 1);
    }
    this.state = EntityDecoderState.NumericDecimal;
    return this.stateNumericDecimal(str, offset);
  }
  addToNumericResult(str, start2, end, base2) {
    if (start2 !== end) {
      const digitCount = end - start2;
      this.result = this.result * Math.pow(base2, digitCount) + parseInt(str.substr(start2, digitCount), base2);
      this.consumed += digitCount;
    }
  }
  /**
   * Parses a hexadecimal numeric entity.
   *
   * Equivalent to the `Hexademical character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericHex(str, offset) {
    const startIdx = offset;
    while (offset < str.length) {
      const char = str.charCodeAt(offset);
      if (isNumber(char) || isHexadecimalCharacter(char)) {
        offset += 1;
      } else {
        this.addToNumericResult(str, startIdx, offset, 16);
        return this.emitNumericEntity(char, 3);
      }
    }
    this.addToNumericResult(str, startIdx, offset, 16);
    return -1;
  }
  /**
   * Parses a decimal numeric entity.
   *
   * Equivalent to the `Decimal character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericDecimal(str, offset) {
    const startIdx = offset;
    while (offset < str.length) {
      const char = str.charCodeAt(offset);
      if (isNumber(char)) {
        offset += 1;
      } else {
        this.addToNumericResult(str, startIdx, offset, 10);
        return this.emitNumericEntity(char, 2);
      }
    }
    this.addToNumericResult(str, startIdx, offset, 10);
    return -1;
  }
  /**
   * Validate and emit a numeric entity.
   *
   * Implements the logic from the `Hexademical character reference start
   * state` and `Numeric character reference end state` in the HTML spec.
   *
   * @param lastCp The last code point of the entity. Used to see if the
   *               entity was terminated with a semicolon.
   * @param expectedLength The minimum number of characters that should be
   *                       consumed. Used to validate that at least one digit
   *                       was consumed.
   * @returns The number of characters that were consumed.
   */
  emitNumericEntity(lastCp, expectedLength) {
    var _a2;
    if (this.consumed <= expectedLength) {
      (_a2 = this.errors) === null || _a2 === void 0 ? void 0 : _a2.absenceOfDigitsInNumericCharacterReference(this.consumed);
      return 0;
    }
    if (lastCp === CharCodes.SEMI) {
      this.consumed += 1;
    } else if (this.decodeMode === DecodingMode.Strict) {
      return 0;
    }
    this.emitCodePoint(replaceCodePoint(this.result), this.consumed);
    if (this.errors) {
      if (lastCp !== CharCodes.SEMI) {
        this.errors.missingSemicolonAfterCharacterReference();
      }
      this.errors.validateNumericCharacterReference(this.result);
    }
    return this.consumed;
  }
  /**
   * Parses a named entity.
   *
   * Equivalent to the `Named character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNamedEntity(str, offset) {
    const { decodeTree } = this;
    let current = decodeTree[this.treeIndex];
    let valueLength = (current & BinTrieFlags.VALUE_LENGTH) >> 14;
    for (; offset < str.length; offset++, this.excess++) {
      const char = str.charCodeAt(offset);
      this.treeIndex = determineBranch(decodeTree, current, this.treeIndex + Math.max(1, valueLength), char);
      if (this.treeIndex < 0) {
        return this.result === 0 || // If we are parsing an attribute
        this.decodeMode === DecodingMode.Attribute && // We shouldn't have consumed any characters after the entity,
        (valueLength === 0 || // And there should be no invalid characters.
        isEntityInAttributeInvalidEnd(char)) ? 0 : this.emitNotTerminatedNamedEntity();
      }
      current = decodeTree[this.treeIndex];
      valueLength = (current & BinTrieFlags.VALUE_LENGTH) >> 14;
      if (valueLength !== 0) {
        if (char === CharCodes.SEMI) {
          return this.emitNamedEntityData(this.treeIndex, valueLength, this.consumed + this.excess);
        }
        if (this.decodeMode !== DecodingMode.Strict) {
          this.result = this.treeIndex;
          this.consumed += this.excess;
          this.excess = 0;
        }
      }
    }
    return -1;
  }
  /**
   * Emit a named entity that was not terminated with a semicolon.
   *
   * @returns The number of characters consumed.
   */
  emitNotTerminatedNamedEntity() {
    var _a2;
    const { result, decodeTree } = this;
    const valueLength = (decodeTree[result] & BinTrieFlags.VALUE_LENGTH) >> 14;
    this.emitNamedEntityData(result, valueLength, this.consumed);
    (_a2 = this.errors) === null || _a2 === void 0 ? void 0 : _a2.missingSemicolonAfterCharacterReference();
    return this.consumed;
  }
  /**
   * Emit a named entity.
   *
   * @param result The index of the entity in the decode tree.
   * @param valueLength The number of bytes in the entity.
   * @param consumed The number of characters consumed.
   *
   * @returns The number of characters consumed.
   */
  emitNamedEntityData(result, valueLength, consumed) {
    const { decodeTree } = this;
    this.emitCodePoint(valueLength === 1 ? decodeTree[result] & ~BinTrieFlags.VALUE_LENGTH : decodeTree[result + 1], consumed);
    if (valueLength === 3) {
      this.emitCodePoint(decodeTree[result + 2], consumed);
    }
    return consumed;
  }
  /**
   * Signal to the parser that the end of the input was reached.
   *
   * Remaining data will be emitted and relevant errors will be produced.
   *
   * @returns The number of characters consumed.
   */
  end() {
    var _a2;
    switch (this.state) {
      case EntityDecoderState.NamedEntity: {
        return this.result !== 0 && (this.decodeMode !== DecodingMode.Attribute || this.result === this.treeIndex) ? this.emitNotTerminatedNamedEntity() : 0;
      }
      case EntityDecoderState.NumericDecimal: {
        return this.emitNumericEntity(0, 2);
      }
      case EntityDecoderState.NumericHex: {
        return this.emitNumericEntity(0, 3);
      }
      case EntityDecoderState.NumericStart: {
        (_a2 = this.errors) === null || _a2 === void 0 ? void 0 : _a2.absenceOfDigitsInNumericCharacterReference(this.consumed);
        return 0;
      }
      case EntityDecoderState.EntityStart: {
        return 0;
      }
    }
  }
}
function getDecoder(decodeTree) {
  let ret = "";
  const decoder = new EntityDecoder(decodeTree, (str) => ret += fromCodePoint$1(str));
  return /* @__PURE__ */ __name(function decodeWithTrie(str, decodeMode) {
    let lastIndex = 0;
    let offset = 0;
    while ((offset = str.indexOf("&", offset)) >= 0) {
      ret += str.slice(lastIndex, offset);
      decoder.startEntity(decodeMode);
      const len = decoder.write(
        str,
        // Skip the "&"
        offset + 1
      );
      if (len < 0) {
        lastIndex = offset + decoder.end();
        break;
      }
      lastIndex = offset + len;
      offset = len === 0 ? lastIndex + 1 : lastIndex;
    }
    const result = ret + str.slice(lastIndex);
    ret = "";
    return result;
  }, "decodeWithTrie");
}
__name(getDecoder, "getDecoder");
function determineBranch(decodeTree, current, nodeIdx, char) {
  const branchCount = (current & BinTrieFlags.BRANCH_LENGTH) >> 7;
  const jumpOffset = current & BinTrieFlags.JUMP_TABLE;
  if (branchCount === 0) {
    return jumpOffset !== 0 && char === jumpOffset ? nodeIdx : -1;
  }
  if (jumpOffset) {
    const value3 = char - jumpOffset;
    return value3 < 0 || value3 >= branchCount ? -1 : decodeTree[nodeIdx + value3] - 1;
  }
  let lo = nodeIdx;
  let hi = lo + branchCount - 1;
  while (lo <= hi) {
    const mid = lo + hi >>> 1;
    const midVal = decodeTree[mid];
    if (midVal < char) {
      lo = mid + 1;
    } else if (midVal > char) {
      hi = mid - 1;
    } else {
      return decodeTree[mid + branchCount];
    }
  }
  return -1;
}
__name(determineBranch, "determineBranch");
const htmlDecoder = getDecoder(htmlDecodeTree);
const xmlDecoder = getDecoder(xmlDecodeTree);
function decodeHTML(str, mode2 = DecodingMode.Legacy) {
  return htmlDecoder(str, mode2);
}
__name(decodeHTML, "decodeHTML");
function decodeHTMLAttribute(str) {
  return htmlDecoder(str, DecodingMode.Attribute);
}
__name(decodeHTMLAttribute, "decodeHTMLAttribute");
function decodeHTMLStrict(str) {
  return htmlDecoder(str, DecodingMode.Strict);
}
__name(decodeHTMLStrict, "decodeHTMLStrict");
function decodeXML(str) {
  return xmlDecoder(str, DecodingMode.Strict);
}
__name(decodeXML, "decodeXML");
function restoreDiff(arr) {
  for (let i2 = 1; i2 < arr.length; i2++) {
    arr[i2][0] += arr[i2 - 1][0] + 1;
  }
  return arr;
}
__name(restoreDiff, "restoreDiff");
const htmlTrie = new Map(/* @__PURE__ */ restoreDiff([[9, "&Tab;"], [0, "&NewLine;"], [22, "&excl;"], [0, "&quot;"], [0, "&num;"], [0, "&dollar;"], [0, "&percnt;"], [0, "&amp;"], [0, "&apos;"], [0, "&lpar;"], [0, "&rpar;"], [0, "&ast;"], [0, "&plus;"], [0, "&comma;"], [1, "&period;"], [0, "&sol;"], [10, "&colon;"], [0, "&semi;"], [0, { v: "&lt;", n: 8402, o: "&nvlt;" }], [0, { v: "&equals;", n: 8421, o: "&bne;" }], [0, { v: "&gt;", n: 8402, o: "&nvgt;" }], [0, "&quest;"], [0, "&commat;"], [26, "&lbrack;"], [0, "&bsol;"], [0, "&rbrack;"], [0, "&Hat;"], [0, "&lowbar;"], [0, "&DiacriticalGrave;"], [5, { n: 106, o: "&fjlig;" }], [20, "&lbrace;"], [0, "&verbar;"], [0, "&rbrace;"], [34, "&nbsp;"], [0, "&iexcl;"], [0, "&cent;"], [0, "&pound;"], [0, "&curren;"], [0, "&yen;"], [0, "&brvbar;"], [0, "&sect;"], [0, "&die;"], [0, "&copy;"], [0, "&ordf;"], [0, "&laquo;"], [0, "&not;"], [0, "&shy;"], [0, "&circledR;"], [0, "&macr;"], [0, "&deg;"], [0, "&PlusMinus;"], [0, "&sup2;"], [0, "&sup3;"], [0, "&acute;"], [0, "&micro;"], [0, "&para;"], [0, "&centerdot;"], [0, "&cedil;"], [0, "&sup1;"], [0, "&ordm;"], [0, "&raquo;"], [0, "&frac14;"], [0, "&frac12;"], [0, "&frac34;"], [0, "&iquest;"], [0, "&Agrave;"], [0, "&Aacute;"], [0, "&Acirc;"], [0, "&Atilde;"], [0, "&Auml;"], [0, "&angst;"], [0, "&AElig;"], [0, "&Ccedil;"], [0, "&Egrave;"], [0, "&Eacute;"], [0, "&Ecirc;"], [0, "&Euml;"], [0, "&Igrave;"], [0, "&Iacute;"], [0, "&Icirc;"], [0, "&Iuml;"], [0, "&ETH;"], [0, "&Ntilde;"], [0, "&Ograve;"], [0, "&Oacute;"], [0, "&Ocirc;"], [0, "&Otilde;"], [0, "&Ouml;"], [0, "&times;"], [0, "&Oslash;"], [0, "&Ugrave;"], [0, "&Uacute;"], [0, "&Ucirc;"], [0, "&Uuml;"], [0, "&Yacute;"], [0, "&THORN;"], [0, "&szlig;"], [0, "&agrave;"], [0, "&aacute;"], [0, "&acirc;"], [0, "&atilde;"], [0, "&auml;"], [0, "&aring;"], [0, "&aelig;"], [0, "&ccedil;"], [0, "&egrave;"], [0, "&eacute;"], [0, "&ecirc;"], [0, "&euml;"], [0, "&igrave;"], [0, "&iacute;"], [0, "&icirc;"], [0, "&iuml;"], [0, "&eth;"], [0, "&ntilde;"], [0, "&ograve;"], [0, "&oacute;"], [0, "&ocirc;"], [0, "&otilde;"], [0, "&ouml;"], [0, "&div;"], [0, "&oslash;"], [0, "&ugrave;"], [0, "&uacute;"], [0, "&ucirc;"], [0, "&uuml;"], [0, "&yacute;"], [0, "&thorn;"], [0, "&yuml;"], [0, "&Amacr;"], [0, "&amacr;"], [0, "&Abreve;"], [0, "&abreve;"], [0, "&Aogon;"], [0, "&aogon;"], [0, "&Cacute;"], [0, "&cacute;"], [0, "&Ccirc;"], [0, "&ccirc;"], [0, "&Cdot;"], [0, "&cdot;"], [0, "&Ccaron;"], [0, "&ccaron;"], [0, "&Dcaron;"], [0, "&dcaron;"], [0, "&Dstrok;"], [0, "&dstrok;"], [0, "&Emacr;"], [0, "&emacr;"], [2, "&Edot;"], [0, "&edot;"], [0, "&Eogon;"], [0, "&eogon;"], [0, "&Ecaron;"], [0, "&ecaron;"], [0, "&Gcirc;"], [0, "&gcirc;"], [0, "&Gbreve;"], [0, "&gbreve;"], [0, "&Gdot;"], [0, "&gdot;"], [0, "&Gcedil;"], [1, "&Hcirc;"], [0, "&hcirc;"], [0, "&Hstrok;"], [0, "&hstrok;"], [0, "&Itilde;"], [0, "&itilde;"], [0, "&Imacr;"], [0, "&imacr;"], [2, "&Iogon;"], [0, "&iogon;"], [0, "&Idot;"], [0, "&imath;"], [0, "&IJlig;"], [0, "&ijlig;"], [0, "&Jcirc;"], [0, "&jcirc;"], [0, "&Kcedil;"], [0, "&kcedil;"], [0, "&kgreen;"], [0, "&Lacute;"], [0, "&lacute;"], [0, "&Lcedil;"], [0, "&lcedil;"], [0, "&Lcaron;"], [0, "&lcaron;"], [0, "&Lmidot;"], [0, "&lmidot;"], [0, "&Lstrok;"], [0, "&lstrok;"], [0, "&Nacute;"], [0, "&nacute;"], [0, "&Ncedil;"], [0, "&ncedil;"], [0, "&Ncaron;"], [0, "&ncaron;"], [0, "&napos;"], [0, "&ENG;"], [0, "&eng;"], [0, "&Omacr;"], [0, "&omacr;"], [2, "&Odblac;"], [0, "&odblac;"], [0, "&OElig;"], [0, "&oelig;"], [0, "&Racute;"], [0, "&racute;"], [0, "&Rcedil;"], [0, "&rcedil;"], [0, "&Rcaron;"], [0, "&rcaron;"], [0, "&Sacute;"], [0, "&sacute;"], [0, "&Scirc;"], [0, "&scirc;"], [0, "&Scedil;"], [0, "&scedil;"], [0, "&Scaron;"], [0, "&scaron;"], [0, "&Tcedil;"], [0, "&tcedil;"], [0, "&Tcaron;"], [0, "&tcaron;"], [0, "&Tstrok;"], [0, "&tstrok;"], [0, "&Utilde;"], [0, "&utilde;"], [0, "&Umacr;"], [0, "&umacr;"], [0, "&Ubreve;"], [0, "&ubreve;"], [0, "&Uring;"], [0, "&uring;"], [0, "&Udblac;"], [0, "&udblac;"], [0, "&Uogon;"], [0, "&uogon;"], [0, "&Wcirc;"], [0, "&wcirc;"], [0, "&Ycirc;"], [0, "&ycirc;"], [0, "&Yuml;"], [0, "&Zacute;"], [0, "&zacute;"], [0, "&Zdot;"], [0, "&zdot;"], [0, "&Zcaron;"], [0, "&zcaron;"], [19, "&fnof;"], [34, "&imped;"], [63, "&gacute;"], [65, "&jmath;"], [142, "&circ;"], [0, "&caron;"], [16, "&breve;"], [0, "&DiacriticalDot;"], [0, "&ring;"], [0, "&ogon;"], [0, "&DiacriticalTilde;"], [0, "&dblac;"], [51, "&DownBreve;"], [127, "&Alpha;"], [0, "&Beta;"], [0, "&Gamma;"], [0, "&Delta;"], [0, "&Epsilon;"], [0, "&Zeta;"], [0, "&Eta;"], [0, "&Theta;"], [0, "&Iota;"], [0, "&Kappa;"], [0, "&Lambda;"], [0, "&Mu;"], [0, "&Nu;"], [0, "&Xi;"], [0, "&Omicron;"], [0, "&Pi;"], [0, "&Rho;"], [1, "&Sigma;"], [0, "&Tau;"], [0, "&Upsilon;"], [0, "&Phi;"], [0, "&Chi;"], [0, "&Psi;"], [0, "&ohm;"], [7, "&alpha;"], [0, "&beta;"], [0, "&gamma;"], [0, "&delta;"], [0, "&epsi;"], [0, "&zeta;"], [0, "&eta;"], [0, "&theta;"], [0, "&iota;"], [0, "&kappa;"], [0, "&lambda;"], [0, "&mu;"], [0, "&nu;"], [0, "&xi;"], [0, "&omicron;"], [0, "&pi;"], [0, "&rho;"], [0, "&sigmaf;"], [0, "&sigma;"], [0, "&tau;"], [0, "&upsi;"], [0, "&phi;"], [0, "&chi;"], [0, "&psi;"], [0, "&omega;"], [7, "&thetasym;"], [0, "&Upsi;"], [2, "&phiv;"], [0, "&piv;"], [5, "&Gammad;"], [0, "&digamma;"], [18, "&kappav;"], [0, "&rhov;"], [3, "&epsiv;"], [0, "&backepsilon;"], [10, "&IOcy;"], [0, "&DJcy;"], [0, "&GJcy;"], [0, "&Jukcy;"], [0, "&DScy;"], [0, "&Iukcy;"], [0, "&YIcy;"], [0, "&Jsercy;"], [0, "&LJcy;"], [0, "&NJcy;"], [0, "&TSHcy;"], [0, "&KJcy;"], [1, "&Ubrcy;"], [0, "&DZcy;"], [0, "&Acy;"], [0, "&Bcy;"], [0, "&Vcy;"], [0, "&Gcy;"], [0, "&Dcy;"], [0, "&IEcy;"], [0, "&ZHcy;"], [0, "&Zcy;"], [0, "&Icy;"], [0, "&Jcy;"], [0, "&Kcy;"], [0, "&Lcy;"], [0, "&Mcy;"], [0, "&Ncy;"], [0, "&Ocy;"], [0, "&Pcy;"], [0, "&Rcy;"], [0, "&Scy;"], [0, "&Tcy;"], [0, "&Ucy;"], [0, "&Fcy;"], [0, "&KHcy;"], [0, "&TScy;"], [0, "&CHcy;"], [0, "&SHcy;"], [0, "&SHCHcy;"], [0, "&HARDcy;"], [0, "&Ycy;"], [0, "&SOFTcy;"], [0, "&Ecy;"], [0, "&YUcy;"], [0, "&YAcy;"], [0, "&acy;"], [0, "&bcy;"], [0, "&vcy;"], [0, "&gcy;"], [0, "&dcy;"], [0, "&iecy;"], [0, "&zhcy;"], [0, "&zcy;"], [0, "&icy;"], [0, "&jcy;"], [0, "&kcy;"], [0, "&lcy;"], [0, "&mcy;"], [0, "&ncy;"], [0, "&ocy;"], [0, "&pcy;"], [0, "&rcy;"], [0, "&scy;"], [0, "&tcy;"], [0, "&ucy;"], [0, "&fcy;"], [0, "&khcy;"], [0, "&tscy;"], [0, "&chcy;"], [0, "&shcy;"], [0, "&shchcy;"], [0, "&hardcy;"], [0, "&ycy;"], [0, "&softcy;"], [0, "&ecy;"], [0, "&yucy;"], [0, "&yacy;"], [1, "&iocy;"], [0, "&djcy;"], [0, "&gjcy;"], [0, "&jukcy;"], [0, "&dscy;"], [0, "&iukcy;"], [0, "&yicy;"], [0, "&jsercy;"], [0, "&ljcy;"], [0, "&njcy;"], [0, "&tshcy;"], [0, "&kjcy;"], [1, "&ubrcy;"], [0, "&dzcy;"], [7074, "&ensp;"], [0, "&emsp;"], [0, "&emsp13;"], [0, "&emsp14;"], [1, "&numsp;"], [0, "&puncsp;"], [0, "&ThinSpace;"], [0, "&hairsp;"], [0, "&NegativeMediumSpace;"], [0, "&zwnj;"], [0, "&zwj;"], [0, "&lrm;"], [0, "&rlm;"], [0, "&dash;"], [2, "&ndash;"], [0, "&mdash;"], [0, "&horbar;"], [0, "&Verbar;"], [1, "&lsquo;"], [0, "&CloseCurlyQuote;"], [0, "&lsquor;"], [1, "&ldquo;"], [0, "&CloseCurlyDoubleQuote;"], [0, "&bdquo;"], [1, "&dagger;"], [0, "&Dagger;"], [0, "&bull;"], [2, "&nldr;"], [0, "&hellip;"], [9, "&permil;"], [0, "&pertenk;"], [0, "&prime;"], [0, "&Prime;"], [0, "&tprime;"], [0, "&backprime;"], [3, "&lsaquo;"], [0, "&rsaquo;"], [3, "&oline;"], [2, "&caret;"], [1, "&hybull;"], [0, "&frasl;"], [10, "&bsemi;"], [7, "&qprime;"], [7, { v: "&MediumSpace;", n: 8202, o: "&ThickSpace;" }], [0, "&NoBreak;"], [0, "&af;"], [0, "&InvisibleTimes;"], [0, "&ic;"], [72, "&euro;"], [46, "&tdot;"], [0, "&DotDot;"], [37, "&complexes;"], [2, "&incare;"], [4, "&gscr;"], [0, "&hamilt;"], [0, "&Hfr;"], [0, "&Hopf;"], [0, "&planckh;"], [0, "&hbar;"], [0, "&imagline;"], [0, "&Ifr;"], [0, "&lagran;"], [0, "&ell;"], [1, "&naturals;"], [0, "&numero;"], [0, "&copysr;"], [0, "&weierp;"], [0, "&Popf;"], [0, "&Qopf;"], [0, "&realine;"], [0, "&real;"], [0, "&reals;"], [0, "&rx;"], [3, "&trade;"], [1, "&integers;"], [2, "&mho;"], [0, "&zeetrf;"], [0, "&iiota;"], [2, "&bernou;"], [0, "&Cayleys;"], [1, "&escr;"], [0, "&Escr;"], [0, "&Fouriertrf;"], [1, "&Mellintrf;"], [0, "&order;"], [0, "&alefsym;"], [0, "&beth;"], [0, "&gimel;"], [0, "&daleth;"], [12, "&CapitalDifferentialD;"], [0, "&dd;"], [0, "&ee;"], [0, "&ii;"], [10, "&frac13;"], [0, "&frac23;"], [0, "&frac15;"], [0, "&frac25;"], [0, "&frac35;"], [0, "&frac45;"], [0, "&frac16;"], [0, "&frac56;"], [0, "&frac18;"], [0, "&frac38;"], [0, "&frac58;"], [0, "&frac78;"], [49, "&larr;"], [0, "&ShortUpArrow;"], [0, "&rarr;"], [0, "&darr;"], [0, "&harr;"], [0, "&updownarrow;"], [0, "&nwarr;"], [0, "&nearr;"], [0, "&LowerRightArrow;"], [0, "&LowerLeftArrow;"], [0, "&nlarr;"], [0, "&nrarr;"], [1, { v: "&rarrw;", n: 824, o: "&nrarrw;" }], [0, "&Larr;"], [0, "&Uarr;"], [0, "&Rarr;"], [0, "&Darr;"], [0, "&larrtl;"], [0, "&rarrtl;"], [0, "&LeftTeeArrow;"], [0, "&mapstoup;"], [0, "&map;"], [0, "&DownTeeArrow;"], [1, "&hookleftarrow;"], [0, "&hookrightarrow;"], [0, "&larrlp;"], [0, "&looparrowright;"], [0, "&harrw;"], [0, "&nharr;"], [1, "&lsh;"], [0, "&rsh;"], [0, "&ldsh;"], [0, "&rdsh;"], [1, "&crarr;"], [0, "&cularr;"], [0, "&curarr;"], [2, "&circlearrowleft;"], [0, "&circlearrowright;"], [0, "&leftharpoonup;"], [0, "&DownLeftVector;"], [0, "&RightUpVector;"], [0, "&LeftUpVector;"], [0, "&rharu;"], [0, "&DownRightVector;"], [0, "&dharr;"], [0, "&dharl;"], [0, "&RightArrowLeftArrow;"], [0, "&udarr;"], [0, "&LeftArrowRightArrow;"], [0, "&leftleftarrows;"], [0, "&upuparrows;"], [0, "&rightrightarrows;"], [0, "&ddarr;"], [0, "&leftrightharpoons;"], [0, "&Equilibrium;"], [0, "&nlArr;"], [0, "&nhArr;"], [0, "&nrArr;"], [0, "&DoubleLeftArrow;"], [0, "&DoubleUpArrow;"], [0, "&DoubleRightArrow;"], [0, "&dArr;"], [0, "&DoubleLeftRightArrow;"], [0, "&DoubleUpDownArrow;"], [0, "&nwArr;"], [0, "&neArr;"], [0, "&seArr;"], [0, "&swArr;"], [0, "&lAarr;"], [0, "&rAarr;"], [1, "&zigrarr;"], [6, "&larrb;"], [0, "&rarrb;"], [15, "&DownArrowUpArrow;"], [7, "&loarr;"], [0, "&roarr;"], [0, "&hoarr;"], [0, "&forall;"], [0, "&comp;"], [0, { v: "&part;", n: 824, o: "&npart;" }], [0, "&exist;"], [0, "&nexist;"], [0, "&empty;"], [1, "&Del;"], [0, "&Element;"], [0, "&NotElement;"], [1, "&ni;"], [0, "&notni;"], [2, "&prod;"], [0, "&coprod;"], [0, "&sum;"], [0, "&minus;"], [0, "&MinusPlus;"], [0, "&dotplus;"], [1, "&Backslash;"], [0, "&lowast;"], [0, "&compfn;"], [1, "&radic;"], [2, "&prop;"], [0, "&infin;"], [0, "&angrt;"], [0, { v: "&ang;", n: 8402, o: "&nang;" }], [0, "&angmsd;"], [0, "&angsph;"], [0, "&mid;"], [0, "&nmid;"], [0, "&DoubleVerticalBar;"], [0, "&NotDoubleVerticalBar;"], [0, "&and;"], [0, "&or;"], [0, { v: "&cap;", n: 65024, o: "&caps;" }], [0, { v: "&cup;", n: 65024, o: "&cups;" }], [0, "&int;"], [0, "&Int;"], [0, "&iiint;"], [0, "&conint;"], [0, "&Conint;"], [0, "&Cconint;"], [0, "&cwint;"], [0, "&ClockwiseContourIntegral;"], [0, "&awconint;"], [0, "&there4;"], [0, "&becaus;"], [0, "&ratio;"], [0, "&Colon;"], [0, "&dotminus;"], [1, "&mDDot;"], [0, "&homtht;"], [0, { v: "&sim;", n: 8402, o: "&nvsim;" }], [0, { v: "&backsim;", n: 817, o: "&race;" }], [0, { v: "&ac;", n: 819, o: "&acE;" }], [0, "&acd;"], [0, "&VerticalTilde;"], [0, "&NotTilde;"], [0, { v: "&eqsim;", n: 824, o: "&nesim;" }], [0, "&sime;"], [0, "&NotTildeEqual;"], [0, "&cong;"], [0, "&simne;"], [0, "&ncong;"], [0, "&ap;"], [0, "&nap;"], [0, "&ape;"], [0, { v: "&apid;", n: 824, o: "&napid;" }], [0, "&backcong;"], [0, { v: "&asympeq;", n: 8402, o: "&nvap;" }], [0, { v: "&bump;", n: 824, o: "&nbump;" }], [0, { v: "&bumpe;", n: 824, o: "&nbumpe;" }], [0, { v: "&doteq;", n: 824, o: "&nedot;" }], [0, "&doteqdot;"], [0, "&efDot;"], [0, "&erDot;"], [0, "&Assign;"], [0, "&ecolon;"], [0, "&ecir;"], [0, "&circeq;"], [1, "&wedgeq;"], [0, "&veeeq;"], [1, "&triangleq;"], [2, "&equest;"], [0, "&ne;"], [0, { v: "&Congruent;", n: 8421, o: "&bnequiv;" }], [0, "&nequiv;"], [1, { v: "&le;", n: 8402, o: "&nvle;" }], [0, { v: "&ge;", n: 8402, o: "&nvge;" }], [0, { v: "&lE;", n: 824, o: "&nlE;" }], [0, { v: "&gE;", n: 824, o: "&ngE;" }], [0, { v: "&lnE;", n: 65024, o: "&lvertneqq;" }], [0, { v: "&gnE;", n: 65024, o: "&gvertneqq;" }], [0, { v: "&ll;", n: new Map(/* @__PURE__ */ restoreDiff([[824, "&nLtv;"], [7577, "&nLt;"]])) }], [0, { v: "&gg;", n: new Map(/* @__PURE__ */ restoreDiff([[824, "&nGtv;"], [7577, "&nGt;"]])) }], [0, "&between;"], [0, "&NotCupCap;"], [0, "&nless;"], [0, "&ngt;"], [0, "&nle;"], [0, "&nge;"], [0, "&lesssim;"], [0, "&GreaterTilde;"], [0, "&nlsim;"], [0, "&ngsim;"], [0, "&LessGreater;"], [0, "&gl;"], [0, "&NotLessGreater;"], [0, "&NotGreaterLess;"], [0, "&pr;"], [0, "&sc;"], [0, "&prcue;"], [0, "&sccue;"], [0, "&PrecedesTilde;"], [0, { v: "&scsim;", n: 824, o: "&NotSucceedsTilde;" }], [0, "&NotPrecedes;"], [0, "&NotSucceeds;"], [0, { v: "&sub;", n: 8402, o: "&NotSubset;" }], [0, { v: "&sup;", n: 8402, o: "&NotSuperset;" }], [0, "&nsub;"], [0, "&nsup;"], [0, "&sube;"], [0, "&supe;"], [0, "&NotSubsetEqual;"], [0, "&NotSupersetEqual;"], [0, { v: "&subne;", n: 65024, o: "&varsubsetneq;" }], [0, { v: "&supne;", n: 65024, o: "&varsupsetneq;" }], [1, "&cupdot;"], [0, "&UnionPlus;"], [0, { v: "&sqsub;", n: 824, o: "&NotSquareSubset;" }], [0, { v: "&sqsup;", n: 824, o: "&NotSquareSuperset;" }], [0, "&sqsube;"], [0, "&sqsupe;"], [0, { v: "&sqcap;", n: 65024, o: "&sqcaps;" }], [0, { v: "&sqcup;", n: 65024, o: "&sqcups;" }], [0, "&CirclePlus;"], [0, "&CircleMinus;"], [0, "&CircleTimes;"], [0, "&osol;"], [0, "&CircleDot;"], [0, "&circledcirc;"], [0, "&circledast;"], [1, "&circleddash;"], [0, "&boxplus;"], [0, "&boxminus;"], [0, "&boxtimes;"], [0, "&dotsquare;"], [0, "&RightTee;"], [0, "&dashv;"], [0, "&DownTee;"], [0, "&bot;"], [1, "&models;"], [0, "&DoubleRightTee;"], [0, "&Vdash;"], [0, "&Vvdash;"], [0, "&VDash;"], [0, "&nvdash;"], [0, "&nvDash;"], [0, "&nVdash;"], [0, "&nVDash;"], [0, "&prurel;"], [1, "&LeftTriangle;"], [0, "&RightTriangle;"], [0, { v: "&LeftTriangleEqual;", n: 8402, o: "&nvltrie;" }], [0, { v: "&RightTriangleEqual;", n: 8402, o: "&nvrtrie;" }], [0, "&origof;"], [0, "&imof;"], [0, "&multimap;"], [0, "&hercon;"], [0, "&intcal;"], [0, "&veebar;"], [1, "&barvee;"], [0, "&angrtvb;"], [0, "&lrtri;"], [0, "&bigwedge;"], [0, "&bigvee;"], [0, "&bigcap;"], [0, "&bigcup;"], [0, "&diam;"], [0, "&sdot;"], [0, "&sstarf;"], [0, "&divideontimes;"], [0, "&bowtie;"], [0, "&ltimes;"], [0, "&rtimes;"], [0, "&leftthreetimes;"], [0, "&rightthreetimes;"], [0, "&backsimeq;"], [0, "&curlyvee;"], [0, "&curlywedge;"], [0, "&Sub;"], [0, "&Sup;"], [0, "&Cap;"], [0, "&Cup;"], [0, "&fork;"], [0, "&epar;"], [0, "&lessdot;"], [0, "&gtdot;"], [0, { v: "&Ll;", n: 824, o: "&nLl;" }], [0, { v: "&Gg;", n: 824, o: "&nGg;" }], [0, { v: "&leg;", n: 65024, o: "&lesg;" }], [0, { v: "&gel;", n: 65024, o: "&gesl;" }], [2, "&cuepr;"], [0, "&cuesc;"], [0, "&NotPrecedesSlantEqual;"], [0, "&NotSucceedsSlantEqual;"], [0, "&NotSquareSubsetEqual;"], [0, "&NotSquareSupersetEqual;"], [2, "&lnsim;"], [0, "&gnsim;"], [0, "&precnsim;"], [0, "&scnsim;"], [0, "&nltri;"], [0, "&NotRightTriangle;"], [0, "&nltrie;"], [0, "&NotRightTriangleEqual;"], [0, "&vellip;"], [0, "&ctdot;"], [0, "&utdot;"], [0, "&dtdot;"], [0, "&disin;"], [0, "&isinsv;"], [0, "&isins;"], [0, { v: "&isindot;", n: 824, o: "&notindot;" }], [0, "&notinvc;"], [0, "&notinvb;"], [1, { v: "&isinE;", n: 824, o: "&notinE;" }], [0, "&nisd;"], [0, "&xnis;"], [0, "&nis;"], [0, "&notnivc;"], [0, "&notnivb;"], [6, "&barwed;"], [0, "&Barwed;"], [1, "&lceil;"], [0, "&rceil;"], [0, "&LeftFloor;"], [0, "&rfloor;"], [0, "&drcrop;"], [0, "&dlcrop;"], [0, "&urcrop;"], [0, "&ulcrop;"], [0, "&bnot;"], [1, "&profline;"], [0, "&profsurf;"], [1, "&telrec;"], [0, "&target;"], [5, "&ulcorn;"], [0, "&urcorn;"], [0, "&dlcorn;"], [0, "&drcorn;"], [2, "&frown;"], [0, "&smile;"], [9, "&cylcty;"], [0, "&profalar;"], [7, "&topbot;"], [6, "&ovbar;"], [1, "&solbar;"], [60, "&angzarr;"], [51, "&lmoustache;"], [0, "&rmoustache;"], [2, "&OverBracket;"], [0, "&bbrk;"], [0, "&bbrktbrk;"], [37, "&OverParenthesis;"], [0, "&UnderParenthesis;"], [0, "&OverBrace;"], [0, "&UnderBrace;"], [2, "&trpezium;"], [4, "&elinters;"], [59, "&blank;"], [164, "&circledS;"], [55, "&boxh;"], [1, "&boxv;"], [9, "&boxdr;"], [3, "&boxdl;"], [3, "&boxur;"], [3, "&boxul;"], [3, "&boxvr;"], [7, "&boxvl;"], [7, "&boxhd;"], [7, "&boxhu;"], [7, "&boxvh;"], [19, "&boxH;"], [0, "&boxV;"], [0, "&boxdR;"], [0, "&boxDr;"], [0, "&boxDR;"], [0, "&boxdL;"], [0, "&boxDl;"], [0, "&boxDL;"], [0, "&boxuR;"], [0, "&boxUr;"], [0, "&boxUR;"], [0, "&boxuL;"], [0, "&boxUl;"], [0, "&boxUL;"], [0, "&boxvR;"], [0, "&boxVr;"], [0, "&boxVR;"], [0, "&boxvL;"], [0, "&boxVl;"], [0, "&boxVL;"], [0, "&boxHd;"], [0, "&boxhD;"], [0, "&boxHD;"], [0, "&boxHu;"], [0, "&boxhU;"], [0, "&boxHU;"], [0, "&boxvH;"], [0, "&boxVh;"], [0, "&boxVH;"], [19, "&uhblk;"], [3, "&lhblk;"], [3, "&block;"], [8, "&blk14;"], [0, "&blk12;"], [0, "&blk34;"], [13, "&square;"], [8, "&blacksquare;"], [0, "&EmptyVerySmallSquare;"], [1, "&rect;"], [0, "&marker;"], [2, "&fltns;"], [1, "&bigtriangleup;"], [0, "&blacktriangle;"], [0, "&triangle;"], [2, "&blacktriangleright;"], [0, "&rtri;"], [3, "&bigtriangledown;"], [0, "&blacktriangledown;"], [0, "&dtri;"], [2, "&blacktriangleleft;"], [0, "&ltri;"], [6, "&loz;"], [0, "&cir;"], [32, "&tridot;"], [2, "&bigcirc;"], [8, "&ultri;"], [0, "&urtri;"], [0, "&lltri;"], [0, "&EmptySmallSquare;"], [0, "&FilledSmallSquare;"], [8, "&bigstar;"], [0, "&star;"], [7, "&phone;"], [49, "&female;"], [1, "&male;"], [29, "&spades;"], [2, "&clubs;"], [1, "&hearts;"], [0, "&diamondsuit;"], [3, "&sung;"], [2, "&flat;"], [0, "&natural;"], [0, "&sharp;"], [163, "&check;"], [3, "&cross;"], [8, "&malt;"], [21, "&sext;"], [33, "&VerticalSeparator;"], [25, "&lbbrk;"], [0, "&rbbrk;"], [84, "&bsolhsub;"], [0, "&suphsol;"], [28, "&LeftDoubleBracket;"], [0, "&RightDoubleBracket;"], [0, "&lang;"], [0, "&rang;"], [0, "&Lang;"], [0, "&Rang;"], [0, "&loang;"], [0, "&roang;"], [7, "&longleftarrow;"], [0, "&longrightarrow;"], [0, "&longleftrightarrow;"], [0, "&DoubleLongLeftArrow;"], [0, "&DoubleLongRightArrow;"], [0, "&DoubleLongLeftRightArrow;"], [1, "&longmapsto;"], [2, "&dzigrarr;"], [258, "&nvlArr;"], [0, "&nvrArr;"], [0, "&nvHarr;"], [0, "&Map;"], [6, "&lbarr;"], [0, "&bkarow;"], [0, "&lBarr;"], [0, "&dbkarow;"], [0, "&drbkarow;"], [0, "&DDotrahd;"], [0, "&UpArrowBar;"], [0, "&DownArrowBar;"], [2, "&Rarrtl;"], [2, "&latail;"], [0, "&ratail;"], [0, "&lAtail;"], [0, "&rAtail;"], [0, "&larrfs;"], [0, "&rarrfs;"], [0, "&larrbfs;"], [0, "&rarrbfs;"], [2, "&nwarhk;"], [0, "&nearhk;"], [0, "&hksearow;"], [0, "&hkswarow;"], [0, "&nwnear;"], [0, "&nesear;"], [0, "&seswar;"], [0, "&swnwar;"], [8, { v: "&rarrc;", n: 824, o: "&nrarrc;" }], [1, "&cudarrr;"], [0, "&ldca;"], [0, "&rdca;"], [0, "&cudarrl;"], [0, "&larrpl;"], [2, "&curarrm;"], [0, "&cularrp;"], [7, "&rarrpl;"], [2, "&harrcir;"], [0, "&Uarrocir;"], [0, "&lurdshar;"], [0, "&ldrushar;"], [2, "&LeftRightVector;"], [0, "&RightUpDownVector;"], [0, "&DownLeftRightVector;"], [0, "&LeftUpDownVector;"], [0, "&LeftVectorBar;"], [0, "&RightVectorBar;"], [0, "&RightUpVectorBar;"], [0, "&RightDownVectorBar;"], [0, "&DownLeftVectorBar;"], [0, "&DownRightVectorBar;"], [0, "&LeftUpVectorBar;"], [0, "&LeftDownVectorBar;"], [0, "&LeftTeeVector;"], [0, "&RightTeeVector;"], [0, "&RightUpTeeVector;"], [0, "&RightDownTeeVector;"], [0, "&DownLeftTeeVector;"], [0, "&DownRightTeeVector;"], [0, "&LeftUpTeeVector;"], [0, "&LeftDownTeeVector;"], [0, "&lHar;"], [0, "&uHar;"], [0, "&rHar;"], [0, "&dHar;"], [0, "&luruhar;"], [0, "&ldrdhar;"], [0, "&ruluhar;"], [0, "&rdldhar;"], [0, "&lharul;"], [0, "&llhard;"], [0, "&rharul;"], [0, "&lrhard;"], [0, "&udhar;"], [0, "&duhar;"], [0, "&RoundImplies;"], [0, "&erarr;"], [0, "&simrarr;"], [0, "&larrsim;"], [0, "&rarrsim;"], [0, "&rarrap;"], [0, "&ltlarr;"], [1, "&gtrarr;"], [0, "&subrarr;"], [1, "&suplarr;"], [0, "&lfisht;"], [0, "&rfisht;"], [0, "&ufisht;"], [0, "&dfisht;"], [5, "&lopar;"], [0, "&ropar;"], [4, "&lbrke;"], [0, "&rbrke;"], [0, "&lbrkslu;"], [0, "&rbrksld;"], [0, "&lbrksld;"], [0, "&rbrkslu;"], [0, "&langd;"], [0, "&rangd;"], [0, "&lparlt;"], [0, "&rpargt;"], [0, "&gtlPar;"], [0, "&ltrPar;"], [3, "&vzigzag;"], [1, "&vangrt;"], [0, "&angrtvbd;"], [6, "&ange;"], [0, "&range;"], [0, "&dwangle;"], [0, "&uwangle;"], [0, "&angmsdaa;"], [0, "&angmsdab;"], [0, "&angmsdac;"], [0, "&angmsdad;"], [0, "&angmsdae;"], [0, "&angmsdaf;"], [0, "&angmsdag;"], [0, "&angmsdah;"], [0, "&bemptyv;"], [0, "&demptyv;"], [0, "&cemptyv;"], [0, "&raemptyv;"], [0, "&laemptyv;"], [0, "&ohbar;"], [0, "&omid;"], [0, "&opar;"], [1, "&operp;"], [1, "&olcross;"], [0, "&odsold;"], [1, "&olcir;"], [0, "&ofcir;"], [0, "&olt;"], [0, "&ogt;"], [0, "&cirscir;"], [0, "&cirE;"], [0, "&solb;"], [0, "&bsolb;"], [3, "&boxbox;"], [3, "&trisb;"], [0, "&rtriltri;"], [0, { v: "&LeftTriangleBar;", n: 824, o: "&NotLeftTriangleBar;" }], [0, { v: "&RightTriangleBar;", n: 824, o: "&NotRightTriangleBar;" }], [11, "&iinfin;"], [0, "&infintie;"], [0, "&nvinfin;"], [4, "&eparsl;"], [0, "&smeparsl;"], [0, "&eqvparsl;"], [5, "&blacklozenge;"], [8, "&RuleDelayed;"], [1, "&dsol;"], [9, "&bigodot;"], [0, "&bigoplus;"], [0, "&bigotimes;"], [1, "&biguplus;"], [1, "&bigsqcup;"], [5, "&iiiint;"], [0, "&fpartint;"], [2, "&cirfnint;"], [0, "&awint;"], [0, "&rppolint;"], [0, "&scpolint;"], [0, "&npolint;"], [0, "&pointint;"], [0, "&quatint;"], [0, "&intlarhk;"], [10, "&pluscir;"], [0, "&plusacir;"], [0, "&simplus;"], [0, "&plusdu;"], [0, "&plussim;"], [0, "&plustwo;"], [1, "&mcomma;"], [0, "&minusdu;"], [2, "&loplus;"], [0, "&roplus;"], [0, "&Cross;"], [0, "&timesd;"], [0, "&timesbar;"], [1, "&smashp;"], [0, "&lotimes;"], [0, "&rotimes;"], [0, "&otimesas;"], [0, "&Otimes;"], [0, "&odiv;"], [0, "&triplus;"], [0, "&triminus;"], [0, "&tritime;"], [0, "&intprod;"], [2, "&amalg;"], [0, "&capdot;"], [1, "&ncup;"], [0, "&ncap;"], [0, "&capand;"], [0, "&cupor;"], [0, "&cupcap;"], [0, "&capcup;"], [0, "&cupbrcap;"], [0, "&capbrcup;"], [0, "&cupcup;"], [0, "&capcap;"], [0, "&ccups;"], [0, "&ccaps;"], [2, "&ccupssm;"], [2, "&And;"], [0, "&Or;"], [0, "&andand;"], [0, "&oror;"], [0, "&orslope;"], [0, "&andslope;"], [1, "&andv;"], [0, "&orv;"], [0, "&andd;"], [0, "&ord;"], [1, "&wedbar;"], [6, "&sdote;"], [3, "&simdot;"], [2, { v: "&congdot;", n: 824, o: "&ncongdot;" }], [0, "&easter;"], [0, "&apacir;"], [0, { v: "&apE;", n: 824, o: "&napE;" }], [0, "&eplus;"], [0, "&pluse;"], [0, "&Esim;"], [0, "&Colone;"], [0, "&Equal;"], [1, "&ddotseq;"], [0, "&equivDD;"], [0, "&ltcir;"], [0, "&gtcir;"], [0, "&ltquest;"], [0, "&gtquest;"], [0, { v: "&leqslant;", n: 824, o: "&nleqslant;" }], [0, { v: "&geqslant;", n: 824, o: "&ngeqslant;" }], [0, "&lesdot;"], [0, "&gesdot;"], [0, "&lesdoto;"], [0, "&gesdoto;"], [0, "&lesdotor;"], [0, "&gesdotol;"], [0, "&lap;"], [0, "&gap;"], [0, "&lne;"], [0, "&gne;"], [0, "&lnap;"], [0, "&gnap;"], [0, "&lEg;"], [0, "&gEl;"], [0, "&lsime;"], [0, "&gsime;"], [0, "&lsimg;"], [0, "&gsiml;"], [0, "&lgE;"], [0, "&glE;"], [0, "&lesges;"], [0, "&gesles;"], [0, "&els;"], [0, "&egs;"], [0, "&elsdot;"], [0, "&egsdot;"], [0, "&el;"], [0, "&eg;"], [2, "&siml;"], [0, "&simg;"], [0, "&simlE;"], [0, "&simgE;"], [0, { v: "&LessLess;", n: 824, o: "&NotNestedLessLess;" }], [0, { v: "&GreaterGreater;", n: 824, o: "&NotNestedGreaterGreater;" }], [1, "&glj;"], [0, "&gla;"], [0, "&ltcc;"], [0, "&gtcc;"], [0, "&lescc;"], [0, "&gescc;"], [0, "&smt;"], [0, "&lat;"], [0, { v: "&smte;", n: 65024, o: "&smtes;" }], [0, { v: "&late;", n: 65024, o: "&lates;" }], [0, "&bumpE;"], [0, { v: "&PrecedesEqual;", n: 824, o: "&NotPrecedesEqual;" }], [0, { v: "&sce;", n: 824, o: "&NotSucceedsEqual;" }], [2, "&prE;"], [0, "&scE;"], [0, "&precneqq;"], [0, "&scnE;"], [0, "&prap;"], [0, "&scap;"], [0, "&precnapprox;"], [0, "&scnap;"], [0, "&Pr;"], [0, "&Sc;"], [0, "&subdot;"], [0, "&supdot;"], [0, "&subplus;"], [0, "&supplus;"], [0, "&submult;"], [0, "&supmult;"], [0, "&subedot;"], [0, "&supedot;"], [0, { v: "&subE;", n: 824, o: "&nsubE;" }], [0, { v: "&supE;", n: 824, o: "&nsupE;" }], [0, "&subsim;"], [0, "&supsim;"], [2, { v: "&subnE;", n: 65024, o: "&varsubsetneqq;" }], [0, { v: "&supnE;", n: 65024, o: "&varsupsetneqq;" }], [2, "&csub;"], [0, "&csup;"], [0, "&csube;"], [0, "&csupe;"], [0, "&subsup;"], [0, "&supsub;"], [0, "&subsub;"], [0, "&supsup;"], [0, "&suphsub;"], [0, "&supdsub;"], [0, "&forkv;"], [0, "&topfork;"], [0, "&mlcp;"], [8, "&Dashv;"], [1, "&Vdashl;"], [0, "&Barv;"], [0, "&vBar;"], [0, "&vBarv;"], [1, "&Vbar;"], [0, "&Not;"], [0, "&bNot;"], [0, "&rnmid;"], [0, "&cirmid;"], [0, "&midcir;"], [0, "&topcir;"], [0, "&nhpar;"], [0, "&parsim;"], [9, { v: "&parsl;", n: 8421, o: "&nparsl;" }], [44343, { n: new Map(/* @__PURE__ */ restoreDiff([[56476, "&Ascr;"], [1, "&Cscr;"], [0, "&Dscr;"], [2, "&Gscr;"], [2, "&Jscr;"], [0, "&Kscr;"], [2, "&Nscr;"], [0, "&Oscr;"], [0, "&Pscr;"], [0, "&Qscr;"], [1, "&Sscr;"], [0, "&Tscr;"], [0, "&Uscr;"], [0, "&Vscr;"], [0, "&Wscr;"], [0, "&Xscr;"], [0, "&Yscr;"], [0, "&Zscr;"], [0, "&ascr;"], [0, "&bscr;"], [0, "&cscr;"], [0, "&dscr;"], [1, "&fscr;"], [1, "&hscr;"], [0, "&iscr;"], [0, "&jscr;"], [0, "&kscr;"], [0, "&lscr;"], [0, "&mscr;"], [0, "&nscr;"], [1, "&pscr;"], [0, "&qscr;"], [0, "&rscr;"], [0, "&sscr;"], [0, "&tscr;"], [0, "&uscr;"], [0, "&vscr;"], [0, "&wscr;"], [0, "&xscr;"], [0, "&yscr;"], [0, "&zscr;"], [52, "&Afr;"], [0, "&Bfr;"], [1, "&Dfr;"], [0, "&Efr;"], [0, "&Ffr;"], [0, "&Gfr;"], [2, "&Jfr;"], [0, "&Kfr;"], [0, "&Lfr;"], [0, "&Mfr;"], [0, "&Nfr;"], [0, "&Ofr;"], [0, "&Pfr;"], [0, "&Qfr;"], [1, "&Sfr;"], [0, "&Tfr;"], [0, "&Ufr;"], [0, "&Vfr;"], [0, "&Wfr;"], [0, "&Xfr;"], [0, "&Yfr;"], [1, "&afr;"], [0, "&bfr;"], [0, "&cfr;"], [0, "&dfr;"], [0, "&efr;"], [0, "&ffr;"], [0, "&gfr;"], [0, "&hfr;"], [0, "&ifr;"], [0, "&jfr;"], [0, "&kfr;"], [0, "&lfr;"], [0, "&mfr;"], [0, "&nfr;"], [0, "&ofr;"], [0, "&pfr;"], [0, "&qfr;"], [0, "&rfr;"], [0, "&sfr;"], [0, "&tfr;"], [0, "&ufr;"], [0, "&vfr;"], [0, "&wfr;"], [0, "&xfr;"], [0, "&yfr;"], [0, "&zfr;"], [0, "&Aopf;"], [0, "&Bopf;"], [1, "&Dopf;"], [0, "&Eopf;"], [0, "&Fopf;"], [0, "&Gopf;"], [1, "&Iopf;"], [0, "&Jopf;"], [0, "&Kopf;"], [0, "&Lopf;"], [0, "&Mopf;"], [1, "&Oopf;"], [3, "&Sopf;"], [0, "&Topf;"], [0, "&Uopf;"], [0, "&Vopf;"], [0, "&Wopf;"], [0, "&Xopf;"], [0, "&Yopf;"], [1, "&aopf;"], [0, "&bopf;"], [0, "&copf;"], [0, "&dopf;"], [0, "&eopf;"], [0, "&fopf;"], [0, "&gopf;"], [0, "&hopf;"], [0, "&iopf;"], [0, "&jopf;"], [0, "&kopf;"], [0, "&lopf;"], [0, "&mopf;"], [0, "&nopf;"], [0, "&oopf;"], [0, "&popf;"], [0, "&qopf;"], [0, "&ropf;"], [0, "&sopf;"], [0, "&topf;"], [0, "&uopf;"], [0, "&vopf;"], [0, "&wopf;"], [0, "&xopf;"], [0, "&yopf;"], [0, "&zopf;"]])) }], [8906, "&fflig;"], [0, "&filig;"], [0, "&fllig;"], [0, "&ffilig;"], [0, "&ffllig;"]]));
const xmlReplacer = /["&'<>$\x80-\uFFFF]/g;
const xmlCodeMap = /* @__PURE__ */ new Map([
  [34, "&quot;"],
  [38, "&amp;"],
  [39, "&apos;"],
  [60, "&lt;"],
  [62, "&gt;"]
]);
const getCodePoint = (
  // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
  String.prototype.codePointAt != null ? (str, index2) => str.codePointAt(index2) : (
    // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
    (c2, index2) => (c2.charCodeAt(index2) & 64512) === 55296 ? (c2.charCodeAt(index2) - 55296) * 1024 + c2.charCodeAt(index2 + 1) - 56320 + 65536 : c2.charCodeAt(index2)
  )
);
function encodeXML(str) {
  let ret = "";
  let lastIdx = 0;
  let match2;
  while ((match2 = xmlReplacer.exec(str)) !== null) {
    const i2 = match2.index;
    const char = str.charCodeAt(i2);
    const next2 = xmlCodeMap.get(char);
    if (next2 !== void 0) {
      ret += str.substring(lastIdx, i2) + next2;
      lastIdx = i2 + 1;
    } else {
      ret += `${str.substring(lastIdx, i2)}&#x${getCodePoint(str, i2).toString(16)};`;
      lastIdx = xmlReplacer.lastIndex += Number((char & 64512) === 55296);
    }
  }
  return ret + str.substr(lastIdx);
}
__name(encodeXML, "encodeXML");
const escape$2 = encodeXML;
function getEscaper(regex2, map3) {
  return /* @__PURE__ */ __name(function escape2(data30) {
    let match2;
    let lastIdx = 0;
    let result = "";
    while (match2 = regex2.exec(data30)) {
      if (lastIdx !== match2.index) {
        result += data30.substring(lastIdx, match2.index);
      }
      result += map3.get(match2[0].charCodeAt(0));
      lastIdx = match2.index + 1;
    }
    return result + data30.substring(lastIdx);
  }, "escape");
}
__name(getEscaper, "getEscaper");
const escapeUTF8 = getEscaper(/[&<>'"]/g, xmlCodeMap);
const escapeAttribute = getEscaper(/["&\u00A0]/g, /* @__PURE__ */ new Map([
  [34, "&quot;"],
  [38, "&amp;"],
  [160, "&nbsp;"]
]));
const escapeText = getEscaper(/[&<>\u00A0]/g, /* @__PURE__ */ new Map([
  [38, "&amp;"],
  [60, "&lt;"],
  [62, "&gt;"],
  [160, "&nbsp;"]
]));
const htmlReplacer = /[\t\n!-,./:-@[-`\f{-}$\x80-\uFFFF]/g;
function encodeHTML(data30) {
  return encodeHTMLTrieRe(htmlReplacer, data30);
}
__name(encodeHTML, "encodeHTML");
function encodeNonAsciiHTML(data30) {
  return encodeHTMLTrieRe(xmlReplacer, data30);
}
__name(encodeNonAsciiHTML, "encodeNonAsciiHTML");
function encodeHTMLTrieRe(regExp, str) {
  let ret = "";
  let lastIdx = 0;
  let match2;
  while ((match2 = regExp.exec(str)) !== null) {
    const i2 = match2.index;
    ret += str.substring(lastIdx, i2);
    const char = str.charCodeAt(i2);
    let next2 = htmlTrie.get(char);
    if (typeof next2 === "object") {
      if (i2 + 1 < str.length) {
        const nextChar = str.charCodeAt(i2 + 1);
        const value3 = typeof next2.n === "number" ? next2.n === nextChar ? next2.o : void 0 : next2.n.get(nextChar);
        if (value3 !== void 0) {
          ret += value3;
          lastIdx = regExp.lastIndex += 1;
          continue;
        }
      }
      next2 = next2.v;
    }
    if (next2 !== void 0) {
      ret += next2;
      lastIdx = i2 + 1;
    } else {
      const cp = getCodePoint(str, i2);
      ret += `&#x${cp.toString(16)};`;
      lastIdx = regExp.lastIndex += Number(cp !== char);
    }
  }
  return ret + str.substr(lastIdx);
}
__name(encodeHTMLTrieRe, "encodeHTMLTrieRe");
var EntityLevel;
(function(EntityLevel2) {
  EntityLevel2[EntityLevel2["XML"] = 0] = "XML";
  EntityLevel2[EntityLevel2["HTML"] = 1] = "HTML";
})(EntityLevel || (EntityLevel = {}));
var EncodingMode;
(function(EncodingMode2) {
  EncodingMode2[EncodingMode2["UTF8"] = 0] = "UTF8";
  EncodingMode2[EncodingMode2["ASCII"] = 1] = "ASCII";
  EncodingMode2[EncodingMode2["Extensive"] = 2] = "Extensive";
  EncodingMode2[EncodingMode2["Attribute"] = 3] = "Attribute";
  EncodingMode2[EncodingMode2["Text"] = 4] = "Text";
})(EncodingMode || (EncodingMode = {}));
function decode$1(data30, options5 = EntityLevel.XML) {
  const level = typeof options5 === "number" ? options5 : options5.level;
  if (level === EntityLevel.HTML) {
    const mode2 = typeof options5 === "object" ? options5.mode : void 0;
    return decodeHTML(data30, mode2);
  }
  return decodeXML(data30);
}
__name(decode$1, "decode$1");
function decodeStrict(data30, options5 = EntityLevel.XML) {
  var _a2;
  const opts = typeof options5 === "number" ? { level: options5 } : options5;
  (_a2 = opts.mode) !== null && _a2 !== void 0 ? _a2 : opts.mode = DecodingMode.Strict;
  return decode$1(data30, opts);
}
__name(decodeStrict, "decodeStrict");
function encode$1(data30, options5 = EntityLevel.XML) {
  const opts = typeof options5 === "number" ? { level: options5 } : options5;
  if (opts.mode === EncodingMode.UTF8)
    return escapeUTF8(data30);
  if (opts.mode === EncodingMode.Attribute)
    return escapeAttribute(data30);
  if (opts.mode === EncodingMode.Text)
    return escapeText(data30);
  if (opts.level === EntityLevel.HTML) {
    if (opts.mode === EncodingMode.ASCII) {
      return encodeNonAsciiHTML(data30);
    }
    return encodeHTML(data30);
  }
  return encodeXML(data30);
}
__name(encode$1, "encode$1");
function _class$1(obj) {
  return Object.prototype.toString.call(obj);
}
__name(_class$1, "_class$1");
function isString$1(obj) {
  return _class$1(obj) === "[object String]";
}
__name(isString$1, "isString$1");
const _hasOwnProperty = Object.prototype.hasOwnProperty;
function has(object, key) {
  return _hasOwnProperty.call(object, key);
}
__name(has, "has");
function assign$1(obj) {
  const sources = Array.prototype.slice.call(arguments, 1);
  sources.forEach(function(source) {
    if (!source) {
      return;
    }
    if (typeof source !== "object") {
      throw new TypeError(source + "must be object");
    }
    Object.keys(source).forEach(function(key) {
      obj[key] = source[key];
    });
  });
  return obj;
}
__name(assign$1, "assign$1");
function arrayReplaceAt(src, pos, newElements) {
  return [].concat(src.slice(0, pos), newElements, src.slice(pos + 1));
}
__name(arrayReplaceAt, "arrayReplaceAt");
function isValidEntityCode(c2) {
  if (c2 >= 55296 && c2 <= 57343) {
    return false;
  }
  if (c2 >= 64976 && c2 <= 65007) {
    return false;
  }
  if ((c2 & 65535) === 65535 || (c2 & 65535) === 65534) {
    return false;
  }
  if (c2 >= 0 && c2 <= 8) {
    return false;
  }
  if (c2 === 11) {
    return false;
  }
  if (c2 >= 14 && c2 <= 31) {
    return false;
  }
  if (c2 >= 127 && c2 <= 159) {
    return false;
  }
  if (c2 > 1114111) {
    return false;
  }
  return true;
}
__name(isValidEntityCode, "isValidEntityCode");
function fromCodePoint(c2) {
  if (c2 > 65535) {
    c2 -= 65536;
    const surrogate1 = 55296 + (c2 >> 10);
    const surrogate2 = 56320 + (c2 & 1023);
    return String.fromCharCode(surrogate1, surrogate2);
  }
  return String.fromCharCode(c2);
}
__name(fromCodePoint, "fromCodePoint");
const UNESCAPE_MD_RE = /\\([!"#$%&'()*+,\-./:;<=>?@[\\\]^_`{|}~])/g;
const ENTITY_RE = /&([a-z#][a-z0-9]{1,31});/gi;
const UNESCAPE_ALL_RE = new RegExp(UNESCAPE_MD_RE.source + "|" + ENTITY_RE.source, "gi");
const DIGITAL_ENTITY_TEST_RE = /^#((?:x[a-f0-9]{1,8}|[0-9]{1,8}))$/i;
function replaceEntityPattern(match2, name2) {
  if (name2.charCodeAt(0) === 35 && DIGITAL_ENTITY_TEST_RE.test(name2)) {
    const code2 = name2[1].toLowerCase() === "x" ? parseInt(name2.slice(2), 16) : parseInt(name2.slice(1), 10);
    if (isValidEntityCode(code2)) {
      return fromCodePoint(code2);
    }
    return match2;
  }
  const decoded = decodeHTML(match2);
  if (decoded !== match2) {
    return decoded;
  }
  return match2;
}
__name(replaceEntityPattern, "replaceEntityPattern");
function unescapeMd(str) {
  if (str.indexOf("\\") < 0) {
    return str;
  }
  return str.replace(UNESCAPE_MD_RE, "$1");
}
__name(unescapeMd, "unescapeMd");
function unescapeAll(str) {
  if (str.indexOf("\\") < 0 && str.indexOf("&") < 0) {
    return str;
  }
  return str.replace(UNESCAPE_ALL_RE, function(match2, escaped, entity2) {
    if (escaped) {
      return escaped;
    }
    return replaceEntityPattern(match2, entity2);
  });
}
__name(unescapeAll, "unescapeAll");
const HTML_ESCAPE_TEST_RE = /[&<>"]/;
const HTML_ESCAPE_REPLACE_RE = /[&<>"]/g;
const HTML_REPLACEMENTS = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;"
};
function replaceUnsafeChar(ch) {
  return HTML_REPLACEMENTS[ch];
}
__name(replaceUnsafeChar, "replaceUnsafeChar");
function escapeHtml(str) {
  if (HTML_ESCAPE_TEST_RE.test(str)) {
    return str.replace(HTML_ESCAPE_REPLACE_RE, replaceUnsafeChar);
  }
  return str;
}
__name(escapeHtml, "escapeHtml");
const REGEXP_ESCAPE_RE = /[.?*+^$[\]\\(){}|-]/g;
function escapeRE$1(str) {
  return str.replace(REGEXP_ESCAPE_RE, "\\$&");
}
__name(escapeRE$1, "escapeRE$1");
function isSpace(code2) {
  switch (code2) {
    case 9:
    case 32:
      return true;
  }
  return false;
}
__name(isSpace, "isSpace");
function isWhiteSpace(code2) {
  if (code2 >= 8192 && code2 <= 8202) {
    return true;
  }
  switch (code2) {
    case 9:
    case 10:
    case 11:
    case 12:
    case 13:
    case 32:
    case 160:
    case 5760:
    case 8239:
    case 8287:
    case 12288:
      return true;
  }
  return false;
}
__name(isWhiteSpace, "isWhiteSpace");
function isPunctChar(ch) {
  return P.test(ch) || regex.test(ch);
}
__name(isPunctChar, "isPunctChar");
function isMdAsciiPunct(ch) {
  switch (ch) {
    case 33:
    case 34:
    case 35:
    case 36:
    case 37:
    case 38:
    case 39:
    case 40:
    case 41:
    case 42:
    case 43:
    case 44:
    case 45:
    case 46:
    case 47:
    case 58:
    case 59:
    case 60:
    case 61:
    case 62:
    case 63:
    case 64:
    case 91:
    case 92:
    case 93:
    case 94:
    case 95:
    case 96:
    case 123:
    case 124:
    case 125:
    case 126:
      return true;
    default:
      return false;
  }
}
__name(isMdAsciiPunct, "isMdAsciiPunct");
function normalizeReference(str) {
  str = str.trim().replace(/\s+/g, " ");
  if ("ẞ".toLowerCase() === "Ṿ") {
    str = str.replace(/ẞ/g, "ß");
  }
  return str.toLowerCase().toUpperCase();
}
__name(normalizeReference, "normalizeReference");
const lib = { mdurl, ucmicro };
const utils = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  arrayReplaceAt,
  assign: assign$1,
  escapeHtml,
  escapeRE: escapeRE$1,
  fromCodePoint,
  has,
  isMdAsciiPunct,
  isPunctChar,
  isSpace,
  isString: isString$1,
  isValidEntityCode,
  isWhiteSpace,
  lib,
  normalizeReference,
  unescapeAll,
  unescapeMd
}, Symbol.toStringTag, { value: "Module" }));
function parseLinkLabel(state, start2, disableNested) {
  let level, found2, marker, prevPos;
  const max = state.posMax;
  const oldPos = state.pos;
  state.pos = start2 + 1;
  level = 1;
  while (state.pos < max) {
    marker = state.src.charCodeAt(state.pos);
    if (marker === 93) {
      level--;
      if (level === 0) {
        found2 = true;
        break;
      }
    }
    prevPos = state.pos;
    state.md.inline.skipToken(state);
    if (marker === 91) {
      if (prevPos === state.pos - 1) {
        level++;
      } else if (disableNested) {
        state.pos = oldPos;
        return -1;
      }
    }
  }
  let labelEnd = -1;
  if (found2) {
    labelEnd = state.pos;
  }
  state.pos = oldPos;
  return labelEnd;
}
__name(parseLinkLabel, "parseLinkLabel");
function parseLinkDestination(str, start2, max) {
  let code2;
  let pos = start2;
  const result = {
    ok: false,
    pos: 0,
    str: ""
  };
  if (str.charCodeAt(pos) === 60) {
    pos++;
    while (pos < max) {
      code2 = str.charCodeAt(pos);
      if (code2 === 10) {
        return result;
      }
      if (code2 === 60) {
        return result;
      }
      if (code2 === 62) {
        result.pos = pos + 1;
        result.str = unescapeAll(str.slice(start2 + 1, pos));
        result.ok = true;
        return result;
      }
      if (code2 === 92 && pos + 1 < max) {
        pos += 2;
        continue;
      }
      pos++;
    }
    return result;
  }
  let level = 0;
  while (pos < max) {
    code2 = str.charCodeAt(pos);
    if (code2 === 32) {
      break;
    }
    if (code2 < 32 || code2 === 127) {
      break;
    }
    if (code2 === 92 && pos + 1 < max) {
      if (str.charCodeAt(pos + 1) === 32) {
        break;
      }
      pos += 2;
      continue;
    }
    if (code2 === 40) {
      level++;
      if (level > 32) {
        return result;
      }
    }
    if (code2 === 41) {
      if (level === 0) {
        break;
      }
      level--;
    }
    pos++;
  }
  if (start2 === pos) {
    return result;
  }
  if (level !== 0) {
    return result;
  }
  result.str = unescapeAll(str.slice(start2, pos));
  result.pos = pos;
  result.ok = true;
  return result;
}
__name(parseLinkDestination, "parseLinkDestination");
function parseLinkTitle(str, start2, max, prev_state) {
  let code2;
  let pos = start2;
  const state = {
    // if `true`, this is a valid link title
    ok: false,
    // if `true`, this link can be continued on the next line
    can_continue: false,
    // if `ok`, it's the position of the first character after the closing marker
    pos: 0,
    // if `ok`, it's the unescaped title
    str: "",
    // expected closing marker character code
    marker: 0
  };
  if (prev_state) {
    state.str = prev_state.str;
    state.marker = prev_state.marker;
  } else {
    if (pos >= max) {
      return state;
    }
    let marker = str.charCodeAt(pos);
    if (marker !== 34 && marker !== 39 && marker !== 40) {
      return state;
    }
    start2++;
    pos++;
    if (marker === 40) {
      marker = 41;
    }
    state.marker = marker;
  }
  while (pos < max) {
    code2 = str.charCodeAt(pos);
    if (code2 === state.marker) {
      state.pos = pos + 1;
      state.str += unescapeAll(str.slice(start2, pos));
      state.ok = true;
      return state;
    } else if (code2 === 40 && state.marker === 41) {
      return state;
    } else if (code2 === 92 && pos + 1 < max) {
      pos++;
    }
    pos++;
  }
  state.can_continue = true;
  state.str += unescapeAll(str.slice(start2, pos));
  return state;
}
__name(parseLinkTitle, "parseLinkTitle");
const helpers = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  parseLinkDestination,
  parseLinkLabel,
  parseLinkTitle
}, Symbol.toStringTag, { value: "Module" }));
const default_rules = {};
default_rules.code_inline = function(tokens, idx, options5, env, slf) {
  const token = tokens[idx];
  return "<code" + slf.renderAttrs(token) + ">" + escapeHtml(token.content) + "</code>";
};
default_rules.code_block = function(tokens, idx, options5, env, slf) {
  const token = tokens[idx];
  return "<pre" + slf.renderAttrs(token) + "><code>" + escapeHtml(tokens[idx].content) + "</code></pre>\n";
};
default_rules.fence = function(tokens, idx, options5, env, slf) {
  const token = tokens[idx];
  const info = token.info ? unescapeAll(token.info).trim() : "";
  let langName = "";
  let langAttrs = "";
  if (info) {
    const arr = info.split(/(\s+)/g);
    langName = arr[0];
    langAttrs = arr.slice(2).join("");
  }
  let highlighted;
  if (options5.highlight) {
    highlighted = options5.highlight(token.content, langName, langAttrs) || escapeHtml(token.content);
  } else {
    highlighted = escapeHtml(token.content);
  }
  if (highlighted.indexOf("<pre") === 0) {
    return highlighted + "\n";
  }
  if (info) {
    const i2 = token.attrIndex("class");
    const tmpAttrs = token.attrs ? token.attrs.slice() : [];
    if (i2 < 0) {
      tmpAttrs.push(["class", options5.langPrefix + langName]);
    } else {
      tmpAttrs[i2] = tmpAttrs[i2].slice();
      tmpAttrs[i2][1] += " " + options5.langPrefix + langName;
    }
    const tmpToken = {
      attrs: tmpAttrs
    };
    return `<pre><code${slf.renderAttrs(tmpToken)}>${highlighted}</code></pre>
`;
  }
  return `<pre><code${slf.renderAttrs(token)}>${highlighted}</code></pre>
`;
};
default_rules.image = function(tokens, idx, options5, env, slf) {
  const token = tokens[idx];
  token.attrs[token.attrIndex("alt")][1] = slf.renderInlineAsText(token.children, options5, env);
  return slf.renderToken(tokens, idx, options5);
};
default_rules.hardbreak = function(tokens, idx, options5) {
  return options5.xhtmlOut ? "<br />\n" : "<br>\n";
};
default_rules.softbreak = function(tokens, idx, options5) {
  return options5.breaks ? options5.xhtmlOut ? "<br />\n" : "<br>\n" : "\n";
};
default_rules.text = function(tokens, idx) {
  return escapeHtml(tokens[idx].content);
};
default_rules.html_block = function(tokens, idx) {
  return tokens[idx].content;
};
default_rules.html_inline = function(tokens, idx) {
  return tokens[idx].content;
};
function Renderer() {
  this.rules = assign$1({}, default_rules);
}
__name(Renderer, "Renderer");
Renderer.prototype.renderAttrs = /* @__PURE__ */ __name(function renderAttrs(token) {
  let i2, l2, result;
  if (!token.attrs) {
    return "";
  }
  result = "";
  for (i2 = 0, l2 = token.attrs.length; i2 < l2; i2++) {
    result += " " + escapeHtml(token.attrs[i2][0]) + '="' + escapeHtml(token.attrs[i2][1]) + '"';
  }
  return result;
}, "renderAttrs");
Renderer.prototype.renderToken = /* @__PURE__ */ __name(function renderToken(tokens, idx, options5) {
  const token = tokens[idx];
  let result = "";
  if (token.hidden) {
    return "";
  }
  if (token.block && token.nesting !== -1 && idx && tokens[idx - 1].hidden) {
    result += "\n";
  }
  result += (token.nesting === -1 ? "</" : "<") + token.tag;
  result += this.renderAttrs(token);
  if (token.nesting === 0 && options5.xhtmlOut) {
    result += " /";
  }
  let needLf = false;
  if (token.block) {
    needLf = true;
    if (token.nesting === 1) {
      if (idx + 1 < tokens.length) {
        const nextToken = tokens[idx + 1];
        if (nextToken.type === "inline" || nextToken.hidden) {
          needLf = false;
        } else if (nextToken.nesting === -1 && nextToken.tag === token.tag) {
          needLf = false;
        }
      }
    }
  }
  result += needLf ? ">\n" : ">";
  return result;
}, "renderToken");
Renderer.prototype.renderInline = function(tokens, options5, env) {
  let result = "";
  const rules = this.rules;
  for (let i2 = 0, len = tokens.length; i2 < len; i2++) {
    const type = tokens[i2].type;
    if (typeof rules[type] !== "undefined") {
      result += rules[type](tokens, i2, options5, env, this);
    } else {
      result += this.renderToken(tokens, i2, options5);
    }
  }
  return result;
};
Renderer.prototype.renderInlineAsText = function(tokens, options5, env) {
  let result = "";
  for (let i2 = 0, len = tokens.length; i2 < len; i2++) {
    switch (tokens[i2].type) {
      case "text":
        result += tokens[i2].content;
        break;
      case "image":
        result += this.renderInlineAsText(tokens[i2].children, options5, env);
        break;
      case "html_inline":
      case "html_block":
        result += tokens[i2].content;
        break;
      case "softbreak":
      case "hardbreak":
        result += "\n";
        break;
      default:
    }
  }
  return result;
};
Renderer.prototype.render = function(tokens, options5, env) {
  let result = "";
  const rules = this.rules;
  for (let i2 = 0, len = tokens.length; i2 < len; i2++) {
    const type = tokens[i2].type;
    if (type === "inline") {
      result += this.renderInline(tokens[i2].children, options5, env);
    } else if (typeof rules[type] !== "undefined") {
      result += rules[type](tokens, i2, options5, env, this);
    } else {
      result += this.renderToken(tokens, i2, options5, env);
    }
  }
  return result;
};
function Ruler() {
  this.__rules__ = [];
  this.__cache__ = null;
}
__name(Ruler, "Ruler");
Ruler.prototype.__find__ = function(name2) {
  for (let i2 = 0; i2 < this.__rules__.length; i2++) {
    if (this.__rules__[i2].name === name2) {
      return i2;
    }
  }
  return -1;
};
Ruler.prototype.__compile__ = function() {
  const self2 = this;
  const chains = [""];
  self2.__rules__.forEach(function(rule) {
    if (!rule.enabled) {
      return;
    }
    rule.alt.forEach(function(altName) {
      if (chains.indexOf(altName) < 0) {
        chains.push(altName);
      }
    });
  });
  self2.__cache__ = {};
  chains.forEach(function(chain) {
    self2.__cache__[chain] = [];
    self2.__rules__.forEach(function(rule) {
      if (!rule.enabled) {
        return;
      }
      if (chain && rule.alt.indexOf(chain) < 0) {
        return;
      }
      self2.__cache__[chain].push(rule.fn);
    });
  });
};
Ruler.prototype.at = function(name2, fn, options5) {
  const index2 = this.__find__(name2);
  const opt = options5 || {};
  if (index2 === -1) {
    throw new Error("Parser rule not found: " + name2);
  }
  this.__rules__[index2].fn = fn;
  this.__rules__[index2].alt = opt.alt || [];
  this.__cache__ = null;
};
Ruler.prototype.before = function(beforeName, ruleName, fn, options5) {
  const index2 = this.__find__(beforeName);
  const opt = options5 || {};
  if (index2 === -1) {
    throw new Error("Parser rule not found: " + beforeName);
  }
  this.__rules__.splice(index2, 0, {
    name: ruleName,
    enabled: true,
    fn,
    alt: opt.alt || []
  });
  this.__cache__ = null;
};
Ruler.prototype.after = function(afterName, ruleName, fn, options5) {
  const index2 = this.__find__(afterName);
  const opt = options5 || {};
  if (index2 === -1) {
    throw new Error("Parser rule not found: " + afterName);
  }
  this.__rules__.splice(index2 + 1, 0, {
    name: ruleName,
    enabled: true,
    fn,
    alt: opt.alt || []
  });
  this.__cache__ = null;
};
Ruler.prototype.push = function(ruleName, fn, options5) {
  const opt = options5 || {};
  this.__rules__.push({
    name: ruleName,
    enabled: true,
    fn,
    alt: opt.alt || []
  });
  this.__cache__ = null;
};
Ruler.prototype.enable = function(list2, ignoreInvalid) {
  if (!Array.isArray(list2)) {
    list2 = [list2];
  }
  const result = [];
  list2.forEach(function(name2) {
    const idx = this.__find__(name2);
    if (idx < 0) {
      if (ignoreInvalid) {
        return;
      }
      throw new Error("Rules manager: invalid rule name " + name2);
    }
    this.__rules__[idx].enabled = true;
    result.push(name2);
  }, this);
  this.__cache__ = null;
  return result;
};
Ruler.prototype.enableOnly = function(list2, ignoreInvalid) {
  if (!Array.isArray(list2)) {
    list2 = [list2];
  }
  this.__rules__.forEach(function(rule) {
    rule.enabled = false;
  });
  this.enable(list2, ignoreInvalid);
};
Ruler.prototype.disable = function(list2, ignoreInvalid) {
  if (!Array.isArray(list2)) {
    list2 = [list2];
  }
  const result = [];
  list2.forEach(function(name2) {
    const idx = this.__find__(name2);
    if (idx < 0) {
      if (ignoreInvalid) {
        return;
      }
      throw new Error("Rules manager: invalid rule name " + name2);
    }
    this.__rules__[idx].enabled = false;
    result.push(name2);
  }, this);
  this.__cache__ = null;
  return result;
};
Ruler.prototype.getRules = function(chainName) {
  if (this.__cache__ === null) {
    this.__compile__();
  }
  return this.__cache__[chainName] || [];
};
function Token(type, tag, nesting) {
  this.type = type;
  this.tag = tag;
  this.attrs = null;
  this.map = null;
  this.nesting = nesting;
  this.level = 0;
  this.children = null;
  this.content = "";
  this.markup = "";
  this.info = "";
  this.meta = null;
  this.block = false;
  this.hidden = false;
}
__name(Token, "Token");
Token.prototype.attrIndex = /* @__PURE__ */ __name(function attrIndex(name2) {
  if (!this.attrs) {
    return -1;
  }
  const attrs7 = this.attrs;
  for (let i2 = 0, len = attrs7.length; i2 < len; i2++) {
    if (attrs7[i2][0] === name2) {
      return i2;
    }
  }
  return -1;
}, "attrIndex");
Token.prototype.attrPush = /* @__PURE__ */ __name(function attrPush(attrData) {
  if (this.attrs) {
    this.attrs.push(attrData);
  } else {
    this.attrs = [attrData];
  }
}, "attrPush");
Token.prototype.attrSet = /* @__PURE__ */ __name(function attrSet2(name2, value3) {
  const idx = this.attrIndex(name2);
  const attrData = [name2, value3];
  if (idx < 0) {
    this.attrPush(attrData);
  } else {
    this.attrs[idx] = attrData;
  }
}, "attrSet");
Token.prototype.attrGet = /* @__PURE__ */ __name(function attrGet(name2) {
  const idx = this.attrIndex(name2);
  let value3 = null;
  if (idx >= 0) {
    value3 = this.attrs[idx][1];
  }
  return value3;
}, "attrGet");
Token.prototype.attrJoin = /* @__PURE__ */ __name(function attrJoin(name2, value3) {
  const idx = this.attrIndex(name2);
  if (idx < 0) {
    this.attrPush([name2, value3]);
  } else {
    this.attrs[idx][1] = this.attrs[idx][1] + " " + value3;
  }
}, "attrJoin");
function StateCore(src, md2, env) {
  this.src = src;
  this.env = env;
  this.tokens = [];
  this.inlineMode = false;
  this.md = md2;
}
__name(StateCore, "StateCore");
StateCore.prototype.Token = Token;
const NEWLINES_RE = /\r\n?|\n/g;
const NULL_RE = /\0/g;
function normalize(state) {
  let str;
  str = state.src.replace(NEWLINES_RE, "\n");
  str = str.replace(NULL_RE, "�");
  state.src = str;
}
__name(normalize, "normalize");
function block(state) {
  let token;
  if (state.inlineMode) {
    token = new state.Token("inline", "", 0);
    token.content = state.src;
    token.map = [0, 1];
    token.children = [];
    state.tokens.push(token);
  } else {
    state.md.block.parse(state.src, state.md, state.env, state.tokens);
  }
}
__name(block, "block");
function inline(state) {
  const tokens = state.tokens;
  for (let i2 = 0, l2 = tokens.length; i2 < l2; i2++) {
    const tok = tokens[i2];
    if (tok.type === "inline") {
      state.md.inline.parse(tok.content, state.md, state.env, tok.children);
    }
  }
}
__name(inline, "inline");
function isLinkOpen$1(str) {
  return /^<a[>\s]/i.test(str);
}
__name(isLinkOpen$1, "isLinkOpen$1");
function isLinkClose$1(str) {
  return /^<\/a\s*>/i.test(str);
}
__name(isLinkClose$1, "isLinkClose$1");
function linkify$1(state) {
  const blockTokens = state.tokens;
  if (!state.md.options.linkify) {
    return;
  }
  for (let j2 = 0, l2 = blockTokens.length; j2 < l2; j2++) {
    if (blockTokens[j2].type !== "inline" || !state.md.linkify.pretest(blockTokens[j2].content)) {
      continue;
    }
    let tokens = blockTokens[j2].children;
    let htmlLinkLevel = 0;
    for (let i2 = tokens.length - 1; i2 >= 0; i2--) {
      const currentToken = tokens[i2];
      if (currentToken.type === "link_close") {
        i2--;
        while (tokens[i2].level !== currentToken.level && tokens[i2].type !== "link_open") {
          i2--;
        }
        continue;
      }
      if (currentToken.type === "html_inline") {
        if (isLinkOpen$1(currentToken.content) && htmlLinkLevel > 0) {
          htmlLinkLevel--;
        }
        if (isLinkClose$1(currentToken.content)) {
          htmlLinkLevel++;
        }
      }
      if (htmlLinkLevel > 0) {
        continue;
      }
      if (currentToken.type === "text" && state.md.linkify.test(currentToken.content)) {
        const text2 = currentToken.content;
        let links = state.md.linkify.match(text2);
        const nodes = [];
        let level = currentToken.level;
        let lastPos = 0;
        if (links.length > 0 && links[0].index === 0 && i2 > 0 && tokens[i2 - 1].type === "text_special") {
          links = links.slice(1);
        }
        for (let ln = 0; ln < links.length; ln++) {
          const url = links[ln].url;
          const fullUrl = state.md.normalizeLink(url);
          if (!state.md.validateLink(fullUrl)) {
            continue;
          }
          let urlText = links[ln].text;
          if (!links[ln].schema) {
            urlText = state.md.normalizeLinkText("http://" + urlText).replace(/^http:\/\//, "");
          } else if (links[ln].schema === "mailto:" && !/^mailto:/i.test(urlText)) {
            urlText = state.md.normalizeLinkText("mailto:" + urlText).replace(/^mailto:/, "");
          } else {
            urlText = state.md.normalizeLinkText(urlText);
          }
          const pos = links[ln].index;
          if (pos > lastPos) {
            const token = new state.Token("text", "", 0);
            token.content = text2.slice(lastPos, pos);
            token.level = level;
            nodes.push(token);
          }
          const token_o = new state.Token("link_open", "a", 1);
          token_o.attrs = [["href", fullUrl]];
          token_o.level = level++;
          token_o.markup = "linkify";
          token_o.info = "auto";
          nodes.push(token_o);
          const token_t = new state.Token("text", "", 0);
          token_t.content = urlText;
          token_t.level = level;
          nodes.push(token_t);
          const token_c = new state.Token("link_close", "a", -1);
          token_c.level = --level;
          token_c.markup = "linkify";
          token_c.info = "auto";
          nodes.push(token_c);
          lastPos = links[ln].lastIndex;
        }
        if (lastPos < text2.length) {
          const token = new state.Token("text", "", 0);
          token.content = text2.slice(lastPos);
          token.level = level;
          nodes.push(token);
        }
        blockTokens[j2].children = tokens = arrayReplaceAt(tokens, i2, nodes);
      }
    }
  }
}
__name(linkify$1, "linkify$1");
const RARE_RE = /\+-|\.\.|\?\?\?\?|!!!!|,,|--/;
const SCOPED_ABBR_TEST_RE = /\((c|tm|r)\)/i;
const SCOPED_ABBR_RE = /\((c|tm|r)\)/ig;
const SCOPED_ABBR = {
  c: "©",
  r: "®",
  tm: "™"
};
function replaceFn(match2, name2) {
  return SCOPED_ABBR[name2.toLowerCase()];
}
__name(replaceFn, "replaceFn");
function replace_scoped(inlineTokens) {
  let inside_autolink = 0;
  for (let i2 = inlineTokens.length - 1; i2 >= 0; i2--) {
    const token = inlineTokens[i2];
    if (token.type === "text" && !inside_autolink) {
      token.content = token.content.replace(SCOPED_ABBR_RE, replaceFn);
    }
    if (token.type === "link_open" && token.info === "auto") {
      inside_autolink--;
    }
    if (token.type === "link_close" && token.info === "auto") {
      inside_autolink++;
    }
  }
}
__name(replace_scoped, "replace_scoped");
function replace_rare(inlineTokens) {
  let inside_autolink = 0;
  for (let i2 = inlineTokens.length - 1; i2 >= 0; i2--) {
    const token = inlineTokens[i2];
    if (token.type === "text" && !inside_autolink) {
      if (RARE_RE.test(token.content)) {
        token.content = token.content.replace(/\+-/g, "±").replace(/\.{2,}/g, "…").replace(/([?!])…/g, "$1..").replace(/([?!]){4,}/g, "$1$1$1").replace(/,{2,}/g, ",").replace(/(^|[^-])---(?=[^-]|$)/mg, "$1—").replace(/(^|\s)--(?=\s|$)/mg, "$1–").replace(/(^|[^-\s])--(?=[^-\s]|$)/mg, "$1–");
      }
    }
    if (token.type === "link_open" && token.info === "auto") {
      inside_autolink--;
    }
    if (token.type === "link_close" && token.info === "auto") {
      inside_autolink++;
    }
  }
}
__name(replace_rare, "replace_rare");
function replace(state) {
  let blkIdx;
  if (!state.md.options.typographer) {
    return;
  }
  for (blkIdx = state.tokens.length - 1; blkIdx >= 0; blkIdx--) {
    if (state.tokens[blkIdx].type !== "inline") {
      continue;
    }
    if (SCOPED_ABBR_TEST_RE.test(state.tokens[blkIdx].content)) {
      replace_scoped(state.tokens[blkIdx].children);
    }
    if (RARE_RE.test(state.tokens[blkIdx].content)) {
      replace_rare(state.tokens[blkIdx].children);
    }
  }
}
__name(replace, "replace");
const QUOTE_TEST_RE = /['"]/;
const QUOTE_RE = /['"]/g;
const APOSTROPHE = "’";
function replaceAt(str, index2, ch) {
  return str.slice(0, index2) + ch + str.slice(index2 + 1);
}
__name(replaceAt, "replaceAt");
function process_inlines(tokens, state) {
  let j2;
  const stack2 = [];
  for (let i2 = 0; i2 < tokens.length; i2++) {
    const token = tokens[i2];
    const thisLevel = tokens[i2].level;
    for (j2 = stack2.length - 1; j2 >= 0; j2--) {
      if (stack2[j2].level <= thisLevel) {
        break;
      }
    }
    stack2.length = j2 + 1;
    if (token.type !== "text") {
      continue;
    }
    let text2 = token.content;
    let pos = 0;
    let max = text2.length;
    OUTER:
      while (pos < max) {
        QUOTE_RE.lastIndex = pos;
        const t2 = QUOTE_RE.exec(text2);
        if (!t2) {
          break;
        }
        let canOpen = true;
        let canClose = true;
        pos = t2.index + 1;
        const isSingle = t2[0] === "'";
        let lastChar = 32;
        if (t2.index - 1 >= 0) {
          lastChar = text2.charCodeAt(t2.index - 1);
        } else {
          for (j2 = i2 - 1; j2 >= 0; j2--) {
            if (tokens[j2].type === "softbreak" || tokens[j2].type === "hardbreak") break;
            if (!tokens[j2].content) continue;
            lastChar = tokens[j2].content.charCodeAt(tokens[j2].content.length - 1);
            break;
          }
        }
        let nextChar = 32;
        if (pos < max) {
          nextChar = text2.charCodeAt(pos);
        } else {
          for (j2 = i2 + 1; j2 < tokens.length; j2++) {
            if (tokens[j2].type === "softbreak" || tokens[j2].type === "hardbreak") break;
            if (!tokens[j2].content) continue;
            nextChar = tokens[j2].content.charCodeAt(0);
            break;
          }
        }
        const isLastPunctChar = isMdAsciiPunct(lastChar) || isPunctChar(String.fromCharCode(lastChar));
        const isNextPunctChar = isMdAsciiPunct(nextChar) || isPunctChar(String.fromCharCode(nextChar));
        const isLastWhiteSpace = isWhiteSpace(lastChar);
        const isNextWhiteSpace = isWhiteSpace(nextChar);
        if (isNextWhiteSpace) {
          canOpen = false;
        } else if (isNextPunctChar) {
          if (!(isLastWhiteSpace || isLastPunctChar)) {
            canOpen = false;
          }
        }
        if (isLastWhiteSpace) {
          canClose = false;
        } else if (isLastPunctChar) {
          if (!(isNextWhiteSpace || isNextPunctChar)) {
            canClose = false;
          }
        }
        if (nextChar === 34 && t2[0] === '"') {
          if (lastChar >= 48 && lastChar <= 57) {
            canClose = canOpen = false;
          }
        }
        if (canOpen && canClose) {
          canOpen = isLastPunctChar;
          canClose = isNextPunctChar;
        }
        if (!canOpen && !canClose) {
          if (isSingle) {
            token.content = replaceAt(token.content, t2.index, APOSTROPHE);
          }
          continue;
        }
        if (canClose) {
          for (j2 = stack2.length - 1; j2 >= 0; j2--) {
            let item3 = stack2[j2];
            if (stack2[j2].level < thisLevel) {
              break;
            }
            if (item3.single === isSingle && stack2[j2].level === thisLevel) {
              item3 = stack2[j2];
              let openQuote;
              let closeQuote;
              if (isSingle) {
                openQuote = state.md.options.quotes[2];
                closeQuote = state.md.options.quotes[3];
              } else {
                openQuote = state.md.options.quotes[0];
                closeQuote = state.md.options.quotes[1];
              }
              token.content = replaceAt(token.content, t2.index, closeQuote);
              tokens[item3.token].content = replaceAt(
                tokens[item3.token].content,
                item3.pos,
                openQuote
              );
              pos += closeQuote.length - 1;
              if (item3.token === i2) {
                pos += openQuote.length - 1;
              }
              text2 = token.content;
              max = text2.length;
              stack2.length = j2;
              continue OUTER;
            }
          }
        }
        if (canOpen) {
          stack2.push({
            token: i2,
            pos: t2.index,
            single: isSingle,
            level: thisLevel
          });
        } else if (canClose && isSingle) {
          token.content = replaceAt(token.content, t2.index, APOSTROPHE);
        }
      }
  }
}
__name(process_inlines, "process_inlines");
function smartquotes(state) {
  if (!state.md.options.typographer) {
    return;
  }
  for (let blkIdx = state.tokens.length - 1; blkIdx >= 0; blkIdx--) {
    if (state.tokens[blkIdx].type !== "inline" || !QUOTE_TEST_RE.test(state.tokens[blkIdx].content)) {
      continue;
    }
    process_inlines(state.tokens[blkIdx].children, state);
  }
}
__name(smartquotes, "smartquotes");
function text_join(state) {
  let curr, last;
  const blockTokens = state.tokens;
  const l2 = blockTokens.length;
  for (let j2 = 0; j2 < l2; j2++) {
    if (blockTokens[j2].type !== "inline") continue;
    const tokens = blockTokens[j2].children;
    const max = tokens.length;
    for (curr = 0; curr < max; curr++) {
      if (tokens[curr].type === "text_special") {
        tokens[curr].type = "text";
      }
    }
    for (curr = last = 0; curr < max; curr++) {
      if (tokens[curr].type === "text" && curr + 1 < max && tokens[curr + 1].type === "text") {
        tokens[curr + 1].content = tokens[curr].content + tokens[curr + 1].content;
      } else {
        if (curr !== last) {
          tokens[last] = tokens[curr];
        }
        last++;
      }
    }
    if (curr !== last) {
      tokens.length = last;
    }
  }
}
__name(text_join, "text_join");
const _rules$2 = [
  ["normalize", normalize],
  ["block", block],
  ["inline", inline],
  ["linkify", linkify$1],
  ["replacements", replace],
  ["smartquotes", smartquotes],
  // `text_join` finds `text_special` tokens (for escape sequences)
  // and joins them with the rest of the text
  ["text_join", text_join]
];
function Core() {
  this.ruler = new Ruler();
  for (let i2 = 0; i2 < _rules$2.length; i2++) {
    this.ruler.push(_rules$2[i2][0], _rules$2[i2][1]);
  }
}
__name(Core, "Core");
Core.prototype.process = function(state) {
  const rules = this.ruler.getRules("");
  for (let i2 = 0, l2 = rules.length; i2 < l2; i2++) {
    rules[i2](state);
  }
};
Core.prototype.State = StateCore;
function StateBlock(src, md2, env, tokens) {
  this.src = src;
  this.md = md2;
  this.env = env;
  this.tokens = tokens;
  this.bMarks = [];
  this.eMarks = [];
  this.tShift = [];
  this.sCount = [];
  this.bsCount = [];
  this.blkIndent = 0;
  this.line = 0;
  this.lineMax = 0;
  this.tight = false;
  this.ddIndent = -1;
  this.listIndent = -1;
  this.parentType = "root";
  this.level = 0;
  const s2 = this.src;
  for (let start2 = 0, pos = 0, indent = 0, offset = 0, len = s2.length, indent_found = false; pos < len; pos++) {
    const ch = s2.charCodeAt(pos);
    if (!indent_found) {
      if (isSpace(ch)) {
        indent++;
        if (ch === 9) {
          offset += 4 - offset % 4;
        } else {
          offset++;
        }
        continue;
      } else {
        indent_found = true;
      }
    }
    if (ch === 10 || pos === len - 1) {
      if (ch !== 10) {
        pos++;
      }
      this.bMarks.push(start2);
      this.eMarks.push(pos);
      this.tShift.push(indent);
      this.sCount.push(offset);
      this.bsCount.push(0);
      indent_found = false;
      indent = 0;
      offset = 0;
      start2 = pos + 1;
    }
  }
  this.bMarks.push(s2.length);
  this.eMarks.push(s2.length);
  this.tShift.push(0);
  this.sCount.push(0);
  this.bsCount.push(0);
  this.lineMax = this.bMarks.length - 1;
}
__name(StateBlock, "StateBlock");
StateBlock.prototype.push = function(type, tag, nesting) {
  const token = new Token(type, tag, nesting);
  token.block = true;
  if (nesting < 0) this.level--;
  token.level = this.level;
  if (nesting > 0) this.level++;
  this.tokens.push(token);
  return token;
};
StateBlock.prototype.isEmpty = /* @__PURE__ */ __name(function isEmpty2(line) {
  return this.bMarks[line] + this.tShift[line] >= this.eMarks[line];
}, "isEmpty");
StateBlock.prototype.skipEmptyLines = /* @__PURE__ */ __name(function skipEmptyLines(from2) {
  for (let max = this.lineMax; from2 < max; from2++) {
    if (this.bMarks[from2] + this.tShift[from2] < this.eMarks[from2]) {
      break;
    }
  }
  return from2;
}, "skipEmptyLines");
StateBlock.prototype.skipSpaces = /* @__PURE__ */ __name(function skipSpaces(pos) {
  for (let max = this.src.length; pos < max; pos++) {
    const ch = this.src.charCodeAt(pos);
    if (!isSpace(ch)) {
      break;
    }
  }
  return pos;
}, "skipSpaces");
StateBlock.prototype.skipSpacesBack = /* @__PURE__ */ __name(function skipSpacesBack(pos, min) {
  if (pos <= min) {
    return pos;
  }
  while (pos > min) {
    if (!isSpace(this.src.charCodeAt(--pos))) {
      return pos + 1;
    }
  }
  return pos;
}, "skipSpacesBack");
StateBlock.prototype.skipChars = /* @__PURE__ */ __name(function skipChars(pos, code2) {
  for (let max = this.src.length; pos < max; pos++) {
    if (this.src.charCodeAt(pos) !== code2) {
      break;
    }
  }
  return pos;
}, "skipChars");
StateBlock.prototype.skipCharsBack = /* @__PURE__ */ __name(function skipCharsBack(pos, code2, min) {
  if (pos <= min) {
    return pos;
  }
  while (pos > min) {
    if (code2 !== this.src.charCodeAt(--pos)) {
      return pos + 1;
    }
  }
  return pos;
}, "skipCharsBack");
StateBlock.prototype.getLines = /* @__PURE__ */ __name(function getLines(begin, end, indent, keepLastLF) {
  if (begin >= end) {
    return "";
  }
  const queue2 = new Array(end - begin);
  for (let i2 = 0, line = begin; line < end; line++, i2++) {
    let lineIndent = 0;
    const lineStart = this.bMarks[line];
    let first2 = lineStart;
    let last;
    if (line + 1 < end || keepLastLF) {
      last = this.eMarks[line] + 1;
    } else {
      last = this.eMarks[line];
    }
    while (first2 < last && lineIndent < indent) {
      const ch = this.src.charCodeAt(first2);
      if (isSpace(ch)) {
        if (ch === 9) {
          lineIndent += 4 - (lineIndent + this.bsCount[line]) % 4;
        } else {
          lineIndent++;
        }
      } else if (first2 - lineStart < this.tShift[line]) {
        lineIndent++;
      } else {
        break;
      }
      first2++;
    }
    if (lineIndent > indent) {
      queue2[i2] = new Array(lineIndent - indent + 1).join(" ") + this.src.slice(first2, last);
    } else {
      queue2[i2] = this.src.slice(first2, last);
    }
  }
  return queue2.join("");
}, "getLines");
StateBlock.prototype.Token = Token;
const MAX_AUTOCOMPLETED_CELLS = 65536;
function getLine(state, line) {
  const pos = state.bMarks[line] + state.tShift[line];
  const max = state.eMarks[line];
  return state.src.slice(pos, max);
}
__name(getLine, "getLine");
function escapedSplit(str) {
  const result = [];
  const max = str.length;
  let pos = 0;
  let ch = str.charCodeAt(pos);
  let isEscaped = false;
  let lastPos = 0;
  let current = "";
  while (pos < max) {
    if (ch === 124) {
      if (!isEscaped) {
        result.push(current + str.substring(lastPos, pos));
        current = "";
        lastPos = pos + 1;
      } else {
        current += str.substring(lastPos, pos - 1);
        lastPos = pos;
      }
    }
    isEscaped = ch === 92;
    pos++;
    ch = str.charCodeAt(pos);
  }
  result.push(current + str.substring(lastPos));
  return result;
}
__name(escapedSplit, "escapedSplit");
function table(state, startLine, endLine, silent) {
  if (startLine + 2 > endLine) {
    return false;
  }
  let nextLine = startLine + 1;
  if (state.sCount[nextLine] < state.blkIndent) {
    return false;
  }
  if (state.sCount[nextLine] - state.blkIndent >= 4) {
    return false;
  }
  let pos = state.bMarks[nextLine] + state.tShift[nextLine];
  if (pos >= state.eMarks[nextLine]) {
    return false;
  }
  const firstCh = state.src.charCodeAt(pos++);
  if (firstCh !== 124 && firstCh !== 45 && firstCh !== 58) {
    return false;
  }
  if (pos >= state.eMarks[nextLine]) {
    return false;
  }
  const secondCh = state.src.charCodeAt(pos++);
  if (secondCh !== 124 && secondCh !== 45 && secondCh !== 58 && !isSpace(secondCh)) {
    return false;
  }
  if (firstCh === 45 && isSpace(secondCh)) {
    return false;
  }
  while (pos < state.eMarks[nextLine]) {
    const ch = state.src.charCodeAt(pos);
    if (ch !== 124 && ch !== 45 && ch !== 58 && !isSpace(ch)) {
      return false;
    }
    pos++;
  }
  let lineText = getLine(state, startLine + 1);
  let columns = lineText.split("|");
  const aligns = [];
  for (let i2 = 0; i2 < columns.length; i2++) {
    const t2 = columns[i2].trim();
    if (!t2) {
      if (i2 === 0 || i2 === columns.length - 1) {
        continue;
      } else {
        return false;
      }
    }
    if (!/^:?-+:?$/.test(t2)) {
      return false;
    }
    if (t2.charCodeAt(t2.length - 1) === 58) {
      aligns.push(t2.charCodeAt(0) === 58 ? "center" : "right");
    } else if (t2.charCodeAt(0) === 58) {
      aligns.push("left");
    } else {
      aligns.push("");
    }
  }
  lineText = getLine(state, startLine).trim();
  if (lineText.indexOf("|") === -1) {
    return false;
  }
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  columns = escapedSplit(lineText);
  if (columns.length && columns[0] === "") columns.shift();
  if (columns.length && columns[columns.length - 1] === "") columns.pop();
  const columnCount = columns.length;
  if (columnCount === 0 || columnCount !== aligns.length) {
    return false;
  }
  if (silent) {
    return true;
  }
  const oldParentType = state.parentType;
  state.parentType = "table";
  const terminatorRules = state.md.block.ruler.getRules("blockquote");
  const token_to = state.push("table_open", "table", 1);
  const tableLines = [startLine, 0];
  token_to.map = tableLines;
  const token_tho = state.push("thead_open", "thead", 1);
  token_tho.map = [startLine, startLine + 1];
  const token_htro = state.push("tr_open", "tr", 1);
  token_htro.map = [startLine, startLine + 1];
  for (let i2 = 0; i2 < columns.length; i2++) {
    const token_ho = state.push("th_open", "th", 1);
    if (aligns[i2]) {
      token_ho.attrs = [["style", "text-align:" + aligns[i2]]];
    }
    const token_il = state.push("inline", "", 0);
    token_il.content = columns[i2].trim();
    token_il.children = [];
    state.push("th_close", "th", -1);
  }
  state.push("tr_close", "tr", -1);
  state.push("thead_close", "thead", -1);
  let tbodyLines;
  let autocompletedCells = 0;
  for (nextLine = startLine + 2; nextLine < endLine; nextLine++) {
    if (state.sCount[nextLine] < state.blkIndent) {
      break;
    }
    let terminate = false;
    for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
      if (terminatorRules[i2](state, nextLine, endLine, true)) {
        terminate = true;
        break;
      }
    }
    if (terminate) {
      break;
    }
    lineText = getLine(state, nextLine).trim();
    if (!lineText) {
      break;
    }
    if (state.sCount[nextLine] - state.blkIndent >= 4) {
      break;
    }
    columns = escapedSplit(lineText);
    if (columns.length && columns[0] === "") columns.shift();
    if (columns.length && columns[columns.length - 1] === "") columns.pop();
    autocompletedCells += columnCount - columns.length;
    if (autocompletedCells > MAX_AUTOCOMPLETED_CELLS) {
      break;
    }
    if (nextLine === startLine + 2) {
      const token_tbo = state.push("tbody_open", "tbody", 1);
      token_tbo.map = tbodyLines = [startLine + 2, 0];
    }
    const token_tro = state.push("tr_open", "tr", 1);
    token_tro.map = [nextLine, nextLine + 1];
    for (let i2 = 0; i2 < columnCount; i2++) {
      const token_tdo = state.push("td_open", "td", 1);
      if (aligns[i2]) {
        token_tdo.attrs = [["style", "text-align:" + aligns[i2]]];
      }
      const token_il = state.push("inline", "", 0);
      token_il.content = columns[i2] ? columns[i2].trim() : "";
      token_il.children = [];
      state.push("td_close", "td", -1);
    }
    state.push("tr_close", "tr", -1);
  }
  if (tbodyLines) {
    state.push("tbody_close", "tbody", -1);
    tbodyLines[1] = nextLine;
  }
  state.push("table_close", "table", -1);
  tableLines[1] = nextLine;
  state.parentType = oldParentType;
  state.line = nextLine;
  return true;
}
__name(table, "table");
function code(state, startLine, endLine) {
  if (state.sCount[startLine] - state.blkIndent < 4) {
    return false;
  }
  let nextLine = startLine + 1;
  let last = nextLine;
  while (nextLine < endLine) {
    if (state.isEmpty(nextLine)) {
      nextLine++;
      continue;
    }
    if (state.sCount[nextLine] - state.blkIndent >= 4) {
      nextLine++;
      last = nextLine;
      continue;
    }
    break;
  }
  state.line = last;
  const token = state.push("code_block", "code", 0);
  token.content = state.getLines(startLine, last, 4 + state.blkIndent, false) + "\n";
  token.map = [startLine, state.line];
  return true;
}
__name(code, "code");
function fence(state, startLine, endLine, silent) {
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  let max = state.eMarks[startLine];
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  if (pos + 3 > max) {
    return false;
  }
  const marker = state.src.charCodeAt(pos);
  if (marker !== 126 && marker !== 96) {
    return false;
  }
  let mem = pos;
  pos = state.skipChars(pos, marker);
  let len = pos - mem;
  if (len < 3) {
    return false;
  }
  const markup = state.src.slice(mem, pos);
  const params = state.src.slice(pos, max);
  if (marker === 96) {
    if (params.indexOf(String.fromCharCode(marker)) >= 0) {
      return false;
    }
  }
  if (silent) {
    return true;
  }
  let nextLine = startLine;
  let haveEndMarker = false;
  for (; ; ) {
    nextLine++;
    if (nextLine >= endLine) {
      break;
    }
    pos = mem = state.bMarks[nextLine] + state.tShift[nextLine];
    max = state.eMarks[nextLine];
    if (pos < max && state.sCount[nextLine] < state.blkIndent) {
      break;
    }
    if (state.src.charCodeAt(pos) !== marker) {
      continue;
    }
    if (state.sCount[nextLine] - state.blkIndent >= 4) {
      continue;
    }
    pos = state.skipChars(pos, marker);
    if (pos - mem < len) {
      continue;
    }
    pos = state.skipSpaces(pos);
    if (pos < max) {
      continue;
    }
    haveEndMarker = true;
    break;
  }
  len = state.sCount[startLine];
  state.line = nextLine + (haveEndMarker ? 1 : 0);
  const token = state.push("fence", "code", 0);
  token.info = params;
  token.content = state.getLines(startLine + 1, nextLine, len, true);
  token.markup = markup;
  token.map = [startLine, state.line];
  return true;
}
__name(fence, "fence");
function blockquote(state, startLine, endLine, silent) {
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  let max = state.eMarks[startLine];
  const oldLineMax = state.lineMax;
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  if (state.src.charCodeAt(pos) !== 62) {
    return false;
  }
  if (silent) {
    return true;
  }
  const oldBMarks = [];
  const oldBSCount = [];
  const oldSCount = [];
  const oldTShift = [];
  const terminatorRules = state.md.block.ruler.getRules("blockquote");
  const oldParentType = state.parentType;
  state.parentType = "blockquote";
  let lastLineEmpty = false;
  let nextLine;
  for (nextLine = startLine; nextLine < endLine; nextLine++) {
    const isOutdented = state.sCount[nextLine] < state.blkIndent;
    pos = state.bMarks[nextLine] + state.tShift[nextLine];
    max = state.eMarks[nextLine];
    if (pos >= max) {
      break;
    }
    if (state.src.charCodeAt(pos++) === 62 && !isOutdented) {
      let initial = state.sCount[nextLine] + 1;
      let spaceAfterMarker;
      let adjustTab;
      if (state.src.charCodeAt(pos) === 32) {
        pos++;
        initial++;
        adjustTab = false;
        spaceAfterMarker = true;
      } else if (state.src.charCodeAt(pos) === 9) {
        spaceAfterMarker = true;
        if ((state.bsCount[nextLine] + initial) % 4 === 3) {
          pos++;
          initial++;
          adjustTab = false;
        } else {
          adjustTab = true;
        }
      } else {
        spaceAfterMarker = false;
      }
      let offset = initial;
      oldBMarks.push(state.bMarks[nextLine]);
      state.bMarks[nextLine] = pos;
      while (pos < max) {
        const ch = state.src.charCodeAt(pos);
        if (isSpace(ch)) {
          if (ch === 9) {
            offset += 4 - (offset + state.bsCount[nextLine] + (adjustTab ? 1 : 0)) % 4;
          } else {
            offset++;
          }
        } else {
          break;
        }
        pos++;
      }
      lastLineEmpty = pos >= max;
      oldBSCount.push(state.bsCount[nextLine]);
      state.bsCount[nextLine] = state.sCount[nextLine] + 1 + (spaceAfterMarker ? 1 : 0);
      oldSCount.push(state.sCount[nextLine]);
      state.sCount[nextLine] = offset - initial;
      oldTShift.push(state.tShift[nextLine]);
      state.tShift[nextLine] = pos - state.bMarks[nextLine];
      continue;
    }
    if (lastLineEmpty) {
      break;
    }
    let terminate = false;
    for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
      if (terminatorRules[i2](state, nextLine, endLine, true)) {
        terminate = true;
        break;
      }
    }
    if (terminate) {
      state.lineMax = nextLine;
      if (state.blkIndent !== 0) {
        oldBMarks.push(state.bMarks[nextLine]);
        oldBSCount.push(state.bsCount[nextLine]);
        oldTShift.push(state.tShift[nextLine]);
        oldSCount.push(state.sCount[nextLine]);
        state.sCount[nextLine] -= state.blkIndent;
      }
      break;
    }
    oldBMarks.push(state.bMarks[nextLine]);
    oldBSCount.push(state.bsCount[nextLine]);
    oldTShift.push(state.tShift[nextLine]);
    oldSCount.push(state.sCount[nextLine]);
    state.sCount[nextLine] = -1;
  }
  const oldIndent = state.blkIndent;
  state.blkIndent = 0;
  const token_o = state.push("blockquote_open", "blockquote", 1);
  token_o.markup = ">";
  const lines = [startLine, 0];
  token_o.map = lines;
  state.md.block.tokenize(state, startLine, nextLine);
  const token_c = state.push("blockquote_close", "blockquote", -1);
  token_c.markup = ">";
  state.lineMax = oldLineMax;
  state.parentType = oldParentType;
  lines[1] = state.line;
  for (let i2 = 0; i2 < oldTShift.length; i2++) {
    state.bMarks[i2 + startLine] = oldBMarks[i2];
    state.tShift[i2 + startLine] = oldTShift[i2];
    state.sCount[i2 + startLine] = oldSCount[i2];
    state.bsCount[i2 + startLine] = oldBSCount[i2];
  }
  state.blkIndent = oldIndent;
  return true;
}
__name(blockquote, "blockquote");
function hr(state, startLine, endLine, silent) {
  const max = state.eMarks[startLine];
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  const marker = state.src.charCodeAt(pos++);
  if (marker !== 42 && marker !== 45 && marker !== 95) {
    return false;
  }
  let cnt = 1;
  while (pos < max) {
    const ch = state.src.charCodeAt(pos++);
    if (ch !== marker && !isSpace(ch)) {
      return false;
    }
    if (ch === marker) {
      cnt++;
    }
  }
  if (cnt < 3) {
    return false;
  }
  if (silent) {
    return true;
  }
  state.line = startLine + 1;
  const token = state.push("hr", "hr", 0);
  token.map = [startLine, state.line];
  token.markup = Array(cnt + 1).join(String.fromCharCode(marker));
  return true;
}
__name(hr, "hr");
function skipBulletListMarker(state, startLine) {
  const max = state.eMarks[startLine];
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  const marker = state.src.charCodeAt(pos++);
  if (marker !== 42 && marker !== 45 && marker !== 43) {
    return -1;
  }
  if (pos < max) {
    const ch = state.src.charCodeAt(pos);
    if (!isSpace(ch)) {
      return -1;
    }
  }
  return pos;
}
__name(skipBulletListMarker, "skipBulletListMarker");
function skipOrderedListMarker(state, startLine) {
  const start2 = state.bMarks[startLine] + state.tShift[startLine];
  const max = state.eMarks[startLine];
  let pos = start2;
  if (pos + 1 >= max) {
    return -1;
  }
  let ch = state.src.charCodeAt(pos++);
  if (ch < 48 || ch > 57) {
    return -1;
  }
  for (; ; ) {
    if (pos >= max) {
      return -1;
    }
    ch = state.src.charCodeAt(pos++);
    if (ch >= 48 && ch <= 57) {
      if (pos - start2 >= 10) {
        return -1;
      }
      continue;
    }
    if (ch === 41 || ch === 46) {
      break;
    }
    return -1;
  }
  if (pos < max) {
    ch = state.src.charCodeAt(pos);
    if (!isSpace(ch)) {
      return -1;
    }
  }
  return pos;
}
__name(skipOrderedListMarker, "skipOrderedListMarker");
function markTightParagraphs(state, idx) {
  const level = state.level + 2;
  for (let i2 = idx + 2, l2 = state.tokens.length - 2; i2 < l2; i2++) {
    if (state.tokens[i2].level === level && state.tokens[i2].type === "paragraph_open") {
      state.tokens[i2 + 2].hidden = true;
      state.tokens[i2].hidden = true;
      i2 += 2;
    }
  }
}
__name(markTightParagraphs, "markTightParagraphs");
function list(state, startLine, endLine, silent) {
  let max, pos, start2, token;
  let nextLine = startLine;
  let tight = true;
  if (state.sCount[nextLine] - state.blkIndent >= 4) {
    return false;
  }
  if (state.listIndent >= 0 && state.sCount[nextLine] - state.listIndent >= 4 && state.sCount[nextLine] < state.blkIndent) {
    return false;
  }
  let isTerminatingParagraph = false;
  if (silent && state.parentType === "paragraph") {
    if (state.sCount[nextLine] >= state.blkIndent) {
      isTerminatingParagraph = true;
    }
  }
  let isOrdered;
  let markerValue;
  let posAfterMarker;
  if ((posAfterMarker = skipOrderedListMarker(state, nextLine)) >= 0) {
    isOrdered = true;
    start2 = state.bMarks[nextLine] + state.tShift[nextLine];
    markerValue = Number(state.src.slice(start2, posAfterMarker - 1));
    if (isTerminatingParagraph && markerValue !== 1) return false;
  } else if ((posAfterMarker = skipBulletListMarker(state, nextLine)) >= 0) {
    isOrdered = false;
  } else {
    return false;
  }
  if (isTerminatingParagraph) {
    if (state.skipSpaces(posAfterMarker) >= state.eMarks[nextLine]) return false;
  }
  if (silent) {
    return true;
  }
  const markerCharCode = state.src.charCodeAt(posAfterMarker - 1);
  const listTokIdx = state.tokens.length;
  if (isOrdered) {
    token = state.push("ordered_list_open", "ol", 1);
    if (markerValue !== 1) {
      token.attrs = [["start", markerValue]];
    }
  } else {
    token = state.push("bullet_list_open", "ul", 1);
  }
  const listLines = [nextLine, 0];
  token.map = listLines;
  token.markup = String.fromCharCode(markerCharCode);
  let prevEmptyEnd = false;
  const terminatorRules = state.md.block.ruler.getRules("list");
  const oldParentType = state.parentType;
  state.parentType = "list";
  while (nextLine < endLine) {
    pos = posAfterMarker;
    max = state.eMarks[nextLine];
    const initial = state.sCount[nextLine] + posAfterMarker - (state.bMarks[nextLine] + state.tShift[nextLine]);
    let offset = initial;
    while (pos < max) {
      const ch = state.src.charCodeAt(pos);
      if (ch === 9) {
        offset += 4 - (offset + state.bsCount[nextLine]) % 4;
      } else if (ch === 32) {
        offset++;
      } else {
        break;
      }
      pos++;
    }
    const contentStart = pos;
    let indentAfterMarker;
    if (contentStart >= max) {
      indentAfterMarker = 1;
    } else {
      indentAfterMarker = offset - initial;
    }
    if (indentAfterMarker > 4) {
      indentAfterMarker = 1;
    }
    const indent = initial + indentAfterMarker;
    token = state.push("list_item_open", "li", 1);
    token.markup = String.fromCharCode(markerCharCode);
    const itemLines = [nextLine, 0];
    token.map = itemLines;
    if (isOrdered) {
      token.info = state.src.slice(start2, posAfterMarker - 1);
    }
    const oldTight = state.tight;
    const oldTShift = state.tShift[nextLine];
    const oldSCount = state.sCount[nextLine];
    const oldListIndent = state.listIndent;
    state.listIndent = state.blkIndent;
    state.blkIndent = indent;
    state.tight = true;
    state.tShift[nextLine] = contentStart - state.bMarks[nextLine];
    state.sCount[nextLine] = offset;
    if (contentStart >= max && state.isEmpty(nextLine + 1)) {
      state.line = Math.min(state.line + 2, endLine);
    } else {
      state.md.block.tokenize(state, nextLine, endLine, true);
    }
    if (!state.tight || prevEmptyEnd) {
      tight = false;
    }
    prevEmptyEnd = state.line - nextLine > 1 && state.isEmpty(state.line - 1);
    state.blkIndent = state.listIndent;
    state.listIndent = oldListIndent;
    state.tShift[nextLine] = oldTShift;
    state.sCount[nextLine] = oldSCount;
    state.tight = oldTight;
    token = state.push("list_item_close", "li", -1);
    token.markup = String.fromCharCode(markerCharCode);
    nextLine = state.line;
    itemLines[1] = nextLine;
    if (nextLine >= endLine) {
      break;
    }
    if (state.sCount[nextLine] < state.blkIndent) {
      break;
    }
    if (state.sCount[nextLine] - state.blkIndent >= 4) {
      break;
    }
    let terminate = false;
    for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
      if (terminatorRules[i2](state, nextLine, endLine, true)) {
        terminate = true;
        break;
      }
    }
    if (terminate) {
      break;
    }
    if (isOrdered) {
      posAfterMarker = skipOrderedListMarker(state, nextLine);
      if (posAfterMarker < 0) {
        break;
      }
      start2 = state.bMarks[nextLine] + state.tShift[nextLine];
    } else {
      posAfterMarker = skipBulletListMarker(state, nextLine);
      if (posAfterMarker < 0) {
        break;
      }
    }
    if (markerCharCode !== state.src.charCodeAt(posAfterMarker - 1)) {
      break;
    }
  }
  if (isOrdered) {
    token = state.push("ordered_list_close", "ol", -1);
  } else {
    token = state.push("bullet_list_close", "ul", -1);
  }
  token.markup = String.fromCharCode(markerCharCode);
  listLines[1] = nextLine;
  state.line = nextLine;
  state.parentType = oldParentType;
  if (tight) {
    markTightParagraphs(state, listTokIdx);
  }
  return true;
}
__name(list, "list");
function reference(state, startLine, _endLine, silent) {
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  let max = state.eMarks[startLine];
  let nextLine = startLine + 1;
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  if (state.src.charCodeAt(pos) !== 91) {
    return false;
  }
  function getNextLine(nextLine2) {
    const endLine = state.lineMax;
    if (nextLine2 >= endLine || state.isEmpty(nextLine2)) {
      return null;
    }
    let isContinuation = false;
    if (state.sCount[nextLine2] - state.blkIndent > 3) {
      isContinuation = true;
    }
    if (state.sCount[nextLine2] < 0) {
      isContinuation = true;
    }
    if (!isContinuation) {
      const terminatorRules = state.md.block.ruler.getRules("reference");
      const oldParentType = state.parentType;
      state.parentType = "reference";
      let terminate = false;
      for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
        if (terminatorRules[i2](state, nextLine2, endLine, true)) {
          terminate = true;
          break;
        }
      }
      state.parentType = oldParentType;
      if (terminate) {
        return null;
      }
    }
    const pos2 = state.bMarks[nextLine2] + state.tShift[nextLine2];
    const max2 = state.eMarks[nextLine2];
    return state.src.slice(pos2, max2 + 1);
  }
  __name(getNextLine, "getNextLine");
  let str = state.src.slice(pos, max + 1);
  max = str.length;
  let labelEnd = -1;
  for (pos = 1; pos < max; pos++) {
    const ch = str.charCodeAt(pos);
    if (ch === 91) {
      return false;
    } else if (ch === 93) {
      labelEnd = pos;
      break;
    } else if (ch === 10) {
      const lineContent = getNextLine(nextLine);
      if (lineContent !== null) {
        str += lineContent;
        max = str.length;
        nextLine++;
      }
    } else if (ch === 92) {
      pos++;
      if (pos < max && str.charCodeAt(pos) === 10) {
        const lineContent = getNextLine(nextLine);
        if (lineContent !== null) {
          str += lineContent;
          max = str.length;
          nextLine++;
        }
      }
    }
  }
  if (labelEnd < 0 || str.charCodeAt(labelEnd + 1) !== 58) {
    return false;
  }
  for (pos = labelEnd + 2; pos < max; pos++) {
    const ch = str.charCodeAt(pos);
    if (ch === 10) {
      const lineContent = getNextLine(nextLine);
      if (lineContent !== null) {
        str += lineContent;
        max = str.length;
        nextLine++;
      }
    } else if (isSpace(ch)) {
    } else {
      break;
    }
  }
  const destRes = state.md.helpers.parseLinkDestination(str, pos, max);
  if (!destRes.ok) {
    return false;
  }
  const href = state.md.normalizeLink(destRes.str);
  if (!state.md.validateLink(href)) {
    return false;
  }
  pos = destRes.pos;
  const destEndPos = pos;
  const destEndLineNo = nextLine;
  const start2 = pos;
  for (; pos < max; pos++) {
    const ch = str.charCodeAt(pos);
    if (ch === 10) {
      const lineContent = getNextLine(nextLine);
      if (lineContent !== null) {
        str += lineContent;
        max = str.length;
        nextLine++;
      }
    } else if (isSpace(ch)) {
    } else {
      break;
    }
  }
  let titleRes = state.md.helpers.parseLinkTitle(str, pos, max);
  while (titleRes.can_continue) {
    const lineContent = getNextLine(nextLine);
    if (lineContent === null) break;
    str += lineContent;
    pos = max;
    max = str.length;
    nextLine++;
    titleRes = state.md.helpers.parseLinkTitle(str, pos, max, titleRes);
  }
  let title;
  if (pos < max && start2 !== pos && titleRes.ok) {
    title = titleRes.str;
    pos = titleRes.pos;
  } else {
    title = "";
    pos = destEndPos;
    nextLine = destEndLineNo;
  }
  while (pos < max) {
    const ch = str.charCodeAt(pos);
    if (!isSpace(ch)) {
      break;
    }
    pos++;
  }
  if (pos < max && str.charCodeAt(pos) !== 10) {
    if (title) {
      title = "";
      pos = destEndPos;
      nextLine = destEndLineNo;
      while (pos < max) {
        const ch = str.charCodeAt(pos);
        if (!isSpace(ch)) {
          break;
        }
        pos++;
      }
    }
  }
  if (pos < max && str.charCodeAt(pos) !== 10) {
    return false;
  }
  const label8 = normalizeReference(str.slice(1, labelEnd));
  if (!label8) {
    return false;
  }
  if (silent) {
    return true;
  }
  if (typeof state.env.references === "undefined") {
    state.env.references = {};
  }
  if (typeof state.env.references[label8] === "undefined") {
    state.env.references[label8] = { title, href };
  }
  state.line = nextLine;
  return true;
}
__name(reference, "reference");
const block_names = [
  "address",
  "article",
  "aside",
  "base",
  "basefont",
  "blockquote",
  "body",
  "caption",
  "center",
  "col",
  "colgroup",
  "dd",
  "details",
  "dialog",
  "dir",
  "div",
  "dl",
  "dt",
  "fieldset",
  "figcaption",
  "figure",
  "footer",
  "form",
  "frame",
  "frameset",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "head",
  "header",
  "hr",
  "html",
  "iframe",
  "legend",
  "li",
  "link",
  "main",
  "menu",
  "menuitem",
  "nav",
  "noframes",
  "ol",
  "optgroup",
  "option",
  "p",
  "param",
  "search",
  "section",
  "summary",
  "table",
  "tbody",
  "td",
  "tfoot",
  "th",
  "thead",
  "title",
  "tr",
  "track",
  "ul"
];
const attr_name = "[a-zA-Z_:][a-zA-Z0-9:._-]*";
const unquoted = "[^\"'=<>`\\x00-\\x20]+";
const single_quoted = "'[^']*'";
const double_quoted = '"[^"]*"';
const attr_value = "(?:" + unquoted + "|" + single_quoted + "|" + double_quoted + ")";
const attribute = "(?:\\s+" + attr_name + "(?:\\s*=\\s*" + attr_value + ")?)";
const open_tag = "<[A-Za-z][A-Za-z0-9\\-]*" + attribute + "*\\s*\\/?>";
const close_tag = "<\\/[A-Za-z][A-Za-z0-9\\-]*\\s*>";
const comment = "<!---?>|<!--(?:[^-]|-[^-]|--[^>])*-->";
const processing = "<[?][\\s\\S]*?[?]>";
const declaration = "<![A-Za-z][^>]*>";
const cdata = "<!\\[CDATA\\[[\\s\\S]*?\\]\\]>";
const HTML_TAG_RE = new RegExp("^(?:" + open_tag + "|" + close_tag + "|" + comment + "|" + processing + "|" + declaration + "|" + cdata + ")");
const HTML_OPEN_CLOSE_TAG_RE = new RegExp("^(?:" + open_tag + "|" + close_tag + ")");
const HTML_SEQUENCES = [
  [/^<(script|pre|style|textarea)(?=(\s|>|$))/i, /<\/(script|pre|style|textarea)>/i, true],
  [/^<!--/, /-->/, true],
  [/^<\?/, /\?>/, true],
  [/^<![A-Z]/, />/, true],
  [/^<!\[CDATA\[/, /\]\]>/, true],
  [new RegExp("^</?(" + block_names.join("|") + ")(?=(\\s|/?>|$))", "i"), /^$/, true],
  [new RegExp(HTML_OPEN_CLOSE_TAG_RE.source + "\\s*$"), /^$/, false]
];
function html_block(state, startLine, endLine, silent) {
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  let max = state.eMarks[startLine];
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  if (!state.md.options.html) {
    return false;
  }
  if (state.src.charCodeAt(pos) !== 60) {
    return false;
  }
  let lineText = state.src.slice(pos, max);
  let i2 = 0;
  for (; i2 < HTML_SEQUENCES.length; i2++) {
    if (HTML_SEQUENCES[i2][0].test(lineText)) {
      break;
    }
  }
  if (i2 === HTML_SEQUENCES.length) {
    return false;
  }
  if (silent) {
    return HTML_SEQUENCES[i2][2];
  }
  let nextLine = startLine + 1;
  if (!HTML_SEQUENCES[i2][1].test(lineText)) {
    for (; nextLine < endLine; nextLine++) {
      if (state.sCount[nextLine] < state.blkIndent) {
        break;
      }
      pos = state.bMarks[nextLine] + state.tShift[nextLine];
      max = state.eMarks[nextLine];
      lineText = state.src.slice(pos, max);
      if (HTML_SEQUENCES[i2][1].test(lineText)) {
        if (lineText.length !== 0) {
          nextLine++;
        }
        break;
      }
    }
  }
  state.line = nextLine;
  const token = state.push("html_block", "", 0);
  token.map = [startLine, nextLine];
  token.content = state.getLines(startLine, nextLine, state.blkIndent, true);
  return true;
}
__name(html_block, "html_block");
function heading(state, startLine, endLine, silent) {
  let pos = state.bMarks[startLine] + state.tShift[startLine];
  let max = state.eMarks[startLine];
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  let ch = state.src.charCodeAt(pos);
  if (ch !== 35 || pos >= max) {
    return false;
  }
  let level = 1;
  ch = state.src.charCodeAt(++pos);
  while (ch === 35 && pos < max && level <= 6) {
    level++;
    ch = state.src.charCodeAt(++pos);
  }
  if (level > 6 || pos < max && !isSpace(ch)) {
    return false;
  }
  if (silent) {
    return true;
  }
  max = state.skipSpacesBack(max, pos);
  const tmp = state.skipCharsBack(max, 35, pos);
  if (tmp > pos && isSpace(state.src.charCodeAt(tmp - 1))) {
    max = tmp;
  }
  state.line = startLine + 1;
  const token_o = state.push("heading_open", "h" + String(level), 1);
  token_o.markup = "########".slice(0, level);
  token_o.map = [startLine, state.line];
  const token_i = state.push("inline", "", 0);
  token_i.content = state.src.slice(pos, max).trim();
  token_i.map = [startLine, state.line];
  token_i.children = [];
  const token_c = state.push("heading_close", "h" + String(level), -1);
  token_c.markup = "########".slice(0, level);
  return true;
}
__name(heading, "heading");
function lheading(state, startLine, endLine) {
  const terminatorRules = state.md.block.ruler.getRules("paragraph");
  if (state.sCount[startLine] - state.blkIndent >= 4) {
    return false;
  }
  const oldParentType = state.parentType;
  state.parentType = "paragraph";
  let level = 0;
  let marker;
  let nextLine = startLine + 1;
  for (; nextLine < endLine && !state.isEmpty(nextLine); nextLine++) {
    if (state.sCount[nextLine] - state.blkIndent > 3) {
      continue;
    }
    if (state.sCount[nextLine] >= state.blkIndent) {
      let pos = state.bMarks[nextLine] + state.tShift[nextLine];
      const max = state.eMarks[nextLine];
      if (pos < max) {
        marker = state.src.charCodeAt(pos);
        if (marker === 45 || marker === 61) {
          pos = state.skipChars(pos, marker);
          pos = state.skipSpaces(pos);
          if (pos >= max) {
            level = marker === 61 ? 1 : 2;
            break;
          }
        }
      }
    }
    if (state.sCount[nextLine] < 0) {
      continue;
    }
    let terminate = false;
    for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
      if (terminatorRules[i2](state, nextLine, endLine, true)) {
        terminate = true;
        break;
      }
    }
    if (terminate) {
      break;
    }
  }
  if (!level) {
    return false;
  }
  const content3 = state.getLines(startLine, nextLine, state.blkIndent, false).trim();
  state.line = nextLine + 1;
  const token_o = state.push("heading_open", "h" + String(level), 1);
  token_o.markup = String.fromCharCode(marker);
  token_o.map = [startLine, state.line];
  const token_i = state.push("inline", "", 0);
  token_i.content = content3;
  token_i.map = [startLine, state.line - 1];
  token_i.children = [];
  const token_c = state.push("heading_close", "h" + String(level), -1);
  token_c.markup = String.fromCharCode(marker);
  state.parentType = oldParentType;
  return true;
}
__name(lheading, "lheading");
function paragraph(state, startLine, endLine) {
  const terminatorRules = state.md.block.ruler.getRules("paragraph");
  const oldParentType = state.parentType;
  let nextLine = startLine + 1;
  state.parentType = "paragraph";
  for (; nextLine < endLine && !state.isEmpty(nextLine); nextLine++) {
    if (state.sCount[nextLine] - state.blkIndent > 3) {
      continue;
    }
    if (state.sCount[nextLine] < 0) {
      continue;
    }
    let terminate = false;
    for (let i2 = 0, l2 = terminatorRules.length; i2 < l2; i2++) {
      if (terminatorRules[i2](state, nextLine, endLine, true)) {
        terminate = true;
        break;
      }
    }
    if (terminate) {
      break;
    }
  }
  const content3 = state.getLines(startLine, nextLine, state.blkIndent, false).trim();
  state.line = nextLine;
  const token_o = state.push("paragraph_open", "p", 1);
  token_o.map = [startLine, state.line];
  const token_i = state.push("inline", "", 0);
  token_i.content = content3;
  token_i.map = [startLine, state.line];
  token_i.children = [];
  state.push("paragraph_close", "p", -1);
  state.parentType = oldParentType;
  return true;
}
__name(paragraph, "paragraph");
const _rules$1 = [
  // First 2 params - rule name & source. Secondary array - list of rules,
  // which can be terminated by this one.
  ["table", table, ["paragraph", "reference"]],
  ["code", code],
  ["fence", fence, ["paragraph", "reference", "blockquote", "list"]],
  ["blockquote", blockquote, ["paragraph", "reference", "blockquote", "list"]],
  ["hr", hr, ["paragraph", "reference", "blockquote", "list"]],
  ["list", list, ["paragraph", "reference", "blockquote"]],
  ["reference", reference],
  ["html_block", html_block, ["paragraph", "reference", "blockquote"]],
  ["heading", heading, ["paragraph", "reference", "blockquote"]],
  ["lheading", lheading],
  ["paragraph", paragraph]
];
function ParserBlock() {
  this.ruler = new Ruler();
  for (let i2 = 0; i2 < _rules$1.length; i2++) {
    this.ruler.push(_rules$1[i2][0], _rules$1[i2][1], { alt: (_rules$1[i2][2] || []).slice() });
  }
}
__name(ParserBlock, "ParserBlock");
ParserBlock.prototype.tokenize = function(state, startLine, endLine) {
  const rules = this.ruler.getRules("");
  const len = rules.length;
  const maxNesting = state.md.options.maxNesting;
  let line = startLine;
  let hasEmptyLines = false;
  while (line < endLine) {
    state.line = line = state.skipEmptyLines(line);
    if (line >= endLine) {
      break;
    }
    if (state.sCount[line] < state.blkIndent) {
      break;
    }
    if (state.level >= maxNesting) {
      state.line = endLine;
      break;
    }
    const prevLine = state.line;
    let ok = false;
    for (let i2 = 0; i2 < len; i2++) {
      ok = rules[i2](state, line, endLine, false);
      if (ok) {
        if (prevLine >= state.line) {
          throw new Error("block rule didn't increment state.line");
        }
        break;
      }
    }
    if (!ok) throw new Error("none of the block rules matched");
    state.tight = !hasEmptyLines;
    if (state.isEmpty(state.line - 1)) {
      hasEmptyLines = true;
    }
    line = state.line;
    if (line < endLine && state.isEmpty(line)) {
      hasEmptyLines = true;
      line++;
      state.line = line;
    }
  }
};
ParserBlock.prototype.parse = function(src, md2, env, outTokens) {
  if (!src) {
    return;
  }
  const state = new this.State(src, md2, env, outTokens);
  this.tokenize(state, state.line, state.lineMax);
};
ParserBlock.prototype.State = StateBlock;
function StateInline(src, md2, env, outTokens) {
  this.src = src;
  this.env = env;
  this.md = md2;
  this.tokens = outTokens;
  this.tokens_meta = Array(outTokens.length);
  this.pos = 0;
  this.posMax = this.src.length;
  this.level = 0;
  this.pending = "";
  this.pendingLevel = 0;
  this.cache = {};
  this.delimiters = [];
  this._prev_delimiters = [];
  this.backticks = {};
  this.backticksScanned = false;
  this.linkLevel = 0;
}
__name(StateInline, "StateInline");
StateInline.prototype.pushPending = function() {
  const token = new Token("text", "", 0);
  token.content = this.pending;
  token.level = this.pendingLevel;
  this.tokens.push(token);
  this.pending = "";
  return token;
};
StateInline.prototype.push = function(type, tag, nesting) {
  if (this.pending) {
    this.pushPending();
  }
  const token = new Token(type, tag, nesting);
  let token_meta = null;
  if (nesting < 0) {
    this.level--;
    this.delimiters = this._prev_delimiters.pop();
  }
  token.level = this.level;
  if (nesting > 0) {
    this.level++;
    this._prev_delimiters.push(this.delimiters);
    this.delimiters = [];
    token_meta = { delimiters: this.delimiters };
  }
  this.pendingLevel = this.level;
  this.tokens.push(token);
  this.tokens_meta.push(token_meta);
  return token;
};
StateInline.prototype.scanDelims = function(start2, canSplitWord) {
  const max = this.posMax;
  const marker = this.src.charCodeAt(start2);
  const lastChar = start2 > 0 ? this.src.charCodeAt(start2 - 1) : 32;
  let pos = start2;
  while (pos < max && this.src.charCodeAt(pos) === marker) {
    pos++;
  }
  const count = pos - start2;
  const nextChar = pos < max ? this.src.charCodeAt(pos) : 32;
  const isLastPunctChar = isMdAsciiPunct(lastChar) || isPunctChar(String.fromCharCode(lastChar));
  const isNextPunctChar = isMdAsciiPunct(nextChar) || isPunctChar(String.fromCharCode(nextChar));
  const isLastWhiteSpace = isWhiteSpace(lastChar);
  const isNextWhiteSpace = isWhiteSpace(nextChar);
  const left_flanking = !isNextWhiteSpace && (!isNextPunctChar || isLastWhiteSpace || isLastPunctChar);
  const right_flanking = !isLastWhiteSpace && (!isLastPunctChar || isNextWhiteSpace || isNextPunctChar);
  const can_open = left_flanking && (canSplitWord || !right_flanking || isLastPunctChar);
  const can_close = right_flanking && (canSplitWord || !left_flanking || isNextPunctChar);
  return { can_open, can_close, length: count };
};
StateInline.prototype.Token = Token;
function isTerminatorChar(ch) {
  switch (ch) {
    case 10:
    case 33:
    case 35:
    case 36:
    case 37:
    case 38:
    case 42:
    case 43:
    case 45:
    case 58:
    case 60:
    case 61:
    case 62:
    case 64:
    case 91:
    case 92:
    case 93:
    case 94:
    case 95:
    case 96:
    case 123:
    case 125:
    case 126:
      return true;
    default:
      return false;
  }
}
__name(isTerminatorChar, "isTerminatorChar");
function text(state, silent) {
  let pos = state.pos;
  while (pos < state.posMax && !isTerminatorChar(state.src.charCodeAt(pos))) {
    pos++;
  }
  if (pos === state.pos) {
    return false;
  }
  if (!silent) {
    state.pending += state.src.slice(state.pos, pos);
  }
  state.pos = pos;
  return true;
}
__name(text, "text");
const SCHEME_RE = /(?:^|[^a-z0-9.+-])([a-z][a-z0-9.+-]*)$/i;
function linkify(state, silent) {
  if (!state.md.options.linkify) return false;
  if (state.linkLevel > 0) return false;
  const pos = state.pos;
  const max = state.posMax;
  if (pos + 3 > max) return false;
  if (state.src.charCodeAt(pos) !== 58) return false;
  if (state.src.charCodeAt(pos + 1) !== 47) return false;
  if (state.src.charCodeAt(pos + 2) !== 47) return false;
  const match2 = state.pending.match(SCHEME_RE);
  if (!match2) return false;
  const proto = match2[1];
  const link2 = state.md.linkify.matchAtStart(state.src.slice(pos - proto.length));
  if (!link2) return false;
  let url = link2.url;
  if (url.length <= proto.length) return false;
  url = url.replace(/\*+$/, "");
  const fullUrl = state.md.normalizeLink(url);
  if (!state.md.validateLink(fullUrl)) return false;
  if (!silent) {
    state.pending = state.pending.slice(0, -proto.length);
    const token_o = state.push("link_open", "a", 1);
    token_o.attrs = [["href", fullUrl]];
    token_o.markup = "linkify";
    token_o.info = "auto";
    const token_t = state.push("text", "", 0);
    token_t.content = state.md.normalizeLinkText(url);
    const token_c = state.push("link_close", "a", -1);
    token_c.markup = "linkify";
    token_c.info = "auto";
  }
  state.pos += url.length - proto.length;
  return true;
}
__name(linkify, "linkify");
function newline(state, silent) {
  let pos = state.pos;
  if (state.src.charCodeAt(pos) !== 10) {
    return false;
  }
  const pmax = state.pending.length - 1;
  const max = state.posMax;
  if (!silent) {
    if (pmax >= 0 && state.pending.charCodeAt(pmax) === 32) {
      if (pmax >= 1 && state.pending.charCodeAt(pmax - 1) === 32) {
        let ws = pmax - 1;
        while (ws >= 1 && state.pending.charCodeAt(ws - 1) === 32) ws--;
        state.pending = state.pending.slice(0, ws);
        state.push("hardbreak", "br", 0);
      } else {
        state.pending = state.pending.slice(0, -1);
        state.push("softbreak", "br", 0);
      }
    } else {
      state.push("softbreak", "br", 0);
    }
  }
  pos++;
  while (pos < max && isSpace(state.src.charCodeAt(pos))) {
    pos++;
  }
  state.pos = pos;
  return true;
}
__name(newline, "newline");
const ESCAPED = [];
for (let i2 = 0; i2 < 256; i2++) {
  ESCAPED.push(0);
}
"\\!\"#$%&'()*+,./:;<=>?@[]^_`{|}~-".split("").forEach(function(ch) {
  ESCAPED[ch.charCodeAt(0)] = 1;
});
function escape$1(state, silent) {
  let pos = state.pos;
  const max = state.posMax;
  if (state.src.charCodeAt(pos) !== 92) return false;
  pos++;
  if (pos >= max) return false;
  let ch1 = state.src.charCodeAt(pos);
  if (ch1 === 10) {
    if (!silent) {
      state.push("hardbreak", "br", 0);
    }
    pos++;
    while (pos < max) {
      ch1 = state.src.charCodeAt(pos);
      if (!isSpace(ch1)) break;
      pos++;
    }
    state.pos = pos;
    return true;
  }
  let escapedStr = state.src[pos];
  if (ch1 >= 55296 && ch1 <= 56319 && pos + 1 < max) {
    const ch2 = state.src.charCodeAt(pos + 1);
    if (ch2 >= 56320 && ch2 <= 57343) {
      escapedStr += state.src[pos + 1];
      pos++;
    }
  }
  const origStr = "\\" + escapedStr;
  if (!silent) {
    const token = state.push("text_special", "", 0);
    if (ch1 < 256 && ESCAPED[ch1] !== 0) {
      token.content = escapedStr;
    } else {
      token.content = origStr;
    }
    token.markup = origStr;
    token.info = "escape";
  }
  state.pos = pos + 1;
  return true;
}
__name(escape$1, "escape$1");
function backtick(state, silent) {
  let pos = state.pos;
  const ch = state.src.charCodeAt(pos);
  if (ch !== 96) {
    return false;
  }
  const start2 = pos;
  pos++;
  const max = state.posMax;
  while (pos < max && state.src.charCodeAt(pos) === 96) {
    pos++;
  }
  const marker = state.src.slice(start2, pos);
  const openerLength = marker.length;
  if (state.backticksScanned && (state.backticks[openerLength] || 0) <= start2) {
    if (!silent) state.pending += marker;
    state.pos += openerLength;
    return true;
  }
  let matchEnd = pos;
  let matchStart;
  while ((matchStart = state.src.indexOf("`", matchEnd)) !== -1) {
    matchEnd = matchStart + 1;
    while (matchEnd < max && state.src.charCodeAt(matchEnd) === 96) {
      matchEnd++;
    }
    const closerLength = matchEnd - matchStart;
    if (closerLength === openerLength) {
      if (!silent) {
        const token = state.push("code_inline", "code", 0);
        token.markup = marker;
        token.content = state.src.slice(pos, matchStart).replace(/\n/g, " ").replace(/^ (.+) $/, "$1");
      }
      state.pos = matchEnd;
      return true;
    }
    state.backticks[closerLength] = matchStart;
  }
  state.backticksScanned = true;
  if (!silent) state.pending += marker;
  state.pos += openerLength;
  return true;
}
__name(backtick, "backtick");
function strikethrough_tokenize(state, silent) {
  const start2 = state.pos;
  const marker = state.src.charCodeAt(start2);
  if (silent) {
    return false;
  }
  if (marker !== 126) {
    return false;
  }
  const scanned = state.scanDelims(state.pos, true);
  let len = scanned.length;
  const ch = String.fromCharCode(marker);
  if (len < 2) {
    return false;
  }
  let token;
  if (len % 2) {
    token = state.push("text", "", 0);
    token.content = ch;
    len--;
  }
  for (let i2 = 0; i2 < len; i2 += 2) {
    token = state.push("text", "", 0);
    token.content = ch + ch;
    state.delimiters.push({
      marker,
      length: 0,
      // disable "rule of 3" length checks meant for emphasis
      token: state.tokens.length - 1,
      end: -1,
      open: scanned.can_open,
      close: scanned.can_close
    });
  }
  state.pos += scanned.length;
  return true;
}
__name(strikethrough_tokenize, "strikethrough_tokenize");
function postProcess$1(state, delimiters) {
  let token;
  const loneMarkers = [];
  const max = delimiters.length;
  for (let i2 = 0; i2 < max; i2++) {
    const startDelim = delimiters[i2];
    if (startDelim.marker !== 126) {
      continue;
    }
    if (startDelim.end === -1) {
      continue;
    }
    const endDelim = delimiters[startDelim.end];
    token = state.tokens[startDelim.token];
    token.type = "s_open";
    token.tag = "s";
    token.nesting = 1;
    token.markup = "~~";
    token.content = "";
    token = state.tokens[endDelim.token];
    token.type = "s_close";
    token.tag = "s";
    token.nesting = -1;
    token.markup = "~~";
    token.content = "";
    if (state.tokens[endDelim.token - 1].type === "text" && state.tokens[endDelim.token - 1].content === "~") {
      loneMarkers.push(endDelim.token - 1);
    }
  }
  while (loneMarkers.length) {
    const i2 = loneMarkers.pop();
    let j2 = i2 + 1;
    while (j2 < state.tokens.length && state.tokens[j2].type === "s_close") {
      j2++;
    }
    j2--;
    if (i2 !== j2) {
      token = state.tokens[j2];
      state.tokens[j2] = state.tokens[i2];
      state.tokens[i2] = token;
    }
  }
}
__name(postProcess$1, "postProcess$1");
function strikethrough_postProcess(state) {
  const tokens_meta = state.tokens_meta;
  const max = state.tokens_meta.length;
  postProcess$1(state, state.delimiters);
  for (let curr = 0; curr < max; curr++) {
    if (tokens_meta[curr] && tokens_meta[curr].delimiters) {
      postProcess$1(state, tokens_meta[curr].delimiters);
    }
  }
}
__name(strikethrough_postProcess, "strikethrough_postProcess");
const r_strikethrough = {
  tokenize: strikethrough_tokenize,
  postProcess: strikethrough_postProcess
};
function emphasis_tokenize(state, silent) {
  const start2 = state.pos;
  const marker = state.src.charCodeAt(start2);
  if (silent) {
    return false;
  }
  if (marker !== 95 && marker !== 42) {
    return false;
  }
  const scanned = state.scanDelims(state.pos, marker === 42);
  for (let i2 = 0; i2 < scanned.length; i2++) {
    const token = state.push("text", "", 0);
    token.content = String.fromCharCode(marker);
    state.delimiters.push({
      // Char code of the starting marker (number).
      //
      marker,
      // Total length of these series of delimiters.
      //
      length: scanned.length,
      // A position of the token this delimiter corresponds to.
      //
      token: state.tokens.length - 1,
      // If this delimiter is matched as a valid opener, `end` will be
      // equal to its position, otherwise it's `-1`.
      //
      end: -1,
      // Boolean flags that determine if this delimiter could open or close
      // an emphasis.
      //
      open: scanned.can_open,
      close: scanned.can_close
    });
  }
  state.pos += scanned.length;
  return true;
}
__name(emphasis_tokenize, "emphasis_tokenize");
function postProcess(state, delimiters) {
  const max = delimiters.length;
  for (let i2 = max - 1; i2 >= 0; i2--) {
    const startDelim = delimiters[i2];
    if (startDelim.marker !== 95 && startDelim.marker !== 42) {
      continue;
    }
    if (startDelim.end === -1) {
      continue;
    }
    const endDelim = delimiters[startDelim.end];
    const isStrong = i2 > 0 && delimiters[i2 - 1].end === startDelim.end + 1 && // check that first two markers match and adjacent
    delimiters[i2 - 1].marker === startDelim.marker && delimiters[i2 - 1].token === startDelim.token - 1 && // check that last two markers are adjacent (we can safely assume they match)
    delimiters[startDelim.end + 1].token === endDelim.token + 1;
    const ch = String.fromCharCode(startDelim.marker);
    const token_o = state.tokens[startDelim.token];
    token_o.type = isStrong ? "strong_open" : "em_open";
    token_o.tag = isStrong ? "strong" : "em";
    token_o.nesting = 1;
    token_o.markup = isStrong ? ch + ch : ch;
    token_o.content = "";
    const token_c = state.tokens[endDelim.token];
    token_c.type = isStrong ? "strong_close" : "em_close";
    token_c.tag = isStrong ? "strong" : "em";
    token_c.nesting = -1;
    token_c.markup = isStrong ? ch + ch : ch;
    token_c.content = "";
    if (isStrong) {
      state.tokens[delimiters[i2 - 1].token].content = "";
      state.tokens[delimiters[startDelim.end + 1].token].content = "";
      i2--;
    }
  }
}
__name(postProcess, "postProcess");
function emphasis_post_process(state) {
  const tokens_meta = state.tokens_meta;
  const max = state.tokens_meta.length;
  postProcess(state, state.delimiters);
  for (let curr = 0; curr < max; curr++) {
    if (tokens_meta[curr] && tokens_meta[curr].delimiters) {
      postProcess(state, tokens_meta[curr].delimiters);
    }
  }
}
__name(emphasis_post_process, "emphasis_post_process");
const r_emphasis = {
  tokenize: emphasis_tokenize,
  postProcess: emphasis_post_process
};
function link(state, silent) {
  let code2, label8, res, ref2;
  let href = "";
  let title = "";
  let start2 = state.pos;
  let parseReference = true;
  if (state.src.charCodeAt(state.pos) !== 91) {
    return false;
  }
  const oldPos = state.pos;
  const max = state.posMax;
  const labelStart = state.pos + 1;
  const labelEnd = state.md.helpers.parseLinkLabel(state, state.pos, true);
  if (labelEnd < 0) {
    return false;
  }
  let pos = labelEnd + 1;
  if (pos < max && state.src.charCodeAt(pos) === 40) {
    parseReference = false;
    pos++;
    for (; pos < max; pos++) {
      code2 = state.src.charCodeAt(pos);
      if (!isSpace(code2) && code2 !== 10) {
        break;
      }
    }
    if (pos >= max) {
      return false;
    }
    start2 = pos;
    res = state.md.helpers.parseLinkDestination(state.src, pos, state.posMax);
    if (res.ok) {
      href = state.md.normalizeLink(res.str);
      if (state.md.validateLink(href)) {
        pos = res.pos;
      } else {
        href = "";
      }
      start2 = pos;
      for (; pos < max; pos++) {
        code2 = state.src.charCodeAt(pos);
        if (!isSpace(code2) && code2 !== 10) {
          break;
        }
      }
      res = state.md.helpers.parseLinkTitle(state.src, pos, state.posMax);
      if (pos < max && start2 !== pos && res.ok) {
        title = res.str;
        pos = res.pos;
        for (; pos < max; pos++) {
          code2 = state.src.charCodeAt(pos);
          if (!isSpace(code2) && code2 !== 10) {
            break;
          }
        }
      }
    }
    if (pos >= max || state.src.charCodeAt(pos) !== 41) {
      parseReference = true;
    }
    pos++;
  }
  if (parseReference) {
    if (typeof state.env.references === "undefined") {
      return false;
    }
    if (pos < max && state.src.charCodeAt(pos) === 91) {
      start2 = pos + 1;
      pos = state.md.helpers.parseLinkLabel(state, pos);
      if (pos >= 0) {
        label8 = state.src.slice(start2, pos++);
      } else {
        pos = labelEnd + 1;
      }
    } else {
      pos = labelEnd + 1;
    }
    if (!label8) {
      label8 = state.src.slice(labelStart, labelEnd);
    }
    ref2 = state.env.references[normalizeReference(label8)];
    if (!ref2) {
      state.pos = oldPos;
      return false;
    }
    href = ref2.href;
    title = ref2.title;
  }
  if (!silent) {
    state.pos = labelStart;
    state.posMax = labelEnd;
    const token_o = state.push("link_open", "a", 1);
    const attrs7 = [["href", href]];
    token_o.attrs = attrs7;
    if (title) {
      attrs7.push(["title", title]);
    }
    state.linkLevel++;
    state.md.inline.tokenize(state);
    state.linkLevel--;
    state.push("link_close", "a", -1);
  }
  state.pos = pos;
  state.posMax = max;
  return true;
}
__name(link, "link");
function image(state, silent) {
  let code2, content3, label8, pos, ref2, res, title, start2;
  let href = "";
  const oldPos = state.pos;
  const max = state.posMax;
  if (state.src.charCodeAt(state.pos) !== 33) {
    return false;
  }
  if (state.src.charCodeAt(state.pos + 1) !== 91) {
    return false;
  }
  const labelStart = state.pos + 2;
  const labelEnd = state.md.helpers.parseLinkLabel(state, state.pos + 1, false);
  if (labelEnd < 0) {
    return false;
  }
  pos = labelEnd + 1;
  if (pos < max && state.src.charCodeAt(pos) === 40) {
    pos++;
    for (; pos < max; pos++) {
      code2 = state.src.charCodeAt(pos);
      if (!isSpace(code2) && code2 !== 10) {
        break;
      }
    }
    if (pos >= max) {
      return false;
    }
    start2 = pos;
    res = state.md.helpers.parseLinkDestination(state.src, pos, state.posMax);
    if (res.ok) {
      href = state.md.normalizeLink(res.str);
      if (state.md.validateLink(href)) {
        pos = res.pos;
      } else {
        href = "";
      }
    }
    start2 = pos;
    for (; pos < max; pos++) {
      code2 = state.src.charCodeAt(pos);
      if (!isSpace(code2) && code2 !== 10) {
        break;
      }
    }
    res = state.md.helpers.parseLinkTitle(state.src, pos, state.posMax);
    if (pos < max && start2 !== pos && res.ok) {
      title = res.str;
      pos = res.pos;
      for (; pos < max; pos++) {
        code2 = state.src.charCodeAt(pos);
        if (!isSpace(code2) && code2 !== 10) {
          break;
        }
      }
    } else {
      title = "";
    }
    if (pos >= max || state.src.charCodeAt(pos) !== 41) {
      state.pos = oldPos;
      return false;
    }
    pos++;
  } else {
    if (typeof state.env.references === "undefined") {
      return false;
    }
    if (pos < max && state.src.charCodeAt(pos) === 91) {
      start2 = pos + 1;
      pos = state.md.helpers.parseLinkLabel(state, pos);
      if (pos >= 0) {
        label8 = state.src.slice(start2, pos++);
      } else {
        pos = labelEnd + 1;
      }
    } else {
      pos = labelEnd + 1;
    }
    if (!label8) {
      label8 = state.src.slice(labelStart, labelEnd);
    }
    ref2 = state.env.references[normalizeReference(label8)];
    if (!ref2) {
      state.pos = oldPos;
      return false;
    }
    href = ref2.href;
    title = ref2.title;
  }
  if (!silent) {
    content3 = state.src.slice(labelStart, labelEnd);
    const tokens = [];
    state.md.inline.parse(
      content3,
      state.md,
      state.env,
      tokens
    );
    const token = state.push("image", "img", 0);
    const attrs7 = [["src", href], ["alt", ""]];
    token.attrs = attrs7;
    token.children = tokens;
    token.content = content3;
    if (title) {
      attrs7.push(["title", title]);
    }
  }
  state.pos = pos;
  state.posMax = max;
  return true;
}
__name(image, "image");
const EMAIL_RE = /^([a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*)$/;
const AUTOLINK_RE = /^([a-zA-Z][a-zA-Z0-9+.-]{1,31}):([^<>\x00-\x20]*)$/;
function autolink(state, silent) {
  let pos = state.pos;
  if (state.src.charCodeAt(pos) !== 60) {
    return false;
  }
  const start2 = state.pos;
  const max = state.posMax;
  for (; ; ) {
    if (++pos >= max) return false;
    const ch = state.src.charCodeAt(pos);
    if (ch === 60) return false;
    if (ch === 62) break;
  }
  const url = state.src.slice(start2 + 1, pos);
  if (AUTOLINK_RE.test(url)) {
    const fullUrl = state.md.normalizeLink(url);
    if (!state.md.validateLink(fullUrl)) {
      return false;
    }
    if (!silent) {
      const token_o = state.push("link_open", "a", 1);
      token_o.attrs = [["href", fullUrl]];
      token_o.markup = "autolink";
      token_o.info = "auto";
      const token_t = state.push("text", "", 0);
      token_t.content = state.md.normalizeLinkText(url);
      const token_c = state.push("link_close", "a", -1);
      token_c.markup = "autolink";
      token_c.info = "auto";
    }
    state.pos += url.length + 2;
    return true;
  }
  if (EMAIL_RE.test(url)) {
    const fullUrl = state.md.normalizeLink("mailto:" + url);
    if (!state.md.validateLink(fullUrl)) {
      return false;
    }
    if (!silent) {
      const token_o = state.push("link_open", "a", 1);
      token_o.attrs = [["href", fullUrl]];
      token_o.markup = "autolink";
      token_o.info = "auto";
      const token_t = state.push("text", "", 0);
      token_t.content = state.md.normalizeLinkText(url);
      const token_c = state.push("link_close", "a", -1);
      token_c.markup = "autolink";
      token_c.info = "auto";
    }
    state.pos += url.length + 2;
    return true;
  }
  return false;
}
__name(autolink, "autolink");
function isLinkOpen(str) {
  return /^<a[>\s]/i.test(str);
}
__name(isLinkOpen, "isLinkOpen");
function isLinkClose(str) {
  return /^<\/a\s*>/i.test(str);
}
__name(isLinkClose, "isLinkClose");
function isLetter(ch) {
  const lc = ch | 32;
  return lc >= 97 && lc <= 122;
}
__name(isLetter, "isLetter");
function html_inline(state, silent) {
  if (!state.md.options.html) {
    return false;
  }
  const max = state.posMax;
  const pos = state.pos;
  if (state.src.charCodeAt(pos) !== 60 || pos + 2 >= max) {
    return false;
  }
  const ch = state.src.charCodeAt(pos + 1);
  if (ch !== 33 && ch !== 63 && ch !== 47 && !isLetter(ch)) {
    return false;
  }
  const match2 = state.src.slice(pos).match(HTML_TAG_RE);
  if (!match2) {
    return false;
  }
  if (!silent) {
    const token = state.push("html_inline", "", 0);
    token.content = match2[0];
    if (isLinkOpen(token.content)) state.linkLevel++;
    if (isLinkClose(token.content)) state.linkLevel--;
  }
  state.pos += match2[0].length;
  return true;
}
__name(html_inline, "html_inline");
const DIGITAL_RE = /^&#((?:x[a-f0-9]{1,6}|[0-9]{1,7}));/i;
const NAMED_RE = /^&([a-z][a-z0-9]{1,31});/i;
function entity(state, silent) {
  const pos = state.pos;
  const max = state.posMax;
  if (state.src.charCodeAt(pos) !== 38) return false;
  if (pos + 1 >= max) return false;
  const ch = state.src.charCodeAt(pos + 1);
  if (ch === 35) {
    const match2 = state.src.slice(pos).match(DIGITAL_RE);
    if (match2) {
      if (!silent) {
        const code2 = match2[1][0].toLowerCase() === "x" ? parseInt(match2[1].slice(1), 16) : parseInt(match2[1], 10);
        const token = state.push("text_special", "", 0);
        token.content = isValidEntityCode(code2) ? fromCodePoint(code2) : fromCodePoint(65533);
        token.markup = match2[0];
        token.info = "entity";
      }
      state.pos += match2[0].length;
      return true;
    }
  } else {
    const match2 = state.src.slice(pos).match(NAMED_RE);
    if (match2) {
      const decoded = decodeHTML(match2[0]);
      if (decoded !== match2[0]) {
        if (!silent) {
          const token = state.push("text_special", "", 0);
          token.content = decoded;
          token.markup = match2[0];
          token.info = "entity";
        }
        state.pos += match2[0].length;
        return true;
      }
    }
  }
  return false;
}
__name(entity, "entity");
function processDelimiters(delimiters) {
  const openersBottom = {};
  const max = delimiters.length;
  if (!max) return;
  let headerIdx = 0;
  let lastTokenIdx = -2;
  const jumps = [];
  for (let closerIdx = 0; closerIdx < max; closerIdx++) {
    const closer = delimiters[closerIdx];
    jumps.push(0);
    if (delimiters[headerIdx].marker !== closer.marker || lastTokenIdx !== closer.token - 1) {
      headerIdx = closerIdx;
    }
    lastTokenIdx = closer.token;
    closer.length = closer.length || 0;
    if (!closer.close) continue;
    if (!openersBottom.hasOwnProperty(closer.marker)) {
      openersBottom[closer.marker] = [-1, -1, -1, -1, -1, -1];
    }
    const minOpenerIdx = openersBottom[closer.marker][(closer.open ? 3 : 0) + closer.length % 3];
    let openerIdx = headerIdx - jumps[headerIdx] - 1;
    let newMinOpenerIdx = openerIdx;
    for (; openerIdx > minOpenerIdx; openerIdx -= jumps[openerIdx] + 1) {
      const opener = delimiters[openerIdx];
      if (opener.marker !== closer.marker) continue;
      if (opener.open && opener.end < 0) {
        let isOddMatch = false;
        if (opener.close || closer.open) {
          if ((opener.length + closer.length) % 3 === 0) {
            if (opener.length % 3 !== 0 || closer.length % 3 !== 0) {
              isOddMatch = true;
            }
          }
        }
        if (!isOddMatch) {
          const lastJump = openerIdx > 0 && !delimiters[openerIdx - 1].open ? jumps[openerIdx - 1] + 1 : 0;
          jumps[closerIdx] = closerIdx - openerIdx + lastJump;
          jumps[openerIdx] = lastJump;
          closer.open = false;
          opener.end = closerIdx;
          opener.close = false;
          newMinOpenerIdx = -1;
          lastTokenIdx = -2;
          break;
        }
      }
    }
    if (newMinOpenerIdx !== -1) {
      openersBottom[closer.marker][(closer.open ? 3 : 0) + (closer.length || 0) % 3] = newMinOpenerIdx;
    }
  }
}
__name(processDelimiters, "processDelimiters");
function link_pairs(state) {
  const tokens_meta = state.tokens_meta;
  const max = state.tokens_meta.length;
  processDelimiters(state.delimiters);
  for (let curr = 0; curr < max; curr++) {
    if (tokens_meta[curr] && tokens_meta[curr].delimiters) {
      processDelimiters(tokens_meta[curr].delimiters);
    }
  }
}
__name(link_pairs, "link_pairs");
function fragments_join(state) {
  let curr, last;
  let level = 0;
  const tokens = state.tokens;
  const max = state.tokens.length;
  for (curr = last = 0; curr < max; curr++) {
    if (tokens[curr].nesting < 0) level--;
    tokens[curr].level = level;
    if (tokens[curr].nesting > 0) level++;
    if (tokens[curr].type === "text" && curr + 1 < max && tokens[curr + 1].type === "text") {
      tokens[curr + 1].content = tokens[curr].content + tokens[curr + 1].content;
    } else {
      if (curr !== last) {
        tokens[last] = tokens[curr];
      }
      last++;
    }
  }
  if (curr !== last) {
    tokens.length = last;
  }
}
__name(fragments_join, "fragments_join");
const _rules = [
  ["text", text],
  ["linkify", linkify],
  ["newline", newline],
  ["escape", escape$1],
  ["backticks", backtick],
  ["strikethrough", r_strikethrough.tokenize],
  ["emphasis", r_emphasis.tokenize],
  ["link", link],
  ["image", image],
  ["autolink", autolink],
  ["html_inline", html_inline],
  ["entity", entity]
];
const _rules2 = [
  ["balance_pairs", link_pairs],
  ["strikethrough", r_strikethrough.postProcess],
  ["emphasis", r_emphasis.postProcess],
  // rules for pairs separate '**' into its own text tokens, which may be left unused,
  // rule below merges unused segments back with the rest of the text
  ["fragments_join", fragments_join]
];
function ParserInline() {
  this.ruler = new Ruler();
  for (let i2 = 0; i2 < _rules.length; i2++) {
    this.ruler.push(_rules[i2][0], _rules[i2][1]);
  }
  this.ruler2 = new Ruler();
  for (let i2 = 0; i2 < _rules2.length; i2++) {
    this.ruler2.push(_rules2[i2][0], _rules2[i2][1]);
  }
}
__name(ParserInline, "ParserInline");
ParserInline.prototype.skipToken = function(state) {
  const pos = state.pos;
  const rules = this.ruler.getRules("");
  const len = rules.length;
  const maxNesting = state.md.options.maxNesting;
  const cache2 = state.cache;
  if (typeof cache2[pos] !== "undefined") {
    state.pos = cache2[pos];
    return;
  }
  let ok = false;
  if (state.level < maxNesting) {
    for (let i2 = 0; i2 < len; i2++) {
      state.level++;
      ok = rules[i2](state, true);
      state.level--;
      if (ok) {
        if (pos >= state.pos) {
          throw new Error("inline rule didn't increment state.pos");
        }
        break;
      }
    }
  } else {
    state.pos = state.posMax;
  }
  if (!ok) {
    state.pos++;
  }
  cache2[pos] = state.pos;
};
ParserInline.prototype.tokenize = function(state) {
  const rules = this.ruler.getRules("");
  const len = rules.length;
  const end = state.posMax;
  const maxNesting = state.md.options.maxNesting;
  while (state.pos < end) {
    const prevPos = state.pos;
    let ok = false;
    if (state.level < maxNesting) {
      for (let i2 = 0; i2 < len; i2++) {
        ok = rules[i2](state, false);
        if (ok) {
          if (prevPos >= state.pos) {
            throw new Error("inline rule didn't increment state.pos");
          }
          break;
        }
      }
    }
    if (ok) {
      if (state.pos >= end) {
        break;
      }
      continue;
    }
    state.pending += state.src[state.pos++];
  }
  if (state.pending) {
    state.pushPending();
  }
};
ParserInline.prototype.parse = function(str, md2, env, outTokens) {
  const state = new this.State(str, md2, env, outTokens);
  this.tokenize(state);
  const rules = this.ruler2.getRules("");
  const len = rules.length;
  for (let i2 = 0; i2 < len; i2++) {
    rules[i2](state);
  }
};
ParserInline.prototype.State = StateInline;
function reFactory(opts) {
  const re = {};
  opts = opts || {};
  re.src_Any = Any.source;
  re.src_Cc = Cc.source;
  re.src_Z = Z.source;
  re.src_P = P.source;
  re.src_ZPCc = [re.src_Z, re.src_P, re.src_Cc].join("|");
  re.src_ZCc = [re.src_Z, re.src_Cc].join("|");
  const text_separators = "[><｜]";
  re.src_pseudo_letter = "(?:(?!" + text_separators + "|" + re.src_ZPCc + ")" + re.src_Any + ")";
  re.src_ip4 = "(?:(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)";
  re.src_auth = "(?:(?:(?!" + re.src_ZCc + "|[@/\\[\\]()]).)+@)?";
  re.src_port = "(?::(?:6(?:[0-4]\\d{3}|5(?:[0-4]\\d{2}|5(?:[0-2]\\d|3[0-5])))|[1-5]?\\d{1,4}))?";
  re.src_host_terminator = "(?=$|" + text_separators + "|" + re.src_ZPCc + ")(?!" + (opts["---"] ? "-(?!--)|" : "-|") + "_|:\\d|\\.-|\\.(?!$|" + re.src_ZPCc + "))";
  re.src_path = "(?:[/?#](?:(?!" + re.src_ZCc + "|" + text_separators + `|[()[\\]{}.,"'?!\\-;]).|\\[(?:(?!` + re.src_ZCc + "|\\]).)*\\]|\\((?:(?!" + re.src_ZCc + "|[)]).)*\\)|\\{(?:(?!" + re.src_ZCc + '|[}]).)*\\}|\\"(?:(?!' + re.src_ZCc + `|["]).)+\\"|\\'(?:(?!` + re.src_ZCc + "|[']).)+\\'|\\'(?=" + re.src_pseudo_letter + "|[-])|\\.{2,}[a-zA-Z0-9%/&]|\\.(?!" + re.src_ZCc + "|[.]|$)|" + (opts["---"] ? "\\-(?!--(?:[^-]|$))(?:-*)|" : "\\-+|") + // allow `,,,` in paths
  ",(?!" + re.src_ZCc + "|$)|;(?!" + re.src_ZCc + "|$)|\\!+(?!" + re.src_ZCc + "|[!]|$)|\\?(?!" + re.src_ZCc + "|[?]|$))+|\\/)?";
  re.src_email_name = '[\\-;:&=\\+\\$,\\.a-zA-Z0-9_][\\-;:&=\\+\\$,\\"\\.a-zA-Z0-9_]*';
  re.src_xn = "xn--[a-z0-9\\-]{1,59}";
  re.src_domain_root = // Allow letters & digits (http://test1)
  "(?:" + re.src_xn + "|" + re.src_pseudo_letter + "{1,63})";
  re.src_domain = "(?:" + re.src_xn + "|(?:" + re.src_pseudo_letter + ")|(?:" + re.src_pseudo_letter + "(?:-|" + re.src_pseudo_letter + "){0,61}" + re.src_pseudo_letter + "))";
  re.src_host = "(?:(?:(?:(?:" + re.src_domain + ")\\.)*" + re.src_domain + "))";
  re.tpl_host_fuzzy = "(?:" + re.src_ip4 + "|(?:(?:(?:" + re.src_domain + ")\\.)+(?:%TLDS%)))";
  re.tpl_host_no_ip_fuzzy = "(?:(?:(?:" + re.src_domain + ")\\.)+(?:%TLDS%))";
  re.src_host_strict = re.src_host + re.src_host_terminator;
  re.tpl_host_fuzzy_strict = re.tpl_host_fuzzy + re.src_host_terminator;
  re.src_host_port_strict = re.src_host + re.src_port + re.src_host_terminator;
  re.tpl_host_port_fuzzy_strict = re.tpl_host_fuzzy + re.src_port + re.src_host_terminator;
  re.tpl_host_port_no_ip_fuzzy_strict = re.tpl_host_no_ip_fuzzy + re.src_port + re.src_host_terminator;
  re.tpl_host_fuzzy_test = "localhost|www\\.|\\.\\d{1,3}\\.|(?:\\.(?:%TLDS%)(?:" + re.src_ZPCc + "|>|$))";
  re.tpl_email_fuzzy = "(^|" + text_separators + '|"|\\(|' + re.src_ZCc + ")(" + re.src_email_name + "@" + re.tpl_host_fuzzy_strict + ")";
  re.tpl_link_fuzzy = // Fuzzy link can't be prepended with .:/\- and non punctuation.
  // but can start with > (markdown blockquote)
  "(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|" + re.src_ZPCc + "))((?![$+<=>^`|｜])" + re.tpl_host_port_fuzzy_strict + re.src_path + ")";
  re.tpl_link_no_ip_fuzzy = // Fuzzy link can't be prepended with .:/\- and non punctuation.
  // but can start with > (markdown blockquote)
  "(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|" + re.src_ZPCc + "))((?![$+<=>^`|｜])" + re.tpl_host_port_no_ip_fuzzy_strict + re.src_path + ")";
  return re;
}
__name(reFactory, "reFactory");
function assign(obj) {
  const sources = Array.prototype.slice.call(arguments, 1);
  sources.forEach(function(source) {
    if (!source) {
      return;
    }
    Object.keys(source).forEach(function(key) {
      obj[key] = source[key];
    });
  });
  return obj;
}
__name(assign, "assign");
function _class(obj) {
  return Object.prototype.toString.call(obj);
}
__name(_class, "_class");
function isString(obj) {
  return _class(obj) === "[object String]";
}
__name(isString, "isString");
function isObject(obj) {
  return _class(obj) === "[object Object]";
}
__name(isObject, "isObject");
function isRegExp(obj) {
  return _class(obj) === "[object RegExp]";
}
__name(isRegExp, "isRegExp");
function isFunction(obj) {
  return _class(obj) === "[object Function]";
}
__name(isFunction, "isFunction");
function escapeRE(str) {
  return str.replace(/[.?*+^$[\]\\(){}|-]/g, "\\$&");
}
__name(escapeRE, "escapeRE");
const defaultOptions = {
  fuzzyLink: true,
  fuzzyEmail: true,
  fuzzyIP: false
};
function isOptionsObj(obj) {
  return Object.keys(obj || {}).reduce(function(acc, k2) {
    return acc || defaultOptions.hasOwnProperty(k2);
  }, false);
}
__name(isOptionsObj, "isOptionsObj");
const defaultSchemas = {
  "http:": {
    validate: /* @__PURE__ */ __name(function(text2, pos, self2) {
      const tail = text2.slice(pos);
      if (!self2.re.http) {
        self2.re.http = new RegExp(
          "^\\/\\/" + self2.re.src_auth + self2.re.src_host_port_strict + self2.re.src_path,
          "i"
        );
      }
      if (self2.re.http.test(tail)) {
        return tail.match(self2.re.http)[0].length;
      }
      return 0;
    }, "validate")
  },
  "https:": "http:",
  "ftp:": "http:",
  "//": {
    validate: /* @__PURE__ */ __name(function(text2, pos, self2) {
      const tail = text2.slice(pos);
      if (!self2.re.no_http) {
        self2.re.no_http = new RegExp(
          "^" + self2.re.src_auth + // Don't allow single-level domains, because of false positives like '//test'
          // with code comments
          "(?:localhost|(?:(?:" + self2.re.src_domain + ")\\.)+" + self2.re.src_domain_root + ")" + self2.re.src_port + self2.re.src_host_terminator + self2.re.src_path,
          "i"
        );
      }
      if (self2.re.no_http.test(tail)) {
        if (pos >= 3 && text2[pos - 3] === ":") {
          return 0;
        }
        if (pos >= 3 && text2[pos - 3] === "/") {
          return 0;
        }
        return tail.match(self2.re.no_http)[0].length;
      }
      return 0;
    }, "validate")
  },
  "mailto:": {
    validate: /* @__PURE__ */ __name(function(text2, pos, self2) {
      const tail = text2.slice(pos);
      if (!self2.re.mailto) {
        self2.re.mailto = new RegExp(
          "^" + self2.re.src_email_name + "@" + self2.re.src_host_strict,
          "i"
        );
      }
      if (self2.re.mailto.test(tail)) {
        return tail.match(self2.re.mailto)[0].length;
      }
      return 0;
    }, "validate")
  }
};
const tlds_2ch_src_re = "a[cdefgilmnoqrstuwxz]|b[abdefghijmnorstvwyz]|c[acdfghiklmnoruvwxyz]|d[ejkmoz]|e[cegrstu]|f[ijkmor]|g[abdefghilmnpqrstuwy]|h[kmnrtu]|i[delmnoqrst]|j[emop]|k[eghimnprwyz]|l[abcikrstuvy]|m[acdeghklmnopqrstuvwxyz]|n[acefgilopruz]|om|p[aefghklmnrstwy]|qa|r[eosuw]|s[abcdeghijklmnortuvxyz]|t[cdfghjklmnortvwz]|u[agksyz]|v[aceginu]|w[fs]|y[et]|z[amw]";
const tlds_default = "biz|com|edu|gov|net|org|pro|web|xxx|aero|asia|coop|info|museum|name|shop|рф".split("|");
function resetScanCache(self2) {
  self2.__index__ = -1;
  self2.__text_cache__ = "";
}
__name(resetScanCache, "resetScanCache");
function createValidator(re) {
  return function(text2, pos) {
    const tail = text2.slice(pos);
    if (re.test(tail)) {
      return tail.match(re)[0].length;
    }
    return 0;
  };
}
__name(createValidator, "createValidator");
function createNormalizer() {
  return function(match2, self2) {
    self2.normalize(match2);
  };
}
__name(createNormalizer, "createNormalizer");
function compile(self2) {
  const re = self2.re = reFactory(self2.__opts__);
  const tlds3 = self2.__tlds__.slice();
  self2.onCompile();
  if (!self2.__tlds_replaced__) {
    tlds3.push(tlds_2ch_src_re);
  }
  tlds3.push(re.src_xn);
  re.src_tlds = tlds3.join("|");
  function untpl(tpl) {
    return tpl.replace("%TLDS%", re.src_tlds);
  }
  __name(untpl, "untpl");
  re.email_fuzzy = RegExp(untpl(re.tpl_email_fuzzy), "i");
  re.link_fuzzy = RegExp(untpl(re.tpl_link_fuzzy), "i");
  re.link_no_ip_fuzzy = RegExp(untpl(re.tpl_link_no_ip_fuzzy), "i");
  re.host_fuzzy_test = RegExp(untpl(re.tpl_host_fuzzy_test), "i");
  const aliases = [];
  self2.__compiled__ = {};
  function schemaError(name2, val) {
    throw new Error('(LinkifyIt) Invalid schema "' + name2 + '": ' + val);
  }
  __name(schemaError, "schemaError");
  Object.keys(self2.__schemas__).forEach(function(name2) {
    const val = self2.__schemas__[name2];
    if (val === null) {
      return;
    }
    const compiled = { validate: null, link: null };
    self2.__compiled__[name2] = compiled;
    if (isObject(val)) {
      if (isRegExp(val.validate)) {
        compiled.validate = createValidator(val.validate);
      } else if (isFunction(val.validate)) {
        compiled.validate = val.validate;
      } else {
        schemaError(name2, val);
      }
      if (isFunction(val.normalize)) {
        compiled.normalize = val.normalize;
      } else if (!val.normalize) {
        compiled.normalize = createNormalizer();
      } else {
        schemaError(name2, val);
      }
      return;
    }
    if (isString(val)) {
      aliases.push(name2);
      return;
    }
    schemaError(name2, val);
  });
  aliases.forEach(function(alias) {
    if (!self2.__compiled__[self2.__schemas__[alias]]) {
      return;
    }
    self2.__compiled__[alias].validate = self2.__compiled__[self2.__schemas__[alias]].validate;
    self2.__compiled__[alias].normalize = self2.__compiled__[self2.__schemas__[alias]].normalize;
  });
  self2.__compiled__[""] = { validate: null, normalize: createNormalizer() };
  const slist = Object.keys(self2.__compiled__).filter(function(name2) {
    return name2.length > 0 && self2.__compiled__[name2];
  }).map(escapeRE).join("|");
  self2.re.schema_test = RegExp("(^|(?!_)(?:[><｜]|" + re.src_ZPCc + "))(" + slist + ")", "i");
  self2.re.schema_search = RegExp("(^|(?!_)(?:[><｜]|" + re.src_ZPCc + "))(" + slist + ")", "ig");
  self2.re.schema_at_start = RegExp("^" + self2.re.schema_search.source, "i");
  self2.re.pretest = RegExp(
    "(" + self2.re.schema_test.source + ")|(" + self2.re.host_fuzzy_test.source + ")|@",
    "i"
  );
  resetScanCache(self2);
}
__name(compile, "compile");
function Match(self2, shift2) {
  const start2 = self2.__index__;
  const end = self2.__last_index__;
  const text2 = self2.__text_cache__.slice(start2, end);
  this.schema = self2.__schema__.toLowerCase();
  this.index = start2 + shift2;
  this.lastIndex = end + shift2;
  this.raw = text2;
  this.text = text2;
  this.url = text2;
}
__name(Match, "Match");
function createMatch(self2, shift2) {
  const match2 = new Match(self2, shift2);
  self2.__compiled__[match2.schema].normalize(match2, self2);
  return match2;
}
__name(createMatch, "createMatch");
function LinkifyIt(schemas, options5) {
  if (!(this instanceof LinkifyIt)) {
    return new LinkifyIt(schemas, options5);
  }
  if (!options5) {
    if (isOptionsObj(schemas)) {
      options5 = schemas;
      schemas = {};
    }
  }
  this.__opts__ = assign({}, defaultOptions, options5);
  this.__index__ = -1;
  this.__last_index__ = -1;
  this.__schema__ = "";
  this.__text_cache__ = "";
  this.__schemas__ = assign({}, defaultSchemas, schemas);
  this.__compiled__ = {};
  this.__tlds__ = tlds_default;
  this.__tlds_replaced__ = false;
  this.re = {};
  compile(this);
}
__name(LinkifyIt, "LinkifyIt");
LinkifyIt.prototype.add = /* @__PURE__ */ __name(function add2(schema2, definition) {
  this.__schemas__[schema2] = definition;
  compile(this);
  return this;
}, "add");
LinkifyIt.prototype.set = /* @__PURE__ */ __name(function set2(options5) {
  this.__opts__ = assign(this.__opts__, options5);
  return this;
}, "set");
LinkifyIt.prototype.test = /* @__PURE__ */ __name(function test2(text2) {
  this.__text_cache__ = text2;
  this.__index__ = -1;
  if (!text2.length) {
    return false;
  }
  let m2, ml, me, len, shift2, next2, re, tld_pos, at_pos;
  if (this.re.schema_test.test(text2)) {
    re = this.re.schema_search;
    re.lastIndex = 0;
    while ((m2 = re.exec(text2)) !== null) {
      len = this.testSchemaAt(text2, m2[2], re.lastIndex);
      if (len) {
        this.__schema__ = m2[2];
        this.__index__ = m2.index + m2[1].length;
        this.__last_index__ = m2.index + m2[0].length + len;
        break;
      }
    }
  }
  if (this.__opts__.fuzzyLink && this.__compiled__["http:"]) {
    tld_pos = text2.search(this.re.host_fuzzy_test);
    if (tld_pos >= 0) {
      if (this.__index__ < 0 || tld_pos < this.__index__) {
        if ((ml = text2.match(this.__opts__.fuzzyIP ? this.re.link_fuzzy : this.re.link_no_ip_fuzzy)) !== null) {
          shift2 = ml.index + ml[1].length;
          if (this.__index__ < 0 || shift2 < this.__index__) {
            this.__schema__ = "";
            this.__index__ = shift2;
            this.__last_index__ = ml.index + ml[0].length;
          }
        }
      }
    }
  }
  if (this.__opts__.fuzzyEmail && this.__compiled__["mailto:"]) {
    at_pos = text2.indexOf("@");
    if (at_pos >= 0) {
      if ((me = text2.match(this.re.email_fuzzy)) !== null) {
        shift2 = me.index + me[1].length;
        next2 = me.index + me[0].length;
        if (this.__index__ < 0 || shift2 < this.__index__ || shift2 === this.__index__ && next2 > this.__last_index__) {
          this.__schema__ = "mailto:";
          this.__index__ = shift2;
          this.__last_index__ = next2;
        }
      }
    }
  }
  return this.__index__ >= 0;
}, "test");
LinkifyIt.prototype.pretest = /* @__PURE__ */ __name(function pretest(text2) {
  return this.re.pretest.test(text2);
}, "pretest");
LinkifyIt.prototype.testSchemaAt = /* @__PURE__ */ __name(function testSchemaAt(text2, schema2, pos) {
  if (!this.__compiled__[schema2.toLowerCase()]) {
    return 0;
  }
  return this.__compiled__[schema2.toLowerCase()].validate(text2, pos, this);
}, "testSchemaAt");
LinkifyIt.prototype.match = /* @__PURE__ */ __name(function match(text2) {
  const result = [];
  let shift2 = 0;
  if (this.__index__ >= 0 && this.__text_cache__ === text2) {
    result.push(createMatch(this, shift2));
    shift2 = this.__last_index__;
  }
  let tail = shift2 ? text2.slice(shift2) : text2;
  while (this.test(tail)) {
    result.push(createMatch(this, shift2));
    tail = tail.slice(this.__last_index__);
    shift2 += this.__last_index__;
  }
  if (result.length) {
    return result;
  }
  return null;
}, "match");
LinkifyIt.prototype.matchAtStart = /* @__PURE__ */ __name(function matchAtStart(text2) {
  this.__text_cache__ = text2;
  this.__index__ = -1;
  if (!text2.length) return null;
  const m2 = this.re.schema_at_start.exec(text2);
  if (!m2) return null;
  const len = this.testSchemaAt(text2, m2[2], m2[0].length);
  if (!len) return null;
  this.__schema__ = m2[2];
  this.__index__ = m2.index + m2[1].length;
  this.__last_index__ = m2.index + m2[0].length + len;
  return createMatch(this, 0);
}, "matchAtStart");
LinkifyIt.prototype.tlds = /* @__PURE__ */ __name(function tlds2(list2, keepOld) {
  list2 = Array.isArray(list2) ? list2 : [list2];
  if (!keepOld) {
    this.__tlds__ = list2.slice();
    this.__tlds_replaced__ = true;
    compile(this);
    return this;
  }
  this.__tlds__ = this.__tlds__.concat(list2).sort().filter(function(el, idx, arr) {
    return el !== arr[idx - 1];
  }).reverse();
  compile(this);
  return this;
}, "tlds");
LinkifyIt.prototype.normalize = /* @__PURE__ */ __name(function normalize2(match2) {
  if (!match2.schema) {
    match2.url = "http://" + match2.url;
  }
  if (match2.schema === "mailto:" && !/^mailto:/i.test(match2.url)) {
    match2.url = "mailto:" + match2.url;
  }
}, "normalize");
LinkifyIt.prototype.onCompile = /* @__PURE__ */ __name(function onCompile() {
}, "onCompile");
"use strict";
const maxInt = 2147483647;
const base = 36;
const tMin = 1;
const tMax = 26;
const skew = 38;
const damp = 700;
const initialBias = 72;
const initialN = 128;
const delimiter = "-";
const regexPunycode = /^xn--/;
const regexNonASCII = /[^\0-\x7F]/;
const regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g;
const errors = {
  "overflow": "Overflow: input needs wider integers to process",
  "not-basic": "Illegal input >= 0x80 (not a basic code point)",
  "invalid-input": "Invalid input"
};
const baseMinusTMin = base - tMin;
const floor = Math.floor;
const stringFromCharCode = String.fromCharCode;
function error(type) {
  throw new RangeError(errors[type]);
}
__name(error, "error");
function map(array, callback) {
  const result = [];
  let length = array.length;
  while (length--) {
    result[length] = callback(array[length]);
  }
  return result;
}
__name(map, "map");
function mapDomain(domain2, callback) {
  const parts2 = domain2.split("@");
  let result = "";
  if (parts2.length > 1) {
    result = parts2[0] + "@";
    domain2 = parts2[1];
  }
  domain2 = domain2.replace(regexSeparators, ".");
  const labels = domain2.split(".");
  const encoded = map(labels, callback).join(".");
  return result + encoded;
}
__name(mapDomain, "mapDomain");
function ucs2decode(string) {
  const output = [];
  let counter = 0;
  const length = string.length;
  while (counter < length) {
    const value3 = string.charCodeAt(counter++);
    if (value3 >= 55296 && value3 <= 56319 && counter < length) {
      const extra = string.charCodeAt(counter++);
      if ((extra & 64512) == 56320) {
        output.push(((value3 & 1023) << 10) + (extra & 1023) + 65536);
      } else {
        output.push(value3);
        counter--;
      }
    } else {
      output.push(value3);
    }
  }
  return output;
}
__name(ucs2decode, "ucs2decode");
const ucs2encode = /* @__PURE__ */ __name((codePoints) => String.fromCodePoint(...codePoints), "ucs2encode");
const basicToDigit = /* @__PURE__ */ __name(function(codePoint) {
  if (codePoint >= 48 && codePoint < 58) {
    return 26 + (codePoint - 48);
  }
  if (codePoint >= 65 && codePoint < 91) {
    return codePoint - 65;
  }
  if (codePoint >= 97 && codePoint < 123) {
    return codePoint - 97;
  }
  return base;
}, "basicToDigit");
const digitToBasic = /* @__PURE__ */ __name(function(digit, flag) {
  return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
}, "digitToBasic");
const adapt = /* @__PURE__ */ __name(function(delta2, numPoints, firstTime) {
  let k2 = 0;
  delta2 = firstTime ? floor(delta2 / damp) : delta2 >> 1;
  delta2 += floor(delta2 / numPoints);
  for (; delta2 > baseMinusTMin * tMax >> 1; k2 += base) {
    delta2 = floor(delta2 / baseMinusTMin);
  }
  return floor(k2 + (baseMinusTMin + 1) * delta2 / (delta2 + skew));
}, "adapt");
const decode = /* @__PURE__ */ __name(function(input) {
  const output = [];
  const inputLength = input.length;
  let i2 = 0;
  let n2 = initialN;
  let bias = initialBias;
  let basic = input.lastIndexOf(delimiter);
  if (basic < 0) {
    basic = 0;
  }
  for (let j2 = 0; j2 < basic; ++j2) {
    if (input.charCodeAt(j2) >= 128) {
      error("not-basic");
    }
    output.push(input.charCodeAt(j2));
  }
  for (let index2 = basic > 0 ? basic + 1 : 0; index2 < inputLength; ) {
    const oldi = i2;
    for (let w2 = 1, k2 = base; ; k2 += base) {
      if (index2 >= inputLength) {
        error("invalid-input");
      }
      const digit = basicToDigit(input.charCodeAt(index2++));
      if (digit >= base) {
        error("invalid-input");
      }
      if (digit > floor((maxInt - i2) / w2)) {
        error("overflow");
      }
      i2 += digit * w2;
      const t2 = k2 <= bias ? tMin : k2 >= bias + tMax ? tMax : k2 - bias;
      if (digit < t2) {
        break;
      }
      const baseMinusT = base - t2;
      if (w2 > floor(maxInt / baseMinusT)) {
        error("overflow");
      }
      w2 *= baseMinusT;
    }
    const out = output.length + 1;
    bias = adapt(i2 - oldi, out, oldi == 0);
    if (floor(i2 / out) > maxInt - n2) {
      error("overflow");
    }
    n2 += floor(i2 / out);
    i2 %= out;
    output.splice(i2++, 0, n2);
  }
  return String.fromCodePoint(...output);
}, "decode");
const encode = /* @__PURE__ */ __name(function(input) {
  const output = [];
  input = ucs2decode(input);
  const inputLength = input.length;
  let n2 = initialN;
  let delta2 = 0;
  let bias = initialBias;
  for (const currentValue of input) {
    if (currentValue < 128) {
      output.push(stringFromCharCode(currentValue));
    }
  }
  const basicLength = output.length;
  let handledCPCount = basicLength;
  if (basicLength) {
    output.push(delimiter);
  }
  while (handledCPCount < inputLength) {
    let m2 = maxInt;
    for (const currentValue of input) {
      if (currentValue >= n2 && currentValue < m2) {
        m2 = currentValue;
      }
    }
    const handledCPCountPlusOne = handledCPCount + 1;
    if (m2 - n2 > floor((maxInt - delta2) / handledCPCountPlusOne)) {
      error("overflow");
    }
    delta2 += (m2 - n2) * handledCPCountPlusOne;
    n2 = m2;
    for (const currentValue of input) {
      if (currentValue < n2 && ++delta2 > maxInt) {
        error("overflow");
      }
      if (currentValue === n2) {
        let q2 = delta2;
        for (let k2 = base; ; k2 += base) {
          const t2 = k2 <= bias ? tMin : k2 >= bias + tMax ? tMax : k2 - bias;
          if (q2 < t2) {
            break;
          }
          const qMinusT = q2 - t2;
          const baseMinusT = base - t2;
          output.push(
            stringFromCharCode(digitToBasic(t2 + qMinusT % baseMinusT, 0))
          );
          q2 = floor(qMinusT / baseMinusT);
        }
        output.push(stringFromCharCode(digitToBasic(q2, 0)));
        bias = adapt(delta2, handledCPCountPlusOne, handledCPCount === basicLength);
        delta2 = 0;
        ++handledCPCount;
      }
    }
    ++delta2;
    ++n2;
  }
  return output.join("");
}, "encode");
const toUnicode = /* @__PURE__ */ __name(function(input) {
  return mapDomain(input, function(string) {
    return regexPunycode.test(string) ? decode(string.slice(4).toLowerCase()) : string;
  });
}, "toUnicode");
const toASCII = /* @__PURE__ */ __name(function(input) {
  return mapDomain(input, function(string) {
    return regexNonASCII.test(string) ? "xn--" + encode(string) : string;
  });
}, "toASCII");
const punycode = {
  /**
   * A string representing the current Punycode.js version number.
   * @memberOf punycode
   * @type String
   */
  "version": "2.3.1",
  /**
   * An object of methods to convert from JavaScript's internal character
   * representation (UCS-2) to Unicode code points, and back.
   * @see <https://mathiasbynens.be/notes/javascript-encoding>
   * @memberOf punycode
   * @type Object
   */
  "ucs2": {
    "decode": ucs2decode,
    "encode": ucs2encode
  },
  "decode": decode,
  "encode": encode,
  "toASCII": toASCII,
  "toUnicode": toUnicode
};
const cfg_default = {
  options: {
    // Enable HTML tags in source
    html: false,
    // Use '/' to close single tags (<br />)
    xhtmlOut: false,
    // Convert '\n' in paragraphs into <br>
    breaks: false,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: false,
    // Enable some language-neutral replacements + quotes beautification
    typographer: false,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 100
  },
  components: {
    core: {},
    block: {},
    inline: {}
  }
};
const cfg_zero = {
  options: {
    // Enable HTML tags in source
    html: false,
    // Use '/' to close single tags (<br />)
    xhtmlOut: false,
    // Convert '\n' in paragraphs into <br>
    breaks: false,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: false,
    // Enable some language-neutral replacements + quotes beautification
    typographer: false,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 20
  },
  components: {
    core: {
      rules: [
        "normalize",
        "block",
        "inline",
        "text_join"
      ]
    },
    block: {
      rules: [
        "paragraph"
      ]
    },
    inline: {
      rules: [
        "text"
      ],
      rules2: [
        "balance_pairs",
        "fragments_join"
      ]
    }
  }
};
const cfg_commonmark = {
  options: {
    // Enable HTML tags in source
    html: true,
    // Use '/' to close single tags (<br />)
    xhtmlOut: true,
    // Convert '\n' in paragraphs into <br>
    breaks: false,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: false,
    // Enable some language-neutral replacements + quotes beautification
    typographer: false,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 20
  },
  components: {
    core: {
      rules: [
        "normalize",
        "block",
        "inline",
        "text_join"
      ]
    },
    block: {
      rules: [
        "blockquote",
        "code",
        "fence",
        "heading",
        "hr",
        "html_block",
        "lheading",
        "list",
        "reference",
        "paragraph"
      ]
    },
    inline: {
      rules: [
        "autolink",
        "backticks",
        "emphasis",
        "entity",
        "escape",
        "html_inline",
        "image",
        "link",
        "newline",
        "text"
      ],
      rules2: [
        "balance_pairs",
        "emphasis",
        "fragments_join"
      ]
    }
  }
};
const config = {
  default: cfg_default,
  zero: cfg_zero,
  commonmark: cfg_commonmark
};
const BAD_PROTO_RE = /^(vbscript|javascript|file|data):/;
const GOOD_DATA_RE = /^data:image\/(gif|png|jpeg|webp);/;
function validateLink(url) {
  const str = url.trim().toLowerCase();
  return BAD_PROTO_RE.test(str) ? GOOD_DATA_RE.test(str) : true;
}
__name(validateLink, "validateLink");
const RECODE_HOSTNAME_FOR = ["http:", "https:", "mailto:"];
function normalizeLink(url) {
  const parsed = urlParse(url, true);
  if (parsed.hostname) {
    if (!parsed.protocol || RECODE_HOSTNAME_FOR.indexOf(parsed.protocol) >= 0) {
      try {
        parsed.hostname = punycode.toASCII(parsed.hostname);
      } catch (er) {
      }
    }
  }
  return encode$2(format(parsed));
}
__name(normalizeLink, "normalizeLink");
function normalizeLinkText(url) {
  const parsed = urlParse(url, true);
  if (parsed.hostname) {
    if (!parsed.protocol || RECODE_HOSTNAME_FOR.indexOf(parsed.protocol) >= 0) {
      try {
        parsed.hostname = punycode.toUnicode(parsed.hostname);
      } catch (er) {
      }
    }
  }
  return decode$2(format(parsed), decode$2.defaultChars + "%");
}
__name(normalizeLinkText, "normalizeLinkText");
function MarkdownIt(presetName, options5) {
  if (!(this instanceof MarkdownIt)) {
    return new MarkdownIt(presetName, options5);
  }
  if (!options5) {
    if (!isString$1(presetName)) {
      options5 = presetName || {};
      presetName = "default";
    }
  }
  this.inline = new ParserInline();
  this.block = new ParserBlock();
  this.core = new Core();
  this.renderer = new Renderer();
  this.linkify = new LinkifyIt();
  this.validateLink = validateLink;
  this.normalizeLink = normalizeLink;
  this.normalizeLinkText = normalizeLinkText;
  this.utils = utils;
  this.helpers = assign$1({}, helpers);
  this.options = {};
  this.configure(presetName);
  if (options5) {
    this.set(options5);
  }
}
__name(MarkdownIt, "MarkdownIt");
MarkdownIt.prototype.set = function(options5) {
  assign$1(this.options, options5);
  return this;
};
MarkdownIt.prototype.configure = function(presets) {
  const self2 = this;
  if (isString$1(presets)) {
    const presetName = presets;
    presets = config[presetName];
    if (!presets) {
      throw new Error('Wrong `markdown-it` preset "' + presetName + '", check name');
    }
  }
  if (!presets) {
    throw new Error("Wrong `markdown-it` preset, can't be empty");
  }
  if (presets.options) {
    self2.set(presets.options);
  }
  if (presets.components) {
    Object.keys(presets.components).forEach(function(name2) {
      if (presets.components[name2].rules) {
        self2[name2].ruler.enableOnly(presets.components[name2].rules);
      }
      if (presets.components[name2].rules2) {
        self2[name2].ruler2.enableOnly(presets.components[name2].rules2);
      }
    });
  }
  return this;
};
MarkdownIt.prototype.enable = function(list2, ignoreInvalid) {
  let result = [];
  if (!Array.isArray(list2)) {
    list2 = [list2];
  }
  ["core", "block", "inline"].forEach(function(chain) {
    result = result.concat(this[chain].ruler.enable(list2, true));
  }, this);
  result = result.concat(this.inline.ruler2.enable(list2, true));
  const missed = list2.filter(function(name2) {
    return result.indexOf(name2) < 0;
  });
  if (missed.length && !ignoreInvalid) {
    throw new Error("MarkdownIt. Failed to enable unknown rule(s): " + missed);
  }
  return this;
};
MarkdownIt.prototype.disable = function(list2, ignoreInvalid) {
  let result = [];
  if (!Array.isArray(list2)) {
    list2 = [list2];
  }
  ["core", "block", "inline"].forEach(function(chain) {
    result = result.concat(this[chain].ruler.disable(list2, true));
  }, this);
  result = result.concat(this.inline.ruler2.disable(list2, true));
  const missed = list2.filter(function(name2) {
    return result.indexOf(name2) < 0;
  });
  if (missed.length && !ignoreInvalid) {
    throw new Error("MarkdownIt. Failed to disable unknown rule(s): " + missed);
  }
  return this;
};
MarkdownIt.prototype.use = function(plugin) {
  const args = [this].concat(Array.prototype.slice.call(arguments, 1));
  plugin.apply(plugin, args);
  return this;
};
MarkdownIt.prototype.parse = function(src, env) {
  if (typeof src !== "string") {
    throw new Error("Input data should be a String");
  }
  const state = new this.core.State(src, this, env);
  this.core.process(state);
  return state.tokens;
};
MarkdownIt.prototype.render = function(src, env) {
  env = env || {};
  return this.renderer.render(this.parse(src, env), this.options, env);
};
MarkdownIt.prototype.parseInline = function(src, env) {
  const state = new this.core.State(src, this, env);
  state.inlineMode = true;
  this.core.process(state);
  return state.tokens;
};
MarkdownIt.prototype.renderInline = function(src, env) {
  env = env || {};
  return this.renderer.render(this.parseInline(src, env), this.options, env);
};
const schema = new Schema({
  nodes: {
    doc: {
      content: "block+"
    },
    paragraph: {
      content: "inline*",
      group: "block",
      parseDOM: [{ tag: "p" }],
      toDOM() {
        return ["p", 0];
      }
    },
    blockquote: {
      content: "block+",
      group: "block",
      parseDOM: [{ tag: "blockquote" }],
      toDOM() {
        return ["blockquote", 0];
      }
    },
    horizontal_rule: {
      group: "block",
      parseDOM: [{ tag: "hr" }],
      toDOM() {
        return ["div", ["hr"]];
      }
    },
    heading: {
      attrs: { level: { default: 1 } },
      content: "(text | image)*",
      group: "block",
      defining: true,
      parseDOM: [
        { tag: "h1", attrs: { level: 1 } },
        { tag: "h2", attrs: { level: 2 } },
        { tag: "h3", attrs: { level: 3 } },
        { tag: "h4", attrs: { level: 4 } },
        { tag: "h5", attrs: { level: 5 } },
        { tag: "h6", attrs: { level: 6 } }
      ],
      toDOM(node3) {
        return ["h" + node3.attrs.level, 0];
      }
    },
    code_block: {
      content: "text*",
      group: "block",
      code: true,
      defining: true,
      marks: "",
      attrs: { params: { default: "" } },
      parseDOM: [{ tag: "pre", preserveWhitespace: "full", getAttrs: /* @__PURE__ */ __name((node3) => ({ params: node3.getAttribute("data-params") || "" }), "getAttrs") }],
      toDOM(node3) {
        return ["pre", node3.attrs.params ? { "data-params": node3.attrs.params } : {}, ["code", 0]];
      }
    },
    ordered_list: {
      content: "list_item+",
      group: "block",
      attrs: { order: { default: 1 }, tight: { default: false } },
      parseDOM: [{ tag: "ol", getAttrs(dom) {
        return {
          order: dom.hasAttribute("start") ? +dom.getAttribute("start") : 1,
          tight: dom.hasAttribute("data-tight")
        };
      } }],
      toDOM(node3) {
        return ["ol", {
          start: node3.attrs.order == 1 ? null : node3.attrs.order,
          "data-tight": node3.attrs.tight ? "true" : null
        }, 0];
      }
    },
    bullet_list: {
      content: "list_item+",
      group: "block",
      attrs: { tight: { default: false } },
      parseDOM: [{ tag: "ul", getAttrs: /* @__PURE__ */ __name((dom) => ({ tight: dom.hasAttribute("data-tight") }), "getAttrs") }],
      toDOM(node3) {
        return ["ul", { "data-tight": node3.attrs.tight ? "true" : null }, 0];
      }
    },
    list_item: {
      content: "block+",
      defining: true,
      parseDOM: [{ tag: "li" }],
      toDOM() {
        return ["li", 0];
      }
    },
    text: {
      group: "inline"
    },
    image: {
      inline: true,
      attrs: {
        src: {},
        alt: { default: null },
        title: { default: null }
      },
      group: "inline",
      draggable: true,
      parseDOM: [{ tag: "img[src]", getAttrs(dom) {
        return {
          src: dom.getAttribute("src"),
          title: dom.getAttribute("title"),
          alt: dom.getAttribute("alt")
        };
      } }],
      toDOM(node3) {
        return ["img", node3.attrs];
      }
    },
    hard_break: {
      inline: true,
      group: "inline",
      selectable: false,
      parseDOM: [{ tag: "br" }],
      toDOM() {
        return ["br"];
      }
    }
  },
  marks: {
    em: {
      parseDOM: [
        { tag: "i" },
        { tag: "em" },
        { style: "font-style=italic" },
        { style: "font-style=normal", clearMark: /* @__PURE__ */ __name((m2) => m2.type.name == "em", "clearMark") }
      ],
      toDOM() {
        return ["em"];
      }
    },
    strong: {
      parseDOM: [
        { tag: "strong" },
        { tag: "b", getAttrs: /* @__PURE__ */ __name((node3) => node3.style.fontWeight != "normal" && null, "getAttrs") },
        { style: "font-weight=400", clearMark: /* @__PURE__ */ __name((m2) => m2.type.name == "strong", "clearMark") },
        { style: "font-weight", getAttrs: /* @__PURE__ */ __name((value3) => /^(bold(er)?|[5-9]\d{2,})$/.test(value3) && null, "getAttrs") }
      ],
      toDOM() {
        return ["strong"];
      }
    },
    link: {
      attrs: {
        href: {},
        title: { default: null }
      },
      inclusive: false,
      parseDOM: [{ tag: "a[href]", getAttrs(dom) {
        return { href: dom.getAttribute("href"), title: dom.getAttribute("title") };
      } }],
      toDOM(node3) {
        return ["a", node3.attrs];
      }
    },
    code: {
      parseDOM: [{ tag: "code" }],
      toDOM() {
        return ["code"];
      }
    }
  }
});
function maybeMerge(a2, b2) {
  if (a2.isText && b2.isText && Mark$1.sameSet(a2.marks, b2.marks))
    return a2.withText(a2.text + b2.text);
}
__name(maybeMerge, "maybeMerge");
class MarkdownParseState {
  static {
    __name(this, "MarkdownParseState");
  }
  constructor(schema2, tokenHandlers2) {
    this.schema = schema2;
    this.tokenHandlers = tokenHandlers2;
    this.stack = [{ type: schema2.topNodeType, attrs: null, content: [], marks: Mark$1.none }];
  }
  top() {
    return this.stack[this.stack.length - 1];
  }
  push(elt) {
    if (this.stack.length)
      this.top().content.push(elt);
  }
  // Adds the given text to the current position in the document,
  // using the current marks as styling.
  addText(text2) {
    if (!text2)
      return;
    let top = this.top(), nodes = top.content, last = nodes[nodes.length - 1];
    let node3 = this.schema.text(text2, top.marks), merged;
    if (last && (merged = maybeMerge(last, node3)))
      nodes[nodes.length - 1] = merged;
    else
      nodes.push(node3);
  }
  // Adds the given mark to the set of active marks.
  openMark(mark2) {
    let top = this.top();
    top.marks = mark2.addToSet(top.marks);
  }
  // Removes the given mark from the set of active marks.
  closeMark(mark2) {
    let top = this.top();
    top.marks = mark2.removeFromSet(top.marks);
  }
  parseTokens(toks) {
    for (let i2 = 0; i2 < toks.length; i2++) {
      let tok = toks[i2];
      let handler14 = this.tokenHandlers[tok.type];
      if (!handler14)
        throw new Error("Token type `" + tok.type + "` not supported by Markdown parser");
      handler14(this, tok, toks, i2);
    }
  }
  // Add a node at the current position.
  addNode(type, attrs7, content3) {
    let top = this.top();
    let node3 = type.createAndFill(attrs7, content3, top ? top.marks : []);
    if (!node3)
      return null;
    this.push(node3);
    return node3;
  }
  // Wrap subsequent content in a node of the given type.
  openNode(type, attrs7) {
    this.stack.push({ type, attrs: attrs7, content: [], marks: Mark$1.none });
  }
  // Close and return the node that is currently on top of the stack.
  closeNode() {
    let info = this.stack.pop();
    return this.addNode(info.type, info.attrs, info.content);
  }
}
function attrs(spec, token, tokens, i2) {
  if (spec.getAttrs)
    return spec.getAttrs(token, tokens, i2);
  else if (spec.attrs instanceof Function)
    return spec.attrs(token);
  else
    return spec.attrs;
}
__name(attrs, "attrs");
function noCloseToken(spec, type) {
  return spec.noCloseToken || type == "code_inline" || type == "code_block" || type == "fence";
}
__name(noCloseToken, "noCloseToken");
function withoutTrailingNewline(str) {
  return str[str.length - 1] == "\n" ? str.slice(0, str.length - 1) : str;
}
__name(withoutTrailingNewline, "withoutTrailingNewline");
function noOp() {
}
__name(noOp, "noOp");
function tokenHandlers(schema2, tokens) {
  let handlers2 = /* @__PURE__ */ Object.create(null);
  for (let type in tokens) {
    let spec = tokens[type];
    if (spec.block) {
      let nodeType = schema2.nodeType(spec.block);
      if (noCloseToken(spec, type)) {
        handlers2[type] = (state, tok, tokens2, i2) => {
          state.openNode(nodeType, attrs(spec, tok, tokens2, i2));
          state.addText(withoutTrailingNewline(tok.content));
          state.closeNode();
        };
      } else {
        handlers2[type + "_open"] = (state, tok, tokens2, i2) => state.openNode(nodeType, attrs(spec, tok, tokens2, i2));
        handlers2[type + "_close"] = (state) => state.closeNode();
      }
    } else if (spec.node) {
      let nodeType = schema2.nodeType(spec.node);
      handlers2[type] = (state, tok, tokens2, i2) => state.addNode(nodeType, attrs(spec, tok, tokens2, i2));
    } else if (spec.mark) {
      let markType = schema2.marks[spec.mark];
      if (noCloseToken(spec, type)) {
        handlers2[type] = (state, tok, tokens2, i2) => {
          state.openMark(markType.create(attrs(spec, tok, tokens2, i2)));
          state.addText(withoutTrailingNewline(tok.content));
          state.closeMark(markType);
        };
      } else {
        handlers2[type + "_open"] = (state, tok, tokens2, i2) => state.openMark(markType.create(attrs(spec, tok, tokens2, i2)));
        handlers2[type + "_close"] = (state) => state.closeMark(markType);
      }
    } else if (spec.ignore) {
      if (noCloseToken(spec, type)) {
        handlers2[type] = noOp;
      } else {
        handlers2[type + "_open"] = noOp;
        handlers2[type + "_close"] = noOp;
      }
    } else {
      throw new RangeError("Unrecognized parsing spec " + JSON.stringify(spec));
    }
  }
  handlers2.text = (state, tok) => state.addText(tok.content);
  handlers2.inline = (state, tok) => state.parseTokens(tok.children);
  handlers2.softbreak = handlers2.softbreak || ((state) => state.addText(" "));
  return handlers2;
}
__name(tokenHandlers, "tokenHandlers");
let MarkdownParser$1 = class MarkdownParser2 {
  static {
    __name(this, "MarkdownParser");
  }
  /**
  Create a parser with the given configuration. You can configure
  the markdown-it parser to parse the dialect you want, and provide
  a description of the ProseMirror entities those tokens map to in
  the `tokens` object, which maps token names to descriptions of
  what to do with them. Such a description is an object, and may
  have the following properties:
  */
  constructor(schema2, tokenizer, tokens) {
    this.schema = schema2;
    this.tokenizer = tokenizer;
    this.tokens = tokens;
    this.tokenHandlers = tokenHandlers(schema2, tokens);
  }
  /**
  Parse a string as [CommonMark](http://commonmark.org/) markup,
  and create a ProseMirror document as prescribed by this parser's
  rules.
  
  The second argument, when given, is passed through to the
  [Markdown
  parser](https://markdown-it.github.io/markdown-it/#MarkdownIt.parse).
  */
  parse(text2, markdownEnv = {}) {
    let state = new MarkdownParseState(this.schema, this.tokenHandlers), doc2;
    state.parseTokens(this.tokenizer.parse(text2, markdownEnv));
    do {
      doc2 = state.closeNode();
    } while (state.stack.length);
    return doc2 || this.schema.topNodeType.createAndFill();
  }
};
function listIsTight(tokens, i2) {
  while (++i2 < tokens.length)
    if (tokens[i2].type != "list_item_open")
      return tokens[i2].hidden;
  return false;
}
__name(listIsTight, "listIsTight");
const defaultMarkdownParser = new MarkdownParser$1(schema, MarkdownIt("commonmark", { html: false }), {
  blockquote: { block: "blockquote" },
  paragraph: { block: "paragraph" },
  list_item: { block: "list_item" },
  bullet_list: { block: "bullet_list", getAttrs: /* @__PURE__ */ __name((_2, tokens, i2) => ({ tight: listIsTight(tokens, i2) }), "getAttrs") },
  ordered_list: { block: "ordered_list", getAttrs: /* @__PURE__ */ __name((tok, tokens, i2) => ({
    order: +tok.attrGet("start") || 1,
    tight: listIsTight(tokens, i2)
  }), "getAttrs") },
  heading: { block: "heading", getAttrs: /* @__PURE__ */ __name((tok) => ({ level: +tok.tag.slice(1) }), "getAttrs") },
  code_block: { block: "code_block", noCloseToken: true },
  fence: { block: "code_block", getAttrs: /* @__PURE__ */ __name((tok) => ({ params: tok.info || "" }), "getAttrs"), noCloseToken: true },
  hr: { node: "horizontal_rule" },
  image: { node: "image", getAttrs: /* @__PURE__ */ __name((tok) => ({
    src: tok.attrGet("src"),
    title: tok.attrGet("title") || null,
    alt: tok.children[0] && tok.children[0].content || null
  }), "getAttrs") },
  hardbreak: { node: "hard_break" },
  em: { mark: "em" },
  strong: { mark: "strong" },
  link: { mark: "link", getAttrs: /* @__PURE__ */ __name((tok) => ({
    href: tok.attrGet("href"),
    title: tok.attrGet("title") || null
  }), "getAttrs") },
  code_inline: { mark: "code", noCloseToken: true }
});
const blankMark = { open: "", close: "", mixable: true };
let MarkdownSerializer$1 = class MarkdownSerializer2 {
  static {
    __name(this, "MarkdownSerializer");
  }
  /**
  Construct a serializer with the given configuration. The `nodes`
  object should map node names in a given schema to function that
  take a serializer state and such a node, and serialize the node.
  */
  constructor(nodes, marks, options5 = {}) {
    this.nodes = nodes;
    this.marks = marks;
    this.options = options5;
  }
  /**
  Serialize the content of the given node to
  [CommonMark](http://commonmark.org/).
  */
  serialize(content3, options5 = {}) {
    options5 = Object.assign({}, this.options, options5);
    let state = new MarkdownSerializerState$1(this.nodes, this.marks, options5);
    state.renderContent(content3);
    return state.out;
  }
};
const defaultMarkdownSerializer = new MarkdownSerializer$1({
  blockquote(state, node3) {
    state.wrapBlock("> ", null, node3, () => state.renderContent(node3));
  },
  code_block(state, node3) {
    const backticks = node3.textContent.match(/`{3,}/gm);
    const fence2 = backticks ? backticks.sort().slice(-1)[0] + "`" : "```";
    state.write(fence2 + (node3.attrs.params || "") + "\n");
    state.text(node3.textContent, false);
    state.write("\n");
    state.write(fence2);
    state.closeBlock(node3);
  },
  heading(state, node3) {
    state.write(state.repeat("#", node3.attrs.level) + " ");
    state.renderInline(node3, false);
    state.closeBlock(node3);
  },
  horizontal_rule(state, node3) {
    state.write(node3.attrs.markup || "---");
    state.closeBlock(node3);
  },
  bullet_list(state, node3) {
    state.renderList(node3, "  ", () => (node3.attrs.bullet || "*") + " ");
  },
  ordered_list(state, node3) {
    let start2 = node3.attrs.order || 1;
    let maxW = String(start2 + node3.childCount - 1).length;
    let space = state.repeat(" ", maxW + 2);
    state.renderList(node3, space, (i2) => {
      let nStr = String(start2 + i2);
      return state.repeat(" ", maxW - nStr.length) + nStr + ". ";
    });
  },
  list_item(state, node3) {
    state.renderContent(node3);
  },
  paragraph(state, node3) {
    state.renderInline(node3);
    state.closeBlock(node3);
  },
  image(state, node3) {
    state.write("![" + state.esc(node3.attrs.alt || "") + "](" + node3.attrs.src.replace(/[\(\)]/g, "\\$&") + (node3.attrs.title ? ' "' + node3.attrs.title.replace(/"/g, '\\"') + '"' : "") + ")");
  },
  hard_break(state, node3, parent, index2) {
    for (let i2 = index2 + 1; i2 < parent.childCount; i2++)
      if (parent.child(i2).type != node3.type) {
        state.write("\\\n");
        return;
      }
  },
  text(state, node3) {
    state.text(node3.text, !state.inAutolink);
  }
}, {
  em: { open: "*", close: "*", mixable: true, expelEnclosingWhitespace: true },
  strong: { open: "**", close: "**", mixable: true, expelEnclosingWhitespace: true },
  link: {
    open(state, mark2, parent, index2) {
      state.inAutolink = isPlainURL(mark2, parent, index2);
      return state.inAutolink ? "<" : "[";
    },
    close(state, mark2, parent, index2) {
      let { inAutolink } = state;
      state.inAutolink = void 0;
      return inAutolink ? ">" : "](" + mark2.attrs.href.replace(/[\(\)"]/g, "\\$&") + (mark2.attrs.title ? ` "${mark2.attrs.title.replace(/"/g, '\\"')}"` : "") + ")";
    },
    mixable: true
  },
  code: {
    open(_state, _mark, parent, index2) {
      return backticksFor(parent.child(index2), -1);
    },
    close(_state, _mark, parent, index2) {
      return backticksFor(parent.child(index2 - 1), 1);
    },
    escape: false
  }
});
function backticksFor(node3, side) {
  let ticks = /`+/g, m2, len = 0;
  if (node3.isText)
    while (m2 = ticks.exec(node3.text))
      len = Math.max(len, m2[0].length);
  let result = len > 0 && side > 0 ? " `" : "`";
  for (let i2 = 0; i2 < len; i2++)
    result += "`";
  if (len > 0 && side < 0)
    result += " ";
  return result;
}
__name(backticksFor, "backticksFor");
function isPlainURL(link2, parent, index2) {
  if (link2.attrs.title || !/^\w+:/.test(link2.attrs.href))
    return false;
  let content3 = parent.child(index2);
  if (!content3.isText || content3.text != link2.attrs.href || content3.marks[content3.marks.length - 1] != link2)
    return false;
  return index2 == parent.childCount - 1 || !link2.isInSet(parent.child(index2 + 1).marks);
}
__name(isPlainURL, "isPlainURL");
let MarkdownSerializerState$1 = class MarkdownSerializerState2 {
  static {
    __name(this, "MarkdownSerializerState");
  }
  /**
  @internal
  */
  constructor(nodes, marks, options5) {
    this.nodes = nodes;
    this.marks = marks;
    this.options = options5;
    this.delim = "";
    this.out = "";
    this.closed = null;
    this.inAutolink = void 0;
    this.atBlockStart = false;
    this.inTightList = false;
    if (typeof this.options.tightLists == "undefined")
      this.options.tightLists = false;
    if (typeof this.options.hardBreakNodeName == "undefined")
      this.options.hardBreakNodeName = "hard_break";
  }
  /**
  @internal
  */
  flushClose(size = 2) {
    if (this.closed) {
      if (!this.atBlank())
        this.out += "\n";
      if (size > 1) {
        let delimMin = this.delim;
        let trim2 = /\s+$/.exec(delimMin);
        if (trim2)
          delimMin = delimMin.slice(0, delimMin.length - trim2[0].length);
        for (let i2 = 1; i2 < size; i2++)
          this.out += delimMin + "\n";
      }
      this.closed = null;
    }
  }
  /**
  @internal
  */
  getMark(name2) {
    let info = this.marks[name2];
    if (!info) {
      if (this.options.strict !== false)
        throw new Error(`Mark type \`${name2}\` not supported by Markdown renderer`);
      info = blankMark;
    }
    return info;
  }
  /**
  Render a block, prefixing each line with `delim`, and the first
  line in `firstDelim`. `node` should be the node that is closed at
  the end of the block, and `f` is a function that renders the
  content of the block.
  */
  wrapBlock(delim, firstDelim, node3, f2) {
    let old = this.delim;
    this.write(firstDelim != null ? firstDelim : delim);
    this.delim += delim;
    f2();
    this.delim = old;
    this.closeBlock(node3);
  }
  /**
  @internal
  */
  atBlank() {
    return /(^|\n)$/.test(this.out);
  }
  /**
  Ensure the current content ends with a newline.
  */
  ensureNewLine() {
    if (!this.atBlank())
      this.out += "\n";
  }
  /**
  Prepare the state for writing output (closing closed paragraphs,
  adding delimiters, and so on), and then optionally add content
  (unescaped) to the output.
  */
  write(content3) {
    this.flushClose();
    if (this.delim && this.atBlank())
      this.out += this.delim;
    if (content3)
      this.out += content3;
  }
  /**
  Close the block for the given node.
  */
  closeBlock(node3) {
    this.closed = node3;
  }
  /**
  Add the given text to the document. When escape is not `false`,
  it will be escaped.
  */
  text(text2, escape2 = true) {
    let lines = text2.split("\n");
    for (let i2 = 0; i2 < lines.length; i2++) {
      this.write();
      if (!escape2 && lines[i2][0] == "[" && /(^|[^\\])\!$/.test(this.out))
        this.out = this.out.slice(0, this.out.length - 1) + "\\!";
      this.out += escape2 ? this.esc(lines[i2], this.atBlockStart) : lines[i2];
      if (i2 != lines.length - 1)
        this.out += "\n";
    }
  }
  /**
  Render the given node as a block.
  */
  render(node3, parent, index2) {
    if (this.nodes[node3.type.name]) {
      this.nodes[node3.type.name](this, node3, parent, index2);
    } else {
      if (this.options.strict !== false) {
        throw new Error("Token type `" + node3.type.name + "` not supported by Markdown renderer");
      } else if (!node3.type.isLeaf) {
        if (node3.type.inlineContent)
          this.renderInline(node3);
        else
          this.renderContent(node3);
        if (node3.isBlock)
          this.closeBlock(node3);
      }
    }
  }
  /**
  Render the contents of `parent` as block nodes.
  */
  renderContent(parent) {
    parent.forEach((node3, _2, i2) => this.render(node3, parent, i2));
  }
  /**
  Render the contents of `parent` as inline content.
  */
  renderInline(parent, fromBlockStart = true) {
    this.atBlockStart = fromBlockStart;
    let active4 = [], trailing = "";
    let progress = /* @__PURE__ */ __name((node3, offset, index2) => {
      let marks = node3 ? node3.marks : [];
      if (node3 && node3.type.name === this.options.hardBreakNodeName)
        marks = marks.filter((m2) => {
          if (index2 + 1 == parent.childCount)
            return false;
          let next2 = parent.child(index2 + 1);
          return m2.isInSet(next2.marks) && (!next2.isText || /\S/.test(next2.text));
        });
      let leading = trailing;
      trailing = "";
      if (node3 && node3.isText && marks.some((mark2) => {
        let info = this.getMark(mark2.type.name);
        return info && info.expelEnclosingWhitespace && !mark2.isInSet(active4);
      })) {
        let [_2, lead, rest] = /^(\s*)(.*)$/m.exec(node3.text);
        if (lead) {
          leading += lead;
          node3 = rest ? node3.withText(rest) : null;
          if (!node3)
            marks = active4;
        }
      }
      if (node3 && node3.isText && marks.some((mark2) => {
        let info = this.getMark(mark2.type.name);
        return info && info.expelEnclosingWhitespace && (index2 == parent.childCount - 1 || !mark2.isInSet(parent.child(index2 + 1).marks));
      })) {
        let [_2, rest, trail] = /^(.*?)(\s*)$/m.exec(node3.text);
        if (trail) {
          trailing = trail;
          node3 = rest ? node3.withText(rest) : null;
          if (!node3)
            marks = active4;
        }
      }
      let inner = marks.length ? marks[marks.length - 1] : null;
      let noEsc = inner && this.getMark(inner.type.name).escape === false;
      let len = marks.length - (noEsc ? 1 : 0);
      outer: for (let i2 = 0; i2 < len; i2++) {
        let mark2 = marks[i2];
        if (!this.getMark(mark2.type.name).mixable)
          break;
        for (let j2 = 0; j2 < active4.length; j2++) {
          let other = active4[j2];
          if (!this.getMark(other.type.name).mixable)
            break;
          if (mark2.eq(other)) {
            if (i2 > j2)
              marks = marks.slice(0, j2).concat(mark2).concat(marks.slice(j2, i2)).concat(marks.slice(i2 + 1, len));
            else if (j2 > i2)
              marks = marks.slice(0, i2).concat(marks.slice(i2 + 1, j2)).concat(mark2).concat(marks.slice(j2, len));
            continue outer;
          }
        }
      }
      let keep = 0;
      while (keep < Math.min(active4.length, len) && marks[keep].eq(active4[keep]))
        ++keep;
      while (keep < active4.length)
        this.text(this.markString(active4.pop(), false, parent, index2), false);
      if (leading)
        this.text(leading);
      if (node3) {
        while (active4.length < len) {
          let add3 = marks[active4.length];
          active4.push(add3);
          this.text(this.markString(add3, true, parent, index2), false);
          this.atBlockStart = false;
        }
        if (noEsc && node3.isText)
          this.text(this.markString(inner, true, parent, index2) + node3.text + this.markString(inner, false, parent, index2 + 1), false);
        else
          this.render(node3, parent, index2);
        this.atBlockStart = false;
      }
      if ((node3 === null || node3 === void 0 ? void 0 : node3.isText) && node3.nodeSize > 0) {
        this.atBlockStart = false;
      }
    }, "progress");
    parent.forEach(progress);
    progress(null, 0, parent.childCount);
    this.atBlockStart = false;
  }
  /**
  Render a node's content as a list. `delim` should be the extra
  indentation added to all lines except the first in an item,
  `firstDelim` is a function going from an item index to a
  delimiter for the first line of the item.
  */
  renderList(node3, delim, firstDelim) {
    if (this.closed && this.closed.type == node3.type)
      this.flushClose(3);
    else if (this.inTightList)
      this.flushClose(1);
    let isTight = typeof node3.attrs.tight != "undefined" ? node3.attrs.tight : this.options.tightLists;
    let prevTight = this.inTightList;
    this.inTightList = isTight;
    node3.forEach((child, _2, i2) => {
      if (i2 && isTight)
        this.flushClose(1);
      this.wrapBlock(delim, firstDelim(i2), node3, () => this.render(child, node3, i2));
    });
    this.inTightList = prevTight;
  }
  /**
  Escape the given string so that it can safely appear in Markdown
  content. If `startOfLine` is true, also escape characters that
  have special meaning only at the start of the line.
  */
  esc(str, startOfLine = false) {
    str = str.replace(/[`*\\~\[\]_]/g, (m2, i2) => m2 == "_" && i2 > 0 && i2 + 1 < str.length && str[i2 - 1].match(/\w/) && str[i2 + 1].match(/\w/) ? m2 : "\\" + m2);
    if (startOfLine)
      str = str.replace(/^(\+[ ]|[\-*>])/, "\\$&").replace(/^(\s*)(#{1,6})(\s|$)/, "$1\\$2$3").replace(/^(\s*\d+)\.\s/, "$1\\. ");
    if (this.options.escapeExtraCharacters)
      str = str.replace(this.options.escapeExtraCharacters, "\\$&");
    return str;
  }
  /**
  @internal
  */
  quote(str) {
    let wrap2 = str.indexOf('"') == -1 ? '""' : str.indexOf("'") == -1 ? "''" : "()";
    return wrap2[0] + str + wrap2[1];
  }
  /**
  Repeat the given string `n` times.
  */
  repeat(str, n2) {
    let out = "";
    for (let i2 = 0; i2 < n2; i2++)
      out += str;
    return out;
  }
  /**
  Get the markdown string for a given opening or closing mark.
  */
  markString(mark2, open2, parent, index2) {
    let info = this.getMark(mark2.type.name);
    let value3 = open2 ? info.open : info.close;
    return typeof value3 == "string" ? value3 : value3(this, mark2, parent, index2);
  }
  /**
  Get leading and trailing whitespace from a string. Values of
  leading or trailing property of the return object will be undefined
  if there is no match.
  */
  getEnclosingWhitespace(text2) {
    return {
      leading: (text2.match(/^(\s+)/) || [void 0])[0],
      trailing: (text2.match(/(\s+)$/) || [void 0])[0]
    };
  }
};
var disableCheckboxes = true;
var useLabelWrapper = false;
var useLabelAfter = false;
var markdownItTaskLists = /* @__PURE__ */ __name(function(md2, options5) {
  if (options5) {
    disableCheckboxes = !options5.enabled;
    useLabelWrapper = !!options5.label;
    useLabelAfter = !!options5.labelAfter;
  }
  md2.core.ruler.after("inline", "github-task-lists", function(state) {
    var tokens = state.tokens;
    for (var i2 = 2; i2 < tokens.length; i2++) {
      if (isTodoItem(tokens, i2)) {
        todoify(tokens[i2], state.Token);
        attrSet(tokens[i2 - 2], "class", "task-list-item" + (!disableCheckboxes ? " enabled" : ""));
        attrSet(tokens[parentToken(tokens, i2 - 2)], "class", "contains-task-list");
      }
    }
  });
}, "markdownItTaskLists");
function attrSet(token, name2, value3) {
  var index2 = token.attrIndex(name2);
  var attr = [name2, value3];
  if (index2 < 0) {
    token.attrPush(attr);
  } else {
    token.attrs[index2] = attr;
  }
}
__name(attrSet, "attrSet");
function parentToken(tokens, index2) {
  var targetLevel = tokens[index2].level - 1;
  for (var i2 = index2 - 1; i2 >= 0; i2--) {
    if (tokens[i2].level === targetLevel) {
      return i2;
    }
  }
  return -1;
}
__name(parentToken, "parentToken");
function isTodoItem(tokens, index2) {
  return isInline(tokens[index2]) && isParagraph(tokens[index2 - 1]) && isListItem(tokens[index2 - 2]) && startsWithTodoMarkdown(tokens[index2]);
}
__name(isTodoItem, "isTodoItem");
function todoify(token, TokenConstructor) {
  token.children.unshift(makeCheckbox(token, TokenConstructor));
  token.children[1].content = token.children[1].content.slice(3);
  token.content = token.content.slice(3);
  if (useLabelWrapper) {
    if (useLabelAfter) {
      token.children.pop();
      var id4 = "task-item-" + Math.ceil(Math.random() * (1e4 * 1e3) - 1e3);
      token.children[0].content = token.children[0].content.slice(0, -1) + ' id="' + id4 + '">';
      token.children.push(afterLabel(token.content, id4, TokenConstructor));
    } else {
      token.children.unshift(beginLabel(TokenConstructor));
      token.children.push(endLabel(TokenConstructor));
    }
  }
}
__name(todoify, "todoify");
function makeCheckbox(token, TokenConstructor) {
  var checkbox = new TokenConstructor("html_inline", "", 0);
  var disabledAttr = disableCheckboxes ? ' disabled="" ' : "";
  if (token.content.indexOf("[ ] ") === 0) {
    checkbox.content = '<input class="task-list-item-checkbox"' + disabledAttr + 'type="checkbox">';
  } else if (token.content.indexOf("[x] ") === 0 || token.content.indexOf("[X] ") === 0) {
    checkbox.content = '<input class="task-list-item-checkbox" checked=""' + disabledAttr + 'type="checkbox">';
  }
  return checkbox;
}
__name(makeCheckbox, "makeCheckbox");
function beginLabel(TokenConstructor) {
  var token = new TokenConstructor("html_inline", "", 0);
  token.content = "<label>";
  return token;
}
__name(beginLabel, "beginLabel");
function endLabel(TokenConstructor) {
  var token = new TokenConstructor("html_inline", "", 0);
  token.content = "</label>";
  return token;
}
__name(endLabel, "endLabel");
function afterLabel(content3, id4, TokenConstructor) {
  var token = new TokenConstructor("html_inline", "", 0);
  token.content = '<label class="task-list-item-label" for="' + id4 + '">' + content3 + "</label>";
  token.attrs = [{ for: id4 }];
  return token;
}
__name(afterLabel, "afterLabel");
function isInline(token) {
  return token.type === "inline";
}
__name(isInline, "isInline");
function isParagraph(token) {
  return token.type === "paragraph_open";
}
__name(isParagraph, "isParagraph");
function isListItem(token) {
  return token.type === "list_item_open";
}
__name(isListItem, "isListItem");
function startsWithTodoMarkdown(token) {
  return token.content.indexOf("[ ] ") === 0 || token.content.indexOf("[x] ") === 0 || token.content.indexOf("[X] ") === 0;
}
__name(startsWithTodoMarkdown, "startsWithTodoMarkdown");
const taskListPlugin = /* @__PURE__ */ getDefaultExportFromCjs(markdownItTaskLists);
var __defProp = Object.defineProperty;
var __defNormalProp = /* @__PURE__ */ __name((obj, key, value3) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value: value3 }) : obj[key] = value3, "__defNormalProp");
var __publicField = /* @__PURE__ */ __name((obj, key, value3) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value3);
  return value3;
}, "__publicField");
const MarkdownTightLists = Extension.create({
  name: "markdownTightLists",
  addOptions: /* @__PURE__ */ __name(() => ({
    tight: true,
    tightClass: "tight",
    listTypes: ["bulletList", "orderedList"]
  }), "addOptions"),
  addGlobalAttributes() {
    return [{
      types: this.options.listTypes,
      attributes: {
        tight: {
          default: this.options.tight,
          parseHTML: /* @__PURE__ */ __name((element) => element.getAttribute("data-tight") === "true" || !element.querySelector("p"), "parseHTML"),
          renderHTML: /* @__PURE__ */ __name((attributes) => ({
            class: attributes.tight ? this.options.tightClass : null,
            "data-tight": attributes.tight ? "true" : null
          }), "renderHTML")
        }
      }
    }];
  },
  addCommands() {
    var _this = this;
    return {
      toggleTight: /* @__PURE__ */ __name(function() {
        let tight = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : null;
        return (_ref) => {
          let {
            editor,
            commands: commands2
          } = _ref;
          function toggleTight(name2) {
            if (!editor.isActive(name2)) {
              return false;
            }
            const attrs7 = editor.getAttributes(name2);
            return commands2.updateAttributes(name2, {
              tight: tight !== null && tight !== void 0 ? tight : !(attrs7 !== null && attrs7 !== void 0 && attrs7.tight)
            });
          }
          __name(toggleTight, "toggleTight");
          return _this.options.listTypes.some((name2) => toggleTight(name2));
        };
      }, "toggleTight")
    };
  }
});
const md = MarkdownIt();
function scanDelims(text2, pos) {
  md.inline.State.prototype.scanDelims.call({
    src: text2,
    posMax: text2.length
  });
  const state = new md.inline.State(text2, null, null, []);
  return state.scanDelims(pos, true);
}
__name(scanDelims, "scanDelims");
function shiftDelim(text2, delim, start2, offset) {
  let res = text2.substring(0, start2) + text2.substring(start2 + delim.length);
  res = res.substring(0, start2 + offset) + delim + res.substring(start2 + offset);
  return res;
}
__name(shiftDelim, "shiftDelim");
function trimStart(text2, delim, from2, to) {
  let pos = from2, res = text2;
  while (pos < to) {
    if (scanDelims(res, pos).can_open) {
      break;
    }
    res = shiftDelim(res, delim, pos, 1);
    pos++;
  }
  return {
    text: res,
    from: pos,
    to
  };
}
__name(trimStart, "trimStart");
function trimEnd(text2, delim, from2, to) {
  let pos = to, res = text2;
  while (pos > from2) {
    if (scanDelims(res, pos).can_close) {
      break;
    }
    res = shiftDelim(res, delim, pos, -1);
    pos--;
  }
  return {
    text: res,
    from: from2,
    to: pos
  };
}
__name(trimEnd, "trimEnd");
function trimInline(text2, delim, from2, to) {
  let state = {
    text: text2,
    from: from2,
    to
  };
  state = trimStart(state.text, delim, state.from, state.to);
  state = trimEnd(state.text, delim, state.from, state.to);
  if (state.to - state.from < delim.length + 1) {
    state.text = state.text.substring(0, state.from) + state.text.substring(state.to + delim.length);
  }
  return state.text;
}
__name(trimInline, "trimInline");
class MarkdownSerializerState extends MarkdownSerializerState$1 {
  static {
    __name(this, "MarkdownSerializerState");
  }
  constructor(nodes, marks, options5) {
    super(nodes, marks, options5 !== null && options5 !== void 0 ? options5 : {});
    __publicField(this, "inTable", false);
    this.inlines = [];
  }
  render(node3, parent, index2) {
    super.render(node3, parent, index2);
    const top = this.inlines[this.inlines.length - 1];
    if (top !== null && top !== void 0 && top.start && top !== null && top !== void 0 && top.end) {
      const {
        delimiter: delimiter2,
        start: start2,
        end
      } = this.normalizeInline(top);
      this.out = trimInline(this.out, delimiter2, start2, end);
      this.inlines.pop();
    }
  }
  markString(mark2, open2, parent, index2) {
    const info = this.marks[mark2.type.name];
    if (info.expelEnclosingWhitespace) {
      if (open2) {
        this.inlines.push({
          start: this.out.length,
          delimiter: info.open
        });
      } else {
        const top = this.inlines.pop();
        this.inlines.push({
          ...top,
          end: this.out.length
        });
      }
    }
    return super.markString(mark2, open2, parent, index2);
  }
  normalizeInline(inline3) {
    let {
      start: start2,
      end
    } = inline3;
    while (this.out.charAt(start2).match(/\s/)) {
      start2++;
    }
    return {
      ...inline3,
      start: start2
    };
  }
}
const HTMLMark = Mark.create({
  name: "markdownHTMLMark",
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: {
          open(state, mark2) {
            var _getMarkTags$, _getMarkTags;
            if (!this.editor.storage.markdown.options.html) {
              console.warn(`Tiptap Markdown: "${mark2.type.name}" mark is only available in html mode`);
              return "";
            }
            return (_getMarkTags$ = (_getMarkTags = getMarkTags(mark2)) === null || _getMarkTags === void 0 ? void 0 : _getMarkTags[0]) !== null && _getMarkTags$ !== void 0 ? _getMarkTags$ : "";
          },
          close(state, mark2) {
            var _getMarkTags$2, _getMarkTags2;
            if (!this.editor.storage.markdown.options.html) {
              return "";
            }
            return (_getMarkTags$2 = (_getMarkTags2 = getMarkTags(mark2)) === null || _getMarkTags2 === void 0 ? void 0 : _getMarkTags2[1]) !== null && _getMarkTags$2 !== void 0 ? _getMarkTags$2 : "";
          }
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
function getMarkTags(mark2) {
  const schema2 = mark2.type.schema;
  const node3 = schema2.text(" ", [mark2]);
  const html = getHTMLFromFragment(Fragment.from(node3), schema2);
  const match2 = html.match(/^(<.*?>) (<\/.*?>)$/);
  return match2 ? [match2[1], match2[2]] : null;
}
__name(getMarkTags, "getMarkTags");
function elementFromString(value3) {
  const wrappedValue = `<body>${value3}</body>`;
  return new window.DOMParser().parseFromString(wrappedValue, "text/html").body;
}
__name(elementFromString, "elementFromString");
function escapeHTML(value3) {
  return value3 === null || value3 === void 0 ? void 0 : value3.replace(/</g, "&lt;").replace(/>/g, "&gt;");
}
__name(escapeHTML, "escapeHTML");
function extractElement(node3) {
  const parent = node3.parentElement;
  const prepend2 = parent.cloneNode();
  while (parent.firstChild && parent.firstChild !== node3) {
    prepend2.appendChild(parent.firstChild);
  }
  if (prepend2.childNodes.length > 0) {
    parent.parentElement.insertBefore(prepend2, parent);
  }
  parent.parentElement.insertBefore(node3, parent);
  if (parent.childNodes.length === 0) {
    parent.remove();
  }
}
__name(extractElement, "extractElement");
function unwrapElement(node3) {
  const parent = node3.parentNode;
  while (node3.firstChild)
    parent.insertBefore(node3.firstChild, node3);
  parent.removeChild(node3);
}
__name(unwrapElement, "unwrapElement");
const HTMLNode = Node$1.create({
  name: "markdownHTMLNode",
  addStorage() {
    return {
      markdown: {
        serialize(state, node3, parent) {
          if (this.editor.storage.markdown.options.html) {
            state.write(serializeHTML(node3, parent));
          } else {
            console.warn(`Tiptap Markdown: "${node3.type.name}" node is only available in html mode`);
            state.write(`[${node3.type.name}]`);
          }
          if (node3.isBlock) {
            state.closeBlock(node3);
          }
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
function serializeHTML(node3, parent) {
  const schema2 = node3.type.schema;
  const html = getHTMLFromFragment(Fragment.from(node3), schema2);
  if (node3.isBlock && (parent instanceof Fragment || parent.type.name === schema2.topNodeType.name)) {
    return formatBlock(html);
  }
  return html;
}
__name(serializeHTML, "serializeHTML");
function formatBlock(html) {
  const dom = elementFromString(html);
  const element = dom.firstElementChild;
  element.innerHTML = element.innerHTML.trim() ? `
${element.innerHTML}
` : `
`;
  return element.outerHTML;
}
__name(formatBlock, "formatBlock");
const Blockquote = Node$1.create({
  name: "blockquote"
});
const Blockquote$1 = Blockquote.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.blockquote,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const BulletList = Node$1.create({
  name: "bulletList"
});
const BulletList$1 = BulletList.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3) {
          return state.renderList(node3, "  ", () => (this.editor.storage.markdown.options.bulletListMarker || "-") + " ");
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const CodeBlock = Node$1.create({
  name: "codeBlock"
});
const CodeBlock$1 = CodeBlock.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3) {
          state.write("```" + (node3.attrs.language || "") + "\n");
          state.text(node3.textContent, false);
          state.ensureNewLine();
          state.write("```");
          state.closeBlock(node3);
        },
        parse: {
          setup(markdownit2) {
            var _this$options$languag;
            markdownit2.set({
              langPrefix: (_this$options$languag = this.options.languageClassPrefix) !== null && _this$options$languag !== void 0 ? _this$options$languag : "language-"
            });
          },
          updateDOM(element) {
            element.innerHTML = element.innerHTML.replace(/\n<\/code><\/pre>/g, "</code></pre>");
          }
        }
      }
    };
  }
});
const HardBreak = Node$1.create({
  name: "hardBreak"
});
const HardBreak$1 = HardBreak.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3, parent, index2) {
          for (let i2 = index2 + 1; i2 < parent.childCount; i2++)
            if (parent.child(i2).type != node3.type) {
              state.write(state.inTable ? HTMLNode.storage.markdown.serialize.call(this, state, node3, parent) : "\\\n");
              return;
            }
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Heading = Node$1.create({
  name: "heading"
});
const Heading$1 = Heading.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.heading,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const HorizontalRule = Node$1.create({
  name: "horizontalRule"
});
const HorizontalRule$1 = HorizontalRule.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.horizontal_rule,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Image$1 = Node$1.create({
  name: "image"
});
const Image$1$1 = Image$1.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.image,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const ListItem = Node$1.create({
  name: "listItem"
});
const ListItem$1 = ListItem.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.list_item,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const OrderedList = Node$1.create({
  name: "orderedList"
});
function findIndexOfAdjacentNode(node3, parent, index2) {
  let i2 = 0;
  for (; index2 - i2 > 0; i2++) {
    if (parent.child(index2 - i2 - 1).type.name !== node3.type.name) {
      break;
    }
  }
  return i2;
}
__name(findIndexOfAdjacentNode, "findIndexOfAdjacentNode");
const OrderedList$1 = OrderedList.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3, parent, index2) {
          const start2 = node3.attrs.start || 1;
          const maxW = String(start2 + node3.childCount - 1).length;
          const space = state.repeat(" ", maxW + 2);
          const adjacentIndex = findIndexOfAdjacentNode(node3, parent, index2);
          const separator = adjacentIndex % 2 ? ") " : ". ";
          state.renderList(node3, space, (i2) => {
            const nStr = String(start2 + i2);
            return state.repeat(" ", maxW - nStr.length) + nStr + separator;
          });
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Paragraph = Node$1.create({
  name: "paragraph"
});
const Paragraph$1 = Paragraph.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.nodes.paragraph,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
function childNodes(node3) {
  var _node$content$content, _node$content;
  return (_node$content$content = node3 === null || node3 === void 0 || (_node$content = node3.content) === null || _node$content === void 0 ? void 0 : _node$content.content) !== null && _node$content$content !== void 0 ? _node$content$content : [];
}
__name(childNodes, "childNodes");
const Table = Node$1.create({
  name: "table"
});
const Table$1 = Table.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3, parent) {
          if (!isMarkdownSerializable(node3)) {
            HTMLNode.storage.markdown.serialize.call(this, state, node3, parent);
            return;
          }
          state.inTable = true;
          node3.forEach((row, p2, i2) => {
            state.write("| ");
            row.forEach((col, p22, j2) => {
              if (j2) {
                state.write(" | ");
              }
              const cellContent = col.firstChild;
              if (cellContent.textContent.trim()) {
                state.renderInline(cellContent);
              }
            });
            state.write(" |");
            state.ensureNewLine();
            if (!i2) {
              const delimiterRow = Array.from({
                length: row.childCount
              }).map(() => "---").join(" | ");
              state.write(`| ${delimiterRow} |`);
              state.ensureNewLine();
            }
          });
          state.closeBlock(node3);
          state.inTable = false;
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
function hasSpan(node3) {
  return node3.attrs.colspan > 1 || node3.attrs.rowspan > 1;
}
__name(hasSpan, "hasSpan");
function isMarkdownSerializable(node3) {
  const rows = childNodes(node3);
  const firstRow = rows[0];
  const bodyRows = rows.slice(1);
  if (childNodes(firstRow).some((cell) => cell.type.name !== "tableHeader" || hasSpan(cell) || cell.childCount > 1)) {
    return false;
  }
  if (bodyRows.some((row) => childNodes(row).some((cell) => cell.type.name === "tableHeader" || hasSpan(cell) || cell.childCount > 1))) {
    return false;
  }
  return true;
}
__name(isMarkdownSerializable, "isMarkdownSerializable");
const TaskItem$1 = Node$1.create({
  name: "taskItem"
});
const TaskItem$1$1 = TaskItem$1.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3) {
          const check = node3.attrs.checked ? "[x]" : "[ ]";
          state.write(`${check} `);
          state.renderContent(node3);
        },
        parse: {
          updateDOM(element) {
            [...element.querySelectorAll(".task-list-item")].forEach((item3) => {
              const input = item3.querySelector("input");
              item3.setAttribute("data-type", "taskItem");
              if (input) {
                item3.setAttribute("data-checked", input.checked);
                input.remove();
              }
            });
          }
        }
      }
    };
  }
});
const TaskList = Node$1.create({
  name: "taskList"
});
const TaskList$1 = TaskList.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: BulletList$1.storage.markdown.serialize,
        parse: {
          setup(markdownit2) {
            markdownit2.use(taskListPlugin);
          },
          updateDOM(element) {
            [...element.querySelectorAll(".contains-task-list")].forEach((list2) => {
              list2.setAttribute("data-type", "taskList");
            });
          }
        }
      }
    };
  }
});
const Text$1 = Node$1.create({
  name: "text"
});
const Text$1$1 = Text$1.extend({
  /**
   * @return {{markdown: MarkdownNodeSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize(state, node3) {
          state.text(escapeHTML(node3.text));
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Bold = Mark.create({
  name: "bold"
});
const Bold$1 = Bold.extend({
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.marks.strong,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Code = Mark.create({
  name: "code"
});
const Code$1 = Code.extend({
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.marks.code,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Italic = Mark.create({
  name: "italic"
});
const Italic$1 = Italic.extend({
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.marks.em,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Link = Mark.create({
  name: "link"
});
const Link$1 = Link.extend({
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: defaultMarkdownSerializer.marks.link,
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const Strike = Mark.create({
  name: "strike"
});
const Strike$1 = Strike.extend({
  /**
   * @return {{markdown: MarkdownMarkSpec}}
   */
  addStorage() {
    return {
      markdown: {
        serialize: {
          open: "~~",
          close: "~~",
          expelEnclosingWhitespace: true
        },
        parse: {
          // handled by markdown-it
        }
      }
    };
  }
});
const markdownExtensions = [Blockquote$1, BulletList$1, CodeBlock$1, HardBreak$1, Heading$1, HorizontalRule$1, HTMLNode, Image$1$1, ListItem$1, OrderedList$1, Paragraph$1, Table$1, TaskItem$1$1, TaskList$1, Text$1$1, Bold$1, Code$1, HTMLMark, Italic$1, Link$1, Strike$1];
function getMarkdownSpec(extension) {
  var _extension$storage, _markdownExtensions$f;
  const markdownSpec = (_extension$storage = extension.storage) === null || _extension$storage === void 0 ? void 0 : _extension$storage.markdown;
  const defaultMarkdownSpec = (_markdownExtensions$f = markdownExtensions.find((e2) => e2.name === extension.name)) === null || _markdownExtensions$f === void 0 ? void 0 : _markdownExtensions$f.storage.markdown;
  if (markdownSpec || defaultMarkdownSpec) {
    return {
      ...defaultMarkdownSpec,
      ...markdownSpec
    };
  }
  return null;
}
__name(getMarkdownSpec, "getMarkdownSpec");
class MarkdownSerializer {
  static {
    __name(this, "MarkdownSerializer");
  }
  constructor(editor) {
    __publicField(this, "editor", null);
    this.editor = editor;
  }
  serialize(content3) {
    const state = new MarkdownSerializerState(this.nodes, this.marks, {
      hardBreakNodeName: HardBreak$1.name
    });
    state.renderContent(content3);
    return state.out;
  }
  get nodes() {
    var _this$editor$extensio;
    return {
      ...Object.fromEntries(Object.keys(this.editor.schema.nodes).map((name2) => [name2, this.serializeNode(HTMLNode)])),
      ...Object.fromEntries((_this$editor$extensio = this.editor.extensionManager.extensions.filter((extension) => extension.type === "node" && this.serializeNode(extension)).map((extension) => [extension.name, this.serializeNode(extension)])) !== null && _this$editor$extensio !== void 0 ? _this$editor$extensio : [])
    };
  }
  get marks() {
    var _this$editor$extensio2;
    return {
      ...Object.fromEntries(Object.keys(this.editor.schema.marks).map((name2) => [name2, this.serializeMark(HTMLMark)])),
      ...Object.fromEntries((_this$editor$extensio2 = this.editor.extensionManager.extensions.filter((extension) => extension.type === "mark" && this.serializeMark(extension)).map((extension) => [extension.name, this.serializeMark(extension)])) !== null && _this$editor$extensio2 !== void 0 ? _this$editor$extensio2 : [])
    };
  }
  serializeNode(node3) {
    var _getMarkdownSpec;
    return (_getMarkdownSpec = getMarkdownSpec(node3)) === null || _getMarkdownSpec === void 0 || (_getMarkdownSpec = _getMarkdownSpec.serialize) === null || _getMarkdownSpec === void 0 ? void 0 : _getMarkdownSpec.bind({
      editor: this.editor,
      options: node3.options
    });
  }
  serializeMark(mark2) {
    var _getMarkdownSpec2;
    const serialize = (_getMarkdownSpec2 = getMarkdownSpec(mark2)) === null || _getMarkdownSpec2 === void 0 ? void 0 : _getMarkdownSpec2.serialize;
    return serialize ? {
      ...serialize,
      open: typeof serialize.open === "function" ? serialize.open.bind({
        editor: this.editor,
        options: mark2.options
      }) : serialize.open,
      close: typeof serialize.close === "function" ? serialize.close.bind({
        editor: this.editor,
        options: mark2.options
      }) : serialize.close
    } : null;
  }
}
class MarkdownParser {
  static {
    __name(this, "MarkdownParser");
  }
  constructor(editor, _ref) {
    __publicField(this, "editor", null);
    __publicField(this, "md", null);
    let {
      html,
      linkify: linkify2,
      breaks
    } = _ref;
    this.editor = editor;
    this.md = this.withPatchedRenderer(MarkdownIt({
      html,
      linkify: linkify2,
      breaks
    }));
  }
  parse(content3) {
    let {
      inline: inline3
    } = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (typeof content3 === "string") {
      this.editor.extensionManager.extensions.forEach((extension) => {
        var _getMarkdownSpec;
        return (_getMarkdownSpec = getMarkdownSpec(extension)) === null || _getMarkdownSpec === void 0 || (_getMarkdownSpec = _getMarkdownSpec.parse) === null || _getMarkdownSpec === void 0 || (_getMarkdownSpec = _getMarkdownSpec.setup) === null || _getMarkdownSpec === void 0 ? void 0 : _getMarkdownSpec.call({
          editor: this.editor,
          options: extension.options
        }, this.md);
      });
      const renderedHTML = this.md.render(content3);
      const element = elementFromString(renderedHTML);
      this.editor.extensionManager.extensions.forEach((extension) => {
        var _getMarkdownSpec2;
        return (_getMarkdownSpec2 = getMarkdownSpec(extension)) === null || _getMarkdownSpec2 === void 0 || (_getMarkdownSpec2 = _getMarkdownSpec2.parse) === null || _getMarkdownSpec2 === void 0 || (_getMarkdownSpec2 = _getMarkdownSpec2.updateDOM) === null || _getMarkdownSpec2 === void 0 ? void 0 : _getMarkdownSpec2.call({
          editor: this.editor,
          options: extension.options
        }, element);
      });
      this.normalizeDOM(element, {
        inline: inline3,
        content: content3
      });
      return element.innerHTML;
    }
    return content3;
  }
  normalizeDOM(node3, _ref2) {
    let {
      inline: inline3,
      content: content3
    } = _ref2;
    this.normalizeBlocks(node3);
    node3.querySelectorAll("*").forEach((el) => {
      var _el$nextSibling;
      if (((_el$nextSibling = el.nextSibling) === null || _el$nextSibling === void 0 ? void 0 : _el$nextSibling.nodeType) === Node.TEXT_NODE && !el.closest("pre")) {
        el.nextSibling.textContent = el.nextSibling.textContent.replace(/^\n/, "");
      }
    });
    if (inline3) {
      this.normalizeInline(node3, content3);
    }
    return node3;
  }
  normalizeBlocks(node3) {
    const blocks = Object.values(this.editor.schema.nodes).filter((node22) => node22.isBlock);
    const selector = blocks.map((block3) => {
      var _block$spec$parseDOM;
      return (_block$spec$parseDOM = block3.spec.parseDOM) === null || _block$spec$parseDOM === void 0 ? void 0 : _block$spec$parseDOM.map((spec) => spec.tag);
    }).flat().filter(Boolean).join(",");
    if (!selector) {
      return;
    }
    [...node3.querySelectorAll(selector)].forEach((el) => {
      if (el.parentElement.matches("p")) {
        extractElement(el);
      }
    });
  }
  normalizeInline(node3, content3) {
    var _node$firstElementChi;
    if ((_node$firstElementChi = node3.firstElementChild) !== null && _node$firstElementChi !== void 0 && _node$firstElementChi.matches("p")) {
      var _content$match$, _content$match, _content$match$2, _content$match2;
      const firstParagraph = node3.firstElementChild;
      const {
        nextElementSibling
      } = firstParagraph;
      const startSpaces = (_content$match$ = (_content$match = content3.match(/^\s+/)) === null || _content$match === void 0 ? void 0 : _content$match[0]) !== null && _content$match$ !== void 0 ? _content$match$ : "";
      const endSpaces = !nextElementSibling ? (_content$match$2 = (_content$match2 = content3.match(/\s+$/)) === null || _content$match2 === void 0 ? void 0 : _content$match2[0]) !== null && _content$match$2 !== void 0 ? _content$match$2 : "" : "";
      if (content3.match(/^\n\n/)) {
        firstParagraph.innerHTML = `${firstParagraph.innerHTML}${endSpaces}`;
        return;
      }
      unwrapElement(firstParagraph);
      node3.innerHTML = `${startSpaces}${node3.innerHTML}${endSpaces}`;
    }
  }
  /**
   * @param {markdownit} md
   */
  withPatchedRenderer(md2) {
    const withoutNewLine = /* @__PURE__ */ __name((renderer2) => function() {
      const rendered = renderer2(...arguments);
      if (rendered === "\n") {
        return rendered;
      }
      if (rendered[rendered.length - 1] === "\n") {
        return rendered.slice(0, -1);
      }
      return rendered;
    }, "withoutNewLine");
    md2.renderer.rules.hardbreak = withoutNewLine(md2.renderer.rules.hardbreak);
    md2.renderer.rules.softbreak = withoutNewLine(md2.renderer.rules.softbreak);
    md2.renderer.rules.fence = withoutNewLine(md2.renderer.rules.fence);
    md2.renderer.rules.code_block = withoutNewLine(md2.renderer.rules.code_block);
    md2.renderer.renderToken = withoutNewLine(md2.renderer.renderToken.bind(md2.renderer));
    return md2;
  }
}
const MarkdownClipboard = Extension.create({
  name: "markdownClipboard",
  addOptions() {
    return {
      transformPastedText: false,
      transformCopiedText: false
    };
  },
  addProseMirrorPlugins() {
    return [new Plugin({
      key: new PluginKey("markdownClipboard"),
      props: {
        clipboardTextParser: /* @__PURE__ */ __name((text2, context, plainText) => {
          if (plainText || !this.options.transformPastedText) {
            return null;
          }
          const parsed = this.editor.storage.markdown.parser.parse(text2, {
            inline: true
          });
          return DOMParser.fromSchema(this.editor.schema).parseSlice(elementFromString(parsed), {
            preserveWhitespace: true,
            context
          });
        }, "clipboardTextParser"),
        /**
         * @param {import('prosemirror-model').Slice} slice
         */
        clipboardTextSerializer: /* @__PURE__ */ __name((slice2) => {
          if (!this.options.transformCopiedText) {
            return null;
          }
          return this.editor.storage.markdown.serializer.serialize(slice2.content);
        }, "clipboardTextSerializer")
      }
    })];
  }
});
const Markdown = Extension.create({
  name: "markdown",
  priority: 50,
  addOptions() {
    return {
      html: true,
      tightLists: true,
      tightListClass: "tight",
      bulletListMarker: "-",
      linkify: false,
      breaks: false,
      transformPastedText: false,
      transformCopiedText: false
    };
  },
  addCommands() {
    const commands2 = index$1.Commands.config.addCommands();
    return {
      setContent: /* @__PURE__ */ __name((content3, emitUpdate, parseOptions) => (props) => {
        return commands2.setContent(props.editor.storage.markdown.parser.parse(content3), emitUpdate, parseOptions)(props);
      }, "setContent"),
      insertContentAt: /* @__PURE__ */ __name((range2, content3, options5) => (props) => {
        return commands2.insertContentAt(range2, props.editor.storage.markdown.parser.parse(content3, {
          inline: true
        }), options5)(props);
      }, "insertContentAt")
    };
  },
  onBeforeCreate() {
    this.editor.storage.markdown = {
      options: {
        ...this.options
      },
      parser: new MarkdownParser(this.editor, this.options),
      serializer: new MarkdownSerializer(this.editor),
      getMarkdown: /* @__PURE__ */ __name(() => {
        return this.editor.storage.markdown.serializer.serialize(this.editor.state.doc);
      }, "getMarkdown")
    };
    this.editor.options.initialContent = this.editor.options.content;
    this.editor.options.content = this.editor.storage.markdown.parser.parse(this.editor.options.content);
  },
  onCreate() {
    this.editor.options.content = this.editor.options.initialContent;
    delete this.editor.options.initialContent;
  },
  addStorage() {
    return {
      /// storage will be defined in onBeforeCreate() to prevent initial object overriding
    };
  },
  addExtensions() {
    return [MarkdownTightLists.configure({
      tight: this.options.tightLists,
      tightClass: this.options.tightListClass
    }), MarkdownClipboard.configure({
      transformPastedText: this.options.transformPastedText,
      transformCopiedText: this.options.transformCopiedText
    })];
  }
});
function addMarkdownWidget(node3, name2, opts) {
  Markdown.configure({
    html: false,
    breaks: true,
    transformPastedText: true
  });
  const editor = new Editor({
    extensions: [
      StarterKit,
      Markdown,
      Link$2,
      Table$2,
      TableCell,
      TableHeader,
      TableRow
    ],
    content: opts.defaultVal,
    editable: false
  });
  const inputEl = editor.options.element;
  inputEl.classList.add("comfy-markdown");
  const textarea = document.createElement("textarea");
  inputEl.append(textarea);
  const widget = node3.addDOMWidget(name2, "MARKDOWN", inputEl, {
    getValue() {
      return textarea.value;
    },
    setValue(v2) {
      textarea.value = v2;
      editor.commands.setContent(v2);
    }
  });
  widget.inputEl = inputEl;
  widget.options.minNodeSize = [400, 200];
  inputEl.addEventListener("pointerdown", (event) => {
    if (event.button !== 0) {
      app$2.canvas.processMouseDown(event);
      return;
    }
    if (event.target instanceof HTMLAnchorElement) {
      return;
    }
    inputEl.classList.add("editing");
    setTimeout(() => {
      textarea.focus();
    }, 0);
  });
  textarea.addEventListener("blur", () => {
    inputEl.classList.remove("editing");
  });
  textarea.addEventListener("change", () => {
    editor.commands.setContent(textarea.value);
    widget.callback?.(widget.value);
  });
  inputEl.addEventListener("keydown", (event) => {
    event.stopPropagation();
  });
  inputEl.addEventListener("pointerdown", (event) => {
    if (event.button === 1) {
      app$2.canvas.processMouseDown(event);
    }
  });
  inputEl.addEventListener("pointermove", (event) => {
    if ((event.buttons & 4) === 4) {
      app$2.canvas.processMouseMove(event);
    }
  });
  inputEl.addEventListener("pointerup", (event) => {
    if (event.button === 1) {
      app$2.canvas.processMouseUp(event);
    }
  });
  return widget;
}
__name(addMarkdownWidget, "addMarkdownWidget");
const useMarkdownWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    return addMarkdownWidget(node3, inputSpec.name, {
      defaultVal: inputSpec.default ?? ""
    });
  }, "widgetConstructor");
  return widgetConstructor;
}, "useMarkdownWidget");
function addMultilineWidget(node3, name2, opts) {
  const inputEl = document.createElement("textarea");
  inputEl.className = "comfy-multiline-input";
  inputEl.value = opts.defaultVal;
  inputEl.placeholder = opts.placeholder || name2;
  inputEl.spellcheck = useSettingStore().get("Comfy.TextareaWidget.Spellcheck");
  const widget = node3.addDOMWidget(name2, "customtext", inputEl, {
    getValue() {
      return inputEl.value;
    },
    setValue(v2) {
      inputEl.value = v2;
    }
  });
  widget.inputEl = inputEl;
  widget.options.minNodeSize = [400, 200];
  inputEl.addEventListener("input", () => {
    widget.callback?.(widget.value);
  });
  inputEl.addEventListener("pointerdown", (event) => {
    if (event.button === 1) {
      app$2.canvas.processMouseDown(event);
    }
  });
  inputEl.addEventListener("pointermove", (event) => {
    if ((event.buttons & 4) === 4) {
      app$2.canvas.processMouseMove(event);
    }
  });
  inputEl.addEventListener("pointerup", (event) => {
    if (event.button === 1) {
      app$2.canvas.processMouseUp(event);
    }
  });
  return widget;
}
__name(addMultilineWidget, "addMultilineWidget");
const useStringWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    if (!isStringInputSpec(inputSpec)) {
      throw new Error(`Invalid input data: ${inputSpec}`);
    }
    const defaultVal = inputSpec.default ?? "";
    const multiline = inputSpec.multiline;
    const widget = multiline ? addMultilineWidget(node3, inputSpec.name, {
      defaultVal,
      placeholder: inputSpec.placeholder
    }) : node3.addWidget("text", inputSpec.name, defaultVal, () => {
    }, {});
    if (typeof inputSpec.dynamicPrompts === "boolean") {
      widget.dynamicPrompts = inputSpec.dynamicPrompts;
    }
    return widget;
  }, "widgetConstructor");
  return widgetConstructor;
}, "useStringWidget");
const transformWidgetConstructorV2ToV1 = /* @__PURE__ */ __name((widgetConstructorV2) => {
  return (node3, inputName, inputData) => {
    const inputSpec = transformInputSpecV1ToV2(inputData, {
      name: inputName
    });
    const widget = widgetConstructorV2(node3, inputSpec);
    return {
      widget,
      minWidth: widget.options.minNodeSize?.[0],
      minHeight: widget.options.minNodeSize?.[1]
    };
  };
}, "transformWidgetConstructorV2ToV1");
function controlValueRunBefore() {
  return useSettingStore().get("Comfy.WidgetControlMode") === "before";
}
__name(controlValueRunBefore, "controlValueRunBefore");
function updateControlWidgetLabel(widget) {
  if (controlValueRunBefore()) {
    widget.label = t("g.control_before_generate");
  } else {
    widget.label = t("g.control_after_generate");
  }
}
__name(updateControlWidgetLabel, "updateControlWidgetLabel");
const IS_CONTROL_WIDGET = Symbol();
const HAS_EXECUTED = Symbol();
function addValueControlWidget(node3, targetWidget, defaultValue2, _values, widgetName, inputData) {
  let name2 = inputData?.[1]?.control_after_generate;
  if (typeof name2 !== "string") {
    name2 = widgetName;
  }
  const widgets = addValueControlWidgets(
    node3,
    targetWidget,
    defaultValue2 ?? "randomize",
    {
      addFilterList: false,
      controlAfterGenerateName: name2
    },
    inputData
  );
  return widgets[0];
}
__name(addValueControlWidget, "addValueControlWidget");
function addValueControlWidgets(node3, targetWidget, defaultValue2, options5, inputData) {
  if (!defaultValue2) defaultValue2 = "randomize";
  if (!options5) options5 = {};
  const getName = /* @__PURE__ */ __name((defaultName, optionName) => {
    let name2 = defaultName;
    if (options5[optionName]) {
      name2 = options5[optionName];
    } else if (typeof inputData?.[1]?.[defaultName] === "string") {
      name2 = inputData?.[1]?.[defaultName];
    } else if (inputData?.[1]?.control_prefix) {
      name2 = inputData?.[1]?.control_prefix + " " + name2;
    }
    return name2;
  }, "getName");
  const widgets = [];
  const valueControl = node3.addWidget(
    "combo",
    getName("control_after_generate", "controlAfterGenerateName"),
    defaultValue2,
    function() {
    },
    {
      values: ["fixed", "increment", "decrement", "randomize"],
      serialize: false
      // Don't include this in prompt.
    }
  );
  valueControl.tooltip = "Allows the linked widget to be changed automatically, for example randomizing the noise seed.";
  valueControl[IS_CONTROL_WIDGET] = true;
  updateControlWidgetLabel(valueControl);
  widgets.push(valueControl);
  const isCombo = targetWidget.type === "combo";
  let comboFilter;
  if (isCombo && valueControl.options.values) {
    valueControl.options.values.push("increment-wrap");
  }
  if (isCombo && options5.addFilterList !== false) {
    comboFilter = node3.addWidget(
      "string",
      getName("control_filter_list", "controlFilterListName"),
      "",
      function() {
      },
      {
        serialize: false
        // Don't include this in prompt.
      }
    );
    updateControlWidgetLabel(comboFilter);
    comboFilter.tooltip = "Allows for filtering the list of values when changing the value via the control generate mode. Allows for RegEx matches in the format /abc/ to only filter to values containing 'abc'.";
    widgets.push(comboFilter);
  }
  const applyWidgetControl = /* @__PURE__ */ __name(() => {
    var v2 = valueControl.value;
    if (isCombo && v2 !== "fixed") {
      let values = targetWidget.options.values ?? [];
      const filter4 = comboFilter?.value;
      if (filter4) {
        let check;
        if (filter4.startsWith("/") && filter4.endsWith("/")) {
          try {
            const regex2 = new RegExp(filter4.substring(1, filter4.length - 1));
            check = /* @__PURE__ */ __name((item3) => regex2.test(item3), "check");
          } catch (error2) {
            console.error(
              "Error constructing RegExp filter for node " + node3.id,
              filter4,
              error2
            );
          }
        }
        if (!check) {
          const lower = filter4.toLocaleLowerCase();
          check = /* @__PURE__ */ __name((item3) => item3.toLocaleLowerCase().includes(lower), "check");
        }
        values = values.filter((item3) => check(item3));
        if (!values.length && targetWidget.options.values?.length) {
          console.warn(
            "Filter for node " + node3.id + " has filtered out all items",
            filter4
          );
        }
      }
      let current_index = values.indexOf(targetWidget.value);
      let current_length = values.length;
      switch (v2) {
        case "increment":
          current_index += 1;
          break;
        case "increment-wrap":
          current_index += 1;
          if (current_index >= current_length) {
            current_index = 0;
          }
          break;
        case "decrement":
          current_index -= 1;
          break;
        case "randomize":
          current_index = Math.floor(Math.random() * current_length);
          break;
        default:
          break;
      }
      current_index = Math.max(0, current_index);
      current_index = Math.min(current_length - 1, current_index);
      if (current_index >= 0) {
        let value3 = values[current_index];
        targetWidget.value = value3;
        targetWidget.callback?.(value3);
      }
    } else {
      let { min = 0, max = 1, step2 = 1 } = targetWidget.options;
      max = Math.min(1125899906842624, max);
      min = Math.max(-1125899906842624, min);
      let range2 = (max - min) / step2;
      switch (v2) {
        case "fixed":
          break;
        case "increment":
          targetWidget.value += step2;
          break;
        case "decrement":
          targetWidget.value -= step2;
          break;
        case "randomize":
          targetWidget.value = Math.floor(Math.random() * range2) * step2 + min;
          break;
        default:
          break;
      }
      if (targetWidget.value < min) targetWidget.value = min;
      if (targetWidget.value > max) targetWidget.value = max;
      targetWidget.callback?.(targetWidget.value);
    }
  }, "applyWidgetControl");
  valueControl.beforeQueued = () => {
    if (controlValueRunBefore()) {
      if (valueControl[HAS_EXECUTED]) {
        applyWidgetControl();
      }
    }
    valueControl[HAS_EXECUTED] = true;
  };
  valueControl.afterQueued = () => {
    if (!controlValueRunBefore()) {
      applyWidgetControl();
    }
  };
  return widgets;
}
__name(addValueControlWidgets, "addValueControlWidgets");
const ComfyWidgets = {
  INT: transformWidgetConstructorV2ToV1(useIntWidget()),
  FLOAT: transformWidgetConstructorV2ToV1(useFloatWidget()),
  BOOLEAN: transformWidgetConstructorV2ToV1(useBooleanWidget()),
  STRING: transformWidgetConstructorV2ToV1(useStringWidget()),
  MARKDOWN: transformWidgetConstructorV2ToV1(useMarkdownWidget()),
  COMBO: transformWidgetConstructorV2ToV1(useComboWidget()),
  IMAGEUPLOAD: useImageUploadWidget()
};
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.widgets = window.comfyAPI.widgets || {};
window.comfyAPI.widgets.updateControlWidgetLabel = updateControlWidgetLabel;
window.comfyAPI.widgets.IS_CONTROL_WIDGET = IS_CONTROL_WIDGET;
window.comfyAPI.widgets.addValueControlWidget = addValueControlWidget;
window.comfyAPI.widgets.addValueControlWidgets = addValueControlWidgets;
window.comfyAPI.widgets.ComfyWidgets = ComfyWidgets;
const useWidgetStore = /* @__PURE__ */ defineStore("widget", () => {
  const coreWidgets = ComfyWidgets;
  const customWidgets = ref({});
  const widgets = computed(() => ({
    ...customWidgets.value,
    ...coreWidgets
  }));
  function inputIsWidget(spec) {
    const type = Array.isArray(spec) ? getInputSpecType(spec) : spec.type;
    return type in widgets.value;
  }
  __name(inputIsWidget, "inputIsWidget");
  function registerCustomWidgets(newWidgets) {
    customWidgets.value = {
      ...customWidgets.value,
      ...newWidgets
    };
  }
  __name(registerCustomWidgets, "registerCustomWidgets");
  return {
    widgets,
    inputIsWidget,
    registerCustomWidgets
  };
});
const _hoisted_1$S = { class: "_sb_node_preview" };
const _hoisted_2$I = { class: "_sb_table" };
const _hoisted_3$s = { class: "_sb_col" };
const _hoisted_4$i = { class: "_sb_col" };
const _hoisted_5$g = { class: "_sb_col" };
const _sfc_main$U = /* @__PURE__ */ defineComponent({
  __name: "NodePreview",
  props: {
    nodeDef: {}
  },
  setup(__props) {
    const props = __props;
    const colorPaletteStore = useColorPaletteStore();
    const litegraphColors = computed(
      () => colorPaletteStore.completedActivePalette.colors.litegraph_base
    );
    const widgetStore = useWidgetStore();
    const nodeDef = props.nodeDef;
    const allInputDefs = Object.values(nodeDef.inputs);
    const allOutputDefs = nodeDef.outputs;
    const slotInputDefs = allInputDefs.filter(
      (input) => !widgetStore.inputIsWidget(input)
    );
    const widgetInputDefs = allInputDefs.filter(
      (input) => widgetStore.inputIsWidget(input)
    );
    const truncateDefaultValue = /* @__PURE__ */ __name((value3, charLimit = 32) => {
      let stringValue;
      if (typeof value3 === "object" && value3 !== null) {
        stringValue = JSON.stringify(value3);
      } else if (Array.isArray(value3)) {
        stringValue = JSON.stringify(value3);
      } else if (typeof value3 === "string") {
        stringValue = value3;
      } else {
        stringValue = String(value3);
      }
      return _.truncate(stringValue, { length: charLimit });
    }, "truncateDefaultValue");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$S, [
        createBaseVNode("div", _hoisted_2$I, [
          createBaseVNode("div", {
            class: "node_header",
            style: normalizeStyle({
              backgroundColor: litegraphColors.value.NODE_DEFAULT_COLOR,
              color: litegraphColors.value.NODE_TITLE_COLOR
            })
          }, [
            _cache[0] || (_cache[0] = createBaseVNode("div", { class: "_sb_dot headdot" }, null, -1)),
            createTextVNode(" " + toDisplayString$1(unref(nodeDef).display_name), 1)
          ], 4),
          _cache[5] || (_cache[5] = createBaseVNode("div", { class: "_sb_preview_badge" }, "PREVIEW", -1)),
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(unref(_).zip(unref(slotInputDefs), unref(allOutputDefs)), ([slotInput, slotOutput]) => {
            return openBlock(), createElementBlock("div", {
              class: "_sb_row slot_row",
              key: (slotInput?.name || "") + (slotOutput?.index.toString() || "")
            }, [
              createBaseVNode("div", _hoisted_3$s, [
                slotInput ? (openBlock(), createElementBlock("div", {
                  key: 0,
                  class: normalizeClass(["_sb_dot", slotInput.type])
                }, null, 2)) : createCommentVNode("", true)
              ]),
              createBaseVNode("div", _hoisted_4$i, toDisplayString$1(slotInput ? slotInput.name : ""), 1),
              _cache[1] || (_cache[1] = createBaseVNode("div", { class: "_sb_col middle-column" }, null, -1)),
              createBaseVNode("div", {
                class: "_sb_col _sb_inherit",
                style: normalizeStyle({
                  color: litegraphColors.value.NODE_TEXT_COLOR
                })
              }, toDisplayString$1(slotOutput ? slotOutput.name : ""), 5),
              createBaseVNode("div", _hoisted_5$g, [
                slotOutput ? (openBlock(), createElementBlock("div", {
                  key: 0,
                  class: normalizeClass(["_sb_dot", slotOutput.type])
                }, null, 2)) : createCommentVNode("", true)
              ])
            ]);
          }), 128)),
          (openBlock(true), createElementBlock(Fragment$1, null, renderList(unref(widgetInputDefs), (widgetInput) => {
            return openBlock(), createElementBlock("div", {
              class: "_sb_row _long_field",
              key: widgetInput.name
            }, [
              _cache[2] || (_cache[2] = createBaseVNode("div", { class: "_sb_col _sb_arrow" }, "◀", -1)),
              createBaseVNode("div", {
                class: "_sb_col",
                style: normalizeStyle({
                  color: litegraphColors.value.WIDGET_SECONDARY_TEXT_COLOR
                })
              }, toDisplayString$1(widgetInput.name), 5),
              _cache[3] || (_cache[3] = createBaseVNode("div", { class: "_sb_col middle-column" }, null, -1)),
              createBaseVNode("div", {
                class: "_sb_col _sb_inherit",
                style: normalizeStyle({ color: litegraphColors.value.WIDGET_TEXT_COLOR })
              }, toDisplayString$1(truncateDefaultValue(widgetInput.default)), 5),
              _cache[4] || (_cache[4] = createBaseVNode("div", { class: "_sb_col _sb_arrow" }, "▶", -1))
            ]);
          }), 128))
        ]),
        unref(nodeDef).description ? (openBlock(), createElementBlock("div", {
          key: 0,
          class: "_sb_description",
          style: normalizeStyle({
            color: litegraphColors.value.WIDGET_SECONDARY_TEXT_COLOR,
            backgroundColor: litegraphColors.value.WIDGET_BGCOLOR
          })
        }, toDisplayString$1(unref(nodeDef).description), 5)) : createCommentVNode("", true)
      ]);
    };
  }
});
const NodePreview = /* @__PURE__ */ _export_sfc(_sfc_main$U, [["__scopeId", "data-v-89ecf730"]]);
const _hoisted_1$R = { class: "flex flex-col gap-4 mt-4 overflow-auto text-sm" };
const _hoisted_2$H = { key: 0 };
const _sfc_main$T = /* @__PURE__ */ defineComponent({
  __name: "NodesTabPanel",
  props: {
    nodePack: {},
    nodeDefs: {}
  },
  setup(__props) {
    const placeholderNodeDef = {
      name: "Sample Node",
      display_name: "Sample Node",
      description: "This is a sample node for preview purposes",
      inputs: {
        input1: { name: "Input 1", type: "IMAGE" },
        input2: { name: "Input 2", type: "CONDITIONING" }
      },
      outputs: [
        { name: "Output 1", type: "IMAGE", index: 0, is_list: false },
        { name: "Output 2", type: "MASK", index: 1, is_list: false }
      ],
      category: "Utility",
      output_node: false,
      python_module: "nodes"
    };
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$R, [
        _ctx.nodeDefs?.length ? (openBlock(), createElementBlock("div", _hoisted_2$H)) : (openBlock(), createElementBlock(Fragment$1, { key: 1 }, renderList(3, (i2) => {
          return createBaseVNode("div", {
            key: i2,
            class: "border border-surface-border rounded-lg p-4"
          }, [
            createVNode(NodePreview, {
              "node-def": placeholderNodeDef,
              class: "!text-[.625rem] !min-w-full"
            })
          ]);
        }), 64))
      ]);
    };
  }
});
const _hoisted_1$Q = { class: "overflow-hidden" };
const _sfc_main$S = /* @__PURE__ */ defineComponent({
  __name: "InfoTabs",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const activeTab = ref("description");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$Q, [
        createVNode(unref(script$C), { value: activeTab.value }, {
          default: withCtx(() => [
            createVNode(unref(script$j), null, {
              default: withCtx(() => [
                createVNode(unref(script$k), { value: "description" }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString$1(_ctx.$t("g.description")), 1)
                  ]),
                  _: 1
                }),
                createVNode(unref(script$k), { value: "nodes" }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString$1(_ctx.$t("g.nodes")), 1)
                  ]),
                  _: 1
                })
              ]),
              _: 1
            }),
            createVNode(unref(script$D), { class: "overflow-auto" }, {
              default: withCtx(() => [
                createVNode(unref(script$y), { value: "description" }, {
                  default: withCtx(() => [
                    createVNode(_sfc_main$W, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
                  ]),
                  _: 1
                }),
                createVNode(unref(script$y), { value: "nodes" }, {
                  default: withCtx(() => [
                    createVNode(_sfc_main$T, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
                  ]),
                  _: 1
                })
              ]),
              _: 1
            })
          ]),
          _: 1
        }, 8, ["value"])
      ]);
    };
  }
});
const _hoisted_1$P = { class: "flex py-1.5 text-xs" };
const _hoisted_2$G = { class: "w-1/3 truncate pr-2 text-muted" };
const _hoisted_3$r = { class: "w-2/3" };
const _sfc_main$R = /* @__PURE__ */ defineComponent({
  __name: "MetadataRow",
  props: {
    label: { default: "N/A" },
    value: { default: "N/A" }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$P, [
        createBaseVNode("div", _hoisted_2$G, toDisplayString$1(_ctx.label) + ":", 1),
        createBaseVNode("div", _hoisted_3$r, [
          renderSlot(_ctx.$slots, "default", {}, () => [
            createTextVNode(toDisplayString$1(_ctx.value), 1)
          ])
        ])
      ]);
    };
  }
});
const _hoisted_1$O = {
  key: 0,
  class: "flex flex-col h-full z-40 w-80 overflow-hidden relative"
};
const _hoisted_2$F = { class: "top-0 z-10 px-6 pt-6 w-full" };
const _hoisted_3$q = { class: "p-6 pt-2 overflow-y-auto flex-1 text-sm hidden-scrollbar" };
const _hoisted_4$h = { class: "mb-6" };
const _hoisted_5$f = { class: "mb-6 overflow-hidden" };
const _hoisted_6$d = {
  key: 1,
  class: "mt-4 mx-8 flex-1 overflow-hidden text-sm"
};
const _sfc_main$Q = /* @__PURE__ */ defineComponent({
  __name: "InfoPanel",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const managerStore = useComfyManagerStore();
    const isInstalled = computed(() => managerStore.isPackInstalled(__props.nodePack.id));
    const isInstalling = ref(false);
    provide(IsInstallingKey, isInstalling);
    whenever(isInstalled, () => {
      isInstalling.value = false;
    });
    const { isPackInstalled } = useComfyManagerStore();
    const { t: t2, d: d2, n: n2 } = useI18n();
    const infoItems = computed(() => [
      {
        key: "publisher",
        label: t2("manager.createdBy"),
        value: __props.nodePack.publisher?.name ?? __props.nodePack.publisher?.id
      },
      {
        key: "downloads",
        label: t2("manager.downloads"),
        value: __props.nodePack.downloads ? n2(__props.nodePack.downloads) : void 0
      },
      {
        key: "lastUpdated",
        label: t2("manager.lastUpdated"),
        value: __props.nodePack.latest_version?.createdAt ? d2(__props.nodePack.latest_version.createdAt, {
          dateStyle: "medium"
        }) : void 0
      }
    ]);
    return (_ctx, _cache) => {
      return _ctx.nodePack ? (openBlock(), createElementBlock("div", _hoisted_1$O, [
        createBaseVNode("div", _hoisted_2$F, [
          createVNode(_sfc_main$Z, {
            "node-packs": [_ctx.nodePack]
          }, null, 8, ["node-packs"])
        ]),
        createBaseVNode("div", _hoisted_3$q, [
          createBaseVNode("div", _hoisted_4$h, [
            unref(isPackInstalled)(_ctx.nodePack.id) ? (openBlock(), createBlock(_sfc_main$R, {
              key: 0,
              label: unref(t2)("manager.filter.enabled"),
              class: "flex",
              style: { "align-items": "center" }
            }, {
              default: withCtx(() => [
                createVNode(_sfc_main$12, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
              ]),
              _: 1
            }, 8, ["label"])) : createCommentVNode("", true),
            (openBlock(true), createElementBlock(Fragment$1, null, renderList(infoItems.value, (item3) => {
              return withDirectives((openBlock(), createBlock(_sfc_main$R, {
                key: item3.key,
                label: item3.label,
                value: item3.value
              }, null, 8, ["label", "value"])), [
                [vShow, item3.value !== void 0 && item3.value !== null]
              ]);
            }), 128)),
            createVNode(_sfc_main$R, {
              label: unref(t2)("g.status")
            }, {
              default: withCtx(() => [
                createVNode(_sfc_main$15, {
                  "status-type": _ctx.nodePack.status
                }, null, 8, ["status-type"])
              ]),
              _: 1
            }, 8, ["label"]),
            createVNode(_sfc_main$R, {
              label: unref(t2)("manager.version")
            }, {
              default: withCtx(() => [
                createVNode(_sfc_main$13, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
              ]),
              _: 1
            }, 8, ["label"])
          ]),
          createBaseVNode("div", _hoisted_5$f, [
            createVNode(_sfc_main$S, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
          ])
        ])
      ])) : (openBlock(), createElementBlock("div", _hoisted_6$d, toDisplayString$1(_ctx.$t("manager.infoPanelEmpty")), 1));
    };
  }
});
const InfoPanel = /* @__PURE__ */ _export_sfc(_sfc_main$Q, [["__scopeId", "data-v-afb02026"]]);
const _hoisted_1$N = { class: "relative w-24 h-24" };
const _hoisted_2$E = { class: "border border-surface-border bg-surface-card rounded-lg p-0.5" };
const _hoisted_3$p = {
  key: 0,
  class: "absolute -top-2 -right-2 bg-primary rounded-full w-7 h-7 flex items-center justify-center text-xs font-bold shadow-md z-10"
};
const _sfc_main$P = /* @__PURE__ */ defineComponent({
  __name: "PackIconStacked",
  props: {
    nodePacks: {},
    maxVisible: { default: 3 },
    offset: { default: 8 }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$N, [
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.nodePacks.slice(0, _ctx.maxVisible), (pack, index2) => {
          return openBlock(), createElementBlock("div", {
            key: pack.id,
            class: "absolute",
            style: normalizeStyle({
              bottom: `${index2 * _ctx.offset}px`,
              right: `${index2 * _ctx.offset}px`,
              zIndex: _ctx.maxVisible - index2
            })
          }, [
            createBaseVNode("div", _hoisted_2$E, [
              createVNode(_sfc_main$_, {
                "node-pack": pack,
                width: "4.5rem",
                height: "4.5rem"
              }, null, 8, ["node-pack"])
            ])
          ], 4);
        }), 128)),
        _ctx.nodePacks.length > _ctx.maxVisible ? (openBlock(), createElementBlock("div", _hoisted_3$p, " +" + toDisplayString$1(_ctx.nodePacks.length - _ctx.maxVisible), 1)) : createCommentVNode("", true)
      ]);
    };
  }
});
const _hoisted_1$M = {
  key: 0,
  class: "flex flex-col h-full"
};
const _hoisted_2$D = { class: "p-6 flex-1 overflow-auto" };
const _hoisted_3$o = { class: "mb-6" };
const _hoisted_4$g = {
  key: 1,
  class: "mt-4 mx-8 flex-1 overflow-hidden text-sm"
};
const _sfc_main$O = /* @__PURE__ */ defineComponent({
  __name: "InfoPanelMultiItem",
  props: {
    nodePacks: {}
  },
  setup(__props) {
    const comfyRegistryService = useComfyRegistryService();
    const getPackNodes = /* @__PURE__ */ __name(async (pack) => {
      if (!comfyRegistryService.packNodesAvailable(pack)) return [];
      return comfyRegistryService.getNodeDefs({
        packId: pack.id,
        versionId: pack.latest_version?.id
      });
    }, "getPackNodes");
    const { state: allNodeDefs } = useAsyncState(
      () => Promise.all(__props.nodePacks.map(getPackNodes)),
      [],
      {
        immediate: true
      }
    );
    const totalNodesCount = computed(
      () => allNodeDefs.value.reduce(
        (total, nodeDefs) => total + (nodeDefs?.length || 0),
        0
      )
    );
    return (_ctx, _cache) => {
      return _ctx.nodePacks?.length ? (openBlock(), createElementBlock("div", _hoisted_1$M, [
        createBaseVNode("div", _hoisted_2$D, [
          createVNode(_sfc_main$Z, { "node-packs": _ctx.nodePacks }, {
            thumbnail: withCtx(() => [
              createVNode(_sfc_main$P, { "node-packs": _ctx.nodePacks }, null, 8, ["node-packs"])
            ]),
            title: withCtx(() => [
              createTextVNode(toDisplayString$1(_ctx.nodePacks.length) + " " + toDisplayString$1(_ctx.$t("manager.packsSelected")), 1)
            ]),
            "install-button": withCtx(() => [
              createVNode(_sfc_main$10, {
                "full-width": true,
                "node-packs": _ctx.nodePacks
              }, null, 8, ["node-packs"])
            ]),
            _: 1
          }, 8, ["node-packs"]),
          createBaseVNode("div", _hoisted_3$o, [
            createVNode(_sfc_main$R, {
              label: _ctx.$t("g.status")
            }, {
              default: withCtx(() => [
                createVNode(_sfc_main$15, { "status-type": "NodeVersionStatusActive" })
              ]),
              _: 1
            }, 8, ["label"]),
            createVNode(_sfc_main$R, {
              label: _ctx.$t("manager.totalNodes"),
              value: totalNodesCount.value
            }, null, 8, ["label", "value"])
          ])
        ])
      ])) : (openBlock(), createElementBlock("div", _hoisted_4$g, toDisplayString$1(_ctx.$t("manager.infoPanelEmpty")), 1));
    };
  }
});
const _hoisted_1$L = { class: "w-[100%] flex justify-between items-center" };
const _hoisted_2$C = { class: "flex justify-start items-center" };
const _hoisted_3$n = { class: "px-3 py-2 rounded-md flex justify-start items-start gap-2.5" };
const _hoisted_4$f = { class: "text-right justify-start text-sm font-bold leading-none" };
const _hoisted_5$e = { class: "inline-flex justify-start items-center gap-3" };
const _hoisted_6$c = {
  key: 0,
  class: "flex items-center text-sm text-muted tracking-tighter"
};
const _sfc_main$N = /* @__PURE__ */ defineComponent({
  __name: "PackCardHeader",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const { isPackInstalled } = useComfyManagerStore();
    const isInstalled = computed(() => isPackInstalled(__props.nodePack?.id));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$L, [
        createBaseVNode("div", _hoisted_2$C, [
          _cache[0] || (_cache[0] = createBaseVNode("div", { class: "w-1 h-6 rounded-md" }, null, -1)),
          _cache[1] || (_cache[1] = createBaseVNode("div", { class: "w-6 h-6 relative overflow-hidden" }, [
            createBaseVNode("i", {
              class: "pi pi-box text-xl text-muted",
              style: { "opacity": "0.6" }
            })
          ], -1)),
          createBaseVNode("div", _hoisted_3$n, [
            createBaseVNode("div", _hoisted_4$f, toDisplayString$1(_ctx.$t("manager.nodePack")), 1)
          ])
        ]),
        createBaseVNode("div", _hoisted_5$e, [
          _ctx.nodePack.downloads ? (openBlock(), createElementBlock("div", _hoisted_6$c, [
            _cache[2] || (_cache[2] = createBaseVNode("i", { class: "pi pi-download mr-2" }, null, -1)),
            createTextVNode(" " + toDisplayString$1(_ctx.$n(_ctx.nodePack.downloads)), 1)
          ])) : createCommentVNode("", true),
          isInstalled.value ? (openBlock(), createBlock(_sfc_main$12, {
            key: 1,
            "node-pack": _ctx.nodePack
          }, null, 8, ["node-pack"])) : (openBlock(), createBlock(_sfc_main$10, {
            key: 2,
            "node-packs": [_ctx.nodePack]
          }, null, 8, ["node-packs"]))
        ])
      ]);
    };
  }
});
const _hoisted_1$K = { class: "flex justify-between px-5 py-4 text-xs text-muted font-medium leading-3" };
const _hoisted_2$B = { class: "flex items-center gap-2 cursor-pointer" };
const _hoisted_3$m = {
  key: 0,
  class: "max-w-40 truncate"
};
const _hoisted_4$e = {
  key: 0,
  class: "flex items-center gap-2 truncate"
};
const _sfc_main$M = /* @__PURE__ */ defineComponent({
  __name: "PackCardFooter",
  props: {
    nodePack: {}
  },
  setup(__props) {
    const publisherName = computed(() => {
      if (!__props.nodePack) return null;
      const { publisher, author } = __props.nodePack;
      return publisher?.name ?? publisher?.id ?? author;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$K, [
        createBaseVNode("div", _hoisted_2$B, [
          publisherName.value ? (openBlock(), createElementBlock("span", _hoisted_3$m, toDisplayString$1(publisherName.value), 1)) : createCommentVNode("", true)
        ]),
        _ctx.nodePack.latest_version?.createdAt ? (openBlock(), createElementBlock("div", _hoisted_4$e, toDisplayString$1(_ctx.$t("g.updated")) + " " + toDisplayString$1(_ctx.$d(new Date(_ctx.nodePack.latest_version.createdAt), {
          dateStyle: "medium"
        })), 1)) : createCommentVNode("", true)
      ]);
    };
  }
});
const _hoisted_1$J = {
  key: 0,
  class: "self-stretch inline-flex flex-col justify-center items-center gap-2 h-full"
};
const _hoisted_2$A = { class: "self-stretch text-center justify-start text-sm font-medium leading-none" };
const _hoisted_3$l = {
  key: 1,
  class: "self-stretch px-4 py-3 inline-flex justify-start items-start cursor-pointer"
};
const _hoisted_4$d = { class: "px-4 inline-flex flex-col justify-start items-start overflow-hidden" };
const _hoisted_5$d = { class: "text-sm font-bold truncate overflow-hidden text-ellipsis" };
const _hoisted_6$b = { class: "self-stretch inline-flex justify-center items-center gap-2.5" };
const _hoisted_7$6 = {
  key: 0,
  class: "flex-1 justify-start text-muted text-sm font-medium leading-3 break-words overflow-hidden min-h-12 line-clamp-3"
};
const _hoisted_8$4 = { class: "self-stretch inline-flex justify-start items-center gap-2" };
const _hoisted_9$3 = {
  key: 0,
  class: "px-2 py-1 flex justify-center text-sm items-center gap-1"
};
const _hoisted_10$3 = { class: "text-center justify-center font-medium leading-3" };
const _hoisted_11$2 = { class: "px-2 py-1 flex justify-center items-center gap-1" };
const _hoisted_12$1 = {
  key: 0,
  class: "w-4 h-4 relative overflow-hidden"
};
const _sfc_main$L = /* @__PURE__ */ defineComponent({
  __name: "PackCard",
  props: {
    nodePack: {},
    isSelected: { type: Boolean, default: false }
  },
  setup(__props) {
    const isInstalling = ref(false);
    provide(IsInstallingKey, isInstalling);
    const { isPackInstalled, isPackEnabled, getInstalledPackVersion } = useComfyManagerStore();
    const isInstalled = computed(() => isPackInstalled(__props.nodePack?.id));
    const isDisabled = computed(
      () => isInstalled.value && !isPackEnabled(__props.nodePack?.id)
    );
    whenever(isInstalled, () => isInstalling.value = false);
    const isUpdateAvailable = computed(() => {
      if (!isInstalled.value) return false;
      const latestVersion = __props.nodePack.latest_version?.version;
      if (!latestVersion) return false;
      const installedVersion = getInstalledPackVersion(__props.nodePack.id ?? "");
      if (installedVersion && !isSemVer(installedVersion)) return false;
      return compareVersions(latestVersion, installedVersion) > 0;
    });
    const nodesCount = computed(() => __props.nodePack.comfy_nodes?.length);
    return (_ctx, _cache) => {
      const _component_PackCardHeader = _sfc_main$N;
      return openBlock(), createBlock(unref(script$W), {
        class: normalizeClass(["w-full h-full inline-flex flex-col justify-between items-start overflow-hidden rounded-2xl shadow-elevation-3 dark-theme:bg-dark-elevation-2 transition-all duration-200", {
          "outline outline-[6px] outline-[var(--p-primary-color)]": _ctx.isSelected,
          "opacity-60": isDisabled.value
        }]),
        pt: {
          body: { class: "p-0 flex flex-col w-full h-full rounded-2xl gap-0" },
          content: { class: "flex-1 flex flex-col rounded-2xl" },
          title: {
            class: "self-stretch w-full px-4 py-3 inline-flex justify-start items-center gap-6"
          },
          footer: { class: "p-0 m-0" }
        }
      }, {
        title: withCtx(() => [
          createVNode(_component_PackCardHeader, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
        ]),
        content: withCtx(() => [
          createVNode(_sfc_main$18),
          isInstalling.value ? (openBlock(), createElementBlock("div", _hoisted_1$J, [
            createVNode(unref(script$19)),
            createBaseVNode("div", _hoisted_2$A, toDisplayString$1(_ctx.$t("g.installing")) + "... ", 1)
          ])) : (openBlock(), createElementBlock("div", _hoisted_3$l, [
            createVNode(_sfc_main$_, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"]),
            createBaseVNode("div", _hoisted_4$d, [
              createBaseVNode("span", _hoisted_5$d, toDisplayString$1(_ctx.nodePack.name), 1),
              createBaseVNode("div", _hoisted_6$b, [
                _ctx.nodePack.description ? (openBlock(), createElementBlock("p", _hoisted_7$6, toDisplayString$1(_ctx.nodePack.description), 1)) : createCommentVNode("", true)
              ]),
              createBaseVNode("div", _hoisted_8$4, [
                nodesCount.value ? (openBlock(), createElementBlock("div", _hoisted_9$3, [
                  createBaseVNode("div", _hoisted_10$3, toDisplayString$1(nodesCount.value) + " " + toDisplayString$1(_ctx.$t("g.nodes")), 1)
                ])) : createCommentVNode("", true),
                createBaseVNode("div", _hoisted_11$2, [
                  isUpdateAvailable.value ? (openBlock(), createElementBlock("div", _hoisted_12$1, _cache[0] || (_cache[0] = [
                    createBaseVNode("i", { class: "pi pi-arrow-circle-up text-blue-600" }, null, -1)
                  ]))) : createCommentVNode("", true),
                  createVNode(_sfc_main$13, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
                ])
              ])
            ])
          ]))
        ]),
        footer: withCtx(() => [
          createVNode(_sfc_main$18, { width: 0.1 }),
          createVNode(_sfc_main$M, { "node-pack": _ctx.nodePack }, null, 8, ["node-pack"])
        ]),
        _: 1
      }, 8, ["class"]);
    };
  }
});
var theme$a = /* @__PURE__ */ __name(function theme36(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-autocomplete {\n    display: inline-flex;\n}\n\n.p-autocomplete-loader {\n    position: absolute;\n    top: 50%;\n    margin-top: -0.5rem;\n    inset-inline-end: ".concat(dt2("autocomplete.padding.x"), ";\n}\n\n.p-autocomplete:has(.p-autocomplete-dropdown) .p-autocomplete-loader {\n    inset-inline-end: calc(").concat(dt2("autocomplete.dropdown.width"), " + ").concat(dt2("autocomplete.padding.x"), ");\n}\n\n.p-autocomplete:has(.p-autocomplete-dropdown) .p-autocomplete-input {\n    flex: 1 1 auto;\n    width: 1%;\n}\n\n.p-autocomplete:has(.p-autocomplete-dropdown) .p-autocomplete-input,\n.p-autocomplete:has(.p-autocomplete-dropdown) .p-autocomplete-input-multiple {\n    border-start-end-radius: 0;\n    border-end-end-radius: 0;\n}\n\n.p-autocomplete-dropdown {\n    cursor: pointer;\n    display: inline-flex;\n    user-select: none;\n    align-items: center;\n    justify-content: center;\n    overflow: hidden;\n    position: relative;\n    width: ").concat(dt2("autocomplete.dropdown.width"), ";\n    border-start-end-radius: ").concat(dt2("autocomplete.dropdown.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("autocomplete.dropdown.border.radius"), ";\n    background: ").concat(dt2("autocomplete.dropdown.background"), ";\n    border: 1px solid ").concat(dt2("autocomplete.dropdown.border.color"), ";\n    border-inline-start: 0 none;\n    color: ").concat(dt2("autocomplete.dropdown.color"), ";\n    transition: background ").concat(dt2("autocomplete.transition.duration"), ", color ").concat(dt2("autocomplete.transition.duration"), ", border-color ").concat(dt2("autocomplete.transition.duration"), ", outline-color ").concat(dt2("autocomplete.transition.duration"), ", box-shadow ").concat(dt2("autocomplete.transition.duration"), ";\n    outline-color: transparent;\n}\n\n.p-autocomplete-dropdown:not(:disabled):hover {\n    background: ").concat(dt2("autocomplete.dropdown.hover.background"), ";\n    border-color: ").concat(dt2("autocomplete.dropdown.hover.border.color"), ";\n    color: ").concat(dt2("autocomplete.dropdown.hover.color"), ";\n}\n\n.p-autocomplete-dropdown:not(:disabled):active {\n    background: ").concat(dt2("autocomplete.dropdown.active.background"), ";\n    border-color: ").concat(dt2("autocomplete.dropdown.active.border.color"), ";\n    color: ").concat(dt2("autocomplete.dropdown.active.color"), ";\n}\n\n.p-autocomplete-dropdown:focus-visible {\n    box-shadow: ").concat(dt2("autocomplete.dropdown.focus.ring.shadow"), ";\n    outline: ").concat(dt2("autocomplete.dropdown.focus.ring.width"), " ").concat(dt2("autocomplete.dropdown.focus.ring.style"), " ").concat(dt2("autocomplete.dropdown.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("autocomplete.dropdown.focus.ring.offset"), ";\n}\n\n.p-autocomplete .p-autocomplete-overlay {\n    min-width: 100%;\n}\n\n.p-autocomplete-overlay {\n    position: absolute;\n    top: 0;\n    left: 0;\n    background: ").concat(dt2("autocomplete.overlay.background"), ";\n    color: ").concat(dt2("autocomplete.overlay.color"), ";\n    border: 1px solid ").concat(dt2("autocomplete.overlay.border.color"), ";\n    border-radius: ").concat(dt2("autocomplete.overlay.border.radius"), ";\n    box-shadow: ").concat(dt2("autocomplete.overlay.shadow"), ";\n}\n\n.p-autocomplete-list-container {\n    overflow: auto;\n}\n\n.p-autocomplete-list {\n    margin: 0;\n    list-style-type: none;\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("autocomplete.list.gap"), ";\n    padding: ").concat(dt2("autocomplete.list.padding"), ";\n}\n\n.p-autocomplete-option {\n    cursor: pointer;\n    white-space: nowrap;\n    position: relative;\n    overflow: hidden;\n    display: flex;\n    align-items: center;\n    padding: ").concat(dt2("autocomplete.option.padding"), ";\n    border: 0 none;\n    color: ").concat(dt2("autocomplete.option.color"), ";\n    background: transparent;\n    transition: background ").concat(dt2("autocomplete.transition.duration"), ", color ").concat(dt2("autocomplete.transition.duration"), ", border-color ").concat(dt2("autocomplete.transition.duration"), ";\n    border-radius: ").concat(dt2("autocomplete.option.border.radius"), ";\n}\n\n.p-autocomplete-option:not(.p-autocomplete-option-selected):not(.p-disabled).p-focus {\n    background: ").concat(dt2("autocomplete.option.focus.background"), ";\n    color: ").concat(dt2("autocomplete.option.focus.color"), ";\n}\n\n.p-autocomplete-option-selected {\n    background: ").concat(dt2("autocomplete.option.selected.background"), ";\n    color: ").concat(dt2("autocomplete.option.selected.color"), ";\n}\n\n.p-autocomplete-option-selected.p-focus {\n    background: ").concat(dt2("autocomplete.option.selected.focus.background"), ";\n    color: ").concat(dt2("autocomplete.option.selected.focus.color"), ";\n}\n\n.p-autocomplete-option-group {\n    margin: 0;\n    padding: ").concat(dt2("autocomplete.option.group.padding"), ";\n    color: ").concat(dt2("autocomplete.option.group.color"), ";\n    background: ").concat(dt2("autocomplete.option.group.background"), ";\n    font-weight: ").concat(dt2("autocomplete.option.group.font.weight"), ";\n}\n\n.p-autocomplete-input-multiple {\n    margin: 0;\n    list-style-type: none;\n    cursor: text;\n    overflow: hidden;\n    display: flex;\n    align-items: center;\n    flex-wrap: wrap;\n    padding: calc(").concat(dt2("autocomplete.padding.y"), " / 2) ").concat(dt2("autocomplete.padding.x"), ";\n    gap: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n    color: ").concat(dt2("autocomplete.color"), ";\n    background: ").concat(dt2("autocomplete.background"), ";\n    border: 1px solid ").concat(dt2("autocomplete.border.color"), ";\n    border-radius: ").concat(dt2("autocomplete.border.radius"), ";\n    width: 100%;\n    transition: background ").concat(dt2("autocomplete.transition.duration"), ", color ").concat(dt2("autocomplete.transition.duration"), ", border-color ").concat(dt2("autocomplete.transition.duration"), ", outline-color ").concat(dt2("autocomplete.transition.duration"), ", box-shadow ").concat(dt2("autocomplete.transition.duration"), ";\n    outline-color: transparent;\n    box-shadow: ").concat(dt2("autocomplete.shadow"), ";\n}\n\n.p-autocomplete:not(.p-disabled):hover .p-autocomplete-input-multiple {\n    border-color: ").concat(dt2("autocomplete.hover.border.color"), ";\n}\n\n.p-autocomplete:not(.p-disabled).p-focus .p-autocomplete-input-multiple {\n    border-color: ").concat(dt2("autocomplete.focus.border.color"), ";\n    box-shadow: ").concat(dt2("autocomplete.focus.ring.shadow"), ";\n    outline: ").concat(dt2("autocomplete.focus.ring.width"), " ").concat(dt2("autocomplete.focus.ring.style"), " ").concat(dt2("autocomplete.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("autocomplete.focus.ring.offset"), ";\n}\n\n.p-autocomplete.p-invalid .p-autocomplete-input-multiple {\n    border-color: ").concat(dt2("autocomplete.invalid.border.color"), ";\n}\n\n.p-variant-filled.p-autocomplete-input-multiple {\n    background: ").concat(dt2("autocomplete.filled.background"), ";\n}\n\n.p-autocomplete:not(.p-disabled):hover .p-variant-filled.p-autocomplete-input-multiple {\n    background: ").concat(dt2("autocomplete.filled.hover.background"), ";\n}\n\n.p-autocomplete:not(.p-disabled).p-focus .p-variant-filled.p-autocomplete-input-multiple  {\n    background: ").concat(dt2("autocomplete.filled.focus.background"), ";\n}\n\n.p-autocomplete.p-disabled .p-autocomplete-input-multiple {\n    opacity: 1;\n    background: ").concat(dt2("autocomplete.disabled.background"), ";\n    color: ").concat(dt2("autocomplete.disabled.color"), ";\n}\n\n.p-autocomplete-chip.p-chip {\n    padding-block-start: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n    padding-block-end: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n    border-radius: ").concat(dt2("autocomplete.chip.border.radius"), ";\n}\n\n.p-autocomplete-input-multiple:has(.p-autocomplete-chip) {\n    padding-inline-start: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n    padding-inline-end: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n}\n\n.p-autocomplete-chip-item.p-focus .p-autocomplete-chip {\n    background: ").concat(dt2("autocomplete.chip.focus.background"), ";\n    color: ").concat(dt2("autocomplete.chip.focus.color"), ";\n}\n\n.p-autocomplete-input-chip {\n    flex: 1 1 auto;\n    display: inline-flex;\n    padding-block-start: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n    padding-block-end: calc(").concat(dt2("autocomplete.padding.y"), " / 2);\n}\n\n.p-autocomplete-input-chip input {\n    border: 0 none;\n    outline: 0 none;\n    background: transparent;\n    margin: 0;\n    padding: 0;\n    box-shadow: none;\n    border-radius: 0;\n    width: 100%;\n    font-family: inherit;\n    font-feature-settings: inherit;\n    font-size: 1rem;\n    color: inherit;\n}\n\n.p-autocomplete-input-chip input::placeholder {\n    color: ").concat(dt2("autocomplete.placeholder.color"), ";\n}\n\n.p-autocomplete.p-invalid .p-autocomplete-input-chip input::placeholder {\n    color: ").concat(dt2("autocomplete.invalid.placeholder.color"), ";\n}\n\n.p-autocomplete-empty-message {\n    padding: ").concat(dt2("autocomplete.empty.message.padding"), ";\n}\n\n.p-autocomplete-fluid {\n    display: flex;\n}\n\n.p-autocomplete-fluid:has(.p-autocomplete-dropdown) .p-autocomplete-input {\n    width: 1%;\n}\n\n.p-autocomplete:has(.p-inputtext-sm) .p-autocomplete-dropdown {\n    width: ").concat(dt2("autocomplete.dropdown.sm.width"), ";\n}\n\n.p-autocomplete:has(.p-inputtext-sm) .p-autocomplete-dropdown .p-icon {\n    font-size: ").concat(dt2("form.field.sm.font.size"), ";\n    width: ").concat(dt2("form.field.sm.font.size"), ";\n    height: ").concat(dt2("form.field.sm.font.size"), ";\n}\n\n.p-autocomplete:has(.p-inputtext-lg) .p-autocomplete-dropdown {\n    width: ").concat(dt2("autocomplete.dropdown.lg.width"), ";\n}\n\n.p-autocomplete:has(.p-inputtext-lg) .p-autocomplete-dropdown .p-icon {\n    font-size: ").concat(dt2("form.field.lg.font.size"), ";\n    width: ").concat(dt2("form.field.lg.font.size"), ";\n    height: ").concat(dt2("form.field.lg.font.size"), ";\n}\n");
}, "theme");
var inlineStyles$1 = {
  root: {
    position: "relative"
  }
};
var classes$a = {
  root: /* @__PURE__ */ __name(function root27(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-autocomplete p-component p-inputwrapper", {
      "p-disabled": props.disabled,
      "p-invalid": instance.$invalid,
      "p-focus": instance.focused,
      "p-inputwrapper-filled": instance.$filled || isNotEmpty$2(instance.inputValue),
      "p-inputwrapper-focus": instance.focused,
      "p-autocomplete-open": instance.overlayVisible,
      "p-autocomplete-fluid": instance.$fluid
    }];
  }, "root"),
  pcInputText: "p-autocomplete-input",
  inputMultiple: /* @__PURE__ */ __name(function inputMultiple(_ref3) {
    _ref3.props;
    var instance = _ref3.instance;
    return ["p-autocomplete-input-multiple", {
      "p-variant-filled": instance.$variant === "filled"
    }];
  }, "inputMultiple"),
  chipItem: /* @__PURE__ */ __name(function chipItem(_ref4) {
    var instance = _ref4.instance, i2 = _ref4.i;
    return ["p-autocomplete-chip-item", {
      "p-focus": instance.focusedMultipleOptionIndex === i2
    }];
  }, "chipItem"),
  pcChip: "p-autocomplete-chip",
  chipIcon: "p-autocomplete-chip-icon",
  inputChip: "p-autocomplete-input-chip",
  loader: "p-autocomplete-loader",
  dropdown: "p-autocomplete-dropdown",
  overlay: "p-autocomplete-overlay p-component",
  listContainer: "p-autocomplete-list-container",
  list: "p-autocomplete-list",
  optionGroup: "p-autocomplete-option-group",
  option: /* @__PURE__ */ __name(function option4(_ref5) {
    var instance = _ref5.instance, _option = _ref5.option, i2 = _ref5.i, getItemOptions = _ref5.getItemOptions;
    return ["p-autocomplete-option", {
      "p-autocomplete-option-selected": instance.isSelected(_option),
      "p-focus": instance.focusedOptionIndex === instance.getOptionIndex(i2, getItemOptions),
      "p-disabled": instance.isOptionDisabled(_option)
    }];
  }, "option"),
  emptyMessage: "p-autocomplete-empty-message"
};
var AutoCompleteStyle = BaseStyle$1.extend({
  name: "autocomplete",
  theme: theme$a,
  classes: classes$a,
  inlineStyles: inlineStyles$1
});
var script$1$a = {
  name: "BaseAutoComplete",
  "extends": script$17,
  props: {
    suggestions: {
      type: Array,
      "default": null
    },
    optionLabel: null,
    optionDisabled: null,
    optionGroupLabel: null,
    optionGroupChildren: null,
    scrollHeight: {
      type: String,
      "default": "14rem"
    },
    dropdown: {
      type: Boolean,
      "default": false
    },
    dropdownMode: {
      type: String,
      "default": "blank"
    },
    multiple: {
      type: Boolean,
      "default": false
    },
    loading: {
      type: Boolean,
      "default": false
    },
    placeholder: {
      type: String,
      "default": null
    },
    dataKey: {
      type: String,
      "default": null
    },
    minLength: {
      type: Number,
      "default": 1
    },
    delay: {
      type: Number,
      "default": 300
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    forceSelection: {
      type: Boolean,
      "default": false
    },
    completeOnFocus: {
      type: Boolean,
      "default": false
    },
    inputId: {
      type: String,
      "default": null
    },
    inputStyle: {
      type: Object,
      "default": null
    },
    inputClass: {
      type: [String, Object],
      "default": null
    },
    panelStyle: {
      type: Object,
      "default": null
    },
    panelClass: {
      type: [String, Object],
      "default": null
    },
    overlayStyle: {
      type: Object,
      "default": null
    },
    overlayClass: {
      type: [String, Object],
      "default": null
    },
    dropdownIcon: {
      type: String,
      "default": null
    },
    dropdownClass: {
      type: [String, Object],
      "default": null
    },
    loader: {
      type: String,
      "default": null
    },
    loadingIcon: {
      type: String,
      "default": null
    },
    removeTokenIcon: {
      type: String,
      "default": null
    },
    chipIcon: {
      type: String,
      "default": null
    },
    virtualScrollerOptions: {
      type: Object,
      "default": null
    },
    autoOptionFocus: {
      type: Boolean,
      "default": false
    },
    selectOnFocus: {
      type: Boolean,
      "default": false
    },
    focusOnHover: {
      type: Boolean,
      "default": true
    },
    searchLocale: {
      type: String,
      "default": void 0
    },
    searchMessage: {
      type: String,
      "default": null
    },
    selectionMessage: {
      type: String,
      "default": null
    },
    emptySelectionMessage: {
      type: String,
      "default": null
    },
    emptySearchMessage: {
      type: String,
      "default": null
    },
    showEmptyMessage: {
      type: Boolean,
      "default": true
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    typeahead: {
      type: Boolean,
      "default": true
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    }
  },
  style: AutoCompleteStyle,
  provide: /* @__PURE__ */ __name(function provide41() {
    return {
      $pcAutoComplete: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$1$2(o2) {
  "@babel/helpers - typeof";
  return _typeof$1$2 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$1$2(o2);
}
__name(_typeof$1$2, "_typeof$1$2");
function _toConsumableArray$5(r2) {
  return _arrayWithoutHoles$5(r2) || _iterableToArray$5(r2) || _unsupportedIterableToArray$7(r2) || _nonIterableSpread$5();
}
__name(_toConsumableArray$5, "_toConsumableArray$5");
function _nonIterableSpread$5() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$5, "_nonIterableSpread$5");
function _unsupportedIterableToArray$7(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$7(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$7(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$7, "_unsupportedIterableToArray$7");
function _iterableToArray$5(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$5, "_iterableToArray$5");
function _arrayWithoutHoles$5(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$7(r2);
}
__name(_arrayWithoutHoles$5, "_arrayWithoutHoles$5");
function _arrayLikeToArray$7(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$7, "_arrayLikeToArray$7");
var script$h = {
  name: "AutoComplete",
  "extends": script$1$a,
  inheritAttrs: false,
  emits: ["change", "focus", "blur", "item-select", "item-unselect", "option-select", "option-unselect", "dropdown-click", "clear", "complete", "before-show", "before-hide", "show", "hide"],
  inject: {
    $pcFluid: {
      "default": null
    }
  },
  outsideClickListener: null,
  resizeListener: null,
  scrollHandler: null,
  overlay: null,
  virtualScroller: null,
  searchTimeout: null,
  dirty: false,
  data: /* @__PURE__ */ __name(function data21() {
    return {
      id: this.$attrs.id,
      clicked: false,
      focused: false,
      focusedOptionIndex: -1,
      focusedMultipleOptionIndex: -1,
      overlayVisible: false,
      searching: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId9(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    suggestions: /* @__PURE__ */ __name(function suggestions() {
      if (this.searching) {
        this.show();
        this.focusedOptionIndex = this.overlayVisible && this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : -1;
        this.searching = false;
        !this.showEmptyMessage && this.visibleOptions.length === 0 && this.hide();
      }
      this.autoUpdateModel();
    }, "suggestions")
  },
  mounted: /* @__PURE__ */ __name(function mounted20() {
    this.id = this.id || UniqueComponentId();
    this.autoUpdateModel();
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated12() {
    if (this.overlayVisible) {
      this.alignOverlay();
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount12() {
    this.unbindOutsideClickListener();
    this.unbindResizeListener();
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    if (this.overlay) {
      ZIndex$1.clear(this.overlay);
      this.overlay = null;
    }
  }, "beforeUnmount"),
  methods: {
    getOptionIndex: /* @__PURE__ */ __name(function getOptionIndex4(index2, fn) {
      return this.virtualScrollerDisabled ? index2 : fn && fn(index2)["index"];
    }, "getOptionIndex"),
    getOptionLabel: /* @__PURE__ */ __name(function getOptionLabel4(option5) {
      return this.optionLabel ? resolveFieldData$2(option5, this.optionLabel) : option5;
    }, "getOptionLabel"),
    getOptionValue: /* @__PURE__ */ __name(function getOptionValue4(option5) {
      return option5;
    }, "getOptionValue"),
    getOptionRenderKey: /* @__PURE__ */ __name(function getOptionRenderKey4(option5, index2) {
      return (this.dataKey ? resolveFieldData$2(option5, this.dataKey) : this.getOptionLabel(option5)) + "_" + index2;
    }, "getOptionRenderKey"),
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions5(option5, itemOptions, index2, key) {
      return this.ptm(key, {
        context: {
          selected: this.isSelected(option5),
          focused: this.focusedOptionIndex === this.getOptionIndex(index2, itemOptions),
          disabled: this.isOptionDisabled(option5)
        }
      });
    }, "getPTOptions"),
    isOptionDisabled: /* @__PURE__ */ __name(function isOptionDisabled4(option5) {
      return this.optionDisabled ? resolveFieldData$2(option5, this.optionDisabled) : false;
    }, "isOptionDisabled"),
    isOptionGroup: /* @__PURE__ */ __name(function isOptionGroup4(option5) {
      return this.optionGroupLabel && option5.optionGroup && option5.group;
    }, "isOptionGroup"),
    getOptionGroupLabel: /* @__PURE__ */ __name(function getOptionGroupLabel4(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupLabel);
    }, "getOptionGroupLabel"),
    getOptionGroupChildren: /* @__PURE__ */ __name(function getOptionGroupChildren4(optionGroup) {
      return resolveFieldData$2(optionGroup, this.optionGroupChildren);
    }, "getOptionGroupChildren"),
    getAriaPosInset: /* @__PURE__ */ __name(function getAriaPosInset4(index2) {
      var _this = this;
      return (this.optionGroupLabel ? index2 - this.visibleOptions.slice(0, index2).filter(function(option5) {
        return _this.isOptionGroup(option5);
      }).length : index2) + 1;
    }, "getAriaPosInset"),
    show: /* @__PURE__ */ __name(function show5(isFocus) {
      this.$emit("before-show");
      this.dirty = true;
      this.overlayVisible = true;
      this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : -1;
      isFocus && focus$2(this.multiple ? this.$refs.focusInput : this.$refs.focusInput.$el);
    }, "show"),
    hide: /* @__PURE__ */ __name(function hide5(isFocus) {
      var _this2 = this;
      var _hide = /* @__PURE__ */ __name(function _hide2() {
        var _this2$$refs$focusInp;
        _this2.$emit("before-hide");
        _this2.dirty = isFocus;
        _this2.overlayVisible = false;
        _this2.clicked = false;
        _this2.focusedOptionIndex = -1;
        isFocus && focus$2(_this2.multiple ? _this2.$refs.focusInput : (_this2$$refs$focusInp = _this2.$refs.focusInput) === null || _this2$$refs$focusInp === void 0 ? void 0 : _this2$$refs$focusInp.$el);
      }, "_hide");
      setTimeout(function() {
        _hide();
      }, 0);
    }, "hide"),
    onFocus: /* @__PURE__ */ __name(function onFocus8(event) {
      if (this.disabled) {
        return;
      }
      if (!this.dirty && this.completeOnFocus) {
        this.search(event, event.target.value, "focus");
      }
      this.dirty = true;
      this.focused = true;
      if (this.overlayVisible) {
        this.focusedOptionIndex = this.focusedOptionIndex !== -1 ? this.focusedOptionIndex : this.overlayVisible && this.autoOptionFocus ? this.findFirstFocusedOptionIndex() : -1;
        this.scrollInView(this.focusedOptionIndex);
      }
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur9(event) {
      var _this$formField$onBlu, _this$formField;
      this.dirty = false;
      this.focused = false;
      this.focusedOptionIndex = -1;
      this.$emit("blur", event);
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField);
    }, "onBlur"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown10(event) {
      if (this.disabled) {
        event.preventDefault();
        return;
      }
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event);
          break;
        case "ArrowLeft":
          this.onArrowLeftKey(event);
          break;
        case "ArrowRight":
          this.onArrowRightKey(event);
          break;
        case "Home":
          this.onHomeKey(event);
          break;
        case "End":
          this.onEndKey(event);
          break;
        case "PageDown":
          this.onPageDownKey(event);
          break;
        case "PageUp":
          this.onPageUpKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event);
          break;
        case "Backspace":
          this.onBackspaceKey(event);
          break;
      }
      this.clicked = false;
    }, "onKeyDown"),
    onInput: /* @__PURE__ */ __name(function onInput3(event) {
      var _this3 = this;
      if (this.typeahead) {
        if (this.searchTimeout) {
          clearTimeout(this.searchTimeout);
        }
        var query = event.target.value;
        if (!this.multiple) {
          this.updateModel(event, query);
        }
        if (query.length === 0) {
          this.hide();
          this.$emit("clear");
        } else {
          if (query.length >= this.minLength) {
            this.focusedOptionIndex = -1;
            this.searchTimeout = setTimeout(function() {
              _this3.search(event, query, "input");
            }, this.delay);
          } else {
            this.hide();
          }
        }
      }
    }, "onInput"),
    onChange: /* @__PURE__ */ __name(function onChange4(event) {
      var _this4 = this;
      if (this.forceSelection) {
        var valid = false;
        if (this.visibleOptions && !this.multiple) {
          var value3 = this.multiple ? this.$refs.focusInput.value : this.$refs.focusInput.$el.value;
          var matchedValue = this.visibleOptions.find(function(option5) {
            return _this4.isOptionMatched(option5, value3 || "");
          });
          if (matchedValue !== void 0) {
            valid = true;
            !this.isSelected(matchedValue) && this.onOptionSelect(event, matchedValue);
          }
        }
        if (!valid) {
          if (this.multiple) this.$refs.focusInput.value = "";
          else this.$refs.focusInput.$el.value = "";
          this.$emit("clear");
          !this.multiple && this.updateModel(event, null);
        }
      }
    }, "onChange"),
    onMultipleContainerFocus: /* @__PURE__ */ __name(function onMultipleContainerFocus() {
      if (this.disabled) {
        return;
      }
      this.focused = true;
    }, "onMultipleContainerFocus"),
    onMultipleContainerBlur: /* @__PURE__ */ __name(function onMultipleContainerBlur() {
      this.focusedMultipleOptionIndex = -1;
      this.focused = false;
    }, "onMultipleContainerBlur"),
    onMultipleContainerKeyDown: /* @__PURE__ */ __name(function onMultipleContainerKeyDown(event) {
      if (this.disabled) {
        event.preventDefault();
        return;
      }
      switch (event.code) {
        case "ArrowLeft":
          this.onArrowLeftKeyOnMultiple(event);
          break;
        case "ArrowRight":
          this.onArrowRightKeyOnMultiple(event);
          break;
        case "Backspace":
          this.onBackspaceKeyOnMultiple(event);
          break;
      }
    }, "onMultipleContainerKeyDown"),
    onContainerClick: /* @__PURE__ */ __name(function onContainerClick3(event) {
      this.clicked = true;
      if (this.disabled || this.searching || this.loading || this.isDropdownClicked(event)) {
        return;
      }
      if (!this.overlay || !this.overlay.contains(event.target)) {
        focus$2(this.multiple ? this.$refs.focusInput : this.$refs.focusInput.$el);
      }
    }, "onContainerClick"),
    onDropdownClick: /* @__PURE__ */ __name(function onDropdownClick(event) {
      var query = void 0;
      if (this.overlayVisible) {
        this.hide(true);
      } else {
        var target2 = this.multiple ? this.$refs.focusInput : this.$refs.focusInput.$el;
        focus$2(target2);
        query = target2.value;
        if (this.dropdownMode === "blank") this.search(event, "", "dropdown");
        else if (this.dropdownMode === "current") this.search(event, query, "dropdown");
      }
      this.$emit("dropdown-click", {
        originalEvent: event,
        query
      });
    }, "onDropdownClick"),
    onOptionSelect: /* @__PURE__ */ __name(function onOptionSelect4(event, option5) {
      var isHide = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : true;
      var value3 = this.getOptionValue(option5);
      if (this.multiple) {
        this.$refs.focusInput.value = "";
        if (!this.isSelected(option5)) {
          this.updateModel(event, [].concat(_toConsumableArray$5(this.d_value || []), [value3]));
        }
      } else {
        this.updateModel(event, value3);
      }
      this.$emit("item-select", {
        originalEvent: event,
        value: option5
      });
      this.$emit("option-select", {
        originalEvent: event,
        value: option5
      });
      isHide && this.hide(true);
    }, "onOptionSelect"),
    onOptionMouseMove: /* @__PURE__ */ __name(function onOptionMouseMove4(event, index2) {
      if (this.focusOnHover) {
        this.changeFocusedOptionIndex(event, index2);
      }
    }, "onOptionMouseMove"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick5(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.$el
      });
    }, "onOverlayClick"),
    onOverlayKeyDown: /* @__PURE__ */ __name(function onOverlayKeyDown3(event) {
      switch (event.code) {
        case "Escape":
          this.onEscapeKey(event);
          break;
      }
    }, "onOverlayKeyDown"),
    onArrowDownKey: /* @__PURE__ */ __name(function onArrowDownKey4(event) {
      if (!this.overlayVisible) {
        return;
      }
      var optionIndex = this.focusedOptionIndex !== -1 ? this.findNextOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findFirstOptionIndex() : this.findFirstFocusedOptionIndex();
      this.changeFocusedOptionIndex(event, optionIndex);
      event.preventDefault();
    }, "onArrowDownKey"),
    onArrowUpKey: /* @__PURE__ */ __name(function onArrowUpKey4(event) {
      if (!this.overlayVisible) {
        return;
      }
      if (event.altKey) {
        if (this.focusedOptionIndex !== -1) {
          this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
        }
        this.overlayVisible && this.hide();
        event.preventDefault();
      } else {
        var optionIndex = this.focusedOptionIndex !== -1 ? this.findPrevOptionIndex(this.focusedOptionIndex) : this.clicked ? this.findLastOptionIndex() : this.findLastFocusedOptionIndex();
        this.changeFocusedOptionIndex(event, optionIndex);
        event.preventDefault();
      }
    }, "onArrowUpKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey5(event) {
      var target2 = event.currentTarget;
      this.focusedOptionIndex = -1;
      if (this.multiple) {
        if (isEmpty$3(target2.value) && this.$filled) {
          focus$2(this.$refs.multiContainer);
          this.focusedMultipleOptionIndex = this.d_value.length;
        } else {
          event.stopPropagation();
        }
      }
    }, "onArrowLeftKey"),
    onArrowRightKey: /* @__PURE__ */ __name(function onArrowRightKey2(event) {
      this.focusedOptionIndex = -1;
      this.multiple && event.stopPropagation();
    }, "onArrowRightKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey5(event) {
      var currentTarget = event.currentTarget;
      var len = currentTarget.value.length;
      currentTarget.setSelectionRange(0, event.shiftKey ? len : 0);
      this.focusedOptionIndex = -1;
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey5(event) {
      var currentTarget = event.currentTarget;
      var len = currentTarget.value.length;
      currentTarget.setSelectionRange(event.shiftKey ? 0 : len, len);
      this.focusedOptionIndex = -1;
      event.preventDefault();
    }, "onEndKey"),
    onPageUpKey: /* @__PURE__ */ __name(function onPageUpKey6(event) {
      this.scrollInView(0);
      event.preventDefault();
    }, "onPageUpKey"),
    onPageDownKey: /* @__PURE__ */ __name(function onPageDownKey6(event) {
      this.scrollInView(this.visibleOptions.length - 1);
      event.preventDefault();
    }, "onPageDownKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey5(event) {
      if (!this.typeahead) {
        if (this.multiple) {
          this.updateModel(event, [].concat(_toConsumableArray$5(this.d_value || []), [event.target.value]));
          this.$refs.focusInput.value = "";
        }
      } else {
        if (!this.overlayVisible) {
          this.focusedOptionIndex = -1;
          this.onArrowDownKey(event);
        } else {
          if (this.focusedOptionIndex !== -1) {
            this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
          }
          this.hide();
        }
      }
      event.preventDefault();
    }, "onEnterKey"),
    onEscapeKey: /* @__PURE__ */ __name(function onEscapeKey3(event) {
      this.overlayVisible && this.hide(true);
      event.preventDefault();
    }, "onEscapeKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey3(event) {
      if (this.focusedOptionIndex !== -1) {
        this.onOptionSelect(event, this.visibleOptions[this.focusedOptionIndex]);
      }
      this.overlayVisible && this.hide();
    }, "onTabKey"),
    onBackspaceKey: /* @__PURE__ */ __name(function onBackspaceKey2(event) {
      if (this.multiple) {
        if (isNotEmpty$2(this.d_value) && !this.$refs.focusInput.value) {
          var removedValue = this.d_value[this.d_value.length - 1];
          var newValue2 = this.d_value.slice(0, -1);
          this.writeValue(newValue2, event);
          this.$emit("item-unselect", {
            originalEvent: event,
            value: removedValue
          });
          this.$emit("option-unselect", {
            originalEvent: event,
            value: removedValue
          });
        }
        event.stopPropagation();
      }
    }, "onBackspaceKey"),
    onArrowLeftKeyOnMultiple: /* @__PURE__ */ __name(function onArrowLeftKeyOnMultiple() {
      this.focusedMultipleOptionIndex = this.focusedMultipleOptionIndex < 1 ? 0 : this.focusedMultipleOptionIndex - 1;
    }, "onArrowLeftKeyOnMultiple"),
    onArrowRightKeyOnMultiple: /* @__PURE__ */ __name(function onArrowRightKeyOnMultiple() {
      this.focusedMultipleOptionIndex++;
      if (this.focusedMultipleOptionIndex > this.d_value.length - 1) {
        this.focusedMultipleOptionIndex = -1;
        focus$2(this.$refs.focusInput);
      }
    }, "onArrowRightKeyOnMultiple"),
    onBackspaceKeyOnMultiple: /* @__PURE__ */ __name(function onBackspaceKeyOnMultiple(event) {
      if (this.focusedMultipleOptionIndex !== -1) {
        this.removeOption(event, this.focusedMultipleOptionIndex);
      }
    }, "onBackspaceKeyOnMultiple"),
    onOverlayEnter: /* @__PURE__ */ __name(function onOverlayEnter4(el) {
      ZIndex$1.set("overlay", el, this.$primevue.config.zIndex.overlay);
      addStyle$1(el, {
        position: "absolute",
        top: "0",
        left: "0"
      });
      this.alignOverlay();
    }, "onOverlayEnter"),
    onOverlayAfterEnter: /* @__PURE__ */ __name(function onOverlayAfterEnter3() {
      this.bindOutsideClickListener();
      this.bindScrollListener();
      this.bindResizeListener();
      this.$emit("show");
    }, "onOverlayAfterEnter"),
    onOverlayLeave: /* @__PURE__ */ __name(function onOverlayLeave4() {
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
      this.$emit("hide");
      this.overlay = null;
    }, "onOverlayLeave"),
    onOverlayAfterLeave: /* @__PURE__ */ __name(function onOverlayAfterLeave4(el) {
      ZIndex$1.clear(el);
    }, "onOverlayAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay6() {
      var target2 = this.multiple ? this.$refs.multiContainer : this.$refs.focusInput.$el;
      if (this.appendTo === "self") {
        relativePosition$1(this.overlay, target2);
      } else {
        this.overlay.style.minWidth = getOuterWidth$1(target2) + "px";
        absolutePosition$1(this.overlay, target2);
      }
    }, "alignOverlay"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener5() {
      var _this5 = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          if (_this5.overlayVisible && _this5.overlay && _this5.isOutsideClicked(event)) {
            _this5.hide();
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener5() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener6() {
      var _this6 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.$refs.container, function() {
          if (_this6.overlayVisible) {
            _this6.hide();
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener6() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener6() {
      var _this7 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this7.overlayVisible && !isTouchDevice$1()) {
            _this7.hide();
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener6() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    isOutsideClicked: /* @__PURE__ */ __name(function isOutsideClicked2(event) {
      return !this.overlay.contains(event.target) && !this.isInputClicked(event) && !this.isDropdownClicked(event);
    }, "isOutsideClicked"),
    isInputClicked: /* @__PURE__ */ __name(function isInputClicked2(event) {
      if (this.multiple) return event.target === this.$refs.multiContainer || this.$refs.multiContainer.contains(event.target);
      else return event.target === this.$refs.focusInput.$el;
    }, "isInputClicked"),
    isDropdownClicked: /* @__PURE__ */ __name(function isDropdownClicked(event) {
      return this.$refs.dropdownButton ? event.target === this.$refs.dropdownButton || this.$refs.dropdownButton.contains(event.target) : false;
    }, "isDropdownClicked"),
    isOptionMatched: /* @__PURE__ */ __name(function isOptionMatched4(option5, value3) {
      var _this$getOptionLabel;
      return this.isValidOption(option5) && ((_this$getOptionLabel = this.getOptionLabel(option5)) === null || _this$getOptionLabel === void 0 ? void 0 : _this$getOptionLabel.toLocaleLowerCase(this.searchLocale)) === value3.toLocaleLowerCase(this.searchLocale);
    }, "isOptionMatched"),
    isValidOption: /* @__PURE__ */ __name(function isValidOption4(option5) {
      return isNotEmpty$2(option5) && !(this.isOptionDisabled(option5) || this.isOptionGroup(option5));
    }, "isValidOption"),
    isValidSelectedOption: /* @__PURE__ */ __name(function isValidSelectedOption4(option5) {
      return this.isValidOption(option5) && this.isSelected(option5);
    }, "isValidSelectedOption"),
    isEquals: /* @__PURE__ */ __name(function isEquals3(value1, value22) {
      return equals$2(value1, value22, this.equalityKey);
    }, "isEquals"),
    isSelected: /* @__PURE__ */ __name(function isSelected4(option5) {
      var _this8 = this;
      var optionValue = this.getOptionValue(option5);
      return this.multiple ? (this.d_value || []).some(function(value3) {
        return _this8.isEquals(value3, optionValue);
      }) : this.isEquals(this.d_value, this.getOptionValue(option5));
    }, "isSelected"),
    findFirstOptionIndex: /* @__PURE__ */ __name(function findFirstOptionIndex4() {
      var _this9 = this;
      return this.visibleOptions.findIndex(function(option5) {
        return _this9.isValidOption(option5);
      });
    }, "findFirstOptionIndex"),
    findLastOptionIndex: /* @__PURE__ */ __name(function findLastOptionIndex4() {
      var _this10 = this;
      return findLastIndex$2(this.visibleOptions, function(option5) {
        return _this10.isValidOption(option5);
      });
    }, "findLastOptionIndex"),
    findNextOptionIndex: /* @__PURE__ */ __name(function findNextOptionIndex4(index2) {
      var _this11 = this;
      var matchedOptionIndex = index2 < this.visibleOptions.length - 1 ? this.visibleOptions.slice(index2 + 1).findIndex(function(option5) {
        return _this11.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex + index2 + 1 : index2;
    }, "findNextOptionIndex"),
    findPrevOptionIndex: /* @__PURE__ */ __name(function findPrevOptionIndex4(index2) {
      var _this12 = this;
      var matchedOptionIndex = index2 > 0 ? findLastIndex$2(this.visibleOptions.slice(0, index2), function(option5) {
        return _this12.isValidOption(option5);
      }) : -1;
      return matchedOptionIndex > -1 ? matchedOptionIndex : index2;
    }, "findPrevOptionIndex"),
    findSelectedOptionIndex: /* @__PURE__ */ __name(function findSelectedOptionIndex4() {
      var _this13 = this;
      return this.$filled ? this.visibleOptions.findIndex(function(option5) {
        return _this13.isValidSelectedOption(option5);
      }) : -1;
    }, "findSelectedOptionIndex"),
    findFirstFocusedOptionIndex: /* @__PURE__ */ __name(function findFirstFocusedOptionIndex4() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findFirstOptionIndex() : selectedIndex;
    }, "findFirstFocusedOptionIndex"),
    findLastFocusedOptionIndex: /* @__PURE__ */ __name(function findLastFocusedOptionIndex4() {
      var selectedIndex = this.findSelectedOptionIndex();
      return selectedIndex < 0 ? this.findLastOptionIndex() : selectedIndex;
    }, "findLastFocusedOptionIndex"),
    search: /* @__PURE__ */ __name(function search2(event, query, source) {
      if (query === void 0 || query === null) {
        return;
      }
      if (source === "input" && query.trim().length === 0) {
        return;
      }
      this.searching = true;
      this.$emit("complete", {
        originalEvent: event,
        query
      });
    }, "search"),
    removeOption: /* @__PURE__ */ __name(function removeOption3(event, index2) {
      var _this14 = this;
      var removedOption = this.d_value[index2];
      var value3 = this.d_value.filter(function(_2, i2) {
        return i2 !== index2;
      }).map(function(option5) {
        return _this14.getOptionValue(option5);
      });
      this.updateModel(event, value3);
      this.$emit("item-unselect", {
        originalEvent: event,
        value: removedOption
      });
      this.$emit("option-unselect", {
        originalEvent: event,
        value: removedOption
      });
      this.dirty = true;
      focus$2(this.multiple ? this.$refs.focusInput : this.$refs.focusInput.$el);
    }, "removeOption"),
    changeFocusedOptionIndex: /* @__PURE__ */ __name(function changeFocusedOptionIndex4(event, index2) {
      if (this.focusedOptionIndex !== index2) {
        this.focusedOptionIndex = index2;
        this.scrollInView();
        if (this.selectOnFocus) {
          this.onOptionSelect(event, this.visibleOptions[index2], false);
        }
      }
    }, "changeFocusedOptionIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView8() {
      var _this15 = this;
      var index2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : -1;
      this.$nextTick(function() {
        var id4 = index2 !== -1 ? "".concat(_this15.id, "_").concat(index2) : _this15.focusedOptionId;
        var element = findSingle$1(_this15.list, 'li[id="'.concat(id4, '"]'));
        if (element) {
          element.scrollIntoView && element.scrollIntoView({
            block: "nearest",
            inline: "start"
          });
        } else if (!_this15.virtualScrollerDisabled) {
          _this15.virtualScroller && _this15.virtualScroller.scrollToIndex(index2 !== -1 ? index2 : _this15.focusedOptionIndex);
        }
      });
    }, "scrollInView"),
    autoUpdateModel: /* @__PURE__ */ __name(function autoUpdateModel4() {
      if (this.selectOnFocus && this.autoOptionFocus && !this.$filled) {
        this.focusedOptionIndex = this.findFirstFocusedOptionIndex();
        this.onOptionSelect(null, this.visibleOptions[this.focusedOptionIndex], false);
      }
    }, "autoUpdateModel"),
    updateModel: /* @__PURE__ */ __name(function updateModel8(event, value3) {
      this.writeValue(value3, event);
      this.$emit("change", {
        originalEvent: event,
        value: value3
      });
    }, "updateModel"),
    flatOptions: /* @__PURE__ */ __name(function flatOptions3(options5) {
      var _this16 = this;
      return (options5 || []).reduce(function(result, option5, index2) {
        result.push({
          optionGroup: option5,
          group: true,
          index: index2
        });
        var optionGroupChildren = _this16.getOptionGroupChildren(option5);
        optionGroupChildren && optionGroupChildren.forEach(function(o2) {
          return result.push(o2);
        });
        return result;
      }, []);
    }, "flatOptions"),
    overlayRef: /* @__PURE__ */ __name(function overlayRef3(el) {
      this.overlay = el;
    }, "overlayRef"),
    listRef: /* @__PURE__ */ __name(function listRef4(el, contentRef3) {
      this.list = el;
      contentRef3 && contentRef3(el);
    }, "listRef"),
    virtualScrollerRef: /* @__PURE__ */ __name(function virtualScrollerRef4(el) {
      this.virtualScroller = el;
    }, "virtualScrollerRef")
  },
  computed: {
    visibleOptions: /* @__PURE__ */ __name(function visibleOptions4() {
      return this.optionGroupLabel ? this.flatOptions(this.suggestions) : this.suggestions || [];
    }, "visibleOptions"),
    inputValue: /* @__PURE__ */ __name(function inputValue() {
      if (this.$filled) {
        if (_typeof$1$2(this.d_value) === "object") {
          var label8 = this.getOptionLabel(this.d_value);
          return label8 != null ? label8 : this.d_value;
        } else {
          return this.d_value;
        }
      } else {
        return "";
      }
    }, "inputValue"),
    // @deprecated use $filled instead.
    hasSelectedOption: /* @__PURE__ */ __name(function hasSelectedOption4() {
      return this.$filled;
    }, "hasSelectedOption"),
    equalityKey: /* @__PURE__ */ __name(function equalityKey4() {
      return this.dataKey;
    }, "equalityKey"),
    searchResultMessageText: /* @__PURE__ */ __name(function searchResultMessageText() {
      return isNotEmpty$2(this.visibleOptions) && this.overlayVisible ? this.searchMessageText.replaceAll("{0}", this.visibleOptions.length) : this.emptySearchMessageText;
    }, "searchResultMessageText"),
    searchMessageText: /* @__PURE__ */ __name(function searchMessageText() {
      return this.searchMessage || this.$primevue.config.locale.searchMessage || "";
    }, "searchMessageText"),
    emptySearchMessageText: /* @__PURE__ */ __name(function emptySearchMessageText() {
      return this.emptySearchMessage || this.$primevue.config.locale.emptySearchMessage || "";
    }, "emptySearchMessageText"),
    selectionMessageText: /* @__PURE__ */ __name(function selectionMessageText4() {
      return this.selectionMessage || this.$primevue.config.locale.selectionMessage || "";
    }, "selectionMessageText"),
    emptySelectionMessageText: /* @__PURE__ */ __name(function emptySelectionMessageText4() {
      return this.emptySelectionMessage || this.$primevue.config.locale.emptySelectionMessage || "";
    }, "emptySelectionMessageText"),
    selectedMessageText: /* @__PURE__ */ __name(function selectedMessageText4() {
      return this.$filled ? this.selectionMessageText.replaceAll("{0}", this.multiple ? this.d_value.length : "1") : this.emptySelectionMessageText;
    }, "selectedMessageText"),
    listAriaLabel: /* @__PURE__ */ __name(function listAriaLabel2() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.listLabel : void 0;
    }, "listAriaLabel"),
    focusedOptionId: /* @__PURE__ */ __name(function focusedOptionId4() {
      return this.focusedOptionIndex !== -1 ? "".concat(this.id, "_").concat(this.focusedOptionIndex) : null;
    }, "focusedOptionId"),
    focusedMultipleOptionId: /* @__PURE__ */ __name(function focusedMultipleOptionId() {
      return this.focusedMultipleOptionIndex !== -1 ? "".concat(this.id, "_multiple_option_").concat(this.focusedMultipleOptionIndex) : null;
    }, "focusedMultipleOptionId"),
    ariaSetSize: /* @__PURE__ */ __name(function ariaSetSize4() {
      var _this17 = this;
      return this.visibleOptions.filter(function(option5) {
        return !_this17.isOptionGroup(option5);
      }).length;
    }, "ariaSetSize"),
    virtualScrollerDisabled: /* @__PURE__ */ __name(function virtualScrollerDisabled4() {
      return !this.virtualScrollerOptions;
    }, "virtualScrollerDisabled"),
    panelId: /* @__PURE__ */ __name(function panelId() {
      return this.id + "_panel";
    }, "panelId")
  },
  components: {
    InputText: script$P,
    VirtualScroller: script$H,
    Portal: script$$,
    ChevronDownIcon: script$u,
    SpinnerIcon: script$12,
    Chip: script$A
  },
  directives: {
    ripple: Ripple
  }
};
function _typeof$5(o2) {
  "@babel/helpers - typeof";
  return _typeof$5 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$5(o2);
}
__name(_typeof$5, "_typeof$5");
function ownKeys$7(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$7, "ownKeys$7");
function _objectSpread$7(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$7(Object(t2), true).forEach(function(r3) {
      _defineProperty$5(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$7(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$7, "_objectSpread$7");
function _defineProperty$5(e2, r2, t2) {
  return (r2 = _toPropertyKey$4(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$5, "_defineProperty$5");
function _toPropertyKey$4(t2) {
  var i2 = _toPrimitive$4(t2, "string");
  return "symbol" == _typeof$5(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$4, "_toPropertyKey$4");
function _toPrimitive$4(t2, r2) {
  if ("object" != _typeof$5(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$5(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$4, "_toPrimitive$4");
var _hoisted_1$I = ["aria-activedescendant"];
var _hoisted_2$z = ["id", "aria-label", "aria-setsize", "aria-posinset"];
var _hoisted_3$k = ["id", "placeholder", "tabindex", "disabled", "aria-label", "aria-labelledby", "aria-expanded", "aria-controls", "aria-activedescendant", "aria-invalid"];
var _hoisted_4$c = ["disabled", "aria-expanded", "aria-controls"];
var _hoisted_5$c = ["id"];
var _hoisted_6$a = ["id", "aria-label"];
var _hoisted_7$5 = ["id"];
var _hoisted_8$3 = ["id", "aria-label", "aria-selected", "aria-disabled", "aria-setsize", "aria-posinset", "onClick", "onMousemove", "data-p-selected", "data-p-focus", "data-p-disabled"];
function render$f(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_InputText = resolveComponent("InputText");
  var _component_Chip = resolveComponent("Chip");
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_VirtualScroller = resolveComponent("VirtualScroller");
  var _component_Portal = resolveComponent("Portal");
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    ref: "container",
    "class": _ctx.cx("root"),
    style: _ctx.sx("root"),
    onClick: _cache[11] || (_cache[11] = function() {
      return $options.onContainerClick && $options.onContainerClick.apply($options, arguments);
    })
  }, _ctx.ptmi("root")), [!_ctx.multiple ? (openBlock(), createBlock(_component_InputText, {
    key: 0,
    ref: "focusInput",
    id: _ctx.inputId,
    type: "text",
    name: _ctx.$formName,
    "class": normalizeClass([_ctx.cx("pcInputText"), _ctx.inputClass]),
    style: normalizeStyle(_ctx.inputStyle),
    value: $options.inputValue,
    placeholder: _ctx.placeholder,
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    fluid: _ctx.$fluid,
    disabled: _ctx.disabled,
    size: _ctx.size,
    invalid: _ctx.invalid,
    variant: _ctx.variant,
    autocomplete: "off",
    role: "combobox",
    "aria-label": _ctx.ariaLabel,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-haspopup": "listbox",
    "aria-autocomplete": "list",
    "aria-expanded": $data.overlayVisible,
    "aria-controls": $options.panelId,
    "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
    onFocus: $options.onFocus,
    onBlur: $options.onBlur,
    onKeydown: $options.onKeyDown,
    onInput: $options.onInput,
    onChange: $options.onChange,
    unstyled: _ctx.unstyled,
    pt: _ctx.ptm("pcInputText")
  }, null, 8, ["id", "name", "class", "style", "value", "placeholder", "tabindex", "fluid", "disabled", "size", "invalid", "variant", "aria-label", "aria-labelledby", "aria-expanded", "aria-controls", "aria-activedescendant", "onFocus", "onBlur", "onKeydown", "onInput", "onChange", "unstyled", "pt"])) : createCommentVNode("", true), _ctx.multiple ? (openBlock(), createElementBlock("ul", mergeProps$2({
    key: 1,
    ref: "multiContainer",
    "class": _ctx.cx("inputMultiple"),
    tabindex: "-1",
    role: "listbox",
    "aria-orientation": "horizontal",
    "aria-activedescendant": $data.focused ? $options.focusedMultipleOptionId : void 0,
    onFocus: _cache[5] || (_cache[5] = function() {
      return $options.onMultipleContainerFocus && $options.onMultipleContainerFocus.apply($options, arguments);
    }),
    onBlur: _cache[6] || (_cache[6] = function() {
      return $options.onMultipleContainerBlur && $options.onMultipleContainerBlur.apply($options, arguments);
    }),
    onKeydown: _cache[7] || (_cache[7] = function() {
      return $options.onMultipleContainerKeyDown && $options.onMultipleContainerKeyDown.apply($options, arguments);
    })
  }, _ctx.ptm("inputMultiple")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.d_value, function(option5, i2) {
    return openBlock(), createElementBlock("li", mergeProps$2({
      key: "".concat(i2, "_").concat($options.getOptionLabel(option5)),
      id: $data.id + "_multiple_option_" + i2,
      "class": _ctx.cx("chipItem", {
        i: i2
      }),
      role: "option",
      "aria-label": $options.getOptionLabel(option5),
      "aria-selected": true,
      "aria-setsize": _ctx.d_value.length,
      "aria-posinset": i2 + 1,
      ref_for: true
    }, _ctx.ptm("chipItem")), [renderSlot(_ctx.$slots, "chip", mergeProps$2({
      "class": _ctx.cx("pcChip"),
      value: option5,
      index: i2,
      removeCallback: /* @__PURE__ */ __name(function removeCallback(event) {
        return $options.removeOption(event, i2);
      }, "removeCallback"),
      ref_for: true
    }, _ctx.ptm("pcChip")), function() {
      return [createVNode(_component_Chip, {
        "class": normalizeClass(_ctx.cx("pcChip")),
        label: $options.getOptionLabel(option5),
        removeIcon: _ctx.chipIcon || _ctx.removeTokenIcon,
        removable: "",
        unstyled: _ctx.unstyled,
        onRemove: /* @__PURE__ */ __name(function onRemove($event) {
          return $options.removeOption($event, i2);
        }, "onRemove"),
        pt: _ctx.ptm("pcChip")
      }, {
        removeicon: withCtx(function() {
          return [renderSlot(_ctx.$slots, _ctx.$slots.chipicon ? "chipicon" : "removetokenicon", {
            "class": normalizeClass(_ctx.cx("chipIcon")),
            index: i2,
            removeCallback: /* @__PURE__ */ __name(function removeCallback(event) {
              return $options.removeOption(event, i2);
            }, "removeCallback")
          })];
        }),
        _: 2
      }, 1032, ["class", "label", "removeIcon", "unstyled", "onRemove", "pt"])];
    })], 16, _hoisted_2$z);
  }), 128)), createBaseVNode("li", mergeProps$2({
    "class": _ctx.cx("inputChip"),
    role: "option"
  }, _ctx.ptm("inputChip")), [createBaseVNode("input", mergeProps$2({
    ref: "focusInput",
    id: _ctx.inputId,
    type: "text",
    style: _ctx.inputStyle,
    "class": _ctx.inputClass,
    placeholder: _ctx.placeholder,
    tabindex: !_ctx.disabled ? _ctx.tabindex : -1,
    disabled: _ctx.disabled,
    autocomplete: "off",
    role: "combobox",
    "aria-label": _ctx.ariaLabel,
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-haspopup": "listbox",
    "aria-autocomplete": "list",
    "aria-expanded": $data.overlayVisible,
    "aria-controls": $data.id + "_list",
    "aria-activedescendant": $data.focused ? $options.focusedOptionId : void 0,
    "aria-invalid": _ctx.invalid || void 0,
    onFocus: _cache[0] || (_cache[0] = function() {
      return $options.onFocus && $options.onFocus.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    }),
    onKeydown: _cache[2] || (_cache[2] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    }),
    onInput: _cache[3] || (_cache[3] = function() {
      return $options.onInput && $options.onInput.apply($options, arguments);
    }),
    onChange: _cache[4] || (_cache[4] = function() {
      return $options.onChange && $options.onChange.apply($options, arguments);
    })
  }, _ctx.ptm("input")), null, 16, _hoisted_3$k)], 16)], 16, _hoisted_1$I)) : createCommentVNode("", true), $data.searching || _ctx.loading ? renderSlot(_ctx.$slots, _ctx.$slots.loader ? "loader" : "loadingicon", {
    key: 2,
    "class": normalizeClass(_ctx.cx("loader"))
  }, function() {
    return [_ctx.loader || _ctx.loadingIcon ? (openBlock(), createElementBlock("i", mergeProps$2({
      key: 0,
      "class": ["pi-spin", _ctx.cx("loader"), _ctx.loader, _ctx.loadingIcon],
      "aria-hidden": "true"
    }, _ctx.ptm("loader")), null, 16)) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
      key: 1,
      "class": _ctx.cx("loader"),
      spin: "",
      "aria-hidden": "true"
    }, _ctx.ptm("loader")), null, 16, ["class"]))];
  }) : createCommentVNode("", true), renderSlot(_ctx.$slots, _ctx.$slots.dropdown ? "dropdown" : "dropdownbutton", {
    toggleCallback: /* @__PURE__ */ __name(function toggleCallback(event) {
      return $options.onDropdownClick(event);
    }, "toggleCallback")
  }, function() {
    return [_ctx.dropdown ? (openBlock(), createElementBlock("button", mergeProps$2({
      key: 0,
      ref: "dropdownButton",
      type: "button",
      "class": [_ctx.cx("dropdown"), _ctx.dropdownClass],
      disabled: _ctx.disabled,
      "aria-haspopup": "listbox",
      "aria-expanded": $data.overlayVisible,
      "aria-controls": $options.panelId,
      onClick: _cache[8] || (_cache[8] = function() {
        return $options.onDropdownClick && $options.onDropdownClick.apply($options, arguments);
      })
    }, _ctx.ptm("dropdown")), [renderSlot(_ctx.$slots, "dropdownicon", {
      "class": normalizeClass(_ctx.dropdownIcon)
    }, function() {
      return [(openBlock(), createBlock(resolveDynamicComponent(_ctx.dropdownIcon ? "span" : "ChevronDownIcon"), mergeProps$2({
        "class": _ctx.dropdownIcon
      }, _ctx.ptm("dropdownIcon")), null, 16, ["class"]))];
    })], 16, _hoisted_4$c)) : createCommentVNode("", true)];
  }), createBaseVNode("span", mergeProps$2({
    role: "status",
    "aria-live": "polite",
    "class": "p-hidden-accessible"
  }, _ctx.ptm("hiddenSearchResult"), {
    "data-p-hidden-accessible": true
  }), toDisplayString$1($options.searchResultMessageText), 17), createVNode(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-connected-overlay",
        onEnter: $options.onOverlayEnter,
        onAfterEnter: $options.onOverlayAfterEnter,
        onLeave: $options.onOverlayLeave,
        onAfterLeave: $options.onOverlayAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [$data.overlayVisible ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.overlayRef,
            id: $options.panelId,
            "class": [_ctx.cx("overlay"), _ctx.panelClass, _ctx.overlayClass],
            style: _objectSpread$7(_objectSpread$7({}, _ctx.panelStyle), _ctx.overlayStyle),
            onClick: _cache[9] || (_cache[9] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            }),
            onKeydown: _cache[10] || (_cache[10] = function() {
              return $options.onOverlayKeyDown && $options.onOverlayKeyDown.apply($options, arguments);
            })
          }, _ctx.ptm("overlay")), [renderSlot(_ctx.$slots, "header", {
            value: _ctx.d_value,
            suggestions: $options.visibleOptions
          }), createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("listContainer"),
            style: {
              "max-height": $options.virtualScrollerDisabled ? _ctx.scrollHeight : ""
            }
          }, _ctx.ptm("listContainer")), [createVNode(_component_VirtualScroller, mergeProps$2({
            ref: $options.virtualScrollerRef
          }, _ctx.virtualScrollerOptions, {
            style: {
              height: _ctx.scrollHeight
            },
            items: $options.visibleOptions,
            tabindex: -1,
            disabled: $options.virtualScrollerDisabled,
            pt: _ctx.ptm("virtualScroller")
          }), createSlots({
            content: withCtx(function(_ref) {
              var styleClass = _ref.styleClass, contentRef3 = _ref.contentRef, items2 = _ref.items, getItemOptions = _ref.getItemOptions, contentStyle = _ref.contentStyle, itemSize2 = _ref.itemSize;
              return [createBaseVNode("ul", mergeProps$2({
                ref: /* @__PURE__ */ __name(function ref2(el) {
                  return $options.listRef(el, contentRef3);
                }, "ref"),
                id: $data.id + "_list",
                "class": [_ctx.cx("list"), styleClass],
                style: contentStyle,
                role: "listbox",
                "aria-label": $options.listAriaLabel
              }, _ctx.ptm("list")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(items2, function(option5, i2) {
                return openBlock(), createElementBlock(Fragment$1, {
                  key: $options.getOptionRenderKey(option5, $options.getOptionIndex(i2, getItemOptions))
                }, [$options.isOptionGroup(option5) ? (openBlock(), createElementBlock("li", mergeProps$2({
                  key: 0,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  "class": _ctx.cx("optionGroup"),
                  role: "option",
                  ref_for: true
                }, _ctx.ptm("optionGroup")), [renderSlot(_ctx.$slots, "optiongroup", {
                  option: option5.optionGroup,
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createTextVNode(toDisplayString$1($options.getOptionGroupLabel(option5.optionGroup)), 1)];
                })], 16, _hoisted_7$5)) : withDirectives((openBlock(), createElementBlock("li", mergeProps$2({
                  key: 1,
                  id: $data.id + "_" + $options.getOptionIndex(i2, getItemOptions),
                  style: {
                    height: itemSize2 ? itemSize2 + "px" : void 0
                  },
                  "class": _ctx.cx("option", {
                    option: option5,
                    i: i2,
                    getItemOptions
                  }),
                  role: "option",
                  "aria-label": $options.getOptionLabel(option5),
                  "aria-selected": $options.isSelected(option5),
                  "aria-disabled": $options.isOptionDisabled(option5),
                  "aria-setsize": $options.ariaSetSize,
                  "aria-posinset": $options.getAriaPosInset($options.getOptionIndex(i2, getItemOptions)),
                  onClick: /* @__PURE__ */ __name(function onClick5($event) {
                    return $options.onOptionSelect($event, option5);
                  }, "onClick"),
                  onMousemove: /* @__PURE__ */ __name(function onMousemove($event) {
                    return $options.onOptionMouseMove($event, $options.getOptionIndex(i2, getItemOptions));
                  }, "onMousemove"),
                  "data-p-selected": $options.isSelected(option5),
                  "data-p-focus": $data.focusedOptionIndex === $options.getOptionIndex(i2, getItemOptions),
                  "data-p-disabled": $options.isOptionDisabled(option5),
                  ref_for: true
                }, $options.getPTOptions(option5, getItemOptions, i2, "option")), [renderSlot(_ctx.$slots, "option", {
                  option: option5,
                  index: $options.getOptionIndex(i2, getItemOptions)
                }, function() {
                  return [createTextVNode(toDisplayString$1($options.getOptionLabel(option5)), 1)];
                })], 16, _hoisted_8$3)), [[_directive_ripple]])], 64);
              }), 128)), _ctx.showEmptyMessage && (!items2 || items2 && items2.length === 0) ? (openBlock(), createElementBlock("li", mergeProps$2({
                key: 0,
                "class": _ctx.cx("emptyMessage"),
                role: "option"
              }, _ctx.ptm("emptyMessage")), [renderSlot(_ctx.$slots, "empty", {}, function() {
                return [createTextVNode(toDisplayString$1($options.searchResultMessageText), 1)];
              })], 16)) : createCommentVNode("", true)], 16, _hoisted_6$a)];
            }),
            _: 2
          }, [_ctx.$slots.loader ? {
            name: "loader",
            fn: withCtx(function(_ref2) {
              var options5 = _ref2.options;
              return [renderSlot(_ctx.$slots, "loader", {
                options: options5
              })];
            }),
            key: "0"
          } : void 0]), 1040, ["style", "items", "disabled", "pt"])], 16), renderSlot(_ctx.$slots, "footer", {
            value: _ctx.d_value,
            suggestions: $options.visibleOptions
          }), createBaseVNode("span", mergeProps$2({
            role: "status",
            "aria-live": "polite",
            "class": "p-hidden-accessible"
          }, _ctx.ptm("hiddenSelectedMessage"), {
            "data-p-hidden-accessible": true
          }), toDisplayString$1($options.selectedMessageText), 17)], 16, _hoisted_5$c)) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onAfterEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 3
  }, 8, ["appendTo"])], 16);
}
__name(render$f, "render$f");
script$h.render = render$f;
var script$g = {
  name: "Dropdown",
  "extends": script$t,
  mounted: /* @__PURE__ */ __name(function mounted21() {
    console.warn("Deprecated since v4. Use Select component instead.");
  }, "mounted")
};
const _hoisted_1$H = { class: "flex items-center gap-1" };
const _hoisted_2$y = { class: "text-muted" };
const _sfc_main$K = /* @__PURE__ */ defineComponent({
  __name: "SearchFilterDropdown",
  props: {
    options: {},
    label: {},
    modelValue: {}
  },
  emits: ["update:modelValue"],
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$H, [
        createBaseVNode("span", _hoisted_2$y, toDisplayString$1(_ctx.label) + ":", 1),
        createVNode(unref(script$g), {
          modelValue: _ctx.modelValue,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => _ctx.$emit("update:modelValue", $event)),
          options: _ctx.options,
          optionLabel: "label",
          optionValue: "id",
          class: "min-w-[6rem] border-none bg-transparent shadow-none",
          pt: {
            input: { class: "py-0 px-1 border-none" },
            trigger: { class: "hidden" },
            panel: { class: "shadow-md" },
            item: { class: "py-2 px-3 text-sm" }
          }
        }, null, 8, ["modelValue", "options"])
      ]);
    };
  }
});
const _hoisted_1$G = { class: "relative w-full p-6" };
const _hoisted_2$x = { class: "flex items-center w-full" };
const _hoisted_3$j = { class: "flex mt-3 text-sm" };
const _hoisted_4$b = { class: "flex gap-6 ml-1" };
const _hoisted_5$b = { class: "flex items-center gap-4 ml-6" };
const _hoisted_6$9 = {
  key: 0,
  class: "text-color-secondary"
};
const _sfc_main$J = /* @__PURE__ */ defineComponent({
  __name: "RegistrySearchBar",
  props: /* @__PURE__ */ mergeModels({
    searchResults: {},
    suggestions: {}
  }, {
    "searchQuery": {},
    "searchQueryModifiers": {},
    "searchMode": { default: "packs" },
    "searchModeModifiers": {},
    "sortField": { default: "downloads" },
    "sortFieldModifiers": {}
  }),
  emits: ["update:searchQuery", "update:searchMode", "update:sortField"],
  setup(__props) {
    const searchQuery = useModel(__props, "searchQuery");
    const searchMode = useModel(__props, "searchMode");
    const sortField = useModel(__props, "sortField");
    const { t: t2 } = useI18n();
    const hasResults = computed(
      () => searchQuery.value?.trim() && __props.searchResults?.length
    );
    const sortOptions = [
      { id: "downloads", label: t2("manager.sort.downloads") },
      { id: "name", label: t2("g.name") },
      { id: "rating", label: t2("manager.sort.rating") },
      { id: "category", label: t2("g.category") }
    ];
    const filterOptions = [
      { id: "packs", label: t2("manager.filter.nodePack") },
      { id: "nodes", label: t2("g.nodes") }
    ];
    const onOptionSelect6 = /* @__PURE__ */ __name((event) => {
      searchQuery.value = event.value.query;
    }, "onOptionSelect");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$G, [
        createBaseVNode("div", _hoisted_2$x, [
          createVNode(unref(script$h), {
            modelValue: searchQuery.value,
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => searchQuery.value = $event),
            modelModifiers: { lazy: true },
            suggestions: _ctx.suggestions || [],
            placeholder: _ctx.$t("manager.searchPlaceholder"),
            "complete-on-focus": false,
            delay: 8,
            optionLabel: "query",
            class: "w-full",
            onComplete: unref(lodashExports.stubTrue),
            onOptionSelect: onOptionSelect6,
            pt: {
              pcInputText: {
                root: {
                  autofocus: true,
                  class: "w-5/12 rounded-2xl"
                }
              },
              loader: {
                style: "display: none"
              }
            }
          }, null, 8, ["modelValue", "suggestions", "placeholder", "onComplete"])
        ]),
        createBaseVNode("div", _hoisted_3$j, [
          createBaseVNode("div", _hoisted_4$b, [
            createVNode(_sfc_main$K, {
              modelValue: searchMode.value,
              "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => searchMode.value = $event),
              options: filterOptions,
              label: _ctx.$t("g.filter")
            }, null, 8, ["modelValue", "label"]),
            createVNode(_sfc_main$K, {
              modelValue: sortField.value,
              "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => sortField.value = $event),
              options: sortOptions,
              label: _ctx.$t("g.sort")
            }, null, 8, ["modelValue", "label"])
          ]),
          createBaseVNode("div", _hoisted_5$b, [
            hasResults.value ? (openBlock(), createElementBlock("small", _hoisted_6$9, toDisplayString$1(_ctx.$t("g.resultsCount", { count: _ctx.searchResults?.length || 0 })), 1)) : createCommentVNode("", true)
          ])
        ])
      ]);
    };
  }
});
var theme$9 = /* @__PURE__ */ __name(function theme37(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-skeleton {\n    overflow: hidden;\n    background: ".concat(dt2("skeleton.background"), ";\n    border-radius: ").concat(dt2("skeleton.border.radius"), ';\n}\n\n.p-skeleton::after {\n    content: "";\n    animation: p-skeleton-animation 1.2s infinite;\n    height: 100%;\n    left: 0;\n    position: absolute;\n    right: 0;\n    top: 0;\n    transform: translateX(-100%);\n    z-index: 1;\n    background: linear-gradient(90deg, rgba(255, 255, 255, 0), ').concat(dt2("skeleton.animation.background"), ", rgba(255, 255, 255, 0));\n}\n\n[dir='rtl'] .p-skeleton::after {\n    animation-name: p-skeleton-animation-rtl;\n}\n\n.p-skeleton-circle {\n    border-radius: 50%;\n}\n\n.p-skeleton-animation-none::after {\n    animation: none;\n}\n\n@keyframes p-skeleton-animation {\n    from {\n        transform: translateX(-100%);\n    }\n    to {\n        transform: translateX(100%);\n    }\n}\n\n@keyframes p-skeleton-animation-rtl {\n    from {\n        transform: translateX(100%);\n    }\n    to {\n        transform: translateX(-100%);\n    }\n}\n");
}, "theme");
var inlineStyles = {
  root: {
    position: "relative"
  }
};
var classes$9 = {
  root: /* @__PURE__ */ __name(function root28(_ref2) {
    var props = _ref2.props;
    return ["p-skeleton p-component", {
      "p-skeleton-circle": props.shape === "circle",
      "p-skeleton-animation-none": props.animation === "none"
    }];
  }, "root")
};
var SkeletonStyle = BaseStyle$1.extend({
  name: "skeleton",
  theme: theme$9,
  classes: classes$9,
  inlineStyles
});
var script$1$9 = {
  name: "BaseSkeleton",
  "extends": script$1b,
  props: {
    shape: {
      type: String,
      "default": "rectangle"
    },
    size: {
      type: String,
      "default": null
    },
    width: {
      type: String,
      "default": "100%"
    },
    height: {
      type: String,
      "default": "1rem"
    },
    borderRadius: {
      type: String,
      "default": null
    },
    animation: {
      type: String,
      "default": "wave"
    }
  },
  style: SkeletonStyle,
  provide: /* @__PURE__ */ __name(function provide42() {
    return {
      $pcSkeleton: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$f = {
  name: "Skeleton",
  "extends": script$1$9,
  inheritAttrs: false,
  computed: {
    containerStyle: /* @__PURE__ */ __name(function containerStyle() {
      if (this.size) return {
        width: this.size,
        height: this.size,
        borderRadius: this.borderRadius
      };
      else return {
        width: this.width,
        height: this.height,
        borderRadius: this.borderRadius
      };
    }, "containerStyle")
  }
};
function render$e(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    style: [_ctx.sx("root"), $options.containerStyle],
    "aria-hidden": "true"
  }, _ctx.ptmi("root")), null, 16);
}
__name(render$e, "render$e");
script$f.render = render$e;
const _hoisted_1$F = {
  class: "rounded-lg border shadow-sm h-full overflow-hidden flex flex-col",
  "data-virtual-grid-item": ""
};
const _hoisted_2$w = { class: "w-full px-4 py-3 flex justify-between items-center border-b" };
const _hoisted_3$i = { class: "flex items-center" };
const _hoisted_4$a = { class: "w-6 h-6 flex items-center justify-center" };
const _hoisted_5$a = { class: "flex-1 p-4 flex" };
const _hoisted_6$8 = { class: "flex-shrink-0 mr-4" };
const _hoisted_7$4 = { class: "flex-1 flex flex-col overflow-hidden" };
const _hoisted_8$2 = { class: "mb-3" };
const _hoisted_9$2 = { class: "flex gap-2" };
const _hoisted_10$2 = { class: "w-full px-5 py-4 flex justify-between items-center border-t" };
const _sfc_main$I = /* @__PURE__ */ defineComponent({
  __name: "PackCardSkeleton",
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$F, [
        createBaseVNode("div", _hoisted_2$w, [
          createBaseVNode("div", _hoisted_3$i, [
            createBaseVNode("div", _hoisted_4$a, [
              createVNode(unref(script$f), {
                shape: "circle",
                width: "1.5rem",
                height: "1.5rem"
              })
            ]),
            createVNode(unref(script$f), {
              width: "5rem",
              height: "1rem",
              class: "ml-2"
            })
          ]),
          createVNode(unref(script$f), {
            width: "4rem",
            height: "1.75rem",
            borderRadius: "0.75rem"
          })
        ]),
        createBaseVNode("div", _hoisted_5$a, [
          createBaseVNode("div", _hoisted_6$8, [
            createVNode(unref(script$f), {
              width: "4rem",
              height: "4rem",
              borderRadius: "0.5rem"
            })
          ]),
          createBaseVNode("div", _hoisted_7$4, [
            createVNode(unref(script$f), {
              width: "80%",
              height: "1rem",
              class: "mb-2"
            }),
            createBaseVNode("div", _hoisted_8$2, [
              createVNode(unref(script$f), {
                width: "100%",
                height: "0.75rem",
                class: "mb-1"
              }),
              createVNode(unref(script$f), {
                width: "95%",
                height: "0.75rem",
                class: "mb-1"
              }),
              createVNode(unref(script$f), {
                width: "90%",
                height: "0.75rem"
              })
            ]),
            createBaseVNode("div", _hoisted_9$2, [
              createVNode(unref(script$f), {
                width: "4rem",
                height: "1.5rem",
                borderRadius: "0.75rem"
              }),
              createVNode(unref(script$f), {
                width: "5rem",
                height: "1.5rem",
                borderRadius: "0.75rem"
              })
            ])
          ])
        ]),
        createBaseVNode("div", _hoisted_10$2, [
          createVNode(unref(script$f), {
            width: "4rem",
            height: "0.8rem"
          }),
          createVNode(unref(script$f), {
            width: "6rem",
            height: "0.8rem"
          })
        ])
      ]);
    };
  }
});
const _sfc_main$H = /* @__PURE__ */ defineComponent({
  __name: "GridSkeleton",
  props: {
    skeletonCardCount: { default: 12 },
    gridStyle: {}
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        style: normalizeStyle(_ctx.gridStyle)
      }, [
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.skeletonCardCount, (n2) => {
          return openBlock(), createBlock(_sfc_main$I, { key: n2 });
        }), 128))
      ], 4);
    };
  }
});
const useResponsiveCollapse = /* @__PURE__ */ __name((breakpointThreshold = "lg") => {
  const breakpoints = useBreakpoints(breakpointsTailwind);
  const isSmallScreen = breakpoints.smallerOrEqual(breakpointThreshold);
  const isOpen = ref(!isSmallScreen.value);
  const onIsSmallScreenChange = /* @__PURE__ */ __name(() => {
    if (isSmallScreen.value && isOpen.value) {
      isOpen.value = false;
    } else if (!isSmallScreen.value && !isOpen.value) {
      isOpen.value = true;
    }
  }, "onIsSmallScreenChange");
  watch(isSmallScreen, onIsSmallScreenChange);
  return {
    breakpoints,
    isOpen,
    isSmallScreen,
    open: /* @__PURE__ */ __name(() => isOpen.value = true, "open"),
    close: /* @__PURE__ */ __name(() => isOpen.value = false, "close"),
    toggle: /* @__PURE__ */ __name(() => isOpen.value = !isOpen.value, "toggle")
  };
}, "useResponsiveCollapse");
const PACK_LIST_CACHE_SIZE = 20;
const PACK_BY_ID_CACHE_SIZE = 50;
const useComfyRegistryStore = /* @__PURE__ */ defineStore("comfyRegistry", () => {
  const registryService = useComfyRegistryService();
  const listAllPacks = useCachedRequest(
    registryService.listAllPacks,
    { maxSize: PACK_LIST_CACHE_SIZE }
  );
  const getPackById = useCachedRequest(
    async (params) => {
      if (!params) return null;
      return registryService.getPackById(params);
    },
    { maxSize: PACK_BY_ID_CACHE_SIZE }
  );
  const getNodeDefs = useCachedRequest(registryService.getNodeDefs, { maxSize: PACK_BY_ID_CACHE_SIZE });
  const clearCache = /* @__PURE__ */ __name(() => {
    getNodeDefs.clear();
    listAllPacks.clear();
    getPackById.clear();
  }, "clearCache");
  const cancelRequests = /* @__PURE__ */ __name(() => {
    getNodeDefs.cancel();
    listAllPacks.cancel();
    getPackById.cancel();
  }, "cancelRequests");
  return {
    listAllPacks,
    getPackById,
    getNodeDefs,
    clearCache,
    cancelRequests,
    isLoading: registryService.isLoading,
    error: registryService.error
  };
});
const DEFAULT_MAX_CONCURRENT = 6;
const useNodePacks = /* @__PURE__ */ __name((packsIds, options5 = {}) => {
  const { immediate = false, maxConcurrent = DEFAULT_MAX_CONCURRENT } = options5;
  const { getPackById } = useComfyRegistryStore();
  const nodePacks = ref([]);
  const processedIds = ref(/* @__PURE__ */ new Set());
  const queuedPackIds = isRef(packsIds) ? packsIds : ref(packsIds);
  const remainingIds = computed(
    () => queuedPackIds.value?.filter((id4) => !processedIds.value.has(id4))
  );
  const chunks = computed(
    () => remainingIds.value?.length ? lodashExports.chunk(remainingIds.value, maxConcurrent) : []
  );
  const fetchPack = /* @__PURE__ */ __name((id4) => id4 ? getPackById.call(id4) : null, "fetchPack");
  const toRequestBatch = /* @__PURE__ */ __name(async (ids) => Promise.all(ids.map(fetchPack)), "toRequestBatch");
  const isValidResponse = /* @__PURE__ */ __name((response) => response !== null, "isValidResponse");
  const fetchPacks = /* @__PURE__ */ __name(async () => {
    for (const chunk2 of chunks.value) {
      const resolvedChunk = await toRequestBatch(chunk2);
      chunk2.forEach((id4) => processedIds.value.add(id4));
      if (!resolvedChunk) continue;
      nodePacks.value.push(...resolvedChunk.filter(isValidResponse));
    }
  }, "fetchPacks");
  const { isReady, isLoading, error: error2, execute } = useAsyncState(
    fetchPacks,
    null,
    {
      immediate
    }
  );
  const clear = /* @__PURE__ */ __name(() => {
    queuedPackIds.value = [];
    isReady.value = false;
    isLoading.value = false;
  }, "clear");
  const cleanup = /* @__PURE__ */ __name(() => {
    getPackById.cancel();
    clear();
  }, "cleanup");
  return {
    error: error2,
    isLoading,
    isReady,
    nodePacks,
    startFetch: execute,
    cleanup
  };
}, "useNodePacks");
const useInstalledPacks = /* @__PURE__ */ __name((options5 = {}) => {
  const comfyManagerStore = useComfyManagerStore();
  const installedPackIds = computed(
    () => Array.from(comfyManagerStore.installedPacksIds)
  );
  const { startFetch, cleanup, error: error2, isLoading, nodePacks } = useNodePacks(
    installedPackIds,
    options5
  );
  const filterInstalledPack = /* @__PURE__ */ __name((packs) => packs.filter((pack) => comfyManagerStore.isPackInstalled(pack.id)), "filterInstalledPack");
  onUnmounted(() => {
    cleanup();
  });
  return {
    error: error2,
    isLoading,
    installedPacks: nodePacks,
    startFetchInstalled: startFetch,
    filterInstalledPack
  };
}, "useInstalledPacks");
const CORE_NODES_PACK_NAME = "comfy-core";
const useWorkflowPacks = /* @__PURE__ */ __name((options5 = {}) => {
  const getWorkflowNodeId = /* @__PURE__ */ __name((node3) => {
    if (typeof node3.properties?.cnr_id === "string") {
      return node3.properties.cnr_id;
    }
    if (typeof node3.properties?.aux_id === "string") {
      return node3.properties.aux_id;
    }
    return void 0;
  }, "getWorkflowNodeId");
  const workflowNodeToPack = /* @__PURE__ */ __name((node3) => {
    const id4 = getWorkflowNodeId(node3);
    if (!id4) return void 0;
    if (id4 === CORE_NODES_PACK_NAME) return void 0;
    const version2 = typeof node3.properties.ver === "string" ? node3.properties.ver : void 0;
    return {
      id: id4,
      version: version2
    };
  }, "workflowNodeToPack");
  const workflowPacks = computed(() => {
    if (!app$2.graph?.nodes?.length) return [];
    return app$2.graph.nodes.map(workflowNodeToPack).filter((pack) => pack !== void 0);
  });
  const packsToUniqueIds = /* @__PURE__ */ __name((packs) => packs.reduce((acc, pack) => {
    if (pack?.id) acc.add(pack.id);
    return acc;
  }, /* @__PURE__ */ new Set()), "packsToUniqueIds");
  const workflowPacksIds = computed(
    () => Array.from(packsToUniqueIds(workflowPacks.value))
  );
  const { startFetch, cleanup, error: error2, isLoading, nodePacks } = useNodePacks(
    workflowPacksIds,
    options5
  );
  const isIdInWorkflow = /* @__PURE__ */ __name((packId) => workflowPacksIds.value.includes(packId), "isIdInWorkflow");
  const filterWorkflowPack = /* @__PURE__ */ __name((packs) => packs.filter((pack) => !!pack.id && isIdInWorkflow(pack.id)), "filterWorkflowPack");
  onUnmounted(() => {
    cleanup();
  });
  return {
    error: error2,
    isLoading,
    workflowPacks: nodePacks,
    startFetchWorkflowPacks: startFetch,
    filterWorkflowPack
  };
}, "useWorkflowPacks");
function m() {
  function r2(t2) {
    return new Promise((s2) => {
      let e2 = new XMLHttpRequest();
      e2.open(t2.method, t2.url, true), Object.keys(t2.headers).forEach((n2) => e2.setRequestHeader(n2, t2.headers[n2]));
      let i2 = /* @__PURE__ */ __name((n2, a2) => setTimeout(() => {
        e2.abort(), s2({ status: 0, content: a2, isTimedOut: true });
      }, n2), "i"), u2 = i2(t2.connectTimeout, "Connection timeout"), o2;
      e2.onreadystatechange = () => {
        e2.readyState > e2.OPENED && o2 === void 0 && (clearTimeout(u2), o2 = i2(t2.responseTimeout, "Socket timeout"));
      }, e2.onerror = () => {
        e2.status === 0 && (clearTimeout(u2), clearTimeout(o2), s2({ content: e2.responseText || "Network request failed", status: e2.status, isTimedOut: false }));
      }, e2.onload = () => {
        clearTimeout(u2), clearTimeout(o2), s2({ content: e2.responseText, status: e2.status, isTimedOut: false });
      }, e2.send(t2.data);
    });
  }
  __name(r2, "r");
  return { send: r2 };
}
__name(m, "m");
function createBrowserLocalStorageCache(options5) {
  let storage;
  const namespaceKey = `algolia-client-js-${options5.key}`;
  function getStorage() {
    if (storage === void 0) {
      storage = options5.localStorage || window.localStorage;
    }
    return storage;
  }
  __name(getStorage, "getStorage");
  function getNamespace() {
    return JSON.parse(getStorage().getItem(namespaceKey) || "{}");
  }
  __name(getNamespace, "getNamespace");
  function setNamespace(namespace) {
    getStorage().setItem(namespaceKey, JSON.stringify(namespace));
  }
  __name(setNamespace, "setNamespace");
  function removeOutdatedCacheItems() {
    const timeToLive = options5.timeToLive ? options5.timeToLive * 1e3 : null;
    const namespace = getNamespace();
    const filteredNamespaceWithoutOldFormattedCacheItems = Object.fromEntries(
      Object.entries(namespace).filter(([, cacheItem]) => {
        return cacheItem.timestamp !== void 0;
      })
    );
    setNamespace(filteredNamespaceWithoutOldFormattedCacheItems);
    if (!timeToLive) {
      return;
    }
    const filteredNamespaceWithoutExpiredItems = Object.fromEntries(
      Object.entries(filteredNamespaceWithoutOldFormattedCacheItems).filter(([, cacheItem]) => {
        const currentTimestamp = (/* @__PURE__ */ new Date()).getTime();
        const isExpired2 = cacheItem.timestamp + timeToLive < currentTimestamp;
        return !isExpired2;
      })
    );
    setNamespace(filteredNamespaceWithoutExpiredItems);
  }
  __name(removeOutdatedCacheItems, "removeOutdatedCacheItems");
  return {
    get(key, defaultValue2, events2 = {
      miss: /* @__PURE__ */ __name(() => Promise.resolve(), "miss")
    }) {
      return Promise.resolve().then(() => {
        removeOutdatedCacheItems();
        return getNamespace()[JSON.stringify(key)];
      }).then((value3) => {
        return Promise.all([value3 ? value3.value : defaultValue2(), value3 !== void 0]);
      }).then(([value3, exists]) => {
        return Promise.all([value3, exists || events2.miss(value3)]);
      }).then(([value3]) => value3);
    },
    set(key, value3) {
      return Promise.resolve().then(() => {
        const namespace = getNamespace();
        namespace[JSON.stringify(key)] = {
          timestamp: (/* @__PURE__ */ new Date()).getTime(),
          value: value3
        };
        getStorage().setItem(namespaceKey, JSON.stringify(namespace));
        return value3;
      });
    },
    delete(key) {
      return Promise.resolve().then(() => {
        const namespace = getNamespace();
        delete namespace[JSON.stringify(key)];
        getStorage().setItem(namespaceKey, JSON.stringify(namespace));
      });
    },
    clear() {
      return Promise.resolve().then(() => {
        getStorage().removeItem(namespaceKey);
      });
    }
  };
}
__name(createBrowserLocalStorageCache, "createBrowserLocalStorageCache");
function createNullCache() {
  return {
    get(_key, defaultValue2, events2 = {
      miss: /* @__PURE__ */ __name(() => Promise.resolve(), "miss")
    }) {
      const value3 = defaultValue2();
      return value3.then((result) => Promise.all([result, events2.miss(result)])).then(([result]) => result);
    },
    set(_key, value3) {
      return Promise.resolve(value3);
    },
    delete(_key) {
      return Promise.resolve();
    },
    clear() {
      return Promise.resolve();
    }
  };
}
__name(createNullCache, "createNullCache");
function createFallbackableCache(options5) {
  const caches = [...options5.caches];
  const current = caches.shift();
  if (current === void 0) {
    return createNullCache();
  }
  return {
    get(key, defaultValue2, events2 = {
      miss: /* @__PURE__ */ __name(() => Promise.resolve(), "miss")
    }) {
      return current.get(key, defaultValue2, events2).catch(() => {
        return createFallbackableCache({ caches }).get(key, defaultValue2, events2);
      });
    },
    set(key, value3) {
      return current.set(key, value3).catch(() => {
        return createFallbackableCache({ caches }).set(key, value3);
      });
    },
    delete(key) {
      return current.delete(key).catch(() => {
        return createFallbackableCache({ caches }).delete(key);
      });
    },
    clear() {
      return current.clear().catch(() => {
        return createFallbackableCache({ caches }).clear();
      });
    }
  };
}
__name(createFallbackableCache, "createFallbackableCache");
function createMemoryCache(options5 = { serializable: true }) {
  let cache2 = {};
  return {
    get(key, defaultValue2, events2 = {
      miss: /* @__PURE__ */ __name(() => Promise.resolve(), "miss")
    }) {
      const keyAsString = JSON.stringify(key);
      if (keyAsString in cache2) {
        return Promise.resolve(options5.serializable ? JSON.parse(cache2[keyAsString]) : cache2[keyAsString]);
      }
      const promise = defaultValue2();
      return promise.then((value3) => events2.miss(value3)).then(() => promise);
    },
    set(key, value3) {
      cache2[JSON.stringify(key)] = options5.serializable ? JSON.stringify(value3) : value3;
      return Promise.resolve(value3);
    },
    delete(key) {
      delete cache2[JSON.stringify(key)];
      return Promise.resolve();
    },
    clear() {
      cache2 = {};
      return Promise.resolve();
    }
  };
}
__name(createMemoryCache, "createMemoryCache");
var DEFAULT_CONNECT_TIMEOUT_BROWSER = 1e3;
var DEFAULT_READ_TIMEOUT_BROWSER = 2e3;
var DEFAULT_WRITE_TIMEOUT_BROWSER = 3e4;
var DEFAULT_CONNECT_TIMEOUT_NODE = 2e3;
var DEFAULT_READ_TIMEOUT_NODE = 5e3;
var DEFAULT_WRITE_TIMEOUT_NODE = 3e4;
function createAlgoliaAgent(version2) {
  const algoliaAgent = {
    value: `Algolia for JavaScript (${version2})`,
    add(options5) {
      const addedAlgoliaAgent = `; ${options5.segment}${options5.version !== void 0 ? ` (${options5.version})` : ""}`;
      if (algoliaAgent.value.indexOf(addedAlgoliaAgent) === -1) {
        algoliaAgent.value = `${algoliaAgent.value}${addedAlgoliaAgent}`;
      }
      return algoliaAgent;
    }
  };
  return algoliaAgent;
}
__name(createAlgoliaAgent, "createAlgoliaAgent");
function createAuth(appId, apiKey, authMode = "WithinHeaders") {
  const credentials = {
    "x-algolia-api-key": apiKey,
    "x-algolia-application-id": appId
  };
  return {
    headers() {
      return authMode === "WithinHeaders" ? credentials : {};
    },
    queryParameters() {
      return authMode === "WithinQueryParameters" ? credentials : {};
    }
  };
}
__name(createAuth, "createAuth");
function createIterablePromise({
  func,
  validate,
  aggregator,
  error: error2,
  timeout = /* @__PURE__ */ __name(() => 0, "timeout")
}) {
  const retry = /* @__PURE__ */ __name((previousResponse) => {
    return new Promise((resolve2, reject3) => {
      func(previousResponse).then(async (response) => {
        if (aggregator) {
          await aggregator(response);
        }
        if (await validate(response)) {
          return resolve2(response);
        }
        if (error2 && await error2.validate(response)) {
          return reject3(new Error(await error2.message(response)));
        }
        return setTimeout(
          () => {
            retry(response).then(resolve2).catch(reject3);
          },
          await timeout()
        );
      }).catch((err) => {
        reject3(err);
      });
    });
  }, "retry");
  return retry();
}
__name(createIterablePromise, "createIterablePromise");
function getAlgoliaAgent({ algoliaAgents, client, version: version2 }) {
  const defaultAlgoliaAgent = createAlgoliaAgent(version2).add({
    segment: client,
    version: version2
  });
  algoliaAgents.forEach((algoliaAgent) => defaultAlgoliaAgent.add(algoliaAgent));
  return defaultAlgoliaAgent;
}
__name(getAlgoliaAgent, "getAlgoliaAgent");
function createNullLogger() {
  return {
    debug(_message, _args) {
      return Promise.resolve();
    },
    info(_message, _args) {
      return Promise.resolve();
    },
    error(_message, _args) {
      return Promise.resolve();
    }
  };
}
__name(createNullLogger, "createNullLogger");
var EXPIRATION_DELAY = 2 * 60 * 1e3;
function createStatefulHost(host, status = "up") {
  const lastUpdate = Date.now();
  function isUp() {
    return status === "up" || Date.now() - lastUpdate > EXPIRATION_DELAY;
  }
  __name(isUp, "isUp");
  function isTimedOut() {
    return status === "timed out" && Date.now() - lastUpdate <= EXPIRATION_DELAY;
  }
  __name(isTimedOut, "isTimedOut");
  return { ...host, status, lastUpdate, isUp, isTimedOut };
}
__name(createStatefulHost, "createStatefulHost");
var AlgoliaError = class extends Error {
  static {
    __name(this, "AlgoliaError");
  }
  name = "AlgoliaError";
  constructor(message3, name2) {
    super(message3);
    if (name2) {
      this.name = name2;
    }
  }
};
var ErrorWithStackTrace = class extends AlgoliaError {
  static {
    __name(this, "ErrorWithStackTrace");
  }
  stackTrace;
  constructor(message3, stackTrace, name2) {
    super(message3, name2);
    this.stackTrace = stackTrace;
  }
};
var RetryError = class extends ErrorWithStackTrace {
  static {
    __name(this, "RetryError");
  }
  constructor(stackTrace) {
    super(
      "Unreachable hosts - your application id may be incorrect. If the error persists, please reach out to the Algolia Support team: https://alg.li/support.",
      stackTrace,
      "RetryError"
    );
  }
};
var ApiError = class extends ErrorWithStackTrace {
  static {
    __name(this, "ApiError");
  }
  status;
  constructor(message3, status, stackTrace, name2 = "ApiError") {
    super(message3, stackTrace, name2);
    this.status = status;
  }
};
var DeserializationError = class extends AlgoliaError {
  static {
    __name(this, "DeserializationError");
  }
  response;
  constructor(message3, response) {
    super(message3, "DeserializationError");
    this.response = response;
  }
};
var DetailedApiError = class extends ApiError {
  static {
    __name(this, "DetailedApiError");
  }
  error;
  constructor(message3, status, error2, stackTrace) {
    super(message3, status, stackTrace, "DetailedApiError");
    this.error = error2;
  }
};
function shuffle(array) {
  const shuffledArray = array;
  for (let c2 = array.length - 1; c2 > 0; c2--) {
    const b2 = Math.floor(Math.random() * (c2 + 1));
    const a2 = array[c2];
    shuffledArray[c2] = array[b2];
    shuffledArray[b2] = a2;
  }
  return shuffledArray;
}
__name(shuffle, "shuffle");
function serializeUrl(host, path, queryParameters) {
  const queryParametersAsString = serializeQueryParameters(queryParameters);
  let url = `${host.protocol}://${host.url}${host.port ? `:${host.port}` : ""}/${path.charAt(0) === "/" ? path.substring(1) : path}`;
  if (queryParametersAsString.length) {
    url += `?${queryParametersAsString}`;
  }
  return url;
}
__name(serializeUrl, "serializeUrl");
function serializeQueryParameters(parameters) {
  return Object.keys(parameters).filter((key) => parameters[key] !== void 0).sort().map(
    (key) => `${key}=${encodeURIComponent(
      Object.prototype.toString.call(parameters[key]) === "[object Array]" ? parameters[key].join(",") : parameters[key]
    ).replace(/\+/g, "%20")}`
  ).join("&");
}
__name(serializeQueryParameters, "serializeQueryParameters");
function serializeData(request, requestOptions) {
  if (request.method === "GET" || request.data === void 0 && requestOptions.data === void 0) {
    return void 0;
  }
  const data30 = Array.isArray(request.data) ? request.data : { ...request.data, ...requestOptions.data };
  return JSON.stringify(data30);
}
__name(serializeData, "serializeData");
function serializeHeaders(baseHeaders, requestHeaders, requestOptionsHeaders) {
  const headers = {
    Accept: "application/json",
    ...baseHeaders,
    ...requestHeaders,
    ...requestOptionsHeaders
  };
  const serializedHeaders = {};
  Object.keys(headers).forEach((header3) => {
    const value3 = headers[header3];
    serializedHeaders[header3.toLowerCase()] = value3;
  });
  return serializedHeaders;
}
__name(serializeHeaders, "serializeHeaders");
function deserializeSuccess(response) {
  try {
    return JSON.parse(response.content);
  } catch (e2) {
    throw new DeserializationError(e2.message, response);
  }
}
__name(deserializeSuccess, "deserializeSuccess");
function deserializeFailure({ content: content3, status }, stackFrame) {
  try {
    const parsed = JSON.parse(content3);
    if ("error" in parsed) {
      return new DetailedApiError(parsed.message, status, parsed.error, stackFrame);
    }
    return new ApiError(parsed.message, status, stackFrame);
  } catch {
  }
  return new ApiError(content3, status, stackFrame);
}
__name(deserializeFailure, "deserializeFailure");
function isNetworkError({ isTimedOut, status }) {
  return !isTimedOut && ~~status === 0;
}
__name(isNetworkError, "isNetworkError");
function isRetryable({ isTimedOut, status }) {
  return isTimedOut || isNetworkError({ isTimedOut, status }) || ~~(status / 100) !== 2 && ~~(status / 100) !== 4;
}
__name(isRetryable, "isRetryable");
function isSuccess({ status }) {
  return ~~(status / 100) === 2;
}
__name(isSuccess, "isSuccess");
function stackTraceWithoutCredentials(stackTrace) {
  return stackTrace.map((stackFrame) => stackFrameWithoutCredentials(stackFrame));
}
__name(stackTraceWithoutCredentials, "stackTraceWithoutCredentials");
function stackFrameWithoutCredentials(stackFrame) {
  const modifiedHeaders = stackFrame.request.headers["x-algolia-api-key"] ? { "x-algolia-api-key": "*****" } : {};
  return {
    ...stackFrame,
    request: {
      ...stackFrame.request,
      headers: {
        ...stackFrame.request.headers,
        ...modifiedHeaders
      }
    }
  };
}
__name(stackFrameWithoutCredentials, "stackFrameWithoutCredentials");
function createTransporter({
  hosts,
  hostsCache,
  baseHeaders,
  logger: logger2,
  baseQueryParameters,
  algoliaAgent,
  timeouts,
  requester,
  requestsCache,
  responsesCache
}) {
  async function createRetryableOptions(compatibleHosts) {
    const statefulHosts = await Promise.all(
      compatibleHosts.map((compatibleHost) => {
        return hostsCache.get(compatibleHost, () => {
          return Promise.resolve(createStatefulHost(compatibleHost));
        });
      })
    );
    const hostsUp = statefulHosts.filter((host) => host.isUp());
    const hostsTimedOut = statefulHosts.filter((host) => host.isTimedOut());
    const hostsAvailable = [...hostsUp, ...hostsTimedOut];
    const compatibleHostsAvailable = hostsAvailable.length > 0 ? hostsAvailable : compatibleHosts;
    return {
      hosts: compatibleHostsAvailable,
      getTimeout(timeoutsCount, baseTimeout) {
        const timeoutMultiplier = hostsTimedOut.length === 0 && timeoutsCount === 0 ? 1 : hostsTimedOut.length + 3 + timeoutsCount;
        return timeoutMultiplier * baseTimeout;
      }
    };
  }
  __name(createRetryableOptions, "createRetryableOptions");
  async function retryableRequest(request, requestOptions, isRead = true) {
    const stackTrace = [];
    const data30 = serializeData(request, requestOptions);
    const headers = serializeHeaders(baseHeaders, request.headers, requestOptions.headers);
    const dataQueryParameters = request.method === "GET" ? {
      ...request.data,
      ...requestOptions.data
    } : {};
    const queryParameters = {
      ...baseQueryParameters,
      ...request.queryParameters,
      ...dataQueryParameters
    };
    if (algoliaAgent.value) {
      queryParameters["x-algolia-agent"] = algoliaAgent.value;
    }
    if (requestOptions && requestOptions.queryParameters) {
      for (const key of Object.keys(requestOptions.queryParameters)) {
        if (!requestOptions.queryParameters[key] || Object.prototype.toString.call(requestOptions.queryParameters[key]) === "[object Object]") {
          queryParameters[key] = requestOptions.queryParameters[key];
        } else {
          queryParameters[key] = requestOptions.queryParameters[key].toString();
        }
      }
    }
    let timeoutsCount = 0;
    const retry = /* @__PURE__ */ __name(async (retryableHosts, getTimeout2) => {
      const host = retryableHosts.pop();
      if (host === void 0) {
        throw new RetryError(stackTraceWithoutCredentials(stackTrace));
      }
      const timeout = { ...timeouts, ...requestOptions.timeouts };
      const payload = {
        data: data30,
        headers,
        method: request.method,
        url: serializeUrl(host, request.path, queryParameters),
        connectTimeout: getTimeout2(timeoutsCount, timeout.connect),
        responseTimeout: getTimeout2(timeoutsCount, isRead ? timeout.read : timeout.write)
      };
      const pushToStackTrace = /* @__PURE__ */ __name((response2) => {
        const stackFrame = {
          request: payload,
          response: response2,
          host,
          triesLeft: retryableHosts.length
        };
        stackTrace.push(stackFrame);
        return stackFrame;
      }, "pushToStackTrace");
      const response = await requester.send(payload);
      if (isRetryable(response)) {
        const stackFrame = pushToStackTrace(response);
        if (response.isTimedOut) {
          timeoutsCount++;
        }
        logger2.info("Retryable failure", stackFrameWithoutCredentials(stackFrame));
        await hostsCache.set(host, createStatefulHost(host, response.isTimedOut ? "timed out" : "down"));
        return retry(retryableHosts, getTimeout2);
      }
      if (isSuccess(response)) {
        return deserializeSuccess(response);
      }
      pushToStackTrace(response);
      throw deserializeFailure(response, stackTrace);
    }, "retry");
    const compatibleHosts = hosts.filter(
      (host) => host.accept === "readWrite" || (isRead ? host.accept === "read" : host.accept === "write")
    );
    const options5 = await createRetryableOptions(compatibleHosts);
    return retry([...options5.hosts].reverse(), options5.getTimeout);
  }
  __name(retryableRequest, "retryableRequest");
  function createRequest(request, requestOptions = {}) {
    const isRead = request.useReadTransporter || request.method === "GET";
    if (!isRead) {
      return retryableRequest(request, requestOptions, isRead);
    }
    const createRetryableRequest = /* @__PURE__ */ __name(() => {
      return retryableRequest(request, requestOptions);
    }, "createRetryableRequest");
    const cacheable = requestOptions.cacheable || request.cacheable;
    if (cacheable !== true) {
      return createRetryableRequest();
    }
    const key = {
      request,
      requestOptions,
      transporter: {
        queryParameters: baseQueryParameters,
        headers: baseHeaders
      }
    };
    return responsesCache.get(
      key,
      () => {
        return requestsCache.get(
          key,
          () => (
            /**
             * Finally, if there is no request in progress with the same key,
             * this `createRetryableRequest()` will actually trigger the
             * retryable request.
             */
            requestsCache.set(key, createRetryableRequest()).then(
              (response) => Promise.all([requestsCache.delete(key), response]),
              (err) => Promise.all([requestsCache.delete(key), Promise.reject(err)])
            ).then(([_2, response]) => response)
          )
        );
      },
      {
        /**
         * Of course, once we get this response back from the server, we
         * tell response cache to actually store the received response
         * to be used later.
         */
        miss: /* @__PURE__ */ __name((response) => responsesCache.set(key, response), "miss")
      }
    );
  }
  __name(createRequest, "createRequest");
  return {
    hostsCache,
    requester,
    timeouts,
    logger: logger2,
    algoliaAgent,
    baseHeaders,
    baseQueryParameters,
    hosts,
    request: createRequest,
    requestsCache,
    responsesCache
  };
}
__name(createTransporter, "createTransporter");
var LogLevelEnum = {
  Debug: 1,
  Info: 2,
  Error: 3
};
var apiClientVersion = "5.21.0";
function getDefaultHosts(appId) {
  return [
    {
      url: `${appId}-dsn.algolia.net`,
      accept: "read",
      protocol: "https"
    },
    {
      url: `${appId}.algolia.net`,
      accept: "write",
      protocol: "https"
    }
  ].concat(
    shuffle([
      {
        url: `${appId}-1.algolianet.com`,
        accept: "readWrite",
        protocol: "https"
      },
      {
        url: `${appId}-2.algolianet.com`,
        accept: "readWrite",
        protocol: "https"
      },
      {
        url: `${appId}-3.algolianet.com`,
        accept: "readWrite",
        protocol: "https"
      }
    ])
  );
}
__name(getDefaultHosts, "getDefaultHosts");
function createLiteClient({
  appId: appIdOption,
  apiKey: apiKeyOption,
  authMode,
  algoliaAgents,
  ...options5
}) {
  const auth = createAuth(appIdOption, apiKeyOption, authMode);
  const transporter = createTransporter({
    hosts: getDefaultHosts(appIdOption),
    ...options5,
    algoliaAgent: getAlgoliaAgent({
      algoliaAgents,
      client: "Lite",
      version: apiClientVersion
    }),
    baseHeaders: {
      "content-type": "text/plain",
      ...auth.headers(),
      ...options5.baseHeaders
    },
    baseQueryParameters: {
      ...auth.queryParameters(),
      ...options5.baseQueryParameters
    }
  });
  return {
    transporter,
    /**
     * The `appId` currently in use.
     */
    appId: appIdOption,
    /**
     * The `apiKey` currently in use.
     */
    apiKey: apiKeyOption,
    /**
     * Clears the cache of the transporter for the `requestsCache` and `responsesCache` properties.
     */
    clearCache() {
      return Promise.all([transporter.requestsCache.clear(), transporter.responsesCache.clear()]).then(() => void 0);
    },
    /**
     * Get the value of the `algoliaAgent`, used by our libraries internally and telemetry system.
     */
    get _ua() {
      return transporter.algoliaAgent.value;
    },
    /**
     * Adds a `segment` to the `x-algolia-agent` sent with every requests.
     *
     * @param segment - The algolia agent (user-agent) segment to add.
     * @param version - The version of the agent.
     */
    addAlgoliaAgent(segment, version2) {
      transporter.algoliaAgent.add({ segment, version: version2 });
    },
    /**
     * Helper method to switch the API key used to authenticate the requests.
     *
     * @param params - Method params.
     * @param params.apiKey - The new API Key to use.
     */
    setClientApiKey({ apiKey }) {
      if (!authMode || authMode === "WithinHeaders") {
        transporter.baseHeaders["x-algolia-api-key"] = apiKey;
      } else {
        transporter.baseQueryParameters["x-algolia-api-key"] = apiKey;
      }
    },
    /**
     * Helper: calls the `search` method but with certainty that we will only request Algolia records (hits) and not facets.
     * Disclaimer: We don't assert that the parameters you pass to this method only contains `hits` requests to prevent impacting search performances, this helper is purely for typing purposes.
     *
     * @summary Search multiple indices for `hits`.
     * @param searchMethodParams - Query requests and strategies. Results will be received in the same order as the queries.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    searchForHits(searchMethodParams, requestOptions) {
      return this.search(searchMethodParams, requestOptions);
    },
    /**
     * Helper: calls the `search` method but with certainty that we will only request Algolia facets and not records (hits).
     * Disclaimer: We don't assert that the parameters you pass to this method only contains `facets` requests to prevent impacting search performances, this helper is purely for typing purposes.
     *
     * @summary Search multiple indices for `facets`.
     * @param searchMethodParams - Query requests and strategies. Results will be received in the same order as the queries.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    searchForFacets(searchMethodParams, requestOptions) {
      return this.search(searchMethodParams, requestOptions);
    },
    /**
     * This method lets you send requests to the Algolia REST API.
     * @param customPost - The customPost object.
     * @param customPost.path - Path of the endpoint, anything after \"/1\" must be specified.
     * @param customPost.parameters - Query parameters to apply to the current query.
     * @param customPost.body - Parameters to send with the custom request.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    customPost({ path, parameters, body }, requestOptions) {
      if (!path) {
        throw new Error("Parameter `path` is required when calling `customPost`.");
      }
      const requestPath = "/{path}".replace("{path}", path);
      const headers = {};
      const queryParameters = parameters ? parameters : {};
      const request = {
        method: "POST",
        path: requestPath,
        queryParameters,
        headers,
        data: body ? body : {}
      };
      return transporter.request(request, requestOptions);
    },
    /**
     * Retrieves recommendations from selected AI models.
     *
     * Required API Key ACLs:
     *  - search
     * @param getRecommendationsParams - The getRecommendationsParams object.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    getRecommendations(getRecommendationsParams, requestOptions) {
      if (getRecommendationsParams && Array.isArray(getRecommendationsParams)) {
        const newSignatureRequest = {
          requests: getRecommendationsParams
        };
        getRecommendationsParams = newSignatureRequest;
      }
      if (!getRecommendationsParams) {
        throw new Error("Parameter `getRecommendationsParams` is required when calling `getRecommendations`.");
      }
      if (!getRecommendationsParams.requests) {
        throw new Error("Parameter `getRecommendationsParams.requests` is required when calling `getRecommendations`.");
      }
      const requestPath = "/1/indexes/*/recommendations";
      const headers = {};
      const queryParameters = {};
      const request = {
        method: "POST",
        path: requestPath,
        queryParameters,
        headers,
        data: getRecommendationsParams,
        useReadTransporter: true,
        cacheable: true
      };
      return transporter.request(request, requestOptions);
    },
    /**
     * Sends multiple search requests to one or more indices.  This can be useful in these cases:  - Different indices for different purposes, such as, one index for products, another one for marketing content. - Multiple searches to the same index—for example, with different filters.
     *
     * Required API Key ACLs:
     *  - search
     * @param searchMethodParams - Muli-search request body. Results are returned in the same order as the requests.
     * @param requestOptions - The requestOptions to send along with the query, they will be merged with the transporter requestOptions.
     */
    search(searchMethodParams, requestOptions) {
      if (searchMethodParams && Array.isArray(searchMethodParams)) {
        const newSignatureRequest = {
          requests: searchMethodParams.map(({ params, ...legacyRequest }) => {
            if (legacyRequest.type === "facet") {
              return {
                ...legacyRequest,
                ...params,
                type: "facet"
              };
            }
            return {
              ...legacyRequest,
              ...params,
              facet: void 0,
              maxFacetHits: void 0,
              facetQuery: void 0
            };
          })
        };
        searchMethodParams = newSignatureRequest;
      }
      if (!searchMethodParams) {
        throw new Error("Parameter `searchMethodParams` is required when calling `search`.");
      }
      if (!searchMethodParams.requests) {
        throw new Error("Parameter `searchMethodParams.requests` is required when calling `search`.");
      }
      const requestPath = "/1/indexes/*/queries";
      const headers = {};
      const queryParameters = {};
      const request = {
        method: "POST",
        path: requestPath,
        queryParameters,
        headers,
        data: searchMethodParams,
        useReadTransporter: true,
        cacheable: true
      };
      return transporter.request(request, requestOptions);
    }
  };
}
__name(createLiteClient, "createLiteClient");
function liteClient(appId, apiKey, options5) {
  if (!appId || typeof appId !== "string") {
    throw new Error("`appId` is missing.");
  }
  if (!apiKey || typeof apiKey !== "string") {
    throw new Error("`apiKey` is missing.");
  }
  return createLiteClient({
    appId,
    apiKey,
    timeouts: {
      connect: 1e3,
      read: 2e3,
      write: 3e4
    },
    logger: createNullLogger(),
    requester: m(),
    algoliaAgents: [{ segment: "Browser" }],
    authMode: "WithinQueryParameters",
    responsesCache: createMemoryCache(),
    requestsCache: createMemoryCache({ serializable: false }),
    hostsCache: createFallbackableCache({
      caches: [createBrowserLocalStorageCache({ key: `${apiClientVersion}-${appId}` }), createMemoryCache()]
    }),
    ...options5
  });
}
__name(liteClient, "liteClient");
const RETRIEVE_ATTRIBUTES = [
  "comfy_nodes",
  "name",
  "description",
  "latest_version",
  "status",
  "publisher_id",
  "total_install",
  "update_time",
  "license",
  "repository_url",
  "latest_version_status",
  "comfy_node_extract_status",
  "id"
];
const useAlgoliaSearchService = /* @__PURE__ */ __name(() => {
  const searchClient = liteClient("", "");
  const toRegistryLatestVersion = /* @__PURE__ */ __name((algoliaNode) => {
    return {
      version: algoliaNode.latest_version,
      createdAt: algoliaNode.update_time,
      status: algoliaNode.latest_version_status,
      comfy_node_extract_status: algoliaNode.comfy_node_extract_status ?? void 0
    };
  }, "toRegistryLatestVersion");
  const toRegistryPublisher = /* @__PURE__ */ __name((algoliaNode) => {
    return {
      id: algoliaNode.publisher_id,
      name: algoliaNode.publisher_id
    };
  }, "toRegistryPublisher");
  function toRegistryPack(algoliaNode) {
    return {
      id: algoliaNode.id ?? algoliaNode.objectID,
      name: algoliaNode.name,
      description: algoliaNode.description,
      repository: algoliaNode.repository_url,
      license: algoliaNode.license,
      downloads: algoliaNode.total_install,
      status: algoliaNode.status,
      icon: algoliaNode.icon_url,
      latest_version: toRegistryLatestVersion(algoliaNode),
      publisher: toRegistryPublisher(algoliaNode),
      // @ts-expect-error remove when comfy_nodes is added to node (pack) info
      comfy_nodes: algoliaNode.comfy_nodes
    };
  }
  __name(toRegistryPack, "toRegistryPack");
  const searchPacks = /* @__PURE__ */ __name(async (query, params) => {
    const { pageSize, pageNumber } = params;
    const rest = lodashExports.omit(params, ["pageSize", "pageNumber"]);
    const { results } = await searchClient.search({
      requests: [
        {
          query,
          indexName: "nodes_index",
          attributesToRetrieve: RETRIEVE_ATTRIBUTES,
          ...rest,
          hitsPerPage: pageSize,
          page: pageNumber
        },
        {
          indexName: "nodes_index_query_suggestions",
          query
        }
      ],
      strategy: "none"
    });
    const [nodePacks, querySuggestions] = results;
    return {
      nodePacks: nodePacks.hits,
      querySuggestions: querySuggestions.hits
    };
  }, "searchPacks");
  return {
    searchPacks,
    toRegistryPack
  };
}, "useAlgoliaSearchService");
const SEARCH_DEBOUNCE_TIME = 256;
const DEFAULT_PAGE_SIZE = 64;
function useRegistrySearch() {
  const isLoading = ref(false);
  const sortField = ref("downloads");
  const searchMode = ref("packs");
  const pageSize = ref(DEFAULT_PAGE_SIZE);
  const pageNumber = ref(0);
  const searchQuery = ref("");
  const results = ref([]);
  const suggestions2 = ref([]);
  const searchAttributes = computed(
    () => searchMode.value === "nodes" ? ["comfy_nodes"] : ["name", "description"]
  );
  const resultsAsRegistryPacks = computed(
    () => results.value ? results.value.map(algoliaToRegistry) : []
  );
  const resultsAsNodes = computed(
    () => results.value ? results.value.reduce(
      (acc, hit) => acc.concat(hit.comfy_nodes),
      []
    ) : []
  );
  const { searchPacks, toRegistryPack } = useAlgoliaSearchService();
  const algoliaToRegistry = lodashExports.memoize(
    toRegistryPack,
    (algoliaNode) => algoliaNode.id
  );
  const updateSearchResults = /* @__PURE__ */ __name(async (options5) => {
    isLoading.value = true;
    if (!options5.append) {
      pageNumber.value = 0;
    }
    const { nodePacks, querySuggestions } = await searchPacks(
      searchQuery.value,
      {
        pageSize: pageSize.value,
        pageNumber: pageNumber.value,
        restrictSearchableAttributes: searchAttributes.value
      }
    );
    if (options5.append && results.value?.length) {
      results.value = results.value.concat(nodePacks);
    } else {
      results.value = nodePacks;
    }
    suggestions2.value = querySuggestions;
    isLoading.value = false;
  }, "updateSearchResults");
  const onQueryChange = /* @__PURE__ */ __name(() => updateSearchResults({ append: false }), "onQueryChange");
  const onPageChange = /* @__PURE__ */ __name(() => updateSearchResults({ append: true }), "onPageChange");
  watch([sortField, searchMode], onQueryChange);
  watch(pageNumber, onPageChange);
  watchDebounced(searchQuery, onQueryChange, {
    debounce: SEARCH_DEBOUNCE_TIME,
    immediate: true
  });
  return {
    isLoading,
    pageNumber,
    pageSize,
    sortField,
    searchMode,
    searchQuery,
    suggestions: suggestions2,
    searchResults: resultsAsRegistryPacks,
    nodeSearchResults: resultsAsNodes
  };
}
__name(useRegistrySearch, "useRegistrySearch");
const _hoisted_1$E = ["aria-label"];
const _hoisted_2$v = { class: "flex flex-1 relative overflow-hidden" };
const _hoisted_3$h = { class: "px-6 pt-6 flex flex-col h-full" };
const _hoisted_4$9 = { class: "flex-1 overflow-auto" };
const _hoisted_5$9 = {
  key: 0,
  class: "w-full h-full overflow-auto scrollbar-hide"
};
const _hoisted_6$7 = { class: "w-80 border-l-0 border-surface-border absolute right-0 top-0 bottom-0 flex z-20" };
const _hoisted_7$3 = { class: "flex-1 flex flex-col isolate" };
var ManagerTab = /* @__PURE__ */ ((ManagerTab2) => {
  ManagerTab2["All"] = "all";
  ManagerTab2["Installed"] = "installed";
  ManagerTab2["Workflow"] = "workflow";
  ManagerTab2["Missing"] = "missing";
  return ManagerTab2;
})(ManagerTab || {});
const _sfc_main$G = /* @__PURE__ */ defineComponent({
  __name: "ManagerDialogContent",
  setup(__props) {
    const { t: t2 } = useI18n();
    const comfyManagerStore = useComfyManagerStore();
    const { getPackById } = useComfyRegistryStore();
    const GRID_STYLE = {
      display: "grid",
      gridTemplateColumns: "repeat(auto-fill, minmax(19rem, 1fr))",
      padding: "0.5rem",
      gap: "1.5rem"
    };
    const {
      isSmallScreen,
      isOpen: isSideNavOpen,
      toggle: toggleSideNav
    } = useResponsiveCollapse();
    const tabs2 = ref([
      { id: "all", label: t2("g.all"), icon: "pi-list" },
      { id: "installed", label: t2("g.installed"), icon: "pi-box" },
      {
        id: "workflow",
        label: t2("manager.inWorkflow"),
        icon: "pi-folder"
      },
      {
        id: "missing",
        label: t2("g.missing"),
        icon: "pi-exclamation-circle"
      }
    ]);
    const selectedTab = ref(tabs2.value[0]);
    const {
      searchQuery,
      pageNumber,
      isLoading: isSearchLoading,
      searchResults,
      searchMode,
      suggestions: suggestions2
    } = useRegistrySearch();
    pageNumber.value = 0;
    const onApproachEnd = /* @__PURE__ */ __name(() => {
      pageNumber.value++;
    }, "onApproachEnd");
    const isInitialLoad = computed(
      () => searchResults.value.length === 0 && searchQuery.value === ""
    );
    const isEmptySearch = computed(() => searchQuery.value === "");
    const displayPacks = ref([]);
    const {
      startFetchInstalled,
      filterInstalledPack,
      installedPacks,
      isLoading: isLoadingInstalled
    } = useInstalledPacks();
    const {
      startFetchWorkflowPacks,
      filterWorkflowPack,
      workflowPacks,
      isLoading: isLoadingWorkflow
    } = useWorkflowPacks();
    const getInstalledResults = /* @__PURE__ */ __name(() => {
      if (isEmptySearch.value) {
        startFetchInstalled();
        return installedPacks.value;
      } else {
        return filterInstalledPack(searchResults.value);
      }
    }, "getInstalledResults");
    const getInWorkflowResults = /* @__PURE__ */ __name(() => {
      if (isEmptySearch.value) {
        startFetchWorkflowPacks();
        return workflowPacks.value;
      } else {
        return filterWorkflowPack(searchResults.value);
      }
    }, "getInWorkflowResults");
    const filterMissingPacks = /* @__PURE__ */ __name((packs) => packs.filter((pack) => !comfyManagerStore.isPackInstalled(pack.id)), "filterMissingPacks");
    const setMissingPacks = /* @__PURE__ */ __name(() => {
      displayPacks.value = filterMissingPacks(workflowPacks.value);
    }, "setMissingPacks");
    const getMissingPacks = /* @__PURE__ */ __name(() => {
      if (isEmptySearch.value) {
        startFetchWorkflowPacks();
        whenever(() => workflowPacks.value.length, setMissingPacks, {
          immediate: true,
          once: true
        });
        return filterMissingPacks(workflowPacks.value);
      } else {
        return filterMissingPacks(filterWorkflowPack(searchResults.value));
      }
    }, "getMissingPacks");
    const onTabChange = /* @__PURE__ */ __name(() => {
      switch (selectedTab.value?.id) {
        case "installed":
          displayPacks.value = getInstalledResults();
          break;
        case "workflow":
          displayPacks.value = getInWorkflowResults();
          break;
        case "missing":
          displayPacks.value = getMissingPacks();
          break;
        default:
          displayPacks.value = searchResults.value;
      }
    }, "onTabChange");
    const onResultsChange = /* @__PURE__ */ __name(() => {
      switch (selectedTab.value?.id) {
        case "installed":
          displayPacks.value = filterInstalledPack(searchResults.value);
          break;
        case "workflow":
          displayPacks.value = filterWorkflowPack(searchResults.value);
          break;
        case "missing":
          displayPacks.value = filterMissingPacks(
            filterWorkflowPack(searchResults.value)
          );
          break;
        default:
          displayPacks.value = searchResults.value;
      }
    }, "onResultsChange");
    whenever(selectedTab, onTabChange);
    watch(searchResults, onResultsChange, { flush: "pre" });
    watch(() => comfyManagerStore.installedPacksIds, onResultsChange);
    const isLoading = computed(() => {
      if (isSearchLoading.value) return searchResults.value.length === 0;
      if (selectedTab.value?.id === "installed") {
        return isLoadingInstalled.value;
      }
      if (selectedTab.value?.id === "workflow" || selectedTab.value?.id === "missing") {
        return isLoadingWorkflow.value;
      }
      return isInitialLoad.value;
    });
    const resultsWithKeys = computed(
      () => displayPacks.value.map((item3) => ({
        ...item3,
        key: item3.id || item3.name
      }))
    );
    const selectedNodePacks = ref([]);
    const selectedNodePack = computed(
      () => selectedNodePacks.value.length === 1 ? selectedNodePacks.value[0] : null
    );
    const getLoadingCount = /* @__PURE__ */ __name(() => {
      switch (selectedTab.value?.id) {
        case "installed":
          return comfyManagerStore.installedPacksIds?.size;
        case "workflow":
          return workflowPacks.value?.length;
        case "missing":
          return workflowPacks.value?.filter?.(
            (pack) => !comfyManagerStore.isPackInstalled(pack.id)
          )?.length;
        default:
          return searchResults.value.length;
      }
    }, "getLoadingCount");
    const skeletonCardCount = computed(() => {
      const loadingCount = getLoadingCount();
      if (loadingCount) return loadingCount;
      return isSmallScreen.value ? 12 : 16;
    });
    const selectNodePack = /* @__PURE__ */ __name((nodePack, event) => {
      if (event.shiftKey || event.ctrlKey || event.metaKey) {
        const index2 = selectedNodePacks.value.findIndex(
          (pack) => pack.id === nodePack.id
        );
        if (index2 === -1) {
          selectedNodePacks.value.push(nodePack);
        } else {
          selectedNodePacks.value.splice(index2, 1);
        }
      } else {
        selectedNodePacks.value = [nodePack];
      }
    }, "selectNodePack");
    const unSelectItems = /* @__PURE__ */ __name(() => {
      selectedNodePacks.value = [];
    }, "unSelectItems");
    const handleGridContainerClick = /* @__PURE__ */ __name((event) => {
      const targetElement = event.target;
      if (targetElement && !targetElement.closest("[data-virtual-grid-item]")) {
        unSelectItems();
      }
    }, "handleGridContainerClick");
    const hasMultipleSelections = computed(() => selectedNodePacks.value.length > 1);
    whenever(selectedNodePack, async () => {
      getPackById.cancel();
      if (!selectedNodePack.value?.id) return;
      if (hasMultipleSelections.value) return;
      const data30 = await getPackById.call(selectedNodePack.value.id);
      if (data30?.id === selectedNodePack.value?.id) {
        selectedNodePacks.value = [lodashExports.merge(selectedNodePack.value, data30)];
      }
    });
    onUnmounted(() => {
      getPackById.cancel();
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: "flex flex-col mx-auto overflow-hidden h-[83vh] relative",
        "aria-label": _ctx.$t("manager.title")
      }, [
        unref(isSmallScreen) ? (openBlock(), createBlock(unref(script$10), {
          key: 0,
          icon: unref(isSideNavOpen) ? "pi pi-chevron-left" : "pi pi-chevron-right",
          text: "",
          class: normalizeClass(["absolute top-1/2 -translate-y-1/2 z-10", unref(isSideNavOpen) ? "left-[19rem]" : "left-2"]),
          onClick: unref(toggleSideNav)
        }, null, 8, ["icon", "class", "onClick"])) : createCommentVNode("", true),
        createBaseVNode("div", _hoisted_2$v, [
          unref(isSideNavOpen) ? (openBlock(), createBlock(_sfc_main$16, {
            key: 0,
            tabs: tabs2.value,
            selectedTab: selectedTab.value,
            "onUpdate:selectedTab": _cache[0] || (_cache[0] = ($event) => selectedTab.value = $event)
          }, null, 8, ["tabs", "selectedTab"])) : createCommentVNode("", true),
          createBaseVNode("div", {
            class: normalizeClass(["flex-1 overflow-auto pr-80", {
              "transition-all duration-300": unref(isSmallScreen),
              "pl-80": unref(isSideNavOpen) || !unref(isSmallScreen),
              "pl-8": !unref(isSideNavOpen) && unref(isSmallScreen)
            }])
          }, [
            createBaseVNode("div", _hoisted_3$h, [
              createVNode(_sfc_main$J, {
                searchQuery: unref(searchQuery),
                "onUpdate:searchQuery": _cache[1] || (_cache[1] = ($event) => isRef(searchQuery) ? searchQuery.value = $event : null),
                searchMode: unref(searchMode),
                "onUpdate:searchMode": _cache[2] || (_cache[2] = ($event) => isRef(searchMode) ? searchMode.value = $event : null),
                searchResults: unref(searchResults),
                suggestions: unref(suggestions2)
              }, null, 8, ["searchQuery", "searchMode", "searchResults", "suggestions"]),
              createBaseVNode("div", _hoisted_4$9, [
                isLoading.value ? (openBlock(), createElementBlock("div", _hoisted_5$9, [
                  createVNode(_sfc_main$H, {
                    "grid-style": GRID_STYLE,
                    "skeleton-card-count": skeletonCardCount.value
                  }, null, 8, ["skeleton-card-count"])
                ])) : unref(searchResults).length === 0 ? (openBlock(), createBlock(NoResultsPlaceholder, {
                  key: 1,
                  title: unref(comfyManagerStore).error ? _ctx.$t("manager.errorConnecting") : _ctx.$t("manager.noResultsFound"),
                  message: unref(comfyManagerStore).error ? _ctx.$t("manager.tryAgainLater") : _ctx.$t("manager.tryDifferentSearch")
                }, null, 8, ["title", "message"])) : (openBlock(), createElementBlock("div", {
                  key: 2,
                  class: "h-full",
                  onClick: handleGridContainerClick
                }, [
                  createVNode(VirtualGrid, {
                    items: resultsWithKeys.value,
                    "buffer-rows": 3,
                    gridStyle: GRID_STYLE,
                    onApproachEnd
                  }, {
                    item: withCtx(({ item: item3 }) => [
                      createVNode(_sfc_main$L, {
                        onClick: withModifiers((event) => selectNodePack(item3, event), ["stop"]),
                        "node-pack": item3,
                        "is-selected": selectedNodePacks.value.some((pack) => pack.id === item3.id)
                      }, null, 8, ["onClick", "node-pack", "is-selected"])
                    ]),
                    _: 1
                  }, 8, ["items"])
                ]))
              ])
            ])
          ], 2),
          createBaseVNode("div", _hoisted_6$7, [
            createVNode(_sfc_main$18, {
              orientation: "vertical",
              width: 0.2
            }),
            createBaseVNode("div", _hoisted_7$3, [
              !hasMultipleSelections.value && selectedNodePack.value ? (openBlock(), createBlock(InfoPanel, {
                key: 0,
                "node-pack": selectedNodePack.value
              }, null, 8, ["node-pack"])) : (openBlock(), createBlock(_sfc_main$O, {
                key: 1,
                "node-packs": selectedNodePacks.value
              }, null, 8, ["node-packs"]))
            ])
          ])
        ])
      ], 8, _hoisted_1$E);
    };
  }
});
const _hoisted_1$D = { class: "w-full" };
const _hoisted_2$u = { class: "px-6 py-4" };
const _hoisted_3$g = { class: "text-lg font-normal text-left" };
const _sfc_main$F = /* @__PURE__ */ defineComponent({
  __name: "ManagerHeader",
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$D, [
        createBaseVNode("div", _hoisted_2$u, [
          createBaseVNode("h2", _hoisted_3$g, toDisplayString$1(_ctx.$t("manager.discoverCommunityContent")), 1)
        ]),
        createVNode(_sfc_main$18, { width: 0.3 })
      ]);
    };
  }
});
const RESERVED_BY_TEXT_INPUT = /* @__PURE__ */ new Set([
  "Ctrl + a",
  "Ctrl + c",
  "Ctrl + v",
  "Ctrl + x",
  "Ctrl + z",
  "Ctrl + y",
  "Ctrl + p",
  "Enter",
  "Shift + Enter",
  "Ctrl + Backspace",
  "Ctrl + Delete",
  "Home",
  "Ctrl + Home",
  "Ctrl + Shift + Home",
  "End",
  "Ctrl + End",
  "Ctrl + Shift + End",
  "PageUp",
  "PageDown",
  "Shift + PageUp",
  "Shift + PageDown",
  "ArrowLeft",
  "Ctrl + ArrowLeft",
  "Shift + ArrowLeft",
  "Ctrl + Shift + ArrowLeft",
  "ArrowRight",
  "Ctrl + ArrowRight",
  "Shift + ArrowRight",
  "Ctrl + Shift + ArrowRight",
  "ArrowUp",
  "Shift + ArrowUp",
  "ArrowDown",
  "Shift + ArrowDown"
]);
class KeybindingImpl {
  static {
    __name(this, "KeybindingImpl");
  }
  commandId;
  combo;
  targetElementId;
  constructor(obj) {
    this.commandId = obj.commandId;
    this.combo = new KeyComboImpl(obj.combo);
    this.targetElementId = obj.targetElementId;
  }
  equals(other) {
    const raw = toRaw(other);
    return raw instanceof KeybindingImpl ? this.commandId === raw.commandId && this.combo.equals(raw.combo) && this.targetElementId === raw.targetElementId : false;
  }
}
class KeyComboImpl {
  static {
    __name(this, "KeyComboImpl");
  }
  key;
  // ctrl or meta(cmd on mac)
  ctrl;
  alt;
  shift;
  constructor(obj) {
    this.key = obj.key;
    this.ctrl = obj.ctrl ?? false;
    this.alt = obj.alt ?? false;
    this.shift = obj.shift ?? false;
  }
  static fromEvent(event) {
    return new KeyComboImpl({
      key: event.key,
      ctrl: event.ctrlKey || event.metaKey,
      alt: event.altKey,
      shift: event.shiftKey
    });
  }
  equals(other) {
    const raw = toRaw(other);
    return raw instanceof KeyComboImpl ? this.key.toUpperCase() === raw.key.toUpperCase() && this.ctrl === raw.ctrl && this.alt === raw.alt && this.shift === raw.shift : false;
  }
  serialize() {
    return `${this.key.toUpperCase()}:${this.ctrl}:${this.alt}:${this.shift}`;
  }
  toString() {
    return this.getKeySequences().join(" + ");
  }
  get hasModifier() {
    return this.ctrl || this.alt || this.shift;
  }
  get isModifier() {
    return ["Control", "Meta", "Alt", "Shift"].includes(this.key);
  }
  get modifierCount() {
    const modifiers2 = [this.ctrl, this.alt, this.shift];
    return modifiers2.reduce((acc, cur) => acc + Number(cur), 0);
  }
  get isShiftOnly() {
    return this.shift && this.modifierCount === 1;
  }
  get isReservedByTextInput() {
    return !this.hasModifier || this.isShiftOnly || RESERVED_BY_TEXT_INPUT.has(this.toString());
  }
  getKeySequences() {
    const sequences = [];
    if (this.ctrl) {
      sequences.push("Ctrl");
    }
    if (this.alt) {
      sequences.push("Alt");
    }
    if (this.shift) {
      sequences.push("Shift");
    }
    sequences.push(this.key);
    return sequences;
  }
}
const useKeybindingStore = /* @__PURE__ */ defineStore("keybinding", () => {
  const defaultKeybindings = ref({});
  const userKeybindings = ref({});
  const userUnsetKeybindings = ref({});
  function getUserKeybindings() {
    return userKeybindings.value;
  }
  __name(getUserKeybindings, "getUserKeybindings");
  function getUserUnsetKeybindings() {
    return userUnsetKeybindings.value;
  }
  __name(getUserUnsetKeybindings, "getUserUnsetKeybindings");
  const keybindingByKeyCombo = computed(() => {
    const result = {
      ...defaultKeybindings.value
    };
    for (const keybinding of Object.values(userUnsetKeybindings.value)) {
      const serializedCombo = keybinding.combo.serialize();
      if (result[serializedCombo]?.equals(keybinding)) {
        delete result[serializedCombo];
      }
    }
    return {
      ...result,
      ...userKeybindings.value
    };
  });
  const keybindings = computed(
    () => Object.values(keybindingByKeyCombo.value)
  );
  function getKeybinding(combo) {
    return keybindingByKeyCombo.value[combo.serialize()];
  }
  __name(getKeybinding, "getKeybinding");
  const keybindingsByCommandId = computed(
    () => {
      return _.groupBy(keybindings.value, "commandId");
    }
  );
  function getKeybindingsByCommandId(commandId) {
    return keybindingsByCommandId.value[commandId] ?? [];
  }
  __name(getKeybindingsByCommandId, "getKeybindingsByCommandId");
  const defaultKeybindingsByCommandId = computed(() => {
    return _.groupBy(Object.values(defaultKeybindings.value), "commandId");
  });
  function getKeybindingByCommandId(commandId) {
    return getKeybindingsByCommandId(commandId)[0];
  }
  __name(getKeybindingByCommandId, "getKeybindingByCommandId");
  function addKeybinding(target2, keybinding, { existOk = false }) {
    if (!existOk && keybinding.combo.serialize() in target2.value) {
      throw new Error(
        `Keybinding on ${keybinding.combo} already exists on ${target2.value[keybinding.combo.serialize()].commandId}`
      );
    }
    target2.value[keybinding.combo.serialize()] = keybinding;
  }
  __name(addKeybinding, "addKeybinding");
  function addDefaultKeybinding(keybinding) {
    addKeybinding(defaultKeybindings, keybinding, { existOk: false });
  }
  __name(addDefaultKeybinding, "addDefaultKeybinding");
  function addUserKeybinding(keybinding) {
    const defaultKeybinding = defaultKeybindings.value[keybinding.combo.serialize()];
    const userUnsetKeybinding = userUnsetKeybindings.value[keybinding.combo.serialize()];
    if (keybinding.equals(defaultKeybinding) && keybinding.equals(userUnsetKeybinding)) {
      delete userUnsetKeybindings.value[keybinding.combo.serialize()];
      return;
    }
    if (defaultKeybinding && !defaultKeybinding.equals(userUnsetKeybinding)) {
      unsetKeybinding(defaultKeybinding);
    }
    addKeybinding(userKeybindings, keybinding, { existOk: true });
  }
  __name(addUserKeybinding, "addUserKeybinding");
  function unsetKeybinding(keybinding) {
    const serializedCombo = keybinding.combo.serialize();
    if (!(serializedCombo in keybindingByKeyCombo.value)) {
      console.warn(
        `Trying to unset non-exist keybinding: ${JSON.stringify(keybinding)}`
      );
      return;
    }
    if (userKeybindings.value[serializedCombo]?.equals(keybinding)) {
      delete userKeybindings.value[serializedCombo];
      return;
    }
    if (defaultKeybindings.value[serializedCombo]?.equals(keybinding)) {
      addKeybinding(userUnsetKeybindings, keybinding, { existOk: false });
      return;
    }
    console.warn(`Unset unknown keybinding: ${JSON.stringify(keybinding)}`);
  }
  __name(unsetKeybinding, "unsetKeybinding");
  function updateKeybindingOnCommand(keybinding) {
    const currentKeybinding = getKeybindingByCommandId(keybinding.commandId);
    if (currentKeybinding?.equals(keybinding)) {
      return false;
    }
    if (currentKeybinding) {
      unsetKeybinding(currentKeybinding);
    }
    addUserKeybinding(keybinding);
    return true;
  }
  __name(updateKeybindingOnCommand, "updateKeybindingOnCommand");
  function resetKeybindings() {
    userKeybindings.value = {};
    userUnsetKeybindings.value = {};
  }
  __name(resetKeybindings, "resetKeybindings");
  function isCommandKeybindingModified(commandId) {
    const currentKeybinding = getKeybindingByCommandId(commandId);
    const defaultKeybinding = defaultKeybindingsByCommandId.value[commandId]?.[0];
    return !(currentKeybinding === void 0 && defaultKeybinding === void 0 || currentKeybinding?.equals(defaultKeybinding));
  }
  __name(isCommandKeybindingModified, "isCommandKeybindingModified");
  return {
    keybindings,
    getUserKeybindings,
    getUserUnsetKeybindings,
    getKeybinding,
    getKeybindingsByCommandId,
    getKeybindingByCommandId,
    addDefaultKeybinding,
    addUserKeybinding,
    unsetKeybinding,
    updateKeybindingOnCommand,
    resetKeybindings,
    isCommandKeybindingModified
  };
});
class ComfyCommandImpl {
  static {
    __name(this, "ComfyCommandImpl");
  }
  id;
  function;
  _label;
  _icon;
  _tooltip;
  _menubarLabel;
  versionAdded;
  confirmation;
  constructor(command2) {
    this.id = command2.id;
    this.function = command2.function;
    this._label = command2.label;
    this._icon = command2.icon;
    this._tooltip = command2.tooltip;
    this._menubarLabel = command2.menubarLabel ?? command2.label;
    this.versionAdded = command2.versionAdded;
    this.confirmation = command2.confirmation;
  }
  get label() {
    return typeof this._label === "function" ? this._label() : this._label;
  }
  get icon() {
    return typeof this._icon === "function" ? this._icon() : this._icon;
  }
  get tooltip() {
    return typeof this._tooltip === "function" ? this._tooltip() : this._tooltip;
  }
  get menubarLabel() {
    return typeof this._menubarLabel === "function" ? this._menubarLabel() : this._menubarLabel;
  }
  get keybinding() {
    return useKeybindingStore().getKeybindingByCommandId(this.id);
  }
}
const useCommandStore = /* @__PURE__ */ defineStore("command", () => {
  const commandsById = ref({});
  const commands2 = computed(() => Object.values(commandsById.value));
  const registerCommand = /* @__PURE__ */ __name((command2) => {
    if (commandsById.value[command2.id]) {
      console.warn(`Command ${command2.id} already registered`);
    }
    commandsById.value[command2.id] = new ComfyCommandImpl(command2);
  }, "registerCommand");
  const registerCommands = /* @__PURE__ */ __name((commands22) => {
    for (const command2 of commands22) {
      registerCommand(command2);
    }
  }, "registerCommands");
  const getCommand = /* @__PURE__ */ __name((command2) => {
    return commandsById.value[command2];
  }, "getCommand");
  const { wrapWithErrorHandlingAsync } = useErrorHandling();
  const execute = /* @__PURE__ */ __name(async (commandId, errorHandler2) => {
    const command2 = getCommand(commandId);
    if (command2) {
      await wrapWithErrorHandlingAsync(command2.function, errorHandler2)();
    } else {
      throw new Error(`Command ${commandId} not found`);
    }
  }, "execute");
  const isRegistered = /* @__PURE__ */ __name((command2) => {
    return !!commandsById.value[command2];
  }, "isRegistered");
  const loadExtensionCommands = /* @__PURE__ */ __name((extension) => {
    if (extension.commands) {
      for (const command2 of extension.commands) {
        registerCommand(command2);
      }
    }
  }, "loadExtensionCommands");
  return {
    commands: commands2,
    execute,
    getCommand,
    registerCommand,
    registerCommands,
    isRegistered,
    loadExtensionCommands
  };
});
const _hoisted_1$C = { class: "justify-center text-sm font-bold leading-none" };
const _hoisted_2$t = { class: "flex items-center" };
const _hoisted_3$f = { class: "leading-none" };
const _hoisted_4$8 = { class: "flex items-center gap-4" };
const _hoisted_5$8 = {
  key: 0,
  class: "text-xs font-bold text-neutral-600"
};
const _hoisted_6$6 = { class: "flex items-center" };
const _sfc_main$E = /* @__PURE__ */ defineComponent({
  __name: "ManagerProgressFooter",
  setup(__props) {
    const { t: t2 } = useI18n();
    const dialogStore = useDialogStore();
    const progressDialogContent = useManagerProgressDialogStore();
    const comfyManagerStore = useComfyManagerStore();
    const isInProgress = computed(() => comfyManagerStore.uncompletedCount > 0);
    const closeDialog = /* @__PURE__ */ __name(() => {
      dialogStore.closeDialog({ key: "global-manager-progress-dialog" });
    }, "closeDialog");
    const fallbackTaskName = t2("g.installing");
    const currentTaskName = computed(() => {
      if (!comfyManagerStore.taskLogs.length) return fallbackTaskName;
      const task = comfyManagerStore.taskLogs.at(-1);
      return task?.taskName ?? fallbackTaskName;
    });
    const handleRestart = /* @__PURE__ */ __name(async () => {
      await useComfyManagerService().rebootComfyUI();
      closeDialog();
      const onReconnect = /* @__PURE__ */ __name(() => {
        useCommandStore().execute("Comfy.RefreshNodeDefinitions");
        comfyManagerStore.clearLogs();
        comfyManagerStore.setStale();
      }, "onReconnect");
      useEventListener(api, "reconnected", onReconnect, { once: true });
    }, "handleRestart");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["w-full px-6 py-4 shadow-lg flex items-center justify-between", {
          "rounded-t-none": unref(progressDialogContent).isExpanded,
          "rounded-lg": !unref(progressDialogContent).isExpanded
        }])
      }, [
        createBaseVNode("div", _hoisted_1$C, [
          createBaseVNode("div", _hoisted_2$t, [
            isInProgress.value ? (openBlock(), createElementBlock(Fragment$1, { key: 0 }, [
              _cache[0] || (_cache[0] = createBaseVNode("i", { class: "pi pi-spin pi-spinner mr-2 text-3xl" }, null, -1)),
              createBaseVNode("span", null, toDisplayString$1(currentTaskName.value), 1)
            ], 64)) : (openBlock(), createElementBlock(Fragment$1, { key: 1 }, [
              _cache[1] || (_cache[1] = createBaseVNode("i", { class: "pi pi-check-circle mr-2 text-green-500" }, null, -1)),
              createBaseVNode("span", _hoisted_3$f, toDisplayString$1(_ctx.$t("manager.restartToApplyChanges")), 1)
            ], 64))
          ])
        ]),
        createBaseVNode("div", _hoisted_4$8, [
          isInProgress.value ? (openBlock(), createElementBlock("span", _hoisted_5$8, toDisplayString$1(unref(comfyManagerStore).uncompletedCount) + " of " + toDisplayString$1(unref(comfyManagerStore).taskLogs.length), 1)) : createCommentVNode("", true),
          createBaseVNode("div", _hoisted_6$6, [
            !isInProgress.value ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              rounded: "",
              outlined: "",
              class: "px-4 py-2 rounded-md mr-4",
              onClick: handleRestart
            }, {
              default: withCtx(() => [
                createTextVNode(toDisplayString$1(_ctx.$t("g.restart")), 1)
              ]),
              _: 1
            })) : createCommentVNode("", true),
            createVNode(unref(script$10), {
              icon: unref(progressDialogContent).isExpanded ? "pi pi-chevron-up" : "pi pi-chevron-right",
              text: "",
              rounded: "",
              size: "small",
              severity: "secondary",
              "aria-label": unref(progressDialogContent).isExpanded ? "Collapse" : "Expand",
              onClick: withModifiers(unref(progressDialogContent).toggle, ["stop"])
            }, null, 8, ["icon", "aria-label", "onClick"]),
            createVNode(unref(script$10), {
              icon: "pi pi-times",
              text: "",
              rounded: "",
              size: "small",
              severity: "secondary",
              "aria-label": "Close",
              onClick: withModifiers(closeDialog, ["stop"])
            })
          ])
        ])
      ], 2);
    };
  }
});
var theme$8 = /* @__PURE__ */ __name(function theme38(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tabmenu {\n    overflow-x: auto;\n}\n\n.p-tabmenu-tablist {\n    display: flex;\n    margin: 0;\n    padding: 0;\n    list-style-type: none;\n    background: ".concat(dt2("tabmenu.tablist.background"), ";\n    border-style: solid;\n    border-color: ").concat(dt2("tabmenu.tablist.border.color"), ";\n    border-width: ").concat(dt2("tabmenu.tablist.border.width"), ";\n    position: relative;\n}\n\n.p-tabmenu-item-link {\n    cursor: pointer;\n    user-select: none;\n    display: flex;\n    align-items: center;\n    text-decoration: none;\n    position: relative;\n    overflow: hidden;\n    background: ").concat(dt2("tabmenu.item.background"), ";\n    border-style: solid;\n    border-width: ").concat(dt2("tabmenu.item.border.width"), ";\n    border-color: ").concat(dt2("tabmenu.item.border.color"), ";\n    color: ").concat(dt2("tabmenu.item.color"), ";\n    padding: ").concat(dt2("tabmenu.item.padding"), ";\n    font-weight: ").concat(dt2("tabmenu.item.font.weight"), ";\n    transition: background ").concat(dt2("tabmenu.transition.duration"), ", border-color ").concat(dt2("tabmenu.transition.duration"), ", color ").concat(dt2("tabmenu.transition.duration"), ", outline-color ").concat(dt2("tabmenu.transition.duration"), ", box-shadow ").concat(dt2("tabmenu.transition.duration"), ";\n    margin: ").concat(dt2("tabmenu.item.margin"), ";\n    outline-color: transparent;\n    gap: ").concat(dt2("tabmenu.item.gap"), ";\n}\n\n.p-tabmenu-item-link:focus-visible {\n    z-index: 1;\n    box-shadow: ").concat(dt2("tabmenu.item.focus.ring.shadow"), ";\n    outline: ").concat(dt2("tabmenu.item.focus.ring.width"), " ").concat(dt2("tabmenu.item.focus.ring.style"), " ").concat(dt2("tabmenu.item.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("tabmenu.item.focus.ring.offset"), ";\n}\n\n.p-tabmenu-item-icon {\n    color: ").concat(dt2("tabmenu.item.icon.color"), ";\n    transition: background ").concat(dt2("tabmenu.transition.duration"), ", border-color ").concat(dt2("tabmenu.transition.duration"), ", color ").concat(dt2("tabmenu.transition.duration"), ", outline-color ").concat(dt2("tabmenu.transition.duration"), ", box-shadow ").concat(dt2("tabmenu.transition.duration"), ";\n}\n\n.p-tabmenu-item-label {\n    line-height: 1;\n}\n\n.p-tabmenu-item:not(.p-tabmenu-item-active):not(.p-disabled):hover .p-tabmenu-item-link {\n    background: ").concat(dt2("tabmenu.item.hover.background"), ";\n    border-color: ").concat(dt2("tabmenu.item.hover.border.color"), ";\n    color: ").concat(dt2("tabmenu.item.hover.color"), ";\n}\n\n.p-tabmenu-item:not(.p-tabmenu-item-active):not(.p-disabled):hover .p-tabmenu-item-icon {\n    color: ").concat(dt2("tabmenu.item.icon.hover.color"), ";\n}\n\n.p-tabmenu-item-active .p-tabmenu-item-link {\n    background: ").concat(dt2("tabmenu.item.active.background"), ";\n    border-color: ").concat(dt2("tabmenu.item.active.border.color"), ";\n    color: ").concat(dt2("tabmenu.item.active.color"), ";\n}\n\n.p-tabmenu-item-active .p-tabmenu-item-icon {\n    color: ").concat(dt2("tabmenu.item.icon.active.color"), ";\n}\n\n.p-tabmenu-active-bar {\n    z-index: 1;\n    display: block;\n    position: absolute;\n    bottom: ").concat(dt2("tabmenu.active.bar.bottom"), ";\n    height: ").concat(dt2("tabmenu.active.bar.height"), ";\n    background: ").concat(dt2("tabmenu.active.bar.background"), ";\n    transition: 250ms cubic-bezier(0.35, 0, 0.25, 1);\n}\n\n.p-tabmenu::-webkit-scrollbar {\n    display: none;\n}\n");
}, "theme");
var classes$8 = {
  root: "p-tabmenu p-component",
  tablist: "p-tabmenu-tablist",
  item: /* @__PURE__ */ __name(function item(_ref2) {
    var instance = _ref2.instance, index2 = _ref2.index, _item = _ref2.item;
    return ["p-tabmenu-item", {
      "p-tabmenu-item-active": instance.d_activeIndex === index2,
      "p-disabled": instance.disabled(_item)
    }];
  }, "item"),
  itemLink: "p-tabmenu-item-link",
  itemIcon: "p-tabmenu-item-icon",
  itemLabel: "p-tabmenu-item-label",
  activeBar: "p-tabmenu-active-bar"
};
var TabMenuStyle = BaseStyle$1.extend({
  name: "tabmenu",
  theme: theme$8,
  classes: classes$8
});
var script$1$8 = {
  name: "BaseTabMenu",
  "extends": script$1b,
  props: {
    model: {
      type: Array,
      "default": null
    },
    activeIndex: {
      type: Number,
      "default": 0
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: TabMenuStyle,
  provide: /* @__PURE__ */ __name(function provide43() {
    return {
      $pcTabMenu: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$e = {
  name: "TabMenu",
  "extends": script$1$8,
  inheritAttrs: false,
  emits: ["update:activeIndex", "tab-change"],
  data: /* @__PURE__ */ __name(function data22() {
    return {
      d_activeIndex: this.activeIndex
    };
  }, "data"),
  watch: {
    activeIndex: {
      flush: "post",
      handler: /* @__PURE__ */ __name(function handler13(newValue2) {
        this.d_activeIndex = newValue2;
        this.updateInkBar();
      }, "handler")
    }
  },
  mounted: /* @__PURE__ */ __name(function mounted22() {
    var _this = this;
    this.$nextTick(function() {
      _this.updateInkBar();
    });
    var activeItem2 = this.findActiveItem();
    activeItem2 && (activeItem2.tabIndex = "0");
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated13() {
    this.updateInkBar();
  }, "updated"),
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions6(key, item3, index2) {
      return this.ptm(key, {
        context: {
          item: item3,
          index: index2
        }
      });
    }, "getPTOptions"),
    onItemClick: /* @__PURE__ */ __name(function onItemClick(event, item3, index2) {
      if (this.disabled(item3)) {
        event.preventDefault();
        return;
      }
      if (item3.command) {
        item3.command({
          originalEvent: event,
          item: item3
        });
      }
      if (index2 !== this.d_activeIndex) {
        this.d_activeIndex = index2;
        this.$emit("update:activeIndex", this.d_activeIndex);
      }
      this.$emit("tab-change", {
        originalEvent: event,
        index: index2
      });
    }, "onItemClick"),
    onKeydownItem: /* @__PURE__ */ __name(function onKeydownItem(event, item3, index2) {
      switch (event.code) {
        case "ArrowRight": {
          this.navigateToNextItem(event.target);
          event.preventDefault();
          break;
        }
        case "ArrowLeft": {
          this.navigateToPrevItem(event.target);
          event.preventDefault();
          break;
        }
        case "Home": {
          this.navigateToFirstItem(event.target);
          event.preventDefault();
          break;
        }
        case "End": {
          this.navigateToLastItem(event.target);
          event.preventDefault();
          break;
        }
        case "Space":
        case "NumpadEnter":
        case "Enter": {
          this.onItemClick(event, item3, index2);
          event.preventDefault();
          break;
        }
        case "Tab": {
          this.onTabKey();
          break;
        }
      }
    }, "onKeydownItem"),
    navigateToNextItem: /* @__PURE__ */ __name(function navigateToNextItem(target2) {
      var nextItem = this.findNextItem(target2);
      nextItem && this.setFocusToMenuitem(target2, nextItem);
    }, "navigateToNextItem"),
    navigateToPrevItem: /* @__PURE__ */ __name(function navigateToPrevItem(target2) {
      var prevItem = this.findPrevItem(target2);
      prevItem && this.setFocusToMenuitem(target2, prevItem);
    }, "navigateToPrevItem"),
    navigateToFirstItem: /* @__PURE__ */ __name(function navigateToFirstItem(target2) {
      var firstItem = this.findFirstItem(target2);
      firstItem && this.setFocusToMenuitem(target2, firstItem);
    }, "navigateToFirstItem"),
    navigateToLastItem: /* @__PURE__ */ __name(function navigateToLastItem(target2) {
      var lastItem = this.findLastItem(target2);
      lastItem && this.setFocusToMenuitem(target2, lastItem);
    }, "navigateToLastItem"),
    findNextItem: /* @__PURE__ */ __name(function findNextItem(item3) {
      var nextItem = item3.parentElement.nextElementSibling;
      return nextItem ? getAttribute$1(nextItem, "data-p-disabled") === true ? this.findNextItem(nextItem.children[0]) : nextItem.children[0] : null;
    }, "findNextItem"),
    findPrevItem: /* @__PURE__ */ __name(function findPrevItem(item3) {
      var prevItem = item3.parentElement.previousElementSibling;
      return prevItem ? getAttribute$1(prevItem, "data-p-disabled") === true ? this.findPrevItem(prevItem.children[0]) : prevItem.children[0] : null;
    }, "findPrevItem"),
    findFirstItem: /* @__PURE__ */ __name(function findFirstItem() {
      var firstSibling = findSingle$1(this.$refs.nav, '[data-pc-section="item"][data-p-disabled="false"]');
      return firstSibling ? firstSibling.children[0] : null;
    }, "findFirstItem"),
    findLastItem: /* @__PURE__ */ __name(function findLastItem() {
      var siblings = find$2(this.$refs.nav, '[data-pc-section="item"][data-p-disabled="false"]');
      return siblings ? siblings[siblings.length - 1].children[0] : null;
    }, "findLastItem"),
    findActiveItem: /* @__PURE__ */ __name(function findActiveItem() {
      var activeItem2 = findSingle$1(this.$refs.nav, '[data-pc-section="item"][data-p-disabled="false"][data-p-active="true"]');
      return activeItem2 ? activeItem2.children[0] : null;
    }, "findActiveItem"),
    setFocusToMenuitem: /* @__PURE__ */ __name(function setFocusToMenuitem(target2, focusableItem) {
      target2.tabIndex = "-1";
      focusableItem.tabIndex = "0";
      focusableItem.focus();
    }, "setFocusToMenuitem"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey4() {
      var activeItem2 = findSingle$1(this.$refs.nav, '[data-pc-section="item"][data-p-disabled="false"][data-p-active="true"]');
      var focusedItem = findSingle$1(this.$refs.nav, '[data-pc-section="itemlink"][tabindex="0"]');
      if (focusedItem !== activeItem2.children[0]) {
        activeItem2 && (activeItem2.children[0].tabIndex = "0");
        focusedItem.tabIndex = "-1";
      }
    }, "onTabKey"),
    visible: /* @__PURE__ */ __name(function visible(item3) {
      return typeof item3.visible === "function" ? item3.visible() : item3.visible !== false;
    }, "visible"),
    disabled: /* @__PURE__ */ __name(function disabled2(item3) {
      return typeof item3.disabled === "function" ? item3.disabled() : item3.disabled === true;
    }, "disabled"),
    label: /* @__PURE__ */ __name(function label5(item3) {
      return typeof item3.label === "function" ? item3.label() : item3.label;
    }, "label"),
    updateInkBar: /* @__PURE__ */ __name(function updateInkBar3() {
      var tabs2 = this.$refs.nav.children;
      var inkHighlighted = false;
      for (var i2 = 0; i2 < tabs2.length; i2++) {
        var tab = tabs2[i2];
        if (getAttribute$1(tab, "data-p-active")) {
          this.$refs.inkbar.style.width = getWidth$1(tab) + "px";
          this.$refs.inkbar.style.left = getOffset$1(tab).left - getOffset$1(this.$refs.nav).left + "px";
          inkHighlighted = true;
        }
      }
      if (!inkHighlighted) {
        this.$refs.inkbar.style.width = "0px";
        this.$refs.inkbar.style.left = "0px";
      }
    }, "updateInkBar"),
    getMenuItemProps: /* @__PURE__ */ __name(function getMenuItemProps(item3, index2) {
      var _this2 = this;
      return {
        action: mergeProps$2({
          "class": this.cx("itemLink"),
          tabindex: -1,
          onClick: /* @__PURE__ */ __name(function onClick5($event) {
            return _this2.onItemClick($event, item3, index2);
          }, "onClick"),
          onKeyDown: /* @__PURE__ */ __name(function onKeyDown13($event) {
            return _this2.onKeydownItem($event, item3, index2);
          }, "onKeyDown")
        }, this.getPTOptions("itemLink", item3, index2)),
        icon: mergeProps$2({
          "class": [this.cx("itemIcon"), item3.icon]
        }, this.getPTOptions("itemIcon", item3, index2)),
        label: mergeProps$2({
          "class": this.cx("itemLabel")
        }, this.getPTOptions("itemLabel", item3, index2))
      };
    }, "getMenuItemProps")
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$B = ["aria-labelledby", "aria-label"];
var _hoisted_2$s = ["onClick", "onKeydown", "data-p-active", "data-p-disabled"];
var _hoisted_3$e = ["href", "target", "aria-label", "aria-disabled"];
function render$d(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [createBaseVNode("ul", mergeProps$2({
    ref: "nav",
    "class": _ctx.cx("tablist"),
    role: "menubar",
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel
  }, _ctx.ptm("tablist")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.model, function(item3, i2) {
    return openBlock(), createElementBlock(Fragment$1, {
      key: $options.label(item3) + "_" + i2.toString()
    }, [$options.visible(item3) ? (openBlock(), createElementBlock("li", mergeProps$2({
      key: 0,
      ref_for: true,
      ref: "tab",
      "class": [_ctx.cx("item", {
        item: item3,
        index: i2
      }), item3["class"]],
      role: "presentation",
      onClick: /* @__PURE__ */ __name(function onClick5($event) {
        return $options.onItemClick($event, item3, i2);
      }, "onClick"),
      onKeydown: /* @__PURE__ */ __name(function onKeydown4($event) {
        return $options.onKeydownItem($event, item3, i2);
      }, "onKeydown")
    }, $options.getPTOptions("item", item3, i2), {
      "data-p-active": $data.d_activeIndex === i2,
      "data-p-disabled": $options.disabled(item3)
    }), [!_ctx.$slots.item ? withDirectives((openBlock(), createElementBlock("a", mergeProps$2({
      key: 0,
      ref_for: true,
      ref: "tabLink",
      role: "menuitem",
      href: item3.url,
      "class": _ctx.cx("itemLink"),
      target: item3.target,
      "aria-label": $options.label(item3),
      "aria-disabled": $options.disabled(item3),
      tabindex: -1
    }, $options.getPTOptions("itemLink", item3, i2)), [_ctx.$slots.itemicon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.itemicon), {
      key: 0,
      item: item3,
      "class": normalizeClass(_ctx.cx("itemIcon"))
    }, null, 8, ["item", "class"])) : item3.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
      key: 1,
      "class": [_ctx.cx("itemIcon"), item3.icon],
      ref_for: true
    }, $options.getPTOptions("itemIcon", item3, i2)), null, 16)) : createCommentVNode("", true), createBaseVNode("span", mergeProps$2({
      "class": _ctx.cx("itemLabel"),
      ref_for: true
    }, $options.getPTOptions("itemLabel", item3, i2)), toDisplayString$1($options.label(item3)), 17)], 16, _hoisted_3$e)), [[_directive_ripple]]) : (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.item), {
      key: 1,
      item: item3,
      index: i2,
      active: i2 === $data.d_activeIndex,
      label: $options.label(item3),
      props: $options.getMenuItemProps(item3, i2)
    }, null, 8, ["item", "index", "active", "label", "props"]))], 16, _hoisted_2$s)) : createCommentVNode("", true)], 64);
  }), 128)), createBaseVNode("li", mergeProps$2({
    ref: "inkbar",
    role: "none",
    "class": _ctx.cx("activeBar")
  }, _ctx.ptm("activeBar")), null, 16)], 16, _hoisted_1$B)], 16);
}
__name(render$d, "render$d");
script$e.render = render$d;
const _hoisted_1$A = {
  key: 0,
  class: "px-4 py-2 flex items-center"
};
const _sfc_main$D = /* @__PURE__ */ defineComponent({
  __name: "ManagerProgressHeader",
  setup(__props) {
    const progressDialogContent = useManagerProgressDialogStore();
    const activeTabIndex = ref(0);
    const tabs2 = [{ label: "Installation Queue" }, { label: "Failed (0)" }];
    return (_ctx, _cache) => {
      return unref(progressDialogContent).isExpanded ? (openBlock(), createElementBlock("div", _hoisted_1$A, [
        createVNode(unref(script$e), {
          activeIndex: activeTabIndex.value,
          "onUpdate:activeIndex": _cache[0] || (_cache[0] = ($event) => activeTabIndex.value = $event),
          model: tabs2,
          class: "w-full border-none",
          pt: {
            menu: { class: "border-none" },
            menuitem: { class: "font-medium" },
            action: { class: "px-4 py-2" }
          }
        }, null, 8, ["activeIndex"])
      ])) : createCommentVNode("", true);
    };
  }
});
const _sfc_main$C = {};
const _hoisted_1$z = { class: "px-4" };
function _sfc_render$1(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [
    createBaseVNode("h2", _hoisted_1$z, [
      _cache[0] || (_cache[0] = createBaseVNode("i", { class: "pi pi-cog" }, null, -1)),
      createBaseVNode("span", null, toDisplayString$1(_ctx.$t("g.settings")), 1)
    ])
  ]);
}
__name(_sfc_render$1, "_sfc_render$1");
const SettingDialogHeader = /* @__PURE__ */ _export_sfc(_sfc_main$C, [["render", _sfc_render$1], ["__scopeId", "data-v-43089afc"]]);
const _hoisted_1$y = { class: "relative w-64 h-64 rounded-t-lg overflow-hidden select-none" };
const _hoisted_2$r = {
  key: 1,
  class: "w-full h-full flex items-center justify-center bg-surface-card"
};
const _sfc_main$B = /* @__PURE__ */ defineComponent({
  __name: "BaseThumbnail",
  props: {
    hoverZoom: { default: 4 },
    isHovered: { type: Boolean }
  },
  setup(__props) {
    const error2 = ref(false);
    const contentRef3 = ref(null);
    onMounted(() => {
      const images = Array.from(contentRef3.value?.getElementsByTagName("img") ?? []);
      images.forEach((img) => {
        useEventListener(img, "error", () => {
          error2.value = true;
        });
      });
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$y, [
        !error2.value ? (openBlock(), createElementBlock("div", {
          key: 0,
          ref_key: "contentRef",
          ref: contentRef3,
          class: "w-64 h-64 object-cover transform-gpu transition-transform duration-1000 ease-out",
          style: normalizeStyle(
            _ctx.isHovered ? { transform: `scale(${1 + _ctx.hoverZoom / 100})` } : void 0
          )
        }, [
          renderSlot(_ctx.$slots, "default", {}, void 0, true)
        ], 4)) : (openBlock(), createElementBlock("div", _hoisted_2$r, _cache[0] || (_cache[0] = [
          createBaseVNode("i", { class: "pi pi-file text-4xl text-surface-600" }, null, -1)
        ])))
      ]);
    };
  }
});
const BaseThumbnail = /* @__PURE__ */ _export_sfc(_sfc_main$B, [["__scopeId", "data-v-89ab9a36"]]);
const _hoisted_1$x = { class: "w-64 h-64 flex items-center justify-center p-4" };
const _hoisted_2$q = ["src"];
const _sfc_main$A = /* @__PURE__ */ defineComponent({
  __name: "AudioThumbnail",
  props: {
    src: {}
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createBlock(BaseThumbnail, null, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$x, [
            createBaseVNode("audio", {
              controls: "",
              class: "w-full relative",
              src: _ctx.src,
              onClick: _cache[0] || (_cache[0] = withModifiers(() => {
              }, ["stop"]))
            }, null, 8, _hoisted_2$q)
          ])
        ]),
        _: 1
      });
    };
  }
});
const _hoisted_1$w = ["src", "alt"];
const _hoisted_2$p = ["src", "alt"];
const SLIDER_START_POSITION = 21;
const _sfc_main$z = /* @__PURE__ */ defineComponent({
  __name: "CompareSliderThumbnail",
  props: {
    baseImageSrc: {},
    overlayImageSrc: {},
    alt: {},
    isHovered: { type: Boolean }
  },
  setup(__props) {
    const sliderPosition = ref(SLIDER_START_POSITION);
    const containerRef6 = ref(null);
    const { elementX, elementWidth, isOutside } = useMouseInElement(containerRef6);
    watch(
      [() => __props.isHovered, elementX, elementWidth, isOutside],
      ([isHovered, x2, width2, outside]) => {
        if (!isHovered) return;
        if (!outside) {
          sliderPosition.value = x2 / width2 * 100;
        }
      }
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(BaseThumbnail, { "is-hovered": _ctx.isHovered }, {
        default: withCtx(() => [
          createBaseVNode("img", {
            src: _ctx.baseImageSrc,
            alt: _ctx.alt,
            class: "w-full h-full object-cover"
          }, null, 8, _hoisted_1$w),
          createBaseVNode("div", {
            ref_key: "containerRef",
            ref: containerRef6,
            class: "absolute inset-0"
          }, [
            createBaseVNode("img", {
              src: _ctx.overlayImageSrc,
              alt: _ctx.alt,
              class: "w-full h-full object-cover",
              style: normalizeStyle({
                clipPath: `inset(0 ${100 - sliderPosition.value}% 0 0)`
              })
            }, null, 12, _hoisted_2$p),
            createBaseVNode("div", {
              class: "absolute inset-y-0 w-0.5 bg-white/30 backdrop-blur-sm z-10 pointer-events-none",
              style: normalizeStyle({
                left: `${sliderPosition.value}%`
              })
            }, null, 4)
          ], 512)
        ]),
        _: 1
      }, 8, ["is-hovered"]);
    };
  }
});
const _hoisted_1$v = { class: "overflow-hidden" };
const _hoisted_2$o = ["src", "alt"];
const _sfc_main$y = /* @__PURE__ */ defineComponent({
  __name: "DefaultThumbnail",
  props: {
    src: {},
    alt: {},
    hoverZoom: {},
    isHovered: { type: Boolean }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createBlock(BaseThumbnail, {
        "hover-zoom": _ctx.hoverZoom,
        "is-hovered": _ctx.isHovered
      }, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$v, [
            createBaseVNode("img", {
              src: _ctx.src,
              alt: _ctx.alt,
              draggable: "false",
              class: "w-64 h-64 object-cover transform-gpu transition-transform duration-300 ease-out",
              style: normalizeStyle(
                _ctx.isHovered ? { transform: `scale(${1 + _ctx.hoverZoom / 100})` } : void 0
              )
            }, null, 12, _hoisted_2$o)
          ])
        ]),
        _: 1
      }, 8, ["hover-zoom", "is-hovered"]);
    };
  }
});
const _hoisted_1$u = { class: "relative w-full h-full" };
const _hoisted_2$n = ["src", "alt"];
const _hoisted_3$d = ["src", "alt"];
const _sfc_main$x = /* @__PURE__ */ defineComponent({
  __name: "HoverDissolveThumbnail",
  props: {
    baseImageSrc: {},
    overlayImageSrc: {},
    alt: {},
    isHovered: { type: Boolean }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createBlock(BaseThumbnail, { "is-hovered": _ctx.isHovered }, {
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$u, [
            createBaseVNode("img", {
              src: _ctx.baseImageSrc,
              alt: _ctx.alt,
              draggable: "false",
              class: "absolute inset-0 w-64 h-64 object-cover"
            }, null, 8, _hoisted_2$n),
            createBaseVNode("img", {
              src: _ctx.overlayImageSrc,
              alt: _ctx.alt,
              draggable: "false",
              class: normalizeClass(["absolute inset-0 w-64 h-64 object-cover transition-opacity duration-300", { "opacity-100": _ctx.isHovered, "opacity-0": !_ctx.isHovered }])
            }, null, 10, _hoisted_3$d)
          ])
        ]),
        _: 1
      }, 8, ["is-hovered"]);
    };
  }
});
const _hoisted_1$t = { class: "flex items-center justify-center" };
const _hoisted_2$m = { class: "relative overflow-hidden rounded-t-lg" };
const _hoisted_3$c = { class: "flex items-center px-4 py-3" };
const _hoisted_4$7 = { class: "flex-1" };
const _hoisted_5$7 = ["title"];
const _hoisted_6$5 = ["title"];
const UPSCALE_ZOOM_SCALE = 16;
const DEFAULT_ZOOM_SCALE = 5;
const _sfc_main$w = /* @__PURE__ */ defineComponent({
  __name: "TemplateWorkflowCard",
  props: {
    sourceModule: {},
    categoryTitle: {},
    loading: { type: Boolean },
    template: {}
  },
  emits: ["loadWorkflow"],
  setup(__props) {
    const cardRef = ref(null);
    const isHovered = useElementHover(cardRef);
    const getThumbnailUrl = /* @__PURE__ */ __name((index2 = "") => {
      const basePath2 = __props.sourceModule === "default" ? api.fileURL(`/templates/${__props.template.name}`) : api.apiURL(`/workflow_templates/${__props.sourceModule}/${__props.template.name}`);
      const indexSuffix = __props.sourceModule === "default" && index2 ? `-${index2}` : "";
      return `${basePath2}${indexSuffix}.${__props.template.mediaSubtype}`;
    }, "getThumbnailUrl");
    const baseThumbnailSrc = computed(
      () => getThumbnailUrl(__props.sourceModule === "default" ? "1" : "")
    );
    const overlayThumbnailSrc = computed(
      () => getThumbnailUrl(__props.sourceModule === "default" ? "2" : "")
    );
    const title = computed(() => {
      return __props.sourceModule === "default" ? st(
        `templateWorkflows.template.${normalizeI18nKey(__props.categoryTitle)}.${normalizeI18nKey(__props.template.name)}`,
        __props.template.name
      ) : __props.template.name ?? `${__props.sourceModule} Template`;
    });
    const description = computed(() => __props.template.description.replace(/[-_]/g, " "));
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$W), {
        ref_key: "cardRef",
        ref: cardRef,
        "data-testid": `template-workflow-${_ctx.template.name}`,
        class: "w-64 template-card rounded-2xl overflow-hidden cursor-pointer shadow-elevation-2 dark-theme:bg-dark-elevation-1",
        pt: {
          body: { class: "p-0" }
        },
        onClick: _cache[0] || (_cache[0] = ($event) => _ctx.$emit("loadWorkflow", _ctx.template.name))
      }, {
        header: withCtx(() => [
          createBaseVNode("div", _hoisted_1$t, [
            createBaseVNode("div", _hoisted_2$m, [
              _ctx.template.mediaType === "audio" ? (openBlock(), createBlock(_sfc_main$A, {
                key: 0,
                src: baseThumbnailSrc.value
              }, null, 8, ["src"])) : _ctx.template.thumbnailVariant === "compareSlider" ? (openBlock(), createBlock(_sfc_main$z, {
                key: 1,
                "base-image-src": baseThumbnailSrc.value,
                "overlay-image-src": overlayThumbnailSrc.value,
                alt: title.value,
                "is-hovered": unref(isHovered)
              }, null, 8, ["base-image-src", "overlay-image-src", "alt", "is-hovered"])) : _ctx.template.thumbnailVariant === "hoverDissolve" ? (openBlock(), createBlock(_sfc_main$x, {
                key: 2,
                "base-image-src": baseThumbnailSrc.value,
                "overlay-image-src": overlayThumbnailSrc.value,
                alt: title.value,
                "is-hovered": unref(isHovered)
              }, null, 8, ["base-image-src", "overlay-image-src", "alt", "is-hovered"])) : (openBlock(), createBlock(_sfc_main$y, {
                key: 3,
                src: baseThumbnailSrc.value,
                alt: title.value,
                "is-hovered": unref(isHovered),
                "hover-zoom": _ctx.template.thumbnailVariant === "zoomHover" ? UPSCALE_ZOOM_SCALE : DEFAULT_ZOOM_SCALE
              }, null, 8, ["src", "alt", "is-hovered", "hover-zoom"])),
              _ctx.loading ? (openBlock(), createBlock(unref(script$19), {
                key: 4,
                class: "absolute inset-0 z-1 w-3/12 h-full"
              })) : createCommentVNode("", true)
            ])
          ])
        ]),
        content: withCtx(() => [
          createBaseVNode("div", _hoisted_3$c, [
            createBaseVNode("div", _hoisted_4$7, [
              createBaseVNode("h3", {
                class: "line-clamp-1 text-lg font-normal text-surface-900 dark:text-surface-100",
                title: title.value
              }, toDisplayString$1(title.value), 9, _hoisted_5$7),
              createBaseVNode("p", {
                class: "line-clamp-2 text-sm text-surface-600 dark:text text-muted",
                title: description.value
              }, toDisplayString$1(description.value), 9, _hoisted_6$5)
            ]),
            _cache[1] || (_cache[1] = createBaseVNode("div", { class: "flex md:hidden xl:flex items-center justify-center ml-4 w-10 h-10 rounded-full bg-surface-100" }, [
              createBaseVNode("i", { class: "pi pi-angle-right text-2xl" })
            ], -1))
          ])
        ]),
        _: 1
      }, 8, ["data-testid"]);
    };
  }
});
const _hoisted_1$s = { class: "text-left py-3 px-12" };
const _hoisted_2$l = { class: "text-lg" };
const _sfc_main$v = /* @__PURE__ */ defineComponent({
  __name: "TemplateWorkflowsSideNav",
  props: {
    tabs: {},
    selectedTab: {}
  },
  emits: ["update:selectedTab"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const handleTabSelection = /* @__PURE__ */ __name((tab) => {
      emit2("update:selectedTab", tab);
    }, "handleTabSelection");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$X), {
        class: "w-80",
        style: { "height": "calc(83vh - 48px)" }
      }, {
        default: withCtx(() => [
          createVNode(unref(script$G), {
            "model-value": _ctx.selectedTab,
            "onUpdate:modelValue": handleTabSelection,
            options: _ctx.tabs,
            "option-group-label": "label",
            "option-label": "title",
            "option-group-children": "modules",
            pt: {
              root: { class: "w-full border-0 bg-transparent" },
              list: { class: "p-0" },
              option: { class: "px-12 py-3 text-lg" },
              optionGroup: { class: "p-0 text-left text-inherit" }
            },
            listStyle: "max-height:unset"
          }, {
            optiongroup: withCtx((slotProps) => [
              createBaseVNode("div", _hoisted_1$s, [
                createBaseVNode("h2", _hoisted_2$l, toDisplayString$1(slotProps.option.label), 1)
              ])
            ]),
            _: 1
          }, 8, ["model-value", "options"])
        ]),
        _: 1
      });
    };
  }
});
const useWorkflowTemplatesStore = /* @__PURE__ */ defineStore(
  "workflowTemplates",
  () => {
    const { t: t2 } = useI18n();
    const customTemplates = shallowRef({});
    const coreTemplates = shallowRef([]);
    const isLoaded = ref(false);
    const groupedTemplates = computed(() => {
      const allTemplates = [
        ...coreTemplates.value.map((template) => ({
          ...template,
          title: t2(
            `templateWorkflows.category.${normalizeI18nKey(template.title)}`,
            {
              defaultValue: template.title
            }
          )
        })),
        ...Object.entries(customTemplates.value).map(
          ([moduleName, templates2]) => ({
            moduleName,
            title: moduleName,
            templates: templates2.map((name2) => ({
              name: name2,
              mediaType: "image",
              mediaSubtype: "jpg",
              description: name2
            }))
          })
        )
      ];
      return Object.entries(
        lodashExports.groupBy(
          allTemplates,
          (template) => template.moduleName === "default" ? t2("templateWorkflows.category.ComfyUI Examples", {
            defaultValue: "ComfyUI Examples"
          }) : t2("templateWorkflows.category.Custom Nodes", {
            defaultValue: "Custom Nodes"
          })
        )
      ).map(([label8, modules]) => ({ label: label8, modules }));
    });
    async function loadWorkflowTemplates() {
      try {
        if (!isLoaded.value) {
          customTemplates.value = await api.getWorkflowTemplates();
          coreTemplates.value = await api.getCoreWorkflowTemplates();
          isLoaded.value = true;
        }
      } catch (error2) {
        console.error("Error fetching workflow templates:", error2);
      }
    }
    __name(loadWorkflowTemplates, "loadWorkflowTemplates");
    return {
      groupedTemplates,
      isLoaded,
      loadWorkflowTemplates
    };
  }
);
const _hoisted_1$r = {
  class: "flex flex-col h-[83vh] w-[90vw] relative pb-6",
  "data-testid": "template-workflows-content"
};
const _hoisted_2$k = { class: "flex flex-1 relative overflow-hidden" };
const _hoisted_3$b = {
  key: 0,
  class: "absolute translate-x-0 top-0 left-0 h-full w-80 shadow-md z-5 transition-transform duration-300 ease-in-out"
};
const _hoisted_4$6 = {
  key: 0,
  class: "flex flex-col px-12 pb-4"
};
const _hoisted_5$6 = { class: "py-3 text-left" };
const _hoisted_6$4 = { class: "text-lg" };
const _hoisted_7$2 = { class: "grid grid-cols-[repeat(auto-fill,minmax(16rem,1fr))] gap-8 justify-items-center" };
const _sfc_main$u = /* @__PURE__ */ defineComponent({
  __name: "TemplateWorkflowsContent",
  setup(__props) {
    const { t: t2 } = useI18n();
    const {
      isSmallScreen,
      isOpen: isSideNavOpen,
      toggle: toggleSideNav
    } = useResponsiveCollapse();
    const workflowTemplatesStore = useWorkflowTemplatesStore();
    const { isReady } = useAsyncState(
      workflowTemplatesStore.loadWorkflowTemplates,
      null
    );
    const selectedTab = ref(null);
    const selectFirstTab = /* @__PURE__ */ __name(() => {
      const firstTab = workflowTemplatesStore.groupedTemplates[0].modules[0];
      handleTabSelection(firstTab);
    }, "selectFirstTab");
    watch(isReady, selectFirstTab, { once: true });
    const workflowLoading = ref(null);
    const tabs2 = computed(() => workflowTemplatesStore.groupedTemplates);
    const handleTabSelection = /* @__PURE__ */ __name((selection) => {
      if (selection !== selectedTab.value && selection !== null) {
        selectedTab.value = selection;
        if (isSmallScreen.value) {
          isSideNavOpen.value = false;
        }
      }
    }, "handleTabSelection");
    const loadWorkflow = /* @__PURE__ */ __name(async (id4) => {
      if (!isReady.value) return;
      workflowLoading.value = id4;
      let json;
      if (selectedTab.value?.moduleName === "default") {
        json = await fetch(api.fileURL(`/templates/${id4}.json`)).then(
          (r2) => r2.json()
        );
      } else {
        json = await fetch(
          api.apiURL(
            `/workflow_templates/${selectedTab.value?.moduleName}/${id4}.json`
          )
        ).then((r2) => r2.json());
      }
      useDialogStore().closeDialog();
      const workflowName = selectedTab.value?.moduleName === "default" ? t2(`templateWorkflows.template.${id4}`, id4) : id4;
      await app$2.loadGraphData(json, true, true, workflowName);
      return false;
    }, "loadWorkflow");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$r, [
        unref(isSmallScreen) ? (openBlock(), createBlock(unref(script$10), {
          key: 0,
          icon: unref(isSideNavOpen) ? "pi pi-chevron-left" : "pi pi-chevron-right",
          text: "",
          class: normalizeClass(["absolute top-1/2 -translate-y-1/2 z-10", unref(isSideNavOpen) ? "left-[19rem]" : "left-2"]),
          onClick: unref(toggleSideNav)
        }, null, 8, ["icon", "class", "onClick"])) : createCommentVNode("", true),
        createVNode(unref(script$Y), { class: "m-0 [&::before]:border-surface-border/70 [&::before]:border-t-2" }),
        createBaseVNode("div", _hoisted_2$k, [
          unref(isSideNavOpen) ? (openBlock(), createElementBlock("aside", _hoisted_3$b, [
            !unref(workflowTemplatesStore).isLoaded || !unref(isReady) ? (openBlock(), createBlock(unref(script$19), {
              key: 0,
              class: "absolute w-8 h-full inset-0"
            })) : createCommentVNode("", true),
            createVNode(_sfc_main$v, {
              tabs: tabs2.value,
              "selected-tab": selectedTab.value,
              "onUpdate:selectedTab": handleTabSelection
            }, null, 8, ["tabs", "selected-tab"])
          ])) : createCommentVNode("", true),
          createBaseVNode("div", {
            class: normalizeClass(["flex-1 overflow-auto transition-all duration-300", {
              "pl-80": unref(isSideNavOpen) || !unref(isSmallScreen),
              "pl-8": !unref(isSideNavOpen) && unref(isSmallScreen)
            }])
          }, [
            unref(isReady) && selectedTab.value ? (openBlock(), createElementBlock("div", _hoisted_4$6, [
              createBaseVNode("div", _hoisted_5$6, [
                createBaseVNode("h2", _hoisted_6$4, toDisplayString$1(selectedTab.value.title), 1)
              ]),
              createBaseVNode("div", _hoisted_7$2, [
                (openBlock(true), createElementBlock(Fragment$1, null, renderList(selectedTab.value.templates, (template) => {
                  return openBlock(), createElementBlock("div", {
                    key: template.name
                  }, [
                    createVNode(_sfc_main$w, {
                      sourceModule: selectedTab.value.moduleName,
                      template,
                      loading: template.name === workflowLoading.value,
                      categoryTitle: selectedTab.value.title,
                      onLoadWorkflow: loadWorkflow
                    }, null, 8, ["sourceModule", "template", "loading", "categoryTitle"])
                  ]);
                }), 128))
              ])
            ])) : createCommentVNode("", true)
          ], 2)
        ])
      ]);
    };
  }
});
const _sfc_main$t = {};
const _hoisted_1$q = { class: "px-4" };
function _sfc_render(_ctx, _cache) {
  return openBlock(), createElementBlock("div", null, [
    createBaseVNode("h3", _hoisted_1$q, [
      createBaseVNode("span", null, toDisplayString$1(_ctx.$t("templateWorkflows.title")), 1)
    ])
  ]);
}
__name(_sfc_render, "_sfc_render");
const TemplateWorkflowsDialogHeader = /* @__PURE__ */ _export_sfc(_sfc_main$t, [["render", _sfc_render]]);
const useDialogService = /* @__PURE__ */ __name(() => {
  const dialogStore = useDialogStore();
  function showLoadWorkflowWarning(props) {
    dialogStore.showDialog({
      key: "global-load-workflow-warning",
      component: LoadWorkflowWarning,
      props
    });
  }
  __name(showLoadWorkflowWarning, "showLoadWorkflowWarning");
  function showMissingModelsWarning(props) {
    dialogStore.showDialog({
      key: "global-missing-models-warning",
      component: MissingModelsWarning,
      props
    });
  }
  __name(showMissingModelsWarning, "showMissingModelsWarning");
  function showSettingsDialog(panel2) {
    const props = panel2 ? { props: { defaultPanel: panel2 } } : void 0;
    dialogStore.showDialog({
      key: "global-settings",
      headerComponent: SettingDialogHeader,
      component: SettingDialogContent,
      ...props
    });
  }
  __name(showSettingsDialog, "showSettingsDialog");
  function showAboutDialog() {
    dialogStore.showDialog({
      key: "global-settings",
      headerComponent: SettingDialogHeader,
      component: SettingDialogContent,
      props: {
        defaultPanel: "about"
      }
    });
  }
  __name(showAboutDialog, "showAboutDialog");
  function showExecutionErrorDialog(props) {
    dialogStore.showDialog({
      key: "global-execution-error",
      component: ExecutionErrorDialogContent,
      props
    });
  }
  __name(showExecutionErrorDialog, "showExecutionErrorDialog");
  function showTemplateWorkflowsDialog(props = {}) {
    dialogStore.showDialog({
      key: "global-template-workflows",
      title: t("templateWorkflows.title"),
      component: _sfc_main$u,
      headerComponent: TemplateWorkflowsDialogHeader,
      dialogComponentProps: {
        pt: {
          content: { class: "!px-0 overflow-y-hidden" }
        }
      },
      props
    });
  }
  __name(showTemplateWorkflowsDialog, "showTemplateWorkflowsDialog");
  function showIssueReportDialog(props) {
    dialogStore.showDialog({
      key: "global-issue-report",
      component: _sfc_main$1z,
      props
    });
  }
  __name(showIssueReportDialog, "showIssueReportDialog");
  function showManagerDialog(props = {}) {
    dialogStore.showDialog({
      key: "global-manager",
      component: _sfc_main$G,
      headerComponent: _sfc_main$F,
      dialogComponentProps: {
        closable: false,
        pt: {
          header: { class: "!p-0 !m-0" },
          content: { class: "!px-0 h-[83vh] w-[90vw] overflow-y-hidden" }
        }
      },
      props
    });
  }
  __name(showManagerDialog, "showManagerDialog");
  function showManagerProgressDialog(options5) {
    return dialogStore.showDialog({
      key: "global-manager-progress-dialog",
      component: _sfc_main$1x,
      headerComponent: _sfc_main$D,
      footerComponent: _sfc_main$E,
      props: options5?.props,
      dialogComponentProps: {
        closable: false,
        modal: false,
        position: "bottom",
        pt: {
          root: { class: "w-[80%] max-w-2xl mx-auto border-none" },
          content: { class: "!p-0" },
          header: { class: "!p-0 border-none" },
          footer: { class: "!p-0 border-none" }
        }
      }
    });
  }
  __name(showManagerProgressDialog, "showManagerProgressDialog");
  async function prompt({
    title,
    message: message3,
    defaultValue: defaultValue2 = ""
  }) {
    return new Promise((resolve2) => {
      dialogStore.showDialog({
        key: "global-prompt",
        title,
        component: _sfc_main$1t,
        props: {
          message: message3,
          defaultValue: defaultValue2,
          onConfirm: /* @__PURE__ */ __name((value3) => {
            resolve2(value3);
          }, "onConfirm")
        },
        dialogComponentProps: {
          onClose: /* @__PURE__ */ __name(() => {
            resolve2(null);
          }, "onClose")
        }
      });
    });
  }
  __name(prompt, "prompt");
  async function confirm2({
    title,
    message: message3,
    type = "default",
    itemList = [],
    hint
  }) {
    return new Promise((resolve2) => {
      const options5 = {
        key: "global-prompt",
        title,
        component: ConfirmationDialogContent,
        props: {
          message: message3,
          type,
          itemList,
          onConfirm: resolve2,
          hint
        },
        dialogComponentProps: {
          onClose: /* @__PURE__ */ __name(() => resolve2(null), "onClose")
        }
      };
      dialogStore.showDialog(options5);
    });
  }
  __name(confirm2, "confirm");
  return {
    showLoadWorkflowWarning,
    showMissingModelsWarning,
    showSettingsDialog,
    showAboutDialog,
    showExecutionErrorDialog,
    showTemplateWorkflowsDialog,
    showIssueReportDialog,
    showManagerDialog,
    showManagerProgressDialog,
    prompt,
    confirm: confirm2
  };
}, "useDialogService");
const CORE_MENU_COMMANDS = [
  [["Workflow"], ["Comfy.NewBlankWorkflow"]],
  [["Workflow"], ["Comfy.OpenWorkflow", "Comfy.BrowseTemplates"]],
  [
    ["Workflow"],
    [
      "Comfy.SaveWorkflow",
      "Comfy.SaveWorkflowAs",
      "Comfy.ExportWorkflow",
      "Comfy.ExportWorkflowAPI"
    ]
  ],
  [["Edit"], ["Comfy.Undo", "Comfy.Redo"]],
  [["Edit"], ["Comfy.RefreshNodeDefinitions"]],
  [["Edit"], ["Comfy.ClearWorkflow"]],
  [["Edit"], ["Comfy.OpenClipspace"]],
  [
    ["Help"],
    [
      "Comfy.Help.OpenComfyUIIssues",
      "Comfy.Help.OpenComfyUIDocs",
      "Comfy.Help.OpenComfyOrgDiscord",
      "Comfy.Help.OpenComfyUIForum"
    ]
  ],
  [["Help"], ["Comfy.Help.AboutComfyUI", "Comfy.Feedback"]]
];
const useMenuItemStore = /* @__PURE__ */ defineStore("menuItem", () => {
  const commandStore = useCommandStore();
  const menuItems = ref([]);
  const registerMenuGroup = /* @__PURE__ */ __name((path, items2) => {
    let currentLevel = menuItems.value;
    for (let i2 = 0; i2 < path.length; i2++) {
      const segment = path[i2];
      let found2 = currentLevel.find((item3) => item3.label === segment);
      if (!found2) {
        found2 = {
          label: segment,
          items: []
        };
        currentLevel.push(found2);
      }
      if (!found2.items) {
        found2.items = [];
      }
      currentLevel = found2.items;
    }
    if (currentLevel.length > 0) {
      currentLevel.push({
        separator: true
      });
    }
    currentLevel.push(...items2);
  }, "registerMenuGroup");
  const registerCommands = /* @__PURE__ */ __name((path, commandIds) => {
    const items2 = commandIds.map((commandId) => commandStore.getCommand(commandId)).map(
      (command2) => ({
        command: /* @__PURE__ */ __name(() => commandStore.execute(command2.id), "command"),
        label: command2.menubarLabel,
        icon: command2.icon,
        tooltip: command2.tooltip,
        comfyCommand: command2
      })
    );
    registerMenuGroup(path, items2);
  }, "registerCommands");
  const loadExtensionMenuCommands = /* @__PURE__ */ __name((extension) => {
    if (!extension.menuCommands) {
      return;
    }
    const extensionCommandIds = new Set(
      extension.commands?.map((command2) => command2.id) ?? []
    );
    extension.menuCommands.forEach((menuCommand) => {
      const commands2 = menuCommand.commands.filter(
        (command2) => extensionCommandIds.has(command2)
      );
      if (commands2.length) {
        registerCommands(menuCommand.path, commands2);
      }
    });
  }, "loadExtensionMenuCommands");
  const registerCoreMenuCommands = /* @__PURE__ */ __name(() => {
    for (const [path, commands2] of CORE_MENU_COMMANDS) {
      registerCommands(path, commands2);
    }
  }, "registerCoreMenuCommands");
  return {
    menuItems,
    registerMenuGroup,
    registerCommands,
    loadExtensionMenuCommands,
    registerCoreMenuCommands
  };
});
var addonFit$2 = { exports: {} };
var addonFit = addonFit$2.exports;
(function(module2, exports) {
  !function(e2, t2) {
    true ? module2.exports = t2() : false ? (void 0)([], t2) : true ? exports.FitAddon = t2() : e2.FitAddon = t2();
  }(self, () => (() => {
    "use strict";
    var e2 = {};
    return (() => {
      var t2 = e2;
      Object.defineProperty(t2, "__esModule", { value: true }), t2.FitAddon = void 0, t2.FitAddon = class {
        activate(e3) {
          this._terminal = e3;
        }
        dispose() {
        }
        fit() {
          const e3 = this.proposeDimensions();
          if (!e3 || !this._terminal || isNaN(e3.cols) || isNaN(e3.rows)) return;
          const t3 = this._terminal._core;
          this._terminal.rows === e3.rows && this._terminal.cols === e3.cols || (t3._renderService.clear(), this._terminal.resize(e3.cols, e3.rows));
        }
        proposeDimensions() {
          if (!this._terminal) return;
          if (!this._terminal.element || !this._terminal.element.parentElement) return;
          const e3 = this._terminal._core, t3 = e3._renderService.dimensions;
          if (0 === t3.css.cell.width || 0 === t3.css.cell.height) return;
          const r2 = 0 === this._terminal.options.scrollback ? 0 : e3.viewport.scrollBarWidth, i2 = window.getComputedStyle(this._terminal.element.parentElement), o2 = parseInt(i2.getPropertyValue("height")), s2 = Math.max(0, parseInt(i2.getPropertyValue("width"))), n2 = window.getComputedStyle(this._terminal.element), l2 = o2 - (parseInt(n2.getPropertyValue("padding-top")) + parseInt(n2.getPropertyValue("padding-bottom"))), a2 = s2 - (parseInt(n2.getPropertyValue("padding-right")) + parseInt(n2.getPropertyValue("padding-left"))) - r2;
          return { cols: Math.max(2, Math.floor(a2 / t3.css.cell.width)), rows: Math.max(1, Math.floor(l2 / t3.css.cell.height)) };
        }
      };
    })(), e2;
  })());
})(addonFit$2, addonFit$2.exports);
var addonFitExports = addonFit$2.exports;
const addonFit$1 = /* @__PURE__ */ getDefaultExportFromCjs(addonFitExports);
var xterm$2 = { exports: {} };
var xterm = xterm$2.exports;
(function(module2, exports) {
  !function(e2, t2) {
    if (true) module2.exports = t2();
    else if (false) (void 0)([], t2);
    else {
      var i2 = t2();
      for (var s2 in i2) (true ? exports : e2)[s2] = i2[s2];
    }
  }(globalThis, () => (() => {
    "use strict";
    var e2 = { 4567: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.AccessibilityManager = void 0;
      const n2 = i3(9042), o2 = i3(9924), a2 = i3(844), h2 = i3(4725), c2 = i3(2585), l2 = i3(3656);
      let d2 = t3.AccessibilityManager = class extends a2.Disposable {
        constructor(e4, t4, i4, s4) {
          super(), this._terminal = e4, this._coreBrowserService = i4, this._renderService = s4, this._rowColumns = /* @__PURE__ */ new WeakMap(), this._liveRegionLineCount = 0, this._charsToConsume = [], this._charsToAnnounce = "", this._accessibilityContainer = this._coreBrowserService.mainDocument.createElement("div"), this._accessibilityContainer.classList.add("xterm-accessibility"), this._rowContainer = this._coreBrowserService.mainDocument.createElement("div"), this._rowContainer.setAttribute("role", "list"), this._rowContainer.classList.add("xterm-accessibility-tree"), this._rowElements = [];
          for (let e5 = 0; e5 < this._terminal.rows; e5++) this._rowElements[e5] = this._createAccessibilityTreeNode(), this._rowContainer.appendChild(this._rowElements[e5]);
          if (this._topBoundaryFocusListener = (e5) => this._handleBoundaryFocus(e5, 0), this._bottomBoundaryFocusListener = (e5) => this._handleBoundaryFocus(e5, 1), this._rowElements[0].addEventListener("focus", this._topBoundaryFocusListener), this._rowElements[this._rowElements.length - 1].addEventListener("focus", this._bottomBoundaryFocusListener), this._refreshRowsDimensions(), this._accessibilityContainer.appendChild(this._rowContainer), this._liveRegion = this._coreBrowserService.mainDocument.createElement("div"), this._liveRegion.classList.add("live-region"), this._liveRegion.setAttribute("aria-live", "assertive"), this._accessibilityContainer.appendChild(this._liveRegion), this._liveRegionDebouncer = this.register(new o2.TimeBasedDebouncer(this._renderRows.bind(this))), !this._terminal.element) throw new Error("Cannot enable accessibility before Terminal.open");
          this._terminal.element.insertAdjacentElement("afterbegin", this._accessibilityContainer), this.register(this._terminal.onResize((e5) => this._handleResize(e5.rows))), this.register(this._terminal.onRender((e5) => this._refreshRows(e5.start, e5.end))), this.register(this._terminal.onScroll(() => this._refreshRows())), this.register(this._terminal.onA11yChar((e5) => this._handleChar(e5))), this.register(this._terminal.onLineFeed(() => this._handleChar("\n"))), this.register(this._terminal.onA11yTab((e5) => this._handleTab(e5))), this.register(this._terminal.onKey((e5) => this._handleKey(e5.key))), this.register(this._terminal.onBlur(() => this._clearLiveRegion())), this.register(this._renderService.onDimensionsChange(() => this._refreshRowsDimensions())), this.register((0, l2.addDisposableDomListener)(document, "selectionchange", () => this._handleSelectionChange())), this.register(this._coreBrowserService.onDprChange(() => this._refreshRowsDimensions())), this._refreshRows(), this.register((0, a2.toDisposable)(() => {
            this._accessibilityContainer.remove(), this._rowElements.length = 0;
          }));
        }
        _handleTab(e4) {
          for (let t4 = 0; t4 < e4; t4++) this._handleChar(" ");
        }
        _handleChar(e4) {
          this._liveRegionLineCount < 21 && (this._charsToConsume.length > 0 ? this._charsToConsume.shift() !== e4 && (this._charsToAnnounce += e4) : this._charsToAnnounce += e4, "\n" === e4 && (this._liveRegionLineCount++, 21 === this._liveRegionLineCount && (this._liveRegion.textContent += n2.tooMuchOutput)));
        }
        _clearLiveRegion() {
          this._liveRegion.textContent = "", this._liveRegionLineCount = 0;
        }
        _handleKey(e4) {
          this._clearLiveRegion(), /\p{Control}/u.test(e4) || this._charsToConsume.push(e4);
        }
        _refreshRows(e4, t4) {
          this._liveRegionDebouncer.refresh(e4, t4, this._terminal.rows);
        }
        _renderRows(e4, t4) {
          const i4 = this._terminal.buffer, s4 = i4.lines.length.toString();
          for (let r3 = e4; r3 <= t4; r3++) {
            const e5 = i4.lines.get(i4.ydisp + r3), t5 = [], n3 = e5?.translateToString(true, void 0, void 0, t5) || "", o3 = (i4.ydisp + r3 + 1).toString(), a3 = this._rowElements[r3];
            a3 && (0 === n3.length ? (a3.innerText = " ", this._rowColumns.set(a3, [0, 1])) : (a3.textContent = n3, this._rowColumns.set(a3, t5)), a3.setAttribute("aria-posinset", o3), a3.setAttribute("aria-setsize", s4));
          }
          this._announceCharacters();
        }
        _announceCharacters() {
          0 !== this._charsToAnnounce.length && (this._liveRegion.textContent += this._charsToAnnounce, this._charsToAnnounce = "");
        }
        _handleBoundaryFocus(e4, t4) {
          const i4 = e4.target, s4 = this._rowElements[0 === t4 ? 1 : this._rowElements.length - 2];
          if (i4.getAttribute("aria-posinset") === (0 === t4 ? "1" : `${this._terminal.buffer.lines.length}`)) return;
          if (e4.relatedTarget !== s4) return;
          let r3, n3;
          if (0 === t4 ? (r3 = i4, n3 = this._rowElements.pop(), this._rowContainer.removeChild(n3)) : (r3 = this._rowElements.shift(), n3 = i4, this._rowContainer.removeChild(r3)), r3.removeEventListener("focus", this._topBoundaryFocusListener), n3.removeEventListener("focus", this._bottomBoundaryFocusListener), 0 === t4) {
            const e5 = this._createAccessibilityTreeNode();
            this._rowElements.unshift(e5), this._rowContainer.insertAdjacentElement("afterbegin", e5);
          } else {
            const e5 = this._createAccessibilityTreeNode();
            this._rowElements.push(e5), this._rowContainer.appendChild(e5);
          }
          this._rowElements[0].addEventListener("focus", this._topBoundaryFocusListener), this._rowElements[this._rowElements.length - 1].addEventListener("focus", this._bottomBoundaryFocusListener), this._terminal.scrollLines(0 === t4 ? -1 : 1), this._rowElements[0 === t4 ? 1 : this._rowElements.length - 2].focus(), e4.preventDefault(), e4.stopImmediatePropagation();
        }
        _handleSelectionChange() {
          if (0 === this._rowElements.length) return;
          const e4 = document.getSelection();
          if (!e4) return;
          if (e4.isCollapsed) return void (this._rowContainer.contains(e4.anchorNode) && this._terminal.clearSelection());
          if (!e4.anchorNode || !e4.focusNode) return void console.error("anchorNode and/or focusNode are null");
          let t4 = { node: e4.anchorNode, offset: e4.anchorOffset }, i4 = { node: e4.focusNode, offset: e4.focusOffset };
          if ((t4.node.compareDocumentPosition(i4.node) & Node.DOCUMENT_POSITION_PRECEDING || t4.node === i4.node && t4.offset > i4.offset) && ([t4, i4] = [i4, t4]), t4.node.compareDocumentPosition(this._rowElements[0]) & (Node.DOCUMENT_POSITION_CONTAINED_BY | Node.DOCUMENT_POSITION_FOLLOWING) && (t4 = { node: this._rowElements[0].childNodes[0], offset: 0 }), !this._rowContainer.contains(t4.node)) return;
          const s4 = this._rowElements.slice(-1)[0];
          if (i4.node.compareDocumentPosition(s4) & (Node.DOCUMENT_POSITION_CONTAINED_BY | Node.DOCUMENT_POSITION_PRECEDING) && (i4 = { node: s4, offset: s4.textContent?.length ?? 0 }), !this._rowContainer.contains(i4.node)) return;
          const r3 = /* @__PURE__ */ __name(({ node: e5, offset: t5 }) => {
            const i5 = e5 instanceof Text ? e5.parentNode : e5;
            let s5 = parseInt(i5?.getAttribute("aria-posinset"), 10) - 1;
            if (isNaN(s5)) return console.warn("row is invalid. Race condition?"), null;
            const r4 = this._rowColumns.get(i5);
            if (!r4) return console.warn("columns is null. Race condition?"), null;
            let n4 = t5 < r4.length ? r4[t5] : r4.slice(-1)[0] + 1;
            return n4 >= this._terminal.cols && (++s5, n4 = 0), { row: s5, column: n4 };
          }, "r"), n3 = r3(t4), o3 = r3(i4);
          if (n3 && o3) {
            if (n3.row > o3.row || n3.row === o3.row && n3.column >= o3.column) throw new Error("invalid range");
            this._terminal.select(n3.column, n3.row, (o3.row - n3.row) * this._terminal.cols - n3.column + o3.column);
          }
        }
        _handleResize(e4) {
          this._rowElements[this._rowElements.length - 1].removeEventListener("focus", this._bottomBoundaryFocusListener);
          for (let e5 = this._rowContainer.children.length; e5 < this._terminal.rows; e5++) this._rowElements[e5] = this._createAccessibilityTreeNode(), this._rowContainer.appendChild(this._rowElements[e5]);
          for (; this._rowElements.length > e4; ) this._rowContainer.removeChild(this._rowElements.pop());
          this._rowElements[this._rowElements.length - 1].addEventListener("focus", this._bottomBoundaryFocusListener), this._refreshRowsDimensions();
        }
        _createAccessibilityTreeNode() {
          const e4 = this._coreBrowserService.mainDocument.createElement("div");
          return e4.setAttribute("role", "listitem"), e4.tabIndex = -1, this._refreshRowDimensions(e4), e4;
        }
        _refreshRowsDimensions() {
          if (this._renderService.dimensions.css.cell.height) {
            this._accessibilityContainer.style.width = `${this._renderService.dimensions.css.canvas.width}px`, this._rowElements.length !== this._terminal.rows && this._handleResize(this._terminal.rows);
            for (let e4 = 0; e4 < this._terminal.rows; e4++) this._refreshRowDimensions(this._rowElements[e4]);
          }
        }
        _refreshRowDimensions(e4) {
          e4.style.height = `${this._renderService.dimensions.css.cell.height}px`;
        }
      };
      t3.AccessibilityManager = d2 = s3([r2(1, c2.IInstantiationService), r2(2, h2.ICoreBrowserService), r2(3, h2.IRenderService)], d2);
    }, 3614: (e3, t3) => {
      function i3(e4) {
        return e4.replace(/\r?\n/g, "\r");
      }
      __name(i3, "i");
      function s3(e4, t4) {
        return t4 ? "\x1B[200~" + e4 + "\x1B[201~" : e4;
      }
      __name(s3, "s");
      function r2(e4, t4, r3, n3) {
        e4 = s3(e4 = i3(e4), r3.decPrivateModes.bracketedPasteMode && true !== n3.rawOptions.ignoreBracketedPasteMode), r3.triggerDataEvent(e4, true), t4.value = "";
      }
      __name(r2, "r");
      function n2(e4, t4, i4) {
        const s4 = i4.getBoundingClientRect(), r3 = e4.clientX - s4.left - 10, n3 = e4.clientY - s4.top - 10;
        t4.style.width = "20px", t4.style.height = "20px", t4.style.left = `${r3}px`, t4.style.top = `${n3}px`, t4.style.zIndex = "1000", t4.focus();
      }
      __name(n2, "n");
      Object.defineProperty(t3, "__esModule", { value: true }), t3.rightClickHandler = t3.moveTextAreaUnderMouseCursor = t3.paste = t3.handlePasteEvent = t3.copyHandler = t3.bracketTextForPaste = t3.prepareTextForTerminal = void 0, t3.prepareTextForTerminal = i3, t3.bracketTextForPaste = s3, t3.copyHandler = function(e4, t4) {
        e4.clipboardData && e4.clipboardData.setData("text/plain", t4.selectionText), e4.preventDefault();
      }, t3.handlePasteEvent = function(e4, t4, i4, s4) {
        e4.stopPropagation(), e4.clipboardData && r2(e4.clipboardData.getData("text/plain"), t4, i4, s4);
      }, t3.paste = r2, t3.moveTextAreaUnderMouseCursor = n2, t3.rightClickHandler = function(e4, t4, i4, s4, r3) {
        n2(e4, t4, i4), r3 && s4.rightClickSelect(e4), t4.value = s4.selectionText, t4.select();
      };
    }, 7239: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ColorContrastCache = void 0;
      const s3 = i3(1505);
      t3.ColorContrastCache = class {
        constructor() {
          this._color = new s3.TwoKeyMap(), this._css = new s3.TwoKeyMap();
        }
        setCss(e4, t4, i4) {
          this._css.set(e4, t4, i4);
        }
        getCss(e4, t4) {
          return this._css.get(e4, t4);
        }
        setColor(e4, t4, i4) {
          this._color.set(e4, t4, i4);
        }
        getColor(e4, t4) {
          return this._color.get(e4, t4);
        }
        clear() {
          this._color.clear(), this._css.clear();
        }
      };
    }, 3656: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.addDisposableDomListener = void 0, t3.addDisposableDomListener = function(e4, t4, i3, s3) {
        e4.addEventListener(t4, i3, s3);
        let r2 = false;
        return { dispose: /* @__PURE__ */ __name(() => {
          r2 || (r2 = true, e4.removeEventListener(t4, i3, s3));
        }, "dispose") };
      };
    }, 3551: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Linkifier = void 0;
      const n2 = i3(3656), o2 = i3(8460), a2 = i3(844), h2 = i3(2585), c2 = i3(4725);
      let l2 = t3.Linkifier = class extends a2.Disposable {
        get currentLink() {
          return this._currentLink;
        }
        constructor(e4, t4, i4, s4, r3) {
          super(), this._element = e4, this._mouseService = t4, this._renderService = i4, this._bufferService = s4, this._linkProviderService = r3, this._linkCacheDisposables = [], this._isMouseOut = true, this._wasResized = false, this._activeLine = -1, this._onShowLinkUnderline = this.register(new o2.EventEmitter()), this.onShowLinkUnderline = this._onShowLinkUnderline.event, this._onHideLinkUnderline = this.register(new o2.EventEmitter()), this.onHideLinkUnderline = this._onHideLinkUnderline.event, this.register((0, a2.getDisposeArrayDisposable)(this._linkCacheDisposables)), this.register((0, a2.toDisposable)(() => {
            this._lastMouseEvent = void 0, this._activeProviderReplies?.clear();
          })), this.register(this._bufferService.onResize(() => {
            this._clearCurrentLink(), this._wasResized = true;
          })), this.register((0, n2.addDisposableDomListener)(this._element, "mouseleave", () => {
            this._isMouseOut = true, this._clearCurrentLink();
          })), this.register((0, n2.addDisposableDomListener)(this._element, "mousemove", this._handleMouseMove.bind(this))), this.register((0, n2.addDisposableDomListener)(this._element, "mousedown", this._handleMouseDown.bind(this))), this.register((0, n2.addDisposableDomListener)(this._element, "mouseup", this._handleMouseUp.bind(this)));
        }
        _handleMouseMove(e4) {
          this._lastMouseEvent = e4;
          const t4 = this._positionFromMouseEvent(e4, this._element, this._mouseService);
          if (!t4) return;
          this._isMouseOut = false;
          const i4 = e4.composedPath();
          for (let e5 = 0; e5 < i4.length; e5++) {
            const t5 = i4[e5];
            if (t5.classList.contains("xterm")) break;
            if (t5.classList.contains("xterm-hover")) return;
          }
          this._lastBufferCell && t4.x === this._lastBufferCell.x && t4.y === this._lastBufferCell.y || (this._handleHover(t4), this._lastBufferCell = t4);
        }
        _handleHover(e4) {
          if (this._activeLine !== e4.y || this._wasResized) return this._clearCurrentLink(), this._askForLink(e4, false), void (this._wasResized = false);
          this._currentLink && this._linkAtPosition(this._currentLink.link, e4) || (this._clearCurrentLink(), this._askForLink(e4, true));
        }
        _askForLink(e4, t4) {
          this._activeProviderReplies && t4 || (this._activeProviderReplies?.forEach((e5) => {
            e5?.forEach((e6) => {
              e6.link.dispose && e6.link.dispose();
            });
          }), this._activeProviderReplies = /* @__PURE__ */ new Map(), this._activeLine = e4.y);
          let i4 = false;
          for (const [s4, r3] of this._linkProviderService.linkProviders.entries()) if (t4) {
            const t5 = this._activeProviderReplies?.get(s4);
            t5 && (i4 = this._checkLinkProviderResult(s4, e4, i4));
          } else r3.provideLinks(e4.y, (t5) => {
            if (this._isMouseOut) return;
            const r4 = t5?.map((e5) => ({ link: e5 }));
            this._activeProviderReplies?.set(s4, r4), i4 = this._checkLinkProviderResult(s4, e4, i4), this._activeProviderReplies?.size === this._linkProviderService.linkProviders.length && this._removeIntersectingLinks(e4.y, this._activeProviderReplies);
          });
        }
        _removeIntersectingLinks(e4, t4) {
          const i4 = /* @__PURE__ */ new Set();
          for (let s4 = 0; s4 < t4.size; s4++) {
            const r3 = t4.get(s4);
            if (r3) for (let t5 = 0; t5 < r3.length; t5++) {
              const s5 = r3[t5], n3 = s5.link.range.start.y < e4 ? 0 : s5.link.range.start.x, o3 = s5.link.range.end.y > e4 ? this._bufferService.cols : s5.link.range.end.x;
              for (let e5 = n3; e5 <= o3; e5++) {
                if (i4.has(e5)) {
                  r3.splice(t5--, 1);
                  break;
                }
                i4.add(e5);
              }
            }
          }
        }
        _checkLinkProviderResult(e4, t4, i4) {
          if (!this._activeProviderReplies) return i4;
          const s4 = this._activeProviderReplies.get(e4);
          let r3 = false;
          for (let t5 = 0; t5 < e4; t5++) this._activeProviderReplies.has(t5) && !this._activeProviderReplies.get(t5) || (r3 = true);
          if (!r3 && s4) {
            const e5 = s4.find((e6) => this._linkAtPosition(e6.link, t4));
            e5 && (i4 = true, this._handleNewLink(e5));
          }
          if (this._activeProviderReplies.size === this._linkProviderService.linkProviders.length && !i4) for (let e5 = 0; e5 < this._activeProviderReplies.size; e5++) {
            const s5 = this._activeProviderReplies.get(e5)?.find((e6) => this._linkAtPosition(e6.link, t4));
            if (s5) {
              i4 = true, this._handleNewLink(s5);
              break;
            }
          }
          return i4;
        }
        _handleMouseDown() {
          this._mouseDownLink = this._currentLink;
        }
        _handleMouseUp(e4) {
          if (!this._currentLink) return;
          const t4 = this._positionFromMouseEvent(e4, this._element, this._mouseService);
          t4 && this._mouseDownLink === this._currentLink && this._linkAtPosition(this._currentLink.link, t4) && this._currentLink.link.activate(e4, this._currentLink.link.text);
        }
        _clearCurrentLink(e4, t4) {
          this._currentLink && this._lastMouseEvent && (!e4 || !t4 || this._currentLink.link.range.start.y >= e4 && this._currentLink.link.range.end.y <= t4) && (this._linkLeave(this._element, this._currentLink.link, this._lastMouseEvent), this._currentLink = void 0, (0, a2.disposeArray)(this._linkCacheDisposables));
        }
        _handleNewLink(e4) {
          if (!this._lastMouseEvent) return;
          const t4 = this._positionFromMouseEvent(this._lastMouseEvent, this._element, this._mouseService);
          t4 && this._linkAtPosition(e4.link, t4) && (this._currentLink = e4, this._currentLink.state = { decorations: { underline: void 0 === e4.link.decorations || e4.link.decorations.underline, pointerCursor: void 0 === e4.link.decorations || e4.link.decorations.pointerCursor }, isHovered: true }, this._linkHover(this._element, e4.link, this._lastMouseEvent), e4.link.decorations = {}, Object.defineProperties(e4.link.decorations, { pointerCursor: { get: /* @__PURE__ */ __name(() => this._currentLink?.state?.decorations.pointerCursor, "get"), set: /* @__PURE__ */ __name((e5) => {
            this._currentLink?.state && this._currentLink.state.decorations.pointerCursor !== e5 && (this._currentLink.state.decorations.pointerCursor = e5, this._currentLink.state.isHovered && this._element.classList.toggle("xterm-cursor-pointer", e5));
          }, "set") }, underline: { get: /* @__PURE__ */ __name(() => this._currentLink?.state?.decorations.underline, "get"), set: /* @__PURE__ */ __name((t5) => {
            this._currentLink?.state && this._currentLink?.state?.decorations.underline !== t5 && (this._currentLink.state.decorations.underline = t5, this._currentLink.state.isHovered && this._fireUnderlineEvent(e4.link, t5));
          }, "set") } }), this._linkCacheDisposables.push(this._renderService.onRenderedViewportChange((e5) => {
            if (!this._currentLink) return;
            const t5 = 0 === e5.start ? 0 : e5.start + 1 + this._bufferService.buffer.ydisp, i4 = this._bufferService.buffer.ydisp + 1 + e5.end;
            if (this._currentLink.link.range.start.y >= t5 && this._currentLink.link.range.end.y <= i4 && (this._clearCurrentLink(t5, i4), this._lastMouseEvent)) {
              const e6 = this._positionFromMouseEvent(this._lastMouseEvent, this._element, this._mouseService);
              e6 && this._askForLink(e6, false);
            }
          })));
        }
        _linkHover(e4, t4, i4) {
          this._currentLink?.state && (this._currentLink.state.isHovered = true, this._currentLink.state.decorations.underline && this._fireUnderlineEvent(t4, true), this._currentLink.state.decorations.pointerCursor && e4.classList.add("xterm-cursor-pointer")), t4.hover && t4.hover(i4, t4.text);
        }
        _fireUnderlineEvent(e4, t4) {
          const i4 = e4.range, s4 = this._bufferService.buffer.ydisp, r3 = this._createLinkUnderlineEvent(i4.start.x - 1, i4.start.y - s4 - 1, i4.end.x, i4.end.y - s4 - 1, void 0);
          (t4 ? this._onShowLinkUnderline : this._onHideLinkUnderline).fire(r3);
        }
        _linkLeave(e4, t4, i4) {
          this._currentLink?.state && (this._currentLink.state.isHovered = false, this._currentLink.state.decorations.underline && this._fireUnderlineEvent(t4, false), this._currentLink.state.decorations.pointerCursor && e4.classList.remove("xterm-cursor-pointer")), t4.leave && t4.leave(i4, t4.text);
        }
        _linkAtPosition(e4, t4) {
          const i4 = e4.range.start.y * this._bufferService.cols + e4.range.start.x, s4 = e4.range.end.y * this._bufferService.cols + e4.range.end.x, r3 = t4.y * this._bufferService.cols + t4.x;
          return i4 <= r3 && r3 <= s4;
        }
        _positionFromMouseEvent(e4, t4, i4) {
          const s4 = i4.getCoords(e4, t4, this._bufferService.cols, this._bufferService.rows);
          if (s4) return { x: s4[0], y: s4[1] + this._bufferService.buffer.ydisp };
        }
        _createLinkUnderlineEvent(e4, t4, i4, s4, r3) {
          return { x1: e4, y1: t4, x2: i4, y2: s4, cols: this._bufferService.cols, fg: r3 };
        }
      };
      t3.Linkifier = l2 = s3([r2(1, c2.IMouseService), r2(2, c2.IRenderService), r2(3, h2.IBufferService), r2(4, c2.ILinkProviderService)], l2);
    }, 9042: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.tooMuchOutput = t3.promptLabel = void 0, t3.promptLabel = "Terminal input", t3.tooMuchOutput = "Too much output to announce, navigate to rows manually to read";
    }, 3730: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.OscLinkProvider = void 0;
      const n2 = i3(511), o2 = i3(2585);
      let a2 = t3.OscLinkProvider = class {
        constructor(e4, t4, i4) {
          this._bufferService = e4, this._optionsService = t4, this._oscLinkService = i4;
        }
        provideLinks(e4, t4) {
          const i4 = this._bufferService.buffer.lines.get(e4 - 1);
          if (!i4) return void t4(void 0);
          const s4 = [], r3 = this._optionsService.rawOptions.linkHandler, o3 = new n2.CellData(), a3 = i4.getTrimmedLength();
          let c2 = -1, l2 = -1, d2 = false;
          for (let t5 = 0; t5 < a3; t5++) if (-1 !== l2 || i4.hasContent(t5)) {
            if (i4.loadCell(t5, o3), o3.hasExtendedAttrs() && o3.extended.urlId) {
              if (-1 === l2) {
                l2 = t5, c2 = o3.extended.urlId;
                continue;
              }
              d2 = o3.extended.urlId !== c2;
            } else -1 !== l2 && (d2 = true);
            if (d2 || -1 !== l2 && t5 === a3 - 1) {
              const i5 = this._oscLinkService.getLinkData(c2)?.uri;
              if (i5) {
                const n3 = { start: { x: l2 + 1, y: e4 }, end: { x: t5 + (d2 || t5 !== a3 - 1 ? 0 : 1), y: e4 } };
                let o4 = false;
                if (!r3?.allowNonHttpProtocols) try {
                  const e5 = new URL(i5);
                  ["http:", "https:"].includes(e5.protocol) || (o4 = true);
                } catch (e5) {
                  o4 = true;
                }
                o4 || s4.push({ text: i5, range: n3, activate: /* @__PURE__ */ __name((e5, t6) => r3 ? r3.activate(e5, t6, n3) : h2(0, t6), "activate"), hover: /* @__PURE__ */ __name((e5, t6) => r3?.hover?.(e5, t6, n3), "hover"), leave: /* @__PURE__ */ __name((e5, t6) => r3?.leave?.(e5, t6, n3), "leave") });
              }
              d2 = false, o3.hasExtendedAttrs() && o3.extended.urlId ? (l2 = t5, c2 = o3.extended.urlId) : (l2 = -1, c2 = -1);
            }
          }
          t4(s4);
        }
      };
      function h2(e4, t4) {
        if (confirm(`Do you want to navigate to ${t4}?

WARNING: This link could potentially be dangerous`)) {
          const e5 = window.open();
          if (e5) {
            try {
              e5.opener = null;
            } catch {
            }
            e5.location.href = t4;
          } else console.warn("Opening link blocked as opener could not be cleared");
        }
      }
      __name(h2, "h");
      t3.OscLinkProvider = a2 = s3([r2(0, o2.IBufferService), r2(1, o2.IOptionsService), r2(2, o2.IOscLinkService)], a2);
    }, 6193: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.RenderDebouncer = void 0, t3.RenderDebouncer = class {
        constructor(e4, t4) {
          this._renderCallback = e4, this._coreBrowserService = t4, this._refreshCallbacks = [];
        }
        dispose() {
          this._animationFrame && (this._coreBrowserService.window.cancelAnimationFrame(this._animationFrame), this._animationFrame = void 0);
        }
        addRefreshCallback(e4) {
          return this._refreshCallbacks.push(e4), this._animationFrame || (this._animationFrame = this._coreBrowserService.window.requestAnimationFrame(() => this._innerRefresh())), this._animationFrame;
        }
        refresh(e4, t4, i3) {
          this._rowCount = i3, e4 = void 0 !== e4 ? e4 : 0, t4 = void 0 !== t4 ? t4 : this._rowCount - 1, this._rowStart = void 0 !== this._rowStart ? Math.min(this._rowStart, e4) : e4, this._rowEnd = void 0 !== this._rowEnd ? Math.max(this._rowEnd, t4) : t4, this._animationFrame || (this._animationFrame = this._coreBrowserService.window.requestAnimationFrame(() => this._innerRefresh()));
        }
        _innerRefresh() {
          if (this._animationFrame = void 0, void 0 === this._rowStart || void 0 === this._rowEnd || void 0 === this._rowCount) return void this._runRefreshCallbacks();
          const e4 = Math.max(this._rowStart, 0), t4 = Math.min(this._rowEnd, this._rowCount - 1);
          this._rowStart = void 0, this._rowEnd = void 0, this._renderCallback(e4, t4), this._runRefreshCallbacks();
        }
        _runRefreshCallbacks() {
          for (const e4 of this._refreshCallbacks) e4(0);
          this._refreshCallbacks = [];
        }
      };
    }, 3236: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Terminal = void 0;
      const s3 = i3(3614), r2 = i3(3656), n2 = i3(3551), o2 = i3(9042), a2 = i3(3730), h2 = i3(1680), c2 = i3(3107), l2 = i3(5744), d2 = i3(2950), _2 = i3(1296), u2 = i3(428), f2 = i3(4269), v2 = i3(5114), p2 = i3(8934), g2 = i3(3230), m2 = i3(9312), S2 = i3(4725), C2 = i3(6731), b2 = i3(8055), w2 = i3(8969), y2 = i3(8460), E = i3(844), k2 = i3(6114), L2 = i3(8437), D2 = i3(2584), R = i3(7399), x2 = i3(5941), A2 = i3(9074), B2 = i3(2585), T2 = i3(5435), M2 = i3(4567), O2 = i3(779);
      class P2 extends w2.CoreTerminal {
        static {
          __name(this, "P");
        }
        get onFocus() {
          return this._onFocus.event;
        }
        get onBlur() {
          return this._onBlur.event;
        }
        get onA11yChar() {
          return this._onA11yCharEmitter.event;
        }
        get onA11yTab() {
          return this._onA11yTabEmitter.event;
        }
        get onWillOpen() {
          return this._onWillOpen.event;
        }
        constructor(e4 = {}) {
          super(e4), this.browser = k2, this._keyDownHandled = false, this._keyDownSeen = false, this._keyPressHandled = false, this._unprocessedDeadKey = false, this._accessibilityManager = this.register(new E.MutableDisposable()), this._onCursorMove = this.register(new y2.EventEmitter()), this.onCursorMove = this._onCursorMove.event, this._onKey = this.register(new y2.EventEmitter()), this.onKey = this._onKey.event, this._onRender = this.register(new y2.EventEmitter()), this.onRender = this._onRender.event, this._onSelectionChange = this.register(new y2.EventEmitter()), this.onSelectionChange = this._onSelectionChange.event, this._onTitleChange = this.register(new y2.EventEmitter()), this.onTitleChange = this._onTitleChange.event, this._onBell = this.register(new y2.EventEmitter()), this.onBell = this._onBell.event, this._onFocus = this.register(new y2.EventEmitter()), this._onBlur = this.register(new y2.EventEmitter()), this._onA11yCharEmitter = this.register(new y2.EventEmitter()), this._onA11yTabEmitter = this.register(new y2.EventEmitter()), this._onWillOpen = this.register(new y2.EventEmitter()), this._setup(), this._decorationService = this._instantiationService.createInstance(A2.DecorationService), this._instantiationService.setService(B2.IDecorationService, this._decorationService), this._linkProviderService = this._instantiationService.createInstance(O2.LinkProviderService), this._instantiationService.setService(S2.ILinkProviderService, this._linkProviderService), this._linkProviderService.registerLinkProvider(this._instantiationService.createInstance(a2.OscLinkProvider)), this.register(this._inputHandler.onRequestBell(() => this._onBell.fire())), this.register(this._inputHandler.onRequestRefreshRows((e5, t4) => this.refresh(e5, t4))), this.register(this._inputHandler.onRequestSendFocus(() => this._reportFocus())), this.register(this._inputHandler.onRequestReset(() => this.reset())), this.register(this._inputHandler.onRequestWindowsOptionsReport((e5) => this._reportWindowsOptions(e5))), this.register(this._inputHandler.onColor((e5) => this._handleColorEvent(e5))), this.register((0, y2.forwardEvent)(this._inputHandler.onCursorMove, this._onCursorMove)), this.register((0, y2.forwardEvent)(this._inputHandler.onTitleChange, this._onTitleChange)), this.register((0, y2.forwardEvent)(this._inputHandler.onA11yChar, this._onA11yCharEmitter)), this.register((0, y2.forwardEvent)(this._inputHandler.onA11yTab, this._onA11yTabEmitter)), this.register(this._bufferService.onResize((e5) => this._afterResize(e5.cols, e5.rows))), this.register((0, E.toDisposable)(() => {
            this._customKeyEventHandler = void 0, this.element?.parentNode?.removeChild(this.element);
          }));
        }
        _handleColorEvent(e4) {
          if (this._themeService) for (const t4 of e4) {
            let e5, i4 = "";
            switch (t4.index) {
              case 256:
                e5 = "foreground", i4 = "10";
                break;
              case 257:
                e5 = "background", i4 = "11";
                break;
              case 258:
                e5 = "cursor", i4 = "12";
                break;
              default:
                e5 = "ansi", i4 = "4;" + t4.index;
            }
            switch (t4.type) {
              case 0:
                const s4 = b2.color.toColorRGB("ansi" === e5 ? this._themeService.colors.ansi[t4.index] : this._themeService.colors[e5]);
                this.coreService.triggerDataEvent(`${D2.C0.ESC}]${i4};${(0, x2.toRgbString)(s4)}${D2.C1_ESCAPED.ST}`);
                break;
              case 1:
                if ("ansi" === e5) this._themeService.modifyColors((e6) => e6.ansi[t4.index] = b2.channels.toColor(...t4.color));
                else {
                  const i5 = e5;
                  this._themeService.modifyColors((e6) => e6[i5] = b2.channels.toColor(...t4.color));
                }
                break;
              case 2:
                this._themeService.restoreColor(t4.index);
            }
          }
        }
        _setup() {
          super._setup(), this._customKeyEventHandler = void 0;
        }
        get buffer() {
          return this.buffers.active;
        }
        focus() {
          this.textarea && this.textarea.focus({ preventScroll: true });
        }
        _handleScreenReaderModeOptionChange(e4) {
          e4 ? !this._accessibilityManager.value && this._renderService && (this._accessibilityManager.value = this._instantiationService.createInstance(M2.AccessibilityManager, this)) : this._accessibilityManager.clear();
        }
        _handleTextAreaFocus(e4) {
          this.coreService.decPrivateModes.sendFocus && this.coreService.triggerDataEvent(D2.C0.ESC + "[I"), this.element.classList.add("focus"), this._showCursor(), this._onFocus.fire();
        }
        blur() {
          return this.textarea?.blur();
        }
        _handleTextAreaBlur() {
          this.textarea.value = "", this.refresh(this.buffer.y, this.buffer.y), this.coreService.decPrivateModes.sendFocus && this.coreService.triggerDataEvent(D2.C0.ESC + "[O"), this.element.classList.remove("focus"), this._onBlur.fire();
        }
        _syncTextArea() {
          if (!this.textarea || !this.buffer.isCursorInViewport || this._compositionHelper.isComposing || !this._renderService) return;
          const e4 = this.buffer.ybase + this.buffer.y, t4 = this.buffer.lines.get(e4);
          if (!t4) return;
          const i4 = Math.min(this.buffer.x, this.cols - 1), s4 = this._renderService.dimensions.css.cell.height, r3 = t4.getWidth(i4), n3 = this._renderService.dimensions.css.cell.width * r3, o3 = this.buffer.y * this._renderService.dimensions.css.cell.height, a3 = i4 * this._renderService.dimensions.css.cell.width;
          this.textarea.style.left = a3 + "px", this.textarea.style.top = o3 + "px", this.textarea.style.width = n3 + "px", this.textarea.style.height = s4 + "px", this.textarea.style.lineHeight = s4 + "px", this.textarea.style.zIndex = "-5";
        }
        _initGlobal() {
          this._bindKeys(), this.register((0, r2.addDisposableDomListener)(this.element, "copy", (e5) => {
            this.hasSelection() && (0, s3.copyHandler)(e5, this._selectionService);
          }));
          const e4 = /* @__PURE__ */ __name((e5) => (0, s3.handlePasteEvent)(e5, this.textarea, this.coreService, this.optionsService), "e");
          this.register((0, r2.addDisposableDomListener)(this.textarea, "paste", e4)), this.register((0, r2.addDisposableDomListener)(this.element, "paste", e4)), k2.isFirefox ? this.register((0, r2.addDisposableDomListener)(this.element, "mousedown", (e5) => {
            2 === e5.button && (0, s3.rightClickHandler)(e5, this.textarea, this.screenElement, this._selectionService, this.options.rightClickSelectsWord);
          })) : this.register((0, r2.addDisposableDomListener)(this.element, "contextmenu", (e5) => {
            (0, s3.rightClickHandler)(e5, this.textarea, this.screenElement, this._selectionService, this.options.rightClickSelectsWord);
          })), k2.isLinux && this.register((0, r2.addDisposableDomListener)(this.element, "auxclick", (e5) => {
            1 === e5.button && (0, s3.moveTextAreaUnderMouseCursor)(e5, this.textarea, this.screenElement);
          }));
        }
        _bindKeys() {
          this.register((0, r2.addDisposableDomListener)(this.textarea, "keyup", (e4) => this._keyUp(e4), true)), this.register((0, r2.addDisposableDomListener)(this.textarea, "keydown", (e4) => this._keyDown(e4), true)), this.register((0, r2.addDisposableDomListener)(this.textarea, "keypress", (e4) => this._keyPress(e4), true)), this.register((0, r2.addDisposableDomListener)(this.textarea, "compositionstart", () => this._compositionHelper.compositionstart())), this.register((0, r2.addDisposableDomListener)(this.textarea, "compositionupdate", (e4) => this._compositionHelper.compositionupdate(e4))), this.register((0, r2.addDisposableDomListener)(this.textarea, "compositionend", () => this._compositionHelper.compositionend())), this.register((0, r2.addDisposableDomListener)(this.textarea, "input", (e4) => this._inputEvent(e4), true)), this.register(this.onRender(() => this._compositionHelper.updateCompositionElements()));
        }
        open(e4) {
          if (!e4) throw new Error("Terminal requires a parent element.");
          if (e4.isConnected || this._logService.debug("Terminal.open was called on an element that was not attached to the DOM"), this.element?.ownerDocument.defaultView && this._coreBrowserService) return void (this.element.ownerDocument.defaultView !== this._coreBrowserService.window && (this._coreBrowserService.window = this.element.ownerDocument.defaultView));
          this._document = e4.ownerDocument, this.options.documentOverride && this.options.documentOverride instanceof Document && (this._document = this.optionsService.rawOptions.documentOverride), this.element = this._document.createElement("div"), this.element.dir = "ltr", this.element.classList.add("terminal"), this.element.classList.add("xterm"), e4.appendChild(this.element);
          const t4 = this._document.createDocumentFragment();
          this._viewportElement = this._document.createElement("div"), this._viewportElement.classList.add("xterm-viewport"), t4.appendChild(this._viewportElement), this._viewportScrollArea = this._document.createElement("div"), this._viewportScrollArea.classList.add("xterm-scroll-area"), this._viewportElement.appendChild(this._viewportScrollArea), this.screenElement = this._document.createElement("div"), this.screenElement.classList.add("xterm-screen"), this.register((0, r2.addDisposableDomListener)(this.screenElement, "mousemove", (e5) => this.updateCursorStyle(e5))), this._helperContainer = this._document.createElement("div"), this._helperContainer.classList.add("xterm-helpers"), this.screenElement.appendChild(this._helperContainer), t4.appendChild(this.screenElement), this.textarea = this._document.createElement("textarea"), this.textarea.classList.add("xterm-helper-textarea"), this.textarea.setAttribute("aria-label", o2.promptLabel), k2.isChromeOS || this.textarea.setAttribute("aria-multiline", "false"), this.textarea.setAttribute("autocorrect", "off"), this.textarea.setAttribute("autocapitalize", "off"), this.textarea.setAttribute("spellcheck", "false"), this.textarea.tabIndex = 0, this._coreBrowserService = this.register(this._instantiationService.createInstance(v2.CoreBrowserService, this.textarea, e4.ownerDocument.defaultView ?? window, this._document ?? "undefined" != typeof window ? window.document : null)), this._instantiationService.setService(S2.ICoreBrowserService, this._coreBrowserService), this.register((0, r2.addDisposableDomListener)(this.textarea, "focus", (e5) => this._handleTextAreaFocus(e5))), this.register((0, r2.addDisposableDomListener)(this.textarea, "blur", () => this._handleTextAreaBlur())), this._helperContainer.appendChild(this.textarea), this._charSizeService = this._instantiationService.createInstance(u2.CharSizeService, this._document, this._helperContainer), this._instantiationService.setService(S2.ICharSizeService, this._charSizeService), this._themeService = this._instantiationService.createInstance(C2.ThemeService), this._instantiationService.setService(S2.IThemeService, this._themeService), this._characterJoinerService = this._instantiationService.createInstance(f2.CharacterJoinerService), this._instantiationService.setService(S2.ICharacterJoinerService, this._characterJoinerService), this._renderService = this.register(this._instantiationService.createInstance(g2.RenderService, this.rows, this.screenElement)), this._instantiationService.setService(S2.IRenderService, this._renderService), this.register(this._renderService.onRenderedViewportChange((e5) => this._onRender.fire(e5))), this.onResize((e5) => this._renderService.resize(e5.cols, e5.rows)), this._compositionView = this._document.createElement("div"), this._compositionView.classList.add("composition-view"), this._compositionHelper = this._instantiationService.createInstance(d2.CompositionHelper, this.textarea, this._compositionView), this._helperContainer.appendChild(this._compositionView), this._mouseService = this._instantiationService.createInstance(p2.MouseService), this._instantiationService.setService(S2.IMouseService, this._mouseService), this.linkifier = this.register(this._instantiationService.createInstance(n2.Linkifier, this.screenElement)), this.element.appendChild(t4);
          try {
            this._onWillOpen.fire(this.element);
          } catch {
          }
          this._renderService.hasRenderer() || this._renderService.setRenderer(this._createRenderer()), this.viewport = this._instantiationService.createInstance(h2.Viewport, this._viewportElement, this._viewportScrollArea), this.viewport.onRequestScrollLines((e5) => this.scrollLines(e5.amount, e5.suppressScrollEvent, 1)), this.register(this._inputHandler.onRequestSyncScrollBar(() => this.viewport.syncScrollArea())), this.register(this.viewport), this.register(this.onCursorMove(() => {
            this._renderService.handleCursorMove(), this._syncTextArea();
          })), this.register(this.onResize(() => this._renderService.handleResize(this.cols, this.rows))), this.register(this.onBlur(() => this._renderService.handleBlur())), this.register(this.onFocus(() => this._renderService.handleFocus())), this.register(this._renderService.onDimensionsChange(() => this.viewport.syncScrollArea())), this._selectionService = this.register(this._instantiationService.createInstance(m2.SelectionService, this.element, this.screenElement, this.linkifier)), this._instantiationService.setService(S2.ISelectionService, this._selectionService), this.register(this._selectionService.onRequestScrollLines((e5) => this.scrollLines(e5.amount, e5.suppressScrollEvent))), this.register(this._selectionService.onSelectionChange(() => this._onSelectionChange.fire())), this.register(this._selectionService.onRequestRedraw((e5) => this._renderService.handleSelectionChanged(e5.start, e5.end, e5.columnSelectMode))), this.register(this._selectionService.onLinuxMouseSelection((e5) => {
            this.textarea.value = e5, this.textarea.focus(), this.textarea.select();
          })), this.register(this._onScroll.event((e5) => {
            this.viewport.syncScrollArea(), this._selectionService.refresh();
          })), this.register((0, r2.addDisposableDomListener)(this._viewportElement, "scroll", () => this._selectionService.refresh())), this.register(this._instantiationService.createInstance(c2.BufferDecorationRenderer, this.screenElement)), this.register((0, r2.addDisposableDomListener)(this.element, "mousedown", (e5) => this._selectionService.handleMouseDown(e5))), this.coreMouseService.areMouseEventsActive ? (this._selectionService.disable(), this.element.classList.add("enable-mouse-events")) : this._selectionService.enable(), this.options.screenReaderMode && (this._accessibilityManager.value = this._instantiationService.createInstance(M2.AccessibilityManager, this)), this.register(this.optionsService.onSpecificOptionChange("screenReaderMode", (e5) => this._handleScreenReaderModeOptionChange(e5))), this.options.overviewRulerWidth && (this._overviewRulerRenderer = this.register(this._instantiationService.createInstance(l2.OverviewRulerRenderer, this._viewportElement, this.screenElement))), this.optionsService.onSpecificOptionChange("overviewRulerWidth", (e5) => {
            !this._overviewRulerRenderer && e5 && this._viewportElement && this.screenElement && (this._overviewRulerRenderer = this.register(this._instantiationService.createInstance(l2.OverviewRulerRenderer, this._viewportElement, this.screenElement)));
          }), this._charSizeService.measure(), this.refresh(0, this.rows - 1), this._initGlobal(), this.bindMouse();
        }
        _createRenderer() {
          return this._instantiationService.createInstance(_2.DomRenderer, this, this._document, this.element, this.screenElement, this._viewportElement, this._helperContainer, this.linkifier);
        }
        bindMouse() {
          const e4 = this, t4 = this.element;
          function i4(t5) {
            const i5 = e4._mouseService.getMouseReportCoords(t5, e4.screenElement);
            if (!i5) return false;
            let s5, r3;
            switch (t5.overrideType || t5.type) {
              case "mousemove":
                r3 = 32, void 0 === t5.buttons ? (s5 = 3, void 0 !== t5.button && (s5 = t5.button < 3 ? t5.button : 3)) : s5 = 1 & t5.buttons ? 0 : 4 & t5.buttons ? 1 : 2 & t5.buttons ? 2 : 3;
                break;
              case "mouseup":
                r3 = 0, s5 = t5.button < 3 ? t5.button : 3;
                break;
              case "mousedown":
                r3 = 1, s5 = t5.button < 3 ? t5.button : 3;
                break;
              case "wheel":
                if (e4._customWheelEventHandler && false === e4._customWheelEventHandler(t5)) return false;
                if (0 === e4.viewport.getLinesScrolled(t5)) return false;
                r3 = t5.deltaY < 0 ? 0 : 1, s5 = 4;
                break;
              default:
                return false;
            }
            return !(void 0 === r3 || void 0 === s5 || s5 > 4) && e4.coreMouseService.triggerMouseEvent({ col: i5.col, row: i5.row, x: i5.x, y: i5.y, button: s5, action: r3, ctrl: t5.ctrlKey, alt: t5.altKey, shift: t5.shiftKey });
          }
          __name(i4, "i");
          const s4 = { mouseup: null, wheel: null, mousedrag: null, mousemove: null }, n3 = { mouseup: /* @__PURE__ */ __name((e5) => (i4(e5), e5.buttons || (this._document.removeEventListener("mouseup", s4.mouseup), s4.mousedrag && this._document.removeEventListener("mousemove", s4.mousedrag)), this.cancel(e5)), "mouseup"), wheel: /* @__PURE__ */ __name((e5) => (i4(e5), this.cancel(e5, true)), "wheel"), mousedrag: /* @__PURE__ */ __name((e5) => {
            e5.buttons && i4(e5);
          }, "mousedrag"), mousemove: /* @__PURE__ */ __name((e5) => {
            e5.buttons || i4(e5);
          }, "mousemove") };
          this.register(this.coreMouseService.onProtocolChange((e5) => {
            e5 ? ("debug" === this.optionsService.rawOptions.logLevel && this._logService.debug("Binding to mouse events:", this.coreMouseService.explainEvents(e5)), this.element.classList.add("enable-mouse-events"), this._selectionService.disable()) : (this._logService.debug("Unbinding from mouse events."), this.element.classList.remove("enable-mouse-events"), this._selectionService.enable()), 8 & e5 ? s4.mousemove || (t4.addEventListener("mousemove", n3.mousemove), s4.mousemove = n3.mousemove) : (t4.removeEventListener("mousemove", s4.mousemove), s4.mousemove = null), 16 & e5 ? s4.wheel || (t4.addEventListener("wheel", n3.wheel, { passive: false }), s4.wheel = n3.wheel) : (t4.removeEventListener("wheel", s4.wheel), s4.wheel = null), 2 & e5 ? s4.mouseup || (s4.mouseup = n3.mouseup) : (this._document.removeEventListener("mouseup", s4.mouseup), s4.mouseup = null), 4 & e5 ? s4.mousedrag || (s4.mousedrag = n3.mousedrag) : (this._document.removeEventListener("mousemove", s4.mousedrag), s4.mousedrag = null);
          })), this.coreMouseService.activeProtocol = this.coreMouseService.activeProtocol, this.register((0, r2.addDisposableDomListener)(t4, "mousedown", (e5) => {
            if (e5.preventDefault(), this.focus(), this.coreMouseService.areMouseEventsActive && !this._selectionService.shouldForceSelection(e5)) return i4(e5), s4.mouseup && this._document.addEventListener("mouseup", s4.mouseup), s4.mousedrag && this._document.addEventListener("mousemove", s4.mousedrag), this.cancel(e5);
          })), this.register((0, r2.addDisposableDomListener)(t4, "wheel", (e5) => {
            if (!s4.wheel) {
              if (this._customWheelEventHandler && false === this._customWheelEventHandler(e5)) return false;
              if (!this.buffer.hasScrollback) {
                const t5 = this.viewport.getLinesScrolled(e5);
                if (0 === t5) return;
                const i5 = D2.C0.ESC + (this.coreService.decPrivateModes.applicationCursorKeys ? "O" : "[") + (e5.deltaY < 0 ? "A" : "B");
                let s5 = "";
                for (let e6 = 0; e6 < Math.abs(t5); e6++) s5 += i5;
                return this.coreService.triggerDataEvent(s5, true), this.cancel(e5, true);
              }
              return this.viewport.handleWheel(e5) ? this.cancel(e5) : void 0;
            }
          }, { passive: false })), this.register((0, r2.addDisposableDomListener)(t4, "touchstart", (e5) => {
            if (!this.coreMouseService.areMouseEventsActive) return this.viewport.handleTouchStart(e5), this.cancel(e5);
          }, { passive: true })), this.register((0, r2.addDisposableDomListener)(t4, "touchmove", (e5) => {
            if (!this.coreMouseService.areMouseEventsActive) return this.viewport.handleTouchMove(e5) ? void 0 : this.cancel(e5);
          }, { passive: false }));
        }
        refresh(e4, t4) {
          this._renderService?.refreshRows(e4, t4);
        }
        updateCursorStyle(e4) {
          this._selectionService?.shouldColumnSelect(e4) ? this.element.classList.add("column-select") : this.element.classList.remove("column-select");
        }
        _showCursor() {
          this.coreService.isCursorInitialized || (this.coreService.isCursorInitialized = true, this.refresh(this.buffer.y, this.buffer.y));
        }
        scrollLines(e4, t4, i4 = 0) {
          1 === i4 ? (super.scrollLines(e4, t4, i4), this.refresh(0, this.rows - 1)) : this.viewport?.scrollLines(e4);
        }
        paste(e4) {
          (0, s3.paste)(e4, this.textarea, this.coreService, this.optionsService);
        }
        attachCustomKeyEventHandler(e4) {
          this._customKeyEventHandler = e4;
        }
        attachCustomWheelEventHandler(e4) {
          this._customWheelEventHandler = e4;
        }
        registerLinkProvider(e4) {
          return this._linkProviderService.registerLinkProvider(e4);
        }
        registerCharacterJoiner(e4) {
          if (!this._characterJoinerService) throw new Error("Terminal must be opened first");
          const t4 = this._characterJoinerService.register(e4);
          return this.refresh(0, this.rows - 1), t4;
        }
        deregisterCharacterJoiner(e4) {
          if (!this._characterJoinerService) throw new Error("Terminal must be opened first");
          this._characterJoinerService.deregister(e4) && this.refresh(0, this.rows - 1);
        }
        get markers() {
          return this.buffer.markers;
        }
        registerMarker(e4) {
          return this.buffer.addMarker(this.buffer.ybase + this.buffer.y + e4);
        }
        registerDecoration(e4) {
          return this._decorationService.registerDecoration(e4);
        }
        hasSelection() {
          return !!this._selectionService && this._selectionService.hasSelection;
        }
        select(e4, t4, i4) {
          this._selectionService.setSelection(e4, t4, i4);
        }
        getSelection() {
          return this._selectionService ? this._selectionService.selectionText : "";
        }
        getSelectionPosition() {
          if (this._selectionService && this._selectionService.hasSelection) return { start: { x: this._selectionService.selectionStart[0], y: this._selectionService.selectionStart[1] }, end: { x: this._selectionService.selectionEnd[0], y: this._selectionService.selectionEnd[1] } };
        }
        clearSelection() {
          this._selectionService?.clearSelection();
        }
        selectAll() {
          this._selectionService?.selectAll();
        }
        selectLines(e4, t4) {
          this._selectionService?.selectLines(e4, t4);
        }
        _keyDown(e4) {
          if (this._keyDownHandled = false, this._keyDownSeen = true, this._customKeyEventHandler && false === this._customKeyEventHandler(e4)) return false;
          const t4 = this.browser.isMac && this.options.macOptionIsMeta && e4.altKey;
          if (!t4 && !this._compositionHelper.keydown(e4)) return this.options.scrollOnUserInput && this.buffer.ybase !== this.buffer.ydisp && this.scrollToBottom(), false;
          t4 || "Dead" !== e4.key && "AltGraph" !== e4.key || (this._unprocessedDeadKey = true);
          const i4 = (0, R.evaluateKeyboardEvent)(e4, this.coreService.decPrivateModes.applicationCursorKeys, this.browser.isMac, this.options.macOptionIsMeta);
          if (this.updateCursorStyle(e4), 3 === i4.type || 2 === i4.type) {
            const t5 = this.rows - 1;
            return this.scrollLines(2 === i4.type ? -t5 : t5), this.cancel(e4, true);
          }
          return 1 === i4.type && this.selectAll(), !!this._isThirdLevelShift(this.browser, e4) || (i4.cancel && this.cancel(e4, true), !i4.key || !!(e4.key && !e4.ctrlKey && !e4.altKey && !e4.metaKey && 1 === e4.key.length && e4.key.charCodeAt(0) >= 65 && e4.key.charCodeAt(0) <= 90) || (this._unprocessedDeadKey ? (this._unprocessedDeadKey = false, true) : (i4.key !== D2.C0.ETX && i4.key !== D2.C0.CR || (this.textarea.value = ""), this._onKey.fire({ key: i4.key, domEvent: e4 }), this._showCursor(), this.coreService.triggerDataEvent(i4.key, true), !this.optionsService.rawOptions.screenReaderMode || e4.altKey || e4.ctrlKey ? this.cancel(e4, true) : void (this._keyDownHandled = true))));
        }
        _isThirdLevelShift(e4, t4) {
          const i4 = e4.isMac && !this.options.macOptionIsMeta && t4.altKey && !t4.ctrlKey && !t4.metaKey || e4.isWindows && t4.altKey && t4.ctrlKey && !t4.metaKey || e4.isWindows && t4.getModifierState("AltGraph");
          return "keypress" === t4.type ? i4 : i4 && (!t4.keyCode || t4.keyCode > 47);
        }
        _keyUp(e4) {
          this._keyDownSeen = false, this._customKeyEventHandler && false === this._customKeyEventHandler(e4) || (function(e5) {
            return 16 === e5.keyCode || 17 === e5.keyCode || 18 === e5.keyCode;
          }(e4) || this.focus(), this.updateCursorStyle(e4), this._keyPressHandled = false);
        }
        _keyPress(e4) {
          let t4;
          if (this._keyPressHandled = false, this._keyDownHandled) return false;
          if (this._customKeyEventHandler && false === this._customKeyEventHandler(e4)) return false;
          if (this.cancel(e4), e4.charCode) t4 = e4.charCode;
          else if (null === e4.which || void 0 === e4.which) t4 = e4.keyCode;
          else {
            if (0 === e4.which || 0 === e4.charCode) return false;
            t4 = e4.which;
          }
          return !(!t4 || (e4.altKey || e4.ctrlKey || e4.metaKey) && !this._isThirdLevelShift(this.browser, e4) || (t4 = String.fromCharCode(t4), this._onKey.fire({ key: t4, domEvent: e4 }), this._showCursor(), this.coreService.triggerDataEvent(t4, true), this._keyPressHandled = true, this._unprocessedDeadKey = false, 0));
        }
        _inputEvent(e4) {
          if (e4.data && "insertText" === e4.inputType && (!e4.composed || !this._keyDownSeen) && !this.optionsService.rawOptions.screenReaderMode) {
            if (this._keyPressHandled) return false;
            this._unprocessedDeadKey = false;
            const t4 = e4.data;
            return this.coreService.triggerDataEvent(t4, true), this.cancel(e4), true;
          }
          return false;
        }
        resize(e4, t4) {
          e4 !== this.cols || t4 !== this.rows ? super.resize(e4, t4) : this._charSizeService && !this._charSizeService.hasValidSize && this._charSizeService.measure();
        }
        _afterResize(e4, t4) {
          this._charSizeService?.measure(), this.viewport?.syncScrollArea(true);
        }
        clear() {
          if (0 !== this.buffer.ybase || 0 !== this.buffer.y) {
            this.buffer.clearAllMarkers(), this.buffer.lines.set(0, this.buffer.lines.get(this.buffer.ybase + this.buffer.y)), this.buffer.lines.length = 1, this.buffer.ydisp = 0, this.buffer.ybase = 0, this.buffer.y = 0;
            for (let e4 = 1; e4 < this.rows; e4++) this.buffer.lines.push(this.buffer.getBlankLine(L2.DEFAULT_ATTR_DATA));
            this._onScroll.fire({ position: this.buffer.ydisp, source: 0 }), this.viewport?.reset(), this.refresh(0, this.rows - 1);
          }
        }
        reset() {
          this.options.rows = this.rows, this.options.cols = this.cols;
          const e4 = this._customKeyEventHandler;
          this._setup(), super.reset(), this._selectionService?.reset(), this._decorationService.reset(), this.viewport?.reset(), this._customKeyEventHandler = e4, this.refresh(0, this.rows - 1);
        }
        clearTextureAtlas() {
          this._renderService?.clearTextureAtlas();
        }
        _reportFocus() {
          this.element?.classList.contains("focus") ? this.coreService.triggerDataEvent(D2.C0.ESC + "[I") : this.coreService.triggerDataEvent(D2.C0.ESC + "[O");
        }
        _reportWindowsOptions(e4) {
          if (this._renderService) switch (e4) {
            case T2.WindowsOptionsReportType.GET_WIN_SIZE_PIXELS:
              const e5 = this._renderService.dimensions.css.canvas.width.toFixed(0), t4 = this._renderService.dimensions.css.canvas.height.toFixed(0);
              this.coreService.triggerDataEvent(`${D2.C0.ESC}[4;${t4};${e5}t`);
              break;
            case T2.WindowsOptionsReportType.GET_CELL_SIZE_PIXELS:
              const i4 = this._renderService.dimensions.css.cell.width.toFixed(0), s4 = this._renderService.dimensions.css.cell.height.toFixed(0);
              this.coreService.triggerDataEvent(`${D2.C0.ESC}[6;${s4};${i4}t`);
          }
        }
        cancel(e4, t4) {
          if (this.options.cancelEvents || t4) return e4.preventDefault(), e4.stopPropagation(), false;
        }
      }
      t3.Terminal = P2;
    }, 9924: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.TimeBasedDebouncer = void 0, t3.TimeBasedDebouncer = class {
        constructor(e4, t4 = 1e3) {
          this._renderCallback = e4, this._debounceThresholdMS = t4, this._lastRefreshMs = 0, this._additionalRefreshRequested = false;
        }
        dispose() {
          this._refreshTimeoutID && clearTimeout(this._refreshTimeoutID);
        }
        refresh(e4, t4, i3) {
          this._rowCount = i3, e4 = void 0 !== e4 ? e4 : 0, t4 = void 0 !== t4 ? t4 : this._rowCount - 1, this._rowStart = void 0 !== this._rowStart ? Math.min(this._rowStart, e4) : e4, this._rowEnd = void 0 !== this._rowEnd ? Math.max(this._rowEnd, t4) : t4;
          const s3 = Date.now();
          if (s3 - this._lastRefreshMs >= this._debounceThresholdMS) this._lastRefreshMs = s3, this._innerRefresh();
          else if (!this._additionalRefreshRequested) {
            const e5 = s3 - this._lastRefreshMs, t5 = this._debounceThresholdMS - e5;
            this._additionalRefreshRequested = true, this._refreshTimeoutID = window.setTimeout(() => {
              this._lastRefreshMs = Date.now(), this._innerRefresh(), this._additionalRefreshRequested = false, this._refreshTimeoutID = void 0;
            }, t5);
          }
        }
        _innerRefresh() {
          if (void 0 === this._rowStart || void 0 === this._rowEnd || void 0 === this._rowCount) return;
          const e4 = Math.max(this._rowStart, 0), t4 = Math.min(this._rowEnd, this._rowCount - 1);
          this._rowStart = void 0, this._rowEnd = void 0, this._renderCallback(e4, t4);
        }
      };
    }, 1680: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Viewport = void 0;
      const n2 = i3(3656), o2 = i3(4725), a2 = i3(8460), h2 = i3(844), c2 = i3(2585);
      let l2 = t3.Viewport = class extends h2.Disposable {
        constructor(e4, t4, i4, s4, r3, o3, h3, c3) {
          super(), this._viewportElement = e4, this._scrollArea = t4, this._bufferService = i4, this._optionsService = s4, this._charSizeService = r3, this._renderService = o3, this._coreBrowserService = h3, this.scrollBarWidth = 0, this._currentRowHeight = 0, this._currentDeviceCellHeight = 0, this._lastRecordedBufferLength = 0, this._lastRecordedViewportHeight = 0, this._lastRecordedBufferHeight = 0, this._lastTouchY = 0, this._lastScrollTop = 0, this._wheelPartialScroll = 0, this._refreshAnimationFrame = null, this._ignoreNextScrollEvent = false, this._smoothScrollState = { startTime: 0, origin: -1, target: -1 }, this._onRequestScrollLines = this.register(new a2.EventEmitter()), this.onRequestScrollLines = this._onRequestScrollLines.event, this.scrollBarWidth = this._viewportElement.offsetWidth - this._scrollArea.offsetWidth || 15, this.register((0, n2.addDisposableDomListener)(this._viewportElement, "scroll", this._handleScroll.bind(this))), this._activeBuffer = this._bufferService.buffer, this.register(this._bufferService.buffers.onBufferActivate((e5) => this._activeBuffer = e5.activeBuffer)), this._renderDimensions = this._renderService.dimensions, this.register(this._renderService.onDimensionsChange((e5) => this._renderDimensions = e5)), this._handleThemeChange(c3.colors), this.register(c3.onChangeColors((e5) => this._handleThemeChange(e5))), this.register(this._optionsService.onSpecificOptionChange("scrollback", () => this.syncScrollArea())), setTimeout(() => this.syncScrollArea());
        }
        _handleThemeChange(e4) {
          this._viewportElement.style.backgroundColor = e4.background.css;
        }
        reset() {
          this._currentRowHeight = 0, this._currentDeviceCellHeight = 0, this._lastRecordedBufferLength = 0, this._lastRecordedViewportHeight = 0, this._lastRecordedBufferHeight = 0, this._lastTouchY = 0, this._lastScrollTop = 0, this._coreBrowserService.window.requestAnimationFrame(() => this.syncScrollArea());
        }
        _refresh(e4) {
          if (e4) return this._innerRefresh(), void (null !== this._refreshAnimationFrame && this._coreBrowserService.window.cancelAnimationFrame(this._refreshAnimationFrame));
          null === this._refreshAnimationFrame && (this._refreshAnimationFrame = this._coreBrowserService.window.requestAnimationFrame(() => this._innerRefresh()));
        }
        _innerRefresh() {
          if (this._charSizeService.height > 0) {
            this._currentRowHeight = this._renderDimensions.device.cell.height / this._coreBrowserService.dpr, this._currentDeviceCellHeight = this._renderDimensions.device.cell.height, this._lastRecordedViewportHeight = this._viewportElement.offsetHeight;
            const e5 = Math.round(this._currentRowHeight * this._lastRecordedBufferLength) + (this._lastRecordedViewportHeight - this._renderDimensions.css.canvas.height);
            this._lastRecordedBufferHeight !== e5 && (this._lastRecordedBufferHeight = e5, this._scrollArea.style.height = this._lastRecordedBufferHeight + "px");
          }
          const e4 = this._bufferService.buffer.ydisp * this._currentRowHeight;
          this._viewportElement.scrollTop !== e4 && (this._ignoreNextScrollEvent = true, this._viewportElement.scrollTop = e4), this._refreshAnimationFrame = null;
        }
        syncScrollArea(e4 = false) {
          if (this._lastRecordedBufferLength !== this._bufferService.buffer.lines.length) return this._lastRecordedBufferLength = this._bufferService.buffer.lines.length, void this._refresh(e4);
          this._lastRecordedViewportHeight === this._renderService.dimensions.css.canvas.height && this._lastScrollTop === this._activeBuffer.ydisp * this._currentRowHeight && this._renderDimensions.device.cell.height === this._currentDeviceCellHeight || this._refresh(e4);
        }
        _handleScroll(e4) {
          if (this._lastScrollTop = this._viewportElement.scrollTop, !this._viewportElement.offsetParent) return;
          if (this._ignoreNextScrollEvent) return this._ignoreNextScrollEvent = false, void this._onRequestScrollLines.fire({ amount: 0, suppressScrollEvent: true });
          const t4 = Math.round(this._lastScrollTop / this._currentRowHeight) - this._bufferService.buffer.ydisp;
          this._onRequestScrollLines.fire({ amount: t4, suppressScrollEvent: true });
        }
        _smoothScroll() {
          if (this._isDisposed || -1 === this._smoothScrollState.origin || -1 === this._smoothScrollState.target) return;
          const e4 = this._smoothScrollPercent();
          this._viewportElement.scrollTop = this._smoothScrollState.origin + Math.round(e4 * (this._smoothScrollState.target - this._smoothScrollState.origin)), e4 < 1 ? this._coreBrowserService.window.requestAnimationFrame(() => this._smoothScroll()) : this._clearSmoothScrollState();
        }
        _smoothScrollPercent() {
          return this._optionsService.rawOptions.smoothScrollDuration && this._smoothScrollState.startTime ? Math.max(Math.min((Date.now() - this._smoothScrollState.startTime) / this._optionsService.rawOptions.smoothScrollDuration, 1), 0) : 1;
        }
        _clearSmoothScrollState() {
          this._smoothScrollState.startTime = 0, this._smoothScrollState.origin = -1, this._smoothScrollState.target = -1;
        }
        _bubbleScroll(e4, t4) {
          const i4 = this._viewportElement.scrollTop + this._lastRecordedViewportHeight;
          return !(t4 < 0 && 0 !== this._viewportElement.scrollTop || t4 > 0 && i4 < this._lastRecordedBufferHeight) || (e4.cancelable && e4.preventDefault(), false);
        }
        handleWheel(e4) {
          const t4 = this._getPixelsScrolled(e4);
          return 0 !== t4 && (this._optionsService.rawOptions.smoothScrollDuration ? (this._smoothScrollState.startTime = Date.now(), this._smoothScrollPercent() < 1 ? (this._smoothScrollState.origin = this._viewportElement.scrollTop, -1 === this._smoothScrollState.target ? this._smoothScrollState.target = this._viewportElement.scrollTop + t4 : this._smoothScrollState.target += t4, this._smoothScrollState.target = Math.max(Math.min(this._smoothScrollState.target, this._viewportElement.scrollHeight), 0), this._smoothScroll()) : this._clearSmoothScrollState()) : this._viewportElement.scrollTop += t4, this._bubbleScroll(e4, t4));
        }
        scrollLines(e4) {
          if (0 !== e4) if (this._optionsService.rawOptions.smoothScrollDuration) {
            const t4 = e4 * this._currentRowHeight;
            this._smoothScrollState.startTime = Date.now(), this._smoothScrollPercent() < 1 ? (this._smoothScrollState.origin = this._viewportElement.scrollTop, this._smoothScrollState.target = this._smoothScrollState.origin + t4, this._smoothScrollState.target = Math.max(Math.min(this._smoothScrollState.target, this._viewportElement.scrollHeight), 0), this._smoothScroll()) : this._clearSmoothScrollState();
          } else this._onRequestScrollLines.fire({ amount: e4, suppressScrollEvent: false });
        }
        _getPixelsScrolled(e4) {
          if (0 === e4.deltaY || e4.shiftKey) return 0;
          let t4 = this._applyScrollModifier(e4.deltaY, e4);
          return e4.deltaMode === WheelEvent.DOM_DELTA_LINE ? t4 *= this._currentRowHeight : e4.deltaMode === WheelEvent.DOM_DELTA_PAGE && (t4 *= this._currentRowHeight * this._bufferService.rows), t4;
        }
        getBufferElements(e4, t4) {
          let i4, s4 = "";
          const r3 = [], n3 = t4 ?? this._bufferService.buffer.lines.length, o3 = this._bufferService.buffer.lines;
          for (let t5 = e4; t5 < n3; t5++) {
            const e5 = o3.get(t5);
            if (!e5) continue;
            const n4 = o3.get(t5 + 1)?.isWrapped;
            if (s4 += e5.translateToString(!n4), !n4 || t5 === o3.length - 1) {
              const e6 = document.createElement("div");
              e6.textContent = s4, r3.push(e6), s4.length > 0 && (i4 = e6), s4 = "";
            }
          }
          return { bufferElements: r3, cursorElement: i4 };
        }
        getLinesScrolled(e4) {
          if (0 === e4.deltaY || e4.shiftKey) return 0;
          let t4 = this._applyScrollModifier(e4.deltaY, e4);
          return e4.deltaMode === WheelEvent.DOM_DELTA_PIXEL ? (t4 /= this._currentRowHeight + 0, this._wheelPartialScroll += t4, t4 = Math.floor(Math.abs(this._wheelPartialScroll)) * (this._wheelPartialScroll > 0 ? 1 : -1), this._wheelPartialScroll %= 1) : e4.deltaMode === WheelEvent.DOM_DELTA_PAGE && (t4 *= this._bufferService.rows), t4;
        }
        _applyScrollModifier(e4, t4) {
          const i4 = this._optionsService.rawOptions.fastScrollModifier;
          return "alt" === i4 && t4.altKey || "ctrl" === i4 && t4.ctrlKey || "shift" === i4 && t4.shiftKey ? e4 * this._optionsService.rawOptions.fastScrollSensitivity * this._optionsService.rawOptions.scrollSensitivity : e4 * this._optionsService.rawOptions.scrollSensitivity;
        }
        handleTouchStart(e4) {
          this._lastTouchY = e4.touches[0].pageY;
        }
        handleTouchMove(e4) {
          const t4 = this._lastTouchY - e4.touches[0].pageY;
          return this._lastTouchY = e4.touches[0].pageY, 0 !== t4 && (this._viewportElement.scrollTop += t4, this._bubbleScroll(e4, t4));
        }
      };
      t3.Viewport = l2 = s3([r2(2, c2.IBufferService), r2(3, c2.IOptionsService), r2(4, o2.ICharSizeService), r2(5, o2.IRenderService), r2(6, o2.ICoreBrowserService), r2(7, o2.IThemeService)], l2);
    }, 3107: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferDecorationRenderer = void 0;
      const n2 = i3(4725), o2 = i3(844), a2 = i3(2585);
      let h2 = t3.BufferDecorationRenderer = class extends o2.Disposable {
        constructor(e4, t4, i4, s4, r3) {
          super(), this._screenElement = e4, this._bufferService = t4, this._coreBrowserService = i4, this._decorationService = s4, this._renderService = r3, this._decorationElements = /* @__PURE__ */ new Map(), this._altBufferIsActive = false, this._dimensionsChanged = false, this._container = document.createElement("div"), this._container.classList.add("xterm-decoration-container"), this._screenElement.appendChild(this._container), this.register(this._renderService.onRenderedViewportChange(() => this._doRefreshDecorations())), this.register(this._renderService.onDimensionsChange(() => {
            this._dimensionsChanged = true, this._queueRefresh();
          })), this.register(this._coreBrowserService.onDprChange(() => this._queueRefresh())), this.register(this._bufferService.buffers.onBufferActivate(() => {
            this._altBufferIsActive = this._bufferService.buffer === this._bufferService.buffers.alt;
          })), this.register(this._decorationService.onDecorationRegistered(() => this._queueRefresh())), this.register(this._decorationService.onDecorationRemoved((e5) => this._removeDecoration(e5))), this.register((0, o2.toDisposable)(() => {
            this._container.remove(), this._decorationElements.clear();
          }));
        }
        _queueRefresh() {
          void 0 === this._animationFrame && (this._animationFrame = this._renderService.addRefreshCallback(() => {
            this._doRefreshDecorations(), this._animationFrame = void 0;
          }));
        }
        _doRefreshDecorations() {
          for (const e4 of this._decorationService.decorations) this._renderDecoration(e4);
          this._dimensionsChanged = false;
        }
        _renderDecoration(e4) {
          this._refreshStyle(e4), this._dimensionsChanged && this._refreshXPosition(e4);
        }
        _createElement(e4) {
          const t4 = this._coreBrowserService.mainDocument.createElement("div");
          t4.classList.add("xterm-decoration"), t4.classList.toggle("xterm-decoration-top-layer", "top" === e4?.options?.layer), t4.style.width = `${Math.round((e4.options.width || 1) * this._renderService.dimensions.css.cell.width)}px`, t4.style.height = (e4.options.height || 1) * this._renderService.dimensions.css.cell.height + "px", t4.style.top = (e4.marker.line - this._bufferService.buffers.active.ydisp) * this._renderService.dimensions.css.cell.height + "px", t4.style.lineHeight = `${this._renderService.dimensions.css.cell.height}px`;
          const i4 = e4.options.x ?? 0;
          return i4 && i4 > this._bufferService.cols && (t4.style.display = "none"), this._refreshXPosition(e4, t4), t4;
        }
        _refreshStyle(e4) {
          const t4 = e4.marker.line - this._bufferService.buffers.active.ydisp;
          if (t4 < 0 || t4 >= this._bufferService.rows) e4.element && (e4.element.style.display = "none", e4.onRenderEmitter.fire(e4.element));
          else {
            let i4 = this._decorationElements.get(e4);
            i4 || (i4 = this._createElement(e4), e4.element = i4, this._decorationElements.set(e4, i4), this._container.appendChild(i4), e4.onDispose(() => {
              this._decorationElements.delete(e4), i4.remove();
            })), i4.style.top = t4 * this._renderService.dimensions.css.cell.height + "px", i4.style.display = this._altBufferIsActive ? "none" : "block", e4.onRenderEmitter.fire(i4);
          }
        }
        _refreshXPosition(e4, t4 = e4.element) {
          if (!t4) return;
          const i4 = e4.options.x ?? 0;
          "right" === (e4.options.anchor || "left") ? t4.style.right = i4 ? i4 * this._renderService.dimensions.css.cell.width + "px" : "" : t4.style.left = i4 ? i4 * this._renderService.dimensions.css.cell.width + "px" : "";
        }
        _removeDecoration(e4) {
          this._decorationElements.get(e4)?.remove(), this._decorationElements.delete(e4), e4.dispose();
        }
      };
      t3.BufferDecorationRenderer = h2 = s3([r2(1, a2.IBufferService), r2(2, n2.ICoreBrowserService), r2(3, a2.IDecorationService), r2(4, n2.IRenderService)], h2);
    }, 5871: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ColorZoneStore = void 0, t3.ColorZoneStore = class {
        constructor() {
          this._zones = [], this._zonePool = [], this._zonePoolIndex = 0, this._linePadding = { full: 0, left: 0, center: 0, right: 0 };
        }
        get zones() {
          return this._zonePool.length = Math.min(this._zonePool.length, this._zones.length), this._zones;
        }
        clear() {
          this._zones.length = 0, this._zonePoolIndex = 0;
        }
        addDecoration(e4) {
          if (e4.options.overviewRulerOptions) {
            for (const t4 of this._zones) if (t4.color === e4.options.overviewRulerOptions.color && t4.position === e4.options.overviewRulerOptions.position) {
              if (this._lineIntersectsZone(t4, e4.marker.line)) return;
              if (this._lineAdjacentToZone(t4, e4.marker.line, e4.options.overviewRulerOptions.position)) return void this._addLineToZone(t4, e4.marker.line);
            }
            if (this._zonePoolIndex < this._zonePool.length) return this._zonePool[this._zonePoolIndex].color = e4.options.overviewRulerOptions.color, this._zonePool[this._zonePoolIndex].position = e4.options.overviewRulerOptions.position, this._zonePool[this._zonePoolIndex].startBufferLine = e4.marker.line, this._zonePool[this._zonePoolIndex].endBufferLine = e4.marker.line, void this._zones.push(this._zonePool[this._zonePoolIndex++]);
            this._zones.push({ color: e4.options.overviewRulerOptions.color, position: e4.options.overviewRulerOptions.position, startBufferLine: e4.marker.line, endBufferLine: e4.marker.line }), this._zonePool.push(this._zones[this._zones.length - 1]), this._zonePoolIndex++;
          }
        }
        setPadding(e4) {
          this._linePadding = e4;
        }
        _lineIntersectsZone(e4, t4) {
          return t4 >= e4.startBufferLine && t4 <= e4.endBufferLine;
        }
        _lineAdjacentToZone(e4, t4, i3) {
          return t4 >= e4.startBufferLine - this._linePadding[i3 || "full"] && t4 <= e4.endBufferLine + this._linePadding[i3 || "full"];
        }
        _addLineToZone(e4, t4) {
          e4.startBufferLine = Math.min(e4.startBufferLine, t4), e4.endBufferLine = Math.max(e4.endBufferLine, t4);
        }
      };
    }, 5744: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.OverviewRulerRenderer = void 0;
      const n2 = i3(5871), o2 = i3(4725), a2 = i3(844), h2 = i3(2585), c2 = { full: 0, left: 0, center: 0, right: 0 }, l2 = { full: 0, left: 0, center: 0, right: 0 }, d2 = { full: 0, left: 0, center: 0, right: 0 };
      let _2 = t3.OverviewRulerRenderer = class extends a2.Disposable {
        get _width() {
          return this._optionsService.options.overviewRulerWidth || 0;
        }
        constructor(e4, t4, i4, s4, r3, o3, h3) {
          super(), this._viewportElement = e4, this._screenElement = t4, this._bufferService = i4, this._decorationService = s4, this._renderService = r3, this._optionsService = o3, this._coreBrowserService = h3, this._colorZoneStore = new n2.ColorZoneStore(), this._shouldUpdateDimensions = true, this._shouldUpdateAnchor = true, this._lastKnownBufferLength = 0, this._canvas = this._coreBrowserService.mainDocument.createElement("canvas"), this._canvas.classList.add("xterm-decoration-overview-ruler"), this._refreshCanvasDimensions(), this._viewportElement.parentElement?.insertBefore(this._canvas, this._viewportElement);
          const c3 = this._canvas.getContext("2d");
          if (!c3) throw new Error("Ctx cannot be null");
          this._ctx = c3, this._registerDecorationListeners(), this._registerBufferChangeListeners(), this._registerDimensionChangeListeners(), this.register((0, a2.toDisposable)(() => {
            this._canvas?.remove();
          }));
        }
        _registerDecorationListeners() {
          this.register(this._decorationService.onDecorationRegistered(() => this._queueRefresh(void 0, true))), this.register(this._decorationService.onDecorationRemoved(() => this._queueRefresh(void 0, true)));
        }
        _registerBufferChangeListeners() {
          this.register(this._renderService.onRenderedViewportChange(() => this._queueRefresh())), this.register(this._bufferService.buffers.onBufferActivate(() => {
            this._canvas.style.display = this._bufferService.buffer === this._bufferService.buffers.alt ? "none" : "block";
          })), this.register(this._bufferService.onScroll(() => {
            this._lastKnownBufferLength !== this._bufferService.buffers.normal.lines.length && (this._refreshDrawHeightConstants(), this._refreshColorZonePadding());
          }));
        }
        _registerDimensionChangeListeners() {
          this.register(this._renderService.onRender(() => {
            this._containerHeight && this._containerHeight === this._screenElement.clientHeight || (this._queueRefresh(true), this._containerHeight = this._screenElement.clientHeight);
          })), this.register(this._optionsService.onSpecificOptionChange("overviewRulerWidth", () => this._queueRefresh(true))), this.register(this._coreBrowserService.onDprChange(() => this._queueRefresh(true))), this._queueRefresh(true);
        }
        _refreshDrawConstants() {
          const e4 = Math.floor(this._canvas.width / 3), t4 = Math.ceil(this._canvas.width / 3);
          l2.full = this._canvas.width, l2.left = e4, l2.center = t4, l2.right = e4, this._refreshDrawHeightConstants(), d2.full = 0, d2.left = 0, d2.center = l2.left, d2.right = l2.left + l2.center;
        }
        _refreshDrawHeightConstants() {
          c2.full = Math.round(2 * this._coreBrowserService.dpr);
          const e4 = this._canvas.height / this._bufferService.buffer.lines.length, t4 = Math.round(Math.max(Math.min(e4, 12), 6) * this._coreBrowserService.dpr);
          c2.left = t4, c2.center = t4, c2.right = t4;
        }
        _refreshColorZonePadding() {
          this._colorZoneStore.setPadding({ full: Math.floor(this._bufferService.buffers.active.lines.length / (this._canvas.height - 1) * c2.full), left: Math.floor(this._bufferService.buffers.active.lines.length / (this._canvas.height - 1) * c2.left), center: Math.floor(this._bufferService.buffers.active.lines.length / (this._canvas.height - 1) * c2.center), right: Math.floor(this._bufferService.buffers.active.lines.length / (this._canvas.height - 1) * c2.right) }), this._lastKnownBufferLength = this._bufferService.buffers.normal.lines.length;
        }
        _refreshCanvasDimensions() {
          this._canvas.style.width = `${this._width}px`, this._canvas.width = Math.round(this._width * this._coreBrowserService.dpr), this._canvas.style.height = `${this._screenElement.clientHeight}px`, this._canvas.height = Math.round(this._screenElement.clientHeight * this._coreBrowserService.dpr), this._refreshDrawConstants(), this._refreshColorZonePadding();
        }
        _refreshDecorations() {
          this._shouldUpdateDimensions && this._refreshCanvasDimensions(), this._ctx.clearRect(0, 0, this._canvas.width, this._canvas.height), this._colorZoneStore.clear();
          for (const e5 of this._decorationService.decorations) this._colorZoneStore.addDecoration(e5);
          this._ctx.lineWidth = 1;
          const e4 = this._colorZoneStore.zones;
          for (const t4 of e4) "full" !== t4.position && this._renderColorZone(t4);
          for (const t4 of e4) "full" === t4.position && this._renderColorZone(t4);
          this._shouldUpdateDimensions = false, this._shouldUpdateAnchor = false;
        }
        _renderColorZone(e4) {
          this._ctx.fillStyle = e4.color, this._ctx.fillRect(d2[e4.position || "full"], Math.round((this._canvas.height - 1) * (e4.startBufferLine / this._bufferService.buffers.active.lines.length) - c2[e4.position || "full"] / 2), l2[e4.position || "full"], Math.round((this._canvas.height - 1) * ((e4.endBufferLine - e4.startBufferLine) / this._bufferService.buffers.active.lines.length) + c2[e4.position || "full"]));
        }
        _queueRefresh(e4, t4) {
          this._shouldUpdateDimensions = e4 || this._shouldUpdateDimensions, this._shouldUpdateAnchor = t4 || this._shouldUpdateAnchor, void 0 === this._animationFrame && (this._animationFrame = this._coreBrowserService.window.requestAnimationFrame(() => {
            this._refreshDecorations(), this._animationFrame = void 0;
          }));
        }
      };
      t3.OverviewRulerRenderer = _2 = s3([r2(2, h2.IBufferService), r2(3, h2.IDecorationService), r2(4, o2.IRenderService), r2(5, h2.IOptionsService), r2(6, o2.ICoreBrowserService)], _2);
    }, 2950: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CompositionHelper = void 0;
      const n2 = i3(4725), o2 = i3(2585), a2 = i3(2584);
      let h2 = t3.CompositionHelper = class {
        get isComposing() {
          return this._isComposing;
        }
        constructor(e4, t4, i4, s4, r3, n3) {
          this._textarea = e4, this._compositionView = t4, this._bufferService = i4, this._optionsService = s4, this._coreService = r3, this._renderService = n3, this._isComposing = false, this._isSendingComposition = false, this._compositionPosition = { start: 0, end: 0 }, this._dataAlreadySent = "";
        }
        compositionstart() {
          this._isComposing = true, this._compositionPosition.start = this._textarea.value.length, this._compositionView.textContent = "", this._dataAlreadySent = "", this._compositionView.classList.add("active");
        }
        compositionupdate(e4) {
          this._compositionView.textContent = e4.data, this.updateCompositionElements(), setTimeout(() => {
            this._compositionPosition.end = this._textarea.value.length;
          }, 0);
        }
        compositionend() {
          this._finalizeComposition(true);
        }
        keydown(e4) {
          if (this._isComposing || this._isSendingComposition) {
            if (229 === e4.keyCode) return false;
            if (16 === e4.keyCode || 17 === e4.keyCode || 18 === e4.keyCode) return false;
            this._finalizeComposition(false);
          }
          return 229 !== e4.keyCode || (this._handleAnyTextareaChanges(), false);
        }
        _finalizeComposition(e4) {
          if (this._compositionView.classList.remove("active"), this._isComposing = false, e4) {
            const e5 = { start: this._compositionPosition.start, end: this._compositionPosition.end };
            this._isSendingComposition = true, setTimeout(() => {
              if (this._isSendingComposition) {
                let t4;
                this._isSendingComposition = false, e5.start += this._dataAlreadySent.length, t4 = this._isComposing ? this._textarea.value.substring(e5.start, e5.end) : this._textarea.value.substring(e5.start), t4.length > 0 && this._coreService.triggerDataEvent(t4, true);
              }
            }, 0);
          } else {
            this._isSendingComposition = false;
            const e5 = this._textarea.value.substring(this._compositionPosition.start, this._compositionPosition.end);
            this._coreService.triggerDataEvent(e5, true);
          }
        }
        _handleAnyTextareaChanges() {
          const e4 = this._textarea.value;
          setTimeout(() => {
            if (!this._isComposing) {
              const t4 = this._textarea.value, i4 = t4.replace(e4, "");
              this._dataAlreadySent = i4, t4.length > e4.length ? this._coreService.triggerDataEvent(i4, true) : t4.length < e4.length ? this._coreService.triggerDataEvent(`${a2.C0.DEL}`, true) : t4.length === e4.length && t4 !== e4 && this._coreService.triggerDataEvent(t4, true);
            }
          }, 0);
        }
        updateCompositionElements(e4) {
          if (this._isComposing) {
            if (this._bufferService.buffer.isCursorInViewport) {
              const e5 = Math.min(this._bufferService.buffer.x, this._bufferService.cols - 1), t4 = this._renderService.dimensions.css.cell.height, i4 = this._bufferService.buffer.y * this._renderService.dimensions.css.cell.height, s4 = e5 * this._renderService.dimensions.css.cell.width;
              this._compositionView.style.left = s4 + "px", this._compositionView.style.top = i4 + "px", this._compositionView.style.height = t4 + "px", this._compositionView.style.lineHeight = t4 + "px", this._compositionView.style.fontFamily = this._optionsService.rawOptions.fontFamily, this._compositionView.style.fontSize = this._optionsService.rawOptions.fontSize + "px";
              const r3 = this._compositionView.getBoundingClientRect();
              this._textarea.style.left = s4 + "px", this._textarea.style.top = i4 + "px", this._textarea.style.width = Math.max(r3.width, 1) + "px", this._textarea.style.height = Math.max(r3.height, 1) + "px", this._textarea.style.lineHeight = r3.height + "px";
            }
            e4 || setTimeout(() => this.updateCompositionElements(true), 0);
          }
        }
      };
      t3.CompositionHelper = h2 = s3([r2(2, o2.IBufferService), r2(3, o2.IOptionsService), r2(4, o2.ICoreService), r2(5, n2.IRenderService)], h2);
    }, 9806: (e3, t3) => {
      function i3(e4, t4, i4) {
        const s3 = i4.getBoundingClientRect(), r2 = e4.getComputedStyle(i4), n2 = parseInt(r2.getPropertyValue("padding-left")), o2 = parseInt(r2.getPropertyValue("padding-top"));
        return [t4.clientX - s3.left - n2, t4.clientY - s3.top - o2];
      }
      __name(i3, "i");
      Object.defineProperty(t3, "__esModule", { value: true }), t3.getCoords = t3.getCoordsRelativeToElement = void 0, t3.getCoordsRelativeToElement = i3, t3.getCoords = function(e4, t4, s3, r2, n2, o2, a2, h2, c2) {
        if (!o2) return;
        const l2 = i3(e4, t4, s3);
        return l2 ? (l2[0] = Math.ceil((l2[0] + (c2 ? a2 / 2 : 0)) / a2), l2[1] = Math.ceil(l2[1] / h2), l2[0] = Math.min(Math.max(l2[0], 1), r2 + (c2 ? 1 : 0)), l2[1] = Math.min(Math.max(l2[1], 1), n2), l2) : void 0;
      };
    }, 9504: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.moveToCellSequence = void 0;
      const s3 = i3(2584);
      function r2(e4, t4, i4, s4) {
        const r3 = e4 - n2(e4, i4), a3 = t4 - n2(t4, i4), l2 = Math.abs(r3 - a3) - function(e5, t5, i5) {
          let s5 = 0;
          const r4 = e5 - n2(e5, i5), a4 = t5 - n2(t5, i5);
          for (let n3 = 0; n3 < Math.abs(r4 - a4); n3++) {
            const a5 = "A" === o2(e5, t5) ? -1 : 1, h3 = i5.buffer.lines.get(r4 + a5 * n3);
            h3?.isWrapped && s5++;
          }
          return s5;
        }(e4, t4, i4);
        return c2(l2, h2(o2(e4, t4), s4));
      }
      __name(r2, "r");
      function n2(e4, t4) {
        let i4 = 0, s4 = t4.buffer.lines.get(e4), r3 = s4?.isWrapped;
        for (; r3 && e4 >= 0 && e4 < t4.rows; ) i4++, s4 = t4.buffer.lines.get(--e4), r3 = s4?.isWrapped;
        return i4;
      }
      __name(n2, "n");
      function o2(e4, t4) {
        return e4 > t4 ? "A" : "B";
      }
      __name(o2, "o");
      function a2(e4, t4, i4, s4, r3, n3) {
        let o3 = e4, a3 = t4, h3 = "";
        for (; o3 !== i4 || a3 !== s4; ) o3 += r3 ? 1 : -1, r3 && o3 > n3.cols - 1 ? (h3 += n3.buffer.translateBufferLineToString(a3, false, e4, o3), o3 = 0, e4 = 0, a3++) : !r3 && o3 < 0 && (h3 += n3.buffer.translateBufferLineToString(a3, false, 0, e4 + 1), o3 = n3.cols - 1, e4 = o3, a3--);
        return h3 + n3.buffer.translateBufferLineToString(a3, false, e4, o3);
      }
      __name(a2, "a");
      function h2(e4, t4) {
        const i4 = t4 ? "O" : "[";
        return s3.C0.ESC + i4 + e4;
      }
      __name(h2, "h");
      function c2(e4, t4) {
        e4 = Math.floor(e4);
        let i4 = "";
        for (let s4 = 0; s4 < e4; s4++) i4 += t4;
        return i4;
      }
      __name(c2, "c");
      t3.moveToCellSequence = function(e4, t4, i4, s4) {
        const o3 = i4.buffer.x, l2 = i4.buffer.y;
        if (!i4.buffer.hasScrollback) return function(e5, t5, i5, s5, o4, l3) {
          return 0 === r2(t5, s5, o4, l3).length ? "" : c2(a2(e5, t5, e5, t5 - n2(t5, o4), false, o4).length, h2("D", l3));
        }(o3, l2, 0, t4, i4, s4) + r2(l2, t4, i4, s4) + function(e5, t5, i5, s5, o4, l3) {
          let d3;
          d3 = r2(t5, s5, o4, l3).length > 0 ? s5 - n2(s5, o4) : t5;
          const _3 = s5, u2 = function(e6, t6, i6, s6, o5, a3) {
            let h3;
            return h3 = r2(i6, s6, o5, a3).length > 0 ? s6 - n2(s6, o5) : t6, e6 < i6 && h3 <= s6 || e6 >= i6 && h3 < s6 ? "C" : "D";
          }(e5, t5, i5, s5, o4, l3);
          return c2(a2(e5, d3, i5, _3, "C" === u2, o4).length, h2(u2, l3));
        }(o3, l2, e4, t4, i4, s4);
        let d2;
        if (l2 === t4) return d2 = o3 > e4 ? "D" : "C", c2(Math.abs(o3 - e4), h2(d2, s4));
        d2 = l2 > t4 ? "D" : "C";
        const _2 = Math.abs(l2 - t4);
        return c2(function(e5, t5) {
          return t5.cols - e5;
        }(l2 > t4 ? e4 : o3, i4) + (_2 - 1) * i4.cols + 1 + ((l2 > t4 ? o3 : e4) - 1), h2(d2, s4));
      };
    }, 1296: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DomRenderer = void 0;
      const n2 = i3(3787), o2 = i3(2550), a2 = i3(2223), h2 = i3(6171), c2 = i3(6052), l2 = i3(4725), d2 = i3(8055), _2 = i3(8460), u2 = i3(844), f2 = i3(2585), v2 = "xterm-dom-renderer-owner-", p2 = "xterm-rows", g2 = "xterm-fg-", m2 = "xterm-bg-", S2 = "xterm-focus", C2 = "xterm-selection";
      let b2 = 1, w2 = t3.DomRenderer = class extends u2.Disposable {
        constructor(e4, t4, i4, s4, r3, a3, l3, d3, f3, g3, m3, S3, w3) {
          super(), this._terminal = e4, this._document = t4, this._element = i4, this._screenElement = s4, this._viewportElement = r3, this._helperContainer = a3, this._linkifier2 = l3, this._charSizeService = f3, this._optionsService = g3, this._bufferService = m3, this._coreBrowserService = S3, this._themeService = w3, this._terminalClass = b2++, this._rowElements = [], this._selectionRenderModel = (0, c2.createSelectionRenderModel)(), this.onRequestRedraw = this.register(new _2.EventEmitter()).event, this._rowContainer = this._document.createElement("div"), this._rowContainer.classList.add(p2), this._rowContainer.style.lineHeight = "normal", this._rowContainer.setAttribute("aria-hidden", "true"), this._refreshRowElements(this._bufferService.cols, this._bufferService.rows), this._selectionContainer = this._document.createElement("div"), this._selectionContainer.classList.add(C2), this._selectionContainer.setAttribute("aria-hidden", "true"), this.dimensions = (0, h2.createRenderDimensions)(), this._updateDimensions(), this.register(this._optionsService.onOptionChange(() => this._handleOptionsChanged())), this.register(this._themeService.onChangeColors((e5) => this._injectCss(e5))), this._injectCss(this._themeService.colors), this._rowFactory = d3.createInstance(n2.DomRendererRowFactory, document), this._element.classList.add(v2 + this._terminalClass), this._screenElement.appendChild(this._rowContainer), this._screenElement.appendChild(this._selectionContainer), this.register(this._linkifier2.onShowLinkUnderline((e5) => this._handleLinkHover(e5))), this.register(this._linkifier2.onHideLinkUnderline((e5) => this._handleLinkLeave(e5))), this.register((0, u2.toDisposable)(() => {
            this._element.classList.remove(v2 + this._terminalClass), this._rowContainer.remove(), this._selectionContainer.remove(), this._widthCache.dispose(), this._themeStyleElement.remove(), this._dimensionsStyleElement.remove();
          })), this._widthCache = new o2.WidthCache(this._document, this._helperContainer), this._widthCache.setFont(this._optionsService.rawOptions.fontFamily, this._optionsService.rawOptions.fontSize, this._optionsService.rawOptions.fontWeight, this._optionsService.rawOptions.fontWeightBold), this._setDefaultSpacing();
        }
        _updateDimensions() {
          const e4 = this._coreBrowserService.dpr;
          this.dimensions.device.char.width = this._charSizeService.width * e4, this.dimensions.device.char.height = Math.ceil(this._charSizeService.height * e4), this.dimensions.device.cell.width = this.dimensions.device.char.width + Math.round(this._optionsService.rawOptions.letterSpacing), this.dimensions.device.cell.height = Math.floor(this.dimensions.device.char.height * this._optionsService.rawOptions.lineHeight), this.dimensions.device.char.left = 0, this.dimensions.device.char.top = 0, this.dimensions.device.canvas.width = this.dimensions.device.cell.width * this._bufferService.cols, this.dimensions.device.canvas.height = this.dimensions.device.cell.height * this._bufferService.rows, this.dimensions.css.canvas.width = Math.round(this.dimensions.device.canvas.width / e4), this.dimensions.css.canvas.height = Math.round(this.dimensions.device.canvas.height / e4), this.dimensions.css.cell.width = this.dimensions.css.canvas.width / this._bufferService.cols, this.dimensions.css.cell.height = this.dimensions.css.canvas.height / this._bufferService.rows;
          for (const e5 of this._rowElements) e5.style.width = `${this.dimensions.css.canvas.width}px`, e5.style.height = `${this.dimensions.css.cell.height}px`, e5.style.lineHeight = `${this.dimensions.css.cell.height}px`, e5.style.overflow = "hidden";
          this._dimensionsStyleElement || (this._dimensionsStyleElement = this._document.createElement("style"), this._screenElement.appendChild(this._dimensionsStyleElement));
          const t4 = `${this._terminalSelector} .${p2} span { display: inline-block; height: 100%; vertical-align: top;}`;
          this._dimensionsStyleElement.textContent = t4, this._selectionContainer.style.height = this._viewportElement.style.height, this._screenElement.style.width = `${this.dimensions.css.canvas.width}px`, this._screenElement.style.height = `${this.dimensions.css.canvas.height}px`;
        }
        _injectCss(e4) {
          this._themeStyleElement || (this._themeStyleElement = this._document.createElement("style"), this._screenElement.appendChild(this._themeStyleElement));
          let t4 = `${this._terminalSelector} .${p2} { color: ${e4.foreground.css}; font-family: ${this._optionsService.rawOptions.fontFamily}; font-size: ${this._optionsService.rawOptions.fontSize}px; font-kerning: none; white-space: pre}`;
          t4 += `${this._terminalSelector} .${p2} .xterm-dim { color: ${d2.color.multiplyOpacity(e4.foreground, 0.5).css};}`, t4 += `${this._terminalSelector} span:not(.xterm-bold) { font-weight: ${this._optionsService.rawOptions.fontWeight};}${this._terminalSelector} span.xterm-bold { font-weight: ${this._optionsService.rawOptions.fontWeightBold};}${this._terminalSelector} span.xterm-italic { font-style: italic;}`;
          const i4 = `blink_underline_${this._terminalClass}`, s4 = `blink_bar_${this._terminalClass}`, r3 = `blink_block_${this._terminalClass}`;
          t4 += `@keyframes ${i4} { 50% {  border-bottom-style: hidden; }}`, t4 += `@keyframes ${s4} { 50% {  box-shadow: none; }}`, t4 += `@keyframes ${r3} { 0% {  background-color: ${e4.cursor.css};  color: ${e4.cursorAccent.css}; } 50% {  background-color: inherit;  color: ${e4.cursor.css}; }}`, t4 += `${this._terminalSelector} .${p2}.${S2} .xterm-cursor.xterm-cursor-blink.xterm-cursor-underline { animation: ${i4} 1s step-end infinite;}${this._terminalSelector} .${p2}.${S2} .xterm-cursor.xterm-cursor-blink.xterm-cursor-bar { animation: ${s4} 1s step-end infinite;}${this._terminalSelector} .${p2}.${S2} .xterm-cursor.xterm-cursor-blink.xterm-cursor-block { animation: ${r3} 1s step-end infinite;}${this._terminalSelector} .${p2} .xterm-cursor.xterm-cursor-block { background-color: ${e4.cursor.css}; color: ${e4.cursorAccent.css};}${this._terminalSelector} .${p2} .xterm-cursor.xterm-cursor-block:not(.xterm-cursor-blink) { background-color: ${e4.cursor.css} !important; color: ${e4.cursorAccent.css} !important;}${this._terminalSelector} .${p2} .xterm-cursor.xterm-cursor-outline { outline: 1px solid ${e4.cursor.css}; outline-offset: -1px;}${this._terminalSelector} .${p2} .xterm-cursor.xterm-cursor-bar { box-shadow: ${this._optionsService.rawOptions.cursorWidth}px 0 0 ${e4.cursor.css} inset;}${this._terminalSelector} .${p2} .xterm-cursor.xterm-cursor-underline { border-bottom: 1px ${e4.cursor.css}; border-bottom-style: solid; height: calc(100% - 1px);}`, t4 += `${this._terminalSelector} .${C2} { position: absolute; top: 0; left: 0; z-index: 1; pointer-events: none;}${this._terminalSelector}.focus .${C2} div { position: absolute; background-color: ${e4.selectionBackgroundOpaque.css};}${this._terminalSelector} .${C2} div { position: absolute; background-color: ${e4.selectionInactiveBackgroundOpaque.css};}`;
          for (const [i5, s5] of e4.ansi.entries()) t4 += `${this._terminalSelector} .${g2}${i5} { color: ${s5.css}; }${this._terminalSelector} .${g2}${i5}.xterm-dim { color: ${d2.color.multiplyOpacity(s5, 0.5).css}; }${this._terminalSelector} .${m2}${i5} { background-color: ${s5.css}; }`;
          t4 += `${this._terminalSelector} .${g2}${a2.INVERTED_DEFAULT_COLOR} { color: ${d2.color.opaque(e4.background).css}; }${this._terminalSelector} .${g2}${a2.INVERTED_DEFAULT_COLOR}.xterm-dim { color: ${d2.color.multiplyOpacity(d2.color.opaque(e4.background), 0.5).css}; }${this._terminalSelector} .${m2}${a2.INVERTED_DEFAULT_COLOR} { background-color: ${e4.foreground.css}; }`, this._themeStyleElement.textContent = t4;
        }
        _setDefaultSpacing() {
          const e4 = this.dimensions.css.cell.width - this._widthCache.get("W", false, false);
          this._rowContainer.style.letterSpacing = `${e4}px`, this._rowFactory.defaultSpacing = e4;
        }
        handleDevicePixelRatioChange() {
          this._updateDimensions(), this._widthCache.clear(), this._setDefaultSpacing();
        }
        _refreshRowElements(e4, t4) {
          for (let e5 = this._rowElements.length; e5 <= t4; e5++) {
            const e6 = this._document.createElement("div");
            this._rowContainer.appendChild(e6), this._rowElements.push(e6);
          }
          for (; this._rowElements.length > t4; ) this._rowContainer.removeChild(this._rowElements.pop());
        }
        handleResize(e4, t4) {
          this._refreshRowElements(e4, t4), this._updateDimensions(), this.handleSelectionChanged(this._selectionRenderModel.selectionStart, this._selectionRenderModel.selectionEnd, this._selectionRenderModel.columnSelectMode);
        }
        handleCharSizeChanged() {
          this._updateDimensions(), this._widthCache.clear(), this._setDefaultSpacing();
        }
        handleBlur() {
          this._rowContainer.classList.remove(S2), this.renderRows(0, this._bufferService.rows - 1);
        }
        handleFocus() {
          this._rowContainer.classList.add(S2), this.renderRows(this._bufferService.buffer.y, this._bufferService.buffer.y);
        }
        handleSelectionChanged(e4, t4, i4) {
          if (this._selectionContainer.replaceChildren(), this._rowFactory.handleSelectionChanged(e4, t4, i4), this.renderRows(0, this._bufferService.rows - 1), !e4 || !t4) return;
          this._selectionRenderModel.update(this._terminal, e4, t4, i4);
          const s4 = this._selectionRenderModel.viewportStartRow, r3 = this._selectionRenderModel.viewportEndRow, n3 = this._selectionRenderModel.viewportCappedStartRow, o3 = this._selectionRenderModel.viewportCappedEndRow;
          if (n3 >= this._bufferService.rows || o3 < 0) return;
          const a3 = this._document.createDocumentFragment();
          if (i4) {
            const i5 = e4[0] > t4[0];
            a3.appendChild(this._createSelectionElement(n3, i5 ? t4[0] : e4[0], i5 ? e4[0] : t4[0], o3 - n3 + 1));
          } else {
            const i5 = s4 === n3 ? e4[0] : 0, h3 = n3 === r3 ? t4[0] : this._bufferService.cols;
            a3.appendChild(this._createSelectionElement(n3, i5, h3));
            const c3 = o3 - n3 - 1;
            if (a3.appendChild(this._createSelectionElement(n3 + 1, 0, this._bufferService.cols, c3)), n3 !== o3) {
              const e5 = r3 === o3 ? t4[0] : this._bufferService.cols;
              a3.appendChild(this._createSelectionElement(o3, 0, e5));
            }
          }
          this._selectionContainer.appendChild(a3);
        }
        _createSelectionElement(e4, t4, i4, s4 = 1) {
          const r3 = this._document.createElement("div"), n3 = t4 * this.dimensions.css.cell.width;
          let o3 = this.dimensions.css.cell.width * (i4 - t4);
          return n3 + o3 > this.dimensions.css.canvas.width && (o3 = this.dimensions.css.canvas.width - n3), r3.style.height = s4 * this.dimensions.css.cell.height + "px", r3.style.top = e4 * this.dimensions.css.cell.height + "px", r3.style.left = `${n3}px`, r3.style.width = `${o3}px`, r3;
        }
        handleCursorMove() {
        }
        _handleOptionsChanged() {
          this._updateDimensions(), this._injectCss(this._themeService.colors), this._widthCache.setFont(this._optionsService.rawOptions.fontFamily, this._optionsService.rawOptions.fontSize, this._optionsService.rawOptions.fontWeight, this._optionsService.rawOptions.fontWeightBold), this._setDefaultSpacing();
        }
        clear() {
          for (const e4 of this._rowElements) e4.replaceChildren();
        }
        renderRows(e4, t4) {
          const i4 = this._bufferService.buffer, s4 = i4.ybase + i4.y, r3 = Math.min(i4.x, this._bufferService.cols - 1), n3 = this._optionsService.rawOptions.cursorBlink, o3 = this._optionsService.rawOptions.cursorStyle, a3 = this._optionsService.rawOptions.cursorInactiveStyle;
          for (let h3 = e4; h3 <= t4; h3++) {
            const e5 = h3 + i4.ydisp, t5 = this._rowElements[h3], c3 = i4.lines.get(e5);
            if (!t5 || !c3) break;
            t5.replaceChildren(...this._rowFactory.createRow(c3, e5, e5 === s4, o3, a3, r3, n3, this.dimensions.css.cell.width, this._widthCache, -1, -1));
          }
        }
        get _terminalSelector() {
          return `.${v2}${this._terminalClass}`;
        }
        _handleLinkHover(e4) {
          this._setCellUnderline(e4.x1, e4.x2, e4.y1, e4.y2, e4.cols, true);
        }
        _handleLinkLeave(e4) {
          this._setCellUnderline(e4.x1, e4.x2, e4.y1, e4.y2, e4.cols, false);
        }
        _setCellUnderline(e4, t4, i4, s4, r3, n3) {
          i4 < 0 && (e4 = 0), s4 < 0 && (t4 = 0);
          const o3 = this._bufferService.rows - 1;
          i4 = Math.max(Math.min(i4, o3), 0), s4 = Math.max(Math.min(s4, o3), 0), r3 = Math.min(r3, this._bufferService.cols);
          const a3 = this._bufferService.buffer, h3 = a3.ybase + a3.y, c3 = Math.min(a3.x, r3 - 1), l3 = this._optionsService.rawOptions.cursorBlink, d3 = this._optionsService.rawOptions.cursorStyle, _3 = this._optionsService.rawOptions.cursorInactiveStyle;
          for (let o4 = i4; o4 <= s4; ++o4) {
            const u3 = o4 + a3.ydisp, f3 = this._rowElements[o4], v3 = a3.lines.get(u3);
            if (!f3 || !v3) break;
            f3.replaceChildren(...this._rowFactory.createRow(v3, u3, u3 === h3, d3, _3, c3, l3, this.dimensions.css.cell.width, this._widthCache, n3 ? o4 === i4 ? e4 : 0 : -1, n3 ? (o4 === s4 ? t4 : r3) - 1 : -1));
          }
        }
      };
      t3.DomRenderer = w2 = s3([r2(7, f2.IInstantiationService), r2(8, l2.ICharSizeService), r2(9, f2.IOptionsService), r2(10, f2.IBufferService), r2(11, l2.ICoreBrowserService), r2(12, l2.IThemeService)], w2);
    }, 3787: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DomRendererRowFactory = void 0;
      const n2 = i3(2223), o2 = i3(643), a2 = i3(511), h2 = i3(2585), c2 = i3(8055), l2 = i3(4725), d2 = i3(4269), _2 = i3(6171), u2 = i3(3734);
      let f2 = t3.DomRendererRowFactory = class {
        constructor(e4, t4, i4, s4, r3, n3, o3) {
          this._document = e4, this._characterJoinerService = t4, this._optionsService = i4, this._coreBrowserService = s4, this._coreService = r3, this._decorationService = n3, this._themeService = o3, this._workCell = new a2.CellData(), this._columnSelectMode = false, this.defaultSpacing = 0;
        }
        handleSelectionChanged(e4, t4, i4) {
          this._selectionStart = e4, this._selectionEnd = t4, this._columnSelectMode = i4;
        }
        createRow(e4, t4, i4, s4, r3, a3, h3, l3, _3, f3, p2) {
          const g2 = [], m2 = this._characterJoinerService.getJoinedCharacters(t4), S2 = this._themeService.colors;
          let C2, b2 = e4.getNoBgTrimmedLength();
          i4 && b2 < a3 + 1 && (b2 = a3 + 1);
          let w2 = 0, y2 = "", E = 0, k2 = 0, L2 = 0, D2 = false, R = 0, x2 = false, A2 = 0;
          const B2 = [], T2 = -1 !== f3 && -1 !== p2;
          for (let M2 = 0; M2 < b2; M2++) {
            e4.loadCell(M2, this._workCell);
            let b3 = this._workCell.getWidth();
            if (0 === b3) continue;
            let O2 = false, P2 = M2, I2 = this._workCell;
            if (m2.length > 0 && M2 === m2[0][0]) {
              O2 = true;
              const t5 = m2.shift();
              I2 = new d2.JoinedCellData(this._workCell, e4.translateToString(true, t5[0], t5[1]), t5[1] - t5[0]), P2 = t5[1] - 1, b3 = I2.getWidth();
            }
            const H = this._isCellInSelection(M2, t4), F2 = i4 && M2 === a3, W = T2 && M2 >= f3 && M2 <= p2;
            let U = false;
            this._decorationService.forEachDecorationAtCell(M2, t4, void 0, (e5) => {
              U = true;
            });
            let N2 = I2.getChars() || o2.WHITESPACE_CELL_CHAR;
            if (" " === N2 && (I2.isUnderline() || I2.isOverline()) && (N2 = " "), A2 = b3 * l3 - _3.get(N2, I2.isBold(), I2.isItalic()), C2) {
              if (w2 && (H && x2 || !H && !x2 && I2.bg === E) && (H && x2 && S2.selectionForeground || I2.fg === k2) && I2.extended.ext === L2 && W === D2 && A2 === R && !F2 && !O2 && !U) {
                I2.isInvisible() ? y2 += o2.WHITESPACE_CELL_CHAR : y2 += N2, w2++;
                continue;
              }
              w2 && (C2.textContent = y2), C2 = this._document.createElement("span"), w2 = 0, y2 = "";
            } else C2 = this._document.createElement("span");
            if (E = I2.bg, k2 = I2.fg, L2 = I2.extended.ext, D2 = W, R = A2, x2 = H, O2 && a3 >= M2 && a3 <= P2 && (a3 = M2), !this._coreService.isCursorHidden && F2 && this._coreService.isCursorInitialized) {
              if (B2.push("xterm-cursor"), this._coreBrowserService.isFocused) h3 && B2.push("xterm-cursor-blink"), B2.push("bar" === s4 ? "xterm-cursor-bar" : "underline" === s4 ? "xterm-cursor-underline" : "xterm-cursor-block");
              else if (r3) switch (r3) {
                case "outline":
                  B2.push("xterm-cursor-outline");
                  break;
                case "block":
                  B2.push("xterm-cursor-block");
                  break;
                case "bar":
                  B2.push("xterm-cursor-bar");
                  break;
                case "underline":
                  B2.push("xterm-cursor-underline");
              }
            }
            if (I2.isBold() && B2.push("xterm-bold"), I2.isItalic() && B2.push("xterm-italic"), I2.isDim() && B2.push("xterm-dim"), y2 = I2.isInvisible() ? o2.WHITESPACE_CELL_CHAR : I2.getChars() || o2.WHITESPACE_CELL_CHAR, I2.isUnderline() && (B2.push(`xterm-underline-${I2.extended.underlineStyle}`), " " === y2 && (y2 = " "), !I2.isUnderlineColorDefault())) if (I2.isUnderlineColorRGB()) C2.style.textDecorationColor = `rgb(${u2.AttributeData.toColorRGB(I2.getUnderlineColor()).join(",")})`;
            else {
              let e5 = I2.getUnderlineColor();
              this._optionsService.rawOptions.drawBoldTextInBrightColors && I2.isBold() && e5 < 8 && (e5 += 8), C2.style.textDecorationColor = S2.ansi[e5].css;
            }
            I2.isOverline() && (B2.push("xterm-overline"), " " === y2 && (y2 = " ")), I2.isStrikethrough() && B2.push("xterm-strikethrough"), W && (C2.style.textDecoration = "underline");
            let $2 = I2.getFgColor(), j2 = I2.getFgColorMode(), z2 = I2.getBgColor(), K = I2.getBgColorMode();
            const q2 = !!I2.isInverse();
            if (q2) {
              const e5 = $2;
              $2 = z2, z2 = e5;
              const t5 = j2;
              j2 = K, K = t5;
            }
            let V2, G, X, J = false;
            switch (this._decorationService.forEachDecorationAtCell(M2, t4, void 0, (e5) => {
              "top" !== e5.options.layer && J || (e5.backgroundColorRGB && (K = 50331648, z2 = e5.backgroundColorRGB.rgba >> 8 & 16777215, V2 = e5.backgroundColorRGB), e5.foregroundColorRGB && (j2 = 50331648, $2 = e5.foregroundColorRGB.rgba >> 8 & 16777215, G = e5.foregroundColorRGB), J = "top" === e5.options.layer);
            }), !J && H && (V2 = this._coreBrowserService.isFocused ? S2.selectionBackgroundOpaque : S2.selectionInactiveBackgroundOpaque, z2 = V2.rgba >> 8 & 16777215, K = 50331648, J = true, S2.selectionForeground && (j2 = 50331648, $2 = S2.selectionForeground.rgba >> 8 & 16777215, G = S2.selectionForeground)), J && B2.push("xterm-decoration-top"), K) {
              case 16777216:
              case 33554432:
                X = S2.ansi[z2], B2.push(`xterm-bg-${z2}`);
                break;
              case 50331648:
                X = c2.channels.toColor(z2 >> 16, z2 >> 8 & 255, 255 & z2), this._addStyle(C2, `background-color:#${v2((z2 >>> 0).toString(16), "0", 6)}`);
                break;
              default:
                q2 ? (X = S2.foreground, B2.push(`xterm-bg-${n2.INVERTED_DEFAULT_COLOR}`)) : X = S2.background;
            }
            switch (V2 || I2.isDim() && (V2 = c2.color.multiplyOpacity(X, 0.5)), j2) {
              case 16777216:
              case 33554432:
                I2.isBold() && $2 < 8 && this._optionsService.rawOptions.drawBoldTextInBrightColors && ($2 += 8), this._applyMinimumContrast(C2, X, S2.ansi[$2], I2, V2, void 0) || B2.push(`xterm-fg-${$2}`);
                break;
              case 50331648:
                const e5 = c2.channels.toColor($2 >> 16 & 255, $2 >> 8 & 255, 255 & $2);
                this._applyMinimumContrast(C2, X, e5, I2, V2, G) || this._addStyle(C2, `color:#${v2($2.toString(16), "0", 6)}`);
                break;
              default:
                this._applyMinimumContrast(C2, X, S2.foreground, I2, V2, G) || q2 && B2.push(`xterm-fg-${n2.INVERTED_DEFAULT_COLOR}`);
            }
            B2.length && (C2.className = B2.join(" "), B2.length = 0), F2 || O2 || U ? C2.textContent = y2 : w2++, A2 !== this.defaultSpacing && (C2.style.letterSpacing = `${A2}px`), g2.push(C2), M2 = P2;
          }
          return C2 && w2 && (C2.textContent = y2), g2;
        }
        _applyMinimumContrast(e4, t4, i4, s4, r3, n3) {
          if (1 === this._optionsService.rawOptions.minimumContrastRatio || (0, _2.treatGlyphAsBackgroundColor)(s4.getCode())) return false;
          const o3 = this._getContrastCache(s4);
          let a3;
          if (r3 || n3 || (a3 = o3.getColor(t4.rgba, i4.rgba)), void 0 === a3) {
            const e5 = this._optionsService.rawOptions.minimumContrastRatio / (s4.isDim() ? 2 : 1);
            a3 = c2.color.ensureContrastRatio(r3 || t4, n3 || i4, e5), o3.setColor((r3 || t4).rgba, (n3 || i4).rgba, a3 ?? null);
          }
          return !!a3 && (this._addStyle(e4, `color:${a3.css}`), true);
        }
        _getContrastCache(e4) {
          return e4.isDim() ? this._themeService.colors.halfContrastCache : this._themeService.colors.contrastCache;
        }
        _addStyle(e4, t4) {
          e4.setAttribute("style", `${e4.getAttribute("style") || ""}${t4};`);
        }
        _isCellInSelection(e4, t4) {
          const i4 = this._selectionStart, s4 = this._selectionEnd;
          return !(!i4 || !s4) && (this._columnSelectMode ? i4[0] <= s4[0] ? e4 >= i4[0] && t4 >= i4[1] && e4 < s4[0] && t4 <= s4[1] : e4 < i4[0] && t4 >= i4[1] && e4 >= s4[0] && t4 <= s4[1] : t4 > i4[1] && t4 < s4[1] || i4[1] === s4[1] && t4 === i4[1] && e4 >= i4[0] && e4 < s4[0] || i4[1] < s4[1] && t4 === s4[1] && e4 < s4[0] || i4[1] < s4[1] && t4 === i4[1] && e4 >= i4[0]);
        }
      };
      function v2(e4, t4, i4) {
        for (; e4.length < i4; ) e4 = t4 + e4;
        return e4;
      }
      __name(v2, "v");
      t3.DomRendererRowFactory = f2 = s3([r2(1, l2.ICharacterJoinerService), r2(2, h2.IOptionsService), r2(3, l2.ICoreBrowserService), r2(4, h2.ICoreService), r2(5, h2.IDecorationService), r2(6, l2.IThemeService)], f2);
    }, 2550: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.WidthCache = void 0, t3.WidthCache = class {
        constructor(e4, t4) {
          this._flat = new Float32Array(256), this._font = "", this._fontSize = 0, this._weight = "normal", this._weightBold = "bold", this._measureElements = [], this._container = e4.createElement("div"), this._container.classList.add("xterm-width-cache-measure-container"), this._container.setAttribute("aria-hidden", "true"), this._container.style.whiteSpace = "pre", this._container.style.fontKerning = "none";
          const i3 = e4.createElement("span");
          i3.classList.add("xterm-char-measure-element");
          const s3 = e4.createElement("span");
          s3.classList.add("xterm-char-measure-element"), s3.style.fontWeight = "bold";
          const r2 = e4.createElement("span");
          r2.classList.add("xterm-char-measure-element"), r2.style.fontStyle = "italic";
          const n2 = e4.createElement("span");
          n2.classList.add("xterm-char-measure-element"), n2.style.fontWeight = "bold", n2.style.fontStyle = "italic", this._measureElements = [i3, s3, r2, n2], this._container.appendChild(i3), this._container.appendChild(s3), this._container.appendChild(r2), this._container.appendChild(n2), t4.appendChild(this._container), this.clear();
        }
        dispose() {
          this._container.remove(), this._measureElements.length = 0, this._holey = void 0;
        }
        clear() {
          this._flat.fill(-9999), this._holey = /* @__PURE__ */ new Map();
        }
        setFont(e4, t4, i3, s3) {
          e4 === this._font && t4 === this._fontSize && i3 === this._weight && s3 === this._weightBold || (this._font = e4, this._fontSize = t4, this._weight = i3, this._weightBold = s3, this._container.style.fontFamily = this._font, this._container.style.fontSize = `${this._fontSize}px`, this._measureElements[0].style.fontWeight = `${i3}`, this._measureElements[1].style.fontWeight = `${s3}`, this._measureElements[2].style.fontWeight = `${i3}`, this._measureElements[3].style.fontWeight = `${s3}`, this.clear());
        }
        get(e4, t4, i3) {
          let s3 = 0;
          if (!t4 && !i3 && 1 === e4.length && (s3 = e4.charCodeAt(0)) < 256) {
            if (-9999 !== this._flat[s3]) return this._flat[s3];
            const t5 = this._measure(e4, 0);
            return t5 > 0 && (this._flat[s3] = t5), t5;
          }
          let r2 = e4;
          t4 && (r2 += "B"), i3 && (r2 += "I");
          let n2 = this._holey.get(r2);
          if (void 0 === n2) {
            let s4 = 0;
            t4 && (s4 |= 1), i3 && (s4 |= 2), n2 = this._measure(e4, s4), n2 > 0 && this._holey.set(r2, n2);
          }
          return n2;
        }
        _measure(e4, t4) {
          const i3 = this._measureElements[t4];
          return i3.textContent = e4.repeat(32), i3.offsetWidth / 32;
        }
      };
    }, 2223: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.TEXT_BASELINE = t3.DIM_OPACITY = t3.INVERTED_DEFAULT_COLOR = void 0;
      const s3 = i3(6114);
      t3.INVERTED_DEFAULT_COLOR = 257, t3.DIM_OPACITY = 0.5, t3.TEXT_BASELINE = s3.isFirefox || s3.isLegacyEdge ? "bottom" : "ideographic";
    }, 6171: (e3, t3) => {
      function i3(e4) {
        return 57508 <= e4 && e4 <= 57558;
      }
      __name(i3, "i");
      function s3(e4) {
        return e4 >= 128512 && e4 <= 128591 || e4 >= 127744 && e4 <= 128511 || e4 >= 128640 && e4 <= 128767 || e4 >= 9728 && e4 <= 9983 || e4 >= 9984 && e4 <= 10175 || e4 >= 65024 && e4 <= 65039 || e4 >= 129280 && e4 <= 129535 || e4 >= 127462 && e4 <= 127487;
      }
      __name(s3, "s");
      Object.defineProperty(t3, "__esModule", { value: true }), t3.computeNextVariantOffset = t3.createRenderDimensions = t3.treatGlyphAsBackgroundColor = t3.allowRescaling = t3.isEmoji = t3.isRestrictedPowerlineGlyph = t3.isPowerlineGlyph = t3.throwIfFalsy = void 0, t3.throwIfFalsy = function(e4) {
        if (!e4) throw new Error("value must not be falsy");
        return e4;
      }, t3.isPowerlineGlyph = i3, t3.isRestrictedPowerlineGlyph = function(e4) {
        return 57520 <= e4 && e4 <= 57527;
      }, t3.isEmoji = s3, t3.allowRescaling = function(e4, t4, r2, n2) {
        return 1 === t4 && r2 > Math.ceil(1.5 * n2) && void 0 !== e4 && e4 > 255 && !s3(e4) && !i3(e4) && !function(e5) {
          return 57344 <= e5 && e5 <= 63743;
        }(e4);
      }, t3.treatGlyphAsBackgroundColor = function(e4) {
        return i3(e4) || function(e5) {
          return 9472 <= e5 && e5 <= 9631;
        }(e4);
      }, t3.createRenderDimensions = function() {
        return { css: { canvas: { width: 0, height: 0 }, cell: { width: 0, height: 0 } }, device: { canvas: { width: 0, height: 0 }, cell: { width: 0, height: 0 }, char: { width: 0, height: 0, left: 0, top: 0 } } };
      }, t3.computeNextVariantOffset = function(e4, t4, i4 = 0) {
        return (e4 - (2 * Math.round(t4) - i4)) % (2 * Math.round(t4));
      };
    }, 6052: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.createSelectionRenderModel = void 0;
      class i3 {
        static {
          __name(this, "i");
        }
        constructor() {
          this.clear();
        }
        clear() {
          this.hasSelection = false, this.columnSelectMode = false, this.viewportStartRow = 0, this.viewportEndRow = 0, this.viewportCappedStartRow = 0, this.viewportCappedEndRow = 0, this.startCol = 0, this.endCol = 0, this.selectionStart = void 0, this.selectionEnd = void 0;
        }
        update(e4, t4, i4, s3 = false) {
          if (this.selectionStart = t4, this.selectionEnd = i4, !t4 || !i4 || t4[0] === i4[0] && t4[1] === i4[1]) return void this.clear();
          const r2 = e4.buffers.active.ydisp, n2 = t4[1] - r2, o2 = i4[1] - r2, a2 = Math.max(n2, 0), h2 = Math.min(o2, e4.rows - 1);
          a2 >= e4.rows || h2 < 0 ? this.clear() : (this.hasSelection = true, this.columnSelectMode = s3, this.viewportStartRow = n2, this.viewportEndRow = o2, this.viewportCappedStartRow = a2, this.viewportCappedEndRow = h2, this.startCol = t4[0], this.endCol = i4[0]);
        }
        isCellSelected(e4, t4, i4) {
          return !!this.hasSelection && (i4 -= e4.buffer.active.viewportY, this.columnSelectMode ? this.startCol <= this.endCol ? t4 >= this.startCol && i4 >= this.viewportCappedStartRow && t4 < this.endCol && i4 <= this.viewportCappedEndRow : t4 < this.startCol && i4 >= this.viewportCappedStartRow && t4 >= this.endCol && i4 <= this.viewportCappedEndRow : i4 > this.viewportStartRow && i4 < this.viewportEndRow || this.viewportStartRow === this.viewportEndRow && i4 === this.viewportStartRow && t4 >= this.startCol && t4 < this.endCol || this.viewportStartRow < this.viewportEndRow && i4 === this.viewportEndRow && t4 < this.endCol || this.viewportStartRow < this.viewportEndRow && i4 === this.viewportStartRow && t4 >= this.startCol);
        }
      }
      t3.createSelectionRenderModel = function() {
        return new i3();
      };
    }, 456: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.SelectionModel = void 0, t3.SelectionModel = class {
        constructor(e4) {
          this._bufferService = e4, this.isSelectAllActive = false, this.selectionStartLength = 0;
        }
        clearSelection() {
          this.selectionStart = void 0, this.selectionEnd = void 0, this.isSelectAllActive = false, this.selectionStartLength = 0;
        }
        get finalSelectionStart() {
          return this.isSelectAllActive ? [0, 0] : this.selectionEnd && this.selectionStart && this.areSelectionValuesReversed() ? this.selectionEnd : this.selectionStart;
        }
        get finalSelectionEnd() {
          if (this.isSelectAllActive) return [this._bufferService.cols, this._bufferService.buffer.ybase + this._bufferService.rows - 1];
          if (this.selectionStart) {
            if (!this.selectionEnd || this.areSelectionValuesReversed()) {
              const e4 = this.selectionStart[0] + this.selectionStartLength;
              return e4 > this._bufferService.cols ? e4 % this._bufferService.cols == 0 ? [this._bufferService.cols, this.selectionStart[1] + Math.floor(e4 / this._bufferService.cols) - 1] : [e4 % this._bufferService.cols, this.selectionStart[1] + Math.floor(e4 / this._bufferService.cols)] : [e4, this.selectionStart[1]];
            }
            if (this.selectionStartLength && this.selectionEnd[1] === this.selectionStart[1]) {
              const e4 = this.selectionStart[0] + this.selectionStartLength;
              return e4 > this._bufferService.cols ? [e4 % this._bufferService.cols, this.selectionStart[1] + Math.floor(e4 / this._bufferService.cols)] : [Math.max(e4, this.selectionEnd[0]), this.selectionEnd[1]];
            }
            return this.selectionEnd;
          }
        }
        areSelectionValuesReversed() {
          const e4 = this.selectionStart, t4 = this.selectionEnd;
          return !(!e4 || !t4) && (e4[1] > t4[1] || e4[1] === t4[1] && e4[0] > t4[0]);
        }
        handleTrim(e4) {
          return this.selectionStart && (this.selectionStart[1] -= e4), this.selectionEnd && (this.selectionEnd[1] -= e4), this.selectionEnd && this.selectionEnd[1] < 0 ? (this.clearSelection(), true) : (this.selectionStart && this.selectionStart[1] < 0 && (this.selectionStart[1] = 0), false);
        }
      };
    }, 428: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CharSizeService = void 0;
      const n2 = i3(2585), o2 = i3(8460), a2 = i3(844);
      let h2 = t3.CharSizeService = class extends a2.Disposable {
        get hasValidSize() {
          return this.width > 0 && this.height > 0;
        }
        constructor(e4, t4, i4) {
          super(), this._optionsService = i4, this.width = 0, this.height = 0, this._onCharSizeChange = this.register(new o2.EventEmitter()), this.onCharSizeChange = this._onCharSizeChange.event;
          try {
            this._measureStrategy = this.register(new d2(this._optionsService));
          } catch {
            this._measureStrategy = this.register(new l2(e4, t4, this._optionsService));
          }
          this.register(this._optionsService.onMultipleOptionChange(["fontFamily", "fontSize"], () => this.measure()));
        }
        measure() {
          const e4 = this._measureStrategy.measure();
          e4.width === this.width && e4.height === this.height || (this.width = e4.width, this.height = e4.height, this._onCharSizeChange.fire());
        }
      };
      t3.CharSizeService = h2 = s3([r2(2, n2.IOptionsService)], h2);
      class c2 extends a2.Disposable {
        static {
          __name(this, "c");
        }
        constructor() {
          super(...arguments), this._result = { width: 0, height: 0 };
        }
        _validateAndSet(e4, t4) {
          void 0 !== e4 && e4 > 0 && void 0 !== t4 && t4 > 0 && (this._result.width = e4, this._result.height = t4);
        }
      }
      class l2 extends c2 {
        static {
          __name(this, "l");
        }
        constructor(e4, t4, i4) {
          super(), this._document = e4, this._parentElement = t4, this._optionsService = i4, this._measureElement = this._document.createElement("span"), this._measureElement.classList.add("xterm-char-measure-element"), this._measureElement.textContent = "W".repeat(32), this._measureElement.setAttribute("aria-hidden", "true"), this._measureElement.style.whiteSpace = "pre", this._measureElement.style.fontKerning = "none", this._parentElement.appendChild(this._measureElement);
        }
        measure() {
          return this._measureElement.style.fontFamily = this._optionsService.rawOptions.fontFamily, this._measureElement.style.fontSize = `${this._optionsService.rawOptions.fontSize}px`, this._validateAndSet(Number(this._measureElement.offsetWidth) / 32, Number(this._measureElement.offsetHeight)), this._result;
        }
      }
      class d2 extends c2 {
        static {
          __name(this, "d");
        }
        constructor(e4) {
          super(), this._optionsService = e4, this._canvas = new OffscreenCanvas(100, 100), this._ctx = this._canvas.getContext("2d");
          const t4 = this._ctx.measureText("W");
          if (!("width" in t4 && "fontBoundingBoxAscent" in t4 && "fontBoundingBoxDescent" in t4)) throw new Error("Required font metrics not supported");
        }
        measure() {
          this._ctx.font = `${this._optionsService.rawOptions.fontSize}px ${this._optionsService.rawOptions.fontFamily}`;
          const e4 = this._ctx.measureText("W");
          return this._validateAndSet(e4.width, e4.fontBoundingBoxAscent + e4.fontBoundingBoxDescent), this._result;
        }
      }
    }, 4269: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CharacterJoinerService = t3.JoinedCellData = void 0;
      const n2 = i3(3734), o2 = i3(643), a2 = i3(511), h2 = i3(2585);
      class c2 extends n2.AttributeData {
        static {
          __name(this, "c");
        }
        constructor(e4, t4, i4) {
          super(), this.content = 0, this.combinedData = "", this.fg = e4.fg, this.bg = e4.bg, this.combinedData = t4, this._width = i4;
        }
        isCombined() {
          return 2097152;
        }
        getWidth() {
          return this._width;
        }
        getChars() {
          return this.combinedData;
        }
        getCode() {
          return 2097151;
        }
        setFromCharData(e4) {
          throw new Error("not implemented");
        }
        getAsCharData() {
          return [this.fg, this.getChars(), this.getWidth(), this.getCode()];
        }
      }
      t3.JoinedCellData = c2;
      let l2 = t3.CharacterJoinerService = class e4 {
        static {
          __name(this, "e");
        }
        constructor(e5) {
          this._bufferService = e5, this._characterJoiners = [], this._nextCharacterJoinerId = 0, this._workCell = new a2.CellData();
        }
        register(e5) {
          const t4 = { id: this._nextCharacterJoinerId++, handler: e5 };
          return this._characterJoiners.push(t4), t4.id;
        }
        deregister(e5) {
          for (let t4 = 0; t4 < this._characterJoiners.length; t4++) if (this._characterJoiners[t4].id === e5) return this._characterJoiners.splice(t4, 1), true;
          return false;
        }
        getJoinedCharacters(e5) {
          if (0 === this._characterJoiners.length) return [];
          const t4 = this._bufferService.buffer.lines.get(e5);
          if (!t4 || 0 === t4.length) return [];
          const i4 = [], s4 = t4.translateToString(true);
          let r3 = 0, n3 = 0, a3 = 0, h3 = t4.getFg(0), c3 = t4.getBg(0);
          for (let e6 = 0; e6 < t4.getTrimmedLength(); e6++) if (t4.loadCell(e6, this._workCell), 0 !== this._workCell.getWidth()) {
            if (this._workCell.fg !== h3 || this._workCell.bg !== c3) {
              if (e6 - r3 > 1) {
                const e7 = this._getJoinedRanges(s4, a3, n3, t4, r3);
                for (let t5 = 0; t5 < e7.length; t5++) i4.push(e7[t5]);
              }
              r3 = e6, a3 = n3, h3 = this._workCell.fg, c3 = this._workCell.bg;
            }
            n3 += this._workCell.getChars().length || o2.WHITESPACE_CELL_CHAR.length;
          }
          if (this._bufferService.cols - r3 > 1) {
            const e6 = this._getJoinedRanges(s4, a3, n3, t4, r3);
            for (let t5 = 0; t5 < e6.length; t5++) i4.push(e6[t5]);
          }
          return i4;
        }
        _getJoinedRanges(t4, i4, s4, r3, n3) {
          const o3 = t4.substring(i4, s4);
          let a3 = [];
          try {
            a3 = this._characterJoiners[0].handler(o3);
          } catch (e5) {
            console.error(e5);
          }
          for (let t5 = 1; t5 < this._characterJoiners.length; t5++) try {
            const i5 = this._characterJoiners[t5].handler(o3);
            for (let t6 = 0; t6 < i5.length; t6++) e4._mergeRanges(a3, i5[t6]);
          } catch (e5) {
            console.error(e5);
          }
          return this._stringRangesToCellRanges(a3, r3, n3), a3;
        }
        _stringRangesToCellRanges(e5, t4, i4) {
          let s4 = 0, r3 = false, n3 = 0, a3 = e5[s4];
          if (a3) {
            for (let h3 = i4; h3 < this._bufferService.cols; h3++) {
              const i5 = t4.getWidth(h3), c3 = t4.getString(h3).length || o2.WHITESPACE_CELL_CHAR.length;
              if (0 !== i5) {
                if (!r3 && a3[0] <= n3 && (a3[0] = h3, r3 = true), a3[1] <= n3) {
                  if (a3[1] = h3, a3 = e5[++s4], !a3) break;
                  a3[0] <= n3 ? (a3[0] = h3, r3 = true) : r3 = false;
                }
                n3 += c3;
              }
            }
            a3 && (a3[1] = this._bufferService.cols);
          }
        }
        static _mergeRanges(e5, t4) {
          let i4 = false;
          for (let s4 = 0; s4 < e5.length; s4++) {
            const r3 = e5[s4];
            if (i4) {
              if (t4[1] <= r3[0]) return e5[s4 - 1][1] = t4[1], e5;
              if (t4[1] <= r3[1]) return e5[s4 - 1][1] = Math.max(t4[1], r3[1]), e5.splice(s4, 1), e5;
              e5.splice(s4, 1), s4--;
            } else {
              if (t4[1] <= r3[0]) return e5.splice(s4, 0, t4), e5;
              if (t4[1] <= r3[1]) return r3[0] = Math.min(t4[0], r3[0]), e5;
              t4[0] < r3[1] && (r3[0] = Math.min(t4[0], r3[0]), i4 = true);
            }
          }
          return i4 ? e5[e5.length - 1][1] = t4[1] : e5.push(t4), e5;
        }
      };
      t3.CharacterJoinerService = l2 = s3([r2(0, h2.IBufferService)], l2);
    }, 5114: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CoreBrowserService = void 0;
      const s3 = i3(844), r2 = i3(8460), n2 = i3(3656);
      class o2 extends s3.Disposable {
        static {
          __name(this, "o");
        }
        constructor(e4, t4, i4) {
          super(), this._textarea = e4, this._window = t4, this.mainDocument = i4, this._isFocused = false, this._cachedIsFocused = void 0, this._screenDprMonitor = new a2(this._window), this._onDprChange = this.register(new r2.EventEmitter()), this.onDprChange = this._onDprChange.event, this._onWindowChange = this.register(new r2.EventEmitter()), this.onWindowChange = this._onWindowChange.event, this.register(this.onWindowChange((e5) => this._screenDprMonitor.setWindow(e5))), this.register((0, r2.forwardEvent)(this._screenDprMonitor.onDprChange, this._onDprChange)), this._textarea.addEventListener("focus", () => this._isFocused = true), this._textarea.addEventListener("blur", () => this._isFocused = false);
        }
        get window() {
          return this._window;
        }
        set window(e4) {
          this._window !== e4 && (this._window = e4, this._onWindowChange.fire(this._window));
        }
        get dpr() {
          return this.window.devicePixelRatio;
        }
        get isFocused() {
          return void 0 === this._cachedIsFocused && (this._cachedIsFocused = this._isFocused && this._textarea.ownerDocument.hasFocus(), queueMicrotask(() => this._cachedIsFocused = void 0)), this._cachedIsFocused;
        }
      }
      t3.CoreBrowserService = o2;
      class a2 extends s3.Disposable {
        static {
          __name(this, "a");
        }
        constructor(e4) {
          super(), this._parentWindow = e4, this._windowResizeListener = this.register(new s3.MutableDisposable()), this._onDprChange = this.register(new r2.EventEmitter()), this.onDprChange = this._onDprChange.event, this._outerListener = () => this._setDprAndFireIfDiffers(), this._currentDevicePixelRatio = this._parentWindow.devicePixelRatio, this._updateDpr(), this._setWindowResizeListener(), this.register((0, s3.toDisposable)(() => this.clearListener()));
        }
        setWindow(e4) {
          this._parentWindow = e4, this._setWindowResizeListener(), this._setDprAndFireIfDiffers();
        }
        _setWindowResizeListener() {
          this._windowResizeListener.value = (0, n2.addDisposableDomListener)(this._parentWindow, "resize", () => this._setDprAndFireIfDiffers());
        }
        _setDprAndFireIfDiffers() {
          this._parentWindow.devicePixelRatio !== this._currentDevicePixelRatio && this._onDprChange.fire(this._parentWindow.devicePixelRatio), this._updateDpr();
        }
        _updateDpr() {
          this._outerListener && (this._resolutionMediaMatchList?.removeListener(this._outerListener), this._currentDevicePixelRatio = this._parentWindow.devicePixelRatio, this._resolutionMediaMatchList = this._parentWindow.matchMedia(`screen and (resolution: ${this._parentWindow.devicePixelRatio}dppx)`), this._resolutionMediaMatchList.addListener(this._outerListener));
        }
        clearListener() {
          this._resolutionMediaMatchList && this._outerListener && (this._resolutionMediaMatchList.removeListener(this._outerListener), this._resolutionMediaMatchList = void 0, this._outerListener = void 0);
        }
      }
    }, 779: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.LinkProviderService = void 0;
      const s3 = i3(844);
      class r2 extends s3.Disposable {
        static {
          __name(this, "r");
        }
        constructor() {
          super(), this.linkProviders = [], this.register((0, s3.toDisposable)(() => this.linkProviders.length = 0));
        }
        registerLinkProvider(e4) {
          return this.linkProviders.push(e4), { dispose: /* @__PURE__ */ __name(() => {
            const t4 = this.linkProviders.indexOf(e4);
            -1 !== t4 && this.linkProviders.splice(t4, 1);
          }, "dispose") };
        }
      }
      t3.LinkProviderService = r2;
    }, 8934: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.MouseService = void 0;
      const n2 = i3(4725), o2 = i3(9806);
      let a2 = t3.MouseService = class {
        constructor(e4, t4) {
          this._renderService = e4, this._charSizeService = t4;
        }
        getCoords(e4, t4, i4, s4, r3) {
          return (0, o2.getCoords)(window, e4, t4, i4, s4, this._charSizeService.hasValidSize, this._renderService.dimensions.css.cell.width, this._renderService.dimensions.css.cell.height, r3);
        }
        getMouseReportCoords(e4, t4) {
          const i4 = (0, o2.getCoordsRelativeToElement)(window, e4, t4);
          if (this._charSizeService.hasValidSize) return i4[0] = Math.min(Math.max(i4[0], 0), this._renderService.dimensions.css.canvas.width - 1), i4[1] = Math.min(Math.max(i4[1], 0), this._renderService.dimensions.css.canvas.height - 1), { col: Math.floor(i4[0] / this._renderService.dimensions.css.cell.width), row: Math.floor(i4[1] / this._renderService.dimensions.css.cell.height), x: Math.floor(i4[0]), y: Math.floor(i4[1]) };
        }
      };
      t3.MouseService = a2 = s3([r2(0, n2.IRenderService), r2(1, n2.ICharSizeService)], a2);
    }, 3230: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.RenderService = void 0;
      const n2 = i3(6193), o2 = i3(4725), a2 = i3(8460), h2 = i3(844), c2 = i3(7226), l2 = i3(2585);
      let d2 = t3.RenderService = class extends h2.Disposable {
        get dimensions() {
          return this._renderer.value.dimensions;
        }
        constructor(e4, t4, i4, s4, r3, o3, l3, d3) {
          super(), this._rowCount = e4, this._charSizeService = s4, this._renderer = this.register(new h2.MutableDisposable()), this._pausedResizeTask = new c2.DebouncedIdleTask(), this._observerDisposable = this.register(new h2.MutableDisposable()), this._isPaused = false, this._needsFullRefresh = false, this._isNextRenderRedrawOnly = true, this._needsSelectionRefresh = false, this._canvasWidth = 0, this._canvasHeight = 0, this._selectionState = { start: void 0, end: void 0, columnSelectMode: false }, this._onDimensionsChange = this.register(new a2.EventEmitter()), this.onDimensionsChange = this._onDimensionsChange.event, this._onRenderedViewportChange = this.register(new a2.EventEmitter()), this.onRenderedViewportChange = this._onRenderedViewportChange.event, this._onRender = this.register(new a2.EventEmitter()), this.onRender = this._onRender.event, this._onRefreshRequest = this.register(new a2.EventEmitter()), this.onRefreshRequest = this._onRefreshRequest.event, this._renderDebouncer = new n2.RenderDebouncer((e5, t5) => this._renderRows(e5, t5), l3), this.register(this._renderDebouncer), this.register(l3.onDprChange(() => this.handleDevicePixelRatioChange())), this.register(o3.onResize(() => this._fullRefresh())), this.register(o3.buffers.onBufferActivate(() => this._renderer.value?.clear())), this.register(i4.onOptionChange(() => this._handleOptionsChanged())), this.register(this._charSizeService.onCharSizeChange(() => this.handleCharSizeChanged())), this.register(r3.onDecorationRegistered(() => this._fullRefresh())), this.register(r3.onDecorationRemoved(() => this._fullRefresh())), this.register(i4.onMultipleOptionChange(["customGlyphs", "drawBoldTextInBrightColors", "letterSpacing", "lineHeight", "fontFamily", "fontSize", "fontWeight", "fontWeightBold", "minimumContrastRatio", "rescaleOverlappingGlyphs"], () => {
            this.clear(), this.handleResize(o3.cols, o3.rows), this._fullRefresh();
          })), this.register(i4.onMultipleOptionChange(["cursorBlink", "cursorStyle"], () => this.refreshRows(o3.buffer.y, o3.buffer.y, true))), this.register(d3.onChangeColors(() => this._fullRefresh())), this._registerIntersectionObserver(l3.window, t4), this.register(l3.onWindowChange((e5) => this._registerIntersectionObserver(e5, t4)));
        }
        _registerIntersectionObserver(e4, t4) {
          if ("IntersectionObserver" in e4) {
            const i4 = new e4.IntersectionObserver((e5) => this._handleIntersectionChange(e5[e5.length - 1]), { threshold: 0 });
            i4.observe(t4), this._observerDisposable.value = (0, h2.toDisposable)(() => i4.disconnect());
          }
        }
        _handleIntersectionChange(e4) {
          this._isPaused = void 0 === e4.isIntersecting ? 0 === e4.intersectionRatio : !e4.isIntersecting, this._isPaused || this._charSizeService.hasValidSize || this._charSizeService.measure(), !this._isPaused && this._needsFullRefresh && (this._pausedResizeTask.flush(), this.refreshRows(0, this._rowCount - 1), this._needsFullRefresh = false);
        }
        refreshRows(e4, t4, i4 = false) {
          this._isPaused ? this._needsFullRefresh = true : (i4 || (this._isNextRenderRedrawOnly = false), this._renderDebouncer.refresh(e4, t4, this._rowCount));
        }
        _renderRows(e4, t4) {
          this._renderer.value && (e4 = Math.min(e4, this._rowCount - 1), t4 = Math.min(t4, this._rowCount - 1), this._renderer.value.renderRows(e4, t4), this._needsSelectionRefresh && (this._renderer.value.handleSelectionChanged(this._selectionState.start, this._selectionState.end, this._selectionState.columnSelectMode), this._needsSelectionRefresh = false), this._isNextRenderRedrawOnly || this._onRenderedViewportChange.fire({ start: e4, end: t4 }), this._onRender.fire({ start: e4, end: t4 }), this._isNextRenderRedrawOnly = true);
        }
        resize(e4, t4) {
          this._rowCount = t4, this._fireOnCanvasResize();
        }
        _handleOptionsChanged() {
          this._renderer.value && (this.refreshRows(0, this._rowCount - 1), this._fireOnCanvasResize());
        }
        _fireOnCanvasResize() {
          this._renderer.value && (this._renderer.value.dimensions.css.canvas.width === this._canvasWidth && this._renderer.value.dimensions.css.canvas.height === this._canvasHeight || this._onDimensionsChange.fire(this._renderer.value.dimensions));
        }
        hasRenderer() {
          return !!this._renderer.value;
        }
        setRenderer(e4) {
          this._renderer.value = e4, this._renderer.value && (this._renderer.value.onRequestRedraw((e5) => this.refreshRows(e5.start, e5.end, true)), this._needsSelectionRefresh = true, this._fullRefresh());
        }
        addRefreshCallback(e4) {
          return this._renderDebouncer.addRefreshCallback(e4);
        }
        _fullRefresh() {
          this._isPaused ? this._needsFullRefresh = true : this.refreshRows(0, this._rowCount - 1);
        }
        clearTextureAtlas() {
          this._renderer.value && (this._renderer.value.clearTextureAtlas?.(), this._fullRefresh());
        }
        handleDevicePixelRatioChange() {
          this._charSizeService.measure(), this._renderer.value && (this._renderer.value.handleDevicePixelRatioChange(), this.refreshRows(0, this._rowCount - 1));
        }
        handleResize(e4, t4) {
          this._renderer.value && (this._isPaused ? this._pausedResizeTask.set(() => this._renderer.value?.handleResize(e4, t4)) : this._renderer.value.handleResize(e4, t4), this._fullRefresh());
        }
        handleCharSizeChanged() {
          this._renderer.value?.handleCharSizeChanged();
        }
        handleBlur() {
          this._renderer.value?.handleBlur();
        }
        handleFocus() {
          this._renderer.value?.handleFocus();
        }
        handleSelectionChanged(e4, t4, i4) {
          this._selectionState.start = e4, this._selectionState.end = t4, this._selectionState.columnSelectMode = i4, this._renderer.value?.handleSelectionChanged(e4, t4, i4);
        }
        handleCursorMove() {
          this._renderer.value?.handleCursorMove();
        }
        clear() {
          this._renderer.value?.clear();
        }
      };
      t3.RenderService = d2 = s3([r2(2, l2.IOptionsService), r2(3, o2.ICharSizeService), r2(4, l2.IDecorationService), r2(5, l2.IBufferService), r2(6, o2.ICoreBrowserService), r2(7, o2.IThemeService)], d2);
    }, 9312: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.SelectionService = void 0;
      const n2 = i3(9806), o2 = i3(9504), a2 = i3(456), h2 = i3(4725), c2 = i3(8460), l2 = i3(844), d2 = i3(6114), _2 = i3(4841), u2 = i3(511), f2 = i3(2585), v2 = String.fromCharCode(160), p2 = new RegExp(v2, "g");
      let g2 = t3.SelectionService = class extends l2.Disposable {
        constructor(e4, t4, i4, s4, r3, n3, o3, h3, d3) {
          super(), this._element = e4, this._screenElement = t4, this._linkifier = i4, this._bufferService = s4, this._coreService = r3, this._mouseService = n3, this._optionsService = o3, this._renderService = h3, this._coreBrowserService = d3, this._dragScrollAmount = 0, this._enabled = true, this._workCell = new u2.CellData(), this._mouseDownTimeStamp = 0, this._oldHasSelection = false, this._oldSelectionStart = void 0, this._oldSelectionEnd = void 0, this._onLinuxMouseSelection = this.register(new c2.EventEmitter()), this.onLinuxMouseSelection = this._onLinuxMouseSelection.event, this._onRedrawRequest = this.register(new c2.EventEmitter()), this.onRequestRedraw = this._onRedrawRequest.event, this._onSelectionChange = this.register(new c2.EventEmitter()), this.onSelectionChange = this._onSelectionChange.event, this._onRequestScrollLines = this.register(new c2.EventEmitter()), this.onRequestScrollLines = this._onRequestScrollLines.event, this._mouseMoveListener = (e5) => this._handleMouseMove(e5), this._mouseUpListener = (e5) => this._handleMouseUp(e5), this._coreService.onUserInput(() => {
            this.hasSelection && this.clearSelection();
          }), this._trimListener = this._bufferService.buffer.lines.onTrim((e5) => this._handleTrim(e5)), this.register(this._bufferService.buffers.onBufferActivate((e5) => this._handleBufferActivate(e5))), this.enable(), this._model = new a2.SelectionModel(this._bufferService), this._activeSelectionMode = 0, this.register((0, l2.toDisposable)(() => {
            this._removeMouseDownListeners();
          }));
        }
        reset() {
          this.clearSelection();
        }
        disable() {
          this.clearSelection(), this._enabled = false;
        }
        enable() {
          this._enabled = true;
        }
        get selectionStart() {
          return this._model.finalSelectionStart;
        }
        get selectionEnd() {
          return this._model.finalSelectionEnd;
        }
        get hasSelection() {
          const e4 = this._model.finalSelectionStart, t4 = this._model.finalSelectionEnd;
          return !(!e4 || !t4 || e4[0] === t4[0] && e4[1] === t4[1]);
        }
        get selectionText() {
          const e4 = this._model.finalSelectionStart, t4 = this._model.finalSelectionEnd;
          if (!e4 || !t4) return "";
          const i4 = this._bufferService.buffer, s4 = [];
          if (3 === this._activeSelectionMode) {
            if (e4[0] === t4[0]) return "";
            const r3 = e4[0] < t4[0] ? e4[0] : t4[0], n3 = e4[0] < t4[0] ? t4[0] : e4[0];
            for (let o3 = e4[1]; o3 <= t4[1]; o3++) {
              const e5 = i4.translateBufferLineToString(o3, true, r3, n3);
              s4.push(e5);
            }
          } else {
            const r3 = e4[1] === t4[1] ? t4[0] : void 0;
            s4.push(i4.translateBufferLineToString(e4[1], true, e4[0], r3));
            for (let r4 = e4[1] + 1; r4 <= t4[1] - 1; r4++) {
              const e5 = i4.lines.get(r4), t5 = i4.translateBufferLineToString(r4, true);
              e5?.isWrapped ? s4[s4.length - 1] += t5 : s4.push(t5);
            }
            if (e4[1] !== t4[1]) {
              const e5 = i4.lines.get(t4[1]), r4 = i4.translateBufferLineToString(t4[1], true, 0, t4[0]);
              e5 && e5.isWrapped ? s4[s4.length - 1] += r4 : s4.push(r4);
            }
          }
          return s4.map((e5) => e5.replace(p2, " ")).join(d2.isWindows ? "\r\n" : "\n");
        }
        clearSelection() {
          this._model.clearSelection(), this._removeMouseDownListeners(), this.refresh(), this._onSelectionChange.fire();
        }
        refresh(e4) {
          this._refreshAnimationFrame || (this._refreshAnimationFrame = this._coreBrowserService.window.requestAnimationFrame(() => this._refresh())), d2.isLinux && e4 && this.selectionText.length && this._onLinuxMouseSelection.fire(this.selectionText);
        }
        _refresh() {
          this._refreshAnimationFrame = void 0, this._onRedrawRequest.fire({ start: this._model.finalSelectionStart, end: this._model.finalSelectionEnd, columnSelectMode: 3 === this._activeSelectionMode });
        }
        _isClickInSelection(e4) {
          const t4 = this._getMouseBufferCoords(e4), i4 = this._model.finalSelectionStart, s4 = this._model.finalSelectionEnd;
          return !!(i4 && s4 && t4) && this._areCoordsInSelection(t4, i4, s4);
        }
        isCellInSelection(e4, t4) {
          const i4 = this._model.finalSelectionStart, s4 = this._model.finalSelectionEnd;
          return !(!i4 || !s4) && this._areCoordsInSelection([e4, t4], i4, s4);
        }
        _areCoordsInSelection(e4, t4, i4) {
          return e4[1] > t4[1] && e4[1] < i4[1] || t4[1] === i4[1] && e4[1] === t4[1] && e4[0] >= t4[0] && e4[0] < i4[0] || t4[1] < i4[1] && e4[1] === i4[1] && e4[0] < i4[0] || t4[1] < i4[1] && e4[1] === t4[1] && e4[0] >= t4[0];
        }
        _selectWordAtCursor(e4, t4) {
          const i4 = this._linkifier.currentLink?.link?.range;
          if (i4) return this._model.selectionStart = [i4.start.x - 1, i4.start.y - 1], this._model.selectionStartLength = (0, _2.getRangeLength)(i4, this._bufferService.cols), this._model.selectionEnd = void 0, true;
          const s4 = this._getMouseBufferCoords(e4);
          return !!s4 && (this._selectWordAt(s4, t4), this._model.selectionEnd = void 0, true);
        }
        selectAll() {
          this._model.isSelectAllActive = true, this.refresh(), this._onSelectionChange.fire();
        }
        selectLines(e4, t4) {
          this._model.clearSelection(), e4 = Math.max(e4, 0), t4 = Math.min(t4, this._bufferService.buffer.lines.length - 1), this._model.selectionStart = [0, e4], this._model.selectionEnd = [this._bufferService.cols, t4], this.refresh(), this._onSelectionChange.fire();
        }
        _handleTrim(e4) {
          this._model.handleTrim(e4) && this.refresh();
        }
        _getMouseBufferCoords(e4) {
          const t4 = this._mouseService.getCoords(e4, this._screenElement, this._bufferService.cols, this._bufferService.rows, true);
          if (t4) return t4[0]--, t4[1]--, t4[1] += this._bufferService.buffer.ydisp, t4;
        }
        _getMouseEventScrollAmount(e4) {
          let t4 = (0, n2.getCoordsRelativeToElement)(this._coreBrowserService.window, e4, this._screenElement)[1];
          const i4 = this._renderService.dimensions.css.canvas.height;
          return t4 >= 0 && t4 <= i4 ? 0 : (t4 > i4 && (t4 -= i4), t4 = Math.min(Math.max(t4, -50), 50), t4 /= 50, t4 / Math.abs(t4) + Math.round(14 * t4));
        }
        shouldForceSelection(e4) {
          return d2.isMac ? e4.altKey && this._optionsService.rawOptions.macOptionClickForcesSelection : e4.shiftKey;
        }
        handleMouseDown(e4) {
          if (this._mouseDownTimeStamp = e4.timeStamp, (2 !== e4.button || !this.hasSelection) && 0 === e4.button) {
            if (!this._enabled) {
              if (!this.shouldForceSelection(e4)) return;
              e4.stopPropagation();
            }
            e4.preventDefault(), this._dragScrollAmount = 0, this._enabled && e4.shiftKey ? this._handleIncrementalClick(e4) : 1 === e4.detail ? this._handleSingleClick(e4) : 2 === e4.detail ? this._handleDoubleClick(e4) : 3 === e4.detail && this._handleTripleClick(e4), this._addMouseDownListeners(), this.refresh(true);
          }
        }
        _addMouseDownListeners() {
          this._screenElement.ownerDocument && (this._screenElement.ownerDocument.addEventListener("mousemove", this._mouseMoveListener), this._screenElement.ownerDocument.addEventListener("mouseup", this._mouseUpListener)), this._dragScrollIntervalTimer = this._coreBrowserService.window.setInterval(() => this._dragScroll(), 50);
        }
        _removeMouseDownListeners() {
          this._screenElement.ownerDocument && (this._screenElement.ownerDocument.removeEventListener("mousemove", this._mouseMoveListener), this._screenElement.ownerDocument.removeEventListener("mouseup", this._mouseUpListener)), this._coreBrowserService.window.clearInterval(this._dragScrollIntervalTimer), this._dragScrollIntervalTimer = void 0;
        }
        _handleIncrementalClick(e4) {
          this._model.selectionStart && (this._model.selectionEnd = this._getMouseBufferCoords(e4));
        }
        _handleSingleClick(e4) {
          if (this._model.selectionStartLength = 0, this._model.isSelectAllActive = false, this._activeSelectionMode = this.shouldColumnSelect(e4) ? 3 : 0, this._model.selectionStart = this._getMouseBufferCoords(e4), !this._model.selectionStart) return;
          this._model.selectionEnd = void 0;
          const t4 = this._bufferService.buffer.lines.get(this._model.selectionStart[1]);
          t4 && t4.length !== this._model.selectionStart[0] && 0 === t4.hasWidth(this._model.selectionStart[0]) && this._model.selectionStart[0]++;
        }
        _handleDoubleClick(e4) {
          this._selectWordAtCursor(e4, true) && (this._activeSelectionMode = 1);
        }
        _handleTripleClick(e4) {
          const t4 = this._getMouseBufferCoords(e4);
          t4 && (this._activeSelectionMode = 2, this._selectLineAt(t4[1]));
        }
        shouldColumnSelect(e4) {
          return e4.altKey && !(d2.isMac && this._optionsService.rawOptions.macOptionClickForcesSelection);
        }
        _handleMouseMove(e4) {
          if (e4.stopImmediatePropagation(), !this._model.selectionStart) return;
          const t4 = this._model.selectionEnd ? [this._model.selectionEnd[0], this._model.selectionEnd[1]] : null;
          if (this._model.selectionEnd = this._getMouseBufferCoords(e4), !this._model.selectionEnd) return void this.refresh(true);
          2 === this._activeSelectionMode ? this._model.selectionEnd[1] < this._model.selectionStart[1] ? this._model.selectionEnd[0] = 0 : this._model.selectionEnd[0] = this._bufferService.cols : 1 === this._activeSelectionMode && this._selectToWordAt(this._model.selectionEnd), this._dragScrollAmount = this._getMouseEventScrollAmount(e4), 3 !== this._activeSelectionMode && (this._dragScrollAmount > 0 ? this._model.selectionEnd[0] = this._bufferService.cols : this._dragScrollAmount < 0 && (this._model.selectionEnd[0] = 0));
          const i4 = this._bufferService.buffer;
          if (this._model.selectionEnd[1] < i4.lines.length) {
            const e5 = i4.lines.get(this._model.selectionEnd[1]);
            e5 && 0 === e5.hasWidth(this._model.selectionEnd[0]) && this._model.selectionEnd[0] < this._bufferService.cols && this._model.selectionEnd[0]++;
          }
          t4 && t4[0] === this._model.selectionEnd[0] && t4[1] === this._model.selectionEnd[1] || this.refresh(true);
        }
        _dragScroll() {
          if (this._model.selectionEnd && this._model.selectionStart && this._dragScrollAmount) {
            this._onRequestScrollLines.fire({ amount: this._dragScrollAmount, suppressScrollEvent: false });
            const e4 = this._bufferService.buffer;
            this._dragScrollAmount > 0 ? (3 !== this._activeSelectionMode && (this._model.selectionEnd[0] = this._bufferService.cols), this._model.selectionEnd[1] = Math.min(e4.ydisp + this._bufferService.rows, e4.lines.length - 1)) : (3 !== this._activeSelectionMode && (this._model.selectionEnd[0] = 0), this._model.selectionEnd[1] = e4.ydisp), this.refresh();
          }
        }
        _handleMouseUp(e4) {
          const t4 = e4.timeStamp - this._mouseDownTimeStamp;
          if (this._removeMouseDownListeners(), this.selectionText.length <= 1 && t4 < 500 && e4.altKey && this._optionsService.rawOptions.altClickMovesCursor) {
            if (this._bufferService.buffer.ybase === this._bufferService.buffer.ydisp) {
              const t5 = this._mouseService.getCoords(e4, this._element, this._bufferService.cols, this._bufferService.rows, false);
              if (t5 && void 0 !== t5[0] && void 0 !== t5[1]) {
                const e5 = (0, o2.moveToCellSequence)(t5[0] - 1, t5[1] - 1, this._bufferService, this._coreService.decPrivateModes.applicationCursorKeys);
                this._coreService.triggerDataEvent(e5, true);
              }
            }
          } else this._fireEventIfSelectionChanged();
        }
        _fireEventIfSelectionChanged() {
          const e4 = this._model.finalSelectionStart, t4 = this._model.finalSelectionEnd, i4 = !(!e4 || !t4 || e4[0] === t4[0] && e4[1] === t4[1]);
          i4 ? e4 && t4 && (this._oldSelectionStart && this._oldSelectionEnd && e4[0] === this._oldSelectionStart[0] && e4[1] === this._oldSelectionStart[1] && t4[0] === this._oldSelectionEnd[0] && t4[1] === this._oldSelectionEnd[1] || this._fireOnSelectionChange(e4, t4, i4)) : this._oldHasSelection && this._fireOnSelectionChange(e4, t4, i4);
        }
        _fireOnSelectionChange(e4, t4, i4) {
          this._oldSelectionStart = e4, this._oldSelectionEnd = t4, this._oldHasSelection = i4, this._onSelectionChange.fire();
        }
        _handleBufferActivate(e4) {
          this.clearSelection(), this._trimListener.dispose(), this._trimListener = e4.activeBuffer.lines.onTrim((e5) => this._handleTrim(e5));
        }
        _convertViewportColToCharacterIndex(e4, t4) {
          let i4 = t4;
          for (let s4 = 0; t4 >= s4; s4++) {
            const r3 = e4.loadCell(s4, this._workCell).getChars().length;
            0 === this._workCell.getWidth() ? i4-- : r3 > 1 && t4 !== s4 && (i4 += r3 - 1);
          }
          return i4;
        }
        setSelection(e4, t4, i4) {
          this._model.clearSelection(), this._removeMouseDownListeners(), this._model.selectionStart = [e4, t4], this._model.selectionStartLength = i4, this.refresh(), this._fireEventIfSelectionChanged();
        }
        rightClickSelect(e4) {
          this._isClickInSelection(e4) || (this._selectWordAtCursor(e4, false) && this.refresh(true), this._fireEventIfSelectionChanged());
        }
        _getWordAt(e4, t4, i4 = true, s4 = true) {
          if (e4[0] >= this._bufferService.cols) return;
          const r3 = this._bufferService.buffer, n3 = r3.lines.get(e4[1]);
          if (!n3) return;
          const o3 = r3.translateBufferLineToString(e4[1], false);
          let a3 = this._convertViewportColToCharacterIndex(n3, e4[0]), h3 = a3;
          const c3 = e4[0] - a3;
          let l3 = 0, d3 = 0, _3 = 0, u3 = 0;
          if (" " === o3.charAt(a3)) {
            for (; a3 > 0 && " " === o3.charAt(a3 - 1); ) a3--;
            for (; h3 < o3.length && " " === o3.charAt(h3 + 1); ) h3++;
          } else {
            let t5 = e4[0], i5 = e4[0];
            0 === n3.getWidth(t5) && (l3++, t5--), 2 === n3.getWidth(i5) && (d3++, i5++);
            const s5 = n3.getString(i5).length;
            for (s5 > 1 && (u3 += s5 - 1, h3 += s5 - 1); t5 > 0 && a3 > 0 && !this._isCharWordSeparator(n3.loadCell(t5 - 1, this._workCell)); ) {
              n3.loadCell(t5 - 1, this._workCell);
              const e5 = this._workCell.getChars().length;
              0 === this._workCell.getWidth() ? (l3++, t5--) : e5 > 1 && (_3 += e5 - 1, a3 -= e5 - 1), a3--, t5--;
            }
            for (; i5 < n3.length && h3 + 1 < o3.length && !this._isCharWordSeparator(n3.loadCell(i5 + 1, this._workCell)); ) {
              n3.loadCell(i5 + 1, this._workCell);
              const e5 = this._workCell.getChars().length;
              2 === this._workCell.getWidth() ? (d3++, i5++) : e5 > 1 && (u3 += e5 - 1, h3 += e5 - 1), h3++, i5++;
            }
          }
          h3++;
          let f3 = a3 + c3 - l3 + _3, v3 = Math.min(this._bufferService.cols, h3 - a3 + l3 + d3 - _3 - u3);
          if (t4 || "" !== o3.slice(a3, h3).trim()) {
            if (i4 && 0 === f3 && 32 !== n3.getCodePoint(0)) {
              const t5 = r3.lines.get(e4[1] - 1);
              if (t5 && n3.isWrapped && 32 !== t5.getCodePoint(this._bufferService.cols - 1)) {
                const t6 = this._getWordAt([this._bufferService.cols - 1, e4[1] - 1], false, true, false);
                if (t6) {
                  const e5 = this._bufferService.cols - t6.start;
                  f3 -= e5, v3 += e5;
                }
              }
            }
            if (s4 && f3 + v3 === this._bufferService.cols && 32 !== n3.getCodePoint(this._bufferService.cols - 1)) {
              const t5 = r3.lines.get(e4[1] + 1);
              if (t5?.isWrapped && 32 !== t5.getCodePoint(0)) {
                const t6 = this._getWordAt([0, e4[1] + 1], false, false, true);
                t6 && (v3 += t6.length);
              }
            }
            return { start: f3, length: v3 };
          }
        }
        _selectWordAt(e4, t4) {
          const i4 = this._getWordAt(e4, t4);
          if (i4) {
            for (; i4.start < 0; ) i4.start += this._bufferService.cols, e4[1]--;
            this._model.selectionStart = [i4.start, e4[1]], this._model.selectionStartLength = i4.length;
          }
        }
        _selectToWordAt(e4) {
          const t4 = this._getWordAt(e4, true);
          if (t4) {
            let i4 = e4[1];
            for (; t4.start < 0; ) t4.start += this._bufferService.cols, i4--;
            if (!this._model.areSelectionValuesReversed()) for (; t4.start + t4.length > this._bufferService.cols; ) t4.length -= this._bufferService.cols, i4++;
            this._model.selectionEnd = [this._model.areSelectionValuesReversed() ? t4.start : t4.start + t4.length, i4];
          }
        }
        _isCharWordSeparator(e4) {
          return 0 !== e4.getWidth() && this._optionsService.rawOptions.wordSeparator.indexOf(e4.getChars()) >= 0;
        }
        _selectLineAt(e4) {
          const t4 = this._bufferService.buffer.getWrappedRangeForLine(e4), i4 = { start: { x: 0, y: t4.first }, end: { x: this._bufferService.cols - 1, y: t4.last } };
          this._model.selectionStart = [0, t4.first], this._model.selectionEnd = void 0, this._model.selectionStartLength = (0, _2.getRangeLength)(i4, this._bufferService.cols);
        }
      };
      t3.SelectionService = g2 = s3([r2(3, f2.IBufferService), r2(4, f2.ICoreService), r2(5, h2.IMouseService), r2(6, f2.IOptionsService), r2(7, h2.IRenderService), r2(8, h2.ICoreBrowserService)], g2);
    }, 4725: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ILinkProviderService = t3.IThemeService = t3.ICharacterJoinerService = t3.ISelectionService = t3.IRenderService = t3.IMouseService = t3.ICoreBrowserService = t3.ICharSizeService = void 0;
      const s3 = i3(8343);
      t3.ICharSizeService = (0, s3.createDecorator)("CharSizeService"), t3.ICoreBrowserService = (0, s3.createDecorator)("CoreBrowserService"), t3.IMouseService = (0, s3.createDecorator)("MouseService"), t3.IRenderService = (0, s3.createDecorator)("RenderService"), t3.ISelectionService = (0, s3.createDecorator)("SelectionService"), t3.ICharacterJoinerService = (0, s3.createDecorator)("CharacterJoinerService"), t3.IThemeService = (0, s3.createDecorator)("ThemeService"), t3.ILinkProviderService = (0, s3.createDecorator)("LinkProviderService");
    }, 6731: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ThemeService = t3.DEFAULT_ANSI_COLORS = void 0;
      const n2 = i3(7239), o2 = i3(8055), a2 = i3(8460), h2 = i3(844), c2 = i3(2585), l2 = o2.css.toColor("#ffffff"), d2 = o2.css.toColor("#000000"), _2 = o2.css.toColor("#ffffff"), u2 = o2.css.toColor("#000000"), f2 = { css: "rgba(255, 255, 255, 0.3)", rgba: 4294967117 };
      t3.DEFAULT_ANSI_COLORS = Object.freeze((() => {
        const e4 = [o2.css.toColor("#2e3436"), o2.css.toColor("#cc0000"), o2.css.toColor("#4e9a06"), o2.css.toColor("#c4a000"), o2.css.toColor("#3465a4"), o2.css.toColor("#75507b"), o2.css.toColor("#06989a"), o2.css.toColor("#d3d7cf"), o2.css.toColor("#555753"), o2.css.toColor("#ef2929"), o2.css.toColor("#8ae234"), o2.css.toColor("#fce94f"), o2.css.toColor("#729fcf"), o2.css.toColor("#ad7fa8"), o2.css.toColor("#34e2e2"), o2.css.toColor("#eeeeec")], t4 = [0, 95, 135, 175, 215, 255];
        for (let i4 = 0; i4 < 216; i4++) {
          const s4 = t4[i4 / 36 % 6 | 0], r3 = t4[i4 / 6 % 6 | 0], n3 = t4[i4 % 6];
          e4.push({ css: o2.channels.toCss(s4, r3, n3), rgba: o2.channels.toRgba(s4, r3, n3) });
        }
        for (let t5 = 0; t5 < 24; t5++) {
          const i4 = 8 + 10 * t5;
          e4.push({ css: o2.channels.toCss(i4, i4, i4), rgba: o2.channels.toRgba(i4, i4, i4) });
        }
        return e4;
      })());
      let v2 = t3.ThemeService = class extends h2.Disposable {
        get colors() {
          return this._colors;
        }
        constructor(e4) {
          super(), this._optionsService = e4, this._contrastCache = new n2.ColorContrastCache(), this._halfContrastCache = new n2.ColorContrastCache(), this._onChangeColors = this.register(new a2.EventEmitter()), this.onChangeColors = this._onChangeColors.event, this._colors = { foreground: l2, background: d2, cursor: _2, cursorAccent: u2, selectionForeground: void 0, selectionBackgroundTransparent: f2, selectionBackgroundOpaque: o2.color.blend(d2, f2), selectionInactiveBackgroundTransparent: f2, selectionInactiveBackgroundOpaque: o2.color.blend(d2, f2), ansi: t3.DEFAULT_ANSI_COLORS.slice(), contrastCache: this._contrastCache, halfContrastCache: this._halfContrastCache }, this._updateRestoreColors(), this._setTheme(this._optionsService.rawOptions.theme), this.register(this._optionsService.onSpecificOptionChange("minimumContrastRatio", () => this._contrastCache.clear())), this.register(this._optionsService.onSpecificOptionChange("theme", () => this._setTheme(this._optionsService.rawOptions.theme)));
        }
        _setTheme(e4 = {}) {
          const i4 = this._colors;
          if (i4.foreground = p2(e4.foreground, l2), i4.background = p2(e4.background, d2), i4.cursor = p2(e4.cursor, _2), i4.cursorAccent = p2(e4.cursorAccent, u2), i4.selectionBackgroundTransparent = p2(e4.selectionBackground, f2), i4.selectionBackgroundOpaque = o2.color.blend(i4.background, i4.selectionBackgroundTransparent), i4.selectionInactiveBackgroundTransparent = p2(e4.selectionInactiveBackground, i4.selectionBackgroundTransparent), i4.selectionInactiveBackgroundOpaque = o2.color.blend(i4.background, i4.selectionInactiveBackgroundTransparent), i4.selectionForeground = e4.selectionForeground ? p2(e4.selectionForeground, o2.NULL_COLOR) : void 0, i4.selectionForeground === o2.NULL_COLOR && (i4.selectionForeground = void 0), o2.color.isOpaque(i4.selectionBackgroundTransparent)) {
            const e5 = 0.3;
            i4.selectionBackgroundTransparent = o2.color.opacity(i4.selectionBackgroundTransparent, e5);
          }
          if (o2.color.isOpaque(i4.selectionInactiveBackgroundTransparent)) {
            const e5 = 0.3;
            i4.selectionInactiveBackgroundTransparent = o2.color.opacity(i4.selectionInactiveBackgroundTransparent, e5);
          }
          if (i4.ansi = t3.DEFAULT_ANSI_COLORS.slice(), i4.ansi[0] = p2(e4.black, t3.DEFAULT_ANSI_COLORS[0]), i4.ansi[1] = p2(e4.red, t3.DEFAULT_ANSI_COLORS[1]), i4.ansi[2] = p2(e4.green, t3.DEFAULT_ANSI_COLORS[2]), i4.ansi[3] = p2(e4.yellow, t3.DEFAULT_ANSI_COLORS[3]), i4.ansi[4] = p2(e4.blue, t3.DEFAULT_ANSI_COLORS[4]), i4.ansi[5] = p2(e4.magenta, t3.DEFAULT_ANSI_COLORS[5]), i4.ansi[6] = p2(e4.cyan, t3.DEFAULT_ANSI_COLORS[6]), i4.ansi[7] = p2(e4.white, t3.DEFAULT_ANSI_COLORS[7]), i4.ansi[8] = p2(e4.brightBlack, t3.DEFAULT_ANSI_COLORS[8]), i4.ansi[9] = p2(e4.brightRed, t3.DEFAULT_ANSI_COLORS[9]), i4.ansi[10] = p2(e4.brightGreen, t3.DEFAULT_ANSI_COLORS[10]), i4.ansi[11] = p2(e4.brightYellow, t3.DEFAULT_ANSI_COLORS[11]), i4.ansi[12] = p2(e4.brightBlue, t3.DEFAULT_ANSI_COLORS[12]), i4.ansi[13] = p2(e4.brightMagenta, t3.DEFAULT_ANSI_COLORS[13]), i4.ansi[14] = p2(e4.brightCyan, t3.DEFAULT_ANSI_COLORS[14]), i4.ansi[15] = p2(e4.brightWhite, t3.DEFAULT_ANSI_COLORS[15]), e4.extendedAnsi) {
            const s4 = Math.min(i4.ansi.length - 16, e4.extendedAnsi.length);
            for (let r3 = 0; r3 < s4; r3++) i4.ansi[r3 + 16] = p2(e4.extendedAnsi[r3], t3.DEFAULT_ANSI_COLORS[r3 + 16]);
          }
          this._contrastCache.clear(), this._halfContrastCache.clear(), this._updateRestoreColors(), this._onChangeColors.fire(this.colors);
        }
        restoreColor(e4) {
          this._restoreColor(e4), this._onChangeColors.fire(this.colors);
        }
        _restoreColor(e4) {
          if (void 0 !== e4) switch (e4) {
            case 256:
              this._colors.foreground = this._restoreColors.foreground;
              break;
            case 257:
              this._colors.background = this._restoreColors.background;
              break;
            case 258:
              this._colors.cursor = this._restoreColors.cursor;
              break;
            default:
              this._colors.ansi[e4] = this._restoreColors.ansi[e4];
          }
          else for (let e5 = 0; e5 < this._restoreColors.ansi.length; ++e5) this._colors.ansi[e5] = this._restoreColors.ansi[e5];
        }
        modifyColors(e4) {
          e4(this._colors), this._onChangeColors.fire(this.colors);
        }
        _updateRestoreColors() {
          this._restoreColors = { foreground: this._colors.foreground, background: this._colors.background, cursor: this._colors.cursor, ansi: this._colors.ansi.slice() };
        }
      };
      function p2(e4, t4) {
        if (void 0 !== e4) try {
          return o2.css.toColor(e4);
        } catch {
        }
        return t4;
      }
      __name(p2, "p");
      t3.ThemeService = v2 = s3([r2(0, c2.IOptionsService)], v2);
    }, 6349: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CircularList = void 0;
      const s3 = i3(8460), r2 = i3(844);
      class n2 extends r2.Disposable {
        static {
          __name(this, "n");
        }
        constructor(e4) {
          super(), this._maxLength = e4, this.onDeleteEmitter = this.register(new s3.EventEmitter()), this.onDelete = this.onDeleteEmitter.event, this.onInsertEmitter = this.register(new s3.EventEmitter()), this.onInsert = this.onInsertEmitter.event, this.onTrimEmitter = this.register(new s3.EventEmitter()), this.onTrim = this.onTrimEmitter.event, this._array = new Array(this._maxLength), this._startIndex = 0, this._length = 0;
        }
        get maxLength() {
          return this._maxLength;
        }
        set maxLength(e4) {
          if (this._maxLength === e4) return;
          const t4 = new Array(e4);
          for (let i4 = 0; i4 < Math.min(e4, this.length); i4++) t4[i4] = this._array[this._getCyclicIndex(i4)];
          this._array = t4, this._maxLength = e4, this._startIndex = 0;
        }
        get length() {
          return this._length;
        }
        set length(e4) {
          if (e4 > this._length) for (let t4 = this._length; t4 < e4; t4++) this._array[t4] = void 0;
          this._length = e4;
        }
        get(e4) {
          return this._array[this._getCyclicIndex(e4)];
        }
        set(e4, t4) {
          this._array[this._getCyclicIndex(e4)] = t4;
        }
        push(e4) {
          this._array[this._getCyclicIndex(this._length)] = e4, this._length === this._maxLength ? (this._startIndex = ++this._startIndex % this._maxLength, this.onTrimEmitter.fire(1)) : this._length++;
        }
        recycle() {
          if (this._length !== this._maxLength) throw new Error("Can only recycle when the buffer is full");
          return this._startIndex = ++this._startIndex % this._maxLength, this.onTrimEmitter.fire(1), this._array[this._getCyclicIndex(this._length - 1)];
        }
        get isFull() {
          return this._length === this._maxLength;
        }
        pop() {
          return this._array[this._getCyclicIndex(this._length-- - 1)];
        }
        splice(e4, t4, ...i4) {
          if (t4) {
            for (let i5 = e4; i5 < this._length - t4; i5++) this._array[this._getCyclicIndex(i5)] = this._array[this._getCyclicIndex(i5 + t4)];
            this._length -= t4, this.onDeleteEmitter.fire({ index: e4, amount: t4 });
          }
          for (let t5 = this._length - 1; t5 >= e4; t5--) this._array[this._getCyclicIndex(t5 + i4.length)] = this._array[this._getCyclicIndex(t5)];
          for (let t5 = 0; t5 < i4.length; t5++) this._array[this._getCyclicIndex(e4 + t5)] = i4[t5];
          if (i4.length && this.onInsertEmitter.fire({ index: e4, amount: i4.length }), this._length + i4.length > this._maxLength) {
            const e5 = this._length + i4.length - this._maxLength;
            this._startIndex += e5, this._length = this._maxLength, this.onTrimEmitter.fire(e5);
          } else this._length += i4.length;
        }
        trimStart(e4) {
          e4 > this._length && (e4 = this._length), this._startIndex += e4, this._length -= e4, this.onTrimEmitter.fire(e4);
        }
        shiftElements(e4, t4, i4) {
          if (!(t4 <= 0)) {
            if (e4 < 0 || e4 >= this._length) throw new Error("start argument out of range");
            if (e4 + i4 < 0) throw new Error("Cannot shift elements in list beyond index 0");
            if (i4 > 0) {
              for (let s5 = t4 - 1; s5 >= 0; s5--) this.set(e4 + s5 + i4, this.get(e4 + s5));
              const s4 = e4 + t4 + i4 - this._length;
              if (s4 > 0) for (this._length += s4; this._length > this._maxLength; ) this._length--, this._startIndex++, this.onTrimEmitter.fire(1);
            } else for (let s4 = 0; s4 < t4; s4++) this.set(e4 + s4 + i4, this.get(e4 + s4));
          }
        }
        _getCyclicIndex(e4) {
          return (this._startIndex + e4) % this._maxLength;
        }
      }
      t3.CircularList = n2;
    }, 1439: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.clone = void 0, t3.clone = /* @__PURE__ */ __name(function e4(t4, i3 = 5) {
        if ("object" != typeof t4) return t4;
        const s3 = Array.isArray(t4) ? [] : {};
        for (const r2 in t4) s3[r2] = i3 <= 1 ? t4[r2] : t4[r2] && e4(t4[r2], i3 - 1);
        return s3;
      }, "e");
    }, 8055: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.contrastRatio = t3.toPaddedHex = t3.rgba = t3.rgb = t3.css = t3.color = t3.channels = t3.NULL_COLOR = void 0;
      let i3 = 0, s3 = 0, r2 = 0, n2 = 0;
      var o2, a2, h2, c2, l2;
      function d2(e4) {
        const t4 = e4.toString(16);
        return t4.length < 2 ? "0" + t4 : t4;
      }
      __name(d2, "d");
      function _2(e4, t4) {
        return e4 < t4 ? (t4 + 0.05) / (e4 + 0.05) : (e4 + 0.05) / (t4 + 0.05);
      }
      __name(_2, "_");
      t3.NULL_COLOR = { css: "#00000000", rgba: 0 }, function(e4) {
        e4.toCss = function(e5, t4, i4, s4) {
          return void 0 !== s4 ? `#${d2(e5)}${d2(t4)}${d2(i4)}${d2(s4)}` : `#${d2(e5)}${d2(t4)}${d2(i4)}`;
        }, e4.toRgba = function(e5, t4, i4, s4 = 255) {
          return (e5 << 24 | t4 << 16 | i4 << 8 | s4) >>> 0;
        }, e4.toColor = function(t4, i4, s4, r3) {
          return { css: e4.toCss(t4, i4, s4, r3), rgba: e4.toRgba(t4, i4, s4, r3) };
        };
      }(o2 || (t3.channels = o2 = {})), function(e4) {
        function t4(e5, t5) {
          return n2 = Math.round(255 * t5), [i3, s3, r2] = l2.toChannels(e5.rgba), { css: o2.toCss(i3, s3, r2, n2), rgba: o2.toRgba(i3, s3, r2, n2) };
        }
        __name(t4, "t");
        e4.blend = function(e5, t5) {
          if (n2 = (255 & t5.rgba) / 255, 1 === n2) return { css: t5.css, rgba: t5.rgba };
          const a3 = t5.rgba >> 24 & 255, h3 = t5.rgba >> 16 & 255, c3 = t5.rgba >> 8 & 255, l3 = e5.rgba >> 24 & 255, d3 = e5.rgba >> 16 & 255, _3 = e5.rgba >> 8 & 255;
          return i3 = l3 + Math.round((a3 - l3) * n2), s3 = d3 + Math.round((h3 - d3) * n2), r2 = _3 + Math.round((c3 - _3) * n2), { css: o2.toCss(i3, s3, r2), rgba: o2.toRgba(i3, s3, r2) };
        }, e4.isOpaque = function(e5) {
          return 255 == (255 & e5.rgba);
        }, e4.ensureContrastRatio = function(e5, t5, i4) {
          const s4 = l2.ensureContrastRatio(e5.rgba, t5.rgba, i4);
          if (s4) return o2.toColor(s4 >> 24 & 255, s4 >> 16 & 255, s4 >> 8 & 255);
        }, e4.opaque = function(e5) {
          const t5 = (255 | e5.rgba) >>> 0;
          return [i3, s3, r2] = l2.toChannels(t5), { css: o2.toCss(i3, s3, r2), rgba: t5 };
        }, e4.opacity = t4, e4.multiplyOpacity = function(e5, i4) {
          return n2 = 255 & e5.rgba, t4(e5, n2 * i4 / 255);
        }, e4.toColorRGB = function(e5) {
          return [e5.rgba >> 24 & 255, e5.rgba >> 16 & 255, e5.rgba >> 8 & 255];
        };
      }(a2 || (t3.color = a2 = {})), function(e4) {
        let t4, a3;
        try {
          const e5 = document.createElement("canvas");
          e5.width = 1, e5.height = 1;
          const i4 = e5.getContext("2d", { willReadFrequently: true });
          i4 && (t4 = i4, t4.globalCompositeOperation = "copy", a3 = t4.createLinearGradient(0, 0, 1, 1));
        } catch {
        }
        e4.toColor = function(e5) {
          if (e5.match(/#[\da-f]{3,8}/i)) switch (e5.length) {
            case 4:
              return i3 = parseInt(e5.slice(1, 2).repeat(2), 16), s3 = parseInt(e5.slice(2, 3).repeat(2), 16), r2 = parseInt(e5.slice(3, 4).repeat(2), 16), o2.toColor(i3, s3, r2);
            case 5:
              return i3 = parseInt(e5.slice(1, 2).repeat(2), 16), s3 = parseInt(e5.slice(2, 3).repeat(2), 16), r2 = parseInt(e5.slice(3, 4).repeat(2), 16), n2 = parseInt(e5.slice(4, 5).repeat(2), 16), o2.toColor(i3, s3, r2, n2);
            case 7:
              return { css: e5, rgba: (parseInt(e5.slice(1), 16) << 8 | 255) >>> 0 };
            case 9:
              return { css: e5, rgba: parseInt(e5.slice(1), 16) >>> 0 };
          }
          const h3 = e5.match(/rgba?\(\s*(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\s*(,\s*(0|1|\d?\.(\d+))\s*)?\)/);
          if (h3) return i3 = parseInt(h3[1]), s3 = parseInt(h3[2]), r2 = parseInt(h3[3]), n2 = Math.round(255 * (void 0 === h3[5] ? 1 : parseFloat(h3[5]))), o2.toColor(i3, s3, r2, n2);
          if (!t4 || !a3) throw new Error("css.toColor: Unsupported css format");
          if (t4.fillStyle = a3, t4.fillStyle = e5, "string" != typeof t4.fillStyle) throw new Error("css.toColor: Unsupported css format");
          if (t4.fillRect(0, 0, 1, 1), [i3, s3, r2, n2] = t4.getImageData(0, 0, 1, 1).data, 255 !== n2) throw new Error("css.toColor: Unsupported css format");
          return { rgba: o2.toRgba(i3, s3, r2, n2), css: e5 };
        };
      }(h2 || (t3.css = h2 = {})), function(e4) {
        function t4(e5, t5, i4) {
          const s4 = e5 / 255, r3 = t5 / 255, n3 = i4 / 255;
          return 0.2126 * (s4 <= 0.03928 ? s4 / 12.92 : Math.pow((s4 + 0.055) / 1.055, 2.4)) + 0.7152 * (r3 <= 0.03928 ? r3 / 12.92 : Math.pow((r3 + 0.055) / 1.055, 2.4)) + 0.0722 * (n3 <= 0.03928 ? n3 / 12.92 : Math.pow((n3 + 0.055) / 1.055, 2.4));
        }
        __name(t4, "t");
        e4.relativeLuminance = function(e5) {
          return t4(e5 >> 16 & 255, e5 >> 8 & 255, 255 & e5);
        }, e4.relativeLuminance2 = t4;
      }(c2 || (t3.rgb = c2 = {})), function(e4) {
        function t4(e5, t5, i4) {
          const s4 = e5 >> 24 & 255, r3 = e5 >> 16 & 255, n3 = e5 >> 8 & 255;
          let o3 = t5 >> 24 & 255, a4 = t5 >> 16 & 255, h3 = t5 >> 8 & 255, l3 = _2(c2.relativeLuminance2(o3, a4, h3), c2.relativeLuminance2(s4, r3, n3));
          for (; l3 < i4 && (o3 > 0 || a4 > 0 || h3 > 0); ) o3 -= Math.max(0, Math.ceil(0.1 * o3)), a4 -= Math.max(0, Math.ceil(0.1 * a4)), h3 -= Math.max(0, Math.ceil(0.1 * h3)), l3 = _2(c2.relativeLuminance2(o3, a4, h3), c2.relativeLuminance2(s4, r3, n3));
          return (o3 << 24 | a4 << 16 | h3 << 8 | 255) >>> 0;
        }
        __name(t4, "t");
        function a3(e5, t5, i4) {
          const s4 = e5 >> 24 & 255, r3 = e5 >> 16 & 255, n3 = e5 >> 8 & 255;
          let o3 = t5 >> 24 & 255, a4 = t5 >> 16 & 255, h3 = t5 >> 8 & 255, l3 = _2(c2.relativeLuminance2(o3, a4, h3), c2.relativeLuminance2(s4, r3, n3));
          for (; l3 < i4 && (o3 < 255 || a4 < 255 || h3 < 255); ) o3 = Math.min(255, o3 + Math.ceil(0.1 * (255 - o3))), a4 = Math.min(255, a4 + Math.ceil(0.1 * (255 - a4))), h3 = Math.min(255, h3 + Math.ceil(0.1 * (255 - h3))), l3 = _2(c2.relativeLuminance2(o3, a4, h3), c2.relativeLuminance2(s4, r3, n3));
          return (o3 << 24 | a4 << 16 | h3 << 8 | 255) >>> 0;
        }
        __name(a3, "a");
        e4.blend = function(e5, t5) {
          if (n2 = (255 & t5) / 255, 1 === n2) return t5;
          const a4 = t5 >> 24 & 255, h3 = t5 >> 16 & 255, c3 = t5 >> 8 & 255, l3 = e5 >> 24 & 255, d3 = e5 >> 16 & 255, _3 = e5 >> 8 & 255;
          return i3 = l3 + Math.round((a4 - l3) * n2), s3 = d3 + Math.round((h3 - d3) * n2), r2 = _3 + Math.round((c3 - _3) * n2), o2.toRgba(i3, s3, r2);
        }, e4.ensureContrastRatio = function(e5, i4, s4) {
          const r3 = c2.relativeLuminance(e5 >> 8), n3 = c2.relativeLuminance(i4 >> 8);
          if (_2(r3, n3) < s4) {
            if (n3 < r3) {
              const n4 = t4(e5, i4, s4), o4 = _2(r3, c2.relativeLuminance(n4 >> 8));
              if (o4 < s4) {
                const t5 = a3(e5, i4, s4);
                return o4 > _2(r3, c2.relativeLuminance(t5 >> 8)) ? n4 : t5;
              }
              return n4;
            }
            const o3 = a3(e5, i4, s4), h3 = _2(r3, c2.relativeLuminance(o3 >> 8));
            if (h3 < s4) {
              const n4 = t4(e5, i4, s4);
              return h3 > _2(r3, c2.relativeLuminance(n4 >> 8)) ? o3 : n4;
            }
            return o3;
          }
        }, e4.reduceLuminance = t4, e4.increaseLuminance = a3, e4.toChannels = function(e5) {
          return [e5 >> 24 & 255, e5 >> 16 & 255, e5 >> 8 & 255, 255 & e5];
        };
      }(l2 || (t3.rgba = l2 = {})), t3.toPaddedHex = d2, t3.contrastRatio = _2;
    }, 8969: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CoreTerminal = void 0;
      const s3 = i3(844), r2 = i3(2585), n2 = i3(4348), o2 = i3(7866), a2 = i3(744), h2 = i3(7302), c2 = i3(6975), l2 = i3(8460), d2 = i3(1753), _2 = i3(1480), u2 = i3(7994), f2 = i3(9282), v2 = i3(5435), p2 = i3(5981), g2 = i3(2660);
      let m2 = false;
      class S2 extends s3.Disposable {
        static {
          __name(this, "S");
        }
        get onScroll() {
          return this._onScrollApi || (this._onScrollApi = this.register(new l2.EventEmitter()), this._onScroll.event((e4) => {
            this._onScrollApi?.fire(e4.position);
          })), this._onScrollApi.event;
        }
        get cols() {
          return this._bufferService.cols;
        }
        get rows() {
          return this._bufferService.rows;
        }
        get buffers() {
          return this._bufferService.buffers;
        }
        get options() {
          return this.optionsService.options;
        }
        set options(e4) {
          for (const t4 in e4) this.optionsService.options[t4] = e4[t4];
        }
        constructor(e4) {
          super(), this._windowsWrappingHeuristics = this.register(new s3.MutableDisposable()), this._onBinary = this.register(new l2.EventEmitter()), this.onBinary = this._onBinary.event, this._onData = this.register(new l2.EventEmitter()), this.onData = this._onData.event, this._onLineFeed = this.register(new l2.EventEmitter()), this.onLineFeed = this._onLineFeed.event, this._onResize = this.register(new l2.EventEmitter()), this.onResize = this._onResize.event, this._onWriteParsed = this.register(new l2.EventEmitter()), this.onWriteParsed = this._onWriteParsed.event, this._onScroll = this.register(new l2.EventEmitter()), this._instantiationService = new n2.InstantiationService(), this.optionsService = this.register(new h2.OptionsService(e4)), this._instantiationService.setService(r2.IOptionsService, this.optionsService), this._bufferService = this.register(this._instantiationService.createInstance(a2.BufferService)), this._instantiationService.setService(r2.IBufferService, this._bufferService), this._logService = this.register(this._instantiationService.createInstance(o2.LogService)), this._instantiationService.setService(r2.ILogService, this._logService), this.coreService = this.register(this._instantiationService.createInstance(c2.CoreService)), this._instantiationService.setService(r2.ICoreService, this.coreService), this.coreMouseService = this.register(this._instantiationService.createInstance(d2.CoreMouseService)), this._instantiationService.setService(r2.ICoreMouseService, this.coreMouseService), this.unicodeService = this.register(this._instantiationService.createInstance(_2.UnicodeService)), this._instantiationService.setService(r2.IUnicodeService, this.unicodeService), this._charsetService = this._instantiationService.createInstance(u2.CharsetService), this._instantiationService.setService(r2.ICharsetService, this._charsetService), this._oscLinkService = this._instantiationService.createInstance(g2.OscLinkService), this._instantiationService.setService(r2.IOscLinkService, this._oscLinkService), this._inputHandler = this.register(new v2.InputHandler(this._bufferService, this._charsetService, this.coreService, this._logService, this.optionsService, this._oscLinkService, this.coreMouseService, this.unicodeService)), this.register((0, l2.forwardEvent)(this._inputHandler.onLineFeed, this._onLineFeed)), this.register(this._inputHandler), this.register((0, l2.forwardEvent)(this._bufferService.onResize, this._onResize)), this.register((0, l2.forwardEvent)(this.coreService.onData, this._onData)), this.register((0, l2.forwardEvent)(this.coreService.onBinary, this._onBinary)), this.register(this.coreService.onRequestScrollToBottom(() => this.scrollToBottom())), this.register(this.coreService.onUserInput(() => this._writeBuffer.handleUserInput())), this.register(this.optionsService.onMultipleOptionChange(["windowsMode", "windowsPty"], () => this._handleWindowsPtyOptionChange())), this.register(this._bufferService.onScroll((e5) => {
            this._onScroll.fire({ position: this._bufferService.buffer.ydisp, source: 0 }), this._inputHandler.markRangeDirty(this._bufferService.buffer.scrollTop, this._bufferService.buffer.scrollBottom);
          })), this.register(this._inputHandler.onScroll((e5) => {
            this._onScroll.fire({ position: this._bufferService.buffer.ydisp, source: 0 }), this._inputHandler.markRangeDirty(this._bufferService.buffer.scrollTop, this._bufferService.buffer.scrollBottom);
          })), this._writeBuffer = this.register(new p2.WriteBuffer((e5, t4) => this._inputHandler.parse(e5, t4))), this.register((0, l2.forwardEvent)(this._writeBuffer.onWriteParsed, this._onWriteParsed));
        }
        write(e4, t4) {
          this._writeBuffer.write(e4, t4);
        }
        writeSync(e4, t4) {
          this._logService.logLevel <= r2.LogLevelEnum.WARN && !m2 && (this._logService.warn("writeSync is unreliable and will be removed soon."), m2 = true), this._writeBuffer.writeSync(e4, t4);
        }
        input(e4, t4 = true) {
          this.coreService.triggerDataEvent(e4, t4);
        }
        resize(e4, t4) {
          isNaN(e4) || isNaN(t4) || (e4 = Math.max(e4, a2.MINIMUM_COLS), t4 = Math.max(t4, a2.MINIMUM_ROWS), this._bufferService.resize(e4, t4));
        }
        scroll(e4, t4 = false) {
          this._bufferService.scroll(e4, t4);
        }
        scrollLines(e4, t4, i4) {
          this._bufferService.scrollLines(e4, t4, i4);
        }
        scrollPages(e4) {
          this.scrollLines(e4 * (this.rows - 1));
        }
        scrollToTop() {
          this.scrollLines(-this._bufferService.buffer.ydisp);
        }
        scrollToBottom() {
          this.scrollLines(this._bufferService.buffer.ybase - this._bufferService.buffer.ydisp);
        }
        scrollToLine(e4) {
          const t4 = e4 - this._bufferService.buffer.ydisp;
          0 !== t4 && this.scrollLines(t4);
        }
        registerEscHandler(e4, t4) {
          return this._inputHandler.registerEscHandler(e4, t4);
        }
        registerDcsHandler(e4, t4) {
          return this._inputHandler.registerDcsHandler(e4, t4);
        }
        registerCsiHandler(e4, t4) {
          return this._inputHandler.registerCsiHandler(e4, t4);
        }
        registerOscHandler(e4, t4) {
          return this._inputHandler.registerOscHandler(e4, t4);
        }
        _setup() {
          this._handleWindowsPtyOptionChange();
        }
        reset() {
          this._inputHandler.reset(), this._bufferService.reset(), this._charsetService.reset(), this.coreService.reset(), this.coreMouseService.reset();
        }
        _handleWindowsPtyOptionChange() {
          let e4 = false;
          const t4 = this.optionsService.rawOptions.windowsPty;
          t4 && void 0 !== t4.buildNumber && void 0 !== t4.buildNumber ? e4 = !!("conpty" === t4.backend && t4.buildNumber < 21376) : this.optionsService.rawOptions.windowsMode && (e4 = true), e4 ? this._enableWindowsWrappingHeuristics() : this._windowsWrappingHeuristics.clear();
        }
        _enableWindowsWrappingHeuristics() {
          if (!this._windowsWrappingHeuristics.value) {
            const e4 = [];
            e4.push(this.onLineFeed(f2.updateWindowsModeWrappedState.bind(null, this._bufferService))), e4.push(this.registerCsiHandler({ final: "H" }, () => ((0, f2.updateWindowsModeWrappedState)(this._bufferService), false))), this._windowsWrappingHeuristics.value = (0, s3.toDisposable)(() => {
              for (const t4 of e4) t4.dispose();
            });
          }
        }
      }
      t3.CoreTerminal = S2;
    }, 8460: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.runAndSubscribe = t3.forwardEvent = t3.EventEmitter = void 0, t3.EventEmitter = class {
        constructor() {
          this._listeners = [], this._disposed = false;
        }
        get event() {
          return this._event || (this._event = (e4) => (this._listeners.push(e4), { dispose: /* @__PURE__ */ __name(() => {
            if (!this._disposed) {
              for (let t4 = 0; t4 < this._listeners.length; t4++) if (this._listeners[t4] === e4) return void this._listeners.splice(t4, 1);
            }
          }, "dispose") })), this._event;
        }
        fire(e4, t4) {
          const i3 = [];
          for (let e5 = 0; e5 < this._listeners.length; e5++) i3.push(this._listeners[e5]);
          for (let s3 = 0; s3 < i3.length; s3++) i3[s3].call(void 0, e4, t4);
        }
        dispose() {
          this.clearListeners(), this._disposed = true;
        }
        clearListeners() {
          this._listeners && (this._listeners.length = 0);
        }
      }, t3.forwardEvent = function(e4, t4) {
        return e4((e5) => t4.fire(e5));
      }, t3.runAndSubscribe = function(e4, t4) {
        return t4(void 0), e4((e5) => t4(e5));
      };
    }, 5435: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.InputHandler = t3.WindowsOptionsReportType = void 0;
      const n2 = i3(2584), o2 = i3(7116), a2 = i3(2015), h2 = i3(844), c2 = i3(482), l2 = i3(8437), d2 = i3(8460), _2 = i3(643), u2 = i3(511), f2 = i3(3734), v2 = i3(2585), p2 = i3(1480), g2 = i3(6242), m2 = i3(6351), S2 = i3(5941), C2 = { "(": 0, ")": 1, "*": 2, "+": 3, "-": 1, ".": 2 }, b2 = 131072;
      function w2(e4, t4) {
        if (e4 > 24) return t4.setWinLines || false;
        switch (e4) {
          case 1:
            return !!t4.restoreWin;
          case 2:
            return !!t4.minimizeWin;
          case 3:
            return !!t4.setWinPosition;
          case 4:
            return !!t4.setWinSizePixels;
          case 5:
            return !!t4.raiseWin;
          case 6:
            return !!t4.lowerWin;
          case 7:
            return !!t4.refreshWin;
          case 8:
            return !!t4.setWinSizeChars;
          case 9:
            return !!t4.maximizeWin;
          case 10:
            return !!t4.fullscreenWin;
          case 11:
            return !!t4.getWinState;
          case 13:
            return !!t4.getWinPosition;
          case 14:
            return !!t4.getWinSizePixels;
          case 15:
            return !!t4.getScreenSizePixels;
          case 16:
            return !!t4.getCellSizePixels;
          case 18:
            return !!t4.getWinSizeChars;
          case 19:
            return !!t4.getScreenSizeChars;
          case 20:
            return !!t4.getIconTitle;
          case 21:
            return !!t4.getWinTitle;
          case 22:
            return !!t4.pushTitle;
          case 23:
            return !!t4.popTitle;
          case 24:
            return !!t4.setWinLines;
        }
        return false;
      }
      __name(w2, "w");
      var y2;
      !function(e4) {
        e4[e4.GET_WIN_SIZE_PIXELS = 0] = "GET_WIN_SIZE_PIXELS", e4[e4.GET_CELL_SIZE_PIXELS = 1] = "GET_CELL_SIZE_PIXELS";
      }(y2 || (t3.WindowsOptionsReportType = y2 = {}));
      let E = 0;
      class k2 extends h2.Disposable {
        static {
          __name(this, "k");
        }
        getAttrData() {
          return this._curAttrData;
        }
        constructor(e4, t4, i4, s4, r3, h3, _3, f3, v3 = new a2.EscapeSequenceParser()) {
          super(), this._bufferService = e4, this._charsetService = t4, this._coreService = i4, this._logService = s4, this._optionsService = r3, this._oscLinkService = h3, this._coreMouseService = _3, this._unicodeService = f3, this._parser = v3, this._parseBuffer = new Uint32Array(4096), this._stringDecoder = new c2.StringToUtf32(), this._utf8Decoder = new c2.Utf8ToUtf32(), this._workCell = new u2.CellData(), this._windowTitle = "", this._iconName = "", this._windowTitleStack = [], this._iconNameStack = [], this._curAttrData = l2.DEFAULT_ATTR_DATA.clone(), this._eraseAttrDataInternal = l2.DEFAULT_ATTR_DATA.clone(), this._onRequestBell = this.register(new d2.EventEmitter()), this.onRequestBell = this._onRequestBell.event, this._onRequestRefreshRows = this.register(new d2.EventEmitter()), this.onRequestRefreshRows = this._onRequestRefreshRows.event, this._onRequestReset = this.register(new d2.EventEmitter()), this.onRequestReset = this._onRequestReset.event, this._onRequestSendFocus = this.register(new d2.EventEmitter()), this.onRequestSendFocus = this._onRequestSendFocus.event, this._onRequestSyncScrollBar = this.register(new d2.EventEmitter()), this.onRequestSyncScrollBar = this._onRequestSyncScrollBar.event, this._onRequestWindowsOptionsReport = this.register(new d2.EventEmitter()), this.onRequestWindowsOptionsReport = this._onRequestWindowsOptionsReport.event, this._onA11yChar = this.register(new d2.EventEmitter()), this.onA11yChar = this._onA11yChar.event, this._onA11yTab = this.register(new d2.EventEmitter()), this.onA11yTab = this._onA11yTab.event, this._onCursorMove = this.register(new d2.EventEmitter()), this.onCursorMove = this._onCursorMove.event, this._onLineFeed = this.register(new d2.EventEmitter()), this.onLineFeed = this._onLineFeed.event, this._onScroll = this.register(new d2.EventEmitter()), this.onScroll = this._onScroll.event, this._onTitleChange = this.register(new d2.EventEmitter()), this.onTitleChange = this._onTitleChange.event, this._onColor = this.register(new d2.EventEmitter()), this.onColor = this._onColor.event, this._parseStack = { paused: false, cursorStartX: 0, cursorStartY: 0, decodedLength: 0, position: 0 }, this._specialColors = [256, 257, 258], this.register(this._parser), this._dirtyRowTracker = new L2(this._bufferService), this._activeBuffer = this._bufferService.buffer, this.register(this._bufferService.buffers.onBufferActivate((e5) => this._activeBuffer = e5.activeBuffer)), this._parser.setCsiHandlerFallback((e5, t5) => {
            this._logService.debug("Unknown CSI code: ", { identifier: this._parser.identToString(e5), params: t5.toArray() });
          }), this._parser.setEscHandlerFallback((e5) => {
            this._logService.debug("Unknown ESC code: ", { identifier: this._parser.identToString(e5) });
          }), this._parser.setExecuteHandlerFallback((e5) => {
            this._logService.debug("Unknown EXECUTE code: ", { code: e5 });
          }), this._parser.setOscHandlerFallback((e5, t5, i5) => {
            this._logService.debug("Unknown OSC code: ", { identifier: e5, action: t5, data: i5 });
          }), this._parser.setDcsHandlerFallback((e5, t5, i5) => {
            "HOOK" === t5 && (i5 = i5.toArray()), this._logService.debug("Unknown DCS code: ", { identifier: this._parser.identToString(e5), action: t5, payload: i5 });
          }), this._parser.setPrintHandler((e5, t5, i5) => this.print(e5, t5, i5)), this._parser.registerCsiHandler({ final: "@" }, (e5) => this.insertChars(e5)), this._parser.registerCsiHandler({ intermediates: " ", final: "@" }, (e5) => this.scrollLeft(e5)), this._parser.registerCsiHandler({ final: "A" }, (e5) => this.cursorUp(e5)), this._parser.registerCsiHandler({ intermediates: " ", final: "A" }, (e5) => this.scrollRight(e5)), this._parser.registerCsiHandler({ final: "B" }, (e5) => this.cursorDown(e5)), this._parser.registerCsiHandler({ final: "C" }, (e5) => this.cursorForward(e5)), this._parser.registerCsiHandler({ final: "D" }, (e5) => this.cursorBackward(e5)), this._parser.registerCsiHandler({ final: "E" }, (e5) => this.cursorNextLine(e5)), this._parser.registerCsiHandler({ final: "F" }, (e5) => this.cursorPrecedingLine(e5)), this._parser.registerCsiHandler({ final: "G" }, (e5) => this.cursorCharAbsolute(e5)), this._parser.registerCsiHandler({ final: "H" }, (e5) => this.cursorPosition(e5)), this._parser.registerCsiHandler({ final: "I" }, (e5) => this.cursorForwardTab(e5)), this._parser.registerCsiHandler({ final: "J" }, (e5) => this.eraseInDisplay(e5, false)), this._parser.registerCsiHandler({ prefix: "?", final: "J" }, (e5) => this.eraseInDisplay(e5, true)), this._parser.registerCsiHandler({ final: "K" }, (e5) => this.eraseInLine(e5, false)), this._parser.registerCsiHandler({ prefix: "?", final: "K" }, (e5) => this.eraseInLine(e5, true)), this._parser.registerCsiHandler({ final: "L" }, (e5) => this.insertLines(e5)), this._parser.registerCsiHandler({ final: "M" }, (e5) => this.deleteLines(e5)), this._parser.registerCsiHandler({ final: "P" }, (e5) => this.deleteChars(e5)), this._parser.registerCsiHandler({ final: "S" }, (e5) => this.scrollUp(e5)), this._parser.registerCsiHandler({ final: "T" }, (e5) => this.scrollDown(e5)), this._parser.registerCsiHandler({ final: "X" }, (e5) => this.eraseChars(e5)), this._parser.registerCsiHandler({ final: "Z" }, (e5) => this.cursorBackwardTab(e5)), this._parser.registerCsiHandler({ final: "`" }, (e5) => this.charPosAbsolute(e5)), this._parser.registerCsiHandler({ final: "a" }, (e5) => this.hPositionRelative(e5)), this._parser.registerCsiHandler({ final: "b" }, (e5) => this.repeatPrecedingCharacter(e5)), this._parser.registerCsiHandler({ final: "c" }, (e5) => this.sendDeviceAttributesPrimary(e5)), this._parser.registerCsiHandler({ prefix: ">", final: "c" }, (e5) => this.sendDeviceAttributesSecondary(e5)), this._parser.registerCsiHandler({ final: "d" }, (e5) => this.linePosAbsolute(e5)), this._parser.registerCsiHandler({ final: "e" }, (e5) => this.vPositionRelative(e5)), this._parser.registerCsiHandler({ final: "f" }, (e5) => this.hVPosition(e5)), this._parser.registerCsiHandler({ final: "g" }, (e5) => this.tabClear(e5)), this._parser.registerCsiHandler({ final: "h" }, (e5) => this.setMode(e5)), this._parser.registerCsiHandler({ prefix: "?", final: "h" }, (e5) => this.setModePrivate(e5)), this._parser.registerCsiHandler({ final: "l" }, (e5) => this.resetMode(e5)), this._parser.registerCsiHandler({ prefix: "?", final: "l" }, (e5) => this.resetModePrivate(e5)), this._parser.registerCsiHandler({ final: "m" }, (e5) => this.charAttributes(e5)), this._parser.registerCsiHandler({ final: "n" }, (e5) => this.deviceStatus(e5)), this._parser.registerCsiHandler({ prefix: "?", final: "n" }, (e5) => this.deviceStatusPrivate(e5)), this._parser.registerCsiHandler({ intermediates: "!", final: "p" }, (e5) => this.softReset(e5)), this._parser.registerCsiHandler({ intermediates: " ", final: "q" }, (e5) => this.setCursorStyle(e5)), this._parser.registerCsiHandler({ final: "r" }, (e5) => this.setScrollRegion(e5)), this._parser.registerCsiHandler({ final: "s" }, (e5) => this.saveCursor(e5)), this._parser.registerCsiHandler({ final: "t" }, (e5) => this.windowOptions(e5)), this._parser.registerCsiHandler({ final: "u" }, (e5) => this.restoreCursor(e5)), this._parser.registerCsiHandler({ intermediates: "'", final: "}" }, (e5) => this.insertColumns(e5)), this._parser.registerCsiHandler({ intermediates: "'", final: "~" }, (e5) => this.deleteColumns(e5)), this._parser.registerCsiHandler({ intermediates: '"', final: "q" }, (e5) => this.selectProtected(e5)), this._parser.registerCsiHandler({ intermediates: "$", final: "p" }, (e5) => this.requestMode(e5, true)), this._parser.registerCsiHandler({ prefix: "?", intermediates: "$", final: "p" }, (e5) => this.requestMode(e5, false)), this._parser.setExecuteHandler(n2.C0.BEL, () => this.bell()), this._parser.setExecuteHandler(n2.C0.LF, () => this.lineFeed()), this._parser.setExecuteHandler(n2.C0.VT, () => this.lineFeed()), this._parser.setExecuteHandler(n2.C0.FF, () => this.lineFeed()), this._parser.setExecuteHandler(n2.C0.CR, () => this.carriageReturn()), this._parser.setExecuteHandler(n2.C0.BS, () => this.backspace()), this._parser.setExecuteHandler(n2.C0.HT, () => this.tab()), this._parser.setExecuteHandler(n2.C0.SO, () => this.shiftOut()), this._parser.setExecuteHandler(n2.C0.SI, () => this.shiftIn()), this._parser.setExecuteHandler(n2.C1.IND, () => this.index()), this._parser.setExecuteHandler(n2.C1.NEL, () => this.nextLine()), this._parser.setExecuteHandler(n2.C1.HTS, () => this.tabSet()), this._parser.registerOscHandler(0, new g2.OscHandler((e5) => (this.setTitle(e5), this.setIconName(e5), true))), this._parser.registerOscHandler(1, new g2.OscHandler((e5) => this.setIconName(e5))), this._parser.registerOscHandler(2, new g2.OscHandler((e5) => this.setTitle(e5))), this._parser.registerOscHandler(4, new g2.OscHandler((e5) => this.setOrReportIndexedColor(e5))), this._parser.registerOscHandler(8, new g2.OscHandler((e5) => this.setHyperlink(e5))), this._parser.registerOscHandler(10, new g2.OscHandler((e5) => this.setOrReportFgColor(e5))), this._parser.registerOscHandler(11, new g2.OscHandler((e5) => this.setOrReportBgColor(e5))), this._parser.registerOscHandler(12, new g2.OscHandler((e5) => this.setOrReportCursorColor(e5))), this._parser.registerOscHandler(104, new g2.OscHandler((e5) => this.restoreIndexedColor(e5))), this._parser.registerOscHandler(110, new g2.OscHandler((e5) => this.restoreFgColor(e5))), this._parser.registerOscHandler(111, new g2.OscHandler((e5) => this.restoreBgColor(e5))), this._parser.registerOscHandler(112, new g2.OscHandler((e5) => this.restoreCursorColor(e5))), this._parser.registerEscHandler({ final: "7" }, () => this.saveCursor()), this._parser.registerEscHandler({ final: "8" }, () => this.restoreCursor()), this._parser.registerEscHandler({ final: "D" }, () => this.index()), this._parser.registerEscHandler({ final: "E" }, () => this.nextLine()), this._parser.registerEscHandler({ final: "H" }, () => this.tabSet()), this._parser.registerEscHandler({ final: "M" }, () => this.reverseIndex()), this._parser.registerEscHandler({ final: "=" }, () => this.keypadApplicationMode()), this._parser.registerEscHandler({ final: ">" }, () => this.keypadNumericMode()), this._parser.registerEscHandler({ final: "c" }, () => this.fullReset()), this._parser.registerEscHandler({ final: "n" }, () => this.setgLevel(2)), this._parser.registerEscHandler({ final: "o" }, () => this.setgLevel(3)), this._parser.registerEscHandler({ final: "|" }, () => this.setgLevel(3)), this._parser.registerEscHandler({ final: "}" }, () => this.setgLevel(2)), this._parser.registerEscHandler({ final: "~" }, () => this.setgLevel(1)), this._parser.registerEscHandler({ intermediates: "%", final: "@" }, () => this.selectDefaultCharset()), this._parser.registerEscHandler({ intermediates: "%", final: "G" }, () => this.selectDefaultCharset());
          for (const e5 in o2.CHARSETS) this._parser.registerEscHandler({ intermediates: "(", final: e5 }, () => this.selectCharset("(" + e5)), this._parser.registerEscHandler({ intermediates: ")", final: e5 }, () => this.selectCharset(")" + e5)), this._parser.registerEscHandler({ intermediates: "*", final: e5 }, () => this.selectCharset("*" + e5)), this._parser.registerEscHandler({ intermediates: "+", final: e5 }, () => this.selectCharset("+" + e5)), this._parser.registerEscHandler({ intermediates: "-", final: e5 }, () => this.selectCharset("-" + e5)), this._parser.registerEscHandler({ intermediates: ".", final: e5 }, () => this.selectCharset("." + e5)), this._parser.registerEscHandler({ intermediates: "/", final: e5 }, () => this.selectCharset("/" + e5));
          this._parser.registerEscHandler({ intermediates: "#", final: "8" }, () => this.screenAlignmentPattern()), this._parser.setErrorHandler((e5) => (this._logService.error("Parsing error: ", e5), e5)), this._parser.registerDcsHandler({ intermediates: "$", final: "q" }, new m2.DcsHandler((e5, t5) => this.requestStatusString(e5, t5)));
        }
        _preserveStack(e4, t4, i4, s4) {
          this._parseStack.paused = true, this._parseStack.cursorStartX = e4, this._parseStack.cursorStartY = t4, this._parseStack.decodedLength = i4, this._parseStack.position = s4;
        }
        _logSlowResolvingAsync(e4) {
          this._logService.logLevel <= v2.LogLevelEnum.WARN && Promise.race([e4, new Promise((e5, t4) => setTimeout(() => t4("#SLOW_TIMEOUT"), 5e3))]).catch((e5) => {
            if ("#SLOW_TIMEOUT" !== e5) throw e5;
            console.warn("async parser handler taking longer than 5000 ms");
          });
        }
        _getCurrentLinkId() {
          return this._curAttrData.extended.urlId;
        }
        parse(e4, t4) {
          let i4, s4 = this._activeBuffer.x, r3 = this._activeBuffer.y, n3 = 0;
          const o3 = this._parseStack.paused;
          if (o3) {
            if (i4 = this._parser.parse(this._parseBuffer, this._parseStack.decodedLength, t4)) return this._logSlowResolvingAsync(i4), i4;
            s4 = this._parseStack.cursorStartX, r3 = this._parseStack.cursorStartY, this._parseStack.paused = false, e4.length > b2 && (n3 = this._parseStack.position + b2);
          }
          if (this._logService.logLevel <= v2.LogLevelEnum.DEBUG && this._logService.debug("parsing data" + ("string" == typeof e4 ? ` "${e4}"` : ` "${Array.prototype.map.call(e4, (e5) => String.fromCharCode(e5)).join("")}"`), "string" == typeof e4 ? e4.split("").map((e5) => e5.charCodeAt(0)) : e4), this._parseBuffer.length < e4.length && this._parseBuffer.length < b2 && (this._parseBuffer = new Uint32Array(Math.min(e4.length, b2))), o3 || this._dirtyRowTracker.clearRange(), e4.length > b2) for (let t5 = n3; t5 < e4.length; t5 += b2) {
            const n4 = t5 + b2 < e4.length ? t5 + b2 : e4.length, o4 = "string" == typeof e4 ? this._stringDecoder.decode(e4.substring(t5, n4), this._parseBuffer) : this._utf8Decoder.decode(e4.subarray(t5, n4), this._parseBuffer);
            if (i4 = this._parser.parse(this._parseBuffer, o4)) return this._preserveStack(s4, r3, o4, t5), this._logSlowResolvingAsync(i4), i4;
          }
          else if (!o3) {
            const t5 = "string" == typeof e4 ? this._stringDecoder.decode(e4, this._parseBuffer) : this._utf8Decoder.decode(e4, this._parseBuffer);
            if (i4 = this._parser.parse(this._parseBuffer, t5)) return this._preserveStack(s4, r3, t5, 0), this._logSlowResolvingAsync(i4), i4;
          }
          this._activeBuffer.x === s4 && this._activeBuffer.y === r3 || this._onCursorMove.fire();
          const a3 = this._dirtyRowTracker.end + (this._bufferService.buffer.ybase - this._bufferService.buffer.ydisp), h3 = this._dirtyRowTracker.start + (this._bufferService.buffer.ybase - this._bufferService.buffer.ydisp);
          h3 < this._bufferService.rows && this._onRequestRefreshRows.fire(Math.min(h3, this._bufferService.rows - 1), Math.min(a3, this._bufferService.rows - 1));
        }
        print(e4, t4, i4) {
          let s4, r3;
          const n3 = this._charsetService.charset, o3 = this._optionsService.rawOptions.screenReaderMode, a3 = this._bufferService.cols, h3 = this._coreService.decPrivateModes.wraparound, d3 = this._coreService.modes.insertMode, u3 = this._curAttrData;
          let f3 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y);
          this._dirtyRowTracker.markDirty(this._activeBuffer.y), this._activeBuffer.x && i4 - t4 > 0 && 2 === f3.getWidth(this._activeBuffer.x - 1) && f3.setCellFromCodepoint(this._activeBuffer.x - 1, 0, 1, u3);
          let v3 = this._parser.precedingJoinState;
          for (let g3 = t4; g3 < i4; ++g3) {
            if (s4 = e4[g3], s4 < 127 && n3) {
              const e5 = n3[String.fromCharCode(s4)];
              e5 && (s4 = e5.charCodeAt(0));
            }
            const t5 = this._unicodeService.charProperties(s4, v3);
            r3 = p2.UnicodeService.extractWidth(t5);
            const i5 = p2.UnicodeService.extractShouldJoin(t5), m3 = i5 ? p2.UnicodeService.extractWidth(v3) : 0;
            if (v3 = t5, o3 && this._onA11yChar.fire((0, c2.stringFromCodePoint)(s4)), this._getCurrentLinkId() && this._oscLinkService.addLineToLink(this._getCurrentLinkId(), this._activeBuffer.ybase + this._activeBuffer.y), this._activeBuffer.x + r3 - m3 > a3) {
              if (h3) {
                const e5 = f3;
                let t6 = this._activeBuffer.x - m3;
                for (this._activeBuffer.x = m3, this._activeBuffer.y++, this._activeBuffer.y === this._activeBuffer.scrollBottom + 1 ? (this._activeBuffer.y--, this._bufferService.scroll(this._eraseAttrData(), true)) : (this._activeBuffer.y >= this._bufferService.rows && (this._activeBuffer.y = this._bufferService.rows - 1), this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y).isWrapped = true), f3 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y), m3 > 0 && f3 instanceof l2.BufferLine && f3.copyCellsFrom(e5, t6, 0, m3, false); t6 < a3; ) e5.setCellFromCodepoint(t6++, 0, 1, u3);
              } else if (this._activeBuffer.x = a3 - 1, 2 === r3) continue;
            }
            if (i5 && this._activeBuffer.x) {
              const e5 = f3.getWidth(this._activeBuffer.x - 1) ? 1 : 2;
              f3.addCodepointToCell(this._activeBuffer.x - e5, s4, r3);
              for (let e6 = r3 - m3; --e6 >= 0; ) f3.setCellFromCodepoint(this._activeBuffer.x++, 0, 0, u3);
            } else if (d3 && (f3.insertCells(this._activeBuffer.x, r3 - m3, this._activeBuffer.getNullCell(u3)), 2 === f3.getWidth(a3 - 1) && f3.setCellFromCodepoint(a3 - 1, _2.NULL_CELL_CODE, _2.NULL_CELL_WIDTH, u3)), f3.setCellFromCodepoint(this._activeBuffer.x++, s4, r3, u3), r3 > 0) for (; --r3; ) f3.setCellFromCodepoint(this._activeBuffer.x++, 0, 0, u3);
          }
          this._parser.precedingJoinState = v3, this._activeBuffer.x < a3 && i4 - t4 > 0 && 0 === f3.getWidth(this._activeBuffer.x) && !f3.hasContent(this._activeBuffer.x) && f3.setCellFromCodepoint(this._activeBuffer.x, 0, 1, u3), this._dirtyRowTracker.markDirty(this._activeBuffer.y);
        }
        registerCsiHandler(e4, t4) {
          return "t" !== e4.final || e4.prefix || e4.intermediates ? this._parser.registerCsiHandler(e4, t4) : this._parser.registerCsiHandler(e4, (e5) => !w2(e5.params[0], this._optionsService.rawOptions.windowOptions) || t4(e5));
        }
        registerDcsHandler(e4, t4) {
          return this._parser.registerDcsHandler(e4, new m2.DcsHandler(t4));
        }
        registerEscHandler(e4, t4) {
          return this._parser.registerEscHandler(e4, t4);
        }
        registerOscHandler(e4, t4) {
          return this._parser.registerOscHandler(e4, new g2.OscHandler(t4));
        }
        bell() {
          return this._onRequestBell.fire(), true;
        }
        lineFeed() {
          return this._dirtyRowTracker.markDirty(this._activeBuffer.y), this._optionsService.rawOptions.convertEol && (this._activeBuffer.x = 0), this._activeBuffer.y++, this._activeBuffer.y === this._activeBuffer.scrollBottom + 1 ? (this._activeBuffer.y--, this._bufferService.scroll(this._eraseAttrData())) : this._activeBuffer.y >= this._bufferService.rows ? this._activeBuffer.y = this._bufferService.rows - 1 : this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y).isWrapped = false, this._activeBuffer.x >= this._bufferService.cols && this._activeBuffer.x--, this._dirtyRowTracker.markDirty(this._activeBuffer.y), this._onLineFeed.fire(), true;
        }
        carriageReturn() {
          return this._activeBuffer.x = 0, true;
        }
        backspace() {
          if (!this._coreService.decPrivateModes.reverseWraparound) return this._restrictCursor(), this._activeBuffer.x > 0 && this._activeBuffer.x--, true;
          if (this._restrictCursor(this._bufferService.cols), this._activeBuffer.x > 0) this._activeBuffer.x--;
          else if (0 === this._activeBuffer.x && this._activeBuffer.y > this._activeBuffer.scrollTop && this._activeBuffer.y <= this._activeBuffer.scrollBottom && this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y)?.isWrapped) {
            this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y).isWrapped = false, this._activeBuffer.y--, this._activeBuffer.x = this._bufferService.cols - 1;
            const e4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y);
            e4.hasWidth(this._activeBuffer.x) && !e4.hasContent(this._activeBuffer.x) && this._activeBuffer.x--;
          }
          return this._restrictCursor(), true;
        }
        tab() {
          if (this._activeBuffer.x >= this._bufferService.cols) return true;
          const e4 = this._activeBuffer.x;
          return this._activeBuffer.x = this._activeBuffer.nextStop(), this._optionsService.rawOptions.screenReaderMode && this._onA11yTab.fire(this._activeBuffer.x - e4), true;
        }
        shiftOut() {
          return this._charsetService.setgLevel(1), true;
        }
        shiftIn() {
          return this._charsetService.setgLevel(0), true;
        }
        _restrictCursor(e4 = this._bufferService.cols - 1) {
          this._activeBuffer.x = Math.min(e4, Math.max(0, this._activeBuffer.x)), this._activeBuffer.y = this._coreService.decPrivateModes.origin ? Math.min(this._activeBuffer.scrollBottom, Math.max(this._activeBuffer.scrollTop, this._activeBuffer.y)) : Math.min(this._bufferService.rows - 1, Math.max(0, this._activeBuffer.y)), this._dirtyRowTracker.markDirty(this._activeBuffer.y);
        }
        _setCursor(e4, t4) {
          this._dirtyRowTracker.markDirty(this._activeBuffer.y), this._coreService.decPrivateModes.origin ? (this._activeBuffer.x = e4, this._activeBuffer.y = this._activeBuffer.scrollTop + t4) : (this._activeBuffer.x = e4, this._activeBuffer.y = t4), this._restrictCursor(), this._dirtyRowTracker.markDirty(this._activeBuffer.y);
        }
        _moveCursor(e4, t4) {
          this._restrictCursor(), this._setCursor(this._activeBuffer.x + e4, this._activeBuffer.y + t4);
        }
        cursorUp(e4) {
          const t4 = this._activeBuffer.y - this._activeBuffer.scrollTop;
          return t4 >= 0 ? this._moveCursor(0, -Math.min(t4, e4.params[0] || 1)) : this._moveCursor(0, -(e4.params[0] || 1)), true;
        }
        cursorDown(e4) {
          const t4 = this._activeBuffer.scrollBottom - this._activeBuffer.y;
          return t4 >= 0 ? this._moveCursor(0, Math.min(t4, e4.params[0] || 1)) : this._moveCursor(0, e4.params[0] || 1), true;
        }
        cursorForward(e4) {
          return this._moveCursor(e4.params[0] || 1, 0), true;
        }
        cursorBackward(e4) {
          return this._moveCursor(-(e4.params[0] || 1), 0), true;
        }
        cursorNextLine(e4) {
          return this.cursorDown(e4), this._activeBuffer.x = 0, true;
        }
        cursorPrecedingLine(e4) {
          return this.cursorUp(e4), this._activeBuffer.x = 0, true;
        }
        cursorCharAbsolute(e4) {
          return this._setCursor((e4.params[0] || 1) - 1, this._activeBuffer.y), true;
        }
        cursorPosition(e4) {
          return this._setCursor(e4.length >= 2 ? (e4.params[1] || 1) - 1 : 0, (e4.params[0] || 1) - 1), true;
        }
        charPosAbsolute(e4) {
          return this._setCursor((e4.params[0] || 1) - 1, this._activeBuffer.y), true;
        }
        hPositionRelative(e4) {
          return this._moveCursor(e4.params[0] || 1, 0), true;
        }
        linePosAbsolute(e4) {
          return this._setCursor(this._activeBuffer.x, (e4.params[0] || 1) - 1), true;
        }
        vPositionRelative(e4) {
          return this._moveCursor(0, e4.params[0] || 1), true;
        }
        hVPosition(e4) {
          return this.cursorPosition(e4), true;
        }
        tabClear(e4) {
          const t4 = e4.params[0];
          return 0 === t4 ? delete this._activeBuffer.tabs[this._activeBuffer.x] : 3 === t4 && (this._activeBuffer.tabs = {}), true;
        }
        cursorForwardTab(e4) {
          if (this._activeBuffer.x >= this._bufferService.cols) return true;
          let t4 = e4.params[0] || 1;
          for (; t4--; ) this._activeBuffer.x = this._activeBuffer.nextStop();
          return true;
        }
        cursorBackwardTab(e4) {
          if (this._activeBuffer.x >= this._bufferService.cols) return true;
          let t4 = e4.params[0] || 1;
          for (; t4--; ) this._activeBuffer.x = this._activeBuffer.prevStop();
          return true;
        }
        selectProtected(e4) {
          const t4 = e4.params[0];
          return 1 === t4 && (this._curAttrData.bg |= 536870912), 2 !== t4 && 0 !== t4 || (this._curAttrData.bg &= -536870913), true;
        }
        _eraseInBufferLine(e4, t4, i4, s4 = false, r3 = false) {
          const n3 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e4);
          n3.replaceCells(t4, i4, this._activeBuffer.getNullCell(this._eraseAttrData()), r3), s4 && (n3.isWrapped = false);
        }
        _resetBufferLine(e4, t4 = false) {
          const i4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e4);
          i4 && (i4.fill(this._activeBuffer.getNullCell(this._eraseAttrData()), t4), this._bufferService.buffer.clearMarkers(this._activeBuffer.ybase + e4), i4.isWrapped = false);
        }
        eraseInDisplay(e4, t4 = false) {
          let i4;
          switch (this._restrictCursor(this._bufferService.cols), e4.params[0]) {
            case 0:
              for (i4 = this._activeBuffer.y, this._dirtyRowTracker.markDirty(i4), this._eraseInBufferLine(i4++, this._activeBuffer.x, this._bufferService.cols, 0 === this._activeBuffer.x, t4); i4 < this._bufferService.rows; i4++) this._resetBufferLine(i4, t4);
              this._dirtyRowTracker.markDirty(i4);
              break;
            case 1:
              for (i4 = this._activeBuffer.y, this._dirtyRowTracker.markDirty(i4), this._eraseInBufferLine(i4, 0, this._activeBuffer.x + 1, true, t4), this._activeBuffer.x + 1 >= this._bufferService.cols && (this._activeBuffer.lines.get(i4 + 1).isWrapped = false); i4--; ) this._resetBufferLine(i4, t4);
              this._dirtyRowTracker.markDirty(0);
              break;
            case 2:
              for (i4 = this._bufferService.rows, this._dirtyRowTracker.markDirty(i4 - 1); i4--; ) this._resetBufferLine(i4, t4);
              this._dirtyRowTracker.markDirty(0);
              break;
            case 3:
              const e5 = this._activeBuffer.lines.length - this._bufferService.rows;
              e5 > 0 && (this._activeBuffer.lines.trimStart(e5), this._activeBuffer.ybase = Math.max(this._activeBuffer.ybase - e5, 0), this._activeBuffer.ydisp = Math.max(this._activeBuffer.ydisp - e5, 0), this._onScroll.fire(0));
          }
          return true;
        }
        eraseInLine(e4, t4 = false) {
          switch (this._restrictCursor(this._bufferService.cols), e4.params[0]) {
            case 0:
              this._eraseInBufferLine(this._activeBuffer.y, this._activeBuffer.x, this._bufferService.cols, 0 === this._activeBuffer.x, t4);
              break;
            case 1:
              this._eraseInBufferLine(this._activeBuffer.y, 0, this._activeBuffer.x + 1, false, t4);
              break;
            case 2:
              this._eraseInBufferLine(this._activeBuffer.y, 0, this._bufferService.cols, true, t4);
          }
          return this._dirtyRowTracker.markDirty(this._activeBuffer.y), true;
        }
        insertLines(e4) {
          this._restrictCursor();
          let t4 = e4.params[0] || 1;
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const i4 = this._activeBuffer.ybase + this._activeBuffer.y, s4 = this._bufferService.rows - 1 - this._activeBuffer.scrollBottom, r3 = this._bufferService.rows - 1 + this._activeBuffer.ybase - s4 + 1;
          for (; t4--; ) this._activeBuffer.lines.splice(r3 - 1, 1), this._activeBuffer.lines.splice(i4, 0, this._activeBuffer.getBlankLine(this._eraseAttrData()));
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.y, this._activeBuffer.scrollBottom), this._activeBuffer.x = 0, true;
        }
        deleteLines(e4) {
          this._restrictCursor();
          let t4 = e4.params[0] || 1;
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const i4 = this._activeBuffer.ybase + this._activeBuffer.y;
          let s4;
          for (s4 = this._bufferService.rows - 1 - this._activeBuffer.scrollBottom, s4 = this._bufferService.rows - 1 + this._activeBuffer.ybase - s4; t4--; ) this._activeBuffer.lines.splice(i4, 1), this._activeBuffer.lines.splice(s4, 0, this._activeBuffer.getBlankLine(this._eraseAttrData()));
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.y, this._activeBuffer.scrollBottom), this._activeBuffer.x = 0, true;
        }
        insertChars(e4) {
          this._restrictCursor();
          const t4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y);
          return t4 && (t4.insertCells(this._activeBuffer.x, e4.params[0] || 1, this._activeBuffer.getNullCell(this._eraseAttrData())), this._dirtyRowTracker.markDirty(this._activeBuffer.y)), true;
        }
        deleteChars(e4) {
          this._restrictCursor();
          const t4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y);
          return t4 && (t4.deleteCells(this._activeBuffer.x, e4.params[0] || 1, this._activeBuffer.getNullCell(this._eraseAttrData())), this._dirtyRowTracker.markDirty(this._activeBuffer.y)), true;
        }
        scrollUp(e4) {
          let t4 = e4.params[0] || 1;
          for (; t4--; ) this._activeBuffer.lines.splice(this._activeBuffer.ybase + this._activeBuffer.scrollTop, 1), this._activeBuffer.lines.splice(this._activeBuffer.ybase + this._activeBuffer.scrollBottom, 0, this._activeBuffer.getBlankLine(this._eraseAttrData()));
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        scrollDown(e4) {
          let t4 = e4.params[0] || 1;
          for (; t4--; ) this._activeBuffer.lines.splice(this._activeBuffer.ybase + this._activeBuffer.scrollBottom, 1), this._activeBuffer.lines.splice(this._activeBuffer.ybase + this._activeBuffer.scrollTop, 0, this._activeBuffer.getBlankLine(l2.DEFAULT_ATTR_DATA));
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        scrollLeft(e4) {
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const t4 = e4.params[0] || 1;
          for (let e5 = this._activeBuffer.scrollTop; e5 <= this._activeBuffer.scrollBottom; ++e5) {
            const i4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e5);
            i4.deleteCells(0, t4, this._activeBuffer.getNullCell(this._eraseAttrData())), i4.isWrapped = false;
          }
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        scrollRight(e4) {
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const t4 = e4.params[0] || 1;
          for (let e5 = this._activeBuffer.scrollTop; e5 <= this._activeBuffer.scrollBottom; ++e5) {
            const i4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e5);
            i4.insertCells(0, t4, this._activeBuffer.getNullCell(this._eraseAttrData())), i4.isWrapped = false;
          }
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        insertColumns(e4) {
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const t4 = e4.params[0] || 1;
          for (let e5 = this._activeBuffer.scrollTop; e5 <= this._activeBuffer.scrollBottom; ++e5) {
            const i4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e5);
            i4.insertCells(this._activeBuffer.x, t4, this._activeBuffer.getNullCell(this._eraseAttrData())), i4.isWrapped = false;
          }
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        deleteColumns(e4) {
          if (this._activeBuffer.y > this._activeBuffer.scrollBottom || this._activeBuffer.y < this._activeBuffer.scrollTop) return true;
          const t4 = e4.params[0] || 1;
          for (let e5 = this._activeBuffer.scrollTop; e5 <= this._activeBuffer.scrollBottom; ++e5) {
            const i4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + e5);
            i4.deleteCells(this._activeBuffer.x, t4, this._activeBuffer.getNullCell(this._eraseAttrData())), i4.isWrapped = false;
          }
          return this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom), true;
        }
        eraseChars(e4) {
          this._restrictCursor();
          const t4 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y);
          return t4 && (t4.replaceCells(this._activeBuffer.x, this._activeBuffer.x + (e4.params[0] || 1), this._activeBuffer.getNullCell(this._eraseAttrData())), this._dirtyRowTracker.markDirty(this._activeBuffer.y)), true;
        }
        repeatPrecedingCharacter(e4) {
          const t4 = this._parser.precedingJoinState;
          if (!t4) return true;
          const i4 = e4.params[0] || 1, s4 = p2.UnicodeService.extractWidth(t4), r3 = this._activeBuffer.x - s4, n3 = this._activeBuffer.lines.get(this._activeBuffer.ybase + this._activeBuffer.y).getString(r3), o3 = new Uint32Array(n3.length * i4);
          let a3 = 0;
          for (let e5 = 0; e5 < n3.length; ) {
            const t5 = n3.codePointAt(e5) || 0;
            o3[a3++] = t5, e5 += t5 > 65535 ? 2 : 1;
          }
          let h3 = a3;
          for (let e5 = 1; e5 < i4; ++e5) o3.copyWithin(h3, 0, a3), h3 += a3;
          return this.print(o3, 0, h3), true;
        }
        sendDeviceAttributesPrimary(e4) {
          return e4.params[0] > 0 || (this._is("xterm") || this._is("rxvt-unicode") || this._is("screen") ? this._coreService.triggerDataEvent(n2.C0.ESC + "[?1;2c") : this._is("linux") && this._coreService.triggerDataEvent(n2.C0.ESC + "[?6c")), true;
        }
        sendDeviceAttributesSecondary(e4) {
          return e4.params[0] > 0 || (this._is("xterm") ? this._coreService.triggerDataEvent(n2.C0.ESC + "[>0;276;0c") : this._is("rxvt-unicode") ? this._coreService.triggerDataEvent(n2.C0.ESC + "[>85;95;0c") : this._is("linux") ? this._coreService.triggerDataEvent(e4.params[0] + "c") : this._is("screen") && this._coreService.triggerDataEvent(n2.C0.ESC + "[>83;40003;0c")), true;
        }
        _is(e4) {
          return 0 === (this._optionsService.rawOptions.termName + "").indexOf(e4);
        }
        setMode(e4) {
          for (let t4 = 0; t4 < e4.length; t4++) switch (e4.params[t4]) {
            case 4:
              this._coreService.modes.insertMode = true;
              break;
            case 20:
              this._optionsService.options.convertEol = true;
          }
          return true;
        }
        setModePrivate(e4) {
          for (let t4 = 0; t4 < e4.length; t4++) switch (e4.params[t4]) {
            case 1:
              this._coreService.decPrivateModes.applicationCursorKeys = true;
              break;
            case 2:
              this._charsetService.setgCharset(0, o2.DEFAULT_CHARSET), this._charsetService.setgCharset(1, o2.DEFAULT_CHARSET), this._charsetService.setgCharset(2, o2.DEFAULT_CHARSET), this._charsetService.setgCharset(3, o2.DEFAULT_CHARSET);
              break;
            case 3:
              this._optionsService.rawOptions.windowOptions.setWinLines && (this._bufferService.resize(132, this._bufferService.rows), this._onRequestReset.fire());
              break;
            case 6:
              this._coreService.decPrivateModes.origin = true, this._setCursor(0, 0);
              break;
            case 7:
              this._coreService.decPrivateModes.wraparound = true;
              break;
            case 12:
              this._optionsService.options.cursorBlink = true;
              break;
            case 45:
              this._coreService.decPrivateModes.reverseWraparound = true;
              break;
            case 66:
              this._logService.debug("Serial port requested application keypad."), this._coreService.decPrivateModes.applicationKeypad = true, this._onRequestSyncScrollBar.fire();
              break;
            case 9:
              this._coreMouseService.activeProtocol = "X10";
              break;
            case 1e3:
              this._coreMouseService.activeProtocol = "VT200";
              break;
            case 1002:
              this._coreMouseService.activeProtocol = "DRAG";
              break;
            case 1003:
              this._coreMouseService.activeProtocol = "ANY";
              break;
            case 1004:
              this._coreService.decPrivateModes.sendFocus = true, this._onRequestSendFocus.fire();
              break;
            case 1005:
              this._logService.debug("DECSET 1005 not supported (see #2507)");
              break;
            case 1006:
              this._coreMouseService.activeEncoding = "SGR";
              break;
            case 1015:
              this._logService.debug("DECSET 1015 not supported (see #2507)");
              break;
            case 1016:
              this._coreMouseService.activeEncoding = "SGR_PIXELS";
              break;
            case 25:
              this._coreService.isCursorHidden = false;
              break;
            case 1048:
              this.saveCursor();
              break;
            case 1049:
              this.saveCursor();
            case 47:
            case 1047:
              this._bufferService.buffers.activateAltBuffer(this._eraseAttrData()), this._coreService.isCursorInitialized = true, this._onRequestRefreshRows.fire(0, this._bufferService.rows - 1), this._onRequestSyncScrollBar.fire();
              break;
            case 2004:
              this._coreService.decPrivateModes.bracketedPasteMode = true;
          }
          return true;
        }
        resetMode(e4) {
          for (let t4 = 0; t4 < e4.length; t4++) switch (e4.params[t4]) {
            case 4:
              this._coreService.modes.insertMode = false;
              break;
            case 20:
              this._optionsService.options.convertEol = false;
          }
          return true;
        }
        resetModePrivate(e4) {
          for (let t4 = 0; t4 < e4.length; t4++) switch (e4.params[t4]) {
            case 1:
              this._coreService.decPrivateModes.applicationCursorKeys = false;
              break;
            case 3:
              this._optionsService.rawOptions.windowOptions.setWinLines && (this._bufferService.resize(80, this._bufferService.rows), this._onRequestReset.fire());
              break;
            case 6:
              this._coreService.decPrivateModes.origin = false, this._setCursor(0, 0);
              break;
            case 7:
              this._coreService.decPrivateModes.wraparound = false;
              break;
            case 12:
              this._optionsService.options.cursorBlink = false;
              break;
            case 45:
              this._coreService.decPrivateModes.reverseWraparound = false;
              break;
            case 66:
              this._logService.debug("Switching back to normal keypad."), this._coreService.decPrivateModes.applicationKeypad = false, this._onRequestSyncScrollBar.fire();
              break;
            case 9:
            case 1e3:
            case 1002:
            case 1003:
              this._coreMouseService.activeProtocol = "NONE";
              break;
            case 1004:
              this._coreService.decPrivateModes.sendFocus = false;
              break;
            case 1005:
              this._logService.debug("DECRST 1005 not supported (see #2507)");
              break;
            case 1006:
            case 1016:
              this._coreMouseService.activeEncoding = "DEFAULT";
              break;
            case 1015:
              this._logService.debug("DECRST 1015 not supported (see #2507)");
              break;
            case 25:
              this._coreService.isCursorHidden = true;
              break;
            case 1048:
              this.restoreCursor();
              break;
            case 1049:
            case 47:
            case 1047:
              this._bufferService.buffers.activateNormalBuffer(), 1049 === e4.params[t4] && this.restoreCursor(), this._coreService.isCursorInitialized = true, this._onRequestRefreshRows.fire(0, this._bufferService.rows - 1), this._onRequestSyncScrollBar.fire();
              break;
            case 2004:
              this._coreService.decPrivateModes.bracketedPasteMode = false;
          }
          return true;
        }
        requestMode(e4, t4) {
          const i4 = this._coreService.decPrivateModes, { activeProtocol: s4, activeEncoding: r3 } = this._coreMouseService, o3 = this._coreService, { buffers: a3, cols: h3 } = this._bufferService, { active: c3, alt: l3 } = a3, d3 = this._optionsService.rawOptions, _3 = /* @__PURE__ */ __name((e5) => e5 ? 1 : 2, "_"), u3 = e4.params[0];
          return f3 = u3, v3 = t4 ? 2 === u3 ? 4 : 4 === u3 ? _3(o3.modes.insertMode) : 12 === u3 ? 3 : 20 === u3 ? _3(d3.convertEol) : 0 : 1 === u3 ? _3(i4.applicationCursorKeys) : 3 === u3 ? d3.windowOptions.setWinLines ? 80 === h3 ? 2 : 132 === h3 ? 1 : 0 : 0 : 6 === u3 ? _3(i4.origin) : 7 === u3 ? _3(i4.wraparound) : 8 === u3 ? 3 : 9 === u3 ? _3("X10" === s4) : 12 === u3 ? _3(d3.cursorBlink) : 25 === u3 ? _3(!o3.isCursorHidden) : 45 === u3 ? _3(i4.reverseWraparound) : 66 === u3 ? _3(i4.applicationKeypad) : 67 === u3 ? 4 : 1e3 === u3 ? _3("VT200" === s4) : 1002 === u3 ? _3("DRAG" === s4) : 1003 === u3 ? _3("ANY" === s4) : 1004 === u3 ? _3(i4.sendFocus) : 1005 === u3 ? 4 : 1006 === u3 ? _3("SGR" === r3) : 1015 === u3 ? 4 : 1016 === u3 ? _3("SGR_PIXELS" === r3) : 1048 === u3 ? 1 : 47 === u3 || 1047 === u3 || 1049 === u3 ? _3(c3 === l3) : 2004 === u3 ? _3(i4.bracketedPasteMode) : 0, o3.triggerDataEvent(`${n2.C0.ESC}[${t4 ? "" : "?"}${f3};${v3}$y`), true;
          var f3, v3;
        }
        _updateAttrColor(e4, t4, i4, s4, r3) {
          return 2 === t4 ? (e4 |= 50331648, e4 &= -16777216, e4 |= f2.AttributeData.fromColorRGB([i4, s4, r3])) : 5 === t4 && (e4 &= -50331904, e4 |= 33554432 | 255 & i4), e4;
        }
        _extractColor(e4, t4, i4) {
          const s4 = [0, 0, -1, 0, 0, 0];
          let r3 = 0, n3 = 0;
          do {
            if (s4[n3 + r3] = e4.params[t4 + n3], e4.hasSubParams(t4 + n3)) {
              const i5 = e4.getSubParams(t4 + n3);
              let o3 = 0;
              do {
                5 === s4[1] && (r3 = 1), s4[n3 + o3 + 1 + r3] = i5[o3];
              } while (++o3 < i5.length && o3 + n3 + 1 + r3 < s4.length);
              break;
            }
            if (5 === s4[1] && n3 + r3 >= 2 || 2 === s4[1] && n3 + r3 >= 5) break;
            s4[1] && (r3 = 1);
          } while (++n3 + t4 < e4.length && n3 + r3 < s4.length);
          for (let e5 = 2; e5 < s4.length; ++e5) -1 === s4[e5] && (s4[e5] = 0);
          switch (s4[0]) {
            case 38:
              i4.fg = this._updateAttrColor(i4.fg, s4[1], s4[3], s4[4], s4[5]);
              break;
            case 48:
              i4.bg = this._updateAttrColor(i4.bg, s4[1], s4[3], s4[4], s4[5]);
              break;
            case 58:
              i4.extended = i4.extended.clone(), i4.extended.underlineColor = this._updateAttrColor(i4.extended.underlineColor, s4[1], s4[3], s4[4], s4[5]);
          }
          return n3;
        }
        _processUnderline(e4, t4) {
          t4.extended = t4.extended.clone(), (!~e4 || e4 > 5) && (e4 = 1), t4.extended.underlineStyle = e4, t4.fg |= 268435456, 0 === e4 && (t4.fg &= -268435457), t4.updateExtended();
        }
        _processSGR0(e4) {
          e4.fg = l2.DEFAULT_ATTR_DATA.fg, e4.bg = l2.DEFAULT_ATTR_DATA.bg, e4.extended = e4.extended.clone(), e4.extended.underlineStyle = 0, e4.extended.underlineColor &= -67108864, e4.updateExtended();
        }
        charAttributes(e4) {
          if (1 === e4.length && 0 === e4.params[0]) return this._processSGR0(this._curAttrData), true;
          const t4 = e4.length;
          let i4;
          const s4 = this._curAttrData;
          for (let r3 = 0; r3 < t4; r3++) i4 = e4.params[r3], i4 >= 30 && i4 <= 37 ? (s4.fg &= -50331904, s4.fg |= 16777216 | i4 - 30) : i4 >= 40 && i4 <= 47 ? (s4.bg &= -50331904, s4.bg |= 16777216 | i4 - 40) : i4 >= 90 && i4 <= 97 ? (s4.fg &= -50331904, s4.fg |= 16777224 | i4 - 90) : i4 >= 100 && i4 <= 107 ? (s4.bg &= -50331904, s4.bg |= 16777224 | i4 - 100) : 0 === i4 ? this._processSGR0(s4) : 1 === i4 ? s4.fg |= 134217728 : 3 === i4 ? s4.bg |= 67108864 : 4 === i4 ? (s4.fg |= 268435456, this._processUnderline(e4.hasSubParams(r3) ? e4.getSubParams(r3)[0] : 1, s4)) : 5 === i4 ? s4.fg |= 536870912 : 7 === i4 ? s4.fg |= 67108864 : 8 === i4 ? s4.fg |= 1073741824 : 9 === i4 ? s4.fg |= 2147483648 : 2 === i4 ? s4.bg |= 134217728 : 21 === i4 ? this._processUnderline(2, s4) : 22 === i4 ? (s4.fg &= -134217729, s4.bg &= -134217729) : 23 === i4 ? s4.bg &= -67108865 : 24 === i4 ? (s4.fg &= -268435457, this._processUnderline(0, s4)) : 25 === i4 ? s4.fg &= -536870913 : 27 === i4 ? s4.fg &= -67108865 : 28 === i4 ? s4.fg &= -1073741825 : 29 === i4 ? s4.fg &= 2147483647 : 39 === i4 ? (s4.fg &= -67108864, s4.fg |= 16777215 & l2.DEFAULT_ATTR_DATA.fg) : 49 === i4 ? (s4.bg &= -67108864, s4.bg |= 16777215 & l2.DEFAULT_ATTR_DATA.bg) : 38 === i4 || 48 === i4 || 58 === i4 ? r3 += this._extractColor(e4, r3, s4) : 53 === i4 ? s4.bg |= 1073741824 : 55 === i4 ? s4.bg &= -1073741825 : 59 === i4 ? (s4.extended = s4.extended.clone(), s4.extended.underlineColor = -1, s4.updateExtended()) : 100 === i4 ? (s4.fg &= -67108864, s4.fg |= 16777215 & l2.DEFAULT_ATTR_DATA.fg, s4.bg &= -67108864, s4.bg |= 16777215 & l2.DEFAULT_ATTR_DATA.bg) : this._logService.debug("Unknown SGR attribute: %d.", i4);
          return true;
        }
        deviceStatus(e4) {
          switch (e4.params[0]) {
            case 5:
              this._coreService.triggerDataEvent(`${n2.C0.ESC}[0n`);
              break;
            case 6:
              const e5 = this._activeBuffer.y + 1, t4 = this._activeBuffer.x + 1;
              this._coreService.triggerDataEvent(`${n2.C0.ESC}[${e5};${t4}R`);
          }
          return true;
        }
        deviceStatusPrivate(e4) {
          if (6 === e4.params[0]) {
            const e5 = this._activeBuffer.y + 1, t4 = this._activeBuffer.x + 1;
            this._coreService.triggerDataEvent(`${n2.C0.ESC}[?${e5};${t4}R`);
          }
          return true;
        }
        softReset(e4) {
          return this._coreService.isCursorHidden = false, this._onRequestSyncScrollBar.fire(), this._activeBuffer.scrollTop = 0, this._activeBuffer.scrollBottom = this._bufferService.rows - 1, this._curAttrData = l2.DEFAULT_ATTR_DATA.clone(), this._coreService.reset(), this._charsetService.reset(), this._activeBuffer.savedX = 0, this._activeBuffer.savedY = this._activeBuffer.ybase, this._activeBuffer.savedCurAttrData.fg = this._curAttrData.fg, this._activeBuffer.savedCurAttrData.bg = this._curAttrData.bg, this._activeBuffer.savedCharset = this._charsetService.charset, this._coreService.decPrivateModes.origin = false, true;
        }
        setCursorStyle(e4) {
          const t4 = e4.params[0] || 1;
          switch (t4) {
            case 1:
            case 2:
              this._optionsService.options.cursorStyle = "block";
              break;
            case 3:
            case 4:
              this._optionsService.options.cursorStyle = "underline";
              break;
            case 5:
            case 6:
              this._optionsService.options.cursorStyle = "bar";
          }
          const i4 = t4 % 2 == 1;
          return this._optionsService.options.cursorBlink = i4, true;
        }
        setScrollRegion(e4) {
          const t4 = e4.params[0] || 1;
          let i4;
          return (e4.length < 2 || (i4 = e4.params[1]) > this._bufferService.rows || 0 === i4) && (i4 = this._bufferService.rows), i4 > t4 && (this._activeBuffer.scrollTop = t4 - 1, this._activeBuffer.scrollBottom = i4 - 1, this._setCursor(0, 0)), true;
        }
        windowOptions(e4) {
          if (!w2(e4.params[0], this._optionsService.rawOptions.windowOptions)) return true;
          const t4 = e4.length > 1 ? e4.params[1] : 0;
          switch (e4.params[0]) {
            case 14:
              2 !== t4 && this._onRequestWindowsOptionsReport.fire(y2.GET_WIN_SIZE_PIXELS);
              break;
            case 16:
              this._onRequestWindowsOptionsReport.fire(y2.GET_CELL_SIZE_PIXELS);
              break;
            case 18:
              this._bufferService && this._coreService.triggerDataEvent(`${n2.C0.ESC}[8;${this._bufferService.rows};${this._bufferService.cols}t`);
              break;
            case 22:
              0 !== t4 && 2 !== t4 || (this._windowTitleStack.push(this._windowTitle), this._windowTitleStack.length > 10 && this._windowTitleStack.shift()), 0 !== t4 && 1 !== t4 || (this._iconNameStack.push(this._iconName), this._iconNameStack.length > 10 && this._iconNameStack.shift());
              break;
            case 23:
              0 !== t4 && 2 !== t4 || this._windowTitleStack.length && this.setTitle(this._windowTitleStack.pop()), 0 !== t4 && 1 !== t4 || this._iconNameStack.length && this.setIconName(this._iconNameStack.pop());
          }
          return true;
        }
        saveCursor(e4) {
          return this._activeBuffer.savedX = this._activeBuffer.x, this._activeBuffer.savedY = this._activeBuffer.ybase + this._activeBuffer.y, this._activeBuffer.savedCurAttrData.fg = this._curAttrData.fg, this._activeBuffer.savedCurAttrData.bg = this._curAttrData.bg, this._activeBuffer.savedCharset = this._charsetService.charset, true;
        }
        restoreCursor(e4) {
          return this._activeBuffer.x = this._activeBuffer.savedX || 0, this._activeBuffer.y = Math.max(this._activeBuffer.savedY - this._activeBuffer.ybase, 0), this._curAttrData.fg = this._activeBuffer.savedCurAttrData.fg, this._curAttrData.bg = this._activeBuffer.savedCurAttrData.bg, this._charsetService.charset = this._savedCharset, this._activeBuffer.savedCharset && (this._charsetService.charset = this._activeBuffer.savedCharset), this._restrictCursor(), true;
        }
        setTitle(e4) {
          return this._windowTitle = e4, this._onTitleChange.fire(e4), true;
        }
        setIconName(e4) {
          return this._iconName = e4, true;
        }
        setOrReportIndexedColor(e4) {
          const t4 = [], i4 = e4.split(";");
          for (; i4.length > 1; ) {
            const e5 = i4.shift(), s4 = i4.shift();
            if (/^\d+$/.exec(e5)) {
              const i5 = parseInt(e5);
              if (D2(i5)) if ("?" === s4) t4.push({ type: 0, index: i5 });
              else {
                const e6 = (0, S2.parseColor)(s4);
                e6 && t4.push({ type: 1, index: i5, color: e6 });
              }
            }
          }
          return t4.length && this._onColor.fire(t4), true;
        }
        setHyperlink(e4) {
          const t4 = e4.split(";");
          return !(t4.length < 2) && (t4[1] ? this._createHyperlink(t4[0], t4[1]) : !t4[0] && this._finishHyperlink());
        }
        _createHyperlink(e4, t4) {
          this._getCurrentLinkId() && this._finishHyperlink();
          const i4 = e4.split(":");
          let s4;
          const r3 = i4.findIndex((e5) => e5.startsWith("id="));
          return -1 !== r3 && (s4 = i4[r3].slice(3) || void 0), this._curAttrData.extended = this._curAttrData.extended.clone(), this._curAttrData.extended.urlId = this._oscLinkService.registerLink({ id: s4, uri: t4 }), this._curAttrData.updateExtended(), true;
        }
        _finishHyperlink() {
          return this._curAttrData.extended = this._curAttrData.extended.clone(), this._curAttrData.extended.urlId = 0, this._curAttrData.updateExtended(), true;
        }
        _setOrReportSpecialColor(e4, t4) {
          const i4 = e4.split(";");
          for (let e5 = 0; e5 < i4.length && !(t4 >= this._specialColors.length); ++e5, ++t4) if ("?" === i4[e5]) this._onColor.fire([{ type: 0, index: this._specialColors[t4] }]);
          else {
            const s4 = (0, S2.parseColor)(i4[e5]);
            s4 && this._onColor.fire([{ type: 1, index: this._specialColors[t4], color: s4 }]);
          }
          return true;
        }
        setOrReportFgColor(e4) {
          return this._setOrReportSpecialColor(e4, 0);
        }
        setOrReportBgColor(e4) {
          return this._setOrReportSpecialColor(e4, 1);
        }
        setOrReportCursorColor(e4) {
          return this._setOrReportSpecialColor(e4, 2);
        }
        restoreIndexedColor(e4) {
          if (!e4) return this._onColor.fire([{ type: 2 }]), true;
          const t4 = [], i4 = e4.split(";");
          for (let e5 = 0; e5 < i4.length; ++e5) if (/^\d+$/.exec(i4[e5])) {
            const s4 = parseInt(i4[e5]);
            D2(s4) && t4.push({ type: 2, index: s4 });
          }
          return t4.length && this._onColor.fire(t4), true;
        }
        restoreFgColor(e4) {
          return this._onColor.fire([{ type: 2, index: 256 }]), true;
        }
        restoreBgColor(e4) {
          return this._onColor.fire([{ type: 2, index: 257 }]), true;
        }
        restoreCursorColor(e4) {
          return this._onColor.fire([{ type: 2, index: 258 }]), true;
        }
        nextLine() {
          return this._activeBuffer.x = 0, this.index(), true;
        }
        keypadApplicationMode() {
          return this._logService.debug("Serial port requested application keypad."), this._coreService.decPrivateModes.applicationKeypad = true, this._onRequestSyncScrollBar.fire(), true;
        }
        keypadNumericMode() {
          return this._logService.debug("Switching back to normal keypad."), this._coreService.decPrivateModes.applicationKeypad = false, this._onRequestSyncScrollBar.fire(), true;
        }
        selectDefaultCharset() {
          return this._charsetService.setgLevel(0), this._charsetService.setgCharset(0, o2.DEFAULT_CHARSET), true;
        }
        selectCharset(e4) {
          return 2 !== e4.length ? (this.selectDefaultCharset(), true) : ("/" === e4[0] || this._charsetService.setgCharset(C2[e4[0]], o2.CHARSETS[e4[1]] || o2.DEFAULT_CHARSET), true);
        }
        index() {
          return this._restrictCursor(), this._activeBuffer.y++, this._activeBuffer.y === this._activeBuffer.scrollBottom + 1 ? (this._activeBuffer.y--, this._bufferService.scroll(this._eraseAttrData())) : this._activeBuffer.y >= this._bufferService.rows && (this._activeBuffer.y = this._bufferService.rows - 1), this._restrictCursor(), true;
        }
        tabSet() {
          return this._activeBuffer.tabs[this._activeBuffer.x] = true, true;
        }
        reverseIndex() {
          if (this._restrictCursor(), this._activeBuffer.y === this._activeBuffer.scrollTop) {
            const e4 = this._activeBuffer.scrollBottom - this._activeBuffer.scrollTop;
            this._activeBuffer.lines.shiftElements(this._activeBuffer.ybase + this._activeBuffer.y, e4, 1), this._activeBuffer.lines.set(this._activeBuffer.ybase + this._activeBuffer.y, this._activeBuffer.getBlankLine(this._eraseAttrData())), this._dirtyRowTracker.markRangeDirty(this._activeBuffer.scrollTop, this._activeBuffer.scrollBottom);
          } else this._activeBuffer.y--, this._restrictCursor();
          return true;
        }
        fullReset() {
          return this._parser.reset(), this._onRequestReset.fire(), true;
        }
        reset() {
          this._curAttrData = l2.DEFAULT_ATTR_DATA.clone(), this._eraseAttrDataInternal = l2.DEFAULT_ATTR_DATA.clone();
        }
        _eraseAttrData() {
          return this._eraseAttrDataInternal.bg &= -67108864, this._eraseAttrDataInternal.bg |= 67108863 & this._curAttrData.bg, this._eraseAttrDataInternal;
        }
        setgLevel(e4) {
          return this._charsetService.setgLevel(e4), true;
        }
        screenAlignmentPattern() {
          const e4 = new u2.CellData();
          e4.content = 1 << 22 | "E".charCodeAt(0), e4.fg = this._curAttrData.fg, e4.bg = this._curAttrData.bg, this._setCursor(0, 0);
          for (let t4 = 0; t4 < this._bufferService.rows; ++t4) {
            const i4 = this._activeBuffer.ybase + this._activeBuffer.y + t4, s4 = this._activeBuffer.lines.get(i4);
            s4 && (s4.fill(e4), s4.isWrapped = false);
          }
          return this._dirtyRowTracker.markAllDirty(), this._setCursor(0, 0), true;
        }
        requestStatusString(e4, t4) {
          const i4 = this._bufferService.buffer, s4 = this._optionsService.rawOptions;
          return ((e5) => (this._coreService.triggerDataEvent(`${n2.C0.ESC}${e5}${n2.C0.ESC}\\`), true))('"q' === e4 ? `P1$r${this._curAttrData.isProtected() ? 1 : 0}"q` : '"p' === e4 ? 'P1$r61;1"p' : "r" === e4 ? `P1$r${i4.scrollTop + 1};${i4.scrollBottom + 1}r` : "m" === e4 ? "P1$r0m" : " q" === e4 ? `P1$r${{ block: 2, underline: 4, bar: 6 }[s4.cursorStyle] - (s4.cursorBlink ? 1 : 0)} q` : "P0$r");
        }
        markRangeDirty(e4, t4) {
          this._dirtyRowTracker.markRangeDirty(e4, t4);
        }
      }
      t3.InputHandler = k2;
      let L2 = class {
        static {
          __name(this, "L");
        }
        constructor(e4) {
          this._bufferService = e4, this.clearRange();
        }
        clearRange() {
          this.start = this._bufferService.buffer.y, this.end = this._bufferService.buffer.y;
        }
        markDirty(e4) {
          e4 < this.start ? this.start = e4 : e4 > this.end && (this.end = e4);
        }
        markRangeDirty(e4, t4) {
          e4 > t4 && (E = e4, e4 = t4, t4 = E), e4 < this.start && (this.start = e4), t4 > this.end && (this.end = t4);
        }
        markAllDirty() {
          this.markRangeDirty(0, this._bufferService.rows - 1);
        }
      };
      function D2(e4) {
        return 0 <= e4 && e4 < 256;
      }
      __name(D2, "D");
      L2 = s3([r2(0, v2.IBufferService)], L2);
    }, 844: (e3, t3) => {
      function i3(e4) {
        for (const t4 of e4) t4.dispose();
        e4.length = 0;
      }
      __name(i3, "i");
      Object.defineProperty(t3, "__esModule", { value: true }), t3.getDisposeArrayDisposable = t3.disposeArray = t3.toDisposable = t3.MutableDisposable = t3.Disposable = void 0, t3.Disposable = class {
        constructor() {
          this._disposables = [], this._isDisposed = false;
        }
        dispose() {
          this._isDisposed = true;
          for (const e4 of this._disposables) e4.dispose();
          this._disposables.length = 0;
        }
        register(e4) {
          return this._disposables.push(e4), e4;
        }
        unregister(e4) {
          const t4 = this._disposables.indexOf(e4);
          -1 !== t4 && this._disposables.splice(t4, 1);
        }
      }, t3.MutableDisposable = class {
        constructor() {
          this._isDisposed = false;
        }
        get value() {
          return this._isDisposed ? void 0 : this._value;
        }
        set value(e4) {
          this._isDisposed || e4 === this._value || (this._value?.dispose(), this._value = e4);
        }
        clear() {
          this.value = void 0;
        }
        dispose() {
          this._isDisposed = true, this._value?.dispose(), this._value = void 0;
        }
      }, t3.toDisposable = function(e4) {
        return { dispose: e4 };
      }, t3.disposeArray = i3, t3.getDisposeArrayDisposable = function(e4) {
        return { dispose: /* @__PURE__ */ __name(() => i3(e4), "dispose") };
      };
    }, 1505: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.FourKeyMap = t3.TwoKeyMap = void 0;
      class i3 {
        static {
          __name(this, "i");
        }
        constructor() {
          this._data = {};
        }
        set(e4, t4, i4) {
          this._data[e4] || (this._data[e4] = {}), this._data[e4][t4] = i4;
        }
        get(e4, t4) {
          return this._data[e4] ? this._data[e4][t4] : void 0;
        }
        clear() {
          this._data = {};
        }
      }
      t3.TwoKeyMap = i3, t3.FourKeyMap = class {
        constructor() {
          this._data = new i3();
        }
        set(e4, t4, s3, r2, n2) {
          this._data.get(e4, t4) || this._data.set(e4, t4, new i3()), this._data.get(e4, t4).set(s3, r2, n2);
        }
        get(e4, t4, i4, s3) {
          return this._data.get(e4, t4)?.get(i4, s3);
        }
        clear() {
          this._data.clear();
        }
      };
    }, 6114: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.isChromeOS = t3.isLinux = t3.isWindows = t3.isIphone = t3.isIpad = t3.isMac = t3.getSafariVersion = t3.isSafari = t3.isLegacyEdge = t3.isFirefox = t3.isNode = void 0, t3.isNode = "undefined" != typeof process && "title" in process;
      const i3 = t3.isNode ? "node" : navigator.userAgent, s3 = t3.isNode ? "node" : navigator.platform;
      t3.isFirefox = i3.includes("Firefox"), t3.isLegacyEdge = i3.includes("Edge"), t3.isSafari = /^((?!chrome|android).)*safari/i.test(i3), t3.getSafariVersion = function() {
        if (!t3.isSafari) return 0;
        const e4 = i3.match(/Version\/(\d+)/);
        return null === e4 || e4.length < 2 ? 0 : parseInt(e4[1]);
      }, t3.isMac = ["Macintosh", "MacIntel", "MacPPC", "Mac68K"].includes(s3), t3.isIpad = "iPad" === s3, t3.isIphone = "iPhone" === s3, t3.isWindows = ["Windows", "Win16", "Win32", "WinCE"].includes(s3), t3.isLinux = s3.indexOf("Linux") >= 0, t3.isChromeOS = /\bCrOS\b/.test(i3);
    }, 6106: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.SortedList = void 0;
      let i3 = 0;
      t3.SortedList = class {
        constructor(e4) {
          this._getKey = e4, this._array = [];
        }
        clear() {
          this._array.length = 0;
        }
        insert(e4) {
          0 !== this._array.length ? (i3 = this._search(this._getKey(e4)), this._array.splice(i3, 0, e4)) : this._array.push(e4);
        }
        delete(e4) {
          if (0 === this._array.length) return false;
          const t4 = this._getKey(e4);
          if (void 0 === t4) return false;
          if (i3 = this._search(t4), -1 === i3) return false;
          if (this._getKey(this._array[i3]) !== t4) return false;
          do {
            if (this._array[i3] === e4) return this._array.splice(i3, 1), true;
          } while (++i3 < this._array.length && this._getKey(this._array[i3]) === t4);
          return false;
        }
        *getKeyIterator(e4) {
          if (0 !== this._array.length && (i3 = this._search(e4), !(i3 < 0 || i3 >= this._array.length) && this._getKey(this._array[i3]) === e4)) do {
            yield this._array[i3];
          } while (++i3 < this._array.length && this._getKey(this._array[i3]) === e4);
        }
        forEachByKey(e4, t4) {
          if (0 !== this._array.length && (i3 = this._search(e4), !(i3 < 0 || i3 >= this._array.length) && this._getKey(this._array[i3]) === e4)) do {
            t4(this._array[i3]);
          } while (++i3 < this._array.length && this._getKey(this._array[i3]) === e4);
        }
        values() {
          return [...this._array].values();
        }
        _search(e4) {
          let t4 = 0, i4 = this._array.length - 1;
          for (; i4 >= t4; ) {
            let s3 = t4 + i4 >> 1;
            const r2 = this._getKey(this._array[s3]);
            if (r2 > e4) i4 = s3 - 1;
            else {
              if (!(r2 < e4)) {
                for (; s3 > 0 && this._getKey(this._array[s3 - 1]) === e4; ) s3--;
                return s3;
              }
              t4 = s3 + 1;
            }
          }
          return t4;
        }
      };
    }, 7226: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DebouncedIdleTask = t3.IdleTaskQueue = t3.PriorityTaskQueue = void 0;
      const s3 = i3(6114);
      class r2 {
        static {
          __name(this, "r");
        }
        constructor() {
          this._tasks = [], this._i = 0;
        }
        enqueue(e4) {
          this._tasks.push(e4), this._start();
        }
        flush() {
          for (; this._i < this._tasks.length; ) this._tasks[this._i]() || this._i++;
          this.clear();
        }
        clear() {
          this._idleCallback && (this._cancelCallback(this._idleCallback), this._idleCallback = void 0), this._i = 0, this._tasks.length = 0;
        }
        _start() {
          this._idleCallback || (this._idleCallback = this._requestCallback(this._process.bind(this)));
        }
        _process(e4) {
          this._idleCallback = void 0;
          let t4 = 0, i4 = 0, s4 = e4.timeRemaining(), r3 = 0;
          for (; this._i < this._tasks.length; ) {
            if (t4 = Date.now(), this._tasks[this._i]() || this._i++, t4 = Math.max(1, Date.now() - t4), i4 = Math.max(t4, i4), r3 = e4.timeRemaining(), 1.5 * i4 > r3) return s4 - t4 < -20 && console.warn(`task queue exceeded allotted deadline by ${Math.abs(Math.round(s4 - t4))}ms`), void this._start();
            s4 = r3;
          }
          this.clear();
        }
      }
      class n2 extends r2 {
        static {
          __name(this, "n");
        }
        _requestCallback(e4) {
          return setTimeout(() => e4(this._createDeadline(16)));
        }
        _cancelCallback(e4) {
          clearTimeout(e4);
        }
        _createDeadline(e4) {
          const t4 = Date.now() + e4;
          return { timeRemaining: /* @__PURE__ */ __name(() => Math.max(0, t4 - Date.now()), "timeRemaining") };
        }
      }
      t3.PriorityTaskQueue = n2, t3.IdleTaskQueue = !s3.isNode && "requestIdleCallback" in window ? class extends r2 {
        _requestCallback(e4) {
          return requestIdleCallback(e4);
        }
        _cancelCallback(e4) {
          cancelIdleCallback(e4);
        }
      } : n2, t3.DebouncedIdleTask = class {
        constructor() {
          this._queue = new t3.IdleTaskQueue();
        }
        set(e4) {
          this._queue.clear(), this._queue.enqueue(e4);
        }
        flush() {
          this._queue.flush();
        }
      };
    }, 9282: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.updateWindowsModeWrappedState = void 0;
      const s3 = i3(643);
      t3.updateWindowsModeWrappedState = function(e4) {
        const t4 = e4.buffer.lines.get(e4.buffer.ybase + e4.buffer.y - 1), i4 = t4?.get(e4.cols - 1), r2 = e4.buffer.lines.get(e4.buffer.ybase + e4.buffer.y);
        r2 && i4 && (r2.isWrapped = i4[s3.CHAR_DATA_CODE_INDEX] !== s3.NULL_CELL_CODE && i4[s3.CHAR_DATA_CODE_INDEX] !== s3.WHITESPACE_CELL_CODE);
      };
    }, 3734: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ExtendedAttrs = t3.AttributeData = void 0;
      class i3 {
        static {
          __name(this, "i");
        }
        constructor() {
          this.fg = 0, this.bg = 0, this.extended = new s3();
        }
        static toColorRGB(e4) {
          return [e4 >>> 16 & 255, e4 >>> 8 & 255, 255 & e4];
        }
        static fromColorRGB(e4) {
          return (255 & e4[0]) << 16 | (255 & e4[1]) << 8 | 255 & e4[2];
        }
        clone() {
          const e4 = new i3();
          return e4.fg = this.fg, e4.bg = this.bg, e4.extended = this.extended.clone(), e4;
        }
        isInverse() {
          return 67108864 & this.fg;
        }
        isBold() {
          return 134217728 & this.fg;
        }
        isUnderline() {
          return this.hasExtendedAttrs() && 0 !== this.extended.underlineStyle ? 1 : 268435456 & this.fg;
        }
        isBlink() {
          return 536870912 & this.fg;
        }
        isInvisible() {
          return 1073741824 & this.fg;
        }
        isItalic() {
          return 67108864 & this.bg;
        }
        isDim() {
          return 134217728 & this.bg;
        }
        isStrikethrough() {
          return 2147483648 & this.fg;
        }
        isProtected() {
          return 536870912 & this.bg;
        }
        isOverline() {
          return 1073741824 & this.bg;
        }
        getFgColorMode() {
          return 50331648 & this.fg;
        }
        getBgColorMode() {
          return 50331648 & this.bg;
        }
        isFgRGB() {
          return 50331648 == (50331648 & this.fg);
        }
        isBgRGB() {
          return 50331648 == (50331648 & this.bg);
        }
        isFgPalette() {
          return 16777216 == (50331648 & this.fg) || 33554432 == (50331648 & this.fg);
        }
        isBgPalette() {
          return 16777216 == (50331648 & this.bg) || 33554432 == (50331648 & this.bg);
        }
        isFgDefault() {
          return 0 == (50331648 & this.fg);
        }
        isBgDefault() {
          return 0 == (50331648 & this.bg);
        }
        isAttributeDefault() {
          return 0 === this.fg && 0 === this.bg;
        }
        getFgColor() {
          switch (50331648 & this.fg) {
            case 16777216:
            case 33554432:
              return 255 & this.fg;
            case 50331648:
              return 16777215 & this.fg;
            default:
              return -1;
          }
        }
        getBgColor() {
          switch (50331648 & this.bg) {
            case 16777216:
            case 33554432:
              return 255 & this.bg;
            case 50331648:
              return 16777215 & this.bg;
            default:
              return -1;
          }
        }
        hasExtendedAttrs() {
          return 268435456 & this.bg;
        }
        updateExtended() {
          this.extended.isEmpty() ? this.bg &= -268435457 : this.bg |= 268435456;
        }
        getUnderlineColor() {
          if (268435456 & this.bg && ~this.extended.underlineColor) switch (50331648 & this.extended.underlineColor) {
            case 16777216:
            case 33554432:
              return 255 & this.extended.underlineColor;
            case 50331648:
              return 16777215 & this.extended.underlineColor;
            default:
              return this.getFgColor();
          }
          return this.getFgColor();
        }
        getUnderlineColorMode() {
          return 268435456 & this.bg && ~this.extended.underlineColor ? 50331648 & this.extended.underlineColor : this.getFgColorMode();
        }
        isUnderlineColorRGB() {
          return 268435456 & this.bg && ~this.extended.underlineColor ? 50331648 == (50331648 & this.extended.underlineColor) : this.isFgRGB();
        }
        isUnderlineColorPalette() {
          return 268435456 & this.bg && ~this.extended.underlineColor ? 16777216 == (50331648 & this.extended.underlineColor) || 33554432 == (50331648 & this.extended.underlineColor) : this.isFgPalette();
        }
        isUnderlineColorDefault() {
          return 268435456 & this.bg && ~this.extended.underlineColor ? 0 == (50331648 & this.extended.underlineColor) : this.isFgDefault();
        }
        getUnderlineStyle() {
          return 268435456 & this.fg ? 268435456 & this.bg ? this.extended.underlineStyle : 1 : 0;
        }
        getUnderlineVariantOffset() {
          return this.extended.underlineVariantOffset;
        }
      }
      t3.AttributeData = i3;
      class s3 {
        static {
          __name(this, "s");
        }
        get ext() {
          return this._urlId ? -469762049 & this._ext | this.underlineStyle << 26 : this._ext;
        }
        set ext(e4) {
          this._ext = e4;
        }
        get underlineStyle() {
          return this._urlId ? 5 : (469762048 & this._ext) >> 26;
        }
        set underlineStyle(e4) {
          this._ext &= -469762049, this._ext |= e4 << 26 & 469762048;
        }
        get underlineColor() {
          return 67108863 & this._ext;
        }
        set underlineColor(e4) {
          this._ext &= -67108864, this._ext |= 67108863 & e4;
        }
        get urlId() {
          return this._urlId;
        }
        set urlId(e4) {
          this._urlId = e4;
        }
        get underlineVariantOffset() {
          const e4 = (3758096384 & this._ext) >> 29;
          return e4 < 0 ? 4294967288 ^ e4 : e4;
        }
        set underlineVariantOffset(e4) {
          this._ext &= 536870911, this._ext |= e4 << 29 & 3758096384;
        }
        constructor(e4 = 0, t4 = 0) {
          this._ext = 0, this._urlId = 0, this._ext = e4, this._urlId = t4;
        }
        clone() {
          return new s3(this._ext, this._urlId);
        }
        isEmpty() {
          return 0 === this.underlineStyle && 0 === this._urlId;
        }
      }
      t3.ExtendedAttrs = s3;
    }, 9092: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Buffer = t3.MAX_BUFFER_SIZE = void 0;
      const s3 = i3(6349), r2 = i3(7226), n2 = i3(3734), o2 = i3(8437), a2 = i3(4634), h2 = i3(511), c2 = i3(643), l2 = i3(4863), d2 = i3(7116);
      t3.MAX_BUFFER_SIZE = 4294967295, t3.Buffer = class {
        constructor(e4, t4, i4) {
          this._hasScrollback = e4, this._optionsService = t4, this._bufferService = i4, this.ydisp = 0, this.ybase = 0, this.y = 0, this.x = 0, this.tabs = {}, this.savedY = 0, this.savedX = 0, this.savedCurAttrData = o2.DEFAULT_ATTR_DATA.clone(), this.savedCharset = d2.DEFAULT_CHARSET, this.markers = [], this._nullCell = h2.CellData.fromCharData([0, c2.NULL_CELL_CHAR, c2.NULL_CELL_WIDTH, c2.NULL_CELL_CODE]), this._whitespaceCell = h2.CellData.fromCharData([0, c2.WHITESPACE_CELL_CHAR, c2.WHITESPACE_CELL_WIDTH, c2.WHITESPACE_CELL_CODE]), this._isClearing = false, this._memoryCleanupQueue = new r2.IdleTaskQueue(), this._memoryCleanupPosition = 0, this._cols = this._bufferService.cols, this._rows = this._bufferService.rows, this.lines = new s3.CircularList(this._getCorrectBufferLength(this._rows)), this.scrollTop = 0, this.scrollBottom = this._rows - 1, this.setupTabStops();
        }
        getNullCell(e4) {
          return e4 ? (this._nullCell.fg = e4.fg, this._nullCell.bg = e4.bg, this._nullCell.extended = e4.extended) : (this._nullCell.fg = 0, this._nullCell.bg = 0, this._nullCell.extended = new n2.ExtendedAttrs()), this._nullCell;
        }
        getWhitespaceCell(e4) {
          return e4 ? (this._whitespaceCell.fg = e4.fg, this._whitespaceCell.bg = e4.bg, this._whitespaceCell.extended = e4.extended) : (this._whitespaceCell.fg = 0, this._whitespaceCell.bg = 0, this._whitespaceCell.extended = new n2.ExtendedAttrs()), this._whitespaceCell;
        }
        getBlankLine(e4, t4) {
          return new o2.BufferLine(this._bufferService.cols, this.getNullCell(e4), t4);
        }
        get hasScrollback() {
          return this._hasScrollback && this.lines.maxLength > this._rows;
        }
        get isCursorInViewport() {
          const e4 = this.ybase + this.y - this.ydisp;
          return e4 >= 0 && e4 < this._rows;
        }
        _getCorrectBufferLength(e4) {
          if (!this._hasScrollback) return e4;
          const i4 = e4 + this._optionsService.rawOptions.scrollback;
          return i4 > t3.MAX_BUFFER_SIZE ? t3.MAX_BUFFER_SIZE : i4;
        }
        fillViewportRows(e4) {
          if (0 === this.lines.length) {
            void 0 === e4 && (e4 = o2.DEFAULT_ATTR_DATA);
            let t4 = this._rows;
            for (; t4--; ) this.lines.push(this.getBlankLine(e4));
          }
        }
        clear() {
          this.ydisp = 0, this.ybase = 0, this.y = 0, this.x = 0, this.lines = new s3.CircularList(this._getCorrectBufferLength(this._rows)), this.scrollTop = 0, this.scrollBottom = this._rows - 1, this.setupTabStops();
        }
        resize(e4, t4) {
          const i4 = this.getNullCell(o2.DEFAULT_ATTR_DATA);
          let s4 = 0;
          const r3 = this._getCorrectBufferLength(t4);
          if (r3 > this.lines.maxLength && (this.lines.maxLength = r3), this.lines.length > 0) {
            if (this._cols < e4) for (let t5 = 0; t5 < this.lines.length; t5++) s4 += +this.lines.get(t5).resize(e4, i4);
            let n3 = 0;
            if (this._rows < t4) for (let s5 = this._rows; s5 < t4; s5++) this.lines.length < t4 + this.ybase && (this._optionsService.rawOptions.windowsMode || void 0 !== this._optionsService.rawOptions.windowsPty.backend || void 0 !== this._optionsService.rawOptions.windowsPty.buildNumber ? this.lines.push(new o2.BufferLine(e4, i4)) : this.ybase > 0 && this.lines.length <= this.ybase + this.y + n3 + 1 ? (this.ybase--, n3++, this.ydisp > 0 && this.ydisp--) : this.lines.push(new o2.BufferLine(e4, i4)));
            else for (let e5 = this._rows; e5 > t4; e5--) this.lines.length > t4 + this.ybase && (this.lines.length > this.ybase + this.y + 1 ? this.lines.pop() : (this.ybase++, this.ydisp++));
            if (r3 < this.lines.maxLength) {
              const e5 = this.lines.length - r3;
              e5 > 0 && (this.lines.trimStart(e5), this.ybase = Math.max(this.ybase - e5, 0), this.ydisp = Math.max(this.ydisp - e5, 0), this.savedY = Math.max(this.savedY - e5, 0)), this.lines.maxLength = r3;
            }
            this.x = Math.min(this.x, e4 - 1), this.y = Math.min(this.y, t4 - 1), n3 && (this.y += n3), this.savedX = Math.min(this.savedX, e4 - 1), this.scrollTop = 0;
          }
          if (this.scrollBottom = t4 - 1, this._isReflowEnabled && (this._reflow(e4, t4), this._cols > e4)) for (let t5 = 0; t5 < this.lines.length; t5++) s4 += +this.lines.get(t5).resize(e4, i4);
          this._cols = e4, this._rows = t4, this._memoryCleanupQueue.clear(), s4 > 0.1 * this.lines.length && (this._memoryCleanupPosition = 0, this._memoryCleanupQueue.enqueue(() => this._batchedMemoryCleanup()));
        }
        _batchedMemoryCleanup() {
          let e4 = true;
          this._memoryCleanupPosition >= this.lines.length && (this._memoryCleanupPosition = 0, e4 = false);
          let t4 = 0;
          for (; this._memoryCleanupPosition < this.lines.length; ) if (t4 += this.lines.get(this._memoryCleanupPosition++).cleanupMemory(), t4 > 100) return true;
          return e4;
        }
        get _isReflowEnabled() {
          const e4 = this._optionsService.rawOptions.windowsPty;
          return e4 && e4.buildNumber ? this._hasScrollback && "conpty" === e4.backend && e4.buildNumber >= 21376 : this._hasScrollback && !this._optionsService.rawOptions.windowsMode;
        }
        _reflow(e4, t4) {
          this._cols !== e4 && (e4 > this._cols ? this._reflowLarger(e4, t4) : this._reflowSmaller(e4, t4));
        }
        _reflowLarger(e4, t4) {
          const i4 = (0, a2.reflowLargerGetLinesToRemove)(this.lines, this._cols, e4, this.ybase + this.y, this.getNullCell(o2.DEFAULT_ATTR_DATA));
          if (i4.length > 0) {
            const s4 = (0, a2.reflowLargerCreateNewLayout)(this.lines, i4);
            (0, a2.reflowLargerApplyNewLayout)(this.lines, s4.layout), this._reflowLargerAdjustViewport(e4, t4, s4.countRemoved);
          }
        }
        _reflowLargerAdjustViewport(e4, t4, i4) {
          const s4 = this.getNullCell(o2.DEFAULT_ATTR_DATA);
          let r3 = i4;
          for (; r3-- > 0; ) 0 === this.ybase ? (this.y > 0 && this.y--, this.lines.length < t4 && this.lines.push(new o2.BufferLine(e4, s4))) : (this.ydisp === this.ybase && this.ydisp--, this.ybase--);
          this.savedY = Math.max(this.savedY - i4, 0);
        }
        _reflowSmaller(e4, t4) {
          const i4 = this.getNullCell(o2.DEFAULT_ATTR_DATA), s4 = [];
          let r3 = 0;
          for (let n3 = this.lines.length - 1; n3 >= 0; n3--) {
            let h3 = this.lines.get(n3);
            if (!h3 || !h3.isWrapped && h3.getTrimmedLength() <= e4) continue;
            const c3 = [h3];
            for (; h3.isWrapped && n3 > 0; ) h3 = this.lines.get(--n3), c3.unshift(h3);
            const l3 = this.ybase + this.y;
            if (l3 >= n3 && l3 < n3 + c3.length) continue;
            const d3 = c3[c3.length - 1].getTrimmedLength(), _2 = (0, a2.reflowSmallerGetNewLineLengths)(c3, this._cols, e4), u2 = _2.length - c3.length;
            let f2;
            f2 = 0 === this.ybase && this.y !== this.lines.length - 1 ? Math.max(0, this.y - this.lines.maxLength + u2) : Math.max(0, this.lines.length - this.lines.maxLength + u2);
            const v2 = [];
            for (let e5 = 0; e5 < u2; e5++) {
              const e6 = this.getBlankLine(o2.DEFAULT_ATTR_DATA, true);
              v2.push(e6);
            }
            v2.length > 0 && (s4.push({ start: n3 + c3.length + r3, newLines: v2 }), r3 += v2.length), c3.push(...v2);
            let p2 = _2.length - 1, g2 = _2[p2];
            0 === g2 && (p2--, g2 = _2[p2]);
            let m2 = c3.length - u2 - 1, S2 = d3;
            for (; m2 >= 0; ) {
              const e5 = Math.min(S2, g2);
              if (void 0 === c3[p2]) break;
              if (c3[p2].copyCellsFrom(c3[m2], S2 - e5, g2 - e5, e5, true), g2 -= e5, 0 === g2 && (p2--, g2 = _2[p2]), S2 -= e5, 0 === S2) {
                m2--;
                const e6 = Math.max(m2, 0);
                S2 = (0, a2.getWrappedLineTrimmedLength)(c3, e6, this._cols);
              }
            }
            for (let t5 = 0; t5 < c3.length; t5++) _2[t5] < e4 && c3[t5].setCell(_2[t5], i4);
            let C2 = u2 - f2;
            for (; C2-- > 0; ) 0 === this.ybase ? this.y < t4 - 1 ? (this.y++, this.lines.pop()) : (this.ybase++, this.ydisp++) : this.ybase < Math.min(this.lines.maxLength, this.lines.length + r3) - t4 && (this.ybase === this.ydisp && this.ydisp++, this.ybase++);
            this.savedY = Math.min(this.savedY + u2, this.ybase + t4 - 1);
          }
          if (s4.length > 0) {
            const e5 = [], t5 = [];
            for (let e6 = 0; e6 < this.lines.length; e6++) t5.push(this.lines.get(e6));
            const i5 = this.lines.length;
            let n3 = i5 - 1, o3 = 0, a3 = s4[o3];
            this.lines.length = Math.min(this.lines.maxLength, this.lines.length + r3);
            let h3 = 0;
            for (let c4 = Math.min(this.lines.maxLength - 1, i5 + r3 - 1); c4 >= 0; c4--) if (a3 && a3.start > n3 + h3) {
              for (let e6 = a3.newLines.length - 1; e6 >= 0; e6--) this.lines.set(c4--, a3.newLines[e6]);
              c4++, e5.push({ index: n3 + 1, amount: a3.newLines.length }), h3 += a3.newLines.length, a3 = s4[++o3];
            } else this.lines.set(c4, t5[n3--]);
            let c3 = 0;
            for (let t6 = e5.length - 1; t6 >= 0; t6--) e5[t6].index += c3, this.lines.onInsertEmitter.fire(e5[t6]), c3 += e5[t6].amount;
            const l3 = Math.max(0, i5 + r3 - this.lines.maxLength);
            l3 > 0 && this.lines.onTrimEmitter.fire(l3);
          }
        }
        translateBufferLineToString(e4, t4, i4 = 0, s4) {
          const r3 = this.lines.get(e4);
          return r3 ? r3.translateToString(t4, i4, s4) : "";
        }
        getWrappedRangeForLine(e4) {
          let t4 = e4, i4 = e4;
          for (; t4 > 0 && this.lines.get(t4).isWrapped; ) t4--;
          for (; i4 + 1 < this.lines.length && this.lines.get(i4 + 1).isWrapped; ) i4++;
          return { first: t4, last: i4 };
        }
        setupTabStops(e4) {
          for (null != e4 ? this.tabs[e4] || (e4 = this.prevStop(e4)) : (this.tabs = {}, e4 = 0); e4 < this._cols; e4 += this._optionsService.rawOptions.tabStopWidth) this.tabs[e4] = true;
        }
        prevStop(e4) {
          for (null == e4 && (e4 = this.x); !this.tabs[--e4] && e4 > 0; ) ;
          return e4 >= this._cols ? this._cols - 1 : e4 < 0 ? 0 : e4;
        }
        nextStop(e4) {
          for (null == e4 && (e4 = this.x); !this.tabs[++e4] && e4 < this._cols; ) ;
          return e4 >= this._cols ? this._cols - 1 : e4 < 0 ? 0 : e4;
        }
        clearMarkers(e4) {
          this._isClearing = true;
          for (let t4 = 0; t4 < this.markers.length; t4++) this.markers[t4].line === e4 && (this.markers[t4].dispose(), this.markers.splice(t4--, 1));
          this._isClearing = false;
        }
        clearAllMarkers() {
          this._isClearing = true;
          for (let e4 = 0; e4 < this.markers.length; e4++) this.markers[e4].dispose(), this.markers.splice(e4--, 1);
          this._isClearing = false;
        }
        addMarker(e4) {
          const t4 = new l2.Marker(e4);
          return this.markers.push(t4), t4.register(this.lines.onTrim((e5) => {
            t4.line -= e5, t4.line < 0 && t4.dispose();
          })), t4.register(this.lines.onInsert((e5) => {
            t4.line >= e5.index && (t4.line += e5.amount);
          })), t4.register(this.lines.onDelete((e5) => {
            t4.line >= e5.index && t4.line < e5.index + e5.amount && t4.dispose(), t4.line > e5.index && (t4.line -= e5.amount);
          })), t4.register(t4.onDispose(() => this._removeMarker(t4))), t4;
        }
        _removeMarker(e4) {
          this._isClearing || this.markers.splice(this.markers.indexOf(e4), 1);
        }
      };
    }, 8437: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferLine = t3.DEFAULT_ATTR_DATA = void 0;
      const s3 = i3(3734), r2 = i3(511), n2 = i3(643), o2 = i3(482);
      t3.DEFAULT_ATTR_DATA = Object.freeze(new s3.AttributeData());
      let a2 = 0;
      class h2 {
        static {
          __name(this, "h");
        }
        constructor(e4, t4, i4 = false) {
          this.isWrapped = i4, this._combined = {}, this._extendedAttrs = {}, this._data = new Uint32Array(3 * e4);
          const s4 = t4 || r2.CellData.fromCharData([0, n2.NULL_CELL_CHAR, n2.NULL_CELL_WIDTH, n2.NULL_CELL_CODE]);
          for (let t5 = 0; t5 < e4; ++t5) this.setCell(t5, s4);
          this.length = e4;
        }
        get(e4) {
          const t4 = this._data[3 * e4 + 0], i4 = 2097151 & t4;
          return [this._data[3 * e4 + 1], 2097152 & t4 ? this._combined[e4] : i4 ? (0, o2.stringFromCodePoint)(i4) : "", t4 >> 22, 2097152 & t4 ? this._combined[e4].charCodeAt(this._combined[e4].length - 1) : i4];
        }
        set(e4, t4) {
          this._data[3 * e4 + 1] = t4[n2.CHAR_DATA_ATTR_INDEX], t4[n2.CHAR_DATA_CHAR_INDEX].length > 1 ? (this._combined[e4] = t4[1], this._data[3 * e4 + 0] = 2097152 | e4 | t4[n2.CHAR_DATA_WIDTH_INDEX] << 22) : this._data[3 * e4 + 0] = t4[n2.CHAR_DATA_CHAR_INDEX].charCodeAt(0) | t4[n2.CHAR_DATA_WIDTH_INDEX] << 22;
        }
        getWidth(e4) {
          return this._data[3 * e4 + 0] >> 22;
        }
        hasWidth(e4) {
          return 12582912 & this._data[3 * e4 + 0];
        }
        getFg(e4) {
          return this._data[3 * e4 + 1];
        }
        getBg(e4) {
          return this._data[3 * e4 + 2];
        }
        hasContent(e4) {
          return 4194303 & this._data[3 * e4 + 0];
        }
        getCodePoint(e4) {
          const t4 = this._data[3 * e4 + 0];
          return 2097152 & t4 ? this._combined[e4].charCodeAt(this._combined[e4].length - 1) : 2097151 & t4;
        }
        isCombined(e4) {
          return 2097152 & this._data[3 * e4 + 0];
        }
        getString(e4) {
          const t4 = this._data[3 * e4 + 0];
          return 2097152 & t4 ? this._combined[e4] : 2097151 & t4 ? (0, o2.stringFromCodePoint)(2097151 & t4) : "";
        }
        isProtected(e4) {
          return 536870912 & this._data[3 * e4 + 2];
        }
        loadCell(e4, t4) {
          return a2 = 3 * e4, t4.content = this._data[a2 + 0], t4.fg = this._data[a2 + 1], t4.bg = this._data[a2 + 2], 2097152 & t4.content && (t4.combinedData = this._combined[e4]), 268435456 & t4.bg && (t4.extended = this._extendedAttrs[e4]), t4;
        }
        setCell(e4, t4) {
          2097152 & t4.content && (this._combined[e4] = t4.combinedData), 268435456 & t4.bg && (this._extendedAttrs[e4] = t4.extended), this._data[3 * e4 + 0] = t4.content, this._data[3 * e4 + 1] = t4.fg, this._data[3 * e4 + 2] = t4.bg;
        }
        setCellFromCodepoint(e4, t4, i4, s4) {
          268435456 & s4.bg && (this._extendedAttrs[e4] = s4.extended), this._data[3 * e4 + 0] = t4 | i4 << 22, this._data[3 * e4 + 1] = s4.fg, this._data[3 * e4 + 2] = s4.bg;
        }
        addCodepointToCell(e4, t4, i4) {
          let s4 = this._data[3 * e4 + 0];
          2097152 & s4 ? this._combined[e4] += (0, o2.stringFromCodePoint)(t4) : 2097151 & s4 ? (this._combined[e4] = (0, o2.stringFromCodePoint)(2097151 & s4) + (0, o2.stringFromCodePoint)(t4), s4 &= -2097152, s4 |= 2097152) : s4 = t4 | 1 << 22, i4 && (s4 &= -12582913, s4 |= i4 << 22), this._data[3 * e4 + 0] = s4;
        }
        insertCells(e4, t4, i4) {
          if ((e4 %= this.length) && 2 === this.getWidth(e4 - 1) && this.setCellFromCodepoint(e4 - 1, 0, 1, i4), t4 < this.length - e4) {
            const s4 = new r2.CellData();
            for (let i5 = this.length - e4 - t4 - 1; i5 >= 0; --i5) this.setCell(e4 + t4 + i5, this.loadCell(e4 + i5, s4));
            for (let s5 = 0; s5 < t4; ++s5) this.setCell(e4 + s5, i4);
          } else for (let t5 = e4; t5 < this.length; ++t5) this.setCell(t5, i4);
          2 === this.getWidth(this.length - 1) && this.setCellFromCodepoint(this.length - 1, 0, 1, i4);
        }
        deleteCells(e4, t4, i4) {
          if (e4 %= this.length, t4 < this.length - e4) {
            const s4 = new r2.CellData();
            for (let i5 = 0; i5 < this.length - e4 - t4; ++i5) this.setCell(e4 + i5, this.loadCell(e4 + t4 + i5, s4));
            for (let e5 = this.length - t4; e5 < this.length; ++e5) this.setCell(e5, i4);
          } else for (let t5 = e4; t5 < this.length; ++t5) this.setCell(t5, i4);
          e4 && 2 === this.getWidth(e4 - 1) && this.setCellFromCodepoint(e4 - 1, 0, 1, i4), 0 !== this.getWidth(e4) || this.hasContent(e4) || this.setCellFromCodepoint(e4, 0, 1, i4);
        }
        replaceCells(e4, t4, i4, s4 = false) {
          if (s4) for (e4 && 2 === this.getWidth(e4 - 1) && !this.isProtected(e4 - 1) && this.setCellFromCodepoint(e4 - 1, 0, 1, i4), t4 < this.length && 2 === this.getWidth(t4 - 1) && !this.isProtected(t4) && this.setCellFromCodepoint(t4, 0, 1, i4); e4 < t4 && e4 < this.length; ) this.isProtected(e4) || this.setCell(e4, i4), e4++;
          else for (e4 && 2 === this.getWidth(e4 - 1) && this.setCellFromCodepoint(e4 - 1, 0, 1, i4), t4 < this.length && 2 === this.getWidth(t4 - 1) && this.setCellFromCodepoint(t4, 0, 1, i4); e4 < t4 && e4 < this.length; ) this.setCell(e4++, i4);
        }
        resize(e4, t4) {
          if (e4 === this.length) return 4 * this._data.length * 2 < this._data.buffer.byteLength;
          const i4 = 3 * e4;
          if (e4 > this.length) {
            if (this._data.buffer.byteLength >= 4 * i4) this._data = new Uint32Array(this._data.buffer, 0, i4);
            else {
              const e5 = new Uint32Array(i4);
              e5.set(this._data), this._data = e5;
            }
            for (let i5 = this.length; i5 < e4; ++i5) this.setCell(i5, t4);
          } else {
            this._data = this._data.subarray(0, i4);
            const t5 = Object.keys(this._combined);
            for (let i5 = 0; i5 < t5.length; i5++) {
              const s5 = parseInt(t5[i5], 10);
              s5 >= e4 && delete this._combined[s5];
            }
            const s4 = Object.keys(this._extendedAttrs);
            for (let t6 = 0; t6 < s4.length; t6++) {
              const i5 = parseInt(s4[t6], 10);
              i5 >= e4 && delete this._extendedAttrs[i5];
            }
          }
          return this.length = e4, 4 * i4 * 2 < this._data.buffer.byteLength;
        }
        cleanupMemory() {
          if (4 * this._data.length * 2 < this._data.buffer.byteLength) {
            const e4 = new Uint32Array(this._data.length);
            return e4.set(this._data), this._data = e4, 1;
          }
          return 0;
        }
        fill(e4, t4 = false) {
          if (t4) for (let t5 = 0; t5 < this.length; ++t5) this.isProtected(t5) || this.setCell(t5, e4);
          else {
            this._combined = {}, this._extendedAttrs = {};
            for (let t5 = 0; t5 < this.length; ++t5) this.setCell(t5, e4);
          }
        }
        copyFrom(e4) {
          this.length !== e4.length ? this._data = new Uint32Array(e4._data) : this._data.set(e4._data), this.length = e4.length, this._combined = {};
          for (const t4 in e4._combined) this._combined[t4] = e4._combined[t4];
          this._extendedAttrs = {};
          for (const t4 in e4._extendedAttrs) this._extendedAttrs[t4] = e4._extendedAttrs[t4];
          this.isWrapped = e4.isWrapped;
        }
        clone() {
          const e4 = new h2(0);
          e4._data = new Uint32Array(this._data), e4.length = this.length;
          for (const t4 in this._combined) e4._combined[t4] = this._combined[t4];
          for (const t4 in this._extendedAttrs) e4._extendedAttrs[t4] = this._extendedAttrs[t4];
          return e4.isWrapped = this.isWrapped, e4;
        }
        getTrimmedLength() {
          for (let e4 = this.length - 1; e4 >= 0; --e4) if (4194303 & this._data[3 * e4 + 0]) return e4 + (this._data[3 * e4 + 0] >> 22);
          return 0;
        }
        getNoBgTrimmedLength() {
          for (let e4 = this.length - 1; e4 >= 0; --e4) if (4194303 & this._data[3 * e4 + 0] || 50331648 & this._data[3 * e4 + 2]) return e4 + (this._data[3 * e4 + 0] >> 22);
          return 0;
        }
        copyCellsFrom(e4, t4, i4, s4, r3) {
          const n3 = e4._data;
          if (r3) for (let r4 = s4 - 1; r4 >= 0; r4--) {
            for (let e5 = 0; e5 < 3; e5++) this._data[3 * (i4 + r4) + e5] = n3[3 * (t4 + r4) + e5];
            268435456 & n3[3 * (t4 + r4) + 2] && (this._extendedAttrs[i4 + r4] = e4._extendedAttrs[t4 + r4]);
          }
          else for (let r4 = 0; r4 < s4; r4++) {
            for (let e5 = 0; e5 < 3; e5++) this._data[3 * (i4 + r4) + e5] = n3[3 * (t4 + r4) + e5];
            268435456 & n3[3 * (t4 + r4) + 2] && (this._extendedAttrs[i4 + r4] = e4._extendedAttrs[t4 + r4]);
          }
          const o3 = Object.keys(e4._combined);
          for (let s5 = 0; s5 < o3.length; s5++) {
            const r4 = parseInt(o3[s5], 10);
            r4 >= t4 && (this._combined[r4 - t4 + i4] = e4._combined[r4]);
          }
        }
        translateToString(e4, t4, i4, s4) {
          t4 = t4 ?? 0, i4 = i4 ?? this.length, e4 && (i4 = Math.min(i4, this.getTrimmedLength())), s4 && (s4.length = 0);
          let r3 = "";
          for (; t4 < i4; ) {
            const e5 = this._data[3 * t4 + 0], i5 = 2097151 & e5, a3 = 2097152 & e5 ? this._combined[t4] : i5 ? (0, o2.stringFromCodePoint)(i5) : n2.WHITESPACE_CELL_CHAR;
            if (r3 += a3, s4) for (let e6 = 0; e6 < a3.length; ++e6) s4.push(t4);
            t4 += e5 >> 22 || 1;
          }
          return s4 && s4.push(t4), r3;
        }
      }
      t3.BufferLine = h2;
    }, 4841: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.getRangeLength = void 0, t3.getRangeLength = function(e4, t4) {
        if (e4.start.y > e4.end.y) throw new Error(`Buffer range end (${e4.end.x}, ${e4.end.y}) cannot be before start (${e4.start.x}, ${e4.start.y})`);
        return t4 * (e4.end.y - e4.start.y) + (e4.end.x - e4.start.x + 1);
      };
    }, 4634: (e3, t3) => {
      function i3(e4, t4, i4) {
        if (t4 === e4.length - 1) return e4[t4].getTrimmedLength();
        const s3 = !e4[t4].hasContent(i4 - 1) && 1 === e4[t4].getWidth(i4 - 1), r2 = 2 === e4[t4 + 1].getWidth(0);
        return s3 && r2 ? i4 - 1 : i4;
      }
      __name(i3, "i");
      Object.defineProperty(t3, "__esModule", { value: true }), t3.getWrappedLineTrimmedLength = t3.reflowSmallerGetNewLineLengths = t3.reflowLargerApplyNewLayout = t3.reflowLargerCreateNewLayout = t3.reflowLargerGetLinesToRemove = void 0, t3.reflowLargerGetLinesToRemove = function(e4, t4, s3, r2, n2) {
        const o2 = [];
        for (let a2 = 0; a2 < e4.length - 1; a2++) {
          let h2 = a2, c2 = e4.get(++h2);
          if (!c2.isWrapped) continue;
          const l2 = [e4.get(a2)];
          for (; h2 < e4.length && c2.isWrapped; ) l2.push(c2), c2 = e4.get(++h2);
          if (r2 >= a2 && r2 < h2) {
            a2 += l2.length - 1;
            continue;
          }
          let d2 = 0, _2 = i3(l2, d2, t4), u2 = 1, f2 = 0;
          for (; u2 < l2.length; ) {
            const e5 = i3(l2, u2, t4), r3 = e5 - f2, o3 = s3 - _2, a3 = Math.min(r3, o3);
            l2[d2].copyCellsFrom(l2[u2], f2, _2, a3, false), _2 += a3, _2 === s3 && (d2++, _2 = 0), f2 += a3, f2 === e5 && (u2++, f2 = 0), 0 === _2 && 0 !== d2 && 2 === l2[d2 - 1].getWidth(s3 - 1) && (l2[d2].copyCellsFrom(l2[d2 - 1], s3 - 1, _2++, 1, false), l2[d2 - 1].setCell(s3 - 1, n2));
          }
          l2[d2].replaceCells(_2, s3, n2);
          let v2 = 0;
          for (let e5 = l2.length - 1; e5 > 0 && (e5 > d2 || 0 === l2[e5].getTrimmedLength()); e5--) v2++;
          v2 > 0 && (o2.push(a2 + l2.length - v2), o2.push(v2)), a2 += l2.length - 1;
        }
        return o2;
      }, t3.reflowLargerCreateNewLayout = function(e4, t4) {
        const i4 = [];
        let s3 = 0, r2 = t4[s3], n2 = 0;
        for (let o2 = 0; o2 < e4.length; o2++) if (r2 === o2) {
          const i5 = t4[++s3];
          e4.onDeleteEmitter.fire({ index: o2 - n2, amount: i5 }), o2 += i5 - 1, n2 += i5, r2 = t4[++s3];
        } else i4.push(o2);
        return { layout: i4, countRemoved: n2 };
      }, t3.reflowLargerApplyNewLayout = function(e4, t4) {
        const i4 = [];
        for (let s3 = 0; s3 < t4.length; s3++) i4.push(e4.get(t4[s3]));
        for (let t5 = 0; t5 < i4.length; t5++) e4.set(t5, i4[t5]);
        e4.length = t4.length;
      }, t3.reflowSmallerGetNewLineLengths = function(e4, t4, s3) {
        const r2 = [], n2 = e4.map((s4, r3) => i3(e4, r3, t4)).reduce((e5, t5) => e5 + t5);
        let o2 = 0, a2 = 0, h2 = 0;
        for (; h2 < n2; ) {
          if (n2 - h2 < s3) {
            r2.push(n2 - h2);
            break;
          }
          o2 += s3;
          const c2 = i3(e4, a2, t4);
          o2 > c2 && (o2 -= c2, a2++);
          const l2 = 2 === e4[a2].getWidth(o2 - 1);
          l2 && o2--;
          const d2 = l2 ? s3 - 1 : s3;
          r2.push(d2), h2 += d2;
        }
        return r2;
      }, t3.getWrappedLineTrimmedLength = i3;
    }, 5295: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferSet = void 0;
      const s3 = i3(8460), r2 = i3(844), n2 = i3(9092);
      class o2 extends r2.Disposable {
        static {
          __name(this, "o");
        }
        constructor(e4, t4) {
          super(), this._optionsService = e4, this._bufferService = t4, this._onBufferActivate = this.register(new s3.EventEmitter()), this.onBufferActivate = this._onBufferActivate.event, this.reset(), this.register(this._optionsService.onSpecificOptionChange("scrollback", () => this.resize(this._bufferService.cols, this._bufferService.rows))), this.register(this._optionsService.onSpecificOptionChange("tabStopWidth", () => this.setupTabStops()));
        }
        reset() {
          this._normal = new n2.Buffer(true, this._optionsService, this._bufferService), this._normal.fillViewportRows(), this._alt = new n2.Buffer(false, this._optionsService, this._bufferService), this._activeBuffer = this._normal, this._onBufferActivate.fire({ activeBuffer: this._normal, inactiveBuffer: this._alt }), this.setupTabStops();
        }
        get alt() {
          return this._alt;
        }
        get active() {
          return this._activeBuffer;
        }
        get normal() {
          return this._normal;
        }
        activateNormalBuffer() {
          this._activeBuffer !== this._normal && (this._normal.x = this._alt.x, this._normal.y = this._alt.y, this._alt.clearAllMarkers(), this._alt.clear(), this._activeBuffer = this._normal, this._onBufferActivate.fire({ activeBuffer: this._normal, inactiveBuffer: this._alt }));
        }
        activateAltBuffer(e4) {
          this._activeBuffer !== this._alt && (this._alt.fillViewportRows(e4), this._alt.x = this._normal.x, this._alt.y = this._normal.y, this._activeBuffer = this._alt, this._onBufferActivate.fire({ activeBuffer: this._alt, inactiveBuffer: this._normal }));
        }
        resize(e4, t4) {
          this._normal.resize(e4, t4), this._alt.resize(e4, t4), this.setupTabStops(e4);
        }
        setupTabStops(e4) {
          this._normal.setupTabStops(e4), this._alt.setupTabStops(e4);
        }
      }
      t3.BufferSet = o2;
    }, 511: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CellData = void 0;
      const s3 = i3(482), r2 = i3(643), n2 = i3(3734);
      class o2 extends n2.AttributeData {
        static {
          __name(this, "o");
        }
        constructor() {
          super(...arguments), this.content = 0, this.fg = 0, this.bg = 0, this.extended = new n2.ExtendedAttrs(), this.combinedData = "";
        }
        static fromCharData(e4) {
          const t4 = new o2();
          return t4.setFromCharData(e4), t4;
        }
        isCombined() {
          return 2097152 & this.content;
        }
        getWidth() {
          return this.content >> 22;
        }
        getChars() {
          return 2097152 & this.content ? this.combinedData : 2097151 & this.content ? (0, s3.stringFromCodePoint)(2097151 & this.content) : "";
        }
        getCode() {
          return this.isCombined() ? this.combinedData.charCodeAt(this.combinedData.length - 1) : 2097151 & this.content;
        }
        setFromCharData(e4) {
          this.fg = e4[r2.CHAR_DATA_ATTR_INDEX], this.bg = 0;
          let t4 = false;
          if (e4[r2.CHAR_DATA_CHAR_INDEX].length > 2) t4 = true;
          else if (2 === e4[r2.CHAR_DATA_CHAR_INDEX].length) {
            const i4 = e4[r2.CHAR_DATA_CHAR_INDEX].charCodeAt(0);
            if (55296 <= i4 && i4 <= 56319) {
              const s4 = e4[r2.CHAR_DATA_CHAR_INDEX].charCodeAt(1);
              56320 <= s4 && s4 <= 57343 ? this.content = 1024 * (i4 - 55296) + s4 - 56320 + 65536 | e4[r2.CHAR_DATA_WIDTH_INDEX] << 22 : t4 = true;
            } else t4 = true;
          } else this.content = e4[r2.CHAR_DATA_CHAR_INDEX].charCodeAt(0) | e4[r2.CHAR_DATA_WIDTH_INDEX] << 22;
          t4 && (this.combinedData = e4[r2.CHAR_DATA_CHAR_INDEX], this.content = 2097152 | e4[r2.CHAR_DATA_WIDTH_INDEX] << 22);
        }
        getAsCharData() {
          return [this.fg, this.getChars(), this.getWidth(), this.getCode()];
        }
      }
      t3.CellData = o2;
    }, 643: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.WHITESPACE_CELL_CODE = t3.WHITESPACE_CELL_WIDTH = t3.WHITESPACE_CELL_CHAR = t3.NULL_CELL_CODE = t3.NULL_CELL_WIDTH = t3.NULL_CELL_CHAR = t3.CHAR_DATA_CODE_INDEX = t3.CHAR_DATA_WIDTH_INDEX = t3.CHAR_DATA_CHAR_INDEX = t3.CHAR_DATA_ATTR_INDEX = t3.DEFAULT_EXT = t3.DEFAULT_ATTR = t3.DEFAULT_COLOR = void 0, t3.DEFAULT_COLOR = 0, t3.DEFAULT_ATTR = 256 | t3.DEFAULT_COLOR << 9, t3.DEFAULT_EXT = 0, t3.CHAR_DATA_ATTR_INDEX = 0, t3.CHAR_DATA_CHAR_INDEX = 1, t3.CHAR_DATA_WIDTH_INDEX = 2, t3.CHAR_DATA_CODE_INDEX = 3, t3.NULL_CELL_CHAR = "", t3.NULL_CELL_WIDTH = 1, t3.NULL_CELL_CODE = 0, t3.WHITESPACE_CELL_CHAR = " ", t3.WHITESPACE_CELL_WIDTH = 1, t3.WHITESPACE_CELL_CODE = 32;
    }, 4863: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Marker = void 0;
      const s3 = i3(8460), r2 = i3(844);
      class n2 {
        static {
          __name(this, "n");
        }
        get id() {
          return this._id;
        }
        constructor(e4) {
          this.line = e4, this.isDisposed = false, this._disposables = [], this._id = n2._nextId++, this._onDispose = this.register(new s3.EventEmitter()), this.onDispose = this._onDispose.event;
        }
        dispose() {
          this.isDisposed || (this.isDisposed = true, this.line = -1, this._onDispose.fire(), (0, r2.disposeArray)(this._disposables), this._disposables.length = 0);
        }
        register(e4) {
          return this._disposables.push(e4), e4;
        }
      }
      t3.Marker = n2, n2._nextId = 1;
    }, 7116: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DEFAULT_CHARSET = t3.CHARSETS = void 0, t3.CHARSETS = {}, t3.DEFAULT_CHARSET = t3.CHARSETS.B, t3.CHARSETS[0] = { "`": "◆", a: "▒", b: "␉", c: "␌", d: "␍", e: "␊", f: "°", g: "±", h: "␤", i: "␋", j: "┘", k: "┐", l: "┌", m: "└", n: "┼", o: "⎺", p: "⎻", q: "─", r: "⎼", s: "⎽", t: "├", u: "┤", v: "┴", w: "┬", x: "│", y: "≤", z: "≥", "{": "π", "|": "≠", "}": "£", "~": "·" }, t3.CHARSETS.A = { "#": "£" }, t3.CHARSETS.B = void 0, t3.CHARSETS[4] = { "#": "£", "@": "¾", "[": "ij", "\\": "½", "]": "|", "{": "¨", "|": "f", "}": "¼", "~": "´" }, t3.CHARSETS.C = t3.CHARSETS[5] = { "[": "Ä", "\\": "Ö", "]": "Å", "^": "Ü", "`": "é", "{": "ä", "|": "ö", "}": "å", "~": "ü" }, t3.CHARSETS.R = { "#": "£", "@": "à", "[": "°", "\\": "ç", "]": "§", "{": "é", "|": "ù", "}": "è", "~": "¨" }, t3.CHARSETS.Q = { "@": "à", "[": "â", "\\": "ç", "]": "ê", "^": "î", "`": "ô", "{": "é", "|": "ù", "}": "è", "~": "û" }, t3.CHARSETS.K = { "@": "§", "[": "Ä", "\\": "Ö", "]": "Ü", "{": "ä", "|": "ö", "}": "ü", "~": "ß" }, t3.CHARSETS.Y = { "#": "£", "@": "§", "[": "°", "\\": "ç", "]": "é", "`": "ù", "{": "à", "|": "ò", "}": "è", "~": "ì" }, t3.CHARSETS.E = t3.CHARSETS[6] = { "@": "Ä", "[": "Æ", "\\": "Ø", "]": "Å", "^": "Ü", "`": "ä", "{": "æ", "|": "ø", "}": "å", "~": "ü" }, t3.CHARSETS.Z = { "#": "£", "@": "§", "[": "¡", "\\": "Ñ", "]": "¿", "{": "°", "|": "ñ", "}": "ç" }, t3.CHARSETS.H = t3.CHARSETS[7] = { "@": "É", "[": "Ä", "\\": "Ö", "]": "Å", "^": "Ü", "`": "é", "{": "ä", "|": "ö", "}": "å", "~": "ü" }, t3.CHARSETS["="] = { "#": "ù", "@": "à", "[": "é", "\\": "ç", "]": "ê", "^": "î", _: "è", "`": "ô", "{": "ä", "|": "ö", "}": "ü", "~": "û" };
    }, 2584: (e3, t3) => {
      var i3, s3, r2;
      Object.defineProperty(t3, "__esModule", { value: true }), t3.C1_ESCAPED = t3.C1 = t3.C0 = void 0, function(e4) {
        e4.NUL = "\0", e4.SOH = "", e4.STX = "", e4.ETX = "", e4.EOT = "", e4.ENQ = "", e4.ACK = "", e4.BEL = "\x07", e4.BS = "\b", e4.HT = "	", e4.LF = "\n", e4.VT = "\v", e4.FF = "\f", e4.CR = "\r", e4.SO = "", e4.SI = "", e4.DLE = "", e4.DC1 = "", e4.DC2 = "", e4.DC3 = "", e4.DC4 = "", e4.NAK = "", e4.SYN = "", e4.ETB = "", e4.CAN = "", e4.EM = "", e4.SUB = "", e4.ESC = "\x1B", e4.FS = "", e4.GS = "", e4.RS = "", e4.US = "", e4.SP = " ", e4.DEL = "";
      }(i3 || (t3.C0 = i3 = {})), function(e4) {
        e4.PAD = "", e4.HOP = "", e4.BPH = "", e4.NBH = "", e4.IND = "", e4.NEL = "", e4.SSA = "", e4.ESA = "", e4.HTS = "", e4.HTJ = "", e4.VTS = "", e4.PLD = "", e4.PLU = "", e4.RI = "", e4.SS2 = "", e4.SS3 = "", e4.DCS = "", e4.PU1 = "", e4.PU2 = "", e4.STS = "", e4.CCH = "", e4.MW = "", e4.SPA = "", e4.EPA = "", e4.SOS = "", e4.SGCI = "", e4.SCI = "", e4.CSI = "", e4.ST = "", e4.OSC = "", e4.PM = "", e4.APC = "";
      }(s3 || (t3.C1 = s3 = {})), function(e4) {
        e4.ST = `${i3.ESC}\\`;
      }(r2 || (t3.C1_ESCAPED = r2 = {}));
    }, 7399: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.evaluateKeyboardEvent = void 0;
      const s3 = i3(2584), r2 = { 48: ["0", ")"], 49: ["1", "!"], 50: ["2", "@"], 51: ["3", "#"], 52: ["4", "$"], 53: ["5", "%"], 54: ["6", "^"], 55: ["7", "&"], 56: ["8", "*"], 57: ["9", "("], 186: [";", ":"], 187: ["=", "+"], 188: [",", "<"], 189: ["-", "_"], 190: [".", ">"], 191: ["/", "?"], 192: ["`", "~"], 219: ["[", "{"], 220: ["\\", "|"], 221: ["]", "}"], 222: ["'", '"'] };
      t3.evaluateKeyboardEvent = function(e4, t4, i4, n2) {
        const o2 = { type: 0, cancel: false, key: void 0 }, a2 = (e4.shiftKey ? 1 : 0) | (e4.altKey ? 2 : 0) | (e4.ctrlKey ? 4 : 0) | (e4.metaKey ? 8 : 0);
        switch (e4.keyCode) {
          case 0:
            "UIKeyInputUpArrow" === e4.key ? o2.key = t4 ? s3.C0.ESC + "OA" : s3.C0.ESC + "[A" : "UIKeyInputLeftArrow" === e4.key ? o2.key = t4 ? s3.C0.ESC + "OD" : s3.C0.ESC + "[D" : "UIKeyInputRightArrow" === e4.key ? o2.key = t4 ? s3.C0.ESC + "OC" : s3.C0.ESC + "[C" : "UIKeyInputDownArrow" === e4.key && (o2.key = t4 ? s3.C0.ESC + "OB" : s3.C0.ESC + "[B");
            break;
          case 8:
            o2.key = e4.ctrlKey ? "\b" : s3.C0.DEL, e4.altKey && (o2.key = s3.C0.ESC + o2.key);
            break;
          case 9:
            if (e4.shiftKey) {
              o2.key = s3.C0.ESC + "[Z";
              break;
            }
            o2.key = s3.C0.HT, o2.cancel = true;
            break;
          case 13:
            o2.key = e4.altKey ? s3.C0.ESC + s3.C0.CR : s3.C0.CR, o2.cancel = true;
            break;
          case 27:
            o2.key = s3.C0.ESC, e4.altKey && (o2.key = s3.C0.ESC + s3.C0.ESC), o2.cancel = true;
            break;
          case 37:
            if (e4.metaKey) break;
            a2 ? (o2.key = s3.C0.ESC + "[1;" + (a2 + 1) + "D", o2.key === s3.C0.ESC + "[1;3D" && (o2.key = s3.C0.ESC + (i4 ? "b" : "[1;5D"))) : o2.key = t4 ? s3.C0.ESC + "OD" : s3.C0.ESC + "[D";
            break;
          case 39:
            if (e4.metaKey) break;
            a2 ? (o2.key = s3.C0.ESC + "[1;" + (a2 + 1) + "C", o2.key === s3.C0.ESC + "[1;3C" && (o2.key = s3.C0.ESC + (i4 ? "f" : "[1;5C"))) : o2.key = t4 ? s3.C0.ESC + "OC" : s3.C0.ESC + "[C";
            break;
          case 38:
            if (e4.metaKey) break;
            a2 ? (o2.key = s3.C0.ESC + "[1;" + (a2 + 1) + "A", i4 || o2.key !== s3.C0.ESC + "[1;3A" || (o2.key = s3.C0.ESC + "[1;5A")) : o2.key = t4 ? s3.C0.ESC + "OA" : s3.C0.ESC + "[A";
            break;
          case 40:
            if (e4.metaKey) break;
            a2 ? (o2.key = s3.C0.ESC + "[1;" + (a2 + 1) + "B", i4 || o2.key !== s3.C0.ESC + "[1;3B" || (o2.key = s3.C0.ESC + "[1;5B")) : o2.key = t4 ? s3.C0.ESC + "OB" : s3.C0.ESC + "[B";
            break;
          case 45:
            e4.shiftKey || e4.ctrlKey || (o2.key = s3.C0.ESC + "[2~");
            break;
          case 46:
            o2.key = a2 ? s3.C0.ESC + "[3;" + (a2 + 1) + "~" : s3.C0.ESC + "[3~";
            break;
          case 36:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "H" : t4 ? s3.C0.ESC + "OH" : s3.C0.ESC + "[H";
            break;
          case 35:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "F" : t4 ? s3.C0.ESC + "OF" : s3.C0.ESC + "[F";
            break;
          case 33:
            e4.shiftKey ? o2.type = 2 : e4.ctrlKey ? o2.key = s3.C0.ESC + "[5;" + (a2 + 1) + "~" : o2.key = s3.C0.ESC + "[5~";
            break;
          case 34:
            e4.shiftKey ? o2.type = 3 : e4.ctrlKey ? o2.key = s3.C0.ESC + "[6;" + (a2 + 1) + "~" : o2.key = s3.C0.ESC + "[6~";
            break;
          case 112:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "P" : s3.C0.ESC + "OP";
            break;
          case 113:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "Q" : s3.C0.ESC + "OQ";
            break;
          case 114:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "R" : s3.C0.ESC + "OR";
            break;
          case 115:
            o2.key = a2 ? s3.C0.ESC + "[1;" + (a2 + 1) + "S" : s3.C0.ESC + "OS";
            break;
          case 116:
            o2.key = a2 ? s3.C0.ESC + "[15;" + (a2 + 1) + "~" : s3.C0.ESC + "[15~";
            break;
          case 117:
            o2.key = a2 ? s3.C0.ESC + "[17;" + (a2 + 1) + "~" : s3.C0.ESC + "[17~";
            break;
          case 118:
            o2.key = a2 ? s3.C0.ESC + "[18;" + (a2 + 1) + "~" : s3.C0.ESC + "[18~";
            break;
          case 119:
            o2.key = a2 ? s3.C0.ESC + "[19;" + (a2 + 1) + "~" : s3.C0.ESC + "[19~";
            break;
          case 120:
            o2.key = a2 ? s3.C0.ESC + "[20;" + (a2 + 1) + "~" : s3.C0.ESC + "[20~";
            break;
          case 121:
            o2.key = a2 ? s3.C0.ESC + "[21;" + (a2 + 1) + "~" : s3.C0.ESC + "[21~";
            break;
          case 122:
            o2.key = a2 ? s3.C0.ESC + "[23;" + (a2 + 1) + "~" : s3.C0.ESC + "[23~";
            break;
          case 123:
            o2.key = a2 ? s3.C0.ESC + "[24;" + (a2 + 1) + "~" : s3.C0.ESC + "[24~";
            break;
          default:
            if (!e4.ctrlKey || e4.shiftKey || e4.altKey || e4.metaKey) if (i4 && !n2 || !e4.altKey || e4.metaKey) !i4 || e4.altKey || e4.ctrlKey || e4.shiftKey || !e4.metaKey ? e4.key && !e4.ctrlKey && !e4.altKey && !e4.metaKey && e4.keyCode >= 48 && 1 === e4.key.length ? o2.key = e4.key : e4.key && e4.ctrlKey && ("_" === e4.key && (o2.key = s3.C0.US), "@" === e4.key && (o2.key = s3.C0.NUL)) : 65 === e4.keyCode && (o2.type = 1);
            else {
              const t5 = r2[e4.keyCode], i5 = t5?.[e4.shiftKey ? 1 : 0];
              if (i5) o2.key = s3.C0.ESC + i5;
              else if (e4.keyCode >= 65 && e4.keyCode <= 90) {
                const t6 = e4.ctrlKey ? e4.keyCode - 64 : e4.keyCode + 32;
                let i6 = String.fromCharCode(t6);
                e4.shiftKey && (i6 = i6.toUpperCase()), o2.key = s3.C0.ESC + i6;
              } else if (32 === e4.keyCode) o2.key = s3.C0.ESC + (e4.ctrlKey ? s3.C0.NUL : " ");
              else if ("Dead" === e4.key && e4.code.startsWith("Key")) {
                let t6 = e4.code.slice(3, 4);
                e4.shiftKey || (t6 = t6.toLowerCase()), o2.key = s3.C0.ESC + t6, o2.cancel = true;
              }
            }
            else e4.keyCode >= 65 && e4.keyCode <= 90 ? o2.key = String.fromCharCode(e4.keyCode - 64) : 32 === e4.keyCode ? o2.key = s3.C0.NUL : e4.keyCode >= 51 && e4.keyCode <= 55 ? o2.key = String.fromCharCode(e4.keyCode - 51 + 27) : 56 === e4.keyCode ? o2.key = s3.C0.DEL : 219 === e4.keyCode ? o2.key = s3.C0.ESC : 220 === e4.keyCode ? o2.key = s3.C0.FS : 221 === e4.keyCode && (o2.key = s3.C0.GS);
        }
        return o2;
      };
    }, 482: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Utf8ToUtf32 = t3.StringToUtf32 = t3.utf32ToString = t3.stringFromCodePoint = void 0, t3.stringFromCodePoint = function(e4) {
        return e4 > 65535 ? (e4 -= 65536, String.fromCharCode(55296 + (e4 >> 10)) + String.fromCharCode(e4 % 1024 + 56320)) : String.fromCharCode(e4);
      }, t3.utf32ToString = function(e4, t4 = 0, i3 = e4.length) {
        let s3 = "";
        for (let r2 = t4; r2 < i3; ++r2) {
          let t5 = e4[r2];
          t5 > 65535 ? (t5 -= 65536, s3 += String.fromCharCode(55296 + (t5 >> 10)) + String.fromCharCode(t5 % 1024 + 56320)) : s3 += String.fromCharCode(t5);
        }
        return s3;
      }, t3.StringToUtf32 = class {
        constructor() {
          this._interim = 0;
        }
        clear() {
          this._interim = 0;
        }
        decode(e4, t4) {
          const i3 = e4.length;
          if (!i3) return 0;
          let s3 = 0, r2 = 0;
          if (this._interim) {
            const i4 = e4.charCodeAt(r2++);
            56320 <= i4 && i4 <= 57343 ? t4[s3++] = 1024 * (this._interim - 55296) + i4 - 56320 + 65536 : (t4[s3++] = this._interim, t4[s3++] = i4), this._interim = 0;
          }
          for (let n2 = r2; n2 < i3; ++n2) {
            const r3 = e4.charCodeAt(n2);
            if (55296 <= r3 && r3 <= 56319) {
              if (++n2 >= i3) return this._interim = r3, s3;
              const o2 = e4.charCodeAt(n2);
              56320 <= o2 && o2 <= 57343 ? t4[s3++] = 1024 * (r3 - 55296) + o2 - 56320 + 65536 : (t4[s3++] = r3, t4[s3++] = o2);
            } else 65279 !== r3 && (t4[s3++] = r3);
          }
          return s3;
        }
      }, t3.Utf8ToUtf32 = class {
        constructor() {
          this.interim = new Uint8Array(3);
        }
        clear() {
          this.interim.fill(0);
        }
        decode(e4, t4) {
          const i3 = e4.length;
          if (!i3) return 0;
          let s3, r2, n2, o2, a2 = 0, h2 = 0, c2 = 0;
          if (this.interim[0]) {
            let s4 = false, r3 = this.interim[0];
            r3 &= 192 == (224 & r3) ? 31 : 224 == (240 & r3) ? 15 : 7;
            let n3, o3 = 0;
            for (; (n3 = 63 & this.interim[++o3]) && o3 < 4; ) r3 <<= 6, r3 |= n3;
            const h3 = 192 == (224 & this.interim[0]) ? 2 : 224 == (240 & this.interim[0]) ? 3 : 4, l3 = h3 - o3;
            for (; c2 < l3; ) {
              if (c2 >= i3) return 0;
              if (n3 = e4[c2++], 128 != (192 & n3)) {
                c2--, s4 = true;
                break;
              }
              this.interim[o3++] = n3, r3 <<= 6, r3 |= 63 & n3;
            }
            s4 || (2 === h3 ? r3 < 128 ? c2-- : t4[a2++] = r3 : 3 === h3 ? r3 < 2048 || r3 >= 55296 && r3 <= 57343 || 65279 === r3 || (t4[a2++] = r3) : r3 < 65536 || r3 > 1114111 || (t4[a2++] = r3)), this.interim.fill(0);
          }
          const l2 = i3 - 4;
          let d2 = c2;
          for (; d2 < i3; ) {
            for (; !(!(d2 < l2) || 128 & (s3 = e4[d2]) || 128 & (r2 = e4[d2 + 1]) || 128 & (n2 = e4[d2 + 2]) || 128 & (o2 = e4[d2 + 3])); ) t4[a2++] = s3, t4[a2++] = r2, t4[a2++] = n2, t4[a2++] = o2, d2 += 4;
            if (s3 = e4[d2++], s3 < 128) t4[a2++] = s3;
            else if (192 == (224 & s3)) {
              if (d2 >= i3) return this.interim[0] = s3, a2;
              if (r2 = e4[d2++], 128 != (192 & r2)) {
                d2--;
                continue;
              }
              if (h2 = (31 & s3) << 6 | 63 & r2, h2 < 128) {
                d2--;
                continue;
              }
              t4[a2++] = h2;
            } else if (224 == (240 & s3)) {
              if (d2 >= i3) return this.interim[0] = s3, a2;
              if (r2 = e4[d2++], 128 != (192 & r2)) {
                d2--;
                continue;
              }
              if (d2 >= i3) return this.interim[0] = s3, this.interim[1] = r2, a2;
              if (n2 = e4[d2++], 128 != (192 & n2)) {
                d2--;
                continue;
              }
              if (h2 = (15 & s3) << 12 | (63 & r2) << 6 | 63 & n2, h2 < 2048 || h2 >= 55296 && h2 <= 57343 || 65279 === h2) continue;
              t4[a2++] = h2;
            } else if (240 == (248 & s3)) {
              if (d2 >= i3) return this.interim[0] = s3, a2;
              if (r2 = e4[d2++], 128 != (192 & r2)) {
                d2--;
                continue;
              }
              if (d2 >= i3) return this.interim[0] = s3, this.interim[1] = r2, a2;
              if (n2 = e4[d2++], 128 != (192 & n2)) {
                d2--;
                continue;
              }
              if (d2 >= i3) return this.interim[0] = s3, this.interim[1] = r2, this.interim[2] = n2, a2;
              if (o2 = e4[d2++], 128 != (192 & o2)) {
                d2--;
                continue;
              }
              if (h2 = (7 & s3) << 18 | (63 & r2) << 12 | (63 & n2) << 6 | 63 & o2, h2 < 65536 || h2 > 1114111) continue;
              t4[a2++] = h2;
            }
          }
          return a2;
        }
      };
    }, 225: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.UnicodeV6 = void 0;
      const s3 = i3(1480), r2 = [[768, 879], [1155, 1158], [1160, 1161], [1425, 1469], [1471, 1471], [1473, 1474], [1476, 1477], [1479, 1479], [1536, 1539], [1552, 1557], [1611, 1630], [1648, 1648], [1750, 1764], [1767, 1768], [1770, 1773], [1807, 1807], [1809, 1809], [1840, 1866], [1958, 1968], [2027, 2035], [2305, 2306], [2364, 2364], [2369, 2376], [2381, 2381], [2385, 2388], [2402, 2403], [2433, 2433], [2492, 2492], [2497, 2500], [2509, 2509], [2530, 2531], [2561, 2562], [2620, 2620], [2625, 2626], [2631, 2632], [2635, 2637], [2672, 2673], [2689, 2690], [2748, 2748], [2753, 2757], [2759, 2760], [2765, 2765], [2786, 2787], [2817, 2817], [2876, 2876], [2879, 2879], [2881, 2883], [2893, 2893], [2902, 2902], [2946, 2946], [3008, 3008], [3021, 3021], [3134, 3136], [3142, 3144], [3146, 3149], [3157, 3158], [3260, 3260], [3263, 3263], [3270, 3270], [3276, 3277], [3298, 3299], [3393, 3395], [3405, 3405], [3530, 3530], [3538, 3540], [3542, 3542], [3633, 3633], [3636, 3642], [3655, 3662], [3761, 3761], [3764, 3769], [3771, 3772], [3784, 3789], [3864, 3865], [3893, 3893], [3895, 3895], [3897, 3897], [3953, 3966], [3968, 3972], [3974, 3975], [3984, 3991], [3993, 4028], [4038, 4038], [4141, 4144], [4146, 4146], [4150, 4151], [4153, 4153], [4184, 4185], [4448, 4607], [4959, 4959], [5906, 5908], [5938, 5940], [5970, 5971], [6002, 6003], [6068, 6069], [6071, 6077], [6086, 6086], [6089, 6099], [6109, 6109], [6155, 6157], [6313, 6313], [6432, 6434], [6439, 6440], [6450, 6450], [6457, 6459], [6679, 6680], [6912, 6915], [6964, 6964], [6966, 6970], [6972, 6972], [6978, 6978], [7019, 7027], [7616, 7626], [7678, 7679], [8203, 8207], [8234, 8238], [8288, 8291], [8298, 8303], [8400, 8431], [12330, 12335], [12441, 12442], [43014, 43014], [43019, 43019], [43045, 43046], [64286, 64286], [65024, 65039], [65056, 65059], [65279, 65279], [65529, 65531]], n2 = [[68097, 68099], [68101, 68102], [68108, 68111], [68152, 68154], [68159, 68159], [119143, 119145], [119155, 119170], [119173, 119179], [119210, 119213], [119362, 119364], [917505, 917505], [917536, 917631], [917760, 917999]];
      let o2;
      t3.UnicodeV6 = class {
        constructor() {
          if (this.version = "6", !o2) {
            o2 = new Uint8Array(65536), o2.fill(1), o2[0] = 0, o2.fill(0, 1, 32), o2.fill(0, 127, 160), o2.fill(2, 4352, 4448), o2[9001] = 2, o2[9002] = 2, o2.fill(2, 11904, 42192), o2[12351] = 1, o2.fill(2, 44032, 55204), o2.fill(2, 63744, 64256), o2.fill(2, 65040, 65050), o2.fill(2, 65072, 65136), o2.fill(2, 65280, 65377), o2.fill(2, 65504, 65511);
            for (let e4 = 0; e4 < r2.length; ++e4) o2.fill(0, r2[e4][0], r2[e4][1] + 1);
          }
        }
        wcwidth(e4) {
          return e4 < 32 ? 0 : e4 < 127 ? 1 : e4 < 65536 ? o2[e4] : function(e5, t4) {
            let i4, s4 = 0, r3 = t4.length - 1;
            if (e5 < t4[0][0] || e5 > t4[r3][1]) return false;
            for (; r3 >= s4; ) if (i4 = s4 + r3 >> 1, e5 > t4[i4][1]) s4 = i4 + 1;
            else {
              if (!(e5 < t4[i4][0])) return true;
              r3 = i4 - 1;
            }
            return false;
          }(e4, n2) ? 0 : e4 >= 131072 && e4 <= 196605 || e4 >= 196608 && e4 <= 262141 ? 2 : 1;
        }
        charProperties(e4, t4) {
          let i4 = this.wcwidth(e4), r3 = 0 === i4 && 0 !== t4;
          if (r3) {
            const e5 = s3.UnicodeService.extractWidth(t4);
            0 === e5 ? r3 = false : e5 > i4 && (i4 = e5);
          }
          return s3.UnicodeService.createPropertyValue(0, i4, r3);
        }
      };
    }, 5981: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.WriteBuffer = void 0;
      const s3 = i3(8460), r2 = i3(844);
      class n2 extends r2.Disposable {
        static {
          __name(this, "n");
        }
        constructor(e4) {
          super(), this._action = e4, this._writeBuffer = [], this._callbacks = [], this._pendingData = 0, this._bufferOffset = 0, this._isSyncWriting = false, this._syncCalls = 0, this._didUserInput = false, this._onWriteParsed = this.register(new s3.EventEmitter()), this.onWriteParsed = this._onWriteParsed.event;
        }
        handleUserInput() {
          this._didUserInput = true;
        }
        writeSync(e4, t4) {
          if (void 0 !== t4 && this._syncCalls > t4) return void (this._syncCalls = 0);
          if (this._pendingData += e4.length, this._writeBuffer.push(e4), this._callbacks.push(void 0), this._syncCalls++, this._isSyncWriting) return;
          let i4;
          for (this._isSyncWriting = true; i4 = this._writeBuffer.shift(); ) {
            this._action(i4);
            const e5 = this._callbacks.shift();
            e5 && e5();
          }
          this._pendingData = 0, this._bufferOffset = 2147483647, this._isSyncWriting = false, this._syncCalls = 0;
        }
        write(e4, t4) {
          if (this._pendingData > 5e7) throw new Error("write data discarded, use flow control to avoid losing data");
          if (!this._writeBuffer.length) {
            if (this._bufferOffset = 0, this._didUserInput) return this._didUserInput = false, this._pendingData += e4.length, this._writeBuffer.push(e4), this._callbacks.push(t4), void this._innerWrite();
            setTimeout(() => this._innerWrite());
          }
          this._pendingData += e4.length, this._writeBuffer.push(e4), this._callbacks.push(t4);
        }
        _innerWrite(e4 = 0, t4 = true) {
          const i4 = e4 || Date.now();
          for (; this._writeBuffer.length > this._bufferOffset; ) {
            const e5 = this._writeBuffer[this._bufferOffset], s4 = this._action(e5, t4);
            if (s4) {
              const e6 = /* @__PURE__ */ __name((e7) => Date.now() - i4 >= 12 ? setTimeout(() => this._innerWrite(0, e7)) : this._innerWrite(i4, e7), "e");
              return void s4.catch((e7) => (queueMicrotask(() => {
                throw e7;
              }), Promise.resolve(false))).then(e6);
            }
            const r3 = this._callbacks[this._bufferOffset];
            if (r3 && r3(), this._bufferOffset++, this._pendingData -= e5.length, Date.now() - i4 >= 12) break;
          }
          this._writeBuffer.length > this._bufferOffset ? (this._bufferOffset > 50 && (this._writeBuffer = this._writeBuffer.slice(this._bufferOffset), this._callbacks = this._callbacks.slice(this._bufferOffset), this._bufferOffset = 0), setTimeout(() => this._innerWrite())) : (this._writeBuffer.length = 0, this._callbacks.length = 0, this._pendingData = 0, this._bufferOffset = 0), this._onWriteParsed.fire();
        }
      }
      t3.WriteBuffer = n2;
    }, 5941: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.toRgbString = t3.parseColor = void 0;
      const i3 = /^([\da-f])\/([\da-f])\/([\da-f])$|^([\da-f]{2})\/([\da-f]{2})\/([\da-f]{2})$|^([\da-f]{3})\/([\da-f]{3})\/([\da-f]{3})$|^([\da-f]{4})\/([\da-f]{4})\/([\da-f]{4})$/, s3 = /^[\da-f]+$/;
      function r2(e4, t4) {
        const i4 = e4.toString(16), s4 = i4.length < 2 ? "0" + i4 : i4;
        switch (t4) {
          case 4:
            return i4[0];
          case 8:
            return s4;
          case 12:
            return (s4 + s4).slice(0, 3);
          default:
            return s4 + s4;
        }
      }
      __name(r2, "r");
      t3.parseColor = function(e4) {
        if (!e4) return;
        let t4 = e4.toLowerCase();
        if (0 === t4.indexOf("rgb:")) {
          t4 = t4.slice(4);
          const e5 = i3.exec(t4);
          if (e5) {
            const t5 = e5[1] ? 15 : e5[4] ? 255 : e5[7] ? 4095 : 65535;
            return [Math.round(parseInt(e5[1] || e5[4] || e5[7] || e5[10], 16) / t5 * 255), Math.round(parseInt(e5[2] || e5[5] || e5[8] || e5[11], 16) / t5 * 255), Math.round(parseInt(e5[3] || e5[6] || e5[9] || e5[12], 16) / t5 * 255)];
          }
        } else if (0 === t4.indexOf("#") && (t4 = t4.slice(1), s3.exec(t4) && [3, 6, 9, 12].includes(t4.length))) {
          const e5 = t4.length / 3, i4 = [0, 0, 0];
          for (let s4 = 0; s4 < 3; ++s4) {
            const r3 = parseInt(t4.slice(e5 * s4, e5 * s4 + e5), 16);
            i4[s4] = 1 === e5 ? r3 << 4 : 2 === e5 ? r3 : 3 === e5 ? r3 >> 4 : r3 >> 8;
          }
          return i4;
        }
      }, t3.toRgbString = function(e4, t4 = 16) {
        const [i4, s4, n2] = e4;
        return `rgb:${r2(i4, t4)}/${r2(s4, t4)}/${r2(n2, t4)}`;
      };
    }, 5770: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.PAYLOAD_LIMIT = void 0, t3.PAYLOAD_LIMIT = 1e7;
    }, 6351: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DcsHandler = t3.DcsParser = void 0;
      const s3 = i3(482), r2 = i3(8742), n2 = i3(5770), o2 = [];
      t3.DcsParser = class {
        constructor() {
          this._handlers = /* @__PURE__ */ Object.create(null), this._active = o2, this._ident = 0, this._handlerFb = () => {
          }, this._stack = { paused: false, loopPosition: 0, fallThrough: false };
        }
        dispose() {
          this._handlers = /* @__PURE__ */ Object.create(null), this._handlerFb = () => {
          }, this._active = o2;
        }
        registerHandler(e4, t4) {
          void 0 === this._handlers[e4] && (this._handlers[e4] = []);
          const i4 = this._handlers[e4];
          return i4.push(t4), { dispose: /* @__PURE__ */ __name(() => {
            const e5 = i4.indexOf(t4);
            -1 !== e5 && i4.splice(e5, 1);
          }, "dispose") };
        }
        clearHandler(e4) {
          this._handlers[e4] && delete this._handlers[e4];
        }
        setHandlerFallback(e4) {
          this._handlerFb = e4;
        }
        reset() {
          if (this._active.length) for (let e4 = this._stack.paused ? this._stack.loopPosition - 1 : this._active.length - 1; e4 >= 0; --e4) this._active[e4].unhook(false);
          this._stack.paused = false, this._active = o2, this._ident = 0;
        }
        hook(e4, t4) {
          if (this.reset(), this._ident = e4, this._active = this._handlers[e4] || o2, this._active.length) for (let e5 = this._active.length - 1; e5 >= 0; e5--) this._active[e5].hook(t4);
          else this._handlerFb(this._ident, "HOOK", t4);
        }
        put(e4, t4, i4) {
          if (this._active.length) for (let s4 = this._active.length - 1; s4 >= 0; s4--) this._active[s4].put(e4, t4, i4);
          else this._handlerFb(this._ident, "PUT", (0, s3.utf32ToString)(e4, t4, i4));
        }
        unhook(e4, t4 = true) {
          if (this._active.length) {
            let i4 = false, s4 = this._active.length - 1, r3 = false;
            if (this._stack.paused && (s4 = this._stack.loopPosition - 1, i4 = t4, r3 = this._stack.fallThrough, this._stack.paused = false), !r3 && false === i4) {
              for (; s4 >= 0 && (i4 = this._active[s4].unhook(e4), true !== i4); s4--) if (i4 instanceof Promise) return this._stack.paused = true, this._stack.loopPosition = s4, this._stack.fallThrough = false, i4;
              s4--;
            }
            for (; s4 >= 0; s4--) if (i4 = this._active[s4].unhook(false), i4 instanceof Promise) return this._stack.paused = true, this._stack.loopPosition = s4, this._stack.fallThrough = true, i4;
          } else this._handlerFb(this._ident, "UNHOOK", e4);
          this._active = o2, this._ident = 0;
        }
      };
      const a2 = new r2.Params();
      a2.addParam(0), t3.DcsHandler = class {
        constructor(e4) {
          this._handler = e4, this._data = "", this._params = a2, this._hitLimit = false;
        }
        hook(e4) {
          this._params = e4.length > 1 || e4.params[0] ? e4.clone() : a2, this._data = "", this._hitLimit = false;
        }
        put(e4, t4, i4) {
          this._hitLimit || (this._data += (0, s3.utf32ToString)(e4, t4, i4), this._data.length > n2.PAYLOAD_LIMIT && (this._data = "", this._hitLimit = true));
        }
        unhook(e4) {
          let t4 = false;
          if (this._hitLimit) t4 = false;
          else if (e4 && (t4 = this._handler(this._data, this._params), t4 instanceof Promise)) return t4.then((e5) => (this._params = a2, this._data = "", this._hitLimit = false, e5));
          return this._params = a2, this._data = "", this._hitLimit = false, t4;
        }
      };
    }, 2015: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.EscapeSequenceParser = t3.VT500_TRANSITION_TABLE = t3.TransitionTable = void 0;
      const s3 = i3(844), r2 = i3(8742), n2 = i3(6242), o2 = i3(6351);
      class a2 {
        static {
          __name(this, "a");
        }
        constructor(e4) {
          this.table = new Uint8Array(e4);
        }
        setDefault(e4, t4) {
          this.table.fill(e4 << 4 | t4);
        }
        add(e4, t4, i4, s4) {
          this.table[t4 << 8 | e4] = i4 << 4 | s4;
        }
        addMany(e4, t4, i4, s4) {
          for (let r3 = 0; r3 < e4.length; r3++) this.table[t4 << 8 | e4[r3]] = i4 << 4 | s4;
        }
      }
      t3.TransitionTable = a2;
      const h2 = 160;
      t3.VT500_TRANSITION_TABLE = function() {
        const e4 = new a2(4095), t4 = Array.apply(null, Array(256)).map((e5, t5) => t5), i4 = /* @__PURE__ */ __name((e5, i5) => t4.slice(e5, i5), "i"), s4 = i4(32, 127), r3 = i4(0, 24);
        r3.push(25), r3.push.apply(r3, i4(28, 32));
        const n3 = i4(0, 14);
        let o3;
        for (o3 in e4.setDefault(1, 0), e4.addMany(s4, 0, 2, 0), n3) e4.addMany([24, 26, 153, 154], o3, 3, 0), e4.addMany(i4(128, 144), o3, 3, 0), e4.addMany(i4(144, 152), o3, 3, 0), e4.add(156, o3, 0, 0), e4.add(27, o3, 11, 1), e4.add(157, o3, 4, 8), e4.addMany([152, 158, 159], o3, 0, 7), e4.add(155, o3, 11, 3), e4.add(144, o3, 11, 9);
        return e4.addMany(r3, 0, 3, 0), e4.addMany(r3, 1, 3, 1), e4.add(127, 1, 0, 1), e4.addMany(r3, 8, 0, 8), e4.addMany(r3, 3, 3, 3), e4.add(127, 3, 0, 3), e4.addMany(r3, 4, 3, 4), e4.add(127, 4, 0, 4), e4.addMany(r3, 6, 3, 6), e4.addMany(r3, 5, 3, 5), e4.add(127, 5, 0, 5), e4.addMany(r3, 2, 3, 2), e4.add(127, 2, 0, 2), e4.add(93, 1, 4, 8), e4.addMany(s4, 8, 5, 8), e4.add(127, 8, 5, 8), e4.addMany([156, 27, 24, 26, 7], 8, 6, 0), e4.addMany(i4(28, 32), 8, 0, 8), e4.addMany([88, 94, 95], 1, 0, 7), e4.addMany(s4, 7, 0, 7), e4.addMany(r3, 7, 0, 7), e4.add(156, 7, 0, 0), e4.add(127, 7, 0, 7), e4.add(91, 1, 11, 3), e4.addMany(i4(64, 127), 3, 7, 0), e4.addMany(i4(48, 60), 3, 8, 4), e4.addMany([60, 61, 62, 63], 3, 9, 4), e4.addMany(i4(48, 60), 4, 8, 4), e4.addMany(i4(64, 127), 4, 7, 0), e4.addMany([60, 61, 62, 63], 4, 0, 6), e4.addMany(i4(32, 64), 6, 0, 6), e4.add(127, 6, 0, 6), e4.addMany(i4(64, 127), 6, 0, 0), e4.addMany(i4(32, 48), 3, 9, 5), e4.addMany(i4(32, 48), 5, 9, 5), e4.addMany(i4(48, 64), 5, 0, 6), e4.addMany(i4(64, 127), 5, 7, 0), e4.addMany(i4(32, 48), 4, 9, 5), e4.addMany(i4(32, 48), 1, 9, 2), e4.addMany(i4(32, 48), 2, 9, 2), e4.addMany(i4(48, 127), 2, 10, 0), e4.addMany(i4(48, 80), 1, 10, 0), e4.addMany(i4(81, 88), 1, 10, 0), e4.addMany([89, 90, 92], 1, 10, 0), e4.addMany(i4(96, 127), 1, 10, 0), e4.add(80, 1, 11, 9), e4.addMany(r3, 9, 0, 9), e4.add(127, 9, 0, 9), e4.addMany(i4(28, 32), 9, 0, 9), e4.addMany(i4(32, 48), 9, 9, 12), e4.addMany(i4(48, 60), 9, 8, 10), e4.addMany([60, 61, 62, 63], 9, 9, 10), e4.addMany(r3, 11, 0, 11), e4.addMany(i4(32, 128), 11, 0, 11), e4.addMany(i4(28, 32), 11, 0, 11), e4.addMany(r3, 10, 0, 10), e4.add(127, 10, 0, 10), e4.addMany(i4(28, 32), 10, 0, 10), e4.addMany(i4(48, 60), 10, 8, 10), e4.addMany([60, 61, 62, 63], 10, 0, 11), e4.addMany(i4(32, 48), 10, 9, 12), e4.addMany(r3, 12, 0, 12), e4.add(127, 12, 0, 12), e4.addMany(i4(28, 32), 12, 0, 12), e4.addMany(i4(32, 48), 12, 9, 12), e4.addMany(i4(48, 64), 12, 0, 11), e4.addMany(i4(64, 127), 12, 12, 13), e4.addMany(i4(64, 127), 10, 12, 13), e4.addMany(i4(64, 127), 9, 12, 13), e4.addMany(r3, 13, 13, 13), e4.addMany(s4, 13, 13, 13), e4.add(127, 13, 0, 13), e4.addMany([27, 156, 24, 26], 13, 14, 0), e4.add(h2, 0, 2, 0), e4.add(h2, 8, 5, 8), e4.add(h2, 6, 0, 6), e4.add(h2, 11, 0, 11), e4.add(h2, 13, 13, 13), e4;
      }();
      class c2 extends s3.Disposable {
        static {
          __name(this, "c");
        }
        constructor(e4 = t3.VT500_TRANSITION_TABLE) {
          super(), this._transitions = e4, this._parseStack = { state: 0, handlers: [], handlerPos: 0, transition: 0, chunkPos: 0 }, this.initialState = 0, this.currentState = this.initialState, this._params = new r2.Params(), this._params.addParam(0), this._collect = 0, this.precedingJoinState = 0, this._printHandlerFb = (e5, t4, i4) => {
          }, this._executeHandlerFb = (e5) => {
          }, this._csiHandlerFb = (e5, t4) => {
          }, this._escHandlerFb = (e5) => {
          }, this._errorHandlerFb = (e5) => e5, this._printHandler = this._printHandlerFb, this._executeHandlers = /* @__PURE__ */ Object.create(null), this._csiHandlers = /* @__PURE__ */ Object.create(null), this._escHandlers = /* @__PURE__ */ Object.create(null), this.register((0, s3.toDisposable)(() => {
            this._csiHandlers = /* @__PURE__ */ Object.create(null), this._executeHandlers = /* @__PURE__ */ Object.create(null), this._escHandlers = /* @__PURE__ */ Object.create(null);
          })), this._oscParser = this.register(new n2.OscParser()), this._dcsParser = this.register(new o2.DcsParser()), this._errorHandler = this._errorHandlerFb, this.registerEscHandler({ final: "\\" }, () => true);
        }
        _identifier(e4, t4 = [64, 126]) {
          let i4 = 0;
          if (e4.prefix) {
            if (e4.prefix.length > 1) throw new Error("only one byte as prefix supported");
            if (i4 = e4.prefix.charCodeAt(0), i4 && 60 > i4 || i4 > 63) throw new Error("prefix must be in range 0x3c .. 0x3f");
          }
          if (e4.intermediates) {
            if (e4.intermediates.length > 2) throw new Error("only two bytes as intermediates are supported");
            for (let t5 = 0; t5 < e4.intermediates.length; ++t5) {
              const s5 = e4.intermediates.charCodeAt(t5);
              if (32 > s5 || s5 > 47) throw new Error("intermediate must be in range 0x20 .. 0x2f");
              i4 <<= 8, i4 |= s5;
            }
          }
          if (1 !== e4.final.length) throw new Error("final must be a single byte");
          const s4 = e4.final.charCodeAt(0);
          if (t4[0] > s4 || s4 > t4[1]) throw new Error(`final must be in range ${t4[0]} .. ${t4[1]}`);
          return i4 <<= 8, i4 |= s4, i4;
        }
        identToString(e4) {
          const t4 = [];
          for (; e4; ) t4.push(String.fromCharCode(255 & e4)), e4 >>= 8;
          return t4.reverse().join("");
        }
        setPrintHandler(e4) {
          this._printHandler = e4;
        }
        clearPrintHandler() {
          this._printHandler = this._printHandlerFb;
        }
        registerEscHandler(e4, t4) {
          const i4 = this._identifier(e4, [48, 126]);
          void 0 === this._escHandlers[i4] && (this._escHandlers[i4] = []);
          const s4 = this._escHandlers[i4];
          return s4.push(t4), { dispose: /* @__PURE__ */ __name(() => {
            const e5 = s4.indexOf(t4);
            -1 !== e5 && s4.splice(e5, 1);
          }, "dispose") };
        }
        clearEscHandler(e4) {
          this._escHandlers[this._identifier(e4, [48, 126])] && delete this._escHandlers[this._identifier(e4, [48, 126])];
        }
        setEscHandlerFallback(e4) {
          this._escHandlerFb = e4;
        }
        setExecuteHandler(e4, t4) {
          this._executeHandlers[e4.charCodeAt(0)] = t4;
        }
        clearExecuteHandler(e4) {
          this._executeHandlers[e4.charCodeAt(0)] && delete this._executeHandlers[e4.charCodeAt(0)];
        }
        setExecuteHandlerFallback(e4) {
          this._executeHandlerFb = e4;
        }
        registerCsiHandler(e4, t4) {
          const i4 = this._identifier(e4);
          void 0 === this._csiHandlers[i4] && (this._csiHandlers[i4] = []);
          const s4 = this._csiHandlers[i4];
          return s4.push(t4), { dispose: /* @__PURE__ */ __name(() => {
            const e5 = s4.indexOf(t4);
            -1 !== e5 && s4.splice(e5, 1);
          }, "dispose") };
        }
        clearCsiHandler(e4) {
          this._csiHandlers[this._identifier(e4)] && delete this._csiHandlers[this._identifier(e4)];
        }
        setCsiHandlerFallback(e4) {
          this._csiHandlerFb = e4;
        }
        registerDcsHandler(e4, t4) {
          return this._dcsParser.registerHandler(this._identifier(e4), t4);
        }
        clearDcsHandler(e4) {
          this._dcsParser.clearHandler(this._identifier(e4));
        }
        setDcsHandlerFallback(e4) {
          this._dcsParser.setHandlerFallback(e4);
        }
        registerOscHandler(e4, t4) {
          return this._oscParser.registerHandler(e4, t4);
        }
        clearOscHandler(e4) {
          this._oscParser.clearHandler(e4);
        }
        setOscHandlerFallback(e4) {
          this._oscParser.setHandlerFallback(e4);
        }
        setErrorHandler(e4) {
          this._errorHandler = e4;
        }
        clearErrorHandler() {
          this._errorHandler = this._errorHandlerFb;
        }
        reset() {
          this.currentState = this.initialState, this._oscParser.reset(), this._dcsParser.reset(), this._params.reset(), this._params.addParam(0), this._collect = 0, this.precedingJoinState = 0, 0 !== this._parseStack.state && (this._parseStack.state = 2, this._parseStack.handlers = []);
        }
        _preserveStack(e4, t4, i4, s4, r3) {
          this._parseStack.state = e4, this._parseStack.handlers = t4, this._parseStack.handlerPos = i4, this._parseStack.transition = s4, this._parseStack.chunkPos = r3;
        }
        parse(e4, t4, i4) {
          let s4, r3 = 0, n3 = 0, o3 = 0;
          if (this._parseStack.state) if (2 === this._parseStack.state) this._parseStack.state = 0, o3 = this._parseStack.chunkPos + 1;
          else {
            if (void 0 === i4 || 1 === this._parseStack.state) throw this._parseStack.state = 1, new Error("improper continuation due to previous async handler, giving up parsing");
            const t5 = this._parseStack.handlers;
            let n4 = this._parseStack.handlerPos - 1;
            switch (this._parseStack.state) {
              case 3:
                if (false === i4 && n4 > -1) {
                  for (; n4 >= 0 && (s4 = t5[n4](this._params), true !== s4); n4--) if (s4 instanceof Promise) return this._parseStack.handlerPos = n4, s4;
                }
                this._parseStack.handlers = [];
                break;
              case 4:
                if (false === i4 && n4 > -1) {
                  for (; n4 >= 0 && (s4 = t5[n4](), true !== s4); n4--) if (s4 instanceof Promise) return this._parseStack.handlerPos = n4, s4;
                }
                this._parseStack.handlers = [];
                break;
              case 6:
                if (r3 = e4[this._parseStack.chunkPos], s4 = this._dcsParser.unhook(24 !== r3 && 26 !== r3, i4), s4) return s4;
                27 === r3 && (this._parseStack.transition |= 1), this._params.reset(), this._params.addParam(0), this._collect = 0;
                break;
              case 5:
                if (r3 = e4[this._parseStack.chunkPos], s4 = this._oscParser.end(24 !== r3 && 26 !== r3, i4), s4) return s4;
                27 === r3 && (this._parseStack.transition |= 1), this._params.reset(), this._params.addParam(0), this._collect = 0;
            }
            this._parseStack.state = 0, o3 = this._parseStack.chunkPos + 1, this.precedingJoinState = 0, this.currentState = 15 & this._parseStack.transition;
          }
          for (let i5 = o3; i5 < t4; ++i5) {
            switch (r3 = e4[i5], n3 = this._transitions.table[this.currentState << 8 | (r3 < 160 ? r3 : h2)], n3 >> 4) {
              case 2:
                for (let s5 = i5 + 1; ; ++s5) {
                  if (s5 >= t4 || (r3 = e4[s5]) < 32 || r3 > 126 && r3 < h2) {
                    this._printHandler(e4, i5, s5), i5 = s5 - 1;
                    break;
                  }
                  if (++s5 >= t4 || (r3 = e4[s5]) < 32 || r3 > 126 && r3 < h2) {
                    this._printHandler(e4, i5, s5), i5 = s5 - 1;
                    break;
                  }
                  if (++s5 >= t4 || (r3 = e4[s5]) < 32 || r3 > 126 && r3 < h2) {
                    this._printHandler(e4, i5, s5), i5 = s5 - 1;
                    break;
                  }
                  if (++s5 >= t4 || (r3 = e4[s5]) < 32 || r3 > 126 && r3 < h2) {
                    this._printHandler(e4, i5, s5), i5 = s5 - 1;
                    break;
                  }
                }
                break;
              case 3:
                this._executeHandlers[r3] ? this._executeHandlers[r3]() : this._executeHandlerFb(r3), this.precedingJoinState = 0;
                break;
              case 0:
                break;
              case 1:
                if (this._errorHandler({ position: i5, code: r3, currentState: this.currentState, collect: this._collect, params: this._params, abort: false }).abort) return;
                break;
              case 7:
                const o4 = this._csiHandlers[this._collect << 8 | r3];
                let a3 = o4 ? o4.length - 1 : -1;
                for (; a3 >= 0 && (s4 = o4[a3](this._params), true !== s4); a3--) if (s4 instanceof Promise) return this._preserveStack(3, o4, a3, n3, i5), s4;
                a3 < 0 && this._csiHandlerFb(this._collect << 8 | r3, this._params), this.precedingJoinState = 0;
                break;
              case 8:
                do {
                  switch (r3) {
                    case 59:
                      this._params.addParam(0);
                      break;
                    case 58:
                      this._params.addSubParam(-1);
                      break;
                    default:
                      this._params.addDigit(r3 - 48);
                  }
                } while (++i5 < t4 && (r3 = e4[i5]) > 47 && r3 < 60);
                i5--;
                break;
              case 9:
                this._collect <<= 8, this._collect |= r3;
                break;
              case 10:
                const c3 = this._escHandlers[this._collect << 8 | r3];
                let l2 = c3 ? c3.length - 1 : -1;
                for (; l2 >= 0 && (s4 = c3[l2](), true !== s4); l2--) if (s4 instanceof Promise) return this._preserveStack(4, c3, l2, n3, i5), s4;
                l2 < 0 && this._escHandlerFb(this._collect << 8 | r3), this.precedingJoinState = 0;
                break;
              case 11:
                this._params.reset(), this._params.addParam(0), this._collect = 0;
                break;
              case 12:
                this._dcsParser.hook(this._collect << 8 | r3, this._params);
                break;
              case 13:
                for (let s5 = i5 + 1; ; ++s5) if (s5 >= t4 || 24 === (r3 = e4[s5]) || 26 === r3 || 27 === r3 || r3 > 127 && r3 < h2) {
                  this._dcsParser.put(e4, i5, s5), i5 = s5 - 1;
                  break;
                }
                break;
              case 14:
                if (s4 = this._dcsParser.unhook(24 !== r3 && 26 !== r3), s4) return this._preserveStack(6, [], 0, n3, i5), s4;
                27 === r3 && (n3 |= 1), this._params.reset(), this._params.addParam(0), this._collect = 0, this.precedingJoinState = 0;
                break;
              case 4:
                this._oscParser.start();
                break;
              case 5:
                for (let s5 = i5 + 1; ; s5++) if (s5 >= t4 || (r3 = e4[s5]) < 32 || r3 > 127 && r3 < h2) {
                  this._oscParser.put(e4, i5, s5), i5 = s5 - 1;
                  break;
                }
                break;
              case 6:
                if (s4 = this._oscParser.end(24 !== r3 && 26 !== r3), s4) return this._preserveStack(5, [], 0, n3, i5), s4;
                27 === r3 && (n3 |= 1), this._params.reset(), this._params.addParam(0), this._collect = 0, this.precedingJoinState = 0;
            }
            this.currentState = 15 & n3;
          }
        }
      }
      t3.EscapeSequenceParser = c2;
    }, 6242: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.OscHandler = t3.OscParser = void 0;
      const s3 = i3(5770), r2 = i3(482), n2 = [];
      t3.OscParser = class {
        constructor() {
          this._state = 0, this._active = n2, this._id = -1, this._handlers = /* @__PURE__ */ Object.create(null), this._handlerFb = () => {
          }, this._stack = { paused: false, loopPosition: 0, fallThrough: false };
        }
        registerHandler(e4, t4) {
          void 0 === this._handlers[e4] && (this._handlers[e4] = []);
          const i4 = this._handlers[e4];
          return i4.push(t4), { dispose: /* @__PURE__ */ __name(() => {
            const e5 = i4.indexOf(t4);
            -1 !== e5 && i4.splice(e5, 1);
          }, "dispose") };
        }
        clearHandler(e4) {
          this._handlers[e4] && delete this._handlers[e4];
        }
        setHandlerFallback(e4) {
          this._handlerFb = e4;
        }
        dispose() {
          this._handlers = /* @__PURE__ */ Object.create(null), this._handlerFb = () => {
          }, this._active = n2;
        }
        reset() {
          if (2 === this._state) for (let e4 = this._stack.paused ? this._stack.loopPosition - 1 : this._active.length - 1; e4 >= 0; --e4) this._active[e4].end(false);
          this._stack.paused = false, this._active = n2, this._id = -1, this._state = 0;
        }
        _start() {
          if (this._active = this._handlers[this._id] || n2, this._active.length) for (let e4 = this._active.length - 1; e4 >= 0; e4--) this._active[e4].start();
          else this._handlerFb(this._id, "START");
        }
        _put(e4, t4, i4) {
          if (this._active.length) for (let s4 = this._active.length - 1; s4 >= 0; s4--) this._active[s4].put(e4, t4, i4);
          else this._handlerFb(this._id, "PUT", (0, r2.utf32ToString)(e4, t4, i4));
        }
        start() {
          this.reset(), this._state = 1;
        }
        put(e4, t4, i4) {
          if (3 !== this._state) {
            if (1 === this._state) for (; t4 < i4; ) {
              const i5 = e4[t4++];
              if (59 === i5) {
                this._state = 2, this._start();
                break;
              }
              if (i5 < 48 || 57 < i5) return void (this._state = 3);
              -1 === this._id && (this._id = 0), this._id = 10 * this._id + i5 - 48;
            }
            2 === this._state && i4 - t4 > 0 && this._put(e4, t4, i4);
          }
        }
        end(e4, t4 = true) {
          if (0 !== this._state) {
            if (3 !== this._state) if (1 === this._state && this._start(), this._active.length) {
              let i4 = false, s4 = this._active.length - 1, r3 = false;
              if (this._stack.paused && (s4 = this._stack.loopPosition - 1, i4 = t4, r3 = this._stack.fallThrough, this._stack.paused = false), !r3 && false === i4) {
                for (; s4 >= 0 && (i4 = this._active[s4].end(e4), true !== i4); s4--) if (i4 instanceof Promise) return this._stack.paused = true, this._stack.loopPosition = s4, this._stack.fallThrough = false, i4;
                s4--;
              }
              for (; s4 >= 0; s4--) if (i4 = this._active[s4].end(false), i4 instanceof Promise) return this._stack.paused = true, this._stack.loopPosition = s4, this._stack.fallThrough = true, i4;
            } else this._handlerFb(this._id, "END", e4);
            this._active = n2, this._id = -1, this._state = 0;
          }
        }
      }, t3.OscHandler = class {
        constructor(e4) {
          this._handler = e4, this._data = "", this._hitLimit = false;
        }
        start() {
          this._data = "", this._hitLimit = false;
        }
        put(e4, t4, i4) {
          this._hitLimit || (this._data += (0, r2.utf32ToString)(e4, t4, i4), this._data.length > s3.PAYLOAD_LIMIT && (this._data = "", this._hitLimit = true));
        }
        end(e4) {
          let t4 = false;
          if (this._hitLimit) t4 = false;
          else if (e4 && (t4 = this._handler(this._data), t4 instanceof Promise)) return t4.then((e5) => (this._data = "", this._hitLimit = false, e5));
          return this._data = "", this._hitLimit = false, t4;
        }
      };
    }, 8742: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.Params = void 0;
      const i3 = 2147483647;
      class s3 {
        static {
          __name(this, "s");
        }
        static fromArray(e4) {
          const t4 = new s3();
          if (!e4.length) return t4;
          for (let i4 = Array.isArray(e4[0]) ? 1 : 0; i4 < e4.length; ++i4) {
            const s4 = e4[i4];
            if (Array.isArray(s4)) for (let e5 = 0; e5 < s4.length; ++e5) t4.addSubParam(s4[e5]);
            else t4.addParam(s4);
          }
          return t4;
        }
        constructor(e4 = 32, t4 = 32) {
          if (this.maxLength = e4, this.maxSubParamsLength = t4, t4 > 256) throw new Error("maxSubParamsLength must not be greater than 256");
          this.params = new Int32Array(e4), this.length = 0, this._subParams = new Int32Array(t4), this._subParamsLength = 0, this._subParamsIdx = new Uint16Array(e4), this._rejectDigits = false, this._rejectSubDigits = false, this._digitIsSub = false;
        }
        clone() {
          const e4 = new s3(this.maxLength, this.maxSubParamsLength);
          return e4.params.set(this.params), e4.length = this.length, e4._subParams.set(this._subParams), e4._subParamsLength = this._subParamsLength, e4._subParamsIdx.set(this._subParamsIdx), e4._rejectDigits = this._rejectDigits, e4._rejectSubDigits = this._rejectSubDigits, e4._digitIsSub = this._digitIsSub, e4;
        }
        toArray() {
          const e4 = [];
          for (let t4 = 0; t4 < this.length; ++t4) {
            e4.push(this.params[t4]);
            const i4 = this._subParamsIdx[t4] >> 8, s4 = 255 & this._subParamsIdx[t4];
            s4 - i4 > 0 && e4.push(Array.prototype.slice.call(this._subParams, i4, s4));
          }
          return e4;
        }
        reset() {
          this.length = 0, this._subParamsLength = 0, this._rejectDigits = false, this._rejectSubDigits = false, this._digitIsSub = false;
        }
        addParam(e4) {
          if (this._digitIsSub = false, this.length >= this.maxLength) this._rejectDigits = true;
          else {
            if (e4 < -1) throw new Error("values lesser than -1 are not allowed");
            this._subParamsIdx[this.length] = this._subParamsLength << 8 | this._subParamsLength, this.params[this.length++] = e4 > i3 ? i3 : e4;
          }
        }
        addSubParam(e4) {
          if (this._digitIsSub = true, this.length) if (this._rejectDigits || this._subParamsLength >= this.maxSubParamsLength) this._rejectSubDigits = true;
          else {
            if (e4 < -1) throw new Error("values lesser than -1 are not allowed");
            this._subParams[this._subParamsLength++] = e4 > i3 ? i3 : e4, this._subParamsIdx[this.length - 1]++;
          }
        }
        hasSubParams(e4) {
          return (255 & this._subParamsIdx[e4]) - (this._subParamsIdx[e4] >> 8) > 0;
        }
        getSubParams(e4) {
          const t4 = this._subParamsIdx[e4] >> 8, i4 = 255 & this._subParamsIdx[e4];
          return i4 - t4 > 0 ? this._subParams.subarray(t4, i4) : null;
        }
        getSubParamsAll() {
          const e4 = {};
          for (let t4 = 0; t4 < this.length; ++t4) {
            const i4 = this._subParamsIdx[t4] >> 8, s4 = 255 & this._subParamsIdx[t4];
            s4 - i4 > 0 && (e4[t4] = this._subParams.slice(i4, s4));
          }
          return e4;
        }
        addDigit(e4) {
          let t4;
          if (this._rejectDigits || !(t4 = this._digitIsSub ? this._subParamsLength : this.length) || this._digitIsSub && this._rejectSubDigits) return;
          const s4 = this._digitIsSub ? this._subParams : this.params, r2 = s4[t4 - 1];
          s4[t4 - 1] = ~r2 ? Math.min(10 * r2 + e4, i3) : e4;
        }
      }
      t3.Params = s3;
    }, 5741: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.AddonManager = void 0, t3.AddonManager = class {
        constructor() {
          this._addons = [];
        }
        dispose() {
          for (let e4 = this._addons.length - 1; e4 >= 0; e4--) this._addons[e4].instance.dispose();
        }
        loadAddon(e4, t4) {
          const i3 = { instance: t4, dispose: t4.dispose, isDisposed: false };
          this._addons.push(i3), t4.dispose = () => this._wrappedAddonDispose(i3), t4.activate(e4);
        }
        _wrappedAddonDispose(e4) {
          if (e4.isDisposed) return;
          let t4 = -1;
          for (let i3 = 0; i3 < this._addons.length; i3++) if (this._addons[i3] === e4) {
            t4 = i3;
            break;
          }
          if (-1 === t4) throw new Error("Could not dispose an addon that has not been loaded");
          e4.isDisposed = true, e4.dispose.apply(e4.instance), this._addons.splice(t4, 1);
        }
      };
    }, 8771: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferApiView = void 0;
      const s3 = i3(3785), r2 = i3(511);
      t3.BufferApiView = class {
        constructor(e4, t4) {
          this._buffer = e4, this.type = t4;
        }
        init(e4) {
          return this._buffer = e4, this;
        }
        get cursorY() {
          return this._buffer.y;
        }
        get cursorX() {
          return this._buffer.x;
        }
        get viewportY() {
          return this._buffer.ydisp;
        }
        get baseY() {
          return this._buffer.ybase;
        }
        get length() {
          return this._buffer.lines.length;
        }
        getLine(e4) {
          const t4 = this._buffer.lines.get(e4);
          if (t4) return new s3.BufferLineApiView(t4);
        }
        getNullCell() {
          return new r2.CellData();
        }
      };
    }, 3785: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferLineApiView = void 0;
      const s3 = i3(511);
      t3.BufferLineApiView = class {
        constructor(e4) {
          this._line = e4;
        }
        get isWrapped() {
          return this._line.isWrapped;
        }
        get length() {
          return this._line.length;
        }
        getCell(e4, t4) {
          if (!(e4 < 0 || e4 >= this._line.length)) return t4 ? (this._line.loadCell(e4, t4), t4) : this._line.loadCell(e4, new s3.CellData());
        }
        translateToString(e4, t4, i4) {
          return this._line.translateToString(e4, t4, i4);
        }
      };
    }, 8285: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferNamespaceApi = void 0;
      const s3 = i3(8771), r2 = i3(8460), n2 = i3(844);
      class o2 extends n2.Disposable {
        static {
          __name(this, "o");
        }
        constructor(e4) {
          super(), this._core = e4, this._onBufferChange = this.register(new r2.EventEmitter()), this.onBufferChange = this._onBufferChange.event, this._normal = new s3.BufferApiView(this._core.buffers.normal, "normal"), this._alternate = new s3.BufferApiView(this._core.buffers.alt, "alternate"), this._core.buffers.onBufferActivate(() => this._onBufferChange.fire(this.active));
        }
        get active() {
          if (this._core.buffers.active === this._core.buffers.normal) return this.normal;
          if (this._core.buffers.active === this._core.buffers.alt) return this.alternate;
          throw new Error("Active buffer is neither normal nor alternate");
        }
        get normal() {
          return this._normal.init(this._core.buffers.normal);
        }
        get alternate() {
          return this._alternate.init(this._core.buffers.alt);
        }
      }
      t3.BufferNamespaceApi = o2;
    }, 7975: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.ParserApi = void 0, t3.ParserApi = class {
        constructor(e4) {
          this._core = e4;
        }
        registerCsiHandler(e4, t4) {
          return this._core.registerCsiHandler(e4, (e5) => t4(e5.toArray()));
        }
        addCsiHandler(e4, t4) {
          return this.registerCsiHandler(e4, t4);
        }
        registerDcsHandler(e4, t4) {
          return this._core.registerDcsHandler(e4, (e5, i3) => t4(e5, i3.toArray()));
        }
        addDcsHandler(e4, t4) {
          return this.registerDcsHandler(e4, t4);
        }
        registerEscHandler(e4, t4) {
          return this._core.registerEscHandler(e4, t4);
        }
        addEscHandler(e4, t4) {
          return this.registerEscHandler(e4, t4);
        }
        registerOscHandler(e4, t4) {
          return this._core.registerOscHandler(e4, t4);
        }
        addOscHandler(e4, t4) {
          return this.registerOscHandler(e4, t4);
        }
      };
    }, 7090: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.UnicodeApi = void 0, t3.UnicodeApi = class {
        constructor(e4) {
          this._core = e4;
        }
        register(e4) {
          this._core.unicodeService.register(e4);
        }
        get versions() {
          return this._core.unicodeService.versions;
        }
        get activeVersion() {
          return this._core.unicodeService.activeVersion;
        }
        set activeVersion(e4) {
          this._core.unicodeService.activeVersion = e4;
        }
      };
    }, 744: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.BufferService = t3.MINIMUM_ROWS = t3.MINIMUM_COLS = void 0;
      const n2 = i3(8460), o2 = i3(844), a2 = i3(5295), h2 = i3(2585);
      t3.MINIMUM_COLS = 2, t3.MINIMUM_ROWS = 1;
      let c2 = t3.BufferService = class extends o2.Disposable {
        get buffer() {
          return this.buffers.active;
        }
        constructor(e4) {
          super(), this.isUserScrolling = false, this._onResize = this.register(new n2.EventEmitter()), this.onResize = this._onResize.event, this._onScroll = this.register(new n2.EventEmitter()), this.onScroll = this._onScroll.event, this.cols = Math.max(e4.rawOptions.cols || 0, t3.MINIMUM_COLS), this.rows = Math.max(e4.rawOptions.rows || 0, t3.MINIMUM_ROWS), this.buffers = this.register(new a2.BufferSet(e4, this));
        }
        resize(e4, t4) {
          this.cols = e4, this.rows = t4, this.buffers.resize(e4, t4), this._onResize.fire({ cols: e4, rows: t4 });
        }
        reset() {
          this.buffers.reset(), this.isUserScrolling = false;
        }
        scroll(e4, t4 = false) {
          const i4 = this.buffer;
          let s4;
          s4 = this._cachedBlankLine, s4 && s4.length === this.cols && s4.getFg(0) === e4.fg && s4.getBg(0) === e4.bg || (s4 = i4.getBlankLine(e4, t4), this._cachedBlankLine = s4), s4.isWrapped = t4;
          const r3 = i4.ybase + i4.scrollTop, n3 = i4.ybase + i4.scrollBottom;
          if (0 === i4.scrollTop) {
            const e5 = i4.lines.isFull;
            n3 === i4.lines.length - 1 ? e5 ? i4.lines.recycle().copyFrom(s4) : i4.lines.push(s4.clone()) : i4.lines.splice(n3 + 1, 0, s4.clone()), e5 ? this.isUserScrolling && (i4.ydisp = Math.max(i4.ydisp - 1, 0)) : (i4.ybase++, this.isUserScrolling || i4.ydisp++);
          } else {
            const e5 = n3 - r3 + 1;
            i4.lines.shiftElements(r3 + 1, e5 - 1, -1), i4.lines.set(n3, s4.clone());
          }
          this.isUserScrolling || (i4.ydisp = i4.ybase), this._onScroll.fire(i4.ydisp);
        }
        scrollLines(e4, t4, i4) {
          const s4 = this.buffer;
          if (e4 < 0) {
            if (0 === s4.ydisp) return;
            this.isUserScrolling = true;
          } else e4 + s4.ydisp >= s4.ybase && (this.isUserScrolling = false);
          const r3 = s4.ydisp;
          s4.ydisp = Math.max(Math.min(s4.ydisp + e4, s4.ybase), 0), r3 !== s4.ydisp && (t4 || this._onScroll.fire(s4.ydisp));
        }
      };
      t3.BufferService = c2 = s3([r2(0, h2.IOptionsService)], c2);
    }, 7994: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CharsetService = void 0, t3.CharsetService = class {
        constructor() {
          this.glevel = 0, this._charsets = [];
        }
        reset() {
          this.charset = void 0, this._charsets = [], this.glevel = 0;
        }
        setgLevel(e4) {
          this.glevel = e4, this.charset = this._charsets[e4];
        }
        setgCharset(e4, t4) {
          this._charsets[e4] = t4, this.glevel === e4 && (this.charset = t4);
        }
      };
    }, 1753: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CoreMouseService = void 0;
      const n2 = i3(2585), o2 = i3(8460), a2 = i3(844), h2 = { NONE: { events: 0, restrict: /* @__PURE__ */ __name(() => false, "restrict") }, X10: { events: 1, restrict: /* @__PURE__ */ __name((e4) => 4 !== e4.button && 1 === e4.action && (e4.ctrl = false, e4.alt = false, e4.shift = false, true), "restrict") }, VT200: { events: 19, restrict: /* @__PURE__ */ __name((e4) => 32 !== e4.action, "restrict") }, DRAG: { events: 23, restrict: /* @__PURE__ */ __name((e4) => 32 !== e4.action || 3 !== e4.button, "restrict") }, ANY: { events: 31, restrict: /* @__PURE__ */ __name((e4) => true, "restrict") } };
      function c2(e4, t4) {
        let i4 = (e4.ctrl ? 16 : 0) | (e4.shift ? 4 : 0) | (e4.alt ? 8 : 0);
        return 4 === e4.button ? (i4 |= 64, i4 |= e4.action) : (i4 |= 3 & e4.button, 4 & e4.button && (i4 |= 64), 8 & e4.button && (i4 |= 128), 32 === e4.action ? i4 |= 32 : 0 !== e4.action || t4 || (i4 |= 3)), i4;
      }
      __name(c2, "c");
      const l2 = String.fromCharCode, d2 = { DEFAULT: /* @__PURE__ */ __name((e4) => {
        const t4 = [c2(e4, false) + 32, e4.col + 32, e4.row + 32];
        return t4[0] > 255 || t4[1] > 255 || t4[2] > 255 ? "" : `\x1B[M${l2(t4[0])}${l2(t4[1])}${l2(t4[2])}`;
      }, "DEFAULT"), SGR: /* @__PURE__ */ __name((e4) => {
        const t4 = 0 === e4.action && 4 !== e4.button ? "m" : "M";
        return `\x1B[<${c2(e4, true)};${e4.col};${e4.row}${t4}`;
      }, "SGR"), SGR_PIXELS: /* @__PURE__ */ __name((e4) => {
        const t4 = 0 === e4.action && 4 !== e4.button ? "m" : "M";
        return `\x1B[<${c2(e4, true)};${e4.x};${e4.y}${t4}`;
      }, "SGR_PIXELS") };
      let _2 = t3.CoreMouseService = class extends a2.Disposable {
        constructor(e4, t4) {
          super(), this._bufferService = e4, this._coreService = t4, this._protocols = {}, this._encodings = {}, this._activeProtocol = "", this._activeEncoding = "", this._lastEvent = null, this._onProtocolChange = this.register(new o2.EventEmitter()), this.onProtocolChange = this._onProtocolChange.event;
          for (const e5 of Object.keys(h2)) this.addProtocol(e5, h2[e5]);
          for (const e5 of Object.keys(d2)) this.addEncoding(e5, d2[e5]);
          this.reset();
        }
        addProtocol(e4, t4) {
          this._protocols[e4] = t4;
        }
        addEncoding(e4, t4) {
          this._encodings[e4] = t4;
        }
        get activeProtocol() {
          return this._activeProtocol;
        }
        get areMouseEventsActive() {
          return 0 !== this._protocols[this._activeProtocol].events;
        }
        set activeProtocol(e4) {
          if (!this._protocols[e4]) throw new Error(`unknown protocol "${e4}"`);
          this._activeProtocol = e4, this._onProtocolChange.fire(this._protocols[e4].events);
        }
        get activeEncoding() {
          return this._activeEncoding;
        }
        set activeEncoding(e4) {
          if (!this._encodings[e4]) throw new Error(`unknown encoding "${e4}"`);
          this._activeEncoding = e4;
        }
        reset() {
          this.activeProtocol = "NONE", this.activeEncoding = "DEFAULT", this._lastEvent = null;
        }
        triggerMouseEvent(e4) {
          if (e4.col < 0 || e4.col >= this._bufferService.cols || e4.row < 0 || e4.row >= this._bufferService.rows) return false;
          if (4 === e4.button && 32 === e4.action) return false;
          if (3 === e4.button && 32 !== e4.action) return false;
          if (4 !== e4.button && (2 === e4.action || 3 === e4.action)) return false;
          if (e4.col++, e4.row++, 32 === e4.action && this._lastEvent && this._equalEvents(this._lastEvent, e4, "SGR_PIXELS" === this._activeEncoding)) return false;
          if (!this._protocols[this._activeProtocol].restrict(e4)) return false;
          const t4 = this._encodings[this._activeEncoding](e4);
          return t4 && ("DEFAULT" === this._activeEncoding ? this._coreService.triggerBinaryEvent(t4) : this._coreService.triggerDataEvent(t4, true)), this._lastEvent = e4, true;
        }
        explainEvents(e4) {
          return { down: !!(1 & e4), up: !!(2 & e4), drag: !!(4 & e4), move: !!(8 & e4), wheel: !!(16 & e4) };
        }
        _equalEvents(e4, t4, i4) {
          if (i4) {
            if (e4.x !== t4.x) return false;
            if (e4.y !== t4.y) return false;
          } else {
            if (e4.col !== t4.col) return false;
            if (e4.row !== t4.row) return false;
          }
          return e4.button === t4.button && e4.action === t4.action && e4.ctrl === t4.ctrl && e4.alt === t4.alt && e4.shift === t4.shift;
        }
      };
      t3.CoreMouseService = _2 = s3([r2(0, n2.IBufferService), r2(1, n2.ICoreService)], _2);
    }, 6975: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.CoreService = void 0;
      const n2 = i3(1439), o2 = i3(8460), a2 = i3(844), h2 = i3(2585), c2 = Object.freeze({ insertMode: false }), l2 = Object.freeze({ applicationCursorKeys: false, applicationKeypad: false, bracketedPasteMode: false, origin: false, reverseWraparound: false, sendFocus: false, wraparound: true });
      let d2 = t3.CoreService = class extends a2.Disposable {
        constructor(e4, t4, i4) {
          super(), this._bufferService = e4, this._logService = t4, this._optionsService = i4, this.isCursorInitialized = false, this.isCursorHidden = false, this._onData = this.register(new o2.EventEmitter()), this.onData = this._onData.event, this._onUserInput = this.register(new o2.EventEmitter()), this.onUserInput = this._onUserInput.event, this._onBinary = this.register(new o2.EventEmitter()), this.onBinary = this._onBinary.event, this._onRequestScrollToBottom = this.register(new o2.EventEmitter()), this.onRequestScrollToBottom = this._onRequestScrollToBottom.event, this.modes = (0, n2.clone)(c2), this.decPrivateModes = (0, n2.clone)(l2);
        }
        reset() {
          this.modes = (0, n2.clone)(c2), this.decPrivateModes = (0, n2.clone)(l2);
        }
        triggerDataEvent(e4, t4 = false) {
          if (this._optionsService.rawOptions.disableStdin) return;
          const i4 = this._bufferService.buffer;
          t4 && this._optionsService.rawOptions.scrollOnUserInput && i4.ybase !== i4.ydisp && this._onRequestScrollToBottom.fire(), t4 && this._onUserInput.fire(), this._logService.debug(`sending data "${e4}"`, () => e4.split("").map((e5) => e5.charCodeAt(0))), this._onData.fire(e4);
        }
        triggerBinaryEvent(e4) {
          this._optionsService.rawOptions.disableStdin || (this._logService.debug(`sending binary "${e4}"`, () => e4.split("").map((e5) => e5.charCodeAt(0))), this._onBinary.fire(e4));
        }
      };
      t3.CoreService = d2 = s3([r2(0, h2.IBufferService), r2(1, h2.ILogService), r2(2, h2.IOptionsService)], d2);
    }, 9074: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.DecorationService = void 0;
      const s3 = i3(8055), r2 = i3(8460), n2 = i3(844), o2 = i3(6106);
      let a2 = 0, h2 = 0;
      class c2 extends n2.Disposable {
        static {
          __name(this, "c");
        }
        get decorations() {
          return this._decorations.values();
        }
        constructor() {
          super(), this._decorations = new o2.SortedList((e4) => e4?.marker.line), this._onDecorationRegistered = this.register(new r2.EventEmitter()), this.onDecorationRegistered = this._onDecorationRegistered.event, this._onDecorationRemoved = this.register(new r2.EventEmitter()), this.onDecorationRemoved = this._onDecorationRemoved.event, this.register((0, n2.toDisposable)(() => this.reset()));
        }
        registerDecoration(e4) {
          if (e4.marker.isDisposed) return;
          const t4 = new l2(e4);
          if (t4) {
            const e5 = t4.marker.onDispose(() => t4.dispose());
            t4.onDispose(() => {
              t4 && (this._decorations.delete(t4) && this._onDecorationRemoved.fire(t4), e5.dispose());
            }), this._decorations.insert(t4), this._onDecorationRegistered.fire(t4);
          }
          return t4;
        }
        reset() {
          for (const e4 of this._decorations.values()) e4.dispose();
          this._decorations.clear();
        }
        *getDecorationsAtCell(e4, t4, i4) {
          let s4 = 0, r3 = 0;
          for (const n3 of this._decorations.getKeyIterator(t4)) s4 = n3.options.x ?? 0, r3 = s4 + (n3.options.width ?? 1), e4 >= s4 && e4 < r3 && (!i4 || (n3.options.layer ?? "bottom") === i4) && (yield n3);
        }
        forEachDecorationAtCell(e4, t4, i4, s4) {
          this._decorations.forEachByKey(t4, (t5) => {
            a2 = t5.options.x ?? 0, h2 = a2 + (t5.options.width ?? 1), e4 >= a2 && e4 < h2 && (!i4 || (t5.options.layer ?? "bottom") === i4) && s4(t5);
          });
        }
      }
      t3.DecorationService = c2;
      class l2 extends n2.Disposable {
        static {
          __name(this, "l");
        }
        get isDisposed() {
          return this._isDisposed;
        }
        get backgroundColorRGB() {
          return null === this._cachedBg && (this.options.backgroundColor ? this._cachedBg = s3.css.toColor(this.options.backgroundColor) : this._cachedBg = void 0), this._cachedBg;
        }
        get foregroundColorRGB() {
          return null === this._cachedFg && (this.options.foregroundColor ? this._cachedFg = s3.css.toColor(this.options.foregroundColor) : this._cachedFg = void 0), this._cachedFg;
        }
        constructor(e4) {
          super(), this.options = e4, this.onRenderEmitter = this.register(new r2.EventEmitter()), this.onRender = this.onRenderEmitter.event, this._onDispose = this.register(new r2.EventEmitter()), this.onDispose = this._onDispose.event, this._cachedBg = null, this._cachedFg = null, this.marker = e4.marker, this.options.overviewRulerOptions && !this.options.overviewRulerOptions.position && (this.options.overviewRulerOptions.position = "full");
        }
        dispose() {
          this._onDispose.fire(), super.dispose();
        }
      }
    }, 4348: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.InstantiationService = t3.ServiceCollection = void 0;
      const s3 = i3(2585), r2 = i3(8343);
      class n2 {
        static {
          __name(this, "n");
        }
        constructor(...e4) {
          this._entries = /* @__PURE__ */ new Map();
          for (const [t4, i4] of e4) this.set(t4, i4);
        }
        set(e4, t4) {
          const i4 = this._entries.get(e4);
          return this._entries.set(e4, t4), i4;
        }
        forEach(e4) {
          for (const [t4, i4] of this._entries.entries()) e4(t4, i4);
        }
        has(e4) {
          return this._entries.has(e4);
        }
        get(e4) {
          return this._entries.get(e4);
        }
      }
      t3.ServiceCollection = n2, t3.InstantiationService = class {
        constructor() {
          this._services = new n2(), this._services.set(s3.IInstantiationService, this);
        }
        setService(e4, t4) {
          this._services.set(e4, t4);
        }
        getService(e4) {
          return this._services.get(e4);
        }
        createInstance(e4, ...t4) {
          const i4 = (0, r2.getServiceDependencies)(e4).sort((e5, t5) => e5.index - t5.index), s4 = [];
          for (const t5 of i4) {
            const i5 = this._services.get(t5.id);
            if (!i5) throw new Error(`[createInstance] ${e4.name} depends on UNKNOWN service ${t5.id}.`);
            s4.push(i5);
          }
          const n3 = i4.length > 0 ? i4[0].index : t4.length;
          if (t4.length !== n3) throw new Error(`[createInstance] First service dependency of ${e4.name} at position ${n3 + 1} conflicts with ${t4.length} static arguments`);
          return new e4(...[...t4, ...s4]);
        }
      };
    }, 7866: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a3 = e4.length - 1; a3 >= 0; a3--) (r3 = e4[a3]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.traceCall = t3.setTraceLogger = t3.LogService = void 0;
      const n2 = i3(844), o2 = i3(2585), a2 = { trace: o2.LogLevelEnum.TRACE, debug: o2.LogLevelEnum.DEBUG, info: o2.LogLevelEnum.INFO, warn: o2.LogLevelEnum.WARN, error: o2.LogLevelEnum.ERROR, off: o2.LogLevelEnum.OFF };
      let h2, c2 = t3.LogService = class extends n2.Disposable {
        get logLevel() {
          return this._logLevel;
        }
        constructor(e4) {
          super(), this._optionsService = e4, this._logLevel = o2.LogLevelEnum.OFF, this._updateLogLevel(), this.register(this._optionsService.onSpecificOptionChange("logLevel", () => this._updateLogLevel())), h2 = this;
        }
        _updateLogLevel() {
          this._logLevel = a2[this._optionsService.rawOptions.logLevel];
        }
        _evalLazyOptionalParams(e4) {
          for (let t4 = 0; t4 < e4.length; t4++) "function" == typeof e4[t4] && (e4[t4] = e4[t4]());
        }
        _log(e4, t4, i4) {
          this._evalLazyOptionalParams(i4), e4.call(console, (this._optionsService.options.logger ? "" : "xterm.js: ") + t4, ...i4);
        }
        trace(e4, ...t4) {
          this._logLevel <= o2.LogLevelEnum.TRACE && this._log(this._optionsService.options.logger?.trace.bind(this._optionsService.options.logger) ?? console.log, e4, t4);
        }
        debug(e4, ...t4) {
          this._logLevel <= o2.LogLevelEnum.DEBUG && this._log(this._optionsService.options.logger?.debug.bind(this._optionsService.options.logger) ?? console.log, e4, t4);
        }
        info(e4, ...t4) {
          this._logLevel <= o2.LogLevelEnum.INFO && this._log(this._optionsService.options.logger?.info.bind(this._optionsService.options.logger) ?? console.info, e4, t4);
        }
        warn(e4, ...t4) {
          this._logLevel <= o2.LogLevelEnum.WARN && this._log(this._optionsService.options.logger?.warn.bind(this._optionsService.options.logger) ?? console.warn, e4, t4);
        }
        error(e4, ...t4) {
          this._logLevel <= o2.LogLevelEnum.ERROR && this._log(this._optionsService.options.logger?.error.bind(this._optionsService.options.logger) ?? console.error, e4, t4);
        }
      };
      t3.LogService = c2 = s3([r2(0, o2.IOptionsService)], c2), t3.setTraceLogger = function(e4) {
        h2 = e4;
      }, t3.traceCall = function(e4, t4, i4) {
        if ("function" != typeof i4.value) throw new Error("not supported");
        const s4 = i4.value;
        i4.value = function(...e5) {
          if (h2.logLevel !== o2.LogLevelEnum.TRACE) return s4.apply(this, e5);
          h2.trace(`GlyphRenderer#${s4.name}(${e5.map((e6) => JSON.stringify(e6)).join(", ")})`);
          const t5 = s4.apply(this, e5);
          return h2.trace(`GlyphRenderer#${s4.name} return`, t5), t5;
        };
      };
    }, 7302: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.OptionsService = t3.DEFAULT_OPTIONS = void 0;
      const s3 = i3(8460), r2 = i3(844), n2 = i3(6114);
      t3.DEFAULT_OPTIONS = { cols: 80, rows: 24, cursorBlink: false, cursorStyle: "block", cursorWidth: 1, cursorInactiveStyle: "outline", customGlyphs: true, drawBoldTextInBrightColors: true, documentOverride: null, fastScrollModifier: "alt", fastScrollSensitivity: 5, fontFamily: "courier-new, courier, monospace", fontSize: 15, fontWeight: "normal", fontWeightBold: "bold", ignoreBracketedPasteMode: false, lineHeight: 1, letterSpacing: 0, linkHandler: null, logLevel: "info", logger: null, scrollback: 1e3, scrollOnUserInput: true, scrollSensitivity: 1, screenReaderMode: false, smoothScrollDuration: 0, macOptionIsMeta: false, macOptionClickForcesSelection: false, minimumContrastRatio: 1, disableStdin: false, allowProposedApi: false, allowTransparency: false, tabStopWidth: 8, theme: {}, rescaleOverlappingGlyphs: false, rightClickSelectsWord: n2.isMac, windowOptions: {}, windowsMode: false, windowsPty: {}, wordSeparator: " ()[]{}',\"`", altClickMovesCursor: true, convertEol: false, termName: "xterm", cancelEvents: false, overviewRulerWidth: 0 };
      const o2 = ["normal", "bold", "100", "200", "300", "400", "500", "600", "700", "800", "900"];
      class a2 extends r2.Disposable {
        static {
          __name(this, "a");
        }
        constructor(e4) {
          super(), this._onOptionChange = this.register(new s3.EventEmitter()), this.onOptionChange = this._onOptionChange.event;
          const i4 = { ...t3.DEFAULT_OPTIONS };
          for (const t4 in e4) if (t4 in i4) try {
            const s4 = e4[t4];
            i4[t4] = this._sanitizeAndValidateOption(t4, s4);
          } catch (e5) {
            console.error(e5);
          }
          this.rawOptions = i4, this.options = { ...i4 }, this._setupOptions(), this.register((0, r2.toDisposable)(() => {
            this.rawOptions.linkHandler = null, this.rawOptions.documentOverride = null;
          }));
        }
        onSpecificOptionChange(e4, t4) {
          return this.onOptionChange((i4) => {
            i4 === e4 && t4(this.rawOptions[e4]);
          });
        }
        onMultipleOptionChange(e4, t4) {
          return this.onOptionChange((i4) => {
            -1 !== e4.indexOf(i4) && t4();
          });
        }
        _setupOptions() {
          const e4 = /* @__PURE__ */ __name((e5) => {
            if (!(e5 in t3.DEFAULT_OPTIONS)) throw new Error(`No option with key "${e5}"`);
            return this.rawOptions[e5];
          }, "e"), i4 = /* @__PURE__ */ __name((e5, i5) => {
            if (!(e5 in t3.DEFAULT_OPTIONS)) throw new Error(`No option with key "${e5}"`);
            i5 = this._sanitizeAndValidateOption(e5, i5), this.rawOptions[e5] !== i5 && (this.rawOptions[e5] = i5, this._onOptionChange.fire(e5));
          }, "i");
          for (const t4 in this.rawOptions) {
            const s4 = { get: e4.bind(this, t4), set: i4.bind(this, t4) };
            Object.defineProperty(this.options, t4, s4);
          }
        }
        _sanitizeAndValidateOption(e4, i4) {
          switch (e4) {
            case "cursorStyle":
              if (i4 || (i4 = t3.DEFAULT_OPTIONS[e4]), !/* @__PURE__ */ function(e5) {
                return "block" === e5 || "underline" === e5 || "bar" === e5;
              }(i4)) throw new Error(`"${i4}" is not a valid value for ${e4}`);
              break;
            case "wordSeparator":
              i4 || (i4 = t3.DEFAULT_OPTIONS[e4]);
              break;
            case "fontWeight":
            case "fontWeightBold":
              if ("number" == typeof i4 && 1 <= i4 && i4 <= 1e3) break;
              i4 = o2.includes(i4) ? i4 : t3.DEFAULT_OPTIONS[e4];
              break;
            case "cursorWidth":
              i4 = Math.floor(i4);
            case "lineHeight":
            case "tabStopWidth":
              if (i4 < 1) throw new Error(`${e4} cannot be less than 1, value: ${i4}`);
              break;
            case "minimumContrastRatio":
              i4 = Math.max(1, Math.min(21, Math.round(10 * i4) / 10));
              break;
            case "scrollback":
              if ((i4 = Math.min(i4, 4294967295)) < 0) throw new Error(`${e4} cannot be less than 0, value: ${i4}`);
              break;
            case "fastScrollSensitivity":
            case "scrollSensitivity":
              if (i4 <= 0) throw new Error(`${e4} cannot be less than or equal to 0, value: ${i4}`);
              break;
            case "rows":
            case "cols":
              if (!i4 && 0 !== i4) throw new Error(`${e4} must be numeric, value: ${i4}`);
              break;
            case "windowsPty":
              i4 = i4 ?? {};
          }
          return i4;
        }
      }
      t3.OptionsService = a2;
    }, 2660: function(e3, t3, i3) {
      var s3 = this && this.__decorate || function(e4, t4, i4, s4) {
        var r3, n3 = arguments.length, o3 = n3 < 3 ? t4 : null === s4 ? s4 = Object.getOwnPropertyDescriptor(t4, i4) : s4;
        if ("object" == typeof Reflect && "function" == typeof Reflect.decorate) o3 = Reflect.decorate(e4, t4, i4, s4);
        else for (var a2 = e4.length - 1; a2 >= 0; a2--) (r3 = e4[a2]) && (o3 = (n3 < 3 ? r3(o3) : n3 > 3 ? r3(t4, i4, o3) : r3(t4, i4)) || o3);
        return n3 > 3 && o3 && Object.defineProperty(t4, i4, o3), o3;
      }, r2 = this && this.__param || function(e4, t4) {
        return function(i4, s4) {
          t4(i4, s4, e4);
        };
      };
      Object.defineProperty(t3, "__esModule", { value: true }), t3.OscLinkService = void 0;
      const n2 = i3(2585);
      let o2 = t3.OscLinkService = class {
        constructor(e4) {
          this._bufferService = e4, this._nextId = 1, this._entriesWithId = /* @__PURE__ */ new Map(), this._dataByLinkId = /* @__PURE__ */ new Map();
        }
        registerLink(e4) {
          const t4 = this._bufferService.buffer;
          if (void 0 === e4.id) {
            const i5 = t4.addMarker(t4.ybase + t4.y), s5 = { data: e4, id: this._nextId++, lines: [i5] };
            return i5.onDispose(() => this._removeMarkerFromLink(s5, i5)), this._dataByLinkId.set(s5.id, s5), s5.id;
          }
          const i4 = e4, s4 = this._getEntryIdKey(i4), r3 = this._entriesWithId.get(s4);
          if (r3) return this.addLineToLink(r3.id, t4.ybase + t4.y), r3.id;
          const n3 = t4.addMarker(t4.ybase + t4.y), o3 = { id: this._nextId++, key: this._getEntryIdKey(i4), data: i4, lines: [n3] };
          return n3.onDispose(() => this._removeMarkerFromLink(o3, n3)), this._entriesWithId.set(o3.key, o3), this._dataByLinkId.set(o3.id, o3), o3.id;
        }
        addLineToLink(e4, t4) {
          const i4 = this._dataByLinkId.get(e4);
          if (i4 && i4.lines.every((e5) => e5.line !== t4)) {
            const e5 = this._bufferService.buffer.addMarker(t4);
            i4.lines.push(e5), e5.onDispose(() => this._removeMarkerFromLink(i4, e5));
          }
        }
        getLinkData(e4) {
          return this._dataByLinkId.get(e4)?.data;
        }
        _getEntryIdKey(e4) {
          return `${e4.id};;${e4.uri}`;
        }
        _removeMarkerFromLink(e4, t4) {
          const i4 = e4.lines.indexOf(t4);
          -1 !== i4 && (e4.lines.splice(i4, 1), 0 === e4.lines.length && (void 0 !== e4.data.id && this._entriesWithId.delete(e4.key), this._dataByLinkId.delete(e4.id)));
        }
      };
      t3.OscLinkService = o2 = s3([r2(0, n2.IBufferService)], o2);
    }, 8343: (e3, t3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.createDecorator = t3.getServiceDependencies = t3.serviceRegistry = void 0;
      const i3 = "di$target", s3 = "di$dependencies";
      t3.serviceRegistry = /* @__PURE__ */ new Map(), t3.getServiceDependencies = function(e4) {
        return e4[s3] || [];
      }, t3.createDecorator = function(e4) {
        if (t3.serviceRegistry.has(e4)) return t3.serviceRegistry.get(e4);
        const r2 = /* @__PURE__ */ __name(function(e5, t4, n2) {
          if (3 !== arguments.length) throw new Error("@IServiceName-decorator can only be used to decorate a parameter");
          !function(e6, t5, r3) {
            t5[i3] === t5 ? t5[s3].push({ id: e6, index: r3 }) : (t5[s3] = [{ id: e6, index: r3 }], t5[i3] = t5);
          }(r2, e5, n2);
        }, "r");
        return r2.toString = () => e4, t3.serviceRegistry.set(e4, r2), r2;
      };
    }, 2585: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.IDecorationService = t3.IUnicodeService = t3.IOscLinkService = t3.IOptionsService = t3.ILogService = t3.LogLevelEnum = t3.IInstantiationService = t3.ICharsetService = t3.ICoreService = t3.ICoreMouseService = t3.IBufferService = void 0;
      const s3 = i3(8343);
      var r2;
      t3.IBufferService = (0, s3.createDecorator)("BufferService"), t3.ICoreMouseService = (0, s3.createDecorator)("CoreMouseService"), t3.ICoreService = (0, s3.createDecorator)("CoreService"), t3.ICharsetService = (0, s3.createDecorator)("CharsetService"), t3.IInstantiationService = (0, s3.createDecorator)("InstantiationService"), function(e4) {
        e4[e4.TRACE = 0] = "TRACE", e4[e4.DEBUG = 1] = "DEBUG", e4[e4.INFO = 2] = "INFO", e4[e4.WARN = 3] = "WARN", e4[e4.ERROR = 4] = "ERROR", e4[e4.OFF = 5] = "OFF";
      }(r2 || (t3.LogLevelEnum = r2 = {})), t3.ILogService = (0, s3.createDecorator)("LogService"), t3.IOptionsService = (0, s3.createDecorator)("OptionsService"), t3.IOscLinkService = (0, s3.createDecorator)("OscLinkService"), t3.IUnicodeService = (0, s3.createDecorator)("UnicodeService"), t3.IDecorationService = (0, s3.createDecorator)("DecorationService");
    }, 1480: (e3, t3, i3) => {
      Object.defineProperty(t3, "__esModule", { value: true }), t3.UnicodeService = void 0;
      const s3 = i3(8460), r2 = i3(225);
      class n2 {
        static {
          __name(this, "n");
        }
        static extractShouldJoin(e4) {
          return 0 != (1 & e4);
        }
        static extractWidth(e4) {
          return e4 >> 1 & 3;
        }
        static extractCharKind(e4) {
          return e4 >> 3;
        }
        static createPropertyValue(e4, t4, i4 = false) {
          return (16777215 & e4) << 3 | (3 & t4) << 1 | (i4 ? 1 : 0);
        }
        constructor() {
          this._providers = /* @__PURE__ */ Object.create(null), this._active = "", this._onChange = new s3.EventEmitter(), this.onChange = this._onChange.event;
          const e4 = new r2.UnicodeV6();
          this.register(e4), this._active = e4.version, this._activeProvider = e4;
        }
        dispose() {
          this._onChange.dispose();
        }
        get versions() {
          return Object.keys(this._providers);
        }
        get activeVersion() {
          return this._active;
        }
        set activeVersion(e4) {
          if (!this._providers[e4]) throw new Error(`unknown Unicode version "${e4}"`);
          this._active = e4, this._activeProvider = this._providers[e4], this._onChange.fire(e4);
        }
        register(e4) {
          this._providers[e4.version] = e4;
        }
        wcwidth(e4) {
          return this._activeProvider.wcwidth(e4);
        }
        getStringCellWidth(e4) {
          let t4 = 0, i4 = 0;
          const s4 = e4.length;
          for (let r3 = 0; r3 < s4; ++r3) {
            let o2 = e4.charCodeAt(r3);
            if (55296 <= o2 && o2 <= 56319) {
              if (++r3 >= s4) return t4 + this.wcwidth(o2);
              const i5 = e4.charCodeAt(r3);
              56320 <= i5 && i5 <= 57343 ? o2 = 1024 * (o2 - 55296) + i5 - 56320 + 65536 : t4 += this.wcwidth(i5);
            }
            const a2 = this.charProperties(o2, i4);
            let h2 = n2.extractWidth(a2);
            n2.extractShouldJoin(a2) && (h2 -= n2.extractWidth(i4)), t4 += h2, i4 = a2;
          }
          return t4;
        }
        charProperties(e4, t4) {
          return this._activeProvider.charProperties(e4, t4);
        }
      }
      t3.UnicodeService = n2;
    } }, t2 = {};
    function i2(s3) {
      var r2 = t2[s3];
      if (void 0 !== r2) return r2.exports;
      var n2 = t2[s3] = { exports: {} };
      return e2[s3].call(n2.exports, n2, n2.exports, i2), n2.exports;
    }
    __name(i2, "i");
    var s2 = {};
    return (() => {
      var e3 = s2;
      Object.defineProperty(e3, "__esModule", { value: true }), e3.Terminal = void 0;
      const t3 = i2(9042), r2 = i2(3236), n2 = i2(844), o2 = i2(5741), a2 = i2(8285), h2 = i2(7975), c2 = i2(7090), l2 = ["cols", "rows"];
      class d2 extends n2.Disposable {
        static {
          __name(this, "d");
        }
        constructor(e4) {
          super(), this._core = this.register(new r2.Terminal(e4)), this._addonManager = this.register(new o2.AddonManager()), this._publicOptions = { ...this._core.options };
          const t4 = /* @__PURE__ */ __name((e5) => this._core.options[e5], "t"), i3 = /* @__PURE__ */ __name((e5, t5) => {
            this._checkReadonlyOptions(e5), this._core.options[e5] = t5;
          }, "i");
          for (const e5 in this._core.options) {
            const s3 = { get: t4.bind(this, e5), set: i3.bind(this, e5) };
            Object.defineProperty(this._publicOptions, e5, s3);
          }
        }
        _checkReadonlyOptions(e4) {
          if (l2.includes(e4)) throw new Error(`Option "${e4}" can only be set in the constructor`);
        }
        _checkProposedApi() {
          if (!this._core.optionsService.rawOptions.allowProposedApi) throw new Error("You must set the allowProposedApi option to true to use proposed API");
        }
        get onBell() {
          return this._core.onBell;
        }
        get onBinary() {
          return this._core.onBinary;
        }
        get onCursorMove() {
          return this._core.onCursorMove;
        }
        get onData() {
          return this._core.onData;
        }
        get onKey() {
          return this._core.onKey;
        }
        get onLineFeed() {
          return this._core.onLineFeed;
        }
        get onRender() {
          return this._core.onRender;
        }
        get onResize() {
          return this._core.onResize;
        }
        get onScroll() {
          return this._core.onScroll;
        }
        get onSelectionChange() {
          return this._core.onSelectionChange;
        }
        get onTitleChange() {
          return this._core.onTitleChange;
        }
        get onWriteParsed() {
          return this._core.onWriteParsed;
        }
        get element() {
          return this._core.element;
        }
        get parser() {
          return this._parser || (this._parser = new h2.ParserApi(this._core)), this._parser;
        }
        get unicode() {
          return this._checkProposedApi(), new c2.UnicodeApi(this._core);
        }
        get textarea() {
          return this._core.textarea;
        }
        get rows() {
          return this._core.rows;
        }
        get cols() {
          return this._core.cols;
        }
        get buffer() {
          return this._buffer || (this._buffer = this.register(new a2.BufferNamespaceApi(this._core))), this._buffer;
        }
        get markers() {
          return this._checkProposedApi(), this._core.markers;
        }
        get modes() {
          const e4 = this._core.coreService.decPrivateModes;
          let t4 = "none";
          switch (this._core.coreMouseService.activeProtocol) {
            case "X10":
              t4 = "x10";
              break;
            case "VT200":
              t4 = "vt200";
              break;
            case "DRAG":
              t4 = "drag";
              break;
            case "ANY":
              t4 = "any";
          }
          return { applicationCursorKeysMode: e4.applicationCursorKeys, applicationKeypadMode: e4.applicationKeypad, bracketedPasteMode: e4.bracketedPasteMode, insertMode: this._core.coreService.modes.insertMode, mouseTrackingMode: t4, originMode: e4.origin, reverseWraparoundMode: e4.reverseWraparound, sendFocusMode: e4.sendFocus, wraparoundMode: e4.wraparound };
        }
        get options() {
          return this._publicOptions;
        }
        set options(e4) {
          for (const t4 in e4) this._publicOptions[t4] = e4[t4];
        }
        blur() {
          this._core.blur();
        }
        focus() {
          this._core.focus();
        }
        input(e4, t4 = true) {
          this._core.input(e4, t4);
        }
        resize(e4, t4) {
          this._verifyIntegers(e4, t4), this._core.resize(e4, t4);
        }
        open(e4) {
          this._core.open(e4);
        }
        attachCustomKeyEventHandler(e4) {
          this._core.attachCustomKeyEventHandler(e4);
        }
        attachCustomWheelEventHandler(e4) {
          this._core.attachCustomWheelEventHandler(e4);
        }
        registerLinkProvider(e4) {
          return this._core.registerLinkProvider(e4);
        }
        registerCharacterJoiner(e4) {
          return this._checkProposedApi(), this._core.registerCharacterJoiner(e4);
        }
        deregisterCharacterJoiner(e4) {
          this._checkProposedApi(), this._core.deregisterCharacterJoiner(e4);
        }
        registerMarker(e4 = 0) {
          return this._verifyIntegers(e4), this._core.registerMarker(e4);
        }
        registerDecoration(e4) {
          return this._checkProposedApi(), this._verifyPositiveIntegers(e4.x ?? 0, e4.width ?? 0, e4.height ?? 0), this._core.registerDecoration(e4);
        }
        hasSelection() {
          return this._core.hasSelection();
        }
        select(e4, t4, i3) {
          this._verifyIntegers(e4, t4, i3), this._core.select(e4, t4, i3);
        }
        getSelection() {
          return this._core.getSelection();
        }
        getSelectionPosition() {
          return this._core.getSelectionPosition();
        }
        clearSelection() {
          this._core.clearSelection();
        }
        selectAll() {
          this._core.selectAll();
        }
        selectLines(e4, t4) {
          this._verifyIntegers(e4, t4), this._core.selectLines(e4, t4);
        }
        dispose() {
          super.dispose();
        }
        scrollLines(e4) {
          this._verifyIntegers(e4), this._core.scrollLines(e4);
        }
        scrollPages(e4) {
          this._verifyIntegers(e4), this._core.scrollPages(e4);
        }
        scrollToTop() {
          this._core.scrollToTop();
        }
        scrollToBottom() {
          this._core.scrollToBottom();
        }
        scrollToLine(e4) {
          this._verifyIntegers(e4), this._core.scrollToLine(e4);
        }
        clear() {
          this._core.clear();
        }
        write(e4, t4) {
          this._core.write(e4, t4);
        }
        writeln(e4, t4) {
          this._core.write(e4), this._core.write("\r\n", t4);
        }
        paste(e4) {
          this._core.paste(e4);
        }
        refresh(e4, t4) {
          this._verifyIntegers(e4, t4), this._core.refresh(e4, t4);
        }
        reset() {
          this._core.reset();
        }
        clearTextureAtlas() {
          this._core.clearTextureAtlas();
        }
        loadAddon(e4) {
          this._addonManager.loadAddon(this, e4);
        }
        static get strings() {
          return t3;
        }
        _verifyIntegers(...e4) {
          for (const t4 of e4) if (t4 === 1 / 0 || isNaN(t4) || t4 % 1 != 0) throw new Error("This API only accepts integers");
        }
        _verifyPositiveIntegers(...e4) {
          for (const t4 of e4) if (t4 && (t4 === 1 / 0 || isNaN(t4) || t4 % 1 != 0 || t4 < 0)) throw new Error("This API only accepts positive integers");
        }
      }
      e3.Terminal = d2;
    })(), s2;
  })());
})(xterm$2, xterm$2.exports);
var xtermExports = xterm$2.exports;
const xterm$1 = /* @__PURE__ */ getDefaultExportFromCjs(xtermExports);
function useTerminal(element) {
  const fitAddon = new addonFitExports.FitAddon();
  const terminal = markRaw(
    new xtermExports.Terminal({
      convertEol: true
    })
  );
  terminal.loadAddon(fitAddon);
  terminal.attachCustomKeyEventHandler((event) => {
    if (event.type === "keydown" && (event.ctrlKey || event.metaKey) && (event.key === "c" && terminal.hasSelection() || event.key === "v")) {
      return false;
    }
    return true;
  });
  onMounted(async () => {
    if (element.value) {
      terminal.open(element.value);
    }
  });
  onUnmounted(() => {
    terminal.dispose();
  });
  return {
    terminal,
    useAutoSize({
      root: root34,
      autoRows = true,
      autoCols = true,
      minCols = Number.NEGATIVE_INFINITY,
      minRows = Number.NEGATIVE_INFINITY,
      onResize: onResize2
    }) {
      const ensureValidRows = /* @__PURE__ */ __name((rows) => {
        if (rows == null || isNaN(rows)) {
          return (root34.value?.clientHeight ?? 80) / 20;
        }
        return rows;
      }, "ensureValidRows");
      const ensureValidCols = /* @__PURE__ */ __name((cols) => {
        if (cols == null || isNaN(cols)) {
          return (root34.value?.clientWidth ?? 80) / 8;
        }
        return cols;
      }, "ensureValidCols");
      const resize2 = /* @__PURE__ */ __name(() => {
        const dims = fitAddon.proposeDimensions();
        terminal.resize(
          Math.max(
            autoCols ? ensureValidCols(dims?.cols) : terminal.cols,
            minCols
          ),
          Math.max(
            autoRows ? ensureValidRows(dims?.rows) : terminal.rows,
            minRows
          )
        );
        onResize2?.();
      }, "resize");
      const resizeObserver = new ResizeObserver(lodashExports.debounce(resize2, 25));
      onMounted(async () => {
        if (root34.value) {
          resizeObserver.observe(root34.value);
          resize2();
        }
      });
      onUnmounted(() => {
        resizeObserver.disconnect();
      });
      return { resize: resize2 };
    }
  };
}
__name(useTerminal, "useTerminal");
const _hoisted_1$p = { class: "p-terminal rounded-none h-full w-full p-2" };
const _sfc_main$s = /* @__PURE__ */ defineComponent({
  __name: "BaseTerminal",
  emits: ["created", "unmounted"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const terminalEl = ref();
    const rootEl = ref();
    emit2("created", useTerminal(terminalEl), rootEl);
    onUnmounted(() => emit2("unmounted"));
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: "relative overflow-hidden h-full w-full bg-black",
        ref_key: "rootEl",
        ref: rootEl
      }, [
        createBaseVNode("div", _hoisted_1$p, [
          createBaseVNode("div", {
            class: "h-full terminal-host",
            ref_key: "terminalEl",
            ref: terminalEl
          }, null, 512)
        ])
      ], 512);
    };
  }
});
const BaseTerminal = /* @__PURE__ */ _export_sfc(_sfc_main$s, [["__scopeId", "data-v-0fe78d0a"]]);
const _sfc_main$r = /* @__PURE__ */ defineComponent({
  __name: "CommandTerminal",
  setup(__props) {
    const terminalCreated = /* @__PURE__ */ __name(({ terminal, useAutoSize }, root34) => {
      const terminalApi = electronAPI().Terminal;
      let offData;
      let offOutput;
      useAutoSize({
        root: root34,
        autoRows: true,
        autoCols: true,
        onResize: /* @__PURE__ */ __name(() => {
          if (!terminal.element?.offsetParent) return;
          terminalApi.resize(terminal.cols, terminal.rows);
        }, "onResize")
      });
      onMounted(async () => {
        offData = terminal.onData(async (message3) => {
          terminalApi.write(message3);
        });
        offOutput = terminalApi.onOutput((message3) => {
          terminal.write(message3);
        });
        const restore = await terminalApi.restore();
        setTimeout(() => {
          if (restore.buffer.length) {
            terminal.resize(restore.size.cols, restore.size.rows);
            terminal.write(restore.buffer.join(""));
          }
        }, 500);
      });
      onUnmounted(() => {
        offData?.dispose();
        offOutput?.();
      });
    }, "terminalCreated");
    return (_ctx, _cache) => {
      return openBlock(), createBlock(BaseTerminal, { onCreated: terminalCreated });
    };
  }
});
const CommandTerminal = /* @__PURE__ */ _export_sfc(_sfc_main$r, [["__scopeId", "data-v-778182dc"]]);
const useExecutionStore = /* @__PURE__ */ defineStore("execution", () => {
  const clientId = ref(null);
  const activePromptId = ref(null);
  const queuedPrompts = ref({});
  const executingNodeId = ref(null);
  const executingNode = computed(() => {
    if (!executingNodeId.value) return null;
    const workflow = activePrompt.value?.workflow;
    if (!workflow) return null;
    const canvasState = workflow.changeTracker?.activeState ?? null;
    if (!canvasState) return null;
    return canvasState.nodes.find(
      (n2) => String(n2.id) === executingNodeId.value
    ) ?? null;
  });
  const _executingNodeProgress = ref(null);
  const executingNodeProgress = computed(
    () => _executingNodeProgress.value ? Math.round(
      _executingNodeProgress.value.value / _executingNodeProgress.value.max * 100
    ) : null
  );
  const activePrompt = computed(
    () => queuedPrompts.value[activePromptId.value ?? ""]
  );
  const totalNodesToExecute = computed(() => {
    if (!activePrompt.value) return 0;
    return Object.values(activePrompt.value.nodes).length;
  });
  const isIdle = computed(() => !activePromptId.value);
  const nodesExecuted = computed(() => {
    if (!activePrompt.value) return 0;
    return Object.values(activePrompt.value.nodes).filter(Boolean).length;
  });
  const executionProgress = computed(() => {
    if (!activePrompt.value) return 0;
    const total = totalNodesToExecute.value;
    const done = nodesExecuted.value;
    return Math.round(done / total * 100);
  });
  function bindExecutionEvents() {
    api.addEventListener(
      "execution_start",
      handleExecutionStart
    );
    api.addEventListener(
      "execution_cached",
      handleExecutionCached
    );
    api.addEventListener("executed", handleExecuted);
    api.addEventListener("executing", handleExecuting);
    api.addEventListener("progress", handleProgress);
    api.addEventListener("status", handleStatus);
  }
  __name(bindExecutionEvents, "bindExecutionEvents");
  function unbindExecutionEvents() {
    api.removeEventListener(
      "execution_start",
      handleExecutionStart
    );
    api.removeEventListener(
      "execution_cached",
      handleExecutionCached
    );
    api.removeEventListener("executed", handleExecuted);
    api.removeEventListener("executing", handleExecuting);
    api.removeEventListener("progress", handleProgress);
    api.removeEventListener("status", handleStatus);
  }
  __name(unbindExecutionEvents, "unbindExecutionEvents");
  function handleExecutionStart(e2) {
    activePromptId.value = e2.detail.prompt_id;
    queuedPrompts.value[activePromptId.value] ??= { nodes: {} };
  }
  __name(handleExecutionStart, "handleExecutionStart");
  function handleExecutionCached(e2) {
    if (!activePrompt.value) return;
    for (const n2 of e2.detail.nodes) {
      activePrompt.value.nodes[n2] = true;
    }
  }
  __name(handleExecutionCached, "handleExecutionCached");
  function handleExecuted(e2) {
    if (!activePrompt.value) return;
    activePrompt.value.nodes[e2.detail.node] = true;
  }
  __name(handleExecuted, "handleExecuted");
  function handleExecuting(e2) {
    _executingNodeProgress.value = null;
    if (!activePrompt.value) return;
    if (executingNodeId.value && activePrompt.value) {
      activePrompt.value.nodes[executingNodeId.value] = true;
    }
    executingNodeId.value = e2.detail ? String(e2.detail) : null;
    if (!executingNodeId.value) {
      if (activePromptId.value) {
        delete queuedPrompts.value[activePromptId.value];
      }
      activePromptId.value = null;
    }
  }
  __name(handleExecuting, "handleExecuting");
  function handleProgress(e2) {
    _executingNodeProgress.value = e2.detail;
  }
  __name(handleProgress, "handleProgress");
  function handleStatus() {
    if (api.clientId) {
      clientId.value = api.clientId;
      api.removeEventListener("status", handleStatus);
    }
  }
  __name(handleStatus, "handleStatus");
  function storePrompt({
    nodes,
    id: id4,
    workflow
  }) {
    queuedPrompts.value[id4] ??= { nodes: {} };
    const queuedPrompt = queuedPrompts.value[id4];
    queuedPrompt.nodes = {
      ...nodes.reduce((p2, n2) => {
        p2[n2] = false;
        return p2;
      }, {}),
      ...queuedPrompt.nodes
    };
    queuedPrompt.workflow = workflow;
    console.debug(
      `queued task ${id4} with ${Object.values(queuedPrompt.nodes).length} nodes`
    );
  }
  __name(storePrompt, "storePrompt");
  return {
    isIdle,
    clientId,
    activePromptId,
    queuedPrompts,
    executingNodeId,
    activePrompt,
    totalNodesToExecute,
    nodesExecuted,
    executionProgress,
    executingNode,
    executingNodeProgress,
    bindExecutionEvents,
    unbindExecutionEvents,
    storePrompt,
    // Raw executing progress data for backward compatibility in ComfyApp.
    _executingNodeProgress
  };
});
const _hoisted_1$o = { class: "bg-black h-full w-full" };
const _hoisted_2$j = {
  key: 0,
  class: "p-4 text-center"
};
const _sfc_main$q = /* @__PURE__ */ defineComponent({
  __name: "LogsTerminal",
  setup(__props) {
    const errorMessage = ref("");
    const loading2 = ref(true);
    const terminalCreated = /* @__PURE__ */ __name(({ terminal, useAutoSize }, root34) => {
      useAutoSize({ root: root34, autoRows: true, autoCols: false, minCols: 80 });
      const update = /* @__PURE__ */ __name((entries, size) => {
        if (size) {
          terminal.resize(size.cols, terminal.rows);
        }
        terminal.write(entries.map((e2) => e2.m).join(""));
      }, "update");
      const logReceived = /* @__PURE__ */ __name((e2) => {
        update(e2.detail.entries, e2.detail.size);
      }, "logReceived");
      const loadLogEntries = /* @__PURE__ */ __name(async () => {
        const logs = await api.getRawLogs();
        update(logs.entries, logs.size);
      }, "loadLogEntries");
      const watchLogs = /* @__PURE__ */ __name(async () => {
        const { clientId } = storeToRefs(useExecutionStore());
        if (!clientId.value) {
          await until(clientId).not.toBeNull();
        }
        api.subscribeLogs(true);
        api.addEventListener("logs", logReceived);
      }, "watchLogs");
      onMounted(async () => {
        try {
          await loadLogEntries();
        } catch (err) {
          console.error("Error loading logs", err);
          errorMessage.value = "Unable to load logs, please ensure you have updated your ComfyUI backend.";
          return;
        }
        await watchLogs();
        loading2.value = false;
      });
      onUnmounted(() => {
        if (api.clientId) {
          api.subscribeLogs(false);
        }
        api.removeEventListener("logs", logReceived);
      });
    }, "terminalCreated");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$o, [
        errorMessage.value ? (openBlock(), createElementBlock("p", _hoisted_2$j, toDisplayString$1(errorMessage.value), 1)) : loading2.value ? (openBlock(), createBlock(unref(script$19), {
          key: 1,
          class: "relative inset-0 flex justify-center items-center h-full z-10"
        })) : createCommentVNode("", true),
        withDirectives(createVNode(BaseTerminal, { onCreated: terminalCreated }, null, 512), [
          [vShow, !loading2.value]
        ])
      ]);
    };
  }
});
const LogsTerminal = /* @__PURE__ */ _export_sfc(_sfc_main$q, [["__scopeId", "data-v-d9fa5fdf"]]);
const useLogsTerminalTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  return {
    id: "logs-terminal",
    title: t2("g.logs"),
    component: markRaw(LogsTerminal),
    type: "vue"
  };
}, "useLogsTerminalTab");
const useCommandTerminalTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  return {
    id: "command-terminal",
    title: t2("g.terminal"),
    component: markRaw(CommandTerminal),
    type: "vue"
  };
}, "useCommandTerminalTab");
const useBottomPanelStore = /* @__PURE__ */ defineStore("bottomPanel", () => {
  const bottomPanelVisible = ref(false);
  const toggleBottomPanel = /* @__PURE__ */ __name(() => {
    if (bottomPanelTabs.value.length === 0) {
      return;
    }
    bottomPanelVisible.value = !bottomPanelVisible.value;
  }, "toggleBottomPanel");
  const bottomPanelTabs = ref([]);
  const activeBottomPanelTabId = ref("");
  const activeBottomPanelTab = computed(() => {
    return bottomPanelTabs.value.find(
      (tab) => tab.id === activeBottomPanelTabId.value
    ) ?? null;
  });
  const setActiveTab = /* @__PURE__ */ __name((tabId) => {
    activeBottomPanelTabId.value = tabId;
  }, "setActiveTab");
  const toggleBottomPanelTab = /* @__PURE__ */ __name((tabId) => {
    if (activeBottomPanelTabId.value === tabId && bottomPanelVisible.value) {
      bottomPanelVisible.value = false;
    } else {
      activeBottomPanelTabId.value = tabId;
      bottomPanelVisible.value = true;
    }
  }, "toggleBottomPanelTab");
  const registerBottomPanelTab = /* @__PURE__ */ __name((tab) => {
    bottomPanelTabs.value = [...bottomPanelTabs.value, tab];
    if (bottomPanelTabs.value.length === 1) {
      activeBottomPanelTabId.value = tab.id;
    }
    useCommandStore().registerCommand({
      id: `Workspace.ToggleBottomPanelTab.${tab.id}`,
      icon: "pi pi-list",
      label: `Toggle ${tab.title} Bottom Panel`,
      function: /* @__PURE__ */ __name(() => toggleBottomPanelTab(tab.id), "function")
    });
  }, "registerBottomPanelTab");
  const registerCoreBottomPanelTabs = /* @__PURE__ */ __name(() => {
    registerBottomPanelTab(useLogsTerminalTab());
    if (isElectron()) {
      registerBottomPanelTab(useCommandTerminalTab());
    }
  }, "registerCoreBottomPanelTabs");
  const registerExtensionBottomPanelTabs = /* @__PURE__ */ __name((extension) => {
    if (extension.bottomPanelTabs) {
      extension.bottomPanelTabs.forEach(registerBottomPanelTab);
    }
  }, "registerExtensionBottomPanelTabs");
  return {
    bottomPanelVisible,
    toggleBottomPanel,
    bottomPanelTabs,
    activeBottomPanelTab,
    activeBottomPanelTabId,
    setActiveTab,
    toggleBottomPanelTab,
    registerBottomPanelTab,
    registerCoreBottomPanelTabs,
    registerExtensionBottomPanelTabs
  };
});
const useExtensionService = /* @__PURE__ */ __name(() => {
  const extensionStore = useExtensionStore();
  const settingStore = useSettingStore();
  const keybindingStore = useKeybindingStore();
  const { wrapWithErrorHandling } = useErrorHandling();
  const loadExtensions = /* @__PURE__ */ __name(async () => {
    extensionStore.loadDisabledExtensionNames(
      settingStore.get("Comfy.Extension.Disabled")
    );
    const extensions = await api.getExtensions();
    await __vitePreload(() => import("./index-dLHBN4II.js"), true ? __vite__mapDeps([36,13,25,1,2,26,27,3,12,37]) : void 0, import.meta.url);
    extensionStore.captureCoreExtensions();
    await Promise.all(
      extensions.filter((extension) => !extension.includes("extensions/core")).map(async (ext) => {
        try {
          await import(
            /* @vite-ignore */
            api.fileURL(ext)
          );
        } catch (error2) {
          console.error("Error loading extension", ext, error2);
        }
      })
    );
  }, "loadExtensions");
  const registerExtension = /* @__PURE__ */ __name((extension) => {
    extensionStore.registerExtension(extension);
    const addKeybinding = wrapWithErrorHandling(
      keybindingStore.addDefaultKeybinding
    );
    const addSetting = wrapWithErrorHandling(settingStore.addSetting);
    extension.keybindings?.forEach((keybinding) => {
      addKeybinding(new KeybindingImpl(keybinding));
    });
    useCommandStore().loadExtensionCommands(extension);
    useMenuItemStore().loadExtensionMenuCommands(extension);
    extension.settings?.forEach(addSetting);
    useBottomPanelStore().registerExtensionBottomPanelTabs(extension);
    if (extension.getCustomWidgets) {
      ;
      (async () => {
        if (extension.getCustomWidgets) {
          const widgets = await extension.getCustomWidgets(app$2);
          useWidgetStore().registerCustomWidgets(widgets);
        }
      })();
    }
  }, "registerExtension");
  const invokeExtensions = /* @__PURE__ */ __name((method, ...args) => {
    const results = [];
    for (const ext of extensionStore.enabledExtensions) {
      if (method in ext) {
        try {
          results.push(ext[method](...args, app$2));
        } catch (error2) {
          console.error(
            `Error calling extension '${ext.name}' method '${method}'`,
            { error: error2 },
            { extension: ext },
            { args }
          );
        }
      }
    }
    return results;
  }, "invokeExtensions");
  const invokeExtensionsAsync = /* @__PURE__ */ __name(async (method, ...args) => {
    return await Promise.all(
      extensionStore.enabledExtensions.map(async (ext) => {
        if (method in ext) {
          try {
            return await ext[method](...args, app$2);
          } catch (error2) {
            console.error(
              `Error calling extension '${ext.name}' method '${method}'`,
              { error: error2 },
              { extension: ext },
              { args }
            );
          }
        }
      })
    );
  }, "invokeExtensionsAsync");
  return {
    loadExtensions,
    registerExtension,
    invokeExtensions,
    invokeExtensionsAsync
  };
}, "useExtensionService");
let ComfyDialog$1 = class ComfyDialog2 extends EventTarget {
  static {
    __name(this, "ComfyDialog");
  }
  element;
  // @ts-expect-error fixme ts strict error
  textElement;
  #buttons;
  constructor(type = "div", buttons = null) {
    super();
    this.#buttons = buttons;
    this.element = $el(type + ".comfy-modal", { parent: document.body }, [
      $el("div.comfy-modal-content", [
        $el("p", { $: /* @__PURE__ */ __name((p2) => this.textElement = p2, "$") }),
        ...this.createButtons()
      ])
    ]);
  }
  createButtons() {
    return this.#buttons ?? [
      $el("button", {
        type: "button",
        textContent: "Close",
        onclick: /* @__PURE__ */ __name(() => this.close(), "onclick")
      })
    ];
  }
  close() {
    this.element.style.display = "none";
  }
  // @ts-expect-error fixme ts strict error
  show(html) {
    if (typeof html === "string") {
      this.textElement.innerHTML = html;
    } else {
      this.textElement.replaceChildren(
        ...html instanceof Array ? html : [html]
      );
    }
    this.element.style.display = "flex";
  }
};
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.dialog = window.comfyAPI.dialog || {};
window.comfyAPI.dialog.ComfyDialog = ComfyDialog$1;
class ComfySettingsDialog extends ComfyDialog$1 {
  static {
    __name(this, "ComfySettingsDialog");
  }
  app;
  constructor(app2) {
    super();
    this.app = app2;
  }
  dispatchChange(id4, value3, oldValue) {
    this.dispatchEvent(
      new CustomEvent(id4 + ".change", {
        detail: {
          value: value3,
          oldValue
        }
      })
    );
  }
  /**
   * @deprecated Use `settingStore.settingValues` instead.
   */
  get settingsValues() {
    return useSettingStore().settingValues;
  }
  /**
   * @deprecated Use `settingStore.settingsById` instead.
   */
  get settingsLookup() {
    return useSettingStore().settingsById;
  }
  /**
   * @deprecated Use `settingStore.settingsById` instead.
   */
  get settingsParamLookup() {
    return useSettingStore().settingsById;
  }
  /**
   * @deprecated Use `settingStore.get` instead.
   */
  getSettingValue(id4, defaultValue2) {
    if (defaultValue2 !== void 0) {
      console.warn(
        `Parameter defaultValue is deprecated. The default value in settings definition will be used instead.`
      );
    }
    return useSettingStore().get(id4);
  }
  /**
   * @deprecated Use `settingStore.getDefaultValue` instead.
   */
  getSettingDefaultValue(id4) {
    return useSettingStore().getDefaultValue(id4);
  }
  /**
   * @deprecated Use `settingStore.set` instead.
   */
  async setSettingValueAsync(id4, value3) {
    await useSettingStore().set(id4, value3);
  }
  /**
   * @deprecated Use `settingStore.set` instead.
   */
  setSettingValue(id4, value3) {
    useSettingStore().set(id4, value3).catch((err) => {
      useToastStore().addAlert(`Error saving setting '${id4}': ${err}`);
    });
  }
  /**
   * @deprecated Deprecated for external callers/extensions. Use
   * `ComfyExtension.settings` field instead.
   *
   * Example:
   * ```ts
   * app.registerExtension({
   *   name: 'My Extension',
   *   settings: [
   *     {
   *       id: 'My.Setting',
   *       name: 'My Setting',
   *       type: 'text',
   *       defaultValue: 'Hello, world!'
   *     }
   *   ]
   * })
   * ```
   */
  addSetting(params) {
    const settingStore = useSettingStore();
    settingStore.addSetting(params);
    return {
      get value() {
        return settingStore.get(params.id);
      },
      set value(v2) {
        settingStore.set(params.id, v2);
      }
    };
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.settings = window.comfyAPI.settings || {};
window.comfyAPI.settings.ComfySettingsDialog = ComfySettingsDialog;
function toggleSwitch(name2, items2, e2) {
  const onChange6 = e2?.onChange;
  let selectedIndex;
  let elements;
  function updateSelected(index2) {
    if (selectedIndex != null) {
      elements[selectedIndex].classList.remove("comfy-toggle-selected");
    }
    onChange6?.({
      item: items2[index2],
      // @ts-expect-error fixme ts strict error
      prev: selectedIndex == null ? void 0 : items2[selectedIndex]
    });
    selectedIndex = index2;
    elements[selectedIndex].classList.add("comfy-toggle-selected");
  }
  __name(updateSelected, "updateSelected");
  elements = items2.map((item3, i2) => {
    if (typeof item3 === "string") item3 = { text: item3 };
    if (!item3.value) item3.value = item3.text;
    const toggle5 = $el(
      "label",
      {
        textContent: item3.text,
        title: item3.tooltip ?? ""
      },
      $el("input", {
        name: name2,
        type: "radio",
        value: item3.value ?? item3.text,
        checked: item3.selected,
        onchange: /* @__PURE__ */ __name(() => {
          updateSelected(i2);
        }, "onchange")
      })
    );
    if (item3.selected) {
      updateSelected(i2);
    }
    return toggle5;
  });
  const container = $el("div.comfy-toggle-switch", elements);
  if (selectedIndex == null) {
    elements[0].children[0].checked = true;
    updateSelected(0);
  }
  return container;
}
__name(toggleSwitch, "toggleSwitch");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.toggleSwitch = window.comfyAPI.toggleSwitch || {};
window.comfyAPI.toggleSwitch.toggleSwitch = toggleSwitch;
const ComfyDialog = ComfyDialog$1;
function $el(tag, propsOrChildren, children) {
  const split2 = tag.split(".");
  const element = document.createElement(split2.shift());
  if (split2.length > 0) {
    element.classList.add(...split2);
  }
  if (propsOrChildren) {
    if (typeof propsOrChildren === "string") {
      propsOrChildren = { textContent: propsOrChildren };
    } else if (propsOrChildren instanceof Element) {
      propsOrChildren = [propsOrChildren];
    }
    if (Array.isArray(propsOrChildren)) {
      element.append(...propsOrChildren);
    } else {
      const {
        parent,
        $: cb,
        dataset,
        style: style2,
        ...rest
      } = propsOrChildren;
      if (rest.for) {
        element.setAttribute("for", rest.for);
      }
      if (style2) {
        Object.assign(element.style, style2);
      }
      if (dataset) {
        Object.assign(element.dataset, dataset);
      }
      Object.assign(element, rest);
      if (children) {
        element.append(...Array.isArray(children) ? children : [children]);
      }
      if (parent) {
        parent.append(element);
      }
      if (cb) {
        cb(element);
      }
    }
  }
  return element;
}
__name($el, "$el");
function dragElement(dragEl) {
  var posDiffX = 0, posDiffY = 0, posStartX = 0, posStartY = 0, newPosX = 0, newPosY = 0;
  if (dragEl.getElementsByClassName("drag-handle")[0]) {
    dragEl.getElementsByClassName("drag-handle")[0].onmousedown = dragMouseDown;
  } else {
    dragEl.onmousedown = dragMouseDown;
  }
  new ResizeObserver(() => {
    ensureInBounds();
  }).observe(dragEl);
  function ensureInBounds() {
    try {
      newPosX = Math.min(
        document.body.clientWidth - dragEl.clientWidth,
        Math.max(0, dragEl.offsetLeft)
      );
      newPosY = Math.min(
        document.body.clientHeight - dragEl.clientHeight,
        Math.max(0, dragEl.offsetTop)
      );
      positionElement();
    } catch (exception) {
    }
  }
  __name(ensureInBounds, "ensureInBounds");
  function positionElement() {
    if (dragEl.style.display === "none") return;
    const halfWidth = document.body.clientWidth / 2;
    const anchorRight = newPosX + dragEl.clientWidth / 2 > halfWidth;
    if (anchorRight) {
      dragEl.style.left = "unset";
      dragEl.style.right = document.body.clientWidth - newPosX - dragEl.clientWidth + "px";
    } else {
      dragEl.style.left = newPosX + "px";
      dragEl.style.right = "unset";
    }
    dragEl.style.top = newPosY + "px";
    dragEl.style.bottom = "unset";
    if (savePos) {
      localStorage.setItem(
        "Comfy.MenuPosition",
        JSON.stringify({
          x: dragEl.offsetLeft,
          y: dragEl.offsetTop
        })
      );
    }
  }
  __name(positionElement, "positionElement");
  function restorePos() {
    let posString = localStorage.getItem("Comfy.MenuPosition");
    if (posString) {
      const pos = JSON.parse(posString);
      newPosX = pos.x;
      newPosY = pos.y;
      positionElement();
      ensureInBounds();
    }
  }
  __name(restorePos, "restorePos");
  let savePos = void 0;
  restorePos();
  savePos = true;
  function dragMouseDown(e2) {
    e2 = e2 || window.event;
    e2.preventDefault();
    posStartX = e2.clientX;
    posStartY = e2.clientY;
    document.onmouseup = closeDragElement;
    document.onmousemove = elementDrag;
  }
  __name(dragMouseDown, "dragMouseDown");
  function elementDrag(e2) {
    e2 = e2 || window.event;
    e2.preventDefault();
    dragEl.classList.add("comfy-menu-manual-pos");
    posDiffX = e2.clientX - posStartX;
    posDiffY = e2.clientY - posStartY;
    posStartX = e2.clientX;
    posStartY = e2.clientY;
    newPosX = Math.min(
      document.body.clientWidth - dragEl.clientWidth,
      Math.max(0, dragEl.offsetLeft + posDiffX)
    );
    newPosY = Math.min(
      document.body.clientHeight - dragEl.clientHeight,
      Math.max(0, dragEl.offsetTop + posDiffY)
    );
    positionElement();
  }
  __name(elementDrag, "elementDrag");
  window.addEventListener("resize", () => {
    ensureInBounds();
  });
  function closeDragElement() {
    document.onmouseup = null;
    document.onmousemove = null;
  }
  __name(closeDragElement, "closeDragElement");
  return restorePos;
}
__name(dragElement, "dragElement");
class ComfyList {
  static {
    __name(this, "ComfyList");
  }
  #type;
  #text;
  #reverse;
  element;
  button;
  // @ts-expect-error fixme ts strict error
  constructor(text2, type, reverse2) {
    this.#text = text2;
    this.#type = type || text2.toLowerCase();
    this.#reverse = reverse2 || false;
    this.element = $el("div.comfy-list");
    this.element.style.display = "none";
  }
  get visible() {
    return this.element.style.display !== "none";
  }
  async load() {
    const items2 = await api.getItems(this.#type);
    this.element.replaceChildren(
      ...Object.keys(items2).flatMap((section) => [
        $el("h4", {
          textContent: section
        }),
        $el("div.comfy-list-items", [
          // @ts-expect-error fixme ts strict error
          ...(this.#reverse ? items2[section].reverse() : items2[section]).map(
            (item3) => {
              const removeAction = "remove" in item3 ? item3.remove : {
                name: "Delete",
                cb: /* @__PURE__ */ __name(() => api.deleteItem(this.#type, item3.prompt[1]), "cb")
              };
              return $el("div", { textContent: item3.prompt[0] + ": " }, [
                $el("button", {
                  textContent: "Load",
                  onclick: /* @__PURE__ */ __name(async () => {
                    await app$2.loadGraphData(
                      // @ts-expect-error fixme ts strict error
                      item3.prompt[3].extra_pnginfo.workflow,
                      true,
                      false
                    );
                    if ("outputs" in item3) {
                      app$2.nodeOutputs = {};
                      for (const [key, value3] of Object.entries(item3.outputs)) {
                        const realKey = item3["meta"]?.[key]?.display_node ?? key;
                        app$2.nodeOutputs[realKey] = value3;
                      }
                    }
                  }, "onclick")
                }),
                $el("button", {
                  textContent: removeAction.name,
                  onclick: /* @__PURE__ */ __name(async () => {
                    await removeAction.cb();
                    await this.update();
                  }, "onclick")
                })
              ]);
            }
          )
        ])
      ]),
      $el("div.comfy-list-actions", [
        $el("button", {
          textContent: "Clear " + this.#text,
          onclick: /* @__PURE__ */ __name(async () => {
            await api.clearItems(this.#type);
            await this.load();
          }, "onclick")
        }),
        $el("button", { textContent: "Refresh", onclick: /* @__PURE__ */ __name(() => this.load(), "onclick") })
      ])
    );
  }
  async update() {
    if (this.visible) {
      await this.load();
    }
  }
  async show() {
    this.element.style.display = "block";
    this.button.textContent = "Close";
    await this.load();
  }
  hide() {
    this.element.style.display = "none";
    this.button.textContent = "View " + this.#text;
  }
  toggle() {
    if (this.visible) {
      this.hide();
      return false;
    } else {
      this.show();
      return true;
    }
  }
}
class ComfyUI {
  static {
    __name(this, "ComfyUI");
  }
  app;
  dialog;
  settings;
  batchCount;
  lastQueueSize;
  queue;
  history;
  // @ts-expect-error fixme ts strict error
  autoQueueMode;
  // @ts-expect-error fixme ts strict error
  graphHasChanged;
  // @ts-expect-error fixme ts strict error
  autoQueueEnabled;
  // @ts-expect-error fixme ts strict error
  menuContainer;
  // @ts-expect-error fixme ts strict error
  queueSize;
  // @ts-expect-error fixme ts strict error
  restoreMenuPosition;
  // @ts-expect-error fixme ts strict error
  loadFile;
  // @ts-expect-error fixme ts strict error
  constructor(app2) {
    this.app = app2;
    this.dialog = new ComfyDialog();
    this.settings = new ComfySettingsDialog(app2);
    this.batchCount = 1;
    this.lastQueueSize = 0;
    this.queue = new ComfyList("Queue");
    this.history = new ComfyList("History", "history", true);
    api.addEventListener("status", () => {
      this.queue.update();
      this.history.update();
    });
    this.setup(document.body);
  }
  setup(containerElement) {
    const fileInput2 = $el("input", {
      id: "comfy-file-input",
      type: "file",
      accept: ".json,image/png,.latent,.safetensors,image/webp,audio/flac",
      style: { display: "none" },
      parent: document.body,
      onchange: /* @__PURE__ */ __name(async () => {
        await app$2.handleFile(fileInput2.files[0]);
        fileInput2.value = "";
      }, "onchange")
    });
    this.loadFile = () => fileInput2.click();
    const autoQueueModeEl = toggleSwitch(
      "autoQueueMode",
      [
        {
          text: "instant",
          tooltip: "A new prompt will be queued as soon as the queue reaches 0"
        },
        {
          text: "change",
          tooltip: "A new prompt will be queued when the queue is at 0 and the graph is/has changed"
        }
      ],
      {
        // @ts-expect-error fixme ts strict error
        onChange: /* @__PURE__ */ __name((value3) => {
          this.autoQueueMode = value3.item.value;
        }, "onChange")
      }
    );
    autoQueueModeEl.style.display = "none";
    api.addEventListener("graphChanged", () => {
      if (this.autoQueueMode === "change" && this.autoQueueEnabled === true) {
        if (this.lastQueueSize === 0) {
          this.graphHasChanged = false;
          app$2.queuePrompt(0, this.batchCount);
        } else {
          this.graphHasChanged = true;
        }
      }
    });
    this.menuContainer = $el(
      "div.comfy-menu.no-drag",
      { parent: containerElement },
      [
        $el(
          "div.drag-handle.comfy-menu-header",
          {
            style: {
              overflow: "hidden",
              position: "relative",
              width: "100%",
              cursor: "default"
            }
          },
          [
            $el("span.drag-handle"),
            $el("span.comfy-menu-queue-size", {
              $: /* @__PURE__ */ __name((q2) => this.queueSize = q2, "$")
            }),
            $el("div.comfy-menu-actions", [
              $el("button.comfy-settings-btn", {
                textContent: "⚙️",
                onclick: /* @__PURE__ */ __name(() => {
                  useDialogService().showSettingsDialog();
                }, "onclick")
              }),
              $el("button.comfy-close-menu-btn", {
                textContent: "×",
                onclick: /* @__PURE__ */ __name(() => {
                  useWorkspaceStore().focusMode = true;
                }, "onclick")
              })
            ])
          ]
        ),
        $el("button.comfy-queue-btn", {
          id: "queue-button",
          textContent: "Queue Prompt",
          onclick: /* @__PURE__ */ __name(() => app$2.queuePrompt(0, this.batchCount), "onclick")
        }),
        $el("div", {}, [
          $el("label", { innerHTML: "Extra options" }, [
            $el("input", {
              type: "checkbox",
              // @ts-expect-error fixme ts strict error
              onchange: /* @__PURE__ */ __name((i2) => {
                document.getElementById("extraOptions").style.display = i2.srcElement.checked ? "block" : "none";
                this.batchCount = i2.srcElement.checked ? Number.parseInt(
                  document.getElementById(
                    "batchCountInputRange"
                  ).value
                ) : 1;
                document.getElementById(
                  "autoQueueCheckbox"
                ).checked = false;
                this.autoQueueEnabled = false;
              }, "onchange")
            })
          ])
        ]),
        $el(
          "div",
          { id: "extraOptions", style: { width: "100%", display: "none" } },
          [
            $el("div", [
              $el("label", { innerHTML: "Batch count" }),
              $el("input", {
                id: "batchCountInputNumber",
                type: "number",
                value: this.batchCount,
                min: "1",
                style: { width: "35%", marginLeft: "0.4em" },
                // @ts-expect-error fixme ts strict error
                oninput: /* @__PURE__ */ __name((i2) => {
                  this.batchCount = i2.target.value;
                  document.getElementById(
                    "batchCountInputRange"
                  ).value = this.batchCount.toString();
                }, "oninput")
              }),
              $el("input", {
                id: "batchCountInputRange",
                type: "range",
                min: "1",
                max: "100",
                value: this.batchCount,
                // @ts-expect-error fixme ts strict error
                oninput: /* @__PURE__ */ __name((i2) => {
                  this.batchCount = i2.srcElement.value;
                  document.getElementById(
                    "batchCountInputNumber"
                  ).value = i2.srcElement.value;
                }, "oninput")
              })
            ]),
            $el("div", [
              $el("label", {
                for: "autoQueueCheckbox",
                innerHTML: "Auto Queue"
              }),
              $el("input", {
                id: "autoQueueCheckbox",
                type: "checkbox",
                checked: false,
                title: "Automatically queue prompt when the queue size hits 0",
                // @ts-expect-error fixme ts strict error
                onchange: /* @__PURE__ */ __name((e2) => {
                  this.autoQueueEnabled = e2.target.checked;
                  autoQueueModeEl.style.display = this.autoQueueEnabled ? "" : "none";
                }, "onchange")
              }),
              autoQueueModeEl
            ])
          ]
        ),
        $el("div.comfy-menu-btns", [
          $el("button", {
            id: "queue-front-button",
            textContent: "Queue Front",
            onclick: /* @__PURE__ */ __name(() => app$2.queuePrompt(-1, this.batchCount), "onclick")
          }),
          $el("button", {
            $: /* @__PURE__ */ __name((b2) => this.queue.button = b2, "$"),
            id: "comfy-view-queue-button",
            textContent: "View Queue",
            onclick: /* @__PURE__ */ __name(() => {
              this.history.hide();
              this.queue.toggle();
            }, "onclick")
          }),
          $el("button", {
            $: /* @__PURE__ */ __name((b2) => this.history.button = b2, "$"),
            id: "comfy-view-history-button",
            textContent: "View History",
            onclick: /* @__PURE__ */ __name(() => {
              this.queue.hide();
              this.history.toggle();
            }, "onclick")
          })
        ]),
        this.queue.element,
        this.history.element,
        $el("button", {
          id: "comfy-save-button",
          textContent: "Save",
          onclick: /* @__PURE__ */ __name(() => {
            useCommandStore().execute("Comfy.ExportWorkflow");
          }, "onclick")
        }),
        $el("button", {
          id: "comfy-dev-save-api-button",
          textContent: "Save (API Format)",
          style: { width: "100%", display: "none" },
          onclick: /* @__PURE__ */ __name(() => {
            useCommandStore().execute("Comfy.ExportWorkflowAPI");
          }, "onclick")
        }),
        $el("button", {
          id: "comfy-load-button",
          textContent: "Load",
          onclick: /* @__PURE__ */ __name(() => fileInput2.click(), "onclick")
        }),
        $el("button", {
          id: "comfy-refresh-button",
          textContent: "Refresh",
          onclick: /* @__PURE__ */ __name(() => app$2.refreshComboInNodes(), "onclick")
        }),
        $el("button", {
          id: "comfy-clipspace-button",
          textContent: "Clipspace",
          onclick: /* @__PURE__ */ __name(() => app$2.openClipspace(), "onclick")
        }),
        $el("button", {
          id: "comfy-clear-button",
          textContent: "Clear",
          onclick: /* @__PURE__ */ __name(() => {
            if (!useSettingStore().get("Comfy.ConfirmClear") || confirm("Clear workflow?")) {
              app$2.clean();
              app$2.graph.clear();
              useLitegraphService().resetView();
              api.dispatchCustomEvent("graphCleared");
            }
          }, "onclick")
        }),
        $el("button", {
          id: "comfy-load-default-button",
          textContent: "Load Default",
          onclick: /* @__PURE__ */ __name(async () => {
            if (!useSettingStore().get("Comfy.ConfirmClear") || confirm("Load default workflow?")) {
              useLitegraphService().resetView();
              await app$2.loadGraphData();
            }
          }, "onclick")
        }),
        $el("button", {
          id: "comfy-reset-view-button",
          textContent: "Reset View",
          onclick: /* @__PURE__ */ __name(async () => {
            useLitegraphService().resetView();
          }, "onclick")
        })
      ]
    );
    this.menuContainer.style.display = "none";
    this.restoreMenuPosition = dragElement(this.menuContainer);
    this.setStatus({ exec_info: { queue_remaining: "X" } });
  }
  setStatus(status) {
    this.queueSize.textContent = "Queue size: " + (status ? status.exec_info.queue_remaining : "ERR");
    if (status) {
      if (this.lastQueueSize != 0 && status.exec_info.queue_remaining == 0 && this.autoQueueEnabled && (this.autoQueueMode === "instant" || this.graphHasChanged) && !app$2.lastExecutionError) {
        app$2.queuePrompt(0, this.batchCount);
        status.exec_info.queue_remaining += this.batchCount;
        this.graphHasChanged = false;
      }
      this.lastQueueSize = status.exec_info.queue_remaining;
    }
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.ui = window.comfyAPI.ui || {};
window.comfyAPI.ui.ComfyDialog = ComfyDialog;
window.comfyAPI.ui.$el = $el;
window.comfyAPI.ui.ComfyUI = ComfyUI;
function calculateImageGrid(imgs, dw, dh) {
  let best = 0;
  let w2 = imgs[0].naturalWidth;
  let h2 = imgs[0].naturalHeight;
  const numImages = imgs.length;
  let cellWidth, cellHeight, cols, rows, shiftX;
  for (let c2 = 1; c2 <= numImages; c2++) {
    const r2 = Math.ceil(numImages / c2);
    const cW = dw / c2;
    const cH = dh / r2;
    const scaleX = cW / w2;
    const scaleY = cH / h2;
    const scale = Math.min(scaleX, scaleY, 1);
    const imageW = w2 * scale;
    const imageH = h2 * scale;
    const area = imageW * imageH * numImages;
    if (area > best) {
      best = area;
      cellWidth = imageW;
      cellHeight = imageH;
      cols = c2;
      rows = r2;
      shiftX = c2 * ((cW - imageW) / 2);
    }
  }
  return { cellWidth, cellHeight, cols, rows, shiftX };
}
__name(calculateImageGrid, "calculateImageGrid");
function createImageHost(node3) {
  const el = $el("div.comfy-img-preview");
  let currentImgs;
  let first2 = true;
  function updateSize() {
    let w2 = null;
    let h2 = null;
    if (currentImgs) {
      let elH = el.clientHeight;
      if (first2) {
        first2 = false;
        if (elH < 190) {
          elH = 190;
        }
        el.style.setProperty("--comfy-widget-min-height", elH.toString());
      } else {
        el.style.setProperty("--comfy-widget-min-height", null);
      }
      const nw = node3.size[0];
      ({ cellWidth: w2, cellHeight: h2 } = calculateImageGrid(
        currentImgs,
        nw - 20,
        elH
      ));
      w2 += "px";
      h2 += "px";
      el.style.setProperty("--comfy-img-preview-width", w2);
      el.style.setProperty("--comfy-img-preview-height", h2);
    }
  }
  __name(updateSize, "updateSize");
  return {
    el,
    // @ts-expect-error fixme ts strict error
    updateImages(imgs) {
      if (imgs !== currentImgs) {
        if (currentImgs == null) {
          requestAnimationFrame(() => {
            updateSize();
          });
        }
        el.replaceChildren(...imgs);
        currentImgs = imgs;
        node3.onResize(node3.size);
        node3.graph.setDirtyCanvas(true, true);
      }
    },
    getHeight() {
      updateSize();
    },
    onDraw() {
      el.style.pointerEvents = "all";
      const over = document.elementFromPoint(
        app$2.canvas.mouse[0],
        app$2.canvas.mouse[1]
      );
      el.style.pointerEvents = "none";
      if (!over) return;
      const idx = currentImgs.indexOf(over);
      node3.overIndex = idx;
    }
  };
}
__name(createImageHost, "createImageHost");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.imagePreview = window.comfyAPI.imagePreview || {};
window.comfyAPI.imagePreview.calculateImageGrid = calculateImageGrid;
window.comfyAPI.imagePreview.createImageHost = createImageHost;
function useNodeAnimatedImage() {
  function showAnimatedPreview(node3) {
    if (!node3.imgs?.length) return;
    if (!node3.widgets) return;
    const widgetIdx = node3.widgets.findIndex(
      (w2) => w2.name === ANIM_PREVIEW_WIDGET
    );
    if (widgetIdx > -1) {
      const widget = node3.widgets[widgetIdx];
      widget.options.host.updateImages(node3.imgs);
    } else {
      const host = createImageHost(node3);
      const widget = node3.addDOMWidget(ANIM_PREVIEW_WIDGET, "img", host.el, {
        host,
        // @ts-expect-error `getHeight` of image host returns void instead of number.
        getHeight: host.getHeight,
        onDraw: host.onDraw,
        hideOnZoom: false
      });
      widget.serializeValue = () => void 0;
      widget.options.host.updateImages(node3.imgs);
    }
  }
  __name(showAnimatedPreview, "showAnimatedPreview");
  function removeAnimatedPreview(node3) {
    if (!node3.widgets) return;
    const widgetIdx = node3.widgets.findIndex(
      (w2) => w2.name === ANIM_PREVIEW_WIDGET
    );
    if (widgetIdx > -1) {
      node3.widgets[widgetIdx].onRemove?.();
      node3.widgets.splice(widgetIdx, 1);
    }
  }
  __name(removeAnimatedPreview, "removeAnimatedPreview");
  return {
    showAnimatedPreview,
    removeAnimatedPreview
  };
}
__name(useNodeAnimatedImage, "useNodeAnimatedImage");
const is_all_same_aspect_ratio = /* @__PURE__ */ __name((imgs) => {
  if (!imgs.length || imgs.length === 1) return true;
  const ratio = imgs[0].naturalWidth / imgs[0].naturalHeight;
  for (let i2 = 1; i2 < imgs.length; i2++) {
    const this_ratio = imgs[i2].naturalWidth / imgs[i2].naturalHeight;
    if (ratio != this_ratio) return false;
  }
  return true;
}, "is_all_same_aspect_ratio");
const renderPreview = /* @__PURE__ */ __name((ctx, node3, shiftY) => {
  const canvas2 = app.canvas;
  const mouse = canvas2.graph_mouse;
  if (!canvas2.pointer_is_down && node3.pointerDown) {
    if (mouse[0] === node3.pointerDown.pos[0] && mouse[1] === node3.pointerDown.pos[1]) {
      node3.imageIndex = node3.pointerDown.index;
    }
    node3.pointerDown = null;
  }
  const imgs = node3.imgs ?? [];
  let { imageIndex } = node3;
  const numImages = imgs.length;
  if (numImages === 1 && !imageIndex) {
    node3.imageIndex = imageIndex = 0;
  }
  const IMAGE_TEXT_SIZE_TEXT_HEIGHT = 15;
  const dw = node3.size[0];
  const dh = node3.size[1] - shiftY - IMAGE_TEXT_SIZE_TEXT_HEIGHT;
  if (imageIndex == null) {
    let cellWidth;
    let cellHeight;
    let shiftX;
    let cell_padding;
    let cols;
    const compact_mode = is_all_same_aspect_ratio(imgs);
    if (!compact_mode) {
      cell_padding = 2;
      const largestDimension = imgs.reduce(
        (acc, current) => Math.max(acc, current.naturalWidth, current.naturalHeight),
        0
      );
      const fakeImgs = [];
      fakeImgs.length = imgs.length;
      fakeImgs[0] = {
        naturalWidth: largestDimension,
        naturalHeight: largestDimension
      };
      ({ cellWidth, cellHeight, cols, shiftX } = calculateImageGrid(
        fakeImgs,
        dw,
        dh
      ));
    } else {
      cell_padding = 0;
      ({ cellWidth, cellHeight, cols, shiftX } = calculateImageGrid(
        imgs,
        dw,
        dh
      ));
    }
    let anyHovered = false;
    node3.imageRects = [];
    for (let i2 = 0; i2 < numImages; i2++) {
      const img2 = imgs[i2];
      const row = Math.floor(i2 / cols);
      const col = i2 % cols;
      const x22 = col * cellWidth + shiftX;
      const y22 = row * cellHeight + shiftY;
      if (!anyHovered) {
        anyHovered = LiteGraph.isInsideRectangle(
          mouse[0],
          mouse[1],
          x22 + node3.pos[0],
          y22 + node3.pos[1],
          cellWidth,
          cellHeight
        );
        if (anyHovered) {
          node3.overIndex = i2;
          let value3 = 110;
          if (canvas2.pointer_is_down) {
            if (!node3.pointerDown || node3.pointerDown.index !== i2) {
              node3.pointerDown = { index: i2, pos: [...mouse] };
            }
            value3 = 125;
          }
          ctx.filter = `contrast(${value3}%) brightness(${value3}%)`;
          canvas2.canvas.style.cursor = "pointer";
        }
      }
      node3.imageRects.push([x22, y22, cellWidth, cellHeight]);
      const wratio = cellWidth / img2.width;
      const hratio = cellHeight / img2.height;
      const ratio = Math.min(wratio, hratio);
      const imgHeight = ratio * img2.height;
      const imgY = row * cellHeight + shiftY + (cellHeight - imgHeight) / 2;
      const imgWidth = ratio * img2.width;
      const imgX = col * cellWidth + shiftX + (cellWidth - imgWidth) / 2;
      ctx.drawImage(
        img2,
        imgX + cell_padding,
        imgY + cell_padding,
        imgWidth - cell_padding * 2,
        imgHeight - cell_padding * 2
      );
      if (!compact_mode) {
        ctx.strokeStyle = "#8F8F8F";
        ctx.lineWidth = 1;
        ctx.strokeRect(
          x22 + cell_padding,
          y22 + cell_padding,
          cellWidth - cell_padding * 2,
          cellHeight - cell_padding * 2
        );
      }
      ctx.filter = "none";
    }
    if (!anyHovered) {
      node3.pointerDown = null;
      node3.overIndex = null;
    }
    return;
  }
  const img = imgs[imageIndex];
  let w2 = img.naturalWidth;
  let h2 = img.naturalHeight;
  const scaleX = dw / w2;
  const scaleY = dh / h2;
  const scale = Math.min(scaleX, scaleY, 1);
  w2 *= scale;
  h2 *= scale;
  const x2 = (dw - w2) / 2;
  const y2 = (dh - h2) / 2 + shiftY;
  ctx.drawImage(img, x2, y2, w2, h2);
  ctx.fillStyle = LiteGraph.NODE_TEXT_COLOR;
  ctx.textAlign = "center";
  ctx.font = "10px sans-serif";
  const sizeText = `${Math.round(img.naturalWidth)} × ${Math.round(img.naturalHeight)}`;
  const textY = y2 + h2 + 10;
  ctx.fillText(sizeText, x2 + w2 / 2, textY);
  const drawButton = /* @__PURE__ */ __name((x22, y22, sz, text2) => {
    const hovered = LiteGraph.isInsideRectangle(
      mouse[0],
      mouse[1],
      x22 + node3.pos[0],
      y22 + node3.pos[1],
      sz,
      sz
    );
    let fill2 = "#333";
    let textFill = "#fff";
    let isClicking = false;
    if (hovered) {
      canvas2.canvas.style.cursor = "pointer";
      if (canvas2.pointer_is_down) {
        fill2 = "#1e90ff";
        isClicking = true;
      } else {
        fill2 = "#eee";
        textFill = "#000";
      }
    }
    ctx.fillStyle = fill2;
    ctx.beginPath();
    ctx.roundRect(x22, y22, sz, sz, [4]);
    ctx.fill();
    ctx.fillStyle = textFill;
    ctx.font = "12px Arial";
    ctx.textAlign = "center";
    ctx.fillText(text2, x22 + 15, y22 + 20);
    return isClicking;
  }, "drawButton");
  if (!(numImages > 1)) return;
  const imageNum = (node3.imageIndex ?? 0) + 1;
  if (drawButton(dw - 40, dh + shiftY - 40, 30, `${imageNum}/${numImages}`)) {
    const i2 = imageNum >= numImages ? 0 : imageNum;
    if (!node3.pointerDown || node3.pointerDown.index !== i2) {
      node3.pointerDown = { index: i2, pos: [...mouse] };
    }
  }
  if (drawButton(dw - 40, shiftY + 10, 30, `x`)) {
    if (!node3.pointerDown || node3.pointerDown.index !== null) {
      node3.pointerDown = { index: null, pos: [...mouse] };
    }
  }
}, "renderPreview");
class ImagePreviewWidget {
  static {
    __name(this, "ImagePreviewWidget");
  }
  type;
  name;
  options;
  // Dummy value to satisfy type requirements
  value;
  y = 0;
  constructor(name2, options5) {
    this.type = "custom";
    this.name = name2;
    this.options = options5;
    this.value = "";
  }
  draw(ctx, node3, _width, y2, _height) {
    renderPreview(ctx, node3, y2);
  }
  computeLayoutSize() {
    return {
      minHeight: 220,
      minWidth: 1
    };
  }
}
const useImagePreviewWidget = /* @__PURE__ */ __name(() => {
  const widgetConstructor = /* @__PURE__ */ __name((node3, inputSpec) => {
    return node3.addCustomWidget(
      new ImagePreviewWidget(inputSpec.name, {
        serialize: false
      })
    );
  }, "widgetConstructor");
  return widgetConstructor;
}, "useImagePreviewWidget");
const CANVAS_IMAGE_PREVIEW_WIDGET = "$$canvas-image-preview";
function useNodeCanvasImagePreview() {
  const imagePreviewWidget = useImagePreviewWidget();
  function showCanvasImagePreview(node3) {
    if (!node3.imgs?.length) return;
    if (!node3.widgets?.find((w2) => w2.name === CANVAS_IMAGE_PREVIEW_WIDGET)) {
      imagePreviewWidget(node3, {
        type: "IMAGE_PREVIEW",
        name: CANVAS_IMAGE_PREVIEW_WIDGET
      });
    }
  }
  __name(showCanvasImagePreview, "showCanvasImagePreview");
  function removeCanvasImagePreview(node3) {
    if (!node3.widgets) return;
    const widgetIdx = node3.widgets.findIndex(
      (w2) => w2.name === CANVAS_IMAGE_PREVIEW_WIDGET
    );
    if (widgetIdx > -1) {
      node3.widgets[widgetIdx].onRemove?.();
      node3.widgets.splice(widgetIdx, 1);
    }
  }
  __name(removeCanvasImagePreview, "removeCanvasImagePreview");
  return {
    showCanvasImagePreview,
    removeCanvasImagePreview
  };
}
__name(useNodeCanvasImagePreview, "useNodeCanvasImagePreview");
const useTitleEditorStore = /* @__PURE__ */ defineStore("titleEditor", () => {
  const titleEditorTarget = shallowRef(null);
  return {
    titleEditorTarget
  };
});
const useCanvasStore = /* @__PURE__ */ defineStore("canvas", () => {
  const canvas2 = shallowRef(null);
  const selectedItems = ref([]);
  const updateSelectedItems = /* @__PURE__ */ __name(() => {
    const items2 = Array.from(canvas2.value?.selectedItems ?? []);
    selectedItems.value = items2.map((item3) => markRaw(item3));
  }, "updateSelectedItems");
  return {
    canvas: canvas2,
    selectedItems,
    updateSelectedItems
  };
});
const useLitegraphService = /* @__PURE__ */ __name(() => {
  const extensionService = useExtensionService();
  const toastStore = useToastStore();
  const widgetStore = useWidgetStore();
  const canvasStore = useCanvasStore();
  async function registerNodeDef(nodeId, nodeDefV1) {
    const node3 = class ComfyNode extends LGraphNode {
      static {
        __name(this, "ComfyNode");
      }
      static comfyClass;
      static title;
      static nodeData;
      static category;
      constructor(title) {
        super(title);
        const nodeMinSize = { width: 1, height: 1 };
        for (const [inputName, inputSpec] of Object.entries(nodeDef.inputs)) {
          const inputType = inputSpec.type;
          const nameKey = `nodeDefs.${normalizeI18nKey(nodeDef.name)}.inputs.${normalizeI18nKey(inputName)}.name`;
          const widgetConstructor = widgetStore.widgets[inputType];
          if (widgetConstructor) {
            const {
              widget,
              minWidth = 1,
              minHeight = 1
            } = widgetConstructor(
              this,
              inputName,
              transformInputSpecV2ToV1(inputSpec),
              app$2
            ) ?? {};
            if (widget) {
              const fallback = widget.label ?? inputName;
              widget.label = st(nameKey, fallback);
              widget.options ??= {};
              if (inputSpec.isOptional) {
                widget.options.inputIsOptional = true;
              }
              if (inputSpec.forceInput) {
                widget.options.forceInput = true;
              }
              if (inputSpec.defaultInput) {
                widget.options.defaultInput = true;
              }
              if (inputSpec.advanced) {
                widget.advanced = true;
              }
              if (inputSpec.hidden) {
                widget.hidden = true;
              }
            }
            nodeMinSize.width = Math.max(nodeMinSize.width, minWidth);
            nodeMinSize.height = Math.max(nodeMinSize.height, minHeight);
          } else {
            const shapeOptions = inputSpec.isOptional ? { shape: RenderShape.HollowCircle } : {};
            this.addInput(inputName, inputType, {
              ...shapeOptions,
              localized_name: st(nameKey, inputName)
            });
          }
        }
        for (const output of nodeDef.outputs) {
          const outputName = output.name;
          const outputType = output.type;
          const outputIsList = output.is_list;
          const shapeOptions = outputIsList ? { shape: LiteGraph.GRID_SHAPE } : {};
          const nameKey = `nodeDefs.${normalizeI18nKey(nodeDef.name)}.outputs.${output.index}.name`;
          const typeKey = `dataTypes.${normalizeI18nKey(outputType)}`;
          const outputOptions = {
            ...shapeOptions,
            // If the output name is different from the output type, use the output name.
            // e.g.
            // - type ("INT"); name ("Positive") => translate name
            // - type ("FLOAT"); name ("FLOAT") => translate type
            localized_name: outputType !== outputName ? st(nameKey, outputName) : st(typeKey, outputName)
          };
          this.addOutput(outputName, outputType, outputOptions);
        }
        const s2 = this.computeSize();
        s2[0] = Math.max(nodeMinSize.width, s2[0] * 1.5);
        s2[1] = Math.max(nodeMinSize.height, s2[1]);
        this.setSize(s2);
        this.serialize_widgets = true;
        extensionService.invokeExtensionsAsync("nodeCreated", this);
      }
      configure(data30) {
        const merge2 = /* @__PURE__ */ __name((current, incoming) => {
          const result = { ...incoming };
          if (current.widget === void 0 && incoming.widget !== void 0) {
            this.inputs.push(current);
            return incoming;
          }
          for (const key of ["name", "type", "shape", "localized_name"]) {
            if (current[key] !== void 0) {
              result[key] = current[key];
            }
          }
          return result;
        }, "merge");
        for (const field2 of ["inputs", "outputs"]) {
          const slots = data30[field2] ?? [];
          data30[field2] = slots.map(
            (slot, i2) => (
              // @ts-expect-error fixme ts strict error
              merge2(this[field2][i2] ?? {}, slot)
            )
          );
        }
        super.configure(data30);
      }
    };
    addNodeContextMenuHandler(node3);
    addDrawBackgroundHandler(node3);
    addNodeKeyHandler(node3);
    node3.prototype.comfyClass = nodeDefV1.name;
    node3.comfyClass = nodeDefV1.name;
    await extensionService.invokeExtensionsAsync(
      "beforeRegisterNodeDef",
      node3,
      nodeDefV1
      // Receives V1 NodeDef, and potentially make modifications to it
    );
    const nodeDef = new ComfyNodeDefImpl(nodeDefV1);
    node3.nodeData = nodeDef;
    LiteGraph.registerNodeType(nodeId, node3);
    node3.category = nodeDef.category;
    node3.title = nodeDef.display_name || nodeDef.name;
  }
  __name(registerNodeDef, "registerNodeDef");
  function addNodeContextMenuHandler(node3) {
    function getCopyImageOption(img) {
      if (typeof window.ClipboardItem === "undefined") return [];
      return [
        {
          content: "Copy Image",
          // @ts-expect-error: async callback is not accepted by litegraph
          callback: /* @__PURE__ */ __name(async () => {
            const url = new URL(img.src);
            url.searchParams.delete("preview");
            const writeImage = /* @__PURE__ */ __name(async (blob) => {
              await navigator.clipboard.write([
                new ClipboardItem({
                  [blob.type]: blob
                })
              ]);
            }, "writeImage");
            try {
              const data30 = await fetch(url);
              const blob = await data30.blob();
              try {
                await writeImage(blob);
              } catch (error2) {
                if (blob.type !== "image/png") {
                  const canvas2 = $el("canvas", {
                    width: img.naturalWidth,
                    height: img.naturalHeight
                  });
                  const ctx = canvas2.getContext("2d");
                  let image2;
                  if (typeof window.createImageBitmap === "undefined") {
                    image2 = new Image();
                    const p2 = new Promise((resolve2, reject3) => {
                      image2.onload = resolve2;
                      image2.onerror = reject3;
                    }).finally(() => {
                      URL.revokeObjectURL(image2.src);
                    });
                    image2.src = URL.createObjectURL(blob);
                    await p2;
                  } else {
                    image2 = await createImageBitmap(blob);
                  }
                  try {
                    ctx.drawImage(image2, 0, 0);
                    canvas2.toBlob(writeImage, "image/png");
                  } finally {
                    if (typeof image2.close === "function") {
                      image2.close();
                    }
                  }
                  return;
                }
                throw error2;
              }
            } catch (error2) {
              toastStore.addAlert(
                // @ts-expect-error fixme ts strict error
                "Error copying image: " + (error2.message ?? error2)
              );
            }
          }, "callback")
        }
      ];
    }
    __name(getCopyImageOption, "getCopyImageOption");
    node3.prototype.getExtraMenuOptions = function(_2, options5) {
      if (this.imgs) {
        let img;
        if (this.imageIndex != null) {
          img = this.imgs[this.imageIndex];
        } else if (this.overIndex != null) {
          img = this.imgs[this.overIndex];
        }
        if (img) {
          options5.unshift(
            {
              content: "Open Image",
              callback: /* @__PURE__ */ __name(() => {
                const url = new URL(img.src);
                url.searchParams.delete("preview");
                window.open(url, "_blank");
              }, "callback")
            },
            ...getCopyImageOption(img),
            {
              content: "Save Image",
              callback: /* @__PURE__ */ __name(() => {
                const a2 = document.createElement("a");
                const url = new URL(img.src);
                url.searchParams.delete("preview");
                a2.href = url.toString();
                a2.setAttribute(
                  "download",
                  // @ts-expect-error fixme ts strict error
                  new URLSearchParams(url.search).get("filename")
                );
                document.body.append(a2);
                a2.click();
                requestAnimationFrame(() => a2.remove());
              }, "callback")
            }
          );
        }
      }
      options5.push({
        content: "Bypass",
        callback: /* @__PURE__ */ __name(() => {
          const mode2 = this.mode === LGraphEventMode.BYPASS ? LGraphEventMode.ALWAYS : LGraphEventMode.BYPASS;
          for (const item3 of app$2.canvas.selectedItems) {
            if (item3 instanceof LGraphNode) item3.mode = mode2;
          }
          this.graph.change();
        }, "callback")
      });
      if (!ComfyApp.clipspace_return_node) {
        options5.push({
          content: "Copy (Clipspace)",
          callback: /* @__PURE__ */ __name(() => {
            ComfyApp.copyToClipspace(this);
          }, "callback")
        });
        if (ComfyApp.clipspace != null) {
          options5.push({
            content: "Paste (Clipspace)",
            callback: /* @__PURE__ */ __name(() => {
              ComfyApp.pasteFromClipspace(this);
            }, "callback")
          });
        }
        if (isImageNode(this)) {
          options5.push({
            content: "Open in MaskEditor",
            callback: /* @__PURE__ */ __name(() => {
              ComfyApp.copyToClipspace(this);
              ComfyApp.clipspace_return_node = this;
              ComfyApp.open_maskeditor();
            }, "callback")
          });
        }
      }
      return [];
    };
  }
  __name(addNodeContextMenuHandler, "addNodeContextMenuHandler");
  function addDrawBackgroundHandler(node3) {
    node3.prototype.setSizeForImage = function() {
      console.warn(
        "node.setSizeForImage is deprecated. Now it has no effect. Please remove the call to it."
      );
    };
    function unsafeDrawBackground() {
      if (this.flags.collapsed) return;
      const nodeOutputStore = useNodeOutputStore();
      const { showAnimatedPreview, removeAnimatedPreview } = useNodeAnimatedImage();
      const { showCanvasImagePreview, removeCanvasImagePreview } = useNodeCanvasImagePreview();
      const output = nodeOutputStore.getNodeOutputs(this);
      const preview2 = nodeOutputStore.getNodePreviews(this);
      const isNewOutput = output && this.images !== output.images;
      const isNewPreview = preview2 && this.preview !== preview2;
      if (isNewPreview) this.preview = preview2;
      if (isNewOutput) this.images = output.images;
      if (isNewOutput || isNewPreview) {
        this.animatedImages = output?.animated?.find(Boolean);
        const isAnimatedWebp = this.animatedImages && // @ts-expect-error fixme ts strict error
        output.images.some((img) => img.filename?.includes("webp"));
        const isVideo = this.animatedImages && !isAnimatedWebp || isVideoNode(this);
        if (isVideo) {
          useNodeVideo(this).showPreview();
        } else {
          useNodeImage(this).showPreview();
        }
      }
      if (!this.imgs?.length) return;
      if (this.animatedImages) {
        removeCanvasImagePreview(this);
        showAnimatedPreview(this);
      } else {
        removeAnimatedPreview(this);
        showCanvasImagePreview(this);
      }
    }
    __name(unsafeDrawBackground, "unsafeDrawBackground");
    node3.prototype.onDrawBackground = function() {
      try {
        unsafeDrawBackground.call(this);
      } catch (error2) {
        console.error("Error drawing node background", error2);
      }
    };
  }
  __name(addDrawBackgroundHandler, "addDrawBackgroundHandler");
  function addNodeKeyHandler(node3) {
    const origNodeOnKeyDown = node3.prototype.onKeyDown;
    node3.prototype.onKeyDown = function(e2) {
      if (origNodeOnKeyDown && origNodeOnKeyDown.apply(this, e2) === false) {
        return false;
      }
      if (this.flags.collapsed || !this.imgs || this.imageIndex === null) {
        return;
      }
      let handled = false;
      if (e2.key === "ArrowLeft" || e2.key === "ArrowRight") {
        if (e2.key === "ArrowLeft") {
          this.imageIndex -= 1;
        } else if (e2.key === "ArrowRight") {
          this.imageIndex += 1;
        }
        this.imageIndex %= this.imgs.length;
        if (this.imageIndex < 0) {
          this.imageIndex = this.imgs.length + this.imageIndex;
        }
        handled = true;
      } else if (e2.key === "Escape") {
        this.imageIndex = null;
        handled = true;
      }
      if (handled === true) {
        e2.preventDefault();
        e2.stopImmediatePropagation();
        return false;
      }
    };
  }
  __name(addNodeKeyHandler, "addNodeKeyHandler");
  function addNodeOnGraph(nodeDef, options5 = {}) {
    options5.pos ??= getCanvasCenter();
    const node3 = LiteGraph.createNode(
      nodeDef.name,
      nodeDef.display_name,
      options5
    );
    app$2.graph.add(node3);
    return node3;
  }
  __name(addNodeOnGraph, "addNodeOnGraph");
  function getCanvasCenter() {
    const dpi = Math.max(window.devicePixelRatio ?? 1, 1);
    const [x2, y2, w2, h2] = app$2.canvas.ds.visible_area;
    return [x2 + w2 / dpi / 2, y2 + h2 / dpi / 2];
  }
  __name(getCanvasCenter, "getCanvasCenter");
  function goToNode(nodeId) {
    const graphNode = app$2.graph.getNodeById(nodeId);
    if (!graphNode) return;
    app$2.canvas.animateToBounds(graphNode.boundingRect);
  }
  __name(goToNode, "goToNode");
  function resetView() {
    const canvas2 = canvasStore.canvas;
    if (!canvas2) return;
    canvas2.ds.scale = 1;
    canvas2.ds.offset = [0, 0];
    canvas2.setDirty(true, true);
  }
  __name(resetView, "resetView");
  return {
    registerNodeDef,
    addNodeOnGraph,
    getCanvasCenter,
    goToNode,
    resetView
  };
}, "useLitegraphService");
const defaultGraph = {
  last_node_id: 9,
  last_link_id: 9,
  nodes: [
    {
      id: 7,
      type: "CLIPTextEncode",
      pos: [413, 389],
      size: [425.27801513671875, 180.6060791015625],
      flags: {},
      order: 3,
      mode: 0,
      inputs: [{ name: "clip", type: "CLIP", link: 5 }],
      outputs: [
        {
          name: "CONDITIONING",
          type: "CONDITIONING",
          links: [6],
          slot_index: 0
        }
      ],
      properties: {},
      widgets_values: ["text, watermark"]
    },
    {
      id: 6,
      type: "CLIPTextEncode",
      pos: [415, 186],
      size: [422.84503173828125, 164.31304931640625],
      flags: {},
      order: 2,
      mode: 0,
      inputs: [{ name: "clip", type: "CLIP", link: 3 }],
      outputs: [
        {
          name: "CONDITIONING",
          type: "CONDITIONING",
          links: [4],
          slot_index: 0
        }
      ],
      properties: {},
      widgets_values: [
        "beautiful scenery nature glass bottle landscape, , purple galaxy bottle,"
      ]
    },
    {
      id: 5,
      type: "EmptyLatentImage",
      pos: [473, 609],
      size: [315, 106],
      flags: {},
      order: 1,
      mode: 0,
      outputs: [{ name: "LATENT", type: "LATENT", links: [2], slot_index: 0 }],
      properties: {},
      widgets_values: [512, 512, 1]
    },
    {
      id: 3,
      type: "KSampler",
      pos: [863, 186],
      size: [315, 262],
      flags: {},
      order: 4,
      mode: 0,
      inputs: [
        { name: "model", type: "MODEL", link: 1 },
        { name: "positive", type: "CONDITIONING", link: 4 },
        { name: "negative", type: "CONDITIONING", link: 6 },
        { name: "latent_image", type: "LATENT", link: 2 }
      ],
      outputs: [{ name: "LATENT", type: "LATENT", links: [7], slot_index: 0 }],
      properties: {},
      widgets_values: [156680208700286, true, 20, 8, "euler", "normal", 1]
    },
    {
      id: 8,
      type: "VAEDecode",
      pos: [1209, 188],
      size: [210, 46],
      flags: {},
      order: 5,
      mode: 0,
      inputs: [
        { name: "samples", type: "LATENT", link: 7 },
        { name: "vae", type: "VAE", link: 8 }
      ],
      outputs: [{ name: "IMAGE", type: "IMAGE", links: [9], slot_index: 0 }],
      properties: {}
    },
    {
      id: 9,
      type: "SaveImage",
      pos: [1451, 189],
      size: [210, 26],
      flags: {},
      order: 6,
      mode: 0,
      inputs: [{ name: "images", type: "IMAGE", link: 9 }],
      properties: {}
    },
    {
      id: 4,
      type: "CheckpointLoaderSimple",
      pos: [26, 474],
      size: [315, 98],
      flags: {},
      order: 0,
      mode: 0,
      outputs: [
        { name: "MODEL", type: "MODEL", links: [1], slot_index: 0 },
        { name: "CLIP", type: "CLIP", links: [3, 5], slot_index: 1 },
        { name: "VAE", type: "VAE", links: [8], slot_index: 2 }
      ],
      properties: {},
      widgets_values: ["v1-5-pruned-emaonly-fp16.safetensors"]
    }
  ],
  links: [
    [1, 4, 0, 3, 0, "MODEL"],
    [2, 5, 0, 3, 3, "LATENT"],
    [3, 4, 1, 6, 0, "CLIP"],
    [4, 6, 0, 3, 1, "CONDITIONING"],
    [5, 4, 1, 7, 0, "CLIP"],
    [6, 7, 0, 3, 2, "CONDITIONING"],
    [7, 3, 0, 8, 0, "LATENT"],
    [8, 4, 2, 8, 1, "VAE"],
    [9, 8, 0, 9, 0, "IMAGE"]
  ],
  groups: [],
  config: {},
  extra: {},
  version: 0.4
};
const defaultGraphJSON = JSON.stringify(defaultGraph);
const blankGraph = {
  last_node_id: 0,
  last_link_id: 0,
  nodes: [],
  links: [],
  groups: [],
  config: {},
  extra: {},
  version: 0.4
};
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.defaultGraph = window.comfyAPI.defaultGraph || {};
window.comfyAPI.defaultGraph.defaultGraph = defaultGraph;
window.comfyAPI.defaultGraph.defaultGraphJSON = defaultGraphJSON;
window.comfyAPI.defaultGraph.blankGraph = blankGraph;
function applyTextReplacements$1(allNodes, value3) {
  return value3.replace(/%([^%]+)%/g, function(match2, text2) {
    const split2 = text2.split(".");
    if (split2.length !== 2) {
      if (split2[0].startsWith("date:")) {
        return formatDate(split2[0].substring(5), /* @__PURE__ */ new Date());
      }
      if (text2 !== "width" && text2 !== "height") {
        console.warn("Invalid replacement pattern", text2);
      }
      return match2;
    }
    let nodes = allNodes.filter(
      (n2) => n2.properties?.["Node name for S&R"] === split2[0]
    );
    if (!nodes.length) {
      nodes = allNodes.filter((n2) => n2.title === split2[0]);
    }
    if (!nodes.length) {
      console.warn("Unable to find node", split2[0]);
      return match2;
    }
    if (nodes.length > 1) {
      console.warn("Multiple nodes matched", split2[0], "using first match");
    }
    const node3 = nodes[0];
    const widget = node3.widgets?.find((w2) => w2.name === split2[1]);
    if (!widget) {
      console.warn("Unable to find widget", split2[1], "on node", split2[0], node3);
      return match2;
    }
    return ((widget.value ?? "") + "").replaceAll(
      // eslint-disable-next-line no-control-regex
      /[/?<>\\:*|"\x00-\x1F\x7F]/g,
      "_"
    );
  });
}
__name(applyTextReplacements$1, "applyTextReplacements$1");
function clone$3(obj) {
  try {
    if (typeof structuredClone !== "undefined") {
      return structuredClone(obj);
    }
  } catch (error2) {
  }
  return JSON.parse(JSON.stringify(obj));
}
__name(clone$3, "clone$3");
function applyTextReplacements(app2, value3) {
  return applyTextReplacements$1(app2.graph.nodes, value3);
}
__name(applyTextReplacements, "applyTextReplacements");
async function addStylesheet(urlOrFile, relativeTo) {
  return new Promise((res, rej) => {
    let url;
    if (urlOrFile.endsWith(".js")) {
      url = urlOrFile.substr(0, urlOrFile.length - 2) + "css";
    } else {
      url = new URL(
        urlOrFile,
        relativeTo ?? `${window.location.protocol}//${window.location.host}`
      ).toString();
    }
    $el("link", {
      parent: document.head,
      rel: "stylesheet",
      type: "text/css",
      href: url,
      onload: res,
      onerror: rej
    });
  });
}
__name(addStylesheet, "addStylesheet");
function downloadBlob(filename, blob) {
  const url = URL.createObjectURL(blob);
  const a2 = $el("a", {
    href: url,
    download: filename,
    style: { display: "none" },
    parent: document.body
  });
  a2.click();
  setTimeout(function() {
    a2.remove();
    window.URL.revokeObjectURL(url);
  }, 0);
}
__name(downloadBlob, "downloadBlob");
function uploadFile(accept3) {
  return new Promise((resolve2, reject3) => {
    const input = document.createElement("input");
    input.type = "file";
    input.accept = accept3;
    input.onchange = (e2) => {
      const file = e2.target.files?.[0];
      if (!file) return reject3(new Error("No file selected"));
      resolve2(file);
    };
    input.click();
  });
}
__name(uploadFile, "uploadFile");
function prop(target2, name2, defaultValue2, onChanged) {
  let currentValue;
  Object.defineProperty(target2, name2, {
    get() {
      return currentValue;
    },
    set(newValue2) {
      const prevValue = currentValue;
      currentValue = newValue2;
      onChanged?.(currentValue, prevValue, target2, name2);
    }
  });
  return defaultValue2;
}
__name(prop, "prop");
function getStorageValue(id4) {
  const clientId = api.clientId ?? api.initialClientId;
  return (clientId && sessionStorage.getItem(`${id4}:${clientId}`)) ?? localStorage.getItem(id4);
}
__name(getStorageValue, "getStorageValue");
function setStorageValue(id4, value3) {
  const clientId = api.clientId ?? api.initialClientId;
  if (clientId) {
    sessionStorage.setItem(`${id4}:${clientId}`, value3);
  }
  localStorage.setItem(id4, value3);
}
__name(setStorageValue, "setStorageValue");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.utils = window.comfyAPI.utils || {};
window.comfyAPI.utils.clone = clone$3;
window.comfyAPI.utils.applyTextReplacements = applyTextReplacements;
window.comfyAPI.utils.addStylesheet = addStylesheet;
window.comfyAPI.utils.downloadBlob = downloadBlob;
window.comfyAPI.utils.uploadFile = uploadFile;
window.comfyAPI.utils.prop = prop;
window.comfyAPI.utils.getStorageValue = getStorageValue;
window.comfyAPI.utils.setStorageValue = setStorageValue;
class Processor {
  static {
    __name(this, "Processor");
  }
  constructor(options5) {
    this.selfOptions = options5 || {};
    this.pipes = {};
  }
  options(options5) {
    if (options5) {
      this.selfOptions = options5;
    }
    return this.selfOptions;
  }
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  pipe(name2, pipeArg) {
    let pipe = pipeArg;
    if (typeof name2 === "string") {
      if (typeof pipe === "undefined") {
        return this.pipes[name2];
      } else {
        this.pipes[name2] = pipe;
      }
    }
    if (name2 && name2.name) {
      pipe = name2;
      if (pipe.processor === this) {
        return pipe;
      }
      this.pipes[pipe.name] = pipe;
    }
    pipe.processor = this;
    return pipe;
  }
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  process(input, pipe) {
    let context = input;
    context.options = this.options();
    let nextPipe = pipe || input.pipe || "default";
    let lastPipe;
    while (nextPipe) {
      if (typeof context.nextAfterChildren !== "undefined") {
        context.next = context.nextAfterChildren;
        context.nextAfterChildren = null;
      }
      if (typeof nextPipe === "string") {
        nextPipe = this.pipe(nextPipe);
      }
      nextPipe.process(context);
      lastPipe = nextPipe;
      nextPipe = null;
      if (context) {
        if (context.next) {
          context = context.next;
          nextPipe = context.pipe || lastPipe;
        }
      }
    }
    return context.hasResult ? context.result : void 0;
  }
}
class Pipe {
  static {
    __name(this, "Pipe");
  }
  constructor(name2) {
    this.name = name2;
    this.filters = [];
  }
  process(input) {
    if (!this.processor) {
      throw new Error("add this pipe to a processor before using it");
    }
    const debug = this.debug;
    const length = this.filters.length;
    const context = input;
    for (let index2 = 0; index2 < length; index2++) {
      const filter4 = this.filters[index2];
      if (debug) {
        this.log(`filter: ${filter4.filterName}`);
      }
      filter4(context);
      if (typeof context === "object" && context.exiting) {
        context.exiting = false;
        break;
      }
    }
    if (!context.next && this.resultCheck) {
      this.resultCheck(context);
    }
  }
  log(msg) {
    console.log(`[jsondiffpatch] ${this.name} pipe, ${msg}`);
  }
  append(...args) {
    this.filters.push(...args);
    return this;
  }
  prepend(...args) {
    this.filters.unshift(...args);
    return this;
  }
  indexOf(filterName) {
    if (!filterName) {
      throw new Error("a filter name is required");
    }
    for (let index2 = 0; index2 < this.filters.length; index2++) {
      const filter4 = this.filters[index2];
      if (filter4.filterName === filterName) {
        return index2;
      }
    }
    throw new Error(`filter not found: ${filterName}`);
  }
  list() {
    return this.filters.map((f2) => f2.filterName);
  }
  after(filterName, ...params) {
    const index2 = this.indexOf(filterName);
    this.filters.splice(index2 + 1, 0, ...params);
    return this;
  }
  before(filterName, ...params) {
    const index2 = this.indexOf(filterName);
    this.filters.splice(index2, 0, ...params);
    return this;
  }
  replace(filterName, ...params) {
    const index2 = this.indexOf(filterName);
    this.filters.splice(index2, 1, ...params);
    return this;
  }
  remove(filterName) {
    const index2 = this.indexOf(filterName);
    this.filters.splice(index2, 1);
    return this;
  }
  clear() {
    this.filters.length = 0;
    return this;
  }
  shouldHaveResult(should) {
    if (should === false) {
      this.resultCheck = null;
      return;
    }
    if (this.resultCheck) {
      return;
    }
    this.resultCheck = (context) => {
      if (!context.hasResult) {
        console.log(context);
        const error2 = new Error(`${this.name} failed`);
        error2.noResult = true;
        throw error2;
      }
    };
    return this;
  }
}
class Context {
  static {
    __name(this, "Context");
  }
  setResult(result) {
    this.result = result;
    this.hasResult = true;
    return this;
  }
  exit() {
    this.exiting = true;
    return this;
  }
  push(child, name2) {
    child.parent = this;
    if (typeof name2 !== "undefined") {
      child.childName = name2;
    }
    child.root = this.root || this;
    child.options = child.options || this.options;
    if (!this.children) {
      this.children = [child];
      this.nextAfterChildren = this.next || null;
      this.next = child;
    } else {
      this.children[this.children.length - 1].next = child;
      this.children.push(child);
    }
    child.next = this;
    return this;
  }
}
function cloneRegExp(re) {
  const regexMatch = /^\/(.*)\/([gimyu]*)$/.exec(re.toString());
  return new RegExp(regexMatch[1], regexMatch[2]);
}
__name(cloneRegExp, "cloneRegExp");
function clone$2(arg) {
  if (typeof arg !== "object") {
    return arg;
  }
  if (arg === null) {
    return null;
  }
  if (Array.isArray(arg)) {
    return arg.map(clone$2);
  }
  if (arg instanceof Date) {
    return new Date(arg.getTime());
  }
  if (arg instanceof RegExp) {
    return cloneRegExp(arg);
  }
  const cloned = {};
  for (const name2 in arg) {
    if (Object.prototype.hasOwnProperty.call(arg, name2)) {
      cloned[name2] = clone$2(arg[name2]);
    }
  }
  return cloned;
}
__name(clone$2, "clone$2");
class DiffContext extends Context {
  static {
    __name(this, "DiffContext");
  }
  constructor(left, right) {
    super();
    this.left = left;
    this.right = right;
    this.pipe = "diff";
  }
  setResult(result) {
    if (this.options.cloneDiffValues && typeof result === "object") {
      const clone2 = typeof this.options.cloneDiffValues === "function" ? this.options.cloneDiffValues : clone$2;
      if (typeof result[0] === "object") {
        result[0] = clone2(result[0]);
      }
      if (typeof result[1] === "object") {
        result[1] = clone2(result[1]);
      }
    }
    return super.setResult(result);
  }
}
class PatchContext extends Context {
  static {
    __name(this, "PatchContext");
  }
  constructor(left, delta2) {
    super();
    this.left = left;
    this.delta = delta2;
    this.pipe = "patch";
  }
}
class ReverseContext extends Context {
  static {
    __name(this, "ReverseContext");
  }
  constructor(delta2) {
    super();
    this.delta = delta2;
    this.pipe = "reverse";
  }
}
const diffFilter$3 = /* @__PURE__ */ __name(function trivialMatchesDiffFilter(context) {
  if (context.left === context.right) {
    context.setResult(void 0).exit();
    return;
  }
  if (typeof context.left === "undefined") {
    if (typeof context.right === "function") {
      throw new Error("functions are not supported");
    }
    context.setResult([context.right]).exit();
    return;
  }
  if (typeof context.right === "undefined") {
    context.setResult([context.left, 0, 0]).exit();
    return;
  }
  if (typeof context.left === "function" || typeof context.right === "function") {
    throw new Error("functions are not supported");
  }
  context.leftType = context.left === null ? "null" : typeof context.left;
  context.rightType = context.right === null ? "null" : typeof context.right;
  if (context.leftType !== context.rightType) {
    context.setResult([context.left, context.right]).exit();
    return;
  }
  if (context.leftType === "boolean" || context.leftType === "number") {
    context.setResult([context.left, context.right]).exit();
    return;
  }
  if (context.leftType === "object") {
    context.leftIsArray = Array.isArray(context.left);
  }
  if (context.rightType === "object") {
    context.rightIsArray = Array.isArray(context.right);
  }
  if (context.leftIsArray !== context.rightIsArray) {
    context.setResult([context.left, context.right]).exit();
    return;
  }
  if (context.left instanceof RegExp) {
    if (context.right instanceof RegExp) {
      context.setResult([context.left.toString(), context.right.toString()]).exit();
    } else {
      context.setResult([context.left, context.right]).exit();
    }
  }
}, "trivialMatchesDiffFilter");
diffFilter$3.filterName = "trivial";
const patchFilter$3 = /* @__PURE__ */ __name(function trivialMatchesPatchFilter(context) {
  if (typeof context.delta === "undefined") {
    context.setResult(context.left).exit();
    return;
  }
  context.nested = !Array.isArray(context.delta);
  if (context.nested) {
    return;
  }
  const nonNestedDelta = context.delta;
  if (nonNestedDelta.length === 1) {
    context.setResult(nonNestedDelta[0]).exit();
    return;
  }
  if (nonNestedDelta.length === 2) {
    if (context.left instanceof RegExp) {
      const regexArgs = /^\/(.*)\/([gimyu]+)$/.exec(nonNestedDelta[1]);
      if (regexArgs) {
        context.setResult(new RegExp(regexArgs[1], regexArgs[2])).exit();
        return;
      }
    }
    context.setResult(nonNestedDelta[1]).exit();
    return;
  }
  if (nonNestedDelta.length === 3 && nonNestedDelta[2] === 0) {
    context.setResult(void 0).exit();
  }
}, "trivialMatchesPatchFilter");
patchFilter$3.filterName = "trivial";
const reverseFilter$3 = /* @__PURE__ */ __name(function trivialReferseFilter(context) {
  if (typeof context.delta === "undefined") {
    context.setResult(context.delta).exit();
    return;
  }
  context.nested = !Array.isArray(context.delta);
  if (context.nested) {
    return;
  }
  const nonNestedDelta = context.delta;
  if (nonNestedDelta.length === 1) {
    context.setResult([nonNestedDelta[0], 0, 0]).exit();
    return;
  }
  if (nonNestedDelta.length === 2) {
    context.setResult([nonNestedDelta[1], nonNestedDelta[0]]).exit();
    return;
  }
  if (nonNestedDelta.length === 3 && nonNestedDelta[2] === 0) {
    context.setResult([nonNestedDelta[0]]).exit();
  }
}, "trivialReferseFilter");
reverseFilter$3.filterName = "trivial";
const collectChildrenDiffFilter = /* @__PURE__ */ __name((context) => {
  if (!context || !context.children) {
    return;
  }
  const length = context.children.length;
  let child;
  let result = context.result;
  for (let index2 = 0; index2 < length; index2++) {
    child = context.children[index2];
    if (typeof child.result === "undefined") {
      continue;
    }
    result = result || {};
    result[child.childName] = child.result;
  }
  if (result && context.leftIsArray) {
    result._t = "a";
  }
  context.setResult(result).exit();
}, "collectChildrenDiffFilter");
collectChildrenDiffFilter.filterName = "collectChildren";
const objectsDiffFilter = /* @__PURE__ */ __name((context) => {
  if (context.leftIsArray || context.leftType !== "object") {
    return;
  }
  const left = context.left;
  const right = context.right;
  let name2;
  let child;
  const propertyFilter = context.options.propertyFilter;
  for (name2 in left) {
    if (!Object.prototype.hasOwnProperty.call(left, name2)) {
      continue;
    }
    if (propertyFilter && !propertyFilter(name2, context)) {
      continue;
    }
    child = new DiffContext(left[name2], right[name2]);
    context.push(child, name2);
  }
  for (name2 in right) {
    if (!Object.prototype.hasOwnProperty.call(right, name2)) {
      continue;
    }
    if (propertyFilter && !propertyFilter(name2, context)) {
      continue;
    }
    if (typeof left[name2] === "undefined") {
      child = new DiffContext(void 0, right[name2]);
      context.push(child, name2);
    }
  }
  if (!context.children || context.children.length === 0) {
    context.setResult(void 0).exit();
    return;
  }
  context.exit();
}, "objectsDiffFilter");
objectsDiffFilter.filterName = "objects";
const patchFilter$2 = /* @__PURE__ */ __name(function nestedPatchFilter(context) {
  if (!context.nested) {
    return;
  }
  const nestedDelta = context.delta;
  if (nestedDelta._t) {
    return;
  }
  const objectDelta = nestedDelta;
  let name2;
  let child;
  for (name2 in objectDelta) {
    child = new PatchContext(context.left[name2], objectDelta[name2]);
    context.push(child, name2);
  }
  context.exit();
}, "nestedPatchFilter");
patchFilter$2.filterName = "objects";
const collectChildrenPatchFilter$1 = /* @__PURE__ */ __name(function collectChildrenPatchFilter2(context) {
  if (!context || !context.children) {
    return;
  }
  const deltaWithChildren = context.delta;
  if (deltaWithChildren._t) {
    return;
  }
  const object = context.left;
  const length = context.children.length;
  let child;
  for (let index2 = 0; index2 < length; index2++) {
    child = context.children[index2];
    const property = child.childName;
    if (Object.prototype.hasOwnProperty.call(context.left, property) && child.result === void 0) {
      delete object[property];
    } else if (object[property] !== child.result) {
      object[property] = child.result;
    }
  }
  context.setResult(object).exit();
}, "collectChildrenPatchFilter");
collectChildrenPatchFilter$1.filterName = "collectChildren";
const reverseFilter$2 = /* @__PURE__ */ __name(function nestedReverseFilter(context) {
  if (!context.nested) {
    return;
  }
  const nestedDelta = context.delta;
  if (nestedDelta._t) {
    return;
  }
  const objectDelta = context.delta;
  let name2;
  let child;
  for (name2 in objectDelta) {
    child = new ReverseContext(objectDelta[name2]);
    context.push(child, name2);
  }
  context.exit();
}, "nestedReverseFilter");
reverseFilter$2.filterName = "objects";
const collectChildrenReverseFilter$1 = /* @__PURE__ */ __name((context) => {
  if (!context || !context.children) {
    return;
  }
  const deltaWithChildren = context.delta;
  if (deltaWithChildren._t) {
    return;
  }
  const length = context.children.length;
  let child;
  const delta2 = {};
  for (let index2 = 0; index2 < length; index2++) {
    child = context.children[index2];
    const property = child.childName;
    if (delta2[property] !== child.result) {
      delta2[property] = child.result;
    }
  }
  context.setResult(delta2).exit();
}, "collectChildrenReverseFilter$1");
collectChildrenReverseFilter$1.filterName = "collectChildren";
const defaultMatch = /* @__PURE__ */ __name(function(array1, array2, index1, index2) {
  return array1[index1] === array2[index2];
}, "defaultMatch");
const lengthMatrix = /* @__PURE__ */ __name(function(array1, array2, match2, context) {
  const len1 = array1.length;
  const len2 = array2.length;
  let x2, y2;
  const matrix = new Array(len1 + 1);
  for (x2 = 0; x2 < len1 + 1; x2++) {
    matrix[x2] = new Array(len2 + 1);
    for (y2 = 0; y2 < len2 + 1; y2++) {
      matrix[x2][y2] = 0;
    }
  }
  matrix.match = match2;
  for (x2 = 1; x2 < len1 + 1; x2++) {
    for (y2 = 1; y2 < len2 + 1; y2++) {
      if (match2(array1, array2, x2 - 1, y2 - 1, context)) {
        matrix[x2][y2] = matrix[x2 - 1][y2 - 1] + 1;
      } else {
        matrix[x2][y2] = Math.max(matrix[x2 - 1][y2], matrix[x2][y2 - 1]);
      }
    }
  }
  return matrix;
}, "lengthMatrix");
const backtrack = /* @__PURE__ */ __name(function(matrix, array1, array2, context) {
  let index1 = array1.length;
  let index2 = array2.length;
  const subsequence = {
    sequence: [],
    indices1: [],
    indices2: []
  };
  while (index1 !== 0 && index2 !== 0) {
    const sameLetter = matrix.match(array1, array2, index1 - 1, index2 - 1, context);
    if (sameLetter) {
      subsequence.sequence.unshift(array1[index1 - 1]);
      subsequence.indices1.unshift(index1 - 1);
      subsequence.indices2.unshift(index2 - 1);
      --index1;
      --index2;
    } else {
      const valueAtMatrixAbove = matrix[index1][index2 - 1];
      const valueAtMatrixLeft = matrix[index1 - 1][index2];
      if (valueAtMatrixAbove > valueAtMatrixLeft) {
        --index2;
      } else {
        --index1;
      }
    }
  }
  return subsequence;
}, "backtrack");
const get = /* @__PURE__ */ __name(function(array1, array2, match2, context) {
  const innerContext = context || {};
  const matrix = lengthMatrix(array1, array2, match2 || defaultMatch, innerContext);
  return backtrack(matrix, array1, array2, innerContext);
}, "get");
const lcs = {
  get
};
const ARRAY_MOVE = 3;
function arraysHaveMatchByRef(array1, array2, len1, len2) {
  for (let index1 = 0; index1 < len1; index1++) {
    const val1 = array1[index1];
    for (let index2 = 0; index2 < len2; index2++) {
      const val2 = array2[index2];
      if (index1 !== index2 && val1 === val2) {
        return true;
      }
    }
  }
}
__name(arraysHaveMatchByRef, "arraysHaveMatchByRef");
function matchItems(array1, array2, index1, index2, context) {
  const value1 = array1[index1];
  const value22 = array2[index2];
  if (value1 === value22) {
    return true;
  }
  if (typeof value1 !== "object" || typeof value22 !== "object") {
    return false;
  }
  const objectHash = context.objectHash;
  if (!objectHash) {
    return context.matchByPosition && index1 === index2;
  }
  context.hashCache1 = context.hashCache1 || [];
  let hash1 = context.hashCache1[index1];
  if (typeof hash1 === "undefined") {
    context.hashCache1[index1] = hash1 = objectHash(value1, index1);
  }
  if (typeof hash1 === "undefined") {
    return false;
  }
  context.hashCache2 = context.hashCache2 || [];
  let hash2 = context.hashCache2[index2];
  if (typeof hash2 === "undefined") {
    context.hashCache2[index2] = hash2 = objectHash(value22, index2);
  }
  if (typeof hash2 === "undefined") {
    return false;
  }
  return hash1 === hash2;
}
__name(matchItems, "matchItems");
const diffFilter$2 = /* @__PURE__ */ __name(function arraysDiffFilter(context) {
  if (!context.leftIsArray) {
    return;
  }
  const matchContext = {
    objectHash: context.options && context.options.objectHash,
    matchByPosition: context.options && context.options.matchByPosition
  };
  let commonHead = 0;
  let commonTail = 0;
  let index2;
  let index1;
  let index22;
  const array1 = context.left;
  const array2 = context.right;
  const len1 = array1.length;
  const len2 = array2.length;
  let child;
  if (len1 > 0 && len2 > 0 && !matchContext.objectHash && typeof matchContext.matchByPosition !== "boolean") {
    matchContext.matchByPosition = !arraysHaveMatchByRef(array1, array2, len1, len2);
  }
  while (commonHead < len1 && commonHead < len2 && matchItems(array1, array2, commonHead, commonHead, matchContext)) {
    index2 = commonHead;
    child = new DiffContext(array1[index2], array2[index2]);
    context.push(child, index2);
    commonHead++;
  }
  while (commonTail + commonHead < len1 && commonTail + commonHead < len2 && matchItems(array1, array2, len1 - 1 - commonTail, len2 - 1 - commonTail, matchContext)) {
    index1 = len1 - 1 - commonTail;
    index22 = len2 - 1 - commonTail;
    child = new DiffContext(array1[index1], array2[index22]);
    context.push(child, index22);
    commonTail++;
  }
  let result;
  if (commonHead + commonTail === len1) {
    if (len1 === len2) {
      context.setResult(void 0).exit();
      return;
    }
    result = result || {
      _t: "a"
    };
    for (index2 = commonHead; index2 < len2 - commonTail; index2++) {
      result[index2] = [array2[index2]];
    }
    context.setResult(result).exit();
    return;
  }
  if (commonHead + commonTail === len2) {
    result = result || {
      _t: "a"
    };
    for (index2 = commonHead; index2 < len1 - commonTail; index2++) {
      result[`_${index2}`] = [array1[index2], 0, 0];
    }
    context.setResult(result).exit();
    return;
  }
  delete matchContext.hashCache1;
  delete matchContext.hashCache2;
  const trimmed1 = array1.slice(commonHead, len1 - commonTail);
  const trimmed2 = array2.slice(commonHead, len2 - commonTail);
  const seq = lcs.get(trimmed1, trimmed2, matchItems, matchContext);
  const removedItems = [];
  result = result || {
    _t: "a"
  };
  for (index2 = commonHead; index2 < len1 - commonTail; index2++) {
    if (seq.indices1.indexOf(index2 - commonHead) < 0) {
      result[`_${index2}`] = [array1[index2], 0, 0];
      removedItems.push(index2);
    }
  }
  let detectMove = true;
  if (context.options && context.options.arrays && context.options.arrays.detectMove === false) {
    detectMove = false;
  }
  let includeValueOnMove = false;
  if (context.options && context.options.arrays && context.options.arrays.includeValueOnMove) {
    includeValueOnMove = true;
  }
  const removedItemsLength = removedItems.length;
  for (index2 = commonHead; index2 < len2 - commonTail; index2++) {
    const indexOnArray2 = seq.indices2.indexOf(index2 - commonHead);
    if (indexOnArray2 < 0) {
      let isMove = false;
      if (detectMove && removedItemsLength > 0) {
        for (let removeItemIndex1 = 0; removeItemIndex1 < removedItemsLength; removeItemIndex1++) {
          index1 = removedItems[removeItemIndex1];
          if (matchItems(trimmed1, trimmed2, index1 - commonHead, index2 - commonHead, matchContext)) {
            result[`_${index1}`].splice(1, 2, index2, ARRAY_MOVE);
            if (!includeValueOnMove) {
              result[`_${index1}`][0] = "";
            }
            index22 = index2;
            child = new DiffContext(array1[index1], array2[index22]);
            context.push(child, index22);
            removedItems.splice(removeItemIndex1, 1);
            isMove = true;
            break;
          }
        }
      }
      if (!isMove) {
        result[index2] = [array2[index2]];
      }
    } else {
      index1 = seq.indices1[indexOnArray2] + commonHead;
      index22 = seq.indices2[indexOnArray2] + commonHead;
      child = new DiffContext(array1[index1], array2[index22]);
      context.push(child, index22);
    }
  }
  context.setResult(result).exit();
}, "arraysDiffFilter");
diffFilter$2.filterName = "arrays";
const compare = {
  numerically(a2, b2) {
    return a2 - b2;
  },
  numericallyBy(name2) {
    return (a2, b2) => a2[name2] - b2[name2];
  }
};
const patchFilter$1 = /* @__PURE__ */ __name(function nestedPatchFilter2(context) {
  if (!context.nested) {
    return;
  }
  const nestedDelta = context.delta;
  if (nestedDelta._t !== "a") {
    return;
  }
  let index2;
  let index1;
  const delta2 = nestedDelta;
  const array = context.left;
  let toRemove = [];
  let toInsert = [];
  const toModify = [];
  for (index2 in delta2) {
    if (index2 !== "_t") {
      if (index2[0] === "_") {
        const removedOrMovedIndex = index2;
        if (delta2[removedOrMovedIndex][2] === 0 || delta2[removedOrMovedIndex][2] === ARRAY_MOVE) {
          toRemove.push(parseInt(index2.slice(1), 10));
        } else {
          throw new Error(`only removal or move can be applied at original array indices, invalid diff type: ${delta2[removedOrMovedIndex][2]}`);
        }
      } else {
        const numberIndex = index2;
        if (delta2[numberIndex].length === 1) {
          toInsert.push({
            index: parseInt(numberIndex, 10),
            value: delta2[numberIndex][0]
          });
        } else {
          toModify.push({
            index: parseInt(numberIndex, 10),
            delta: delta2[numberIndex]
          });
        }
      }
    }
  }
  toRemove = toRemove.sort(compare.numerically);
  for (index2 = toRemove.length - 1; index2 >= 0; index2--) {
    index1 = toRemove[index2];
    const indexDiff = delta2[`_${index1}`];
    const removedValue = array.splice(index1, 1)[0];
    if (indexDiff[2] === ARRAY_MOVE) {
      toInsert.push({
        index: indexDiff[1],
        value: removedValue
      });
    }
  }
  toInsert = toInsert.sort(compare.numericallyBy("index"));
  const toInsertLength = toInsert.length;
  for (index2 = 0; index2 < toInsertLength; index2++) {
    const insertion = toInsert[index2];
    array.splice(insertion.index, 0, insertion.value);
  }
  const toModifyLength = toModify.length;
  let child;
  if (toModifyLength > 0) {
    for (index2 = 0; index2 < toModifyLength; index2++) {
      const modification = toModify[index2];
      child = new PatchContext(array[modification.index], modification.delta);
      context.push(child, modification.index);
    }
  }
  if (!context.children) {
    context.setResult(array).exit();
    return;
  }
  context.exit();
}, "nestedPatchFilter");
patchFilter$1.filterName = "arrays";
const collectChildrenPatchFilter = /* @__PURE__ */ __name(function collectChildrenPatchFilter3(context) {
  if (!context || !context.children) {
    return;
  }
  const deltaWithChildren = context.delta;
  if (deltaWithChildren._t !== "a") {
    return;
  }
  const array = context.left;
  const length = context.children.length;
  let child;
  for (let index2 = 0; index2 < length; index2++) {
    child = context.children[index2];
    const arrayIndex = child.childName;
    array[arrayIndex] = child.result;
  }
  context.setResult(array).exit();
}, "collectChildrenPatchFilter");
collectChildrenPatchFilter.filterName = "arraysCollectChildren";
const reverseFilter$1 = /* @__PURE__ */ __name(function arraysReverseFilter(context) {
  if (!context.nested) {
    const nonNestedDelta = context.delta;
    if (nonNestedDelta[2] === ARRAY_MOVE) {
      const arrayMoveDelta = nonNestedDelta;
      context.newName = `_${arrayMoveDelta[1]}`;
      context.setResult([
        arrayMoveDelta[0],
        parseInt(context.childName.substring(1), 10),
        ARRAY_MOVE
      ]).exit();
    }
    return;
  }
  const nestedDelta = context.delta;
  if (nestedDelta._t !== "a") {
    return;
  }
  const arrayDelta = nestedDelta;
  let name2;
  let child;
  for (name2 in arrayDelta) {
    if (name2 === "_t") {
      continue;
    }
    child = new ReverseContext(arrayDelta[name2]);
    context.push(child, name2);
  }
  context.exit();
}, "arraysReverseFilter");
reverseFilter$1.filterName = "arrays";
const reverseArrayDeltaIndex = /* @__PURE__ */ __name((delta2, index2, itemDelta) => {
  if (typeof index2 === "string" && index2[0] === "_") {
    return parseInt(index2.substring(1), 10);
  } else if (Array.isArray(itemDelta) && itemDelta[2] === 0) {
    return `_${index2}`;
  }
  let reverseIndex = +index2;
  for (const deltaIndex in delta2) {
    const deltaItem = delta2[deltaIndex];
    if (Array.isArray(deltaItem)) {
      if (deltaItem[2] === ARRAY_MOVE) {
        const moveFromIndex = parseInt(deltaIndex.substring(1), 10);
        const moveToIndex = deltaItem[1];
        if (moveToIndex === +index2) {
          return moveFromIndex;
        }
        if (moveFromIndex <= reverseIndex && moveToIndex > reverseIndex) {
          reverseIndex++;
        } else if (moveFromIndex >= reverseIndex && moveToIndex < reverseIndex) {
          reverseIndex--;
        }
      } else if (deltaItem[2] === 0) {
        const deleteIndex = parseInt(deltaIndex.substring(1), 10);
        if (deleteIndex <= reverseIndex) {
          reverseIndex++;
        }
      } else if (deltaItem.length === 1 && parseInt(deltaIndex, 10) <= reverseIndex) {
        reverseIndex--;
      }
    }
  }
  return reverseIndex;
}, "reverseArrayDeltaIndex");
const collectChildrenReverseFilter = /* @__PURE__ */ __name((context) => {
  if (!context || !context.children) {
    return;
  }
  const deltaWithChildren = context.delta;
  if (deltaWithChildren._t !== "a") {
    return;
  }
  const arrayDelta = deltaWithChildren;
  const length = context.children.length;
  let child;
  const delta2 = {
    _t: "a"
  };
  for (let index2 = 0; index2 < length; index2++) {
    child = context.children[index2];
    let name2 = child.newName;
    if (typeof name2 === "undefined") {
      name2 = reverseArrayDeltaIndex(arrayDelta, child.childName, child.result);
    }
    if (delta2[name2] !== child.result) {
      delta2[name2] = child.result;
    }
  }
  context.setResult(delta2).exit();
}, "collectChildrenReverseFilter");
collectChildrenReverseFilter.filterName = "arraysCollectChildren";
const diffFilter$1 = /* @__PURE__ */ __name(function datesDiffFilter(context) {
  if (context.left instanceof Date) {
    if (context.right instanceof Date) {
      if (context.left.getTime() !== context.right.getTime()) {
        context.setResult([context.left, context.right]);
      } else {
        context.setResult(void 0);
      }
    } else {
      context.setResult([context.left, context.right]);
    }
    context.exit();
  } else if (context.right instanceof Date) {
    context.setResult([context.left, context.right]).exit();
  }
}, "datesDiffFilter");
diffFilter$1.filterName = "dates";
const TEXT_DIFF = 2;
const DEFAULT_MIN_LENGTH = 60;
let cachedDiffPatch = null;
function getDiffMatchPatch(options5, required) {
  var _a2;
  if (!cachedDiffPatch) {
    let instance;
    if ((_a2 = options5 === null || options5 === void 0 ? void 0 : options5.textDiff) === null || _a2 === void 0 ? void 0 : _a2.diffMatchPatch) {
      instance = new options5.textDiff.diffMatchPatch();
    } else {
      if (!required) {
        return null;
      }
      const error2 = new Error("The diff-match-patch library was not provided. Pass the library in through the options or use the `jsondiffpatch/with-text-diffs` entry-point.");
      error2.diff_match_patch_not_found = true;
      throw error2;
    }
    cachedDiffPatch = {
      diff: /* @__PURE__ */ __name(function(txt1, txt2) {
        return instance.patch_toText(instance.patch_make(txt1, txt2));
      }, "diff"),
      patch: /* @__PURE__ */ __name(function(txt1, patch2) {
        const results = instance.patch_apply(instance.patch_fromText(patch2), txt1);
        for (let i2 = 0; i2 < results[1].length; i2++) {
          if (!results[1][i2]) {
            const error2 = new Error("text patch failed");
            error2.textPatchFailed = true;
          }
        }
        return results[0];
      }, "patch")
    };
  }
  return cachedDiffPatch;
}
__name(getDiffMatchPatch, "getDiffMatchPatch");
const diffFilter = /* @__PURE__ */ __name(function textsDiffFilter(context) {
  if (context.leftType !== "string") {
    return;
  }
  const left = context.left;
  const right = context.right;
  const minLength = context.options && context.options.textDiff && context.options.textDiff.minLength || DEFAULT_MIN_LENGTH;
  if (left.length < minLength || right.length < minLength) {
    context.setResult([left, right]).exit();
    return;
  }
  const diffMatchPatch = getDiffMatchPatch(context.options);
  if (!diffMatchPatch) {
    context.setResult([left, right]).exit();
    return;
  }
  const diff2 = diffMatchPatch.diff;
  context.setResult([diff2(left, right), 0, TEXT_DIFF]).exit();
}, "textsDiffFilter");
diffFilter.filterName = "texts";
const patchFilter = /* @__PURE__ */ __name(function textsPatchFilter(context) {
  if (context.nested) {
    return;
  }
  const nonNestedDelta = context.delta;
  if (nonNestedDelta[2] !== TEXT_DIFF) {
    return;
  }
  const textDiffDelta = nonNestedDelta;
  const patch2 = getDiffMatchPatch(context.options, true).patch;
  context.setResult(patch2(context.left, textDiffDelta[0])).exit();
}, "textsPatchFilter");
patchFilter.filterName = "texts";
const textDeltaReverse = /* @__PURE__ */ __name(function(delta2) {
  let i2;
  let l2;
  let line;
  let lineTmp;
  let header3 = null;
  const headerRegex = /^@@ +-(\d+),(\d+) +\+(\d+),(\d+) +@@$/;
  let lineHeader;
  const lines = delta2.split("\n");
  for (i2 = 0, l2 = lines.length; i2 < l2; i2++) {
    line = lines[i2];
    const lineStart = line.slice(0, 1);
    if (lineStart === "@") {
      header3 = headerRegex.exec(line);
      lineHeader = i2;
      lines[lineHeader] = "@@ -" + header3[3] + "," + header3[4] + " +" + header3[1] + "," + header3[2] + " @@";
    } else if (lineStart === "+") {
      lines[i2] = "-" + lines[i2].slice(1);
      if (lines[i2 - 1].slice(0, 1) === "+") {
        lineTmp = lines[i2];
        lines[i2] = lines[i2 - 1];
        lines[i2 - 1] = lineTmp;
      }
    } else if (lineStart === "-") {
      lines[i2] = "+" + lines[i2].slice(1);
    }
  }
  return lines.join("\n");
}, "textDeltaReverse");
const reverseFilter = /* @__PURE__ */ __name(function textsReverseFilter(context) {
  if (context.nested) {
    return;
  }
  const nonNestedDelta = context.delta;
  if (nonNestedDelta[2] !== TEXT_DIFF) {
    return;
  }
  const textDiffDelta = nonNestedDelta;
  context.setResult([textDeltaReverse(textDiffDelta[0]), 0, TEXT_DIFF]).exit();
}, "textsReverseFilter");
reverseFilter.filterName = "texts";
class DiffPatcher {
  static {
    __name(this, "DiffPatcher");
  }
  constructor(options5) {
    this.processor = new Processor(options5);
    this.processor.pipe(new Pipe("diff").append(collectChildrenDiffFilter, diffFilter$3, diffFilter$1, diffFilter, objectsDiffFilter, diffFilter$2).shouldHaveResult());
    this.processor.pipe(new Pipe("patch").append(collectChildrenPatchFilter$1, collectChildrenPatchFilter, patchFilter$3, patchFilter, patchFilter$2, patchFilter$1).shouldHaveResult());
    this.processor.pipe(new Pipe("reverse").append(collectChildrenReverseFilter$1, collectChildrenReverseFilter, reverseFilter$3, reverseFilter, reverseFilter$2, reverseFilter$1).shouldHaveResult());
  }
  options(options5) {
    return this.processor.options(options5);
  }
  diff(left, right) {
    return this.processor.process(new DiffContext(left, right));
  }
  patch(left, delta2) {
    return this.processor.process(new PatchContext(left, delta2));
  }
  reverse(delta2) {
    return this.processor.process(new ReverseContext(delta2));
  }
  unpatch(right, delta2) {
    return this.patch(right, this.reverse(delta2));
  }
  clone(value3) {
    return clone$2(value3);
  }
}
function dateReviver(key, value3) {
  let parts2;
  if (typeof value3 === "string") {
    parts2 = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})(?:\.(\d*))?(Z|([+-])(\d{2}):(\d{2}))$/.exec(value3);
    if (parts2) {
      return new Date(Date.UTC(+parts2[1], +parts2[2] - 1, +parts2[3], +parts2[4], +parts2[5], +parts2[6], +(parts2[7] || 0)));
    }
  }
  return value3;
}
__name(dateReviver, "dateReviver");
function create(options5) {
  return new DiffPatcher(options5);
}
__name(create, "create");
let defaultInstance;
function diff(left, right) {
  if (!defaultInstance) {
    defaultInstance = new DiffPatcher();
  }
  return defaultInstance.diff(left, right);
}
__name(diff, "diff");
function patch(left, delta2) {
  if (!defaultInstance) {
    defaultInstance = new DiffPatcher();
  }
  return defaultInstance.patch(left, delta2);
}
__name(patch, "patch");
function unpatch(right, delta2) {
  if (!defaultInstance) {
    defaultInstance = new DiffPatcher();
  }
  return defaultInstance.unpatch(right, delta2);
}
__name(unpatch, "unpatch");
function reverse(delta2) {
  if (!defaultInstance) {
    defaultInstance = new DiffPatcher();
  }
  return defaultInstance.reverse(delta2);
}
__name(reverse, "reverse");
function clone$1(value3) {
  if (!defaultInstance) {
    defaultInstance = new DiffPatcher();
  }
  return defaultInstance.clone(value3);
}
__name(clone$1, "clone$1");
var loglevel$1 = { exports: {} };
var loglevel = loglevel$1.exports;
(function(module2) {
  (function(root34, definition) {
    "use strict";
    if (false) {
      (void 0)(definition);
    } else if (module2.exports) {
      module2.exports = definition();
    } else {
      root34.log = definition();
    }
  })(commonjsGlobal, function() {
    "use strict";
    var noop2 = /* @__PURE__ */ __name(function() {
    }, "noop");
    var undefinedType2 = "undefined";
    var isIE = typeof window !== undefinedType2 && typeof window.navigator !== undefinedType2 && /Trident\/|MSIE /.test(window.navigator.userAgent);
    var logMethods = [
      "trace",
      "debug",
      "info",
      "warn",
      "error"
    ];
    var _loggersByName = {};
    var defaultLogger = null;
    function bindMethod(obj, methodName) {
      var method = obj[methodName];
      if (typeof method.bind === "function") {
        return method.bind(obj);
      } else {
        try {
          return Function.prototype.bind.call(method, obj);
        } catch (e2) {
          return function() {
            return Function.prototype.apply.apply(method, [obj, arguments]);
          };
        }
      }
    }
    __name(bindMethod, "bindMethod");
    function traceForIE() {
      if (console.log) {
        if (console.log.apply) {
          console.log.apply(console, arguments);
        } else {
          Function.prototype.apply.apply(console.log, [console, arguments]);
        }
      }
      if (console.trace) console.trace();
    }
    __name(traceForIE, "traceForIE");
    function realMethod(methodName) {
      if (methodName === "debug") {
        methodName = "log";
      }
      if (typeof console === undefinedType2) {
        return false;
      } else if (methodName === "trace" && isIE) {
        return traceForIE;
      } else if (console[methodName] !== void 0) {
        return bindMethod(console, methodName);
      } else if (console.log !== void 0) {
        return bindMethod(console, "log");
      } else {
        return noop2;
      }
    }
    __name(realMethod, "realMethod");
    function replaceLoggingMethods() {
      var level = this.getLevel();
      for (var i2 = 0; i2 < logMethods.length; i2++) {
        var methodName = logMethods[i2];
        this[methodName] = i2 < level ? noop2 : this.methodFactory(methodName, level, this.name);
      }
      this.log = this.debug;
      if (typeof console === undefinedType2 && level < this.levels.SILENT) {
        return "No console available for logging";
      }
    }
    __name(replaceLoggingMethods, "replaceLoggingMethods");
    function enableLoggingWhenConsoleArrives(methodName) {
      return function() {
        if (typeof console !== undefinedType2) {
          replaceLoggingMethods.call(this);
          this[methodName].apply(this, arguments);
        }
      };
    }
    __name(enableLoggingWhenConsoleArrives, "enableLoggingWhenConsoleArrives");
    function defaultMethodFactory(methodName, _level, _loggerName) {
      return realMethod(methodName) || enableLoggingWhenConsoleArrives.apply(this, arguments);
    }
    __name(defaultMethodFactory, "defaultMethodFactory");
    function Logger(name2, factory) {
      var self2 = this;
      var inheritedLevel;
      var defaultLevel;
      var userLevel;
      var storageKey = "loglevel";
      if (typeof name2 === "string") {
        storageKey += ":" + name2;
      } else if (typeof name2 === "symbol") {
        storageKey = void 0;
      }
      function persistLevelIfPossible(levelNum) {
        var levelName = (logMethods[levelNum] || "silent").toUpperCase();
        if (typeof window === undefinedType2 || !storageKey) return;
        try {
          window.localStorage[storageKey] = levelName;
          return;
        } catch (ignore) {
        }
        try {
          window.document.cookie = encodeURIComponent(storageKey) + "=" + levelName + ";";
        } catch (ignore) {
        }
      }
      __name(persistLevelIfPossible, "persistLevelIfPossible");
      function getPersistedLevel() {
        var storedLevel;
        if (typeof window === undefinedType2 || !storageKey) return;
        try {
          storedLevel = window.localStorage[storageKey];
        } catch (ignore) {
        }
        if (typeof storedLevel === undefinedType2) {
          try {
            var cookie = window.document.cookie;
            var cookieName = encodeURIComponent(storageKey);
            var location2 = cookie.indexOf(cookieName + "=");
            if (location2 !== -1) {
              storedLevel = /^([^;]+)/.exec(
                cookie.slice(location2 + cookieName.length + 1)
              )[1];
            }
          } catch (ignore) {
          }
        }
        if (self2.levels[storedLevel] === void 0) {
          storedLevel = void 0;
        }
        return storedLevel;
      }
      __name(getPersistedLevel, "getPersistedLevel");
      function clearPersistedLevel() {
        if (typeof window === undefinedType2 || !storageKey) return;
        try {
          window.localStorage.removeItem(storageKey);
        } catch (ignore) {
        }
        try {
          window.document.cookie = encodeURIComponent(storageKey) + "=; expires=Thu, 01 Jan 1970 00:00:00 UTC";
        } catch (ignore) {
        }
      }
      __name(clearPersistedLevel, "clearPersistedLevel");
      function normalizeLevel(input) {
        var level = input;
        if (typeof level === "string" && self2.levels[level.toUpperCase()] !== void 0) {
          level = self2.levels[level.toUpperCase()];
        }
        if (typeof level === "number" && level >= 0 && level <= self2.levels.SILENT) {
          return level;
        } else {
          throw new TypeError("log.setLevel() called with invalid level: " + input);
        }
      }
      __name(normalizeLevel, "normalizeLevel");
      self2.name = name2;
      self2.levels = {
        "TRACE": 0,
        "DEBUG": 1,
        "INFO": 2,
        "WARN": 3,
        "ERROR": 4,
        "SILENT": 5
      };
      self2.methodFactory = factory || defaultMethodFactory;
      self2.getLevel = function() {
        if (userLevel != null) {
          return userLevel;
        } else if (defaultLevel != null) {
          return defaultLevel;
        } else {
          return inheritedLevel;
        }
      };
      self2.setLevel = function(level, persist) {
        userLevel = normalizeLevel(level);
        if (persist !== false) {
          persistLevelIfPossible(userLevel);
        }
        return replaceLoggingMethods.call(self2);
      };
      self2.setDefaultLevel = function(level) {
        defaultLevel = normalizeLevel(level);
        if (!getPersistedLevel()) {
          self2.setLevel(level, false);
        }
      };
      self2.resetLevel = function() {
        userLevel = null;
        clearPersistedLevel();
        replaceLoggingMethods.call(self2);
      };
      self2.enableAll = function(persist) {
        self2.setLevel(self2.levels.TRACE, persist);
      };
      self2.disableAll = function(persist) {
        self2.setLevel(self2.levels.SILENT, persist);
      };
      self2.rebuild = function() {
        if (defaultLogger !== self2) {
          inheritedLevel = normalizeLevel(defaultLogger.getLevel());
        }
        replaceLoggingMethods.call(self2);
        if (defaultLogger === self2) {
          for (var childName in _loggersByName) {
            _loggersByName[childName].rebuild();
          }
        }
      };
      inheritedLevel = normalizeLevel(
        defaultLogger ? defaultLogger.getLevel() : "WARN"
      );
      var initialLevel = getPersistedLevel();
      if (initialLevel != null) {
        userLevel = normalizeLevel(initialLevel);
      }
      replaceLoggingMethods.call(self2);
    }
    __name(Logger, "Logger");
    defaultLogger = new Logger();
    defaultLogger.getLogger = /* @__PURE__ */ __name(function getLogger(name2) {
      if (typeof name2 !== "symbol" && typeof name2 !== "string" || name2 === "") {
        throw new TypeError("You must supply a name when creating a logger.");
      }
      var logger2 = _loggersByName[name2];
      if (!logger2) {
        logger2 = _loggersByName[name2] = new Logger(
          name2,
          defaultLogger.methodFactory
        );
      }
      return logger2;
    }, "getLogger");
    var _log = typeof window !== undefinedType2 ? window.log : void 0;
    defaultLogger.noConflict = function() {
      if (typeof window !== undefinedType2 && window.log === defaultLogger) {
        window.log = _log;
      }
      return defaultLogger;
    };
    defaultLogger.getLoggers = /* @__PURE__ */ __name(function getLoggers() {
      return _loggersByName;
    }, "getLoggers");
    defaultLogger["default"] = defaultLogger;
    return defaultLogger;
  });
})(loglevel$1);
var loglevelExports = loglevel$1.exports;
const log = /* @__PURE__ */ getDefaultExportFromCjs(loglevelExports);
function clone(obj) {
  return JSON.parse(JSON.stringify(obj));
}
__name(clone, "clone");
const logger = log.getLogger("ChangeTracker");
logger.setLevel("info");
class ChangeTracker {
  static {
    __name(this, "ChangeTracker");
  }
  constructor(workflow, initialState) {
    this.workflow = workflow;
    this.initialState = initialState;
    this.activeState = initialState;
  }
  static MAX_HISTORY = 50;
  /**
   * The active state of the workflow.
   */
  activeState;
  undoQueue = [];
  redoQueue = [];
  changeCount = 0;
  /**
   * Whether the redo/undo restoring is in progress.
   */
  restoringState = false;
  ds;
  nodeOutputs;
  static app;
  get app() {
    return ChangeTracker.app;
  }
  /**
   * Save the current state as the initial state.
   */
  reset(state) {
    if (this.restoringState) return;
    logger.debug("Reset State");
    if (state) this.activeState = clone(state);
    this.initialState = clone(this.activeState);
  }
  store() {
    this.ds = {
      scale: this.app.canvas.ds.scale,
      offset: [this.app.canvas.ds.offset[0], this.app.canvas.ds.offset[1]]
    };
  }
  restore() {
    if (this.ds) {
      this.app.canvas.ds.scale = this.ds.scale;
      this.app.canvas.ds.offset = this.ds.offset;
    }
    if (this.nodeOutputs) {
      this.app.nodeOutputs = this.nodeOutputs;
    }
  }
  updateModified() {
    api.dispatchCustomEvent("graphChanged", this.activeState);
    const workflow = useWorkflowStore().getWorkflowByPath(this.workflow.path);
    if (workflow) {
      workflow.isModified = !ChangeTracker.graphEqual(
        this.initialState,
        this.activeState
      );
      if (logger.getLevel() <= logger.levels.DEBUG && workflow.isModified) {
        const diff2 = ChangeTracker.graphDiff(
          this.initialState,
          this.activeState
        );
        logger.debug("Graph diff:", diff2);
      }
    }
  }
  checkState() {
    if (!this.app.graph || this.changeCount) return;
    const currentState = clone(this.app.graph.serialize());
    if (!this.activeState) {
      this.activeState = currentState;
      return;
    }
    if (!ChangeTracker.graphEqual(this.activeState, currentState)) {
      this.undoQueue.push(this.activeState);
      if (this.undoQueue.length > ChangeTracker.MAX_HISTORY) {
        this.undoQueue.shift();
      }
      logger.debug("Diff detected. Undo queue length:", this.undoQueue.length);
      this.activeState = currentState;
      this.redoQueue.length = 0;
      this.updateModified();
    }
  }
  async updateState(source, target2) {
    const prevState = source.pop();
    if (prevState) {
      target2.push(this.activeState);
      this.restoringState = true;
      try {
        await this.app.loadGraphData(prevState, false, false, this.workflow, {
          showMissingModelsDialog: false,
          showMissingNodesDialog: false
        });
        this.activeState = prevState;
        this.updateModified();
      } finally {
        this.restoringState = false;
      }
    }
  }
  async undo() {
    await this.updateState(this.undoQueue, this.redoQueue);
    logger.debug(
      "Undo. Undo queue length:",
      this.undoQueue.length,
      "Redo queue length:",
      this.redoQueue.length
    );
  }
  async redo() {
    await this.updateState(this.redoQueue, this.undoQueue);
    logger.debug(
      "Redo. Undo queue length:",
      this.undoQueue.length,
      "Redo queue length:",
      this.redoQueue.length
    );
  }
  async undoRedo(e2) {
    if ((e2.ctrlKey || e2.metaKey) && !e2.altKey) {
      const key = e2.key.toUpperCase();
      if (key === "Y" && !e2.shiftKey || key == "Z" && e2.shiftKey) {
        await this.redo();
        return true;
      } else if (key === "Z" && !e2.shiftKey) {
        await this.undo();
        return true;
      }
    }
  }
  beforeChange() {
    this.changeCount++;
  }
  afterChange() {
    if (!--this.changeCount) {
      this.checkState();
    }
  }
  static init(app2) {
    const getCurrentChangeTracker = /* @__PURE__ */ __name(() => useWorkflowStore().activeWorkflow?.changeTracker, "getCurrentChangeTracker");
    const checkState = /* @__PURE__ */ __name(() => getCurrentChangeTracker()?.checkState(), "checkState");
    ChangeTracker.app = app2;
    let keyIgnored = false;
    window.addEventListener(
      "keydown",
      (e2) => {
        if (e2.repeat) return;
        const activeEl = document.activeElement;
        requestAnimationFrame(async () => {
          let bindInputEl = null;
          if (!app2.ui.autoQueueEnabled || app2.ui.autoQueueMode === "instant") {
            if (activeEl?.tagName === "INPUT" || activeEl && "type" in activeEl && activeEl.type === "textarea") {
              return;
            }
            bindInputEl = activeEl;
          }
          keyIgnored = e2.key === "Control" || e2.key === "Shift" || e2.key === "Alt" || e2.key === "Meta";
          if (keyIgnored) return;
          const changeTracker = getCurrentChangeTracker();
          if (!changeTracker) return;
          if (await changeTracker.undoRedo(e2)) return;
          if (ChangeTracker.bindInput(app2, bindInputEl)) return;
          logger.debug("checkState on keydown");
          changeTracker.checkState();
        });
      },
      true
    );
    window.addEventListener("keyup", () => {
      if (keyIgnored) {
        keyIgnored = false;
        logger.debug("checkState on keyup");
        checkState();
      }
    });
    window.addEventListener("mouseup", () => {
      logger.debug("checkState on mouseup");
      checkState();
    });
    api.addEventListener("promptQueued", () => {
      logger.debug("checkState on promptQueued");
      checkState();
    });
    api.addEventListener("graphCleared", () => {
      logger.debug("checkState on graphCleared");
      checkState();
    });
    const processMouseUp = LGraphCanvas.prototype.processMouseUp;
    LGraphCanvas.prototype.processMouseUp = function(e2) {
      const v2 = processMouseUp.apply(this, [e2]);
      logger.debug("checkState on processMouseUp");
      checkState();
      return v2;
    };
    const processMouseDown = LGraphCanvas.prototype.processMouseDown;
    LGraphCanvas.prototype.processMouseDown = function(e2) {
      const v2 = processMouseDown.apply(this, [e2]);
      logger.debug("checkState on processMouseDown");
      checkState();
      return v2;
    };
    const prompt = LGraphCanvas.prototype.prompt;
    LGraphCanvas.prototype.prompt = function(title, value3, callback, event) {
      const extendedCallback = /* @__PURE__ */ __name((v2) => {
        callback(v2);
        checkState();
      }, "extendedCallback");
      logger.debug("checkState on prompt");
      return prompt.apply(this, [title, value3, extendedCallback, event]);
    };
    const close5 = LiteGraph.ContextMenu.prototype.close;
    LiteGraph.ContextMenu.prototype.close = function(e2) {
      const v2 = close5.apply(this, [e2]);
      logger.debug("checkState on contextMenuClose");
      checkState();
      return v2;
    };
    const onNodeAdded = LiteGraph.LGraph.prototype.onNodeAdded;
    LiteGraph.LGraph.prototype.onNodeAdded = function(node3) {
      const v2 = onNodeAdded?.apply(this, [node3]);
      if (!app2?.configuringGraph) {
        logger.debug("checkState on onNodeAdded");
        checkState();
      }
      return v2;
    };
    document.addEventListener("litegraph:canvas", (e2) => {
      const detail = e2.detail;
      if (detail.subType === "before-change") {
        getCurrentChangeTracker()?.beforeChange();
      } else if (detail.subType === "after-change") {
        getCurrentChangeTracker()?.afterChange();
      }
    });
    api.addEventListener("executed", (e2) => {
      const detail = e2.detail;
      const workflow = useExecutionStore().queuedPrompts[detail.prompt_id]?.workflow;
      const changeTracker = workflow?.changeTracker;
      if (!changeTracker) return;
      changeTracker.nodeOutputs ??= {};
      const nodeOutputs = changeTracker.nodeOutputs;
      const output = nodeOutputs[detail.node];
      if (detail.merge && output) {
        for (const k2 in detail.output ?? {}) {
          const v2 = output[k2];
          if (v2 instanceof Array) {
            output[k2] = v2.concat(detail.output[k2]);
          } else {
            output[k2] = detail.output[k2];
          }
        }
      } else {
        nodeOutputs[detail.node] = detail.output;
      }
    });
  }
  static bindInput(_app, activeEl) {
    if (!activeEl || activeEl.tagName === "CANVAS" || activeEl.tagName === "BODY") {
      return false;
    }
    for (const evt of ["change", "input", "blur"]) {
      const htmlElement = activeEl;
      if (`on${evt}` in htmlElement) {
        const listener = /* @__PURE__ */ __name(() => {
          useWorkflowStore().activeWorkflow?.changeTracker?.checkState?.();
          htmlElement.removeEventListener(evt, listener);
        }, "listener");
        htmlElement.addEventListener(evt, listener);
        return true;
      }
    }
    return false;
  }
  static graphEqual(a2, b2) {
    if (a2 === b2) return true;
    if (typeof a2 == "object" && a2 && typeof b2 == "object" && b2) {
      if (!_.isEqualWith(a2.nodes, b2.nodes, (arrA, arrB) => {
        if (Array.isArray(arrA) && Array.isArray(arrB)) {
          return _.isEqual(new Set(arrA), new Set(arrB));
        }
      })) {
        return false;
      }
      if (!_.isEqual(_.omit(a2.extra ?? {}, ["ds"]), _.omit(b2.extra ?? {}, ["ds"])))
        return false;
      for (const key of ["links", "floatingLinks", "reroutes", "groups"]) {
        if (!_.isEqual(a2[key], b2[key])) {
          return false;
        }
      }
      return true;
    }
    return false;
  }
  static graphDiff(a2, b2) {
    function sortGraphNodes(graph) {
      return {
        links: graph.links,
        groups: graph.groups,
        nodes: graph.nodes.sort((a22, b22) => {
          if (typeof a22.id === "number" && typeof b22.id === "number") {
            return a22.id - b22.id;
          }
          return 0;
        })
      };
    }
    __name(sortGraphNodes, "sortGraphNodes");
    return diff(sortGraphNodes(a2), sortGraphNodes(b2));
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.changeTracker = window.comfyAPI.changeTracker || {};
window.comfyAPI.changeTracker.ChangeTracker = ChangeTracker;
async function syncEntities(dir, entityByPath, createEntity, updateEntity, exclude = () => false) {
  const files = (await api.listUserDataFullInfo(dir)).map((file) => ({
    ...file,
    path: dir ? `${dir}/${file.path}` : file.path
  }));
  for (const file of files) {
    const existingEntity = entityByPath[file.path];
    if (!existingEntity) {
      entityByPath[file.path] = createEntity(file);
    } else if (exclude(existingEntity)) {
      continue;
    } else {
      updateEntity(existingEntity, file);
    }
  }
  for (const [path, entity2] of Object.entries(entityByPath)) {
    if (exclude(entity2)) continue;
    if (!files.some((file) => file.path === path)) {
      delete entityByPath[path];
    }
  }
}
__name(syncEntities, "syncEntities");
class UserFile {
  static {
    __name(this, "UserFile");
  }
  constructor(path, lastModified, size) {
    this.path = path;
    this.lastModified = lastModified;
    this.size = size;
    const details = getPathDetails(path);
    this.path = path;
    this.directory = details.directory;
    this.fullFilename = details.fullFilename;
    this.filename = details.filename;
    this.suffix = details.suffix;
  }
  /**
   * Various path components.
   * Example:
   * - path: 'dir/file.txt'
   * - directory: 'dir'
   * - fullFilename: 'file.txt'
   * - filename: 'file'
   * - suffix: 'txt'
   */
  directory;
  fullFilename;
  filename;
  suffix;
  isLoading = false;
  content = null;
  originalContent = null;
  updatePath(newPath) {
    const details = getPathDetails(newPath);
    this.path = newPath;
    this.directory = details.directory;
    this.fullFilename = details.fullFilename;
    this.filename = details.filename;
    this.suffix = details.suffix;
  }
  static createTemporary(path) {
    return new UserFile(path, Date.now(), -1);
  }
  get isTemporary() {
    return this.size === -1;
  }
  get isPersisted() {
    return !this.isTemporary;
  }
  get key() {
    return this.path;
  }
  get isLoaded() {
    return this.content !== null;
  }
  get isModified() {
    return this.content !== this.originalContent;
  }
  /**
   * Loads the file content from the remote storage.
   */
  async load({
    force = false
  } = {}) {
    if (this.isTemporary || !force && this.isLoaded)
      return this;
    this.isLoading = true;
    const resp = await api.getUserData(this.path);
    if (resp.status !== 200) {
      throw new Error(
        `Failed to load file '${this.path}': ${resp.status} ${resp.statusText}`
      );
    }
    this.content = await resp.text();
    this.originalContent = this.content;
    this.isLoading = false;
    return this;
  }
  /**
   * Unloads the file content from memory
   */
  unload() {
    this.content = null;
    this.originalContent = null;
    this.isLoading = false;
  }
  async saveAs(newPath) {
    const tempFile = this.isTemporary ? this : UserFile.createTemporary(newPath);
    tempFile.content = this.content;
    await tempFile.save();
    return tempFile;
  }
  /**
   * Saves the file to the remote storage.
   * @param force Whether to force the save even if the file is not modified.
   */
  async save({ force = false } = {}) {
    if (this.isPersisted && !this.isModified && !force) return this;
    const resp = await api.storeUserData(this.path, this.content, {
      overwrite: this.isPersisted,
      throwOnError: true,
      full_info: true
    });
    const updatedFile = await resp.json();
    if (typeof updatedFile === "object") {
      this.lastModified = updatedFile.modified;
      this.size = updatedFile.size;
    }
    this.originalContent = this.content;
    return this;
  }
  async delete() {
    if (this.isTemporary) return;
    const resp = await api.deleteUserData(this.path);
    if (resp.status !== 204) {
      throw new Error(
        `Failed to delete file '${this.path}': ${resp.status} ${resp.statusText}`
      );
    }
  }
  async rename(newPath) {
    if (this.isTemporary) {
      this.updatePath(newPath);
      return this;
    }
    const resp = await api.moveUserData(this.path, newPath);
    if (resp.status !== 200) {
      throw new Error(
        `Failed to rename file '${this.path}': ${resp.status} ${resp.statusText}`
      );
    }
    this.updatePath(newPath);
    const updatedFile = await resp.json();
    if (typeof updatedFile === "object") {
      this.lastModified = updatedFile.modified;
      this.size = updatedFile.size;
    }
    return this;
  }
}
const useUserFileStore = /* @__PURE__ */ defineStore("userFile", () => {
  const userFilesByPath = ref({});
  const userFiles = computed(() => Object.values(userFilesByPath.value));
  const modifiedFiles = computed(
    () => userFiles.value.filter((file) => file.isModified)
  );
  const loadedFiles = computed(
    () => userFiles.value.filter((file) => file.isLoaded)
  );
  const fileTree = computed(
    () => buildTree$1(
      userFiles.value,
      (userFile) => userFile.path.split("/")
    )
  );
  const syncFiles = /* @__PURE__ */ __name(async (dir = "") => {
    await syncEntities(
      dir,
      userFilesByPath.value,
      (file) => new UserFile(file.path, file.modified, file.size),
      (existingFile, file) => {
        existingFile.lastModified = file.modified;
        existingFile.size = file.size;
        existingFile.unload();
      }
    );
  }, "syncFiles");
  return {
    userFiles,
    modifiedFiles,
    loadedFiles,
    fileTree,
    syncFiles
  };
});
class ComfyWorkflow extends UserFile {
  static {
    __name(this, "ComfyWorkflow");
  }
  static basePath = "workflows/";
  /**
   * The change tracker for the workflow. Non-reactive raw object.
   */
  changeTracker = null;
  /**
   * Whether the workflow has been modified comparing to the initial state.
   */
  _isModified = false;
  /**
   * @param options The path, modified, and size of the workflow.
   * Note: path is the full path, including the 'workflows/' prefix.
   */
  constructor(options5) {
    super(options5.path, options5.modified, options5.size);
  }
  get key() {
    return this.path.substring(ComfyWorkflow.basePath.length);
  }
  get activeState() {
    return this.changeTracker?.activeState ?? null;
  }
  get initialState() {
    return this.changeTracker?.initialState ?? null;
  }
  get isLoaded() {
    return this.changeTracker !== null;
  }
  get isModified() {
    return this._isModified;
  }
  set isModified(value3) {
    this._isModified = value3;
  }
  /**
   * Load the workflow content from remote storage. Directly returns the loaded
   * workflow if the content is already loaded.
   *
   * @param force Whether to force loading the content even if it is already loaded.
   * @returns this
   */
  async load({
    force = false
  } = {}) {
    await super.load({ force });
    if (!force && this.isLoaded) return this;
    if (!this.originalContent) {
      throw new Error("[ASSERT] Workflow content should be loaded");
    }
    console.debug("load and start tracking of workflow", this.path);
    this.changeTracker = markRaw(
      new ChangeTracker(
        this,
        /* initialState= */
        JSON.parse(this.originalContent)
      )
    );
    return this;
  }
  unload() {
    console.debug("unload workflow", this.path);
    this.changeTracker = null;
    super.unload();
  }
  async save() {
    this.content = JSON.stringify(this.activeState);
    const ret = await super.save({ force: true });
    this.changeTracker?.reset();
    this.isModified = false;
    return ret;
  }
  /**
   * Save the workflow as a new file.
   * @param path The path to save the workflow to. Note: with 'workflows/' prefix.
   * @returns this
   */
  async saveAs(path) {
    this.content = JSON.stringify(this.activeState);
    return await super.saveAs(path);
  }
}
const useWorkflowStore = /* @__PURE__ */ defineStore("workflow", () => {
  const detachWorkflow = /* @__PURE__ */ __name((workflow) => {
    delete workflowLookup.value[workflow.path];
    const index2 = openWorkflowPaths.value.indexOf(workflow.path);
    if (index2 !== -1) {
      openWorkflowPaths.value = openWorkflowPaths.value.filter(
        (path) => path !== workflow.path
      );
    }
    return index2;
  }, "detachWorkflow");
  const attachWorkflow = /* @__PURE__ */ __name((workflow, openIndex = -1) => {
    workflowLookup.value[workflow.path] = workflow;
    if (openIndex !== -1) {
      openWorkflowPaths.value.splice(openIndex, 0, workflow.path);
    }
  }, "attachWorkflow");
  const activeWorkflow = ref(null);
  const isActive2 = /* @__PURE__ */ __name((workflow) => activeWorkflow.value?.path === workflow.path, "isActive");
  const workflowLookup = ref({});
  const workflows = computed(
    () => Object.values(workflowLookup.value)
  );
  const getWorkflowByPath = /* @__PURE__ */ __name((path) => workflowLookup.value[path] ?? null, "getWorkflowByPath");
  const openWorkflowPaths = ref([]);
  const openWorkflowPathSet = computed(() => new Set(openWorkflowPaths.value));
  const openWorkflows = computed(
    () => openWorkflowPaths.value.map((path) => workflowLookup.value[path])
  );
  const reorderWorkflows = /* @__PURE__ */ __name((from2, to) => {
    const movedTab = openWorkflowPaths.value[from2];
    openWorkflowPaths.value.splice(from2, 1);
    openWorkflowPaths.value.splice(to, 0, movedTab);
  }, "reorderWorkflows");
  const isOpen = /* @__PURE__ */ __name((workflow) => openWorkflowPathSet.value.has(workflow.path), "isOpen");
  const openWorkflowsInBackground = /* @__PURE__ */ __name((paths) => {
    const { left = [], right = [] } = paths;
    if (!left.length && !right.length) return;
    const isValidPath = /* @__PURE__ */ __name((path) => typeof path === "string" && path in workflowLookup.value, "isValidPath");
    openWorkflowPaths.value = _.union(
      left,
      openWorkflowPaths.value,
      right
    ).filter(isValidPath);
  }, "openWorkflowsInBackground");
  const openWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    if (isActive2(workflow)) return workflow;
    if (!openWorkflowPaths.value.includes(workflow.path)) {
      openWorkflowPaths.value.push(workflow.path);
    }
    const loadedWorkflow = await workflow.load();
    activeWorkflow.value = loadedWorkflow;
    console.debug("[workflowStore] open workflow", workflow.path);
    return loadedWorkflow;
  }, "openWorkflow");
  const getUnconflictedPath = /* @__PURE__ */ __name((basePath2) => {
    const { directory, filename, suffix: suffix2 } = getPathDetails(basePath2);
    let counter = 2;
    let newPath = basePath2;
    while (workflowLookup.value[newPath]) {
      newPath = `${directory}/${filename} (${counter}).${suffix2}`;
      counter++;
    }
    return newPath;
  }, "getUnconflictedPath");
  const createTemporary = /* @__PURE__ */ __name((path, workflowData) => {
    const fullPath = getUnconflictedPath(
      ComfyWorkflow.basePath + (path ?? "Unsaved Workflow.json")
    );
    const workflow = new ComfyWorkflow({
      path: fullPath,
      modified: Date.now(),
      size: -1
    });
    workflow.originalContent = workflow.content = workflowData ? JSON.stringify(workflowData) : defaultGraphJSON;
    workflowLookup.value[workflow.path] = workflow;
    return workflow;
  }, "createTemporary");
  const closeWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    openWorkflowPaths.value = openWorkflowPaths.value.filter(
      (path) => path !== workflow.path
    );
    if (workflow.isTemporary) {
      delete workflowLookup.value[workflow.path];
    } else {
      workflow.unload();
    }
    console.debug("[workflowStore] close workflow", workflow.path);
  }, "closeWorkflow");
  const openedWorkflowIndexShift = /* @__PURE__ */ __name((shift2) => {
    const index2 = openWorkflowPaths.value.indexOf(
      activeWorkflow.value?.path ?? ""
    );
    if (index2 !== -1) {
      const length = openWorkflows.value.length;
      const nextIndex = (index2 + shift2 + length) % length;
      const nextWorkflow = openWorkflows.value[nextIndex];
      return nextWorkflow ?? null;
    }
    return null;
  }, "openedWorkflowIndexShift");
  const persistedWorkflows = computed(
    () => Array.from(workflows.value).filter((workflow) => workflow.isPersisted)
  );
  const syncWorkflows = /* @__PURE__ */ __name(async (dir = "") => {
    await syncEntities(
      dir ? "workflows/" + dir : "workflows",
      workflowLookup.value,
      (file) => new ComfyWorkflow({
        path: file.path,
        modified: file.modified,
        size: file.size
      }),
      (existingWorkflow, file) => {
        existingWorkflow.lastModified = file.modified;
        existingWorkflow.size = file.size;
        existingWorkflow.unload();
      },
      /* exclude */
      (workflow) => workflow.isTemporary
    );
  }, "syncWorkflows");
  const bookmarkStore = useWorkflowBookmarkStore();
  const bookmarkedWorkflows = computed(
    () => workflows.value.filter(
      (workflow) => bookmarkStore.isBookmarked(workflow.path)
    )
  );
  const modifiedWorkflows = computed(
    () => workflows.value.filter((workflow) => workflow.isModified)
  );
  const isBusy = ref(false);
  const renameWorkflow = /* @__PURE__ */ __name(async (workflow, newPath) => {
    isBusy.value = true;
    try {
      const oldPath = workflow.path;
      const wasBookmarked = bookmarkStore.isBookmarked(oldPath);
      const openIndex = detachWorkflow(workflow);
      try {
        await workflow.rename(newPath);
      } finally {
        attachWorkflow(workflow, openIndex);
      }
      if (wasBookmarked) {
        bookmarkStore.setBookmarked(oldPath, false);
        bookmarkStore.setBookmarked(newPath, true);
      }
    } finally {
      isBusy.value = false;
    }
  }, "renameWorkflow");
  const deleteWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    isBusy.value = true;
    try {
      await workflow.delete();
      if (bookmarkStore.isBookmarked(workflow.path)) {
        bookmarkStore.setBookmarked(workflow.path, false);
      }
      delete workflowLookup.value[workflow.path];
    } finally {
      isBusy.value = false;
    }
  }, "deleteWorkflow");
  const saveWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    isBusy.value = true;
    try {
      const openIndex = detachWorkflow(workflow);
      try {
        await workflow.save();
      } finally {
        attachWorkflow(workflow, openIndex);
      }
    } finally {
      isBusy.value = false;
    }
  }, "saveWorkflow");
  return {
    activeWorkflow,
    isActive: isActive2,
    openWorkflows,
    openedWorkflowIndexShift,
    openWorkflow,
    openWorkflowsInBackground,
    isOpen,
    isBusy,
    closeWorkflow,
    createTemporary,
    renameWorkflow,
    deleteWorkflow,
    saveWorkflow,
    reorderWorkflows,
    workflows,
    bookmarkedWorkflows,
    persistedWorkflows,
    modifiedWorkflows,
    getWorkflowByPath,
    syncWorkflows
  };
});
const useWorkflowBookmarkStore = /* @__PURE__ */ defineStore("workflowBookmark", () => {
  const bookmarks = ref(/* @__PURE__ */ new Set());
  const isBookmarked = /* @__PURE__ */ __name((path) => bookmarks.value.has(path), "isBookmarked");
  const loadBookmarks = /* @__PURE__ */ __name(async () => {
    const resp = await api.getUserData("workflows/.index.json");
    if (resp.status === 200) {
      const info = await resp.json();
      bookmarks.value = new Set(info?.favorites ?? []);
    }
  }, "loadBookmarks");
  const saveBookmarks = /* @__PURE__ */ __name(async () => {
    await api.storeUserData("workflows/.index.json", {
      favorites: Array.from(bookmarks.value)
    });
  }, "saveBookmarks");
  const setBookmarked = /* @__PURE__ */ __name((path, value3) => {
    if (bookmarks.value.has(path) === value3) return;
    if (value3) {
      bookmarks.value.add(path);
    } else {
      bookmarks.value.delete(path);
    }
    saveBookmarks();
  }, "setBookmarked");
  const toggleBookmarked = /* @__PURE__ */ __name((path) => {
    setBookmarked(path, !bookmarks.value.has(path));
  }, "toggleBookmarked");
  return {
    isBookmarked,
    loadBookmarks,
    saveBookmarks,
    setBookmarked,
    toggleBookmarked
  };
});
const useWorkflowService = /* @__PURE__ */ __name(() => {
  const settingStore = useSettingStore();
  const workflowStore = useWorkflowStore();
  const toastStore = useToastStore();
  const dialogService = useDialogService();
  async function getFilename(defaultName) {
    if (settingStore.get("Comfy.PromptFilename")) {
      let filename = await dialogService.prompt({
        title: t("workflowService.exportWorkflow"),
        message: t("workflowService.enterFilename") + ":",
        defaultValue: defaultName
      });
      if (!filename) return null;
      if (!filename.toLowerCase().endsWith(".json")) {
        filename += ".json";
      }
      return filename;
    }
    return defaultName;
  }
  __name(getFilename, "getFilename");
  const exportWorkflow = /* @__PURE__ */ __name(async (filename, promptProperty) => {
    const workflow = workflowStore.activeWorkflow;
    if (workflow?.path) {
      filename = workflow.filename;
    }
    const p2 = await app$2.graphToPrompt();
    const json = JSON.stringify(p2[promptProperty], null, 2);
    const blob = new Blob([json], { type: "application/json" });
    const file = await getFilename(filename);
    if (!file) return;
    downloadBlob(file, blob);
  }, "exportWorkflow");
  const saveWorkflowAs = /* @__PURE__ */ __name(async (workflow) => {
    const newFilename = await dialogService.prompt({
      title: t("workflowService.saveWorkflow"),
      message: t("workflowService.enterFilename") + ":",
      defaultValue: workflow.filename
    });
    if (!newFilename) return;
    const newPath = workflow.directory + "/" + appendJsonExt(newFilename);
    const newKey = newPath.substring(ComfyWorkflow.basePath.length);
    const existingWorkflow = workflowStore.getWorkflowByPath(newPath);
    if (existingWorkflow && !existingWorkflow.isTemporary) {
      const res = await dialogService.confirm({
        title: t("sideToolbar.workflowTab.confirmOverwriteTitle"),
        type: "overwrite",
        message: t("sideToolbar.workflowTab.confirmOverwrite"),
        itemList: [newPath]
      });
      if (res !== true) return;
      if (existingWorkflow.path === workflow.path) {
        await saveWorkflow(workflow);
        return;
      }
      const deleted = await deleteWorkflow(existingWorkflow, true);
      if (!deleted) return;
    }
    if (workflow.isTemporary) {
      await renameWorkflow(workflow, newPath);
      await workflowStore.saveWorkflow(workflow);
    } else {
      const tempWorkflow = workflowStore.createTemporary(
        newKey,
        workflow.activeState
      );
      await openWorkflow(tempWorkflow);
      await workflowStore.saveWorkflow(tempWorkflow);
    }
  }, "saveWorkflowAs");
  const saveWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    if (workflow.isTemporary) {
      await saveWorkflowAs(workflow);
    } else {
      await workflowStore.saveWorkflow(workflow);
    }
  }, "saveWorkflow");
  const loadDefaultWorkflow = /* @__PURE__ */ __name(async () => {
    await app$2.loadGraphData(defaultGraph);
  }, "loadDefaultWorkflow");
  const loadBlankWorkflow = /* @__PURE__ */ __name(async () => {
    await app$2.loadGraphData(blankGraph);
  }, "loadBlankWorkflow");
  const reloadCurrentWorkflow = /* @__PURE__ */ __name(async () => {
    const workflow = workflowStore.activeWorkflow;
    if (workflow) {
      await openWorkflow(workflow, { force: true });
    }
  }, "reloadCurrentWorkflow");
  const openWorkflow = /* @__PURE__ */ __name(async (workflow, options5 = { force: false }) => {
    if (workflowStore.isActive(workflow) && !options5.force) return;
    const loadFromRemote = !workflow.isLoaded;
    if (loadFromRemote) {
      await workflow.load();
    }
    await app$2.loadGraphData(
      toRaw(workflow.activeState),
      /* clean=*/
      true,
      /* restore_view=*/
      true,
      workflow,
      {
        showMissingModelsDialog: loadFromRemote,
        showMissingNodesDialog: loadFromRemote
      }
    );
  }, "openWorkflow");
  const closeWorkflow = /* @__PURE__ */ __name(async (workflow, options5 = {
    warnIfUnsaved: true
  }) => {
    if (workflow.isModified && options5.warnIfUnsaved) {
      const confirmed = await dialogService.confirm({
        title: t("sideToolbar.workflowTab.dirtyCloseTitle"),
        type: "dirtyClose",
        message: t("sideToolbar.workflowTab.dirtyClose"),
        itemList: [workflow.path],
        hint: options5.hint
      });
      if (confirmed === null) return false;
      if (confirmed === true) {
        await saveWorkflow(workflow);
      }
    }
    if (workflowStore.openWorkflows.length === 1) {
      await loadDefaultWorkflow();
    }
    if (workflowStore.isActive(workflow)) {
      await loadNextOpenedWorkflow();
    }
    await workflowStore.closeWorkflow(workflow);
    return true;
  }, "closeWorkflow");
  const renameWorkflow = /* @__PURE__ */ __name(async (workflow, newPath) => {
    await workflowStore.renameWorkflow(workflow, newPath);
  }, "renameWorkflow");
  const deleteWorkflow = /* @__PURE__ */ __name(async (workflow, silent = false) => {
    const bypassConfirm = !settingStore.get("Comfy.Workflow.ConfirmDelete");
    let confirmed = bypassConfirm || silent;
    if (!confirmed) {
      confirmed = await dialogService.confirm({
        title: t("sideToolbar.workflowTab.confirmDeleteTitle"),
        type: "delete",
        message: t("sideToolbar.workflowTab.confirmDelete"),
        itemList: [workflow.path]
      });
      if (!confirmed) return false;
    }
    if (workflowStore.isOpen(workflow)) {
      const closed = await closeWorkflow(workflow, {
        warnIfUnsaved: !confirmed
      });
      if (!closed) return false;
    }
    await workflowStore.deleteWorkflow(workflow);
    if (!silent) {
      toastStore.add({
        severity: "info",
        summary: t("sideToolbar.workflowTab.deleted"),
        life: 1e3
      });
    }
    return true;
  }, "deleteWorkflow");
  const beforeLoadNewGraph = /* @__PURE__ */ __name(() => {
    const workflowStore2 = useWorkspaceStore().workflow;
    const activeWorkflow = workflowStore2.activeWorkflow;
    if (activeWorkflow) {
      activeWorkflow.changeTracker.store();
    }
  }, "beforeLoadNewGraph");
  const afterLoadNewGraph = /* @__PURE__ */ __name(async (value3, workflowData) => {
    const workflowStore2 = useWorkspaceStore().workflow;
    if (typeof value3 === "string") {
      const workflow = workflowStore2.getWorkflowByPath(
        ComfyWorkflow.basePath + appendJsonExt(value3)
      );
      if (workflow?.isPersisted) {
        const loadedWorkflow2 = await workflowStore2.openWorkflow(workflow);
        loadedWorkflow2.changeTracker.restore();
        loadedWorkflow2.changeTracker.reset(workflowData);
        return;
      }
    }
    if (value3 === null || typeof value3 === "string") {
      const path = value3;
      const tempWorkflow = workflowStore2.createTemporary(
        path ? appendJsonExt(path) : void 0,
        workflowData
      );
      await workflowStore2.openWorkflow(tempWorkflow);
      return;
    }
    const loadedWorkflow = await workflowStore2.openWorkflow(value3);
    loadedWorkflow.changeTracker.reset(workflowData);
    loadedWorkflow.changeTracker.restore();
  }, "afterLoadNewGraph");
  const insertWorkflow = /* @__PURE__ */ __name(async (workflow, options5 = {}) => {
    const loadedWorkflow = await workflow.load();
    const data30 = loadedWorkflow.initialState;
    const old = localStorage.getItem("litegrapheditor_clipboard");
    const graph = new LGraph(data30);
    const canvasElement = document.createElement("canvas");
    const canvas2 = new LGraphCanvas(canvasElement, graph, {
      skip_events: true,
      skip_render: true
    });
    canvas2.reroutesEnabled = true;
    canvas2.selectItems();
    canvas2.copyToClipboard();
    app$2.canvas.pasteFromClipboard(options5);
    if (old !== null) {
      localStorage.setItem("litegrapheditor_clipboard", old);
    }
  }, "insertWorkflow");
  const loadNextOpenedWorkflow = /* @__PURE__ */ __name(async () => {
    const nextWorkflow = workflowStore.openedWorkflowIndexShift(1);
    if (nextWorkflow) {
      await openWorkflow(nextWorkflow);
    }
  }, "loadNextOpenedWorkflow");
  const loadPreviousOpenedWorkflow = /* @__PURE__ */ __name(async () => {
    const previousWorkflow = workflowStore.openedWorkflowIndexShift(-1);
    if (previousWorkflow) {
      await openWorkflow(previousWorkflow);
    }
  }, "loadPreviousOpenedWorkflow");
  const duplicateWorkflow = /* @__PURE__ */ __name(async (workflow) => {
    const state = JSON.parse(JSON.stringify(workflow.activeState));
    const suffix2 = workflow.isPersisted ? " (Copy)" : "";
    const filename = workflow.filename.replace(/\s*\(\d+\)$/, "") + suffix2;
    await app$2.loadGraphData(state, true, true, filename);
  }, "duplicateWorkflow");
  return {
    exportWorkflow,
    saveWorkflowAs,
    saveWorkflow,
    loadDefaultWorkflow,
    loadBlankWorkflow,
    reloadCurrentWorkflow,
    openWorkflow,
    closeWorkflow,
    renameWorkflow,
    deleteWorkflow,
    insertWorkflow,
    loadNextOpenedWorkflow,
    loadPreviousOpenedWorkflow,
    duplicateWorkflow,
    afterLoadNewGraph,
    beforeLoadNewGraph
  };
}, "useWorkflowService");
function _findInMetadata(metadata, ...keys2) {
  for (const key of keys2) {
    if (key in metadata) {
      return metadata[key];
    }
    for (const k2 in metadata) {
      if (k2.endsWith(key)) {
        return metadata[k2];
      }
    }
  }
  return null;
}
__name(_findInMetadata, "_findInMetadata");
class ComfyModelDef {
  static {
    __name(this, "ComfyModelDef");
  }
  /** Path to the model */
  path_index;
  /** Proper filename of the model */
  file_name;
  /** Normalized filename of the model, with all backslashes replaced with forward slashes */
  normalized_file_name;
  /** Directory containing the model, eg 'checkpoints' */
  directory;
  /** Simplified copy of name, used as a default title. Excludes the directory and the '.safetensors' file extension */
  simplified_file_name;
  /** Key for the model, used to uniquely identify the model. */
  key;
  /** Title / display name of the model, sometimes same as the name but not always */
  title;
  /** Metadata: architecture ID for the model, such as 'stable-diffusion-xl-v1-base' */
  architecture_id = "";
  /** Metadata: author of the model */
  author = "";
  /** Metadata: resolution of the model, eg '1024x1024' */
  resolution = "";
  /** Metadata: description of the model */
  description = "";
  /** Metadata: usage hint for the model */
  usage_hint = "";
  /** Metadata: trigger phrase for the model */
  trigger_phrase = "";
  /** Metadata: tags list for the model */
  tags = [];
  /** Metadata: image for the model */
  image = "";
  /** Whether the model metadata has been loaded from the server, used for `load()` */
  has_loaded_metadata = false;
  /** If true, a metadata load request has been triggered, but may or may not yet have finished loading */
  is_load_requested = false;
  /** A string full of auto-computed lowercase-only searchable text for this model */
  searchable = "";
  constructor(name2, directory, pathIndex) {
    this.path_index = pathIndex;
    this.file_name = name2;
    this.normalized_file_name = name2.replaceAll("\\", "/");
    this.simplified_file_name = this.normalized_file_name.split("/").pop() ?? "";
    if (this.simplified_file_name.endsWith(".safetensors")) {
      this.simplified_file_name = this.simplified_file_name.slice(
        0,
        -".safetensors".length
      );
    }
    this.title = this.simplified_file_name;
    this.directory = directory;
    this.key = `${directory}/${this.normalized_file_name}`;
    this.updateSearchable();
  }
  updateSearchable() {
    this.searchable = [
      this.file_name,
      this.title,
      this.author,
      this.description,
      this.trigger_phrase,
      this.tags.join(", ")
    ].join("\n").toLowerCase();
  }
  /** Loads the model metadata from the server, filling in this object if data is available */
  async load() {
    if (this.has_loaded_metadata || this.is_load_requested) {
      return;
    }
    this.is_load_requested = true;
    try {
      const metadata = await api.viewMetadata(this.directory, this.file_name);
      if (!metadata) {
        return;
      }
      this.title = _findInMetadata(
        metadata,
        "modelspec.title",
        "title",
        "display_name",
        "name"
      ) || this.title;
      this.architecture_id = _findInMetadata(metadata, "modelspec.architecture", "architecture") || "";
      this.author = _findInMetadata(metadata, "modelspec.author", "author") || "";
      this.description = _findInMetadata(metadata, "modelspec.description", "description") || "";
      this.resolution = _findInMetadata(metadata, "modelspec.resolution", "resolution") || "";
      this.usage_hint = _findInMetadata(metadata, "modelspec.usage_hint", "usage_hint") || "";
      this.trigger_phrase = _findInMetadata(
        metadata,
        "modelspec.trigger_phrase",
        "trigger_phrase"
      ) || "";
      this.image = _findInMetadata(
        metadata,
        "modelspec.thumbnail",
        "thumbnail",
        "image",
        "icon"
      ) || "";
      const tagsCommaSeparated = _findInMetadata(metadata, "modelspec.tags", "tags") || "";
      this.tags = tagsCommaSeparated.split(",").map((tag) => tag.trim());
      this.has_loaded_metadata = true;
      this.updateSearchable();
    } catch (error2) {
      console.error("Error loading model metadata", this.file_name, this, error2);
    }
  }
}
var ResourceState = /* @__PURE__ */ ((ResourceState2) => {
  ResourceState2[ResourceState2["Uninitialized"] = 0] = "Uninitialized";
  ResourceState2[ResourceState2["Loading"] = 1] = "Loading";
  ResourceState2[ResourceState2["Loaded"] = 2] = "Loaded";
  return ResourceState2;
})(ResourceState || {});
class ModelFolder {
  static {
    __name(this, "ModelFolder");
  }
  constructor(directory) {
    this.directory = directory;
  }
  /** Models in this folder */
  models = {};
  state = 0;
  get key() {
    return this.directory + "/";
  }
  /**
   * Loads the models in this folder from the server
   */
  async load() {
    if (this.state !== 0) {
      return this;
    }
    this.state = 1;
    const models = await api.getModels(this.directory);
    for (const model of models) {
      this.models[`${model.pathIndex}/${model.name}`] = new ComfyModelDef(
        model.name,
        this.directory,
        model.pathIndex
      );
    }
    this.state = 2;
    return this;
  }
}
const useModelStore = /* @__PURE__ */ defineStore("models", () => {
  const modelFolderNames = ref([]);
  const modelFolderByName = ref({});
  const modelFolders = computed(
    () => modelFolderNames.value.map(
      (folderName) => modelFolderByName.value[folderName]
    )
  );
  const models = computed(
    () => modelFolders.value.flatMap((folder) => Object.values(folder.models))
  );
  async function loadModelFolders() {
    const resData = await api.getModelFolders();
    modelFolderNames.value = resData.map((folder) => folder.name);
    modelFolderByName.value = {};
    for (const folderName of modelFolderNames.value) {
      modelFolderByName.value[folderName] = new ModelFolder(folderName);
    }
  }
  __name(loadModelFolders, "loadModelFolders");
  async function getLoadedModelFolder(folderName) {
    const folder = modelFolderByName.value[folderName];
    return folder ? await folder.load() : null;
  }
  __name(getLoadedModelFolder, "getLoadedModelFolder");
  async function loadModels() {
    return Promise.all(modelFolders.value.map((folder) => folder.load()));
  }
  __name(loadModels, "loadModels");
  return {
    models,
    modelFolders,
    loadModelFolders,
    loadModels,
    getLoadedModelFolder
  };
});
function rgbToHsl({ r: r2, g: g2, b: b2 }) {
  r2 /= 255;
  g2 /= 255;
  b2 /= 255;
  const max = Math.max(r2, g2, b2), min = Math.min(r2, g2, b2);
  let h2 = 0, s2 = 0;
  const l2 = (max + min) / 2;
  if (max !== min) {
    const d2 = max - min;
    s2 = l2 > 0.5 ? d2 / (2 - max - min) : d2 / (max + min);
    switch (max) {
      case r2:
        h2 = (g2 - b2) / d2 + (g2 < b2 ? 6 : 0);
        break;
      case g2:
        h2 = (b2 - r2) / d2 + 2;
        break;
      case b2:
        h2 = (r2 - g2) / d2 + 4;
        break;
    }
    h2 /= 6;
  }
  return { h: h2, s: s2, l: l2 };
}
__name(rgbToHsl, "rgbToHsl");
function hexToRgb(hex) {
  let r2 = 0, g2 = 0, b2 = 0;
  if (hex.length == 4) {
    r2 = parseInt(hex[1] + hex[1], 16);
    g2 = parseInt(hex[2] + hex[2], 16);
    b2 = parseInt(hex[3] + hex[3], 16);
  } else if (hex.length == 7) {
    r2 = parseInt(hex.slice(1, 3), 16);
    g2 = parseInt(hex.slice(3, 5), 16);
    b2 = parseInt(hex.slice(5, 7), 16);
  }
  return { r: r2, g: g2, b: b2 };
}
__name(hexToRgb, "hexToRgb");
const identifyColorFormat = /* @__PURE__ */ __name((color2) => {
  if (!color2) return null;
  if (color2.startsWith("#") && (color2.length === 4 || color2.length === 7))
    return "hex";
  if (/rgba?\(\s*\d+\s*,\s*\d+\s*,\s*\d+\s*/.test(color2))
    return color2.includes("rgba") ? "rgba" : "rgb";
  if (/hsla?\(\s*\d+(\.\d+)?\s*,\s*\d+(\.\d+)?%\s*,\s*\d+(\.\d+)?%/.test(color2))
    return color2.includes("hsla") ? "hsla" : "hsl";
  return null;
}, "identifyColorFormat");
const isHSLA = /* @__PURE__ */ __name((color2) => {
  if (typeof color2 !== "object" || color2 === null) return false;
  return ["h", "s", "l", "a"].every(
    (key) => typeof color2[key] === "number" && !isNaN(color2[key])
  );
}, "isHSLA");
function parseToHSLA(color2, format2) {
  let match2;
  switch (format2) {
    case "hex": {
      const hsl = rgbToHsl(hexToRgb(color2));
      return {
        h: Math.round(hsl.h * 360),
        s: +(hsl.s * 100).toFixed(1),
        l: +(hsl.l * 100).toFixed(1),
        a: 1
      };
    }
    case "rgb":
    case "rgba": {
      match2 = color2.match(/\d+(\.\d+)?/g);
      if (!match2 || match2.length < 3) return null;
      const [r2, g2, b2] = match2.map(Number);
      const hsl = rgbToHsl({ r: r2, g: g2, b: b2 });
      const a2 = format2 === "rgba" && match2[3] ? parseFloat(match2[3]) : 1;
      return {
        h: Math.round(hsl.h * 360),
        s: +(hsl.s * 100).toFixed(1),
        l: +(hsl.l * 100).toFixed(1),
        a: a2
      };
    }
    case "hsl":
    case "hsla": {
      match2 = color2.match(/\d+(\.\d+)?/g);
      if (!match2 || match2.length < 3) return null;
      const [h2, s2, l2] = match2.map(Number);
      const a2 = format2 === "hsla" && match2[3] ? parseFloat(match2[3]) : 1;
      return { h: h2, s: s2, l: l2, a: a2 };
    }
    default:
      return null;
  }
}
__name(parseToHSLA, "parseToHSLA");
const applyColorAdjustments = /* @__PURE__ */ __name((color2, options5) => {
  if (!Object.keys(options5).length) return color2;
  const format2 = identifyColorFormat(color2);
  if (!format2) {
    console.warn(`Unsupported color format in color palette: ${color2}`);
    return color2;
  }
  const hsla = parseToHSLA(color2, format2);
  if (!isHSLA(hsla)) {
    console.warn(`Invalid color values in color palette: ${color2}`);
    return color2;
  }
  if (options5.lightness) {
    hsla.l = Math.max(0, Math.min(100, hsla.l + options5.lightness * 100));
  }
  if (options5.opacity) {
    hsla.a = Math.max(0, Math.min(1, options5.opacity));
  }
  return `hsla(${hsla.h}, ${hsla.s}%, ${hsla.l}%, ${hsla.a})`;
}, "applyColorAdjustments");
const adjustColor = lodashExports.memoize(
  applyColorAdjustments,
  (color2, options5) => `${color2}-${JSON.stringify(options5)}`
);
const graphToPrompt = /* @__PURE__ */ __name(async (graph, options5 = {}) => {
  const { sortNodes = false } = options5;
  for (const node3 of graph.computeExecutionOrder(false)) {
    const innerNodes = node3.getInnerNodes ? node3.getInnerNodes() : [node3];
    for (const innerNode of innerNodes) {
      if (innerNode.isVirtualNode) {
        innerNode.applyToGraph?.();
      }
    }
  }
  const workflow = graph.serialize({ sortNodes });
  for (const node3 of workflow.nodes) {
    for (const slot of node3.inputs ?? []) {
      delete slot.localized_name;
    }
    for (const slot of node3.outputs ?? []) {
      delete slot.localized_name;
    }
  }
  const output = {};
  for (const outerNode of graph.computeExecutionOrder(false)) {
    const skipNode = outerNode.mode === LGraphEventMode.NEVER || outerNode.mode === LGraphEventMode.BYPASS;
    const innerNodes = !skipNode && outerNode.getInnerNodes ? outerNode.getInnerNodes() : [outerNode];
    for (const node3 of innerNodes) {
      if (node3.isVirtualNode || // Don't serialize muted nodes
      node3.mode === LGraphEventMode.NEVER || node3.mode === LGraphEventMode.BYPASS) {
        continue;
      }
      const inputs = {};
      const { widgets } = node3;
      if (widgets) {
        for (const [i2, widget] of widgets.entries()) {
          if (!widget.name || widget.options?.serialize === false) continue;
          const widgetValue = widget.serializeValue ? await widget.serializeValue(node3, i2) : widget.value;
          inputs[widget.name] = Array.isArray(widgetValue) ? {
            __value__: widgetValue
          } : widgetValue;
        }
      }
      for (const [i2, input] of node3.inputs.entries()) {
        let parent = node3.getInputNode(i2);
        if (!parent) continue;
        let link2 = node3.getInputLink(i2);
        while (parent?.mode === LGraphEventMode.BYPASS || parent?.isVirtualNode) {
          if (!link2) break;
          if (parent.isVirtualNode) {
            link2 = parent.getInputLink(link2.origin_slot);
            if (!link2) break;
            parent = parent.getInputNode(link2.target_slot);
            if (!parent) break;
          } else if (!parent.inputs) {
            break;
          } else if (parent.mode === LGraphEventMode.BYPASS) {
            const parentInputIndexes = Object.keys(parent.inputs).map(Number);
            const indexes = [link2.origin_slot].concat(parentInputIndexes);
            const matchingIndex = indexes.find(
              (index2) => parent?.inputs[index2]?.type === input.type
            );
            if (matchingIndex === void 0) break;
            link2 = parent.getInputLink(matchingIndex);
            if (link2) parent = parent.getInputNode(matchingIndex);
          }
        }
        if (link2) {
          if (parent?.updateLink) {
            link2 = parent.updateLink(link2);
          }
          if (link2) {
            inputs[input.name] = [
              String(link2.origin_id),
              // @ts-expect-error link.origin_slot is already number.
              parseInt(link2.origin_slot)
            ];
          }
        }
      }
      output[String(node3.id)] = {
        inputs,
        // TODO(huchenlei): Filter out all nodes that cannot be mapped to a
        // comfyClass.
        class_type: node3.comfyClass,
        // Ignored by the backend.
        _meta: {
          title: node3.title
        }
      };
    }
  }
  for (const { inputs } of Object.values(output)) {
    for (const [i2, input] of Object.entries(inputs)) {
      if (Array.isArray(input) && input.length === 2 && !output[input[0]]) {
        delete inputs[i2];
      }
    }
  }
  return { workflow, output };
}, "graphToPrompt");
function serialise(nodes, graph) {
  const serialisable = {
    nodes: [],
    links: []
  };
  let index2 = 0;
  const cloneable = [];
  for (const node3 of nodes) {
    if (node3.clonable === false) continue;
    node3._relative_id = index2++;
    cloneable.push(node3);
  }
  for (const node3 of cloneable) {
    const cloned = node3.clone();
    if (!cloned) {
      console.warn("node type not found: " + node3.type);
      continue;
    }
    serialisable.nodes.push(cloned.serialize());
    if (!node3.inputs?.length) continue;
    for (const input of node3.inputs) {
      if (!input || input.link == null) continue;
      const link2 = graph.links.get(input.link);
      if (!link2) continue;
      const outNode = graph.getNodeById(link2.origin_id);
      if (!outNode) continue;
      serialisable.links.push([
        outNode._relative_id,
        link2.origin_slot,
        node3._relative_id,
        link2.target_slot,
        outNode.id
      ]);
    }
  }
  return JSON.stringify(serialisable);
}
__name(serialise, "serialise");
function deserialiseAndCreate(data30, canvas2) {
  if (!data30) return;
  const { graph, graph_mouse } = canvas2;
  canvas2.emitBeforeChange();
  try {
    graph.beforeChange();
    const deserialised = JSON.parse(data30);
    const topLeft = [Infinity, Infinity];
    for (const { pos } of deserialised.nodes) {
      if (topLeft[0] > pos[0]) topLeft[0] = pos[0];
      if (topLeft[1] > pos[1]) topLeft[1] = pos[1];
    }
    if (!Number.isFinite(topLeft[0]) || !Number.isFinite(topLeft[1])) {
      topLeft[0] = graph_mouse[0];
      topLeft[1] = graph_mouse[1];
    }
    const nodes = [];
    for (const info of deserialised.nodes) {
      const node3 = LiteGraph.createNode(info.type);
      if (!node3) continue;
      node3.configure(info);
      node3.pos[0] += graph_mouse[0] - topLeft[0];
      node3.pos[1] += graph_mouse[1] - topLeft[1];
      graph.add(node3, true);
      nodes.push(node3);
    }
    for (const info of deserialised.links) {
      const relativeId = info[0];
      const outNode = relativeId != null ? nodes[relativeId] : void 0;
      const inNode = nodes[info[2]];
      if (outNode && inNode) outNode.connect(info[1], inNode, info[3]);
      else console.warn("Warning, nodes missing on pasting");
    }
    canvas2.selectNodes(nodes);
    graph.afterChange();
  } finally {
    canvas2.emitAfterChange();
  }
}
__name(deserialiseAndCreate, "deserialiseAndCreate");
function getFromFlacBuffer(buffer2) {
  const dataView = new DataView(buffer2);
  const signature = String.fromCharCode(...new Uint8Array(buffer2, 0, 4));
  if (signature !== "fLaC") {
    console.error("Not a valid FLAC file");
    return;
  }
  let offset = 4;
  let vorbisComment = null;
  while (offset < dataView.byteLength) {
    const isLastBlock = dataView.getUint8(offset) & 128;
    const blockType = dataView.getUint8(offset) & 127;
    const blockSize = dataView.getUint32(offset, false) & 16777215;
    offset += 4;
    if (blockType === 4) {
      vorbisComment = parseVorbisComment(
        new DataView(buffer2, offset, blockSize)
      );
    }
    offset += blockSize;
    if (isLastBlock) break;
  }
  return vorbisComment;
}
__name(getFromFlacBuffer, "getFromFlacBuffer");
function getFromFlacFile(file) {
  return new Promise((r2) => {
    const reader = new FileReader();
    reader.onload = function(event) {
      const arrayBuffer = event.target.result;
      r2(getFromFlacBuffer(arrayBuffer));
    };
    reader.readAsArrayBuffer(file);
  });
}
__name(getFromFlacFile, "getFromFlacFile");
function parseVorbisComment(dataView) {
  let offset = 0;
  const vendorLength = dataView.getUint32(offset, true);
  offset += 4;
  const vendorString = getString(dataView, offset, vendorLength);
  offset += vendorLength;
  const userCommentListLength = dataView.getUint32(offset, true);
  offset += 4;
  const comments = {};
  for (let i2 = 0; i2 < userCommentListLength; i2++) {
    const commentLength = dataView.getUint32(offset, true);
    offset += 4;
    const comment2 = getString(dataView, offset, commentLength);
    offset += commentLength;
    const ind = comment2.indexOf("=");
    const key = comment2.substring(0, ind);
    comments[key] = comment2.substring(ind + 1);
  }
  return comments;
}
__name(parseVorbisComment, "parseVorbisComment");
function getString(dataView, offset, length) {
  let string = "";
  for (let i2 = 0; i2 < length; i2++) {
    string += String.fromCharCode(dataView.getUint8(offset + i2));
  }
  return string;
}
__name(getString, "getString");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.flac = window.comfyAPI.flac || {};
window.comfyAPI.flac.getFromFlacBuffer = getFromFlacBuffer;
window.comfyAPI.flac.getFromFlacFile = getFromFlacFile;
function getFromPngBuffer(buffer2) {
  const pngData = new Uint8Array(buffer2);
  const dataView = new DataView(pngData.buffer);
  if (dataView.getUint32(0) !== 2303741511) {
    console.error("Not a valid PNG file");
    return;
  }
  let offset = 8;
  let txt_chunks = {};
  while (offset < pngData.length) {
    const length = dataView.getUint32(offset);
    const type = String.fromCharCode(...pngData.slice(offset + 4, offset + 8));
    if (type === "tEXt" || type == "comf" || type === "iTXt") {
      let keyword_end = offset + 8;
      while (pngData[keyword_end] !== 0) {
        keyword_end++;
      }
      const keyword = String.fromCharCode(
        ...pngData.slice(offset + 8, keyword_end)
      );
      const contentArraySegment = pngData.slice(
        keyword_end + 1,
        offset + 8 + length
      );
      const contentJson = new TextDecoder("utf-8").decode(contentArraySegment);
      txt_chunks[keyword] = contentJson;
    }
    offset += 12 + length;
  }
  return txt_chunks;
}
__name(getFromPngBuffer, "getFromPngBuffer");
function getFromPngFile(file) {
  return new Promise((r2) => {
    const reader = new FileReader();
    reader.onload = (event) => {
      r2(getFromPngBuffer(event.target.result));
    };
    reader.readAsArrayBuffer(file);
  });
}
__name(getFromPngFile, "getFromPngFile");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.png = window.comfyAPI.png || {};
window.comfyAPI.png.getFromPngBuffer = getFromPngBuffer;
window.comfyAPI.png.getFromPngFile = getFromPngFile;
function getPngMetadata(file) {
  return getFromPngFile(file);
}
__name(getPngMetadata, "getPngMetadata");
function getFlacMetadata(file) {
  return getFromFlacFile(file);
}
__name(getFlacMetadata, "getFlacMetadata");
function parseExifData(exifData) {
  const isLittleEndian = String.fromCharCode(...exifData.slice(0, 2)) === "II";
  function readInt(offset, isLittleEndian2, length) {
    let arr = exifData.slice(offset, offset + length);
    if (length === 2) {
      return new DataView(arr.buffer, arr.byteOffset, arr.byteLength).getUint16(
        0,
        isLittleEndian2
      );
    } else if (length === 4) {
      return new DataView(arr.buffer, arr.byteOffset, arr.byteLength).getUint32(
        0,
        isLittleEndian2
      );
    }
  }
  __name(readInt, "readInt");
  const ifdOffset = readInt(4, isLittleEndian, 4);
  function parseIFD(offset) {
    const numEntries = readInt(offset, isLittleEndian, 2);
    const result = {};
    for (let i2 = 0; i2 < numEntries; i2++) {
      const entryOffset = offset + 2 + i2 * 12;
      const tag = readInt(entryOffset, isLittleEndian, 2);
      const type = readInt(entryOffset + 2, isLittleEndian, 2);
      const numValues = readInt(entryOffset + 4, isLittleEndian, 4);
      const valueOffset = readInt(entryOffset + 8, isLittleEndian, 4);
      let value3;
      if (type === 2) {
        value3 = new TextDecoder("utf-8").decode(
          // @ts-expect-error fixme ts strict error
          exifData.subarray(valueOffset, valueOffset + numValues - 1)
        );
      }
      result[tag] = value3;
    }
    return result;
  }
  __name(parseIFD, "parseIFD");
  const ifdData = parseIFD(ifdOffset);
  return ifdData;
}
__name(parseExifData, "parseExifData");
function getWebpMetadata(file) {
  return new Promise((r2) => {
    const reader = new FileReader();
    reader.onload = (event) => {
      const webp = new Uint8Array(event.target.result);
      const dataView = new DataView(webp.buffer);
      if (dataView.getUint32(0) !== 1380533830 || dataView.getUint32(8) !== 1464156752) {
        console.error("Not a valid WEBP file");
        r2({});
        return;
      }
      let offset = 12;
      let txt_chunks = {};
      while (offset < webp.length) {
        const chunk_length = dataView.getUint32(offset + 4, true);
        const chunk_type = String.fromCharCode(
          ...webp.slice(offset, offset + 4)
        );
        if (chunk_type === "EXIF") {
          if (String.fromCharCode(...webp.slice(offset + 8, offset + 8 + 6)) == "Exif\0\0") {
            offset += 6;
          }
          let data30 = parseExifData(
            webp.slice(offset + 8, offset + 8 + chunk_length)
          );
          for (var key in data30) {
            const value3 = data30[key];
            if (typeof value3 === "string") {
              const index2 = value3.indexOf(":");
              txt_chunks[value3.slice(0, index2)] = value3.slice(index2 + 1);
            }
          }
          break;
        }
        offset += 8 + chunk_length;
      }
      r2(txt_chunks);
    };
    reader.readAsArrayBuffer(file);
  });
}
__name(getWebpMetadata, "getWebpMetadata");
function getLatentMetadata(file) {
  return new Promise((r2) => {
    const reader = new FileReader();
    reader.onload = (event) => {
      const safetensorsData = new Uint8Array(event.target.result);
      const dataView = new DataView(safetensorsData.buffer);
      let header_size = dataView.getUint32(0, true);
      let offset = 8;
      let header3 = JSON.parse(
        new TextDecoder().decode(
          safetensorsData.slice(offset, offset + header_size)
        )
      );
      r2(header3.__metadata__);
    };
    var slice2 = file.slice(0, 1024 * 1024 * 4);
    reader.readAsArrayBuffer(slice2);
  });
}
__name(getLatentMetadata, "getLatentMetadata");
async function importA1111(graph, parameters) {
  const p2 = parameters.lastIndexOf("\nSteps:");
  if (p2 > -1) {
    const embeddings = await api.getEmbeddings();
    const opts = parameters.substr(p2).split("\n")[1].match(
      new RegExp('\\s*([^:]+:\\s*([^"\\{].*?|".*?"|\\{.*?\\}))\\s*(,|$)', "g")
    ).reduce((p3, n2) => {
      const s2 = n2.split(":");
      if (s2[1].endsWith(",")) {
        s2[1] = s2[1].substr(0, s2[1].length - 1);
      }
      p3[s2[0].trim().toLowerCase()] = s2[1].trim();
      return p3;
    }, {});
    const p22 = parameters.lastIndexOf("\nNegative prompt:", p2);
    if (p22 > -1) {
      let positive = parameters.substr(0, p22).trim();
      let negative = parameters.substring(p22 + 18, p2).trim();
      const ckptNode = LiteGraph.createNode("CheckpointLoaderSimple");
      const clipSkipNode = LiteGraph.createNode("CLIPSetLastLayer");
      const positiveNode = LiteGraph.createNode("CLIPTextEncode");
      const negativeNode = LiteGraph.createNode("CLIPTextEncode");
      const samplerNode = LiteGraph.createNode("KSampler");
      const imageNode = LiteGraph.createNode("EmptyLatentImage");
      const vaeNode = LiteGraph.createNode("VAEDecode");
      const saveNode = LiteGraph.createNode("SaveImage");
      let hrSamplerNode = null;
      let hrSteps = null;
      const ceil64 = /* @__PURE__ */ __name((v2) => Math.ceil(v2 / 64) * 64, "ceil64");
      const getWidget = /* @__PURE__ */ __name((node3, name2) => {
        return node3.widgets.find((w2) => w2.name === name2);
      }, "getWidget");
      const setWidgetValue = /* @__PURE__ */ __name((node3, name2, value3, isOptionPrefix) => {
        const w2 = getWidget(node3, name2);
        if (isOptionPrefix) {
          const o2 = w2.options.values.find((w22) => w22.startsWith(value3));
          if (o2) {
            w2.value = o2;
          } else {
            console.warn(`Unknown value '${value3}' for widget '${name2}'`, node3);
            w2.value = value3;
          }
        } else {
          w2.value = value3;
        }
      }, "setWidgetValue");
      const createLoraNodes = /* @__PURE__ */ __name((clipNode, text2, prevClip, prevModel) => {
        const loras = [];
        text2 = text2.replace(/<lora:([^:]+:[^>]+)>/g, function(m2, c2) {
          const s2 = c2.split(":");
          const weight = parseFloat(s2[1]);
          if (isNaN(weight)) {
            console.warn("Invalid LORA", m2);
          } else {
            loras.push({ name: s2[0], weight });
          }
          return "";
        });
        for (const l2 of loras) {
          const loraNode = LiteGraph.createNode("LoraLoader");
          graph.add(loraNode);
          setWidgetValue(loraNode, "lora_name", l2.name, true);
          setWidgetValue(loraNode, "strength_model", l2.weight);
          setWidgetValue(loraNode, "strength_clip", l2.weight);
          prevModel.node.connect(prevModel.index, loraNode, 0);
          prevClip.node.connect(prevClip.index, loraNode, 1);
          prevModel = { node: loraNode, index: 0 };
          prevClip = { node: loraNode, index: 1 };
        }
        prevClip.node.connect(1, clipNode, 0);
        prevModel.node.connect(0, samplerNode, 0);
        if (hrSamplerNode) {
          prevModel.node.connect(0, hrSamplerNode, 0);
        }
        return { text: text2, prevModel, prevClip };
      }, "createLoraNodes");
      const replaceEmbeddings = /* @__PURE__ */ __name((text2) => {
        if (!embeddings.length) return text2;
        return text2.replaceAll(
          new RegExp(
            "\\b(" + embeddings.map((e2) => e2.replace(/[.*+?^${}()|[\]\\]/g, "\\$&")).join("\\b|\\b") + ")\\b",
            "ig"
          ),
          "embedding:$1"
        );
      }, "replaceEmbeddings");
      const popOpt = /* @__PURE__ */ __name((name2) => {
        const v2 = opts[name2];
        delete opts[name2];
        return v2;
      }, "popOpt");
      graph.clear();
      graph.add(ckptNode);
      graph.add(clipSkipNode);
      graph.add(positiveNode);
      graph.add(negativeNode);
      graph.add(samplerNode);
      graph.add(imageNode);
      graph.add(vaeNode);
      graph.add(saveNode);
      ckptNode.connect(1, clipSkipNode, 0);
      clipSkipNode.connect(0, positiveNode, 0);
      clipSkipNode.connect(0, negativeNode, 0);
      ckptNode.connect(0, samplerNode, 0);
      positiveNode.connect(0, samplerNode, 1);
      negativeNode.connect(0, samplerNode, 2);
      imageNode.connect(0, samplerNode, 3);
      vaeNode.connect(0, saveNode, 0);
      samplerNode.connect(0, vaeNode, 0);
      ckptNode.connect(2, vaeNode, 1);
      const handlers2 = {
        // @ts-expect-error fixme ts strict error
        model(v2) {
          setWidgetValue(ckptNode, "ckpt_name", v2, true);
        },
        vae() {
        },
        // @ts-expect-error fixme ts strict error
        "cfg scale"(v2) {
          setWidgetValue(samplerNode, "cfg", +v2);
        },
        // @ts-expect-error fixme ts strict error
        "clip skip"(v2) {
          setWidgetValue(clipSkipNode, "stop_at_clip_layer", -v2);
        },
        // @ts-expect-error fixme ts strict error
        sampler(v2) {
          let name2 = v2.toLowerCase().replace("++", "pp").replaceAll(" ", "_");
          if (name2.includes("karras")) {
            name2 = name2.replace("karras", "").replace(/_+$/, "");
            setWidgetValue(samplerNode, "scheduler", "karras");
          } else {
            setWidgetValue(samplerNode, "scheduler", "normal");
          }
          const w2 = getWidget(samplerNode, "sampler_name");
          const o2 = w2.options.values.find(
            // @ts-expect-error fixme ts strict error
            (w22) => w22 === name2 || w22 === "sample_" + name2
          );
          if (o2) {
            setWidgetValue(samplerNode, "sampler_name", o2);
          }
        },
        // @ts-expect-error fixme ts strict error
        size(v2) {
          const wxh = v2.split("x");
          const w2 = ceil64(+wxh[0]);
          const h2 = ceil64(+wxh[1]);
          const hrUp = popOpt("hires upscale");
          const hrSz = popOpt("hires resize");
          hrSteps = popOpt("hires steps");
          let hrMethod = popOpt("hires upscaler");
          setWidgetValue(imageNode, "width", w2);
          setWidgetValue(imageNode, "height", h2);
          if (hrUp || hrSz) {
            let uw, uh;
            if (hrUp) {
              uw = w2 * hrUp;
              uh = h2 * hrUp;
            } else {
              const s2 = hrSz.split("x");
              uw = +s2[0];
              uh = +s2[1];
            }
            let upscaleNode;
            let latentNode;
            if (hrMethod.startsWith("Latent")) {
              latentNode = upscaleNode = LiteGraph.createNode("LatentUpscale");
              graph.add(upscaleNode);
              samplerNode.connect(0, upscaleNode, 0);
              switch (hrMethod) {
                case "Latent (nearest-exact)":
                  hrMethod = "nearest-exact";
                  break;
              }
              setWidgetValue(upscaleNode, "upscale_method", hrMethod, true);
            } else {
              const decode2 = LiteGraph.createNode("VAEDecodeTiled");
              graph.add(decode2);
              samplerNode.connect(0, decode2, 0);
              ckptNode.connect(2, decode2, 1);
              const upscaleLoaderNode = LiteGraph.createNode("UpscaleModelLoader");
              graph.add(upscaleLoaderNode);
              setWidgetValue(upscaleLoaderNode, "model_name", hrMethod, true);
              const modelUpscaleNode = LiteGraph.createNode(
                "ImageUpscaleWithModel"
              );
              graph.add(modelUpscaleNode);
              decode2.connect(0, modelUpscaleNode, 1);
              upscaleLoaderNode.connect(0, modelUpscaleNode, 0);
              upscaleNode = LiteGraph.createNode("ImageScale");
              graph.add(upscaleNode);
              modelUpscaleNode.connect(0, upscaleNode, 0);
              const vaeEncodeNode = latentNode = LiteGraph.createNode("VAEEncodeTiled");
              graph.add(vaeEncodeNode);
              upscaleNode.connect(0, vaeEncodeNode, 0);
              ckptNode.connect(2, vaeEncodeNode, 1);
            }
            setWidgetValue(upscaleNode, "width", ceil64(uw));
            setWidgetValue(upscaleNode, "height", ceil64(uh));
            hrSamplerNode = LiteGraph.createNode("KSampler");
            graph.add(hrSamplerNode);
            ckptNode.connect(0, hrSamplerNode, 0);
            positiveNode.connect(0, hrSamplerNode, 1);
            negativeNode.connect(0, hrSamplerNode, 2);
            latentNode.connect(0, hrSamplerNode, 3);
            hrSamplerNode.connect(0, vaeNode, 0);
          }
        },
        // @ts-expect-error fixme ts strict error
        steps(v2) {
          setWidgetValue(samplerNode, "steps", +v2);
        },
        // @ts-expect-error fixme ts strict error
        seed(v2) {
          setWidgetValue(samplerNode, "seed", +v2);
        }
      };
      for (const opt in opts) {
        if (opt in handlers2) {
          handlers2[opt](popOpt(opt));
        }
      }
      if (hrSamplerNode) {
        setWidgetValue(
          hrSamplerNode,
          "steps",
          hrSteps ? +hrSteps : getWidget(samplerNode, "steps").value
        );
        setWidgetValue(
          hrSamplerNode,
          "cfg",
          getWidget(samplerNode, "cfg").value
        );
        setWidgetValue(
          hrSamplerNode,
          "scheduler",
          getWidget(samplerNode, "scheduler").value
        );
        setWidgetValue(
          hrSamplerNode,
          "sampler_name",
          getWidget(samplerNode, "sampler_name").value
        );
        setWidgetValue(
          hrSamplerNode,
          "denoise",
          +(popOpt("denoising strength") || "1")
        );
      }
      let n2 = createLoraNodes(
        positiveNode,
        positive,
        { node: clipSkipNode, index: 0 },
        { node: ckptNode, index: 0 }
      );
      positive = n2.text;
      n2 = createLoraNodes(negativeNode, negative, n2.prevClip, n2.prevModel);
      negative = n2.text;
      setWidgetValue(positiveNode, "text", replaceEmbeddings(positive));
      setWidgetValue(negativeNode, "text", replaceEmbeddings(negative));
      graph.arrange();
      for (const opt of [
        "model hash",
        "ensd",
        "version",
        "vae hash",
        "ti hashes",
        "lora hashes",
        "hashes"
      ]) {
        delete opts[opt];
      }
      console.warn("Unhandled parameters:", opts);
    }
  }
}
__name(importA1111, "importA1111");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.pnginfo = window.comfyAPI.pnginfo || {};
window.comfyAPI.pnginfo.getPngMetadata = getPngMetadata;
window.comfyAPI.pnginfo.getFlacMetadata = getFlacMetadata;
window.comfyAPI.pnginfo.getWebpMetadata = getWebpMetadata;
window.comfyAPI.pnginfo.getLatentMetadata = getLatentMetadata;
window.comfyAPI.pnginfo.importA1111 = importA1111;
class ComfyButtonGroup {
  static {
    __name(this, "ComfyButtonGroup");
  }
  element = $el("div.comfyui-button-group");
  buttons;
  constructor(...buttons) {
    this.buttons = prop(this, "buttons", buttons, () => this.update());
  }
  insert(button, index2) {
    this.buttons.splice(index2, 0, button);
    this.update();
  }
  append(button) {
    this.buttons.push(button);
    this.update();
  }
  remove(indexOrButton) {
    if (typeof indexOrButton !== "number") {
      indexOrButton = this.buttons.indexOf(indexOrButton);
    }
    if (indexOrButton > -1) {
      const r2 = this.buttons.splice(indexOrButton, 1);
      this.update();
      return r2;
    }
  }
  update() {
    this.element.replaceChildren(...this.buttons.map((b2) => b2["element"] ?? b2));
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.buttonGroup = window.comfyAPI.buttonGroup || {};
window.comfyAPI.buttonGroup.ComfyButtonGroup = ComfyButtonGroup;
function applyClasses(element, classList, ...requiredClasses) {
  classList ??= "";
  let str;
  if (typeof classList === "string") {
    str = classList;
  } else if (classList instanceof Array) {
    str = classList.join(" ");
  } else {
    str = Object.entries(classList).reduce((p2, c2) => {
      if (c2[1]) {
        p2 += (p2.length ? " " : "") + c2[0];
      }
      return p2;
    }, "");
  }
  element.className = str;
  if (requiredClasses) {
    element.classList.add(...requiredClasses);
  }
}
__name(applyClasses, "applyClasses");
function toggleElement(element, {
  onHide: onHide3,
  onShow
} = {}) {
  let placeholder;
  let hidden;
  return (value3) => {
    if (value3) {
      if (hidden) {
        hidden = false;
        placeholder.replaceWith(element);
      }
      onShow?.(element, value3);
    } else {
      if (!placeholder) {
        placeholder = document.createComment("");
      }
      hidden = true;
      element.replaceWith(placeholder);
      onHide3?.(element);
    }
  };
}
__name(toggleElement, "toggleElement");
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.utils = window.comfyAPI.utils || {};
window.comfyAPI.utils.applyClasses = applyClasses;
window.comfyAPI.utils.toggleElement = toggleElement;
class ComfyButton {
  static {
    __name(this, "ComfyButton");
  }
  #over = 0;
  #popupOpen = false;
  isOver = false;
  iconElement = $el("i.mdi");
  contentElement = $el("span");
  // @ts-expect-error fixme ts strict error
  popup;
  element;
  overIcon;
  iconSize;
  content;
  icon;
  tooltip;
  classList;
  hidden;
  enabled;
  action;
  constructor({
    icon: icon3,
    overIcon,
    iconSize,
    content: content3,
    tooltip,
    action,
    classList = "comfyui-button",
    visibilitySetting,
    app: app2,
    enabled = true
  }) {
    this.element = $el(
      "button",
      {
        onmouseenter: /* @__PURE__ */ __name(() => {
          this.isOver = true;
          if (this.overIcon) {
            this.updateIcon();
          }
        }, "onmouseenter"),
        onmouseleave: /* @__PURE__ */ __name(() => {
          this.isOver = false;
          if (this.overIcon) {
            this.updateIcon();
          }
        }, "onmouseleave")
      },
      [this.iconElement, this.contentElement]
    );
    this.icon = prop(
      this,
      "icon",
      icon3,
      toggleElement(this.iconElement, { onShow: this.updateIcon })
    );
    this.overIcon = prop(this, "overIcon", overIcon, () => {
      if (this.isOver) {
        this.updateIcon();
      }
    });
    this.iconSize = prop(this, "iconSize", iconSize, this.updateIcon);
    this.content = prop(
      this,
      "content",
      content3,
      toggleElement(this.contentElement, {
        onShow: /* @__PURE__ */ __name((el, v2) => {
          if (typeof v2 === "string") {
            el.textContent = v2;
          } else {
            el.replaceChildren(v2);
          }
        }, "onShow")
      })
    );
    this.tooltip = prop(this, "tooltip", tooltip, (v2) => {
      if (v2) {
        this.element.title = v2;
      } else {
        this.element.removeAttribute("title");
      }
    });
    if (tooltip !== void 0) {
      this.element.setAttribute("aria-label", tooltip);
    }
    this.classList = prop(this, "classList", classList, this.updateClasses);
    this.hidden = prop(this, "hidden", false, this.updateClasses);
    this.enabled = prop(this, "enabled", enabled, () => {
      this.updateClasses();
      this.element.disabled = !this.enabled;
    });
    this.action = prop(this, "action", action);
    this.element.addEventListener("click", (e2) => {
      if (this.popup) {
        if (!this.#over) {
          this.popup.toggle();
        }
      }
      this.action?.(e2, this);
    });
    if (visibilitySetting?.id) {
      const settingUpdated = /* @__PURE__ */ __name(() => {
        this.hidden = // @ts-expect-error fixme ts strict error
        app2.ui.settings.getSettingValue(visibilitySetting.id) !== visibilitySetting.showValue;
      }, "settingUpdated");
      app2.ui.settings.addEventListener(
        visibilitySetting.id + ".change",
        settingUpdated
      );
      settingUpdated();
    }
  }
  updateIcon = /* @__PURE__ */ __name(() => this.iconElement.className = `mdi mdi-${this.isOver && this.overIcon || this.icon}${this.iconSize ? " mdi-" + this.iconSize + "px" : ""}`, "updateIcon");
  updateClasses = /* @__PURE__ */ __name(() => {
    const internalClasses = [];
    if (this.hidden) {
      internalClasses.push("hidden");
    }
    if (!this.enabled) {
      internalClasses.push("disabled");
    }
    if (this.popup) {
      if (this.#popupOpen) {
        internalClasses.push("popup-open");
      } else {
        internalClasses.push("popup-closed");
      }
    }
    applyClasses(this.element, this.classList, ...internalClasses);
  }, "updateClasses");
  withPopup(popup, mode2 = "click") {
    this.popup = popup;
    if (mode2 === "hover") {
      for (const el of [this.element, this.popup.element]) {
        el.addEventListener("mouseenter", () => {
          this.popup.open = !!++this.#over;
        });
        el.addEventListener("mouseleave", () => {
          this.popup.open = !!--this.#over;
        });
      }
    }
    popup.addEventListener("change", () => {
      this.#popupOpen = popup.open;
      this.updateClasses();
    });
    return this;
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.button = window.comfyAPI.button || {};
window.comfyAPI.button.ComfyButton = ComfyButton;
class ComfyPopup extends EventTarget {
  static {
    __name(this, "ComfyPopup");
  }
  element = $el("div.comfyui-popup");
  open;
  children;
  target;
  ignoreTarget;
  container;
  position;
  closeOnEscape;
  horizontal;
  classList;
  constructor({
    target: target2,
    container = document.body,
    classList = "",
    ignoreTarget = true,
    closeOnEscape: closeOnEscape2 = true,
    position: position3 = "absolute",
    horizontal: horizontal2 = "left"
  }, ...children) {
    super();
    this.target = target2;
    this.ignoreTarget = ignoreTarget;
    this.container = container;
    this.position = position3;
    this.closeOnEscape = closeOnEscape2;
    this.horizontal = horizontal2;
    container.append(this.element);
    this.children = prop(this, "children", children, () => {
      this.element.replaceChildren(...this.children);
      this.update();
    });
    this.classList = prop(
      this,
      "classList",
      classList,
      () => applyClasses(this.element, this.classList, "comfyui-popup", horizontal2)
    );
    this.open = prop(this, "open", false, (v2, o2) => {
      if (v2 === o2) return;
      if (v2) {
        this.#show();
      } else {
        this.#hide();
      }
    });
  }
  toggle() {
    this.open = !this.open;
  }
  #hide() {
    this.element.classList.remove("open");
    window.removeEventListener("resize", this.update);
    window.removeEventListener("click", this.#clickHandler, { capture: true });
    window.removeEventListener("keydown", this.#escHandler, { capture: true });
    this.dispatchEvent(new CustomEvent("close"));
    this.dispatchEvent(new CustomEvent("change"));
  }
  #show() {
    this.element.classList.add("open");
    this.update();
    window.addEventListener("resize", this.update);
    window.addEventListener("click", this.#clickHandler, { capture: true });
    if (this.closeOnEscape) {
      window.addEventListener("keydown", this.#escHandler, { capture: true });
    }
    this.dispatchEvent(new CustomEvent("open"));
    this.dispatchEvent(new CustomEvent("change"));
  }
  // @ts-expect-error fixme ts strict error
  #escHandler = /* @__PURE__ */ __name((e2) => {
    if (e2.key === "Escape") {
      this.open = false;
      e2.preventDefault();
      e2.stopImmediatePropagation();
    }
  }, "#escHandler");
  // @ts-expect-error fixme ts strict error
  #clickHandler = /* @__PURE__ */ __name((e2) => {
    const target2 = e2.target;
    if (!this.element.contains(target2) && this.ignoreTarget && !this.target.contains(target2)) {
      this.open = false;
    }
  }, "#clickHandler");
  update = /* @__PURE__ */ __name(() => {
    const rect = this.target.getBoundingClientRect();
    this.element.style.setProperty("--bottom", "unset");
    if (this.position === "absolute") {
      if (this.horizontal === "left") {
        this.element.style.setProperty("--left", rect.left + "px");
      } else {
        this.element.style.setProperty(
          "--left",
          rect.right - this.element.clientWidth + "px"
        );
      }
      this.element.style.setProperty("--top", rect.bottom + "px");
      this.element.style.setProperty("--limit", rect.bottom + "px");
    } else {
      this.element.style.setProperty("--left", "0px");
      this.element.style.setProperty("--top", rect.height + "px");
      this.element.style.setProperty("--limit", rect.height + "px");
    }
    const thisRect = this.element.getBoundingClientRect();
    if (thisRect.height < 30) {
      this.element.style.setProperty("--top", "unset");
      this.element.style.setProperty("--bottom", rect.height + 5 + "px");
      this.element.style.setProperty("--limit", rect.height + 5 + "px");
    }
  }, "update");
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.popup = window.comfyAPI.popup || {};
window.comfyAPI.popup.ComfyPopup = ComfyPopup;
class ComfySplitButton {
  static {
    __name(this, "ComfySplitButton");
  }
  arrow;
  element;
  popup;
  items;
  constructor({
    primary,
    mode: mode2,
    horizontal: horizontal2 = "left",
    position: position3 = "relative"
  }, ...items2) {
    this.arrow = new ComfyButton({
      icon: "chevron-down"
    });
    this.element = $el(
      "div.comfyui-split-button" + (mode2 === "hover" ? ".hover" : ""),
      [
        $el(
          "div.comfyui-split-primary",
          {
            ariaLabel: "Queue current workflow"
          },
          primary.element
        ),
        $el(
          "div.comfyui-split-arrow",
          {
            ariaLabel: "Open extra opens",
            ariaHasPopup: "true"
          },
          this.arrow.element
        )
      ]
    );
    this.popup = new ComfyPopup({
      target: this.element,
      container: position3 === "relative" ? this.element : document.body,
      classList: "comfyui-split-button-popup" + (mode2 === "hover" ? " hover" : ""),
      closeOnEscape: mode2 === "click",
      position: position3,
      horizontal: horizontal2
    });
    this.arrow.withPopup(this.popup, mode2);
    this.items = prop(this, "items", items2, () => this.update());
  }
  update() {
    this.popup.element.replaceChildren(
      ...this.items.map((b2) => "element" in b2 ? b2.element : b2)
    );
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.splitButton = window.comfyAPI.splitButton || {};
window.comfyAPI.splitButton.ComfySplitButton = ComfySplitButton;
class ComfyAsyncDialog extends ComfyDialog$1 {
  static {
    __name(this, "ComfyAsyncDialog");
  }
  // @ts-expect-error fixme ts strict error
  #resolve;
  constructor(actions) {
    super(
      "dialog.comfy-dialog.comfyui-dialog",
      // @ts-expect-error fixme ts strict error
      actions?.map((opt) => {
        if (typeof opt === "string") {
          opt = { text: opt };
        }
        return $el("button.comfyui-button", {
          type: "button",
          textContent: opt.text,
          onclick: /* @__PURE__ */ __name(() => this.close(opt.value ?? opt.text), "onclick")
        });
      })
    );
  }
  show(html) {
    this.element.addEventListener("close", () => {
      this.close();
    });
    super.show(html);
    return new Promise((resolve2) => {
      this.#resolve = resolve2;
    });
  }
  showModal(html) {
    this.element.addEventListener("close", () => {
      this.close();
    });
    super.show(html);
    this.element.showModal();
    return new Promise((resolve2) => {
      this.#resolve = resolve2;
    });
  }
  close(result = null) {
    this.#resolve(result);
    this.element.close();
    super.close();
  }
  static async prompt({
    title = null,
    message: message3,
    actions
  }) {
    const dialog = new ComfyAsyncDialog(actions);
    const content3 = [$el("span", message3)];
    if (title) {
      content3.unshift($el("h3", title));
    }
    const res = await dialog.showModal(content3);
    dialog.element.remove();
    return res;
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.asyncDialog = window.comfyAPI.asyncDialog || {};
window.comfyAPI.asyncDialog.ComfyAsyncDialog = ComfyAsyncDialog;
$el("style", {
  parent: document.head,
  textContent: `
        .draggable-item {
            position: relative;
            will-change: transform;
            user-select: none;
        }
        .draggable-item.is-idle {
            transition: 0.25s ease transform;
        }
        .draggable-item.is-draggable {
            z-index: 10;
        }
    `
});
class DraggableList extends EventTarget {
  static {
    __name(this, "DraggableList");
  }
  listContainer;
  // @ts-expect-error fixme ts strict error
  draggableItem;
  // @ts-expect-error fixme ts strict error
  pointerStartX;
  // @ts-expect-error fixme ts strict error
  pointerStartY;
  // @ts-expect-error fixme ts strict error
  scrollYMax;
  itemsGap = 0;
  items = [];
  itemSelector;
  handleClass = "drag-handle";
  off = [];
  offDrag = [];
  // @ts-expect-error fixme ts strict error
  constructor(element, itemSelector) {
    super();
    this.listContainer = element;
    this.itemSelector = itemSelector;
    if (!this.listContainer) return;
    this.off.push(this.on(this.listContainer, "mousedown", this.dragStart));
    this.off.push(this.on(this.listContainer, "touchstart", this.dragStart));
    this.off.push(this.on(document, "mouseup", this.dragEnd));
    this.off.push(this.on(document, "touchend", this.dragEnd));
  }
  getAllItems() {
    if (!this.items?.length) {
      this.items = Array.from(
        this.listContainer.querySelectorAll(this.itemSelector)
      );
      this.items.forEach((element) => {
        element.classList.add("is-idle");
      });
    }
    return this.items;
  }
  getIdleItems() {
    return this.getAllItems().filter(
      (item3) => (
        // @ts-expect-error fixme ts strict error
        item3.classList.contains("is-idle")
      )
    );
  }
  // @ts-expect-error fixme ts strict error
  isItemAbove(item3) {
    return item3.hasAttribute("data-is-above");
  }
  // @ts-expect-error fixme ts strict error
  isItemToggled(item3) {
    return item3.hasAttribute("data-is-toggled");
  }
  // @ts-expect-error fixme ts strict error
  on(source, event, listener, options5) {
    listener = listener.bind(this);
    source.addEventListener(event, listener, options5);
    return () => source.removeEventListener(event, listener);
  }
  // @ts-expect-error fixme ts strict error
  dragStart(e2) {
    if (e2.target.classList.contains(this.handleClass)) {
      this.draggableItem = e2.target.closest(this.itemSelector);
    }
    if (!this.draggableItem) return;
    this.pointerStartX = e2.clientX || e2.touches[0].clientX;
    this.pointerStartY = e2.clientY || e2.touches[0].clientY;
    this.scrollYMax = this.listContainer.scrollHeight - this.listContainer.clientHeight;
    this.setItemsGap();
    this.initDraggableItem();
    this.initItemsState();
    this.offDrag.push(this.on(document, "mousemove", this.drag));
    this.offDrag.push(
      // @ts-expect-error fixme ts strict error
      this.on(document, "touchmove", this.drag, { passive: false })
    );
    this.dispatchEvent(
      new CustomEvent("dragstart", {
        detail: {
          element: this.draggableItem,
          // @ts-expect-error fixme ts strict error
          position: this.getAllItems().indexOf(this.draggableItem)
        }
      })
    );
  }
  setItemsGap() {
    if (this.getIdleItems().length <= 1) {
      this.itemsGap = 0;
      return;
    }
    const item1 = this.getIdleItems()[0];
    const item22 = this.getIdleItems()[1];
    const item1Rect = item1.getBoundingClientRect();
    const item2Rect = item22.getBoundingClientRect();
    this.itemsGap = Math.abs(item1Rect.bottom - item2Rect.top);
  }
  initItemsState() {
    this.getIdleItems().forEach((item3, i2) => {
      if (this.getAllItems().indexOf(this.draggableItem) > i2) {
        item3.dataset.isAbove = "";
      }
    });
  }
  initDraggableItem() {
    this.draggableItem.classList.remove("is-idle");
    this.draggableItem.classList.add("is-draggable");
  }
  // @ts-expect-error fixme ts strict error
  drag(e2) {
    if (!this.draggableItem) return;
    e2.preventDefault();
    const clientX = e2.clientX || e2.touches[0].clientX;
    const clientY = e2.clientY || e2.touches[0].clientY;
    const listRect = this.listContainer.getBoundingClientRect();
    if (clientY > listRect.bottom) {
      if (this.listContainer.scrollTop < this.scrollYMax) {
        this.listContainer.scrollBy(0, 10);
        this.pointerStartY -= 10;
      }
    } else if (clientY < listRect.top && this.listContainer.scrollTop > 0) {
      this.pointerStartY += 10;
      this.listContainer.scrollBy(0, -10);
    }
    const pointerOffsetX = clientX - this.pointerStartX;
    const pointerOffsetY = clientY - this.pointerStartY;
    this.updateIdleItemsStateAndPosition();
    this.draggableItem.style.transform = `translate(${pointerOffsetX}px, ${pointerOffsetY}px)`;
  }
  updateIdleItemsStateAndPosition() {
    const draggableItemRect = this.draggableItem.getBoundingClientRect();
    const draggableItemY = draggableItemRect.top + draggableItemRect.height / 2;
    this.getIdleItems().forEach((item3) => {
      const itemRect = item3.getBoundingClientRect();
      const itemY = itemRect.top + itemRect.height / 2;
      if (this.isItemAbove(item3)) {
        if (draggableItemY <= itemY) {
          item3.dataset.isToggled = "";
        } else {
          delete item3.dataset.isToggled;
        }
      } else {
        if (draggableItemY >= itemY) {
          item3.dataset.isToggled = "";
        } else {
          delete item3.dataset.isToggled;
        }
      }
    });
    this.getIdleItems().forEach((item3) => {
      if (this.isItemToggled(item3)) {
        const direction = this.isItemAbove(item3) ? 1 : -1;
        item3.style.transform = `translateY(${direction * (draggableItemRect.height + this.itemsGap)}px)`;
      } else {
        item3.style.transform = "";
      }
    });
  }
  dragEnd() {
    if (!this.draggableItem) return;
    this.applyNewItemsOrder();
    this.cleanup();
  }
  applyNewItemsOrder() {
    const reorderedItems = [];
    let oldPosition = -1;
    this.getAllItems().forEach((item3, index2) => {
      if (item3 === this.draggableItem) {
        oldPosition = index2;
        return;
      }
      if (!this.isItemToggled(item3)) {
        reorderedItems[index2] = item3;
        return;
      }
      const newIndex = this.isItemAbove(item3) ? index2 + 1 : index2 - 1;
      reorderedItems[newIndex] = item3;
    });
    for (let index2 = 0; index2 < this.getAllItems().length; index2++) {
      const item3 = reorderedItems[index2];
      if (typeof item3 === "undefined") {
        reorderedItems[index2] = this.draggableItem;
      }
    }
    reorderedItems.forEach((item3) => {
      this.listContainer.appendChild(item3);
    });
    this.items = reorderedItems;
    this.dispatchEvent(
      new CustomEvent("dragend", {
        detail: {
          element: this.draggableItem,
          oldPosition,
          newPosition: reorderedItems.indexOf(this.draggableItem)
        }
      })
    );
  }
  cleanup() {
    this.itemsGap = 0;
    this.items = [];
    this.unsetDraggableItem();
    this.unsetItemState();
    this.offDrag.forEach((f2) => f2());
    this.offDrag = [];
  }
  unsetDraggableItem() {
    this.draggableItem.style = null;
    this.draggableItem.classList.remove("is-draggable");
    this.draggableItem.classList.add("is-idle");
    this.draggableItem = null;
  }
  unsetItemState() {
    this.getIdleItems().forEach((item3) => {
      delete item3.dataset.isAbove;
      delete item3.dataset.isToggled;
      item3.style.transform = "";
    });
  }
  dispose() {
    this.off.forEach((f2) => f2());
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.draggableList = window.comfyAPI.draggableList || {};
window.comfyAPI.draggableList.DraggableList = DraggableList;
class ComfyAppMenu {
  static {
    __name(this, "ComfyAppMenu");
  }
  app;
  actionsGroup;
  settingsGroup;
  viewGroup;
  element;
  constructor(app2) {
    this.app = app2;
    this.actionsGroup = new ComfyButtonGroup();
    this.settingsGroup = new ComfyButtonGroup();
    this.viewGroup = new ComfyButtonGroup();
    this.element = $el("div.flex.gap-2.mx-2", [
      this.actionsGroup.element,
      this.settingsGroup.element,
      this.viewGroup.element
    ]);
  }
}
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.index = window.comfyAPI.index || {};
window.comfyAPI.index.ComfyAppMenu = ComfyAppMenu;
const ANIM_PREVIEW_WIDGET = "$$comfy_animation_preview";
function sanitizeNodeName(string) {
  let entityMap = {
    "&": "",
    "<": "",
    ">": "",
    '"': "",
    "'": "",
    "`": "",
    "=": ""
  };
  return String(string).replace(/[&<>"'`=]/g, /* @__PURE__ */ __name(function fromEntityMap(s2) {
    return entityMap[s2];
  }, "fromEntityMap"));
}
__name(sanitizeNodeName, "sanitizeNodeName");
class ComfyApp {
  static {
    __name(this, "ComfyApp");
  }
  /**
   * List of entries to queue
   * @type {{number: number, batchCount: number}[]}
   */
  #queueItems = [];
  /**
   * If the queue is currently being processed
   * @type {boolean}
   */
  #processingQueue = false;
  /**
   * Content Clipboard
   * @type {serialized node object}
   */
  static clipspace = null;
  static clipspace_invalidate_handler = null;
  static open_maskeditor = null;
  static clipspace_return_node = null;
  vueAppReady;
  api;
  ui;
  // @ts-expect-error fixme ts strict error
  extensionManager;
  // @ts-expect-error fixme ts strict error
  _nodeOutputs;
  nodePreviewImages;
  // @ts-expect-error fixme ts strict error
  graph;
  // @ts-expect-error fixme ts strict error
  canvas;
  // @ts-expect-error fixme ts strict error
  dragOverNode;
  // @ts-expect-error fixme ts strict error
  canvasEl;
  // @ts-expect-error fixme ts strict error
  lastNodeErrors;
  /** @type {ExecutionErrorWsMessage} */
  // @ts-expect-error fixme ts strict error
  lastExecutionError;
  // @ts-expect-error fixme ts strict error
  configuringGraph;
  // @ts-expect-error fixme ts strict error
  ctx;
  bodyTop;
  bodyLeft;
  bodyRight;
  bodyBottom;
  canvasContainer;
  menu;
  bypassBgColor;
  // Set by Comfy.Clipspace extension
  openClipspace = /* @__PURE__ */ __name(() => {
  }, "openClipspace");
  /**
   * @deprecated Use useExecutionStore().executingNodeId instead
   */
  get runningNodeId() {
    return useExecutionStore().executingNodeId;
  }
  /**
   * @deprecated Use useWorkspaceStore().shiftDown instead
   */
  get shiftDown() {
    return useWorkspaceStore().shiftDown;
  }
  /**
   * @deprecated Use useWidgetStore().widgets instead
   */
  get widgets() {
    if (this.vueAppReady) {
      return useWidgetStore().widgets;
    }
    return ComfyWidgets;
  }
  /**
   * @deprecated storageLocation is always 'server' since
   * https://github.com/comfyanonymous/ComfyUI/commit/53c8a99e6c00b5e20425100f6680cd9ea2652218
   */
  get storageLocation() {
    return "server";
  }
  /**
   * @deprecated storage migration is no longer needed.
   */
  get isNewUserSession() {
    return false;
  }
  /**
   * @deprecated Use useExtensionStore().extensions instead
   */
  get extensions() {
    return useExtensionStore().extensions;
  }
  /**
   * The progress on the current executing node, if the node reports any.
   * @deprecated Use useExecutionStore().executingNodeProgress instead
   */
  get progress() {
    return useExecutionStore()._executingNodeProgress;
  }
  /**
   * @deprecated Use {@link isImageNode} from @/utils/litegraphUtil instead
   */
  static isImageNode(node3) {
    return isImageNode(node3);
  }
  /**
   * Resets the canvas view to the default
   * @deprecated Use {@link useLitegraphService().resetView} instead
   */
  resetView() {
    useLitegraphService().resetView();
  }
  constructor() {
    this.vueAppReady = false;
    this.ui = new ComfyUI(this);
    this.api = api;
    this.bodyTop = $el("div.comfyui-body-top");
    this.bodyLeft = $el("div.comfyui-body-left");
    this.bodyRight = $el("div.comfyui-body-right");
    this.bodyBottom = $el("div.comfyui-body-bottom");
    this.canvasContainer = $el("div.graph-canvas-container");
    this.menu = new ComfyAppMenu(this);
    this.bypassBgColor = "#FF00FF";
    this.nodeOutputs = {};
    this.nodePreviewImages = {};
  }
  get nodeOutputs() {
    return this._nodeOutputs;
  }
  set nodeOutputs(value3) {
    this._nodeOutputs = value3;
    if (this.vueAppReady)
      useExtensionService().invokeExtensions("onNodeOutputsUpdated", value3);
  }
  getPreviewFormatParam() {
    let preview_format = this.ui.settings.getSettingValue("Comfy.PreviewFormat");
    if (preview_format) return `&preview=${preview_format}`;
    else return "";
  }
  getRandParam() {
    return "&rand=" + Math.random();
  }
  static onClipspaceEditorSave() {
    if (ComfyApp.clipspace_return_node) {
      ComfyApp.pasteFromClipspace(ComfyApp.clipspace_return_node);
    }
  }
  static onClipspaceEditorClosed() {
    ComfyApp.clipspace_return_node = null;
  }
  // @ts-expect-error fixme ts strict error
  static copyToClipspace(node3) {
    var widgets = null;
    if (node3.widgets) {
      widgets = node3.widgets.map(({ type, name: name2, value: value3 }) => ({
        type,
        name: name2,
        value: value3
      }));
    }
    var imgs = void 0;
    var orig_imgs = void 0;
    if (node3.imgs != void 0) {
      imgs = [];
      orig_imgs = [];
      for (let i2 = 0; i2 < node3.imgs.length; i2++) {
        imgs[i2] = new Image();
        imgs[i2].src = node3.imgs[i2].src;
        orig_imgs[i2] = imgs[i2];
      }
    }
    var selectedIndex = 0;
    if (node3.imageIndex) {
      selectedIndex = node3.imageIndex;
    }
    ComfyApp.clipspace = {
      widgets,
      imgs,
      original_imgs: orig_imgs,
      images: node3.images,
      selectedIndex,
      img_paste_mode: "selected"
      // reset to default im_paste_mode state on copy action
    };
    ComfyApp.clipspace_return_node = null;
    if (ComfyApp.clipspace_invalidate_handler) {
      ComfyApp.clipspace_invalidate_handler();
    }
  }
  static pasteFromClipspace(node3) {
    if (ComfyApp.clipspace) {
      if (ComfyApp.clipspace.imgs && node3.imgs) {
        if (node3.images && ComfyApp.clipspace.images) {
          if (ComfyApp.clipspace["img_paste_mode"] == "selected") {
            node3.images = [
              ComfyApp.clipspace.images[ComfyApp.clipspace["selectedIndex"]]
            ];
          } else {
            node3.images = ComfyApp.clipspace.images;
          }
          if (app$2.nodeOutputs[node3.id + ""])
            app$2.nodeOutputs[node3.id + ""].images = node3.images;
        }
        if (ComfyApp.clipspace.imgs) {
          if (ComfyApp.clipspace["img_paste_mode"] == "selected") {
            const img = new Image();
            img.src = ComfyApp.clipspace.imgs[ComfyApp.clipspace["selectedIndex"]].src;
            node3.imgs = [img];
            node3.imageIndex = 0;
          } else {
            const imgs = [];
            for (let i2 = 0; i2 < ComfyApp.clipspace.imgs.length; i2++) {
              imgs[i2] = new Image();
              imgs[i2].src = ComfyApp.clipspace.imgs[i2].src;
              node3.imgs = imgs;
            }
          }
        }
      }
      if (node3.widgets) {
        if (ComfyApp.clipspace.images) {
          const clip_image = ComfyApp.clipspace.images[ComfyApp.clipspace["selectedIndex"]];
          const index2 = node3.widgets.findIndex((obj) => obj.name === "image");
          if (index2 >= 0) {
            if (
              // @ts-expect-error custom widget type
              node3.widgets[index2].type != "image" && typeof node3.widgets[index2].value == "string" && clip_image.filename
            ) {
              node3.widgets[index2].value = (clip_image.subfolder ? clip_image.subfolder + "/" : "") + clip_image.filename + (clip_image.type ? ` [${clip_image.type}]` : "");
            } else {
              node3.widgets[index2].value = clip_image;
            }
          }
        }
        if (ComfyApp.clipspace.widgets) {
          ComfyApp.clipspace.widgets.forEach(({ type, name: name2, value: value3 }) => {
            const prop2 = Object.values(node3.widgets).find(
              (obj) => obj.type === type && obj.name === name2
            );
            if (prop2 && prop2.type != "button") {
              if (
                // @ts-expect-error Custom widget type
                prop2.type != "image" && typeof prop2.value == "string" && // @ts-expect-error Custom widget value
                value3.filename
              ) {
                const resultItem = value3;
                prop2.value = (resultItem.subfolder ? resultItem.subfolder + "/" : "") + resultItem.filename + (resultItem.type ? ` [${resultItem.type}]` : "");
              } else {
                prop2.value = value3;
                prop2.callback?.(value3);
              }
            }
          });
        }
      }
      app$2.graph.setDirtyCanvas(true);
    }
  }
  #addRestoreWorkflowView() {
    const serialize = LGraph$1.prototype.serialize;
    const self2 = this;
    LGraph$1.prototype.serialize = function() {
      const workflow = serialize.apply(this, arguments);
      if (useSettingStore().get("Comfy.EnableWorkflowViewRestore")) {
        if (!workflow.extra) {
          workflow.extra = {};
        }
        workflow.extra.ds = {
          scale: self2.canvas.ds.scale,
          offset: [...self2.canvas.ds.offset]
        };
      } else if (workflow.extra?.ds) {
        delete workflow.extra.ds;
      }
      return workflow;
    };
  }
  /**
   * Adds a handler allowing drag+drop of files onto the window to load workflows
   */
  #addDropHandler() {
    document.addEventListener("drop", async (event) => {
      event.preventDefault();
      event.stopPropagation();
      const n2 = this.dragOverNode;
      this.dragOverNode = null;
      if (n2 && n2.onDragDrop && await n2.onDragDrop(event)) {
        return;
      }
      if (
        // @ts-expect-error fixme ts strict error
        event.dataTransfer.files.length && // @ts-expect-error fixme ts strict error
        event.dataTransfer.files[0].type !== "image/bmp"
      ) {
        await this.handleFile(event.dataTransfer.files[0]);
      } else {
        const validTypes = ["text/uri-list", "text/x-moz-url"];
        const match2 = [...event.dataTransfer.types].find(
          (t2) => validTypes.find((v2) => t2 === v2)
        );
        if (match2) {
          const uri = event.dataTransfer.getData(match2)?.split("\n")?.[0];
          if (uri) {
            await this.handleFile(await (await fetch(uri)).blob());
          }
        }
      }
    });
    this.canvasEl.addEventListener("dragleave", async () => {
      if (this.dragOverNode) {
        this.dragOverNode = null;
        this.graph.setDirtyCanvas(false, true);
      }
    });
    this.canvasEl.addEventListener(
      "dragover",
      (e2) => {
        this.canvas.adjustMouseEvent(e2);
        const node3 = this.graph.getNodeOnPos(e2.canvasX, e2.canvasY);
        if (node3) {
          if (node3.onDragOver && node3.onDragOver(e2)) {
            this.dragOverNode = node3;
            requestAnimationFrame(() => {
              this.graph.setDirtyCanvas(false, true);
            });
            return;
          }
        }
        this.dragOverNode = null;
      },
      false
    );
  }
  /**
   * Handle keypress
   */
  #addProcessKeyHandler() {
    const origProcessKey = LGraphCanvas.prototype.processKey;
    LGraphCanvas.prototype.processKey = function(e2) {
      if (!this.graph) {
        return;
      }
      var block_default = false;
      if (e2.target instanceof Element && e2.target.localName == "input") {
        return;
      }
      if (e2.type == "keydown" && !e2.repeat) {
        const keyCombo = KeyComboImpl.fromEvent(e2);
        const keybindingStore = useKeybindingStore();
        const keybinding = keybindingStore.getKeybinding(keyCombo);
        if (keybinding && keybinding.targetElementId === "graph-canvas") {
          useCommandStore().execute(keybinding.commandId);
          block_default = true;
        }
        if (e2.key === "c" && (e2.metaKey || e2.ctrlKey)) {
          return true;
        }
        if ((e2.key === "v" || e2.key == "V") && (e2.metaKey || e2.ctrlKey) && !e2.shiftKey) {
          return true;
        }
      }
      this.graph.change();
      if (block_default) {
        e2.preventDefault();
        e2.stopImmediatePropagation();
        return false;
      }
      return origProcessKey.apply(this, arguments);
    };
  }
  /**
   * Draws node highlights (executing, drag drop) and progress bar
   */
  #addDrawNodeHandler() {
    const origDrawNodeShape = LGraphCanvas.prototype.drawNodeShape;
    const self2 = this;
    LGraphCanvas.prototype.drawNodeShape = function(node3, ctx, size, _fgcolor, bgcolor) {
      const res = origDrawNodeShape.apply(this, arguments);
      const nodeErrors = self2.lastNodeErrors?.[node3.id];
      let color2 = null;
      let lineWidth = 1;
      if (node3.id === +self2.runningNodeId) {
        color2 = "#0f0";
      } else if (self2.dragOverNode && node3.id === self2.dragOverNode.id) {
        color2 = "dodgerblue";
      } else if (nodeErrors?.errors) {
        color2 = "red";
        lineWidth = 2;
      } else if (self2.lastExecutionError && // @ts-expect-error fixme ts strict error
      +self2.lastExecutionError.node_id === node3.id) {
        color2 = "#f0f";
        lineWidth = 2;
      }
      if (color2) {
        const area = [
          0,
          -LiteGraph.NODE_TITLE_HEIGHT,
          size[0],
          size[1] + LiteGraph.NODE_TITLE_HEIGHT
        ];
        strokeShape(ctx, area, {
          shape: node3._shape || node3.constructor.shape || LiteGraph.ROUND_SHAPE,
          thickness: lineWidth,
          colour: color2,
          title_height: LiteGraph.NODE_TITLE_HEIGHT,
          collapsed: node3.collapsed
        });
      }
      if (self2.progress && node3.id === +self2.runningNodeId) {
        ctx.fillStyle = "green";
        ctx.fillRect(
          0,
          0,
          size[0] * (self2.progress.value / self2.progress.max),
          6
        );
        ctx.fillStyle = bgcolor;
      }
      if (nodeErrors) {
        ctx.lineWidth = 2;
        ctx.strokeStyle = "red";
        for (const error2 of nodeErrors.errors) {
          if (error2.extra_info && error2.extra_info.input_name) {
            const inputIndex = node3.findInputSlot(error2.extra_info.input_name);
            if (inputIndex !== -1) {
              let pos = node3.getConnectionPos(true, inputIndex);
              ctx.beginPath();
              ctx.arc(
                pos[0] - node3.pos[0],
                pos[1] - node3.pos[1],
                12,
                0,
                2 * Math.PI,
                false
              );
              ctx.stroke();
            }
          }
        }
      }
      return res;
    };
    const origDrawNode = LGraphCanvas.prototype.drawNode;
    LGraphCanvas.prototype.drawNode = function(node3) {
      const editor_alpha = this.editor_alpha;
      const old_color = node3.color;
      const old_bgcolor = node3.bgcolor;
      if (node3.mode === LGraphEventMode.NEVER) {
        this.editor_alpha = 0.4;
      }
      let bgColor;
      if (node3.mode === LGraphEventMode.BYPASS) {
        bgColor = app$2.bypassBgColor;
        this.editor_alpha = 0.2;
      } else {
        bgColor = old_bgcolor || LiteGraph.NODE_DEFAULT_BGCOLOR;
      }
      const adjustments = {};
      const opacity = useSettingStore().get("Comfy.Node.Opacity");
      if (opacity) adjustments.opacity = opacity;
      if (useColorPaletteStore().completedActivePalette.light_theme) {
        adjustments.lightness = 0.5;
        if (old_color) {
          node3.color = adjustColor(old_color, { lightness: 0.5 });
        }
      }
      node3.bgcolor = adjustColor(bgColor, adjustments);
      const res = origDrawNode.apply(this, arguments);
      this.editor_alpha = editor_alpha;
      node3.color = old_color;
      node3.bgcolor = old_bgcolor;
      return res;
    };
  }
  /**
   * Handles updates from the API socket
   */
  #addApiUpdateHandlers() {
    api.addEventListener("status", ({ detail }) => {
      this.ui.setStatus(detail);
    });
    api.addEventListener("progress", () => {
      this.graph.setDirtyCanvas(true, false);
    });
    api.addEventListener("executing", () => {
      this.graph.setDirtyCanvas(true, false);
      this.revokePreviews(this.runningNodeId);
      delete this.nodePreviewImages[this.runningNodeId];
    });
    api.addEventListener("executed", ({ detail }) => {
      const output = this.nodeOutputs[detail.display_node || detail.node];
      if (detail.merge && output) {
        for (const k2 in detail.output ?? {}) {
          const v2 = output[k2];
          if (v2 instanceof Array) {
            output[k2] = v2.concat(detail.output[k2]);
          } else {
            output[k2] = detail.output[k2];
          }
        }
      } else {
        this.nodeOutputs[detail.display_node || detail.node] = detail.output;
      }
      const node3 = this.graph.getNodeById(detail.display_node || detail.node);
      if (node3) {
        if (node3.onExecuted) node3.onExecuted(detail.output);
      }
    });
    api.addEventListener("execution_start", () => {
      this.lastExecutionError = null;
      this.graph.nodes.forEach((node3) => {
        if (node3.onExecutionStart) node3.onExecutionStart();
      });
    });
    api.addEventListener("execution_error", ({ detail }) => {
      this.lastExecutionError = detail;
      useDialogService().showExecutionErrorDialog({ error: detail });
      this.canvas.draw(true, true);
    });
    api.addEventListener("b_preview", ({ detail }) => {
      const id4 = this.runningNodeId;
      if (id4 == null) return;
      const blob = detail;
      const blobUrl = URL.createObjectURL(blob);
      this.revokePreviews(id4);
      this.nodePreviewImages[id4] = [blobUrl];
    });
    api.init();
  }
  #addConfigureHandler() {
    const app2 = this;
    const configure = LGraph$1.prototype.configure;
    LGraph$1.prototype.configure = function() {
      app2.configuringGraph = true;
      try {
        return configure.apply(this, arguments);
      } finally {
        app2.configuringGraph = false;
      }
    };
  }
  #addAfterConfigureHandler() {
    const app2 = this;
    const onConfigure = app2.graph.onConfigure;
    app2.graph.onConfigure = function() {
      for (const node3 of app2.graph.nodes) {
        node3.onGraphConfigured?.();
      }
      const r2 = onConfigure?.apply(this, arguments);
      for (const node3 of app2.graph.nodes) {
        node3.onAfterGraphConfigured?.();
      }
      return r2;
    };
  }
  /**
   * Set up the app on the page
   */
  async setup(canvasEl) {
    this.bodyTop = document.getElementById("comfyui-body-top");
    this.bodyLeft = document.getElementById("comfyui-body-left");
    this.bodyRight = document.getElementById("comfyui-body-right");
    this.bodyBottom = document.getElementById("comfyui-body-bottom");
    this.canvasContainer = document.getElementById("graph-canvas-container");
    this.canvasEl = canvasEl;
    this.resizeCanvas();
    await useWorkspaceStore().workflow.syncWorkflows();
    await useExtensionService().loadExtensions();
    this.#addProcessKeyHandler();
    this.#addConfigureHandler();
    this.#addApiUpdateHandlers();
    this.#addRestoreWorkflowView();
    this.graph = new LGraph$1();
    this.#addAfterConfigureHandler();
    this.canvas = new LGraphCanvas(canvasEl, this.graph);
    this.canvas.state = reactive(this.canvas.state);
    this.canvas.ds.state = reactive(this.canvas.ds.state);
    this.ctx = canvasEl.getContext("2d");
    LiteGraph.alt_drag_do_clone_nodes = true;
    this.graph.start();
    this.resizeCanvas();
    window.addEventListener("resize", () => this.resizeCanvas());
    const ro = new ResizeObserver(() => this.resizeCanvas());
    ro.observe(this.bodyTop);
    ro.observe(this.bodyLeft);
    ro.observe(this.bodyRight);
    ro.observe(this.bodyBottom);
    await useExtensionService().invokeExtensionsAsync("init");
    await this.registerNodes();
    this.#addDrawNodeHandler();
    this.#addDropHandler();
    await useExtensionService().invokeExtensionsAsync("setup");
  }
  resizeCanvas() {
    const scale = Math.max(window.devicePixelRatio, 1);
    this.canvasEl.height = this.canvasEl.width = NaN;
    const { width: width2, height } = this.canvasEl.getBoundingClientRect();
    this.canvasEl.width = Math.round(width2 * scale);
    this.canvasEl.height = Math.round(height * scale);
    this.canvasEl.getContext("2d").scale(scale, scale);
    this.canvas?.draw(true, true);
  }
  updateVueAppNodeDefs(defs) {
    const rawDefs = Object.fromEntries(
      Object.entries(LiteGraph.registered_node_types).map(([name2, node3]) => [
        name2,
        {
          name: name2,
          display_name: name2,
          category: node3.category || "__frontend_only__",
          input: { required: {}, optional: {} },
          output: [],
          output_name: [],
          output_is_list: [],
          python_module: "custom_nodes.frontend_only",
          description: `Frontend only node for ${name2}`
        }
      ])
    );
    const allNodeDefs = {
      ...rawDefs,
      ...defs,
      ...SYSTEM_NODE_DEFS
    };
    const nodeDefStore = useNodeDefStore();
    const nodeDefArray = Object.values(allNodeDefs);
    useExtensionService().invokeExtensions(
      "beforeRegisterVueAppNodeDefs",
      nodeDefArray,
      this
    );
    nodeDefStore.updateNodeDefs(nodeDefArray);
  }
  async #getNodeDefs() {
    const translateNodeDef = /* @__PURE__ */ __name((def2) => ({
      ...def2,
      display_name: st(
        `nodeDefs.${def2.name}.display_name`,
        def2.display_name ?? def2.name
      ),
      // @ts-expect-error fixme ts strict error
      description: def2.description ? st(`nodeDefs.${def2.name}.description`, def2.description) : void 0,
      category: def2.category.split("/").map((category) => st(`nodeCategories.${category}`, category)).join("/")
    }), "translateNodeDef");
    return _.mapValues(
      await api.getNodeDefs({
        validate: useSettingStore().get("Comfy.Validation.NodeDefs")
      }),
      (def2) => translateNodeDef(def2)
    );
  }
  /**
   * Registers nodes with the graph
   */
  async registerNodes() {
    const defs = await this.#getNodeDefs();
    await this.registerNodesFromDefs(defs);
    await useExtensionService().invokeExtensionsAsync("registerCustomNodes");
    if (this.vueAppReady) {
      this.updateVueAppNodeDefs(defs);
    }
  }
  async registerNodeDef(nodeId, nodeDef) {
    return await useLitegraphService().registerNodeDef(nodeId, nodeDef);
  }
  async registerNodesFromDefs(defs) {
    await useExtensionService().invokeExtensionsAsync("addCustomNodeDefs", defs);
    for (const nodeId in defs) {
      this.registerNodeDef(nodeId, defs[nodeId]);
    }
  }
  // @ts-expect-error fixme ts strict error
  loadTemplateData(templateData) {
    if (!templateData?.templates) {
      return;
    }
    const old = localStorage.getItem("litegrapheditor_clipboard");
    var maxY2, nodeBottom, node3;
    for (const template of templateData.templates) {
      if (!template?.data) {
        continue;
      }
      const data30 = JSON.parse(template.data);
      if (!data30.reroutes) {
        deserialiseAndCreate(template.data, app$2.canvas);
      } else {
        localStorage.setItem("litegrapheditor_clipboard", template.data);
        app$2.canvas.pasteFromClipboard();
      }
      maxY2 = false;
      for (const i2 in app$2.canvas.selected_nodes) {
        node3 = app$2.canvas.selected_nodes[i2];
        nodeBottom = node3.pos[1] + node3.size[1];
        if (maxY2 === false || nodeBottom > maxY2) {
          maxY2 = nodeBottom;
        }
      }
      app$2.canvas.graph_mouse[1] = maxY2 + 50;
    }
    localStorage.setItem("litegrapheditor_clipboard", old);
  }
  #showMissingNodesError(missingNodeTypes) {
    if (useSettingStore().get("Comfy.Workflow.ShowMissingNodesWarning")) {
      useDialogService().showLoadWorkflowWarning({ missingNodeTypes });
    }
  }
  // @ts-expect-error fixme ts strict error
  #showMissingModelsError(missingModels, paths) {
    if (useSettingStore().get("Comfy.Workflow.ShowMissingModelsWarning")) {
      useDialogService().showMissingModelsWarning({
        missingModels,
        paths
      });
    }
  }
  async loadGraphData(graphData, clean = true, restore_view = true, workflow = null, { showMissingNodesDialog = true, showMissingModelsDialog = true } = {}) {
    if (clean !== false) {
      this.clean();
    }
    let reset_invalid_values = false;
    if (!graphData) {
      graphData = defaultGraph;
      reset_invalid_values = true;
    }
    graphData = clone$3(graphData);
    if (useSettingStore().get("Comfy.Validation.Workflows")) {
      const validatedGraphData = await validateComfyWorkflow(
        graphData,
        /* onError=*/
        (err) => {
          useToastStore().addAlert(err);
        }
      );
      graphData = validatedGraphData ?? graphData;
    }
    useWorkflowService().beforeLoadNewGraph();
    const missingNodeTypes = [];
    const missingModels = [];
    await useExtensionService().invokeExtensionsAsync(
      "beforeConfigureGraph",
      graphData,
      missingNodeTypes
      // TODO: missingModels
    );
    const embeddedModels = [];
    for (let n2 of graphData.nodes) {
      if (n2.type == "T2IAdapterLoader") n2.type = "ControlNetLoader";
      if (n2.type == "ConditioningAverage ") n2.type = "ConditioningAverage";
      if (n2.type == "SDV_img2vid_Conditioning")
        n2.type = "SVD_img2vid_Conditioning";
      if (!(n2.type in LiteGraph.registered_node_types)) {
        missingNodeTypes.push(n2.type);
        n2.type = sanitizeNodeName(n2.type);
      }
      if (n2.properties?.models?.length)
        embeddedModels.push(...n2.properties.models);
    }
    const workflowSchemaV1Models = graphData.models;
    if (workflowSchemaV1Models?.length)
      embeddedModels.push(...workflowSchemaV1Models);
    const getModelKey = /* @__PURE__ */ __name((model) => model.url || model.hash, "getModelKey");
    const validModels = embeddedModels.filter(getModelKey);
    const uniqueModels = _.uniqBy(validModels, getModelKey);
    if (uniqueModels.length && useSettingStore().get("Comfy.Workflow.ShowMissingModelsWarning")) {
      const modelStore = useModelStore();
      await modelStore.loadModelFolders();
      for (const m2 of uniqueModels) {
        const modelFolder = await modelStore.getLoadedModelFolder(m2.directory);
        if (!modelFolder) m2.directory_invalid = true;
        const modelsAvailable = modelFolder?.models;
        const modelExists = modelsAvailable && Object.values(modelsAvailable).some(
          (model) => model.file_name === m2.name
        );
        if (!modelExists) missingModels.push(m2);
      }
    }
    try {
      this.graph.configure(graphData);
      if (restore_view && useSettingStore().get("Comfy.EnableWorkflowViewRestore") && graphData.extra?.ds) {
        this.canvas.ds.offset = graphData.extra.ds.offset;
        this.canvas.ds.scale = graphData.extra.ds.scale;
      }
    } catch (error2) {
      let errorHint = [];
      const filename = (
        // @ts-expect-error fixme ts strict error
        error2.fileName || // @ts-expect-error fixme ts strict error
        (error2.stack || "").match(/(\/extensions\/.*\.js)/)?.[1]
      );
      const pos = (filename || "").indexOf("/extensions/");
      if (pos > -1) {
        errorHint.push(
          $el("span", {
            textContent: "This may be due to the following script:"
          }),
          $el("br"),
          $el("span", {
            style: {
              fontWeight: "bold"
            },
            textContent: filename.substring(pos)
          })
        );
      }
      this.ui.dialog.show(
        $el("div", [
          $el("p", {
            textContent: "Loading aborted due to error reloading workflow data"
          }),
          $el("pre", {
            style: { padding: "5px", backgroundColor: "rgba(255,0,0,0.2)" },
            // @ts-expect-error fixme ts strict error
            textContent: error2.toString()
          }),
          $el("pre", {
            style: {
              padding: "5px",
              color: "#ccc",
              fontSize: "10px",
              maxHeight: "50vh",
              overflow: "auto",
              backgroundColor: "rgba(0,0,0,0.2)"
            },
            // @ts-expect-error fixme ts strict error
            textContent: error2.stack || "No stacktrace available"
          }),
          ...errorHint
        ]).outerHTML
      );
      return;
    }
    for (const node3 of this.graph.nodes) {
      const size = node3.computeSize();
      size[0] = Math.max(node3.size[0], size[0]);
      size[1] = Math.max(node3.size[1], size[1]);
      node3.setSize(size);
      if (node3.widgets) {
        for (let widget of node3.widgets) {
          if (node3.type == "KSampler" || node3.type == "KSamplerAdvanced") {
            if (widget.name == "sampler_name") {
              if (typeof widget.value === "string" && widget.value.startsWith("sample_")) {
                widget.value = widget.value.slice(7);
              }
            }
          }
          if (node3.type == "KSampler" || node3.type == "KSamplerAdvanced" || node3.type == "PrimitiveNode") {
            if (widget.name == "control_after_generate") {
              if (widget.value === true) {
                widget.value = "randomize";
              } else if (widget.value === false) {
                widget.value = "fixed";
              }
            }
          }
          if (reset_invalid_values) {
            if (widget.type == "combo") {
              if (
                // @ts-expect-error fixme ts strict error
                !widget.options.values.includes(widget.value) && // @ts-expect-error fixme ts strict error
                widget.options.values.length > 0
              ) {
                widget.value = widget.options.values[0];
              }
            }
          }
        }
      }
      useExtensionService().invokeExtensions("loadedGraphNode", node3);
    }
    if (missingNodeTypes.length && showMissingNodesDialog) {
      this.#showMissingNodesError(missingNodeTypes);
    }
    if (missingModels.length && showMissingModelsDialog) {
      const paths = await api.getFolderPaths();
      this.#showMissingModelsError(missingModels, paths);
    }
    await useExtensionService().invokeExtensionsAsync(
      "afterConfigureGraph",
      missingNodeTypes
    );
    await useWorkflowService().afterLoadNewGraph(
      workflow,
      // @ts-expect-error zod types issue. Will be fixed after we enable ts-strict
      this.graph.serialize()
    );
    requestAnimationFrame(() => {
      this.graph.setDirtyCanvas(true, true);
    });
  }
  /**
   * Serializes a graph using preferred user settings.
   * @param graph The litegraph to serialize.
   * @returns A serialized graph (aka workflow) with preferred user settings.
   */
  serializeGraph(graph = this.graph) {
    const sortNodes = useSettingStore().get("Comfy.Workflow.SortNodeIdOnSave");
    return graph.serialize({ sortNodes });
  }
  async graphToPrompt(graph = this.graph) {
    return graphToPrompt(graph, {
      sortNodes: useSettingStore().get("Comfy.Workflow.SortNodeIdOnSave")
    });
  }
  // @ts-expect-error fixme ts strict error
  #formatPromptError(error2) {
    if (error2 == null) {
      return "(unknown error)";
    } else if (typeof error2 === "string") {
      return error2;
    } else if (error2.stack && error2.message) {
      return error2.toString();
    } else if (error2.response) {
      let message3 = error2.response.error.message;
      if (error2.response.error.details)
        message3 += ": " + error2.response.error.details;
      for (const [_2, nodeError] of Object.entries(error2.response.node_errors)) {
        message3 += "\n" + nodeError.class_type + ":";
        for (const errorReason of nodeError.errors) {
          message3 += "\n    - " + errorReason.message + ": " + errorReason.details;
        }
      }
      return message3;
    }
    return "(unknown error)";
  }
  async queuePrompt(number2, batchCount = 1) {
    this.#queueItems.push({ number: number2, batchCount });
    if (this.#processingQueue) {
      return;
    }
    this.#processingQueue = true;
    this.lastNodeErrors = null;
    try {
      while (this.#queueItems.length) {
        ;
        ({ number: number2, batchCount } = this.#queueItems.pop());
        for (let i2 = 0; i2 < batchCount; i2++) {
          executeWidgetsCallback(this.graph.nodes, "beforeQueued");
          const p2 = await this.graphToPrompt();
          try {
            const res = await api.queuePrompt(number2, p2);
            this.lastNodeErrors = res.node_errors;
            if (this.lastNodeErrors.length > 0) {
              this.canvas.draw(true, true);
            } else {
              try {
                useExecutionStore().storePrompt({
                  // @ts-expect-error fixme ts strict error
                  id: res.prompt_id,
                  nodes: Object.keys(p2.output),
                  workflow: useWorkspaceStore().workflow.activeWorkflow
                });
              } catch (error2) {
              }
            }
          } catch (error2) {
            const formattedError = this.#formatPromptError(error2);
            this.ui.dialog.show(formattedError);
            if (error2.response) {
              this.lastNodeErrors = error2.response.node_errors;
              this.canvas.draw(true, true);
            }
            break;
          }
          executeWidgetsCallback(
            // @ts-expect-error fixme ts strict error
            p2.workflow.nodes.map((n2) => this.graph.getNodeById(n2.id)),
            "afterQueued"
          );
          this.canvas.draw(true, true);
          await this.ui.queue.update();
        }
      }
    } finally {
      this.#processingQueue = false;
    }
    api.dispatchCustomEvent("promptQueued", { number: number2, batchCount });
    return !this.lastNodeErrors;
  }
  // @ts-expect-error fixme ts strict error
  showErrorOnFileLoad(file) {
    this.ui.dialog.show(
      $el("div", [
        $el("p", { textContent: `Unable to find workflow in ${file.name}` })
      ]).outerHTML
    );
  }
  /**
   * Loads workflow data from the specified file
   * @param {File} file
   */
  // @ts-expect-error fixme ts strict error
  async handleFile(file) {
    const removeExt = /* @__PURE__ */ __name((f2) => {
      if (!f2) return f2;
      const p2 = f2.lastIndexOf(".");
      if (p2 === -1) return f2;
      return f2.substring(0, p2);
    }, "removeExt");
    const fileName = removeExt(file.name);
    if (file.type === "image/png") {
      const pngInfo = await getPngMetadata(file);
      if (pngInfo?.workflow) {
        await this.loadGraphData(
          JSON.parse(pngInfo.workflow),
          true,
          true,
          fileName
        );
      } else if (pngInfo?.prompt) {
        this.loadApiJson(JSON.parse(pngInfo.prompt), fileName);
      } else if (pngInfo?.parameters) {
        useWorkflowService().beforeLoadNewGraph();
        importA1111(this.graph, pngInfo.parameters);
        useWorkflowService().afterLoadNewGraph(fileName, this.serializeGraph());
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else if (file.type === "image/webp") {
      const pngInfo = await getWebpMetadata(file);
      const workflow = pngInfo?.workflow || pngInfo?.Workflow;
      const prompt = pngInfo?.prompt || pngInfo?.Prompt;
      if (workflow) {
        this.loadGraphData(JSON.parse(workflow), true, true, fileName);
      } else if (prompt) {
        this.loadApiJson(JSON.parse(prompt), fileName);
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else if (file.type === "audio/flac" || file.type === "audio/x-flac") {
      const pngInfo = await getFlacMetadata(file);
      const workflow = pngInfo?.workflow || pngInfo?.Workflow;
      const prompt = pngInfo?.prompt || pngInfo?.Prompt;
      if (workflow) {
        this.loadGraphData(JSON.parse(workflow), true, true, fileName);
      } else if (prompt) {
        this.loadApiJson(JSON.parse(prompt), fileName);
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else if (file.type === "video/webm") {
      const webmInfo = await getFromWebmFile(file);
      if (webmInfo.workflow) {
        this.loadGraphData(webmInfo.workflow, true, true, fileName);
      } else if (webmInfo.prompt) {
        this.loadApiJson(webmInfo.prompt, fileName);
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else if (file.type === "model/gltf-binary") {
      const gltfInfo = await getGltfBinaryMetadata(file);
      if (gltfInfo.workflow) {
        this.loadGraphData(gltfInfo.workflow, true, true, fileName);
      } else if (gltfInfo.prompt) {
        this.loadApiJson(gltfInfo.prompt, fileName);
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else if (file.type === "application/json" || file.name?.endsWith(".json")) {
      const reader = new FileReader();
      reader.onload = async () => {
        const readerResult = reader.result;
        const jsonContent = JSON.parse(readerResult);
        if (jsonContent?.templates) {
          this.loadTemplateData(jsonContent);
        } else if (this.isApiJson(jsonContent)) {
          this.loadApiJson(jsonContent, fileName);
        } else {
          await this.loadGraphData(
            JSON.parse(readerResult),
            true,
            false,
            fileName
          );
        }
      };
      reader.readAsText(file);
    } else if (file.name?.endsWith(".latent") || file.name?.endsWith(".safetensors")) {
      const info = await getLatentMetadata(file);
      if (info.workflow) {
        await this.loadGraphData(
          // @ts-expect-error
          JSON.parse(info.workflow),
          true,
          true,
          fileName
        );
      } else if (info.prompt) {
        this.loadApiJson(JSON.parse(info.prompt));
      } else {
        this.showErrorOnFileLoad(file);
      }
    } else {
      this.showErrorOnFileLoad(file);
    }
  }
  // @ts-expect-error fixme ts strict error
  isApiJson(data30) {
    return Object.values(data30).every((v2) => v2.class_type);
  }
  // @ts-expect-error fixme ts strict error
  loadApiJson(apiData, fileName) {
    useWorkflowService().beforeLoadNewGraph();
    const missingNodeTypes = Object.values(apiData).filter(
      // @ts-expect-error
      (n2) => !LiteGraph.registered_node_types[n2.class_type]
    );
    if (missingNodeTypes.length) {
      this.#showMissingNodesError(
        // @ts-expect-error
        missingNodeTypes.map((t2) => t2.class_type)
      );
      return;
    }
    const ids = Object.keys(apiData);
    app$2.graph.clear();
    for (const id4 of ids) {
      const data30 = apiData[id4];
      const node3 = LiteGraph.createNode(data30.class_type);
      node3.id = isNaN(+id4) ? id4 : +id4;
      node3.title = data30._meta?.title ?? node3.title;
      app$2.graph.add(node3);
    }
    for (const id4 of ids) {
      const data30 = apiData[id4];
      const node3 = app$2.graph.getNodeById(id4);
      for (const input in data30.inputs ?? {}) {
        const value3 = data30.inputs[input];
        if (value3 instanceof Array) {
          const [fromId, fromSlot] = value3;
          const fromNode = app$2.graph.getNodeById(fromId);
          let toSlot = node3.inputs?.findIndex((inp) => inp.name === input);
          if (toSlot == null || toSlot === -1) {
            try {
              const widget = node3.widgets?.find((w2) => w2.name === input);
              if (widget && node3.convertWidgetToInput?.(widget)) {
                toSlot = node3.inputs?.length - 1;
              }
            } catch (error2) {
            }
          }
          if (toSlot != null || toSlot !== -1) {
            fromNode.connect(fromSlot, node3, toSlot);
          }
        } else {
          const widget = node3.widgets?.find((w2) => w2.name === input);
          if (widget) {
            widget.value = value3;
            widget.callback?.(value3);
          }
        }
      }
    }
    app$2.graph.arrange();
    for (const id4 of ids) {
      const data30 = apiData[id4];
      const node3 = app$2.graph.getNodeById(id4);
      for (const input in data30.inputs ?? {}) {
        const value3 = data30.inputs[input];
        if (value3 instanceof Array) {
          const [fromId, fromSlot] = value3;
          const fromNode = app$2.graph.getNodeById(fromId);
          let toSlot = node3.inputs?.findIndex((inp) => inp.name === input);
          if (toSlot == null || toSlot === -1) {
            try {
              const widget = node3.widgets?.find((w2) => w2.name === input);
              if (widget && node3.convertWidgetToInput?.(widget)) {
                toSlot = node3.inputs?.length - 1;
              }
            } catch (error2) {
            }
          }
          if (toSlot != null || toSlot !== -1) {
            fromNode.connect(fromSlot, node3, toSlot);
          }
        } else {
          const widget = node3.widgets?.find((w2) => w2.name === input);
          if (widget) {
            widget.value = value3;
            widget.callback?.(value3);
          }
        }
      }
    }
    app$2.graph.arrange();
    useWorkflowService().afterLoadNewGraph(fileName, this.serializeGraph());
  }
  /**
   * Registers a Comfy web extension with the app
   * @param {ComfyExtension} extension
   * @deprecated Use useExtensionService().registerExtension instead
   */
  registerExtension(extension) {
    useExtensionService().registerExtension(extension);
  }
  /**
   * Refresh combo list on whole nodes
   */
  async refreshComboInNodes() {
    const requestToastMessage = {
      severity: "info",
      summary: "Update",
      detail: "Update requested"
    };
    if (this.vueAppReady) {
      useToastStore().add(requestToastMessage);
    }
    const defs = await this.#getNodeDefs();
    for (const nodeId in defs) {
      this.registerNodeDef(nodeId, defs[nodeId]);
    }
    for (const node3 of this.graph.nodes) {
      const def2 = defs[node3.type];
      node3.refreshComboInNode?.(defs);
      if (!def2?.input) continue;
      for (const widget of node3.widgets) {
        if (widget.type === "combo") {
          if (def2["input"].required?.[widget.name] !== void 0) {
            widget.options.values = def2["input"].required[widget.name][0];
          } else if (def2["input"].optional?.[widget.name] !== void 0) {
            widget.options.values = def2["input"].optional[widget.name][0];
          }
        }
      }
    }
    await useExtensionService().invokeExtensionsAsync(
      "refreshComboInNodes",
      defs
    );
    if (this.vueAppReady) {
      this.updateVueAppNodeDefs(defs);
      useToastStore().remove(requestToastMessage);
      useToastStore().add({
        severity: "success",
        summary: "Updated",
        detail: "Node definitions updated",
        life: 1e3
      });
    }
  }
  /**
   * Frees memory allocated to image preview blobs for a specific node, by revoking the URLs associated with them.
   * @param nodeId ID of the node to revoke all preview images of
   */
  revokePreviews(nodeId) {
    if (!this.nodePreviewImages[nodeId]?.[Symbol.iterator]) return;
    for (const url of this.nodePreviewImages[nodeId]) {
      URL.revokeObjectURL(url);
    }
  }
  /**
   * Clean current state
   */
  clean() {
    this.nodeOutputs = {};
    for (const id4 of Object.keys(this.nodePreviewImages)) {
      this.revokePreviews(id4);
    }
    this.nodePreviewImages = {};
    this.lastNodeErrors = null;
    this.lastExecutionError = null;
  }
  clientPosToCanvasPos(pos) {
    const rect = this.canvasContainer.getBoundingClientRect();
    const containerOffsets = [rect.left, rect.top];
    return _.zip(pos, this.canvas.ds.offset, containerOffsets).map(
      // @ts-expect-error fixme ts strict error
      ([p2, o1, o2]) => (p2 - o2) / this.canvas.ds.scale - o1
    );
  }
  canvasPosToClientPos(pos) {
    const rect = this.canvasContainer.getBoundingClientRect();
    const containerOffsets = [rect.left, rect.top];
    return _.zip(pos, this.canvas.ds.offset, containerOffsets).map(
      // @ts-expect-error fixme ts strict error
      ([p2, o1, o2]) => (p2 + o1) * this.canvas.ds.scale + o2
    );
  }
}
const app$2 = new ComfyApp();
window.comfyAPI = window.comfyAPI || {};
window.comfyAPI.app = window.comfyAPI.app || {};
window.comfyAPI.app.ANIM_PREVIEW_WIDGET = ANIM_PREVIEW_WIDGET;
window.comfyAPI.app.ComfyApp = ComfyApp;
window.comfyAPI.app.app = app$2;
const useColorPaletteService = /* @__PURE__ */ __name(() => {
  const colorPaletteStore = useColorPaletteStore();
  const settingStore = useSettingStore();
  const nodeDefStore = useNodeDefStore();
  const { wrapWithErrorHandling, wrapWithErrorHandlingAsync } = useErrorHandling();
  const validateColorPalette = /* @__PURE__ */ __name((data30) => {
    const result = paletteSchema.safeParse(data30);
    if (result.success) return result.data;
    const error2 = fromZodError(result.error);
    throw new Error(`Invalid color palette against zod schema:
${error2}`);
  }, "validateColorPalette");
  const persistCustomColorPalettes = /* @__PURE__ */ __name(() => {
    settingStore.set(
      "Comfy.CustomColorPalettes",
      colorPaletteStore.customPalettes
    );
  }, "persistCustomColorPalettes");
  const deleteCustomColorPalette = /* @__PURE__ */ __name((colorPaletteId) => {
    colorPaletteStore.deleteCustomPalette(colorPaletteId);
    persistCustomColorPalettes();
  }, "deleteCustomColorPalette");
  const addCustomColorPalette = /* @__PURE__ */ __name((colorPalette) => {
    validateColorPalette(colorPalette);
    colorPaletteStore.addCustomPalette(colorPalette);
    persistCustomColorPalettes();
  }, "addCustomColorPalette");
  const loadLinkColorPalette = /* @__PURE__ */ __name((linkColorPalette) => {
    const types = Object.fromEntries(
      Array.from(nodeDefStore.nodeDataTypes).map((type) => [type, ""])
    );
    Object.assign(
      app$2.canvas.default_connection_color_byType,
      types,
      linkColorPalette
    );
    Object.assign(LGraphCanvas.link_type_colors, types, linkColorPalette);
  }, "loadLinkColorPalette");
  const loadLiteGraphColorPalette = /* @__PURE__ */ __name((palette) => {
    app$2.bypassBgColor = palette.NODE_BYPASS_BGCOLOR;
    app$2.canvas.node_title_color = palette.NODE_TITLE_COLOR;
    app$2.canvas.default_link_color = palette.LINK_COLOR;
    app$2.canvas.background_image = palette.BACKGROUND_IMAGE;
    app$2.canvas.clear_background_color = palette.CLEAR_BACKGROUND_COLOR;
    app$2.canvas._pattern = void 0;
    for (const [key, value3] of Object.entries(palette)) {
      if (Object.prototype.hasOwnProperty.call(LiteGraph, key)) {
        if (key === "NODE_DEFAULT_SHAPE" && typeof value3 === "string") {
          console.warn(
            `litegraph_base.NODE_DEFAULT_SHAPE only accepts [${[
              LiteGraph.BOX_SHAPE,
              LiteGraph.ROUND_SHAPE,
              LiteGraph.CARD_SHAPE
            ].join(", ")}] but got ${value3}`
          );
          LiteGraph.NODE_DEFAULT_SHAPE = LiteGraph.ROUND_SHAPE;
        } else {
          ;
          LiteGraph[key] = value3;
        }
      }
    }
  }, "loadLiteGraphColorPalette");
  const loadComfyColorPalette = /* @__PURE__ */ __name((comfyColorPalette) => {
    if (comfyColorPalette) {
      const rootStyle = document.documentElement.style;
      for (const [key, value3] of Object.entries(comfyColorPalette)) {
        rootStyle.setProperty("--" + key, value3);
      }
    }
  }, "loadComfyColorPalette");
  const loadColorPalette = /* @__PURE__ */ __name(async (colorPaletteId) => {
    const colorPalette = colorPaletteStore.palettesLookup[colorPaletteId];
    if (!colorPalette) {
      throw new Error(`Color palette ${colorPaletteId} not found`);
    }
    const completedPalette = colorPaletteStore.completePalette(colorPalette);
    loadLinkColorPalette(completedPalette.colors.node_slot);
    loadLiteGraphColorPalette(completedPalette.colors.litegraph_base);
    loadComfyColorPalette(completedPalette.colors.comfy_base);
    app$2.canvas.setDirty(true, true);
    colorPaletteStore.activePaletteId = colorPaletteId;
  }, "loadColorPalette");
  const exportColorPalette = /* @__PURE__ */ __name((colorPaletteId) => {
    const colorPalette = colorPaletteStore.palettesLookup[colorPaletteId];
    if (!colorPalette) {
      throw new Error(`Color palette ${colorPaletteId} not found`);
    }
    downloadBlob(
      colorPalette.id + ".json",
      new Blob([JSON.stringify(toRaw(colorPalette), null, 2)], {
        type: "application/json"
      })
    );
  }, "exportColorPalette");
  const importColorPalette = /* @__PURE__ */ __name(async () => {
    const file = await uploadFile("application/json");
    const text2 = await file.text();
    const palette = JSON.parse(text2);
    addCustomColorPalette(palette);
    return palette;
  }, "importColorPalette");
  return {
    addCustomColorPalette: wrapWithErrorHandling(addCustomColorPalette),
    deleteCustomColorPalette: wrapWithErrorHandling(deleteCustomColorPalette),
    loadColorPalette: wrapWithErrorHandlingAsync(loadColorPalette),
    exportColorPalette: wrapWithErrorHandling(exportColorPalette),
    importColorPalette: wrapWithErrorHandlingAsync(importColorPalette)
  };
}, "useColorPaletteService");
var TaskItemDisplayStatus = /* @__PURE__ */ ((TaskItemDisplayStatus2) => {
  TaskItemDisplayStatus2["Running"] = "Running";
  TaskItemDisplayStatus2["Pending"] = "Pending";
  TaskItemDisplayStatus2["Completed"] = "Completed";
  TaskItemDisplayStatus2["Failed"] = "Failed";
  TaskItemDisplayStatus2["Cancelled"] = "Cancelled";
  return TaskItemDisplayStatus2;
})(TaskItemDisplayStatus || {});
class ResultItemImpl {
  static {
    __name(this, "ResultItemImpl");
  }
  filename;
  subfolder;
  type;
  nodeId;
  // 'audio' | 'images' | ...
  mediaType;
  // VHS output specific fields
  format;
  frame_rate;
  constructor(obj) {
    this.filename = obj.filename ?? "";
    this.subfolder = obj.subfolder ?? "";
    this.type = obj.type ?? "";
    this.nodeId = obj.nodeId;
    this.mediaType = obj.mediaType;
    this.format = obj.format;
    this.frame_rate = obj.frame_rate;
  }
  get urlParams() {
    const params = new URLSearchParams();
    params.set("filename", this.filename);
    params.set("type", this.type);
    params.set("subfolder", this.subfolder);
    if (this.format) {
      params.set("format", this.format);
    }
    if (this.frame_rate) {
      params.set("frame_rate", this.frame_rate.toString());
    }
    return params;
  }
  /**
   * VHS advanced preview URL. `/viewvideo` endpoint is provided by VHS node.
   *
   * `/viewvideo` always returns a webm file.
   */
  get vhsAdvancedPreviewUrl() {
    return api.apiURL("/viewvideo?" + this.urlParams);
  }
  get url() {
    return api.apiURL("/view?" + this.urlParams);
  }
  get urlWithTimestamp() {
    return `${this.url}&t=${+/* @__PURE__ */ new Date()}`;
  }
  get isVhsFormat() {
    return !!this.format && !!this.frame_rate;
  }
  get htmlVideoType() {
    if (this.isWebm) {
      return "video/webm";
    }
    if (this.isVhsFormat) {
      if (this.format?.endsWith("webm")) {
        return "video/webm";
      }
      if (this.format?.endsWith("mp4")) {
        return "video/mp4";
      }
    }
    return;
  }
  get isVideo() {
    return this.mediaType === "video" || !!this.format?.startsWith("video/");
  }
  get isGif() {
    return this.filename.endsWith(".gif");
  }
  get isWebp() {
    return this.filename.endsWith(".webp");
  }
  get isWebm() {
    return this.filename.endsWith(".webm");
  }
  get isImage() {
    return this.mediaType === "images" || this.isGif || this.isWebp;
  }
  get supportsPreview() {
    return this.isImage || this.isVideo;
  }
}
class TaskItemImpl {
  static {
    __name(this, "TaskItemImpl");
  }
  taskType;
  prompt;
  status;
  outputs;
  flatOutputs;
  constructor(taskType, prompt, status, outputs, flatOutputs) {
    this.taskType = taskType;
    this.prompt = prompt;
    this.status = status;
    this.outputs = _.mapValues(
      outputs ?? {},
      (nodeOutputs) => _.omit(nodeOutputs, "animated")
    );
    this.flatOutputs = flatOutputs ?? this.calculateFlatOutputs();
  }
  calculateFlatOutputs() {
    if (!this.outputs) {
      return [];
    }
    return Object.entries(this.outputs).flatMap(
      ([nodeId, nodeOutputs]) => Object.entries(nodeOutputs).flatMap(
        ([mediaType, items2]) => items2.map(
          (item3) => new ResultItemImpl({
            ...item3,
            nodeId,
            mediaType
          })
        )
      )
    );
  }
  get previewOutput() {
    return this.flatOutputs.find(
      // Prefer saved media files over the temp previews
      (output) => output.type === "output" && output.supportsPreview
    ) ?? this.flatOutputs.find((output) => output.supportsPreview);
  }
  get apiTaskType() {
    switch (this.taskType) {
      case "Running":
      case "Pending":
        return "queue";
      case "History":
        return "history";
    }
  }
  get key() {
    return this.promptId + this.displayStatus;
  }
  get queueIndex() {
    return this.prompt[0];
  }
  get promptId() {
    return this.prompt[1];
  }
  get promptInputs() {
    return this.prompt[2];
  }
  get extraData() {
    return this.prompt[3];
  }
  get outputsToExecute() {
    return this.prompt[4];
  }
  get extraPngInfo() {
    return this.extraData.extra_pnginfo;
  }
  get clientId() {
    return this.extraData.client_id;
  }
  get workflow() {
    return this.extraPngInfo?.workflow;
  }
  get messages() {
    return this.status?.messages || [];
  }
  get interrupted() {
    return _.some(
      this.messages,
      (message3) => message3[0] === "execution_interrupted"
    );
  }
  get isHistory() {
    return this.taskType === "History";
  }
  get isRunning() {
    return this.taskType === "Running";
  }
  get displayStatus() {
    switch (this.taskType) {
      case "Running":
        return "Running";
      case "Pending":
        return "Pending";
      case "History":
        if (this.interrupted) return "Cancelled";
        switch (this.status.status_str) {
          case "success":
            return "Completed";
          case "error":
            return "Failed";
        }
    }
  }
  get executionStartTimestamp() {
    const message3 = this.messages.find(
      (message22) => message22[0] === "execution_start"
    );
    return message3 ? message3[1].timestamp : void 0;
  }
  get executionEndTimestamp() {
    const messages2 = this.messages.filter(
      (message3) => [
        "execution_success",
        "execution_interrupted",
        "execution_error"
      ].includes(message3[0])
    );
    if (!messages2.length) {
      return void 0;
    }
    return _.max(messages2.map((message3) => message3[1].timestamp));
  }
  get executionTime() {
    if (!this.executionStartTimestamp || !this.executionEndTimestamp) {
      return void 0;
    }
    return this.executionEndTimestamp - this.executionStartTimestamp;
  }
  get executionTimeInSeconds() {
    return this.executionTime !== void 0 ? this.executionTime / 1e3 : void 0;
  }
  async loadWorkflow(app2) {
    if (!this.workflow) {
      return;
    }
    await app2.loadGraphData(toRaw(this.workflow));
    if (this.outputs) {
      app2.nodeOutputs = toRaw(this.outputs);
    }
  }
  flatten() {
    if (this.displayStatus !== "Completed") {
      return [this];
    }
    return this.flatOutputs.map(
      (output, i2) => new TaskItemImpl(
        this.taskType,
        [
          this.queueIndex,
          `${this.promptId}-${i2}`,
          this.promptInputs,
          this.extraData,
          this.outputsToExecute
        ],
        this.status,
        {
          [output.nodeId]: {
            [output.mediaType]: [output]
          }
        },
        [output]
      )
    );
  }
}
const useQueueStore = /* @__PURE__ */ defineStore("queue", () => {
  const runningTasks = ref([]);
  const pendingTasks = ref([]);
  const historyTasks = ref([]);
  const maxHistoryItems = ref(64);
  const isLoading = ref(false);
  const tasks = computed(
    () => [
      ...pendingTasks.value,
      ...runningTasks.value,
      ...historyTasks.value
    ]
  );
  const flatTasks = computed(
    () => tasks.value.flatMap((task) => task.flatten())
  );
  const lastHistoryQueueIndex = computed(
    () => historyTasks.value.length ? historyTasks.value[0].queueIndex : -1
  );
  const hasPendingTasks = computed(() => pendingTasks.value.length > 0);
  const update = /* @__PURE__ */ __name(async () => {
    isLoading.value = true;
    try {
      const [queue2, history2] = await Promise.all([
        api.getQueue(),
        api.getHistory(maxHistoryItems.value)
      ]);
      const toClassAll = /* @__PURE__ */ __name((tasks2) => tasks2.map(
        (task) => new TaskItemImpl(
          task.taskType,
          task.prompt,
          // status and outputs only exist on history tasks
          "status" in task ? task.status : void 0,
          "outputs" in task ? task.outputs : void 0
        )
      ).sort((a2, b2) => b2.queueIndex - a2.queueIndex), "toClassAll");
      runningTasks.value = toClassAll(queue2.Running);
      pendingTasks.value = toClassAll(queue2.Pending);
      const allIndex = new Set(
        history2.History.map((item3) => item3.prompt[0])
      );
      const newHistoryItems = toClassAll(
        history2.History.filter(
          (item3) => item3.prompt[0] > lastHistoryQueueIndex.value
        )
      );
      const existingHistoryItems = historyTasks.value.filter(
        (item3) => allIndex.has(item3.queueIndex)
      );
      historyTasks.value = [...newHistoryItems, ...existingHistoryItems].slice(0, maxHistoryItems.value).sort((a2, b2) => b2.queueIndex - a2.queueIndex);
    } finally {
      isLoading.value = false;
    }
  }, "update");
  const clear = /* @__PURE__ */ __name(async (targets = ["queue", "history"]) => {
    if (targets.length === 0) {
      return;
    }
    await Promise.all(targets.map((type) => api.clearItems(type)));
    await update();
  }, "clear");
  const deleteTask = /* @__PURE__ */ __name(async (task) => {
    await api.deleteItem(task.apiTaskType, task.promptId);
    await update();
  }, "deleteTask");
  return {
    runningTasks,
    pendingTasks,
    historyTasks,
    maxHistoryItems,
    isLoading,
    tasks,
    flatTasks,
    lastHistoryQueueIndex,
    hasPendingTasks,
    update,
    clear,
    delete: deleteTask
  };
});
const useQueuePendingTaskCountStore = /* @__PURE__ */ defineStore(
  "queuePendingTaskCount",
  {
    state: /* @__PURE__ */ __name(() => ({
      count: 0
    }), "state"),
    actions: {
      update(e2) {
        this.count = e2.detail?.exec_info?.queue_remaining || 0;
      }
    }
  }
);
const useQueueSettingsStore = /* @__PURE__ */ defineStore("queueSettingsStore", {
  state: /* @__PURE__ */ __name(() => ({
    mode: "disabled",
    batchCount: 1
  }), "state")
});
var theme$7 = /* @__PURE__ */ __name(function theme39(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-contextmenu {\n    background: ".concat(dt2("contextmenu.background"), ";\n    color: ").concat(dt2("contextmenu.color"), ";\n    border: 1px solid ").concat(dt2("contextmenu.border.color"), ";\n    border-radius: ").concat(dt2("contextmenu.border.radius"), ";\n    box-shadow: ").concat(dt2("contextmenu.shadow"), ";\n    min-width: 12.5rem;\n}\n\n.p-contextmenu-root-list,\n.p-contextmenu-submenu {\n    margin: 0;\n    padding: ").concat(dt2("contextmenu.list.padding"), ";\n    list-style: none;\n    outline: 0 none;\n    display: flex;\n    flex-direction: column;\n    gap: ").concat(dt2("contextmenu.list.gap"), ";\n}\n\n.p-contextmenu-submenu {\n    position: absolute;\n    display: flex;\n    flex-direction: column;\n    min-width: 100%;\n    z-index: 1;\n    background: ").concat(dt2("contextmenu.background"), ";\n    color: ").concat(dt2("contextmenu.color"), ";\n    border: 1px solid ").concat(dt2("contextmenu.border.color"), ";\n    border-radius: ").concat(dt2("contextmenu.border.radius"), ";\n    box-shadow: ").concat(dt2("contextmenu.shadow"), ";\n}\n\n.p-contextmenu-item {\n    position: relative;\n}\n\n.p-contextmenu-item-content {\n    transition: background ").concat(dt2("contextmenu.transition.duration"), ", color ").concat(dt2("contextmenu.transition.duration"), ";\n    border-radius: ").concat(dt2("contextmenu.item.border.radius"), ";\n    color: ").concat(dt2("contextmenu.item.color"), ";\n}\n\n.p-contextmenu-item-link {\n    cursor: pointer;\n    display: flex;\n    align-items: center;\n    text-decoration: none;\n    overflow: hidden;\n    position: relative;\n    color: inherit;\n    padding: ").concat(dt2("contextmenu.item.padding"), ";\n    gap: ").concat(dt2("contextmenu.item.gap"), ";\n    user-select: none;\n}\n\n.p-contextmenu-item-label {\n    line-height: 1;\n}\n\n.p-contextmenu-item-icon {\n    color: ").concat(dt2("contextmenu.item.icon.color"), ";\n}\n\n.p-contextmenu-submenu-icon {\n    color: ").concat(dt2("contextmenu.submenu.icon.color"), ";\n    margin-left: auto;\n    font-size: ").concat(dt2("contextmenu.submenu.icon.size"), ";\n    width: ").concat(dt2("contextmenu.submenu.icon.size"), ";\n    height: ").concat(dt2("contextmenu.submenu.icon.size"), ";\n}\n\n.p-contextmenu-submenu-icon:dir(rtl) {\n    margin-left: 0;\n    margin-right: auto;\n}\n\n.p-contextmenu-item.p-focus > .p-contextmenu-item-content {\n    color: ").concat(dt2("contextmenu.item.focus.color"), ";\n    background: ").concat(dt2("contextmenu.item.focus.background"), ";\n}\n\n.p-contextmenu-item.p-focus > .p-contextmenu-item-content .p-contextmenu-item-icon {\n    color: ").concat(dt2("contextmenu.item.icon.focus.color"), ";\n}\n\n.p-contextmenu-item.p-focus > .p-contextmenu-item-content .p-contextmenu-submenu-icon {\n    color: ").concat(dt2("contextmenu.submenu.icon.focus.color"), ";\n}\n\n.p-contextmenu-item:not(.p-disabled) > .p-contextmenu-item-content:hover {\n    color: ").concat(dt2("contextmenu.item.focus.color"), ";\n    background: ").concat(dt2("contextmenu.item.focus.background"), ";\n}\n\n.p-contextmenu-item:not(.p-disabled) > .p-contextmenu-item-content:hover .p-contextmenu-item-icon {\n    color: ").concat(dt2("contextmenu.item.icon.focus.color"), ";\n}\n\n.p-contextmenu-item:not(.p-disabled) > .p-contextmenu-item-content:hover .p-contextmenu-submenu-icon {\n    color: ").concat(dt2("contextmenu.submenu.icon.focus.color"), ";\n}\n\n.p-contextmenu-item-active > .p-contextmenu-item-content {\n    color: ").concat(dt2("contextmenu.item.active.color"), ";\n    background: ").concat(dt2("contextmenu.item.active.background"), ";\n}\n\n.p-contextmenu-item-active > .p-contextmenu-item-content .p-contextmenu-item-icon {\n    color: ").concat(dt2("contextmenu.item.icon.active.color"), ";\n}\n\n.p-contextmenu-item-active > .p-contextmenu-item-content .p-contextmenu-submenu-icon {\n    color: ").concat(dt2("contextmenu.submenu.icon.active.color"), ";\n}\n\n.p-contextmenu-separator {\n    border-block-start: 1px solid ").concat(dt2("contextmenu.separator.border.color"), ";\n}\n\n.p-contextmenu-enter-from,\n.p-contextmenu-leave-active {\n    opacity: 0;\n}\n\n.p-contextmenu-enter-active {\n    transition: opacity 250ms;\n}\n\n.p-contextmenu-mobile .p-contextmenu-submenu {\n    position: static;\n    box-shadow: none;\n    border: 0 none;\n    padding-inline-start: ").concat(dt2("tieredmenu.submenu.mobile.indent"), ";\n    padding-inline-end: 0;\n}\n\n.p-contextmenu-mobile .p-contextmenu-submenu-icon {\n    transition: transform 0.2s;\n    transform: rotate(90deg);\n}\n\n.p-contextmenu-mobile .p-contextmenu-item-active > .p-contextmenu-item-content .p-contextmenu-submenu-icon {\n    transform: rotate(-90deg);\n}\n");
}, "theme");
var classes$7 = {
  root: /* @__PURE__ */ __name(function root29(_ref2) {
    var instance = _ref2.instance;
    return ["p-contextmenu p-component", {
      "p-contextmenu-mobile": instance.queryMatches
    }];
  }, "root"),
  rootList: "p-contextmenu-root-list",
  item: /* @__PURE__ */ __name(function item2(_ref3) {
    var instance = _ref3.instance, processedItem = _ref3.processedItem;
    return ["p-contextmenu-item", {
      "p-contextmenu-item-active": instance.isItemActive(processedItem),
      "p-focus": instance.isItemFocused(processedItem),
      "p-disabled": instance.isItemDisabled(processedItem)
    }];
  }, "item"),
  itemContent: "p-contextmenu-item-content",
  itemLink: "p-contextmenu-item-link",
  itemIcon: "p-contextmenu-item-icon",
  itemLabel: "p-contextmenu-item-label",
  submenuIcon: "p-contextmenu-submenu-icon",
  submenu: "p-contextmenu-submenu",
  separator: "p-contextmenu-separator"
};
var ContextMenuStyle = BaseStyle$1.extend({
  name: "contextmenu",
  theme: theme$7,
  classes: classes$7
});
var script$d = {
  name: "AngleRightIcon",
  "extends": script$16
};
function render$c(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M5.25 11.1728C5.14929 11.1694 5.05033 11.1455 4.9592 11.1025C4.86806 11.0595 4.78666 10.9984 4.72 10.9228C4.57955 10.7822 4.50066 10.5916 4.50066 10.3928C4.50066 10.1941 4.57955 10.0035 4.72 9.86283L7.72 6.86283L4.72 3.86283C4.66067 3.71882 4.64765 3.55991 4.68275 3.40816C4.71785 3.25642 4.79932 3.11936 4.91585 3.01602C5.03238 2.91268 5.17819 2.84819 5.33305 2.83149C5.4879 2.81479 5.64411 2.84671 5.78 2.92283L9.28 6.42283C9.42045 6.56346 9.49934 6.75408 9.49934 6.95283C9.49934 7.15158 9.42045 7.34221 9.28 7.48283L5.78 10.9228C5.71333 10.9984 5.63193 11.0595 5.5408 11.1025C5.44966 11.1455 5.35071 11.1694 5.25 11.1728Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$c, "render$c");
script$d.render = render$c;
var script$2$2 = {
  name: "BaseContextMenu",
  "extends": script$1b,
  props: {
    model: {
      type: Array,
      "default": null
    },
    appendTo: {
      type: [String, Object],
      "default": "body"
    },
    autoZIndex: {
      type: Boolean,
      "default": true
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    global: {
      type: Boolean,
      "default": false
    },
    breakpoint: {
      type: String,
      "default": "960px"
    },
    tabindex: {
      type: Number,
      "default": 0
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: ContextMenuStyle,
  provide: /* @__PURE__ */ __name(function provide44() {
    return {
      $pcContextMenu: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$1$7 = {
  name: "ContextMenuSub",
  hostName: "ContextMenu",
  "extends": script$1b,
  emits: ["item-click", "item-mouseenter", "item-mousemove"],
  props: {
    items: {
      type: Array,
      "default": null
    },
    menuId: {
      type: String,
      "default": null
    },
    focusedItemId: {
      type: String,
      "default": null
    },
    root: {
      type: Boolean,
      "default": false
    },
    visible: {
      type: Boolean,
      "default": false
    },
    level: {
      type: Number,
      "default": 0
    },
    templates: {
      type: Object,
      "default": null
    },
    activeItemPath: {
      type: Object,
      "default": null
    },
    tabindex: {
      type: Number,
      "default": 0
    }
  },
  methods: {
    getItemId: /* @__PURE__ */ __name(function getItemId(processedItem) {
      return "".concat(this.menuId, "_").concat(processedItem.key);
    }, "getItemId"),
    getItemKey: /* @__PURE__ */ __name(function getItemKey(processedItem) {
      return this.getItemId(processedItem);
    }, "getItemKey"),
    getItemProp: /* @__PURE__ */ __name(function getItemProp(processedItem, name2, params) {
      return processedItem && processedItem.item ? resolve$4(processedItem.item[name2], params) : void 0;
    }, "getItemProp"),
    getItemLabel: /* @__PURE__ */ __name(function getItemLabel(processedItem) {
      return this.getItemProp(processedItem, "label");
    }, "getItemLabel"),
    getItemLabelId: /* @__PURE__ */ __name(function getItemLabelId(processedItem) {
      return "".concat(this.menuId, "_").concat(processedItem.key, "_label");
    }, "getItemLabelId"),
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions7(key, processedItem, index2) {
      return this.ptm(key, {
        context: {
          item: processedItem.item,
          active: this.isItemActive(processedItem),
          focused: this.isItemFocused(processedItem),
          disabled: this.isItemDisabled(processedItem),
          index: index2
        }
      });
    }, "getPTOptions"),
    isItemActive: /* @__PURE__ */ __name(function isItemActive(processedItem) {
      return this.activeItemPath.some(function(path) {
        return path.key === processedItem.key;
      });
    }, "isItemActive"),
    isItemVisible: /* @__PURE__ */ __name(function isItemVisible(processedItem) {
      return this.getItemProp(processedItem, "visible") !== false;
    }, "isItemVisible"),
    isItemDisabled: /* @__PURE__ */ __name(function isItemDisabled(processedItem) {
      return this.getItemProp(processedItem, "disabled");
    }, "isItemDisabled"),
    isItemFocused: /* @__PURE__ */ __name(function isItemFocused(processedItem) {
      return this.focusedItemId === this.getItemId(processedItem);
    }, "isItemFocused"),
    isItemGroup: /* @__PURE__ */ __name(function isItemGroup(processedItem) {
      return isNotEmpty$2(processedItem.items);
    }, "isItemGroup"),
    onItemClick: /* @__PURE__ */ __name(function onItemClick2(event, processedItem) {
      this.getItemProp(processedItem, "command", {
        originalEvent: event,
        item: processedItem.item
      });
      this.$emit("item-click", {
        originalEvent: event,
        processedItem,
        isFocus: true
      });
    }, "onItemClick"),
    onItemMouseEnter: /* @__PURE__ */ __name(function onItemMouseEnter(event, processedItem) {
      this.$emit("item-mouseenter", {
        originalEvent: event,
        processedItem
      });
    }, "onItemMouseEnter"),
    onItemMouseMove: /* @__PURE__ */ __name(function onItemMouseMove(event, processedItem) {
      this.$emit("item-mousemove", {
        originalEvent: event,
        processedItem,
        isFocus: true
      });
    }, "onItemMouseMove"),
    getAriaSetSize: /* @__PURE__ */ __name(function getAriaSetSize() {
      var _this = this;
      return this.items.filter(function(processedItem) {
        return _this.isItemVisible(processedItem) && !_this.getItemProp(processedItem, "separator");
      }).length;
    }, "getAriaSetSize"),
    getAriaPosInset: /* @__PURE__ */ __name(function getAriaPosInset5(index2) {
      var _this2 = this;
      return index2 - this.items.slice(0, index2).filter(function(processedItem) {
        return _this2.isItemVisible(processedItem) && _this2.getItemProp(processedItem, "separator");
      }).length + 1;
    }, "getAriaPosInset"),
    onEnter: /* @__PURE__ */ __name(function onEnter3() {
      nestedPosition$1(this.$refs.container, this.level);
    }, "onEnter"),
    getMenuItemProps: /* @__PURE__ */ __name(function getMenuItemProps2(processedItem, index2) {
      return {
        action: mergeProps$2({
          "class": this.cx("itemLink"),
          tabindex: -1
        }, this.getPTOptions("itemLink", processedItem, index2)),
        icon: mergeProps$2({
          "class": [this.cx("itemIcon"), this.getItemProp(processedItem, "icon")]
        }, this.getPTOptions("itemIcon", processedItem, index2)),
        label: mergeProps$2({
          "class": this.cx("itemLabel")
        }, this.getPTOptions("itemLabel", processedItem, index2)),
        submenuicon: mergeProps$2({
          "class": this.cx("submenuIcon")
        }, this.getPTOptions("submenuicon", processedItem, index2))
      };
    }, "getMenuItemProps")
  },
  components: {
    AngleRightIcon: script$d
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$n = ["tabindex"];
var _hoisted_2$i = ["id", "aria-label", "aria-disabled", "aria-expanded", "aria-haspopup", "aria-level", "aria-setsize", "aria-posinset", "data-p-active", "data-p-focused", "data-p-disabled"];
var _hoisted_3$a = ["onClick", "onMouseenter", "onMousemove"];
var _hoisted_4$5 = ["href", "target"];
var _hoisted_5$5 = ["id"];
var _hoisted_6$3 = ["id"];
function render$1$2(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_AngleRightIcon = resolveComponent("AngleRightIcon");
  var _component_ContextMenuSub = resolveComponent("ContextMenuSub", true);
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createBlock(Transition, mergeProps$2({
    name: "p-contextmenusub",
    onEnter: $options.onEnter
  }, _ctx.ptm("menu.transition")), {
    "default": withCtx(function() {
      return [($props.root ? true : $props.visible) ? (openBlock(), createElementBlock("ul", mergeProps$2({
        key: 0,
        ref: "container",
        tabindex: $props.tabindex
      }, _ctx.ptm("rootList")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($props.items, function(processedItem, index2) {
        return openBlock(), createElementBlock(Fragment$1, {
          key: $options.getItemKey(processedItem)
        }, [$options.isItemVisible(processedItem) && !$options.getItemProp(processedItem, "separator") ? (openBlock(), createElementBlock("li", mergeProps$2({
          key: 0,
          id: $options.getItemId(processedItem),
          style: $options.getItemProp(processedItem, "style"),
          "class": [_ctx.cx("item", {
            processedItem
          }), $options.getItemProp(processedItem, "class")],
          role: "menuitem",
          "aria-label": $options.getItemLabel(processedItem),
          "aria-disabled": $options.isItemDisabled(processedItem) || void 0,
          "aria-expanded": $options.isItemGroup(processedItem) ? $options.isItemActive(processedItem) : void 0,
          "aria-haspopup": $options.isItemGroup(processedItem) && !$options.getItemProp(processedItem, "to") ? "menu" : void 0,
          "aria-level": $props.level + 1,
          "aria-setsize": $options.getAriaSetSize(),
          "aria-posinset": $options.getAriaPosInset(index2),
          ref_for: true
        }, $options.getPTOptions("item", processedItem, index2), {
          "data-p-active": $options.isItemActive(processedItem),
          "data-p-focused": $options.isItemFocused(processedItem),
          "data-p-disabled": $options.isItemDisabled(processedItem)
        }), [createBaseVNode("div", mergeProps$2({
          "class": _ctx.cx("itemContent"),
          onClick: /* @__PURE__ */ __name(function onClick5($event) {
            return $options.onItemClick($event, processedItem);
          }, "onClick"),
          onMouseenter: /* @__PURE__ */ __name(function onMouseenter($event) {
            return $options.onItemMouseEnter($event, processedItem);
          }, "onMouseenter"),
          onMousemove: /* @__PURE__ */ __name(function onMousemove($event) {
            return $options.onItemMouseMove($event, processedItem);
          }, "onMousemove"),
          ref_for: true
        }, $options.getPTOptions("itemContent", processedItem, index2)), [!$props.templates.item ? withDirectives((openBlock(), createElementBlock("a", mergeProps$2({
          key: 0,
          href: $options.getItemProp(processedItem, "url"),
          "class": _ctx.cx("itemLink"),
          target: $options.getItemProp(processedItem, "target"),
          tabindex: "-1",
          ref_for: true
        }, $options.getPTOptions("itemLink", processedItem, index2)), [$props.templates.itemicon ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.itemicon), {
          key: 0,
          item: processedItem.item,
          "class": normalizeClass(_ctx.cx("itemIcon"))
        }, null, 8, ["item", "class"])) : $options.getItemProp(processedItem, "icon") ? (openBlock(), createElementBlock("span", mergeProps$2({
          key: 1,
          "class": [_ctx.cx("itemIcon"), $options.getItemProp(processedItem, "icon")],
          ref_for: true
        }, $options.getPTOptions("itemIcon", processedItem, index2)), null, 16)) : createCommentVNode("", true), createBaseVNode("span", mergeProps$2({
          id: $options.getItemLabelId(processedItem),
          "class": _ctx.cx("itemLabel"),
          ref_for: true
        }, $options.getPTOptions("itemLabel", processedItem, index2)), toDisplayString$1($options.getItemLabel(processedItem)), 17, _hoisted_5$5), $options.getItemProp(processedItem, "items") ? (openBlock(), createElementBlock(Fragment$1, {
          key: 2
        }, [$props.templates.submenuicon ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.submenuicon), {
          key: 0,
          active: $options.isItemActive(processedItem),
          "class": normalizeClass(_ctx.cx("submenuIcon"))
        }, null, 8, ["active", "class"])) : (openBlock(), createBlock(_component_AngleRightIcon, mergeProps$2({
          key: 1,
          "class": _ctx.cx("submenuIcon"),
          ref_for: true
        }, $options.getPTOptions("submenuicon", processedItem, index2)), null, 16, ["class"]))], 64)) : createCommentVNode("", true)], 16, _hoisted_4$5)), [[_directive_ripple]]) : (openBlock(), createBlock(resolveDynamicComponent($props.templates.item), {
          key: 1,
          item: processedItem.item,
          hasSubmenu: $options.getItemProp(processedItem, "items"),
          label: $options.getItemLabel(processedItem),
          props: $options.getMenuItemProps(processedItem, index2)
        }, null, 8, ["item", "hasSubmenu", "label", "props"]))], 16, _hoisted_3$a), $options.isItemVisible(processedItem) && $options.isItemGroup(processedItem) ? (openBlock(), createBlock(_component_ContextMenuSub, mergeProps$2({
          key: 0,
          id: $options.getItemId(processedItem) + "_list",
          role: "menu",
          "class": _ctx.cx("submenu"),
          menuId: $props.menuId,
          focusedItemId: $props.focusedItemId,
          items: processedItem.items,
          templates: $props.templates,
          activeItemPath: $props.activeItemPath,
          level: $props.level + 1,
          visible: $options.isItemActive(processedItem) && $options.isItemGroup(processedItem),
          pt: _ctx.pt,
          unstyled: _ctx.unstyled,
          onItemClick: _cache[0] || (_cache[0] = function($event) {
            return _ctx.$emit("item-click", $event);
          }),
          onItemMouseenter: _cache[1] || (_cache[1] = function($event) {
            return _ctx.$emit("item-mouseenter", $event);
          }),
          onItemMousemove: _cache[2] || (_cache[2] = function($event) {
            return _ctx.$emit("item-mousemove", $event);
          }),
          "aria-labelledby": $options.getItemLabelId(processedItem),
          ref_for: true
        }, _ctx.ptm("submenu")), null, 16, ["id", "class", "menuId", "focusedItemId", "items", "templates", "activeItemPath", "level", "visible", "pt", "unstyled", "aria-labelledby"])) : createCommentVNode("", true)], 16, _hoisted_2$i)) : createCommentVNode("", true), $options.isItemVisible(processedItem) && $options.getItemProp(processedItem, "separator") ? (openBlock(), createElementBlock("li", mergeProps$2({
          key: 1,
          id: $options.getItemId(processedItem),
          style: $options.getItemProp(processedItem, "style"),
          "class": [_ctx.cx("separator"), $options.getItemProp(processedItem, "class")],
          role: "separator",
          ref_for: true
        }, _ctx.ptm("separator")), null, 16, _hoisted_6$3)) : createCommentVNode("", true)], 64);
      }), 128))], 16, _hoisted_1$n)) : createCommentVNode("", true)];
    }),
    _: 1
  }, 16, ["onEnter"]);
}
__name(render$1$2, "render$1$2");
script$1$7.render = render$1$2;
var script$c = {
  name: "ContextMenu",
  "extends": script$2$2,
  inheritAttrs: false,
  emits: ["focus", "blur", "show", "hide", "before-show", "before-hide"],
  target: null,
  outsideClickListener: null,
  resizeListener: null,
  documentContextMenuListener: null,
  matchMediaListener: null,
  pageX: null,
  pageY: null,
  container: null,
  list: null,
  data: /* @__PURE__ */ __name(function data23() {
    return {
      id: this.$attrs.id,
      focused: false,
      focusedItemInfo: {
        index: -1,
        level: 0,
        parentKey: ""
      },
      activeItemPath: [],
      visible: false,
      submenuVisible: false,
      query: null,
      queryMatches: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId10(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    activeItemPath: /* @__PURE__ */ __name(function activeItemPath(newPath) {
      if (isNotEmpty$2(newPath)) {
        this.bindOutsideClickListener();
        this.bindResizeListener();
      } else if (!this.visible) {
        this.unbindOutsideClickListener();
        this.unbindResizeListener();
      }
    }, "activeItemPath")
  },
  mounted: /* @__PURE__ */ __name(function mounted23() {
    this.id = this.id || UniqueComponentId();
    this.bindMatchMediaListener();
    if (this.global) {
      this.bindDocumentContextMenuListener();
    }
  }, "mounted"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount13() {
    this.unbindResizeListener();
    this.unbindOutsideClickListener();
    this.unbindDocumentContextMenuListener();
    this.unbindMatchMediaListener();
    if (this.container && this.autoZIndex) {
      ZIndex$1.clear(this.container);
    }
    this.target = null;
    this.container = null;
  }, "beforeUnmount"),
  methods: {
    getItemProp: /* @__PURE__ */ __name(function getItemProp2(item3, name2) {
      return item3 ? resolve$4(item3[name2]) : void 0;
    }, "getItemProp"),
    getItemLabel: /* @__PURE__ */ __name(function getItemLabel2(item3) {
      return this.getItemProp(item3, "label");
    }, "getItemLabel"),
    isItemDisabled: /* @__PURE__ */ __name(function isItemDisabled2(item3) {
      return this.getItemProp(item3, "disabled");
    }, "isItemDisabled"),
    isItemVisible: /* @__PURE__ */ __name(function isItemVisible2(item3) {
      return this.getItemProp(item3, "visible") !== false;
    }, "isItemVisible"),
    isItemGroup: /* @__PURE__ */ __name(function isItemGroup2(item3) {
      return isNotEmpty$2(this.getItemProp(item3, "items"));
    }, "isItemGroup"),
    isItemSeparator: /* @__PURE__ */ __name(function isItemSeparator(item3) {
      return this.getItemProp(item3, "separator");
    }, "isItemSeparator"),
    getProccessedItemLabel: /* @__PURE__ */ __name(function getProccessedItemLabel(processedItem) {
      return processedItem ? this.getItemLabel(processedItem.item) : void 0;
    }, "getProccessedItemLabel"),
    isProccessedItemGroup: /* @__PURE__ */ __name(function isProccessedItemGroup(processedItem) {
      return processedItem && isNotEmpty$2(processedItem.items);
    }, "isProccessedItemGroup"),
    toggle: /* @__PURE__ */ __name(function toggle3(event) {
      this.visible ? this.hide() : this.show(event);
    }, "toggle"),
    show: /* @__PURE__ */ __name(function show6(event) {
      this.$emit("before-show");
      this.activeItemPath = [];
      this.focusedItemInfo = {
        index: -1,
        level: 0,
        parentKey: ""
      };
      focus$2(this.list);
      this.pageX = event.pageX;
      this.pageY = event.pageY;
      this.visible ? this.position() : this.visible = true;
      event.stopPropagation();
      event.preventDefault();
    }, "show"),
    hide: /* @__PURE__ */ __name(function hide6() {
      this.$emit("before-hide");
      this.visible = false;
      this.activeItemPath = [];
      this.focusedItemInfo = {
        index: -1,
        level: 0,
        parentKey: ""
      };
    }, "hide"),
    onFocus: /* @__PURE__ */ __name(function onFocus9(event) {
      this.focused = true;
      this.focusedItemInfo = this.focusedItemInfo.index !== -1 ? this.focusedItemInfo : {
        index: -1,
        level: 0,
        parentKey: ""
      };
      this.$emit("focus", event);
    }, "onFocus"),
    onBlur: /* @__PURE__ */ __name(function onBlur10(event) {
      this.focused = false;
      this.focusedItemInfo = {
        index: -1,
        level: 0,
        parentKey: ""
      };
      this.searchValue = "";
      this.$emit("blur", event);
    }, "onBlur"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown11(event) {
      var metaKey = event.metaKey || event.ctrlKey;
      switch (event.code) {
        case "ArrowDown":
          this.onArrowDownKey(event);
          break;
        case "ArrowUp":
          this.onArrowUpKey(event);
          break;
        case "ArrowLeft":
          this.onArrowLeftKey(event);
          break;
        case "ArrowRight":
          this.onArrowRightKey(event);
          break;
        case "Home":
          this.onHomeKey(event);
          break;
        case "End":
          this.onEndKey(event);
          break;
        case "Space":
          this.onSpaceKey(event);
          break;
        case "Enter":
        case "NumpadEnter":
          this.onEnterKey(event);
          break;
        case "Escape":
          this.onEscapeKey(event);
          break;
        case "Tab":
          this.onTabKey(event);
          break;
        case "PageDown":
        case "PageUp":
        case "Backspace":
        case "ShiftLeft":
        case "ShiftRight":
          break;
        default:
          if (!metaKey && isPrintableCharacter$2(event.key)) {
            this.searchItems(event, event.key);
          }
          break;
      }
    }, "onKeyDown"),
    onItemChange: /* @__PURE__ */ __name(function onItemChange(event, type) {
      var processedItem = event.processedItem, isFocus = event.isFocus;
      if (isEmpty$3(processedItem)) return;
      var index2 = processedItem.index, key = processedItem.key, level = processedItem.level, parentKey = processedItem.parentKey, items2 = processedItem.items;
      var grouped = isNotEmpty$2(items2);
      var activeItemPath2 = this.activeItemPath.filter(function(p2) {
        return p2.parentKey !== parentKey && p2.parentKey !== key;
      });
      if (grouped) {
        activeItemPath2.push(processedItem);
        this.submenuVisible = true;
      }
      this.focusedItemInfo = {
        index: index2,
        level,
        parentKey
      };
      isFocus && focus$2(this.list);
      if (type === "hover" && this.queryMatches) {
        return;
      }
      this.activeItemPath = activeItemPath2;
    }, "onItemChange"),
    onItemClick: /* @__PURE__ */ __name(function onItemClick3(event) {
      var processedItem = event.processedItem;
      var grouped = this.isProccessedItemGroup(processedItem);
      var selected2 = this.isSelected(processedItem);
      if (selected2) {
        var index2 = processedItem.index, key = processedItem.key, level = processedItem.level, parentKey = processedItem.parentKey;
        this.activeItemPath = this.activeItemPath.filter(function(p2) {
          return key !== p2.key && key.startsWith(p2.key);
        });
        this.focusedItemInfo = {
          index: index2,
          level,
          parentKey
        };
        focus$2(this.list);
      } else {
        grouped ? this.onItemChange(event) : this.hide();
      }
    }, "onItemClick"),
    onItemMouseEnter: /* @__PURE__ */ __name(function onItemMouseEnter2(event) {
      this.onItemChange(event, "hover");
    }, "onItemMouseEnter"),
    onItemMouseMove: /* @__PURE__ */ __name(function onItemMouseMove2(event) {
      if (this.focused) {
        this.changeFocusedItemIndex(event, event.processedItem.index);
      }
    }, "onItemMouseMove"),
    onArrowDownKey: /* @__PURE__ */ __name(function onArrowDownKey5(event) {
      var itemIndex = this.focusedItemInfo.index !== -1 ? this.findNextItemIndex(this.focusedItemInfo.index) : this.findFirstFocusedItemIndex();
      this.changeFocusedItemIndex(event, itemIndex);
      event.preventDefault();
    }, "onArrowDownKey"),
    onArrowUpKey: /* @__PURE__ */ __name(function onArrowUpKey5(event) {
      if (event.altKey) {
        if (this.focusedItemInfo.index !== -1) {
          var processedItem = this.visibleItems[this.focusedItemInfo.index];
          var grouped = this.isProccessedItemGroup(processedItem);
          !grouped && this.onItemChange({
            originalEvent: event,
            processedItem
          });
        }
        this.popup && this.hide();
        event.preventDefault();
      } else {
        var itemIndex = this.focusedItemInfo.index !== -1 ? this.findPrevItemIndex(this.focusedItemInfo.index) : this.findLastFocusedItemIndex();
        this.changeFocusedItemIndex(event, itemIndex);
        event.preventDefault();
      }
    }, "onArrowUpKey"),
    onArrowLeftKey: /* @__PURE__ */ __name(function onArrowLeftKey6(event) {
      var _this = this;
      var processedItem = this.visibleItems[this.focusedItemInfo.index];
      var parentItem = this.activeItemPath.find(function(p2) {
        return p2.key === processedItem.parentKey;
      });
      var root34 = isEmpty$3(processedItem.parent);
      if (!root34) {
        this.focusedItemInfo = {
          index: -1,
          parentKey: parentItem ? parentItem.parentKey : ""
        };
        this.searchValue = "";
        this.onArrowDownKey(event);
      }
      this.activeItemPath = this.activeItemPath.filter(function(p2) {
        return p2.parentKey !== _this.focusedItemInfo.parentKey;
      });
      event.preventDefault();
    }, "onArrowLeftKey"),
    onArrowRightKey: /* @__PURE__ */ __name(function onArrowRightKey3(event) {
      var processedItem = this.visibleItems[this.focusedItemInfo.index];
      var grouped = this.isProccessedItemGroup(processedItem);
      if (grouped) {
        this.onItemChange({
          originalEvent: event,
          processedItem
        });
        this.focusedItemInfo = {
          index: -1,
          parentKey: processedItem.key
        };
        this.searchValue = "";
        this.onArrowDownKey(event);
      }
      event.preventDefault();
    }, "onArrowRightKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey6(event) {
      this.changeFocusedItemIndex(event, this.findFirstItemIndex());
      event.preventDefault();
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey6(event) {
      this.changeFocusedItemIndex(event, this.findLastItemIndex());
      event.preventDefault();
    }, "onEndKey"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey6(event) {
      if (this.focusedItemInfo.index !== -1) {
        var element = findSingle$1(this.list, 'li[id="'.concat("".concat(this.focusedItemIdx), '"]'));
        var anchorElement = element && findSingle$1(element, '[data-pc-section="itemlink"]');
        anchorElement ? anchorElement.click() : element && element.click();
        var processedItem = this.visibleItems[this.focusedItemInfo.index];
        var grouped = this.isProccessedItemGroup(processedItem);
        !grouped && (this.focusedItemInfo.index = this.findFirstFocusedItemIndex());
      }
      event.preventDefault();
    }, "onEnterKey"),
    onSpaceKey: /* @__PURE__ */ __name(function onSpaceKey3(event) {
      this.onEnterKey(event);
    }, "onSpaceKey"),
    onEscapeKey: /* @__PURE__ */ __name(function onEscapeKey4(event) {
      this.hide();
      !this.popup && (this.focusedItemInfo.index = this.findFirstFocusedItemIndex());
      event.preventDefault();
    }, "onEscapeKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey5(event) {
      if (this.focusedItemInfo.index !== -1) {
        var processedItem = this.visibleItems[this.focusedItemInfo.index];
        var grouped = this.isProccessedItemGroup(processedItem);
        !grouped && this.onItemChange({
          originalEvent: event,
          processedItem
        });
      }
      this.hide();
    }, "onTabKey"),
    onEnter: /* @__PURE__ */ __name(function onEnter4(el) {
      addStyle$1(el, {
        position: "absolute"
      });
      this.position();
      if (this.autoZIndex) {
        ZIndex$1.set("menu", el, this.baseZIndex + this.$primevue.config.zIndex.menu);
      }
    }, "onEnter"),
    onAfterEnter: /* @__PURE__ */ __name(function onAfterEnter2() {
      this.bindOutsideClickListener();
      this.bindResizeListener();
      this.$emit("show");
      focus$2(this.list);
    }, "onAfterEnter"),
    onLeave: /* @__PURE__ */ __name(function onLeave3() {
      this.$emit("hide");
      this.container = null;
    }, "onLeave"),
    onAfterLeave: /* @__PURE__ */ __name(function onAfterLeave3(el) {
      if (this.autoZIndex) {
        ZIndex$1.clear(el);
      }
      this.unbindOutsideClickListener();
      this.unbindResizeListener();
    }, "onAfterLeave"),
    position: /* @__PURE__ */ __name(function position() {
      var left = this.pageX + 1;
      var top = this.pageY + 1;
      var width2 = this.container.offsetParent ? this.container.offsetWidth : getHiddenElementOuterWidth$1(this.container);
      var height = this.container.offsetParent ? this.container.offsetHeight : getHiddenElementOuterHeight$1(this.container);
      var viewport = getViewport$1();
      var scrollTop2 = window.scrollY || document.documentElement.scrollTop || document.body.scrollTop || 0;
      var scrollLeft = window.scrollX || document.documentElement.scrollLeft || document.body.scrollLeft || 0;
      if (left + width2 - scrollLeft > viewport.width) {
        left -= width2;
      }
      if (top + height - scrollTop2 > viewport.height) {
        top -= height;
      }
      if (left < scrollLeft) {
        left = scrollLeft;
      }
      if (top < scrollTop2) {
        top = scrollTop2;
      }
      this.container.style.left = left + "px";
      this.container.style.top = top + "px";
    }, "position"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener6() {
      var _this2 = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          var isOutsideContainer = _this2.container && !_this2.container.contains(event.target);
          var isOutsideTarget = _this2.visible ? !(_this2.target && (_this2.target === event.target || _this2.target.contains(event.target))) : true;
          if (isOutsideContainer && isOutsideTarget) {
            _this2.hide();
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener6() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener7() {
      var _this3 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this3.visible && !isTouchDevice$1()) {
            _this3.hide();
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener7() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    bindDocumentContextMenuListener: /* @__PURE__ */ __name(function bindDocumentContextMenuListener() {
      var _this4 = this;
      if (!this.documentContextMenuListener) {
        this.documentContextMenuListener = function(event) {
          event.button === 2 && _this4.show(event);
        };
        document.addEventListener("contextmenu", this.documentContextMenuListener);
      }
    }, "bindDocumentContextMenuListener"),
    unbindDocumentContextMenuListener: /* @__PURE__ */ __name(function unbindDocumentContextMenuListener() {
      if (this.documentContextMenuListener) {
        document.removeEventListener("contextmenu", this.documentContextMenuListener);
        this.documentContextMenuListener = null;
      }
    }, "unbindDocumentContextMenuListener"),
    bindMatchMediaListener: /* @__PURE__ */ __name(function bindMatchMediaListener() {
      var _this5 = this;
      if (!this.matchMediaListener) {
        var query = matchMedia("(max-width: ".concat(this.breakpoint, ")"));
        this.query = query;
        this.queryMatches = query.matches;
        this.matchMediaListener = function() {
          _this5.queryMatches = query.matches;
        };
        this.query.addEventListener("change", this.matchMediaListener);
      }
    }, "bindMatchMediaListener"),
    unbindMatchMediaListener: /* @__PURE__ */ __name(function unbindMatchMediaListener() {
      if (this.matchMediaListener) {
        this.query.removeEventListener("change", this.matchMediaListener);
        this.matchMediaListener = null;
      }
    }, "unbindMatchMediaListener"),
    isItemMatched: /* @__PURE__ */ __name(function isItemMatched(processedItem) {
      var _this$getProccessedIt;
      return this.isValidItem(processedItem) && ((_this$getProccessedIt = this.getProccessedItemLabel(processedItem)) === null || _this$getProccessedIt === void 0 ? void 0 : _this$getProccessedIt.toLocaleLowerCase().startsWith(this.searchValue.toLocaleLowerCase()));
    }, "isItemMatched"),
    isValidItem: /* @__PURE__ */ __name(function isValidItem(processedItem) {
      return !!processedItem && !this.isItemDisabled(processedItem.item) && !this.isItemSeparator(processedItem.item) && this.isItemVisible(processedItem.item);
    }, "isValidItem"),
    isValidSelectedItem: /* @__PURE__ */ __name(function isValidSelectedItem(processedItem) {
      return this.isValidItem(processedItem) && this.isSelected(processedItem);
    }, "isValidSelectedItem"),
    isSelected: /* @__PURE__ */ __name(function isSelected5(processedItem) {
      return this.activeItemPath.some(function(p2) {
        return p2.key === processedItem.key;
      });
    }, "isSelected"),
    findFirstItemIndex: /* @__PURE__ */ __name(function findFirstItemIndex() {
      var _this6 = this;
      return this.visibleItems.findIndex(function(processedItem) {
        return _this6.isValidItem(processedItem);
      });
    }, "findFirstItemIndex"),
    findLastItemIndex: /* @__PURE__ */ __name(function findLastItemIndex() {
      var _this7 = this;
      return findLastIndex$2(this.visibleItems, function(processedItem) {
        return _this7.isValidItem(processedItem);
      });
    }, "findLastItemIndex"),
    findNextItemIndex: /* @__PURE__ */ __name(function findNextItemIndex(index2) {
      var _this8 = this;
      var matchedItemIndex = index2 < this.visibleItems.length - 1 ? this.visibleItems.slice(index2 + 1).findIndex(function(processedItem) {
        return _this8.isValidItem(processedItem);
      }) : -1;
      return matchedItemIndex > -1 ? matchedItemIndex + index2 + 1 : index2;
    }, "findNextItemIndex"),
    findPrevItemIndex: /* @__PURE__ */ __name(function findPrevItemIndex(index2) {
      var _this9 = this;
      var matchedItemIndex = index2 > 0 ? findLastIndex$2(this.visibleItems.slice(0, index2), function(processedItem) {
        return _this9.isValidItem(processedItem);
      }) : -1;
      return matchedItemIndex > -1 ? matchedItemIndex : index2;
    }, "findPrevItemIndex"),
    findSelectedItemIndex: /* @__PURE__ */ __name(function findSelectedItemIndex() {
      var _this10 = this;
      return this.visibleItems.findIndex(function(processedItem) {
        return _this10.isValidSelectedItem(processedItem);
      });
    }, "findSelectedItemIndex"),
    findFirstFocusedItemIndex: /* @__PURE__ */ __name(function findFirstFocusedItemIndex() {
      var selectedIndex = this.findSelectedItemIndex();
      return selectedIndex < 0 ? this.findFirstItemIndex() : selectedIndex;
    }, "findFirstFocusedItemIndex"),
    findLastFocusedItemIndex: /* @__PURE__ */ __name(function findLastFocusedItemIndex() {
      var selectedIndex = this.findSelectedItemIndex();
      return selectedIndex < 0 ? this.findLastItemIndex() : selectedIndex;
    }, "findLastFocusedItemIndex"),
    searchItems: /* @__PURE__ */ __name(function searchItems(event, _char) {
      var _this11 = this;
      this.searchValue = (this.searchValue || "") + _char;
      var itemIndex = -1;
      var matched = false;
      if (this.focusedItemInfo.index !== -1) {
        itemIndex = this.visibleItems.slice(this.focusedItemInfo.index).findIndex(function(processedItem) {
          return _this11.isItemMatched(processedItem);
        });
        itemIndex = itemIndex === -1 ? this.visibleItems.slice(0, this.focusedItemInfo.index).findIndex(function(processedItem) {
          return _this11.isItemMatched(processedItem);
        }) : itemIndex + this.focusedItemInfo.index;
      } else {
        itemIndex = this.visibleItems.findIndex(function(processedItem) {
          return _this11.isItemMatched(processedItem);
        });
      }
      if (itemIndex !== -1) {
        matched = true;
      }
      if (itemIndex === -1 && this.focusedItemInfo.index === -1) {
        itemIndex = this.findFirstFocusedItemIndex();
      }
      if (itemIndex !== -1) {
        this.changeFocusedItemIndex(event, itemIndex);
      }
      if (this.searchTimeout) {
        clearTimeout(this.searchTimeout);
      }
      this.searchTimeout = setTimeout(function() {
        _this11.searchValue = "";
        _this11.searchTimeout = null;
      }, 500);
      return matched;
    }, "searchItems"),
    changeFocusedItemIndex: /* @__PURE__ */ __name(function changeFocusedItemIndex(event, index2) {
      if (this.focusedItemInfo.index !== index2) {
        this.focusedItemInfo.index = index2;
        this.scrollInView();
      }
    }, "changeFocusedItemIndex"),
    scrollInView: /* @__PURE__ */ __name(function scrollInView9() {
      var index2 = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : -1;
      var id4 = index2 !== -1 ? "".concat(this.id, "_").concat(index2) : this.focusedItemIdx;
      var element = findSingle$1(this.list, 'li[id="'.concat(id4, '"]'));
      if (element) {
        element.scrollIntoView && element.scrollIntoView({
          block: "nearest",
          inline: "start"
        });
      }
    }, "scrollInView"),
    createProcessedItems: /* @__PURE__ */ __name(function createProcessedItems(items2) {
      var _this12 = this;
      var level = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 0;
      var parent = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      var parentKey = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : "";
      var processedItems2 = [];
      items2 && items2.forEach(function(item3, index2) {
        var key = (parentKey !== "" ? parentKey + "_" : "") + index2;
        var newItem = {
          item: item3,
          index: index2,
          level,
          key,
          parent,
          parentKey
        };
        newItem["items"] = _this12.createProcessedItems(item3.items, level + 1, newItem, key);
        processedItems2.push(newItem);
      });
      return processedItems2;
    }, "createProcessedItems"),
    containerRef: /* @__PURE__ */ __name(function containerRef3(el) {
      this.container = el;
    }, "containerRef"),
    listRef: /* @__PURE__ */ __name(function listRef5(el) {
      this.list = el ? el.$el : void 0;
    }, "listRef")
  },
  computed: {
    processedItems: /* @__PURE__ */ __name(function processedItems() {
      return this.createProcessedItems(this.model || []);
    }, "processedItems"),
    visibleItems: /* @__PURE__ */ __name(function visibleItems() {
      var _this13 = this;
      var processedItem = this.activeItemPath.find(function(p2) {
        return p2.key === _this13.focusedItemInfo.parentKey;
      });
      return processedItem ? processedItem.items : this.processedItems;
    }, "visibleItems"),
    focusedItemIdx: /* @__PURE__ */ __name(function focusedItemIdx() {
      return this.focusedItemInfo.index !== -1 ? "".concat(this.id).concat(isNotEmpty$2(this.focusedItemInfo.parentKey) ? "_" + this.focusedItemInfo.parentKey : "", "_").concat(this.focusedItemInfo.index) : null;
    }, "focusedItemIdx")
  },
  components: {
    ContextMenuSub: script$1$7,
    Portal: script$$
  }
};
function render$b(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_ContextMenuSub = resolveComponent("ContextMenuSub");
  var _component_Portal = resolveComponent("Portal");
  return openBlock(), createBlock(_component_Portal, {
    appendTo: _ctx.appendTo
  }, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-contextmenu",
        onEnter: $options.onEnter,
        onAfterEnter: $options.onAfterEnter,
        onLeave: $options.onLeave,
        onAfterLeave: $options.onAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [$data.visible ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.containerRef,
            "class": _ctx.cx("root")
          }, _ctx.ptmi("root")), [createVNode(_component_ContextMenuSub, {
            ref: $options.listRef,
            id: $data.id + "_list",
            "class": normalizeClass(_ctx.cx("rootList")),
            role: "menubar",
            root: true,
            tabindex: _ctx.tabindex,
            "aria-orientation": "vertical",
            "aria-activedescendant": $data.focused ? $options.focusedItemIdx : void 0,
            menuId: $data.id,
            focusedItemId: $data.focused ? $options.focusedItemIdx : void 0,
            items: $options.processedItems,
            templates: _ctx.$slots,
            activeItemPath: $data.activeItemPath,
            "aria-labelledby": _ctx.ariaLabelledby,
            "aria-label": _ctx.ariaLabel,
            level: 0,
            visible: $data.submenuVisible,
            pt: _ctx.pt,
            unstyled: _ctx.unstyled,
            onFocus: $options.onFocus,
            onBlur: $options.onBlur,
            onKeydown: $options.onKeyDown,
            onItemClick: $options.onItemClick,
            onItemMouseenter: $options.onItemMouseEnter,
            onItemMousemove: $options.onItemMouseMove
          }, null, 8, ["id", "class", "tabindex", "aria-activedescendant", "menuId", "focusedItemId", "items", "templates", "activeItemPath", "aria-labelledby", "aria-label", "visible", "pt", "unstyled", "onFocus", "onBlur", "onKeydown", "onItemClick", "onItemMouseenter", "onItemMousemove"])], 16)) : createCommentVNode("", true)];
        }),
        _: 1
      }, 16, ["onEnter", "onAfterEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 1
  }, 8, ["appendTo"]);
}
__name(render$b, "render$b");
script$c.render = render$b;
var theme$6 = /* @__PURE__ */ __name(function theme40(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-tree {\n    background: ".concat(dt2("tree.background"), ";\n    color: ").concat(dt2("tree.color"), ";\n    padding: ").concat(dt2("tree.padding"), ";\n}\n\n.p-tree-root-children,\n.p-tree-node-children {\n    display: flex;\n    list-style-type: none;\n    flex-direction: column;\n    margin: 0;\n    gap: ").concat(dt2("tree.gap"), ";\n}\n\n.p-tree-root-children {\n    padding: 0;\n    padding-block-start: ").concat(dt2("tree.gap"), ";\n}\n\n.p-tree-node-children {\n    padding: 0;\n    padding-block-start: ").concat(dt2("tree.gap"), ";\n    padding-inline-start: ").concat(dt2("tree.indent"), ";\n}\n\n.p-tree-node {\n    padding: 0;\n    outline: 0 none;\n}\n\n.p-tree-node-content {\n    border-radius: ").concat(dt2("tree.node.border.radius"), ";\n    padding: ").concat(dt2("tree.node.padding"), ";\n    display: flex;\n    align-items: center;\n    outline-color: transparent;\n    color: ").concat(dt2("tree.node.color"), ";\n    gap: ").concat(dt2("tree.node.gap"), ";\n    transition: background ").concat(dt2("tree.transition.duration"), ", color ").concat(dt2("tree.transition.duration"), ", outline-color ").concat(dt2("tree.transition.duration"), ", box-shadow ").concat(dt2("tree.transition.duration"), ";\n}\n\n.p-tree-node:focus-visible > .p-tree-node-content {\n    box-shadow: ").concat(dt2("tree.node.focus.ring.shadow"), ";\n    outline: ").concat(dt2("tree.node.focus.ring.width"), " ").concat(dt2("tree.node.focus.ring.style"), " ").concat(dt2("tree.node.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("tree.node.focus.ring.offset"), ";\n}\n\n.p-tree-node-content.p-tree-node-selectable:not(.p-tree-node-selected):hover {\n    background: ").concat(dt2("tree.node.hover.background"), ";\n    color: ").concat(dt2("tree.node.hover.color"), ";\n}\n\n.p-tree-node-content.p-tree-node-selectable:not(.p-tree-node-selected):hover .p-tree-node-icon {\n    color: ").concat(dt2("tree.node.icon.hover.color"), ";\n}\n\n.p-tree-node-content.p-tree-node-selected {\n    background: ").concat(dt2("tree.node.selected.background"), ";\n    color: ").concat(dt2("tree.node.selected.color"), ";\n}\n\n.p-tree-node-content.p-tree-node-selected .p-tree-node-toggle-button {\n    color: inherit;\n}\n\n.p-tree-node-toggle-button {\n    cursor: pointer;\n    user-select: none;\n    display: inline-flex;\n    align-items: center;\n    justify-content: center;\n    overflow: hidden;\n    position: relative;\n    flex-shrink: 0;\n    width: ").concat(dt2("tree.node.toggle.button.size"), ";\n    height: ").concat(dt2("tree.node.toggle.button.size"), ";\n    color: ").concat(dt2("tree.node.toggle.button.color"), ";\n    border: 0 none;\n    background: transparent;\n    border-radius: ").concat(dt2("tree.node.toggle.button.border.radius"), ";\n    transition: background ").concat(dt2("tree.transition.duration"), ", color ").concat(dt2("tree.transition.duration"), ", border-color ").concat(dt2("tree.transition.duration"), ", outline-color ").concat(dt2("tree.transition.duration"), ", box-shadow ").concat(dt2("tree.transition.duration"), ";\n    outline-color: transparent;\n    padding: 0;\n}\n\n.p-tree-node-toggle-button:enabled:hover {\n    background: ").concat(dt2("tree.node.toggle.button.hover.background"), ";\n    color: ").concat(dt2("tree.node.toggle.button.hover.color"), ";\n}\n\n.p-tree-node-content.p-tree-node-selected .p-tree-node-toggle-button:hover {\n    background: ").concat(dt2("tree.node.toggle.button.selected.hover.background"), ";\n    color: ").concat(dt2("tree.node.toggle.button.selected.hover.color"), ";\n}\n\n.p-tree-root {\n    overflow: auto;\n}\n\n.p-tree-node-selectable {\n    cursor: pointer;\n    user-select: none;\n}\n\n.p-tree-node-leaf > .p-tree-node-content .p-tree-node-toggle-button {\n    visibility: hidden;\n}\n\n.p-tree-node-icon {\n    color: ").concat(dt2("tree.node.icon.color"), ";\n    transition: color ").concat(dt2("tree.transition.duration"), ";\n}\n\n.p-tree-node-content.p-tree-node-selected .p-tree-node-icon {\n    color: ").concat(dt2("tree.node.icon.selected.color"), ";\n}\n\n.p-tree-filter {\n    margin: ").concat(dt2("tree.filter.margin"), ";\n}\n\n.p-tree-filter-input {\n    width: 100%;\n}\n\n.p-tree-loading {\n    position: relative;\n    height: 100%;\n}\n\n.p-tree-loading-icon {\n    font-size: ").concat(dt2("tree.loading.icon.size"), ";\n    width: ").concat(dt2("tree.loading.icon.size"), ";\n    height: ").concat(dt2("tree.loading.icon.size"), ";\n}\n\n.p-tree .p-tree-mask {\n    position: absolute;\n    z-index: 1;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n}\n\n.p-tree-flex-scrollable {\n    display: flex;\n    flex: 1;\n    height: 100%;\n    flex-direction: column;\n}\n\n.p-tree-flex-scrollable .p-tree-root {\n    flex: 1;\n}\n");
}, "theme");
var classes$6 = {
  root: /* @__PURE__ */ __name(function root30(_ref2) {
    var props = _ref2.props;
    return ["p-tree p-component", {
      "p-tree-selectable": props.selectionMode != null,
      "p-tree-loading": props.loading,
      "p-tree-flex-scrollable": props.scrollHeight === "flex"
    }];
  }, "root"),
  mask: "p-tree-mask p-overlay-mask",
  loadingIcon: "p-tree-loading-icon",
  pcFilterContainer: "p-tree-filter",
  pcFilterInput: "p-tree-filter-input",
  wrapper: "p-tree-root",
  //TODO: discuss
  rootChildren: "p-tree-root-children",
  node: /* @__PURE__ */ __name(function node2(_ref3) {
    var instance = _ref3.instance;
    return ["p-tree-node", {
      "p-tree-node-leaf": instance.leaf
    }];
  }, "node"),
  nodeContent: /* @__PURE__ */ __name(function nodeContent(_ref4) {
    var instance = _ref4.instance;
    return ["p-tree-node-content", instance.node.styleClass, {
      "p-tree-node-selectable": instance.selectable,
      "p-tree-node-selected": instance.checkboxMode && instance.$parentInstance.highlightOnSelect ? instance.checked : instance.selected
    }];
  }, "nodeContent"),
  nodeToggleButton: "p-tree-node-toggle-button",
  nodeToggleIcon: "p-tree-node-toggle-icon",
  nodeCheckbox: "p-tree-node-checkbox",
  nodeIcon: "p-tree-node-icon",
  nodeLabel: "p-tree-node-label",
  nodeChildren: "p-tree-node-children"
};
var TreeStyle = BaseStyle$1.extend({
  name: "tree",
  theme: theme$6,
  classes: classes$6
});
var script$2$1 = {
  name: "BaseTree",
  "extends": script$1b,
  props: {
    value: {
      type: null,
      "default": null
    },
    expandedKeys: {
      type: null,
      "default": null
    },
    selectionKeys: {
      type: null,
      "default": null
    },
    selectionMode: {
      type: String,
      "default": null
    },
    metaKeySelection: {
      type: Boolean,
      "default": false
    },
    loading: {
      type: Boolean,
      "default": false
    },
    loadingIcon: {
      type: String,
      "default": void 0
    },
    loadingMode: {
      type: String,
      "default": "mask"
    },
    filter: {
      type: Boolean,
      "default": false
    },
    filterBy: {
      type: [String, Function],
      "default": "label"
    },
    filterMode: {
      type: String,
      "default": "lenient"
    },
    filterPlaceholder: {
      type: String,
      "default": null
    },
    filterLocale: {
      type: String,
      "default": void 0
    },
    highlightOnSelect: {
      type: Boolean,
      "default": false
    },
    scrollHeight: {
      type: String,
      "default": null
    },
    level: {
      type: Number,
      "default": 0
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    }
  },
  style: TreeStyle,
  provide: /* @__PURE__ */ __name(function provide45() {
    return {
      $pcTree: this,
      $parentInstance: this
    };
  }, "provide")
};
function _typeof$2$1(o2) {
  "@babel/helpers - typeof";
  return _typeof$2$1 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$2$1(o2);
}
__name(_typeof$2$1, "_typeof$2$1");
function _createForOfIteratorHelper$1$1(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$1$1(r2)) || e2) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F3() {
      }, "F");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
        throw r3;
      }, "e"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r3 = t2.next();
    return a2 = r3.done, r3;
  }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
    u2 = true, o2 = r3;
  }, "e"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2["return"] || t2["return"]();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper$1$1, "_createForOfIteratorHelper$1$1");
function ownKeys$2$1(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$2$1, "ownKeys$2$1");
function _objectSpread$2$1(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$2$1(Object(t2), true).forEach(function(r3) {
      _defineProperty$2$1(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$2$1(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$2$1, "_objectSpread$2$1");
function _defineProperty$2$1(e2, r2, t2) {
  return (r2 = _toPropertyKey$2$1(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$2$1, "_defineProperty$2$1");
function _toPropertyKey$2$1(t2) {
  var i2 = _toPrimitive$2$1(t2, "string");
  return "symbol" == _typeof$2$1(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$2$1, "_toPropertyKey$2$1");
function _toPrimitive$2$1(t2, r2) {
  if ("object" != _typeof$2$1(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$2$1(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$2$1, "_toPrimitive$2$1");
function _toConsumableArray$1$1(r2) {
  return _arrayWithoutHoles$1$1(r2) || _iterableToArray$1$1(r2) || _unsupportedIterableToArray$1$1(r2) || _nonIterableSpread$1$1();
}
__name(_toConsumableArray$1$1, "_toConsumableArray$1$1");
function _nonIterableSpread$1$1() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$1$1, "_nonIterableSpread$1$1");
function _unsupportedIterableToArray$1$1(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$1$1(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$1$1(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$1$1, "_unsupportedIterableToArray$1$1");
function _iterableToArray$1$1(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$1$1, "_iterableToArray$1$1");
function _arrayWithoutHoles$1$1(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$1$1(r2);
}
__name(_arrayWithoutHoles$1$1, "_arrayWithoutHoles$1$1");
function _arrayLikeToArray$1$1(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$1$1, "_arrayLikeToArray$1$1");
var script$1$6 = {
  name: "TreeNode",
  hostName: "Tree",
  "extends": script$1b,
  emits: ["node-toggle", "node-click", "checkbox-change"],
  props: {
    node: {
      type: null,
      "default": null
    },
    expandedKeys: {
      type: null,
      "default": null
    },
    loadingMode: {
      type: String,
      "default": "mask"
    },
    selectionKeys: {
      type: null,
      "default": null
    },
    selectionMode: {
      type: String,
      "default": null
    },
    templates: {
      type: null,
      "default": null
    },
    level: {
      type: Number,
      "default": null
    },
    index: null
  },
  nodeTouched: false,
  toggleClicked: false,
  mounted: /* @__PURE__ */ __name(function mounted24() {
    this.setAllNodesTabIndexes();
  }, "mounted"),
  methods: {
    toggle: /* @__PURE__ */ __name(function toggle4() {
      this.$emit("node-toggle", this.node);
      this.toggleClicked = true;
    }, "toggle"),
    label: /* @__PURE__ */ __name(function label6(node3) {
      return typeof node3.label === "function" ? node3.label() : node3.label;
    }, "label"),
    onChildNodeToggle: /* @__PURE__ */ __name(function onChildNodeToggle(node3) {
      this.$emit("node-toggle", node3);
    }, "onChildNodeToggle"),
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions8(key) {
      return this.ptm(key, {
        context: {
          node: this.node,
          index: this.index,
          expanded: this.expanded,
          selected: this.selected,
          checked: this.checked,
          partialChecked: this.partialChecked,
          leaf: this.leaf
        }
      });
    }, "getPTOptions"),
    onClick: /* @__PURE__ */ __name(function onClick4(event) {
      if (this.toggleClicked || getAttribute$1(event.target, '[data-pc-section="nodetogglebutton"]') || getAttribute$1(event.target.parentElement, '[data-pc-section="nodetogglebutton"]')) {
        this.toggleClicked = false;
        return;
      }
      if (this.isCheckboxSelectionMode()) {
        if (this.node.selectable != false) {
          this.toggleCheckbox();
        }
      } else {
        this.$emit("node-click", {
          originalEvent: event,
          nodeTouched: this.nodeTouched,
          node: this.node
        });
      }
      this.nodeTouched = false;
    }, "onClick"),
    onChildNodeClick: /* @__PURE__ */ __name(function onChildNodeClick(event) {
      this.$emit("node-click", event);
    }, "onChildNodeClick"),
    onTouchEnd: /* @__PURE__ */ __name(function onTouchEnd2() {
      this.nodeTouched = true;
    }, "onTouchEnd"),
    onKeyDown: /* @__PURE__ */ __name(function onKeyDown12(event) {
      if (!this.isSameNode(event)) return;
      switch (event.code) {
        case "Tab":
          this.onTabKey(event);
          break;
        case "ArrowDown":
          this.onArrowDown(event);
          break;
        case "ArrowUp":
          this.onArrowUp(event);
          break;
        case "ArrowRight":
          this.onArrowRight(event);
          break;
        case "ArrowLeft":
          this.onArrowLeft(event);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onEnterKey(event);
          break;
      }
    }, "onKeyDown"),
    onArrowDown: /* @__PURE__ */ __name(function onArrowDown(event) {
      var nodeElement = event.target.getAttribute("data-pc-section") === "nodetogglebutton" ? event.target.closest('[role="treeitem"]') : event.target;
      var listElement = nodeElement.children[1];
      if (listElement) {
        this.focusRowChange(nodeElement, listElement.children[0]);
      } else {
        if (nodeElement.nextElementSibling) {
          this.focusRowChange(nodeElement, nodeElement.nextElementSibling);
        } else {
          var nextSiblingAncestor = this.findNextSiblingOfAncestor(nodeElement);
          if (nextSiblingAncestor) {
            this.focusRowChange(nodeElement, nextSiblingAncestor);
          }
        }
      }
      event.preventDefault();
    }, "onArrowDown"),
    onArrowUp: /* @__PURE__ */ __name(function onArrowUp(event) {
      var nodeElement = event.target;
      if (nodeElement.previousElementSibling) {
        this.focusRowChange(nodeElement, nodeElement.previousElementSibling, this.findLastVisibleDescendant(nodeElement.previousElementSibling));
      } else {
        var parentNodeElement = this.getParentNodeElement(nodeElement);
        if (parentNodeElement) {
          this.focusRowChange(nodeElement, parentNodeElement);
        }
      }
      event.preventDefault();
    }, "onArrowUp"),
    onArrowRight: /* @__PURE__ */ __name(function onArrowRight(event) {
      var _this = this;
      if (this.leaf || this.expanded) return;
      event.currentTarget.tabIndex = -1;
      this.$emit("node-toggle", this.node);
      this.$nextTick(function() {
        _this.onArrowDown(event);
      });
    }, "onArrowRight"),
    onArrowLeft: /* @__PURE__ */ __name(function onArrowLeft(event) {
      var togglerElement = findSingle$1(event.currentTarget, '[data-pc-section="nodetogglebutton"]');
      if (this.level === 0 && !this.expanded) {
        return false;
      }
      if (this.expanded && !this.leaf) {
        togglerElement.click();
        return false;
      }
      var target2 = this.findBeforeClickableNode(event.currentTarget);
      if (target2) {
        this.focusRowChange(event.currentTarget, target2);
      }
    }, "onArrowLeft"),
    onEnterKey: /* @__PURE__ */ __name(function onEnterKey7(event) {
      this.setTabIndexForSelectionMode(event, this.nodeTouched);
      this.onClick(event);
      event.preventDefault();
    }, "onEnterKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey6() {
      this.setAllNodesTabIndexes();
    }, "onTabKey"),
    setAllNodesTabIndexes: /* @__PURE__ */ __name(function setAllNodesTabIndexes() {
      var nodes = find$2(this.$refs.currentNode.closest('[data-pc-section="rootchildren"]'), '[role="treeitem"]');
      var hasSelectedNode = _toConsumableArray$1$1(nodes).some(function(node3) {
        return node3.getAttribute("aria-selected") === "true" || node3.getAttribute("aria-checked") === "true";
      });
      _toConsumableArray$1$1(nodes).forEach(function(node3) {
        node3.tabIndex = -1;
      });
      if (hasSelectedNode) {
        var selectedNodes = _toConsumableArray$1$1(nodes).filter(function(node3) {
          return node3.getAttribute("aria-selected") === "true" || node3.getAttribute("aria-checked") === "true";
        });
        selectedNodes[0].tabIndex = 0;
        return;
      }
      _toConsumableArray$1$1(nodes)[0].tabIndex = 0;
    }, "setAllNodesTabIndexes"),
    setTabIndexForSelectionMode: /* @__PURE__ */ __name(function setTabIndexForSelectionMode(event, nodeTouched) {
      if (this.selectionMode !== null) {
        var elements = _toConsumableArray$1$1(find$2(this.$refs.currentNode.parentElement, '[role="treeitem"]'));
        event.currentTarget.tabIndex = nodeTouched === false ? -1 : 0;
        if (elements.every(function(element) {
          return element.tabIndex === -1;
        })) {
          elements[0].tabIndex = 0;
        }
      }
    }, "setTabIndexForSelectionMode"),
    focusRowChange: /* @__PURE__ */ __name(function focusRowChange(firstFocusableRow, currentFocusedRow, lastVisibleDescendant) {
      firstFocusableRow.tabIndex = "-1";
      currentFocusedRow.tabIndex = "0";
      this.focusNode(lastVisibleDescendant || currentFocusedRow);
    }, "focusRowChange"),
    findBeforeClickableNode: /* @__PURE__ */ __name(function findBeforeClickableNode(node3) {
      var parentListElement = node3.closest("ul").closest("li");
      if (parentListElement) {
        var prevNodeButton = findSingle$1(parentListElement, "button");
        if (prevNodeButton && prevNodeButton.style.visibility !== "hidden") {
          return parentListElement;
        }
        return this.findBeforeClickableNode(node3.previousElementSibling);
      }
      return null;
    }, "findBeforeClickableNode"),
    toggleCheckbox: /* @__PURE__ */ __name(function toggleCheckbox() {
      var _selectionKeys = this.selectionKeys ? _objectSpread$2$1({}, this.selectionKeys) : {};
      var _check = !this.checked;
      this.propagateDown(this.node, _check, _selectionKeys);
      this.$emit("checkbox-change", {
        node: this.node,
        check: _check,
        selectionKeys: _selectionKeys
      });
    }, "toggleCheckbox"),
    propagateDown: /* @__PURE__ */ __name(function propagateDown(node3, check, selectionKeys) {
      if (check && node3.selectable != false) selectionKeys[node3.key] = {
        checked: true,
        partialChecked: false
      };
      else delete selectionKeys[node3.key];
      if (node3.children && node3.children.length) {
        var _iterator = _createForOfIteratorHelper$1$1(node3.children), _step;
        try {
          for (_iterator.s(); !(_step = _iterator.n()).done; ) {
            var child = _step.value;
            this.propagateDown(child, check, selectionKeys);
          }
        } catch (err) {
          _iterator.e(err);
        } finally {
          _iterator.f();
        }
      }
    }, "propagateDown"),
    propagateUp: /* @__PURE__ */ __name(function propagateUp(event) {
      var check = event.check;
      var _selectionKeys = _objectSpread$2$1({}, event.selectionKeys);
      var checkedChildCount = 0;
      var childPartialSelected = false;
      var _iterator2 = _createForOfIteratorHelper$1$1(this.node.children), _step2;
      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done; ) {
          var child = _step2.value;
          if (_selectionKeys[child.key] && _selectionKeys[child.key].checked) checkedChildCount++;
          else if (_selectionKeys[child.key] && _selectionKeys[child.key].partialChecked) childPartialSelected = true;
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
      if (check && checkedChildCount === this.node.children.length) {
        _selectionKeys[this.node.key] = {
          checked: true,
          partialChecked: false
        };
      } else {
        if (!check) {
          delete _selectionKeys[this.node.key];
        }
        if (childPartialSelected || checkedChildCount > 0 && checkedChildCount !== this.node.children.length) _selectionKeys[this.node.key] = {
          checked: false,
          partialChecked: true
        };
        else delete _selectionKeys[this.node.key];
      }
      this.$emit("checkbox-change", {
        node: event.node,
        check: event.check,
        selectionKeys: _selectionKeys
      });
    }, "propagateUp"),
    onChildCheckboxChange: /* @__PURE__ */ __name(function onChildCheckboxChange(event) {
      this.$emit("checkbox-change", event);
    }, "onChildCheckboxChange"),
    findNextSiblingOfAncestor: /* @__PURE__ */ __name(function findNextSiblingOfAncestor(nodeElement) {
      var parentNodeElement = this.getParentNodeElement(nodeElement);
      if (parentNodeElement) {
        if (parentNodeElement.nextElementSibling) return parentNodeElement.nextElementSibling;
        else return this.findNextSiblingOfAncestor(parentNodeElement);
      } else {
        return null;
      }
    }, "findNextSiblingOfAncestor"),
    findLastVisibleDescendant: /* @__PURE__ */ __name(function findLastVisibleDescendant(nodeElement) {
      var childrenListElement = nodeElement.children[1];
      if (childrenListElement) {
        var lastChildElement = childrenListElement.children[childrenListElement.children.length - 1];
        return this.findLastVisibleDescendant(lastChildElement);
      } else {
        return nodeElement;
      }
    }, "findLastVisibleDescendant"),
    getParentNodeElement: /* @__PURE__ */ __name(function getParentNodeElement(nodeElement) {
      var parentNodeElement = nodeElement.parentElement.parentElement;
      return getAttribute$1(parentNodeElement, "role") === "treeitem" ? parentNodeElement : null;
    }, "getParentNodeElement"),
    focusNode: /* @__PURE__ */ __name(function focusNode(element) {
      element.focus();
    }, "focusNode"),
    isCheckboxSelectionMode: /* @__PURE__ */ __name(function isCheckboxSelectionMode() {
      return this.selectionMode === "checkbox";
    }, "isCheckboxSelectionMode"),
    isSameNode: /* @__PURE__ */ __name(function isSameNode(event) {
      return event.currentTarget && (event.currentTarget.isSameNode(event.target) || event.currentTarget.isSameNode(event.target.closest('[role="treeitem"]')));
    }, "isSameNode")
  },
  computed: {
    hasChildren: /* @__PURE__ */ __name(function hasChildren() {
      return this.node.children && this.node.children.length > 0;
    }, "hasChildren"),
    expanded: /* @__PURE__ */ __name(function expanded() {
      return this.expandedKeys && this.expandedKeys[this.node.key] === true;
    }, "expanded"),
    leaf: /* @__PURE__ */ __name(function leaf() {
      return this.node.leaf === false ? false : !(this.node.children && this.node.children.length);
    }, "leaf"),
    selectable: /* @__PURE__ */ __name(function selectable() {
      return this.node.selectable === false ? false : this.selectionMode != null;
    }, "selectable"),
    selected: /* @__PURE__ */ __name(function selected() {
      return this.selectionMode && this.selectionKeys ? this.selectionKeys[this.node.key] === true : false;
    }, "selected"),
    checkboxMode: /* @__PURE__ */ __name(function checkboxMode() {
      return this.selectionMode === "checkbox" && this.node.selectable !== false;
    }, "checkboxMode"),
    checked: /* @__PURE__ */ __name(function checked3() {
      return this.selectionKeys ? this.selectionKeys[this.node.key] && this.selectionKeys[this.node.key].checked : false;
    }, "checked"),
    partialChecked: /* @__PURE__ */ __name(function partialChecked() {
      return this.selectionKeys ? this.selectionKeys[this.node.key] && this.selectionKeys[this.node.key].partialChecked : false;
    }, "partialChecked"),
    ariaChecked: /* @__PURE__ */ __name(function ariaChecked() {
      return this.selectionMode === "single" || this.selectionMode === "multiple" ? this.selected : void 0;
    }, "ariaChecked"),
    ariaSelected: /* @__PURE__ */ __name(function ariaSelected() {
      return this.checkboxMode ? this.checked : void 0;
    }, "ariaSelected")
  },
  components: {
    Checkbox: script$Q,
    ChevronDownIcon: script$u,
    ChevronRightIcon: script$w,
    CheckIcon: script$S,
    MinusIcon: script$R,
    SpinnerIcon: script$12
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$1$2 = ["aria-label", "aria-selected", "aria-expanded", "aria-setsize", "aria-posinset", "aria-level", "aria-checked", "tabindex"];
var _hoisted_2$h = ["data-p-selected", "data-p-selectable"];
function render$1$1(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_Checkbox = resolveComponent("Checkbox");
  var _component_TreeNode = resolveComponent("TreeNode", true);
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("li", mergeProps$2({
    ref: "currentNode",
    "class": _ctx.cx("node"),
    role: "treeitem",
    "aria-label": $options.label($props.node),
    "aria-selected": $options.ariaSelected,
    "aria-expanded": $options.expanded,
    "aria-setsize": $props.node.children ? $props.node.children.length : 0,
    "aria-posinset": $props.index + 1,
    "aria-level": $props.level,
    "aria-checked": $options.ariaChecked,
    tabindex: $props.index === 0 ? 0 : -1,
    onKeydown: _cache[4] || (_cache[4] = function() {
      return $options.onKeyDown && $options.onKeyDown.apply($options, arguments);
    })
  }, $props.level === 1 ? $options.getPTOptions("node") : _ctx.ptm("nodeChildren")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("nodeContent"),
    onClick: _cache[2] || (_cache[2] = function() {
      return $options.onClick && $options.onClick.apply($options, arguments);
    }),
    onTouchend: _cache[3] || (_cache[3] = function() {
      return $options.onTouchEnd && $options.onTouchEnd.apply($options, arguments);
    }),
    style: $props.node.style
  }, $options.getPTOptions("nodeContent"), {
    "data-p-selected": $options.checkboxMode ? $options.checked : $options.selected,
    "data-p-selectable": $options.selectable
  }), [withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    type: "button",
    "class": _ctx.cx("nodeToggleButton"),
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.toggle && $options.toggle.apply($options, arguments);
    }),
    tabindex: "-1"
  }, $options.getPTOptions("nodeToggleButton")), [$props.node.loading && $props.loadingMode === "icon" ? (openBlock(), createElementBlock(Fragment$1, {
    key: 0
  }, [$props.templates["nodetoggleicon"] || $props.templates["nodetogglericon"] ? (openBlock(), createBlock(resolveDynamicComponent($props.templates["nodetoggleicon"] || $props.templates["nodetogglericon"]), {
    key: 0,
    node: $props.node,
    expanded: $options.expanded,
    "class": normalizeClass(_ctx.cx("nodeToggleIcon"))
  }, null, 8, ["node", "expanded", "class"])) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
    key: 1,
    spin: "",
    "class": _ctx.cx("nodeToggleIcon")
  }, $options.getPTOptions("nodeToggleIcon")), null, 16, ["class"]))], 64)) : (openBlock(), createElementBlock(Fragment$1, {
    key: 1
  }, [$props.templates["nodetoggleicon"] || $props.templates["togglericon"] ? (openBlock(), createBlock(resolveDynamicComponent($props.templates["nodetoggleicon"] || $props.templates["togglericon"]), {
    key: 0,
    node: $props.node,
    expanded: $options.expanded,
    "class": normalizeClass(_ctx.cx("nodeToggleIcon"))
  }, null, 8, ["node", "expanded", "class"])) : $options.expanded ? (openBlock(), createBlock(resolveDynamicComponent($props.node.expandedIcon ? "span" : "ChevronDownIcon"), mergeProps$2({
    key: 1,
    "class": _ctx.cx("nodeToggleIcon")
  }, $options.getPTOptions("nodeToggleIcon")), null, 16, ["class"])) : (openBlock(), createBlock(resolveDynamicComponent($props.node.collapsedIcon ? "span" : "ChevronRightIcon"), mergeProps$2({
    key: 2,
    "class": _ctx.cx("nodeToggleIcon")
  }, $options.getPTOptions("nodeToggleIcon")), null, 16, ["class"]))], 64))], 16)), [[_directive_ripple]]), $options.checkboxMode ? (openBlock(), createBlock(_component_Checkbox, {
    key: 0,
    defaultValue: $options.checked,
    binary: true,
    indeterminate: $options.partialChecked,
    "class": normalizeClass(_ctx.cx("nodeCheckbox")),
    tabindex: -1,
    unstyled: _ctx.unstyled,
    pt: $options.getPTOptions("pcNodeCheckbox"),
    "data-p-partialchecked": $options.partialChecked
  }, {
    icon: withCtx(function(slotProps) {
      return [$props.templates["checkboxicon"] ? (openBlock(), createBlock(resolveDynamicComponent($props.templates["checkboxicon"]), {
        key: 0,
        checked: slotProps.checked,
        partialChecked: $options.partialChecked,
        "class": normalizeClass(slotProps["class"])
      }, null, 8, ["checked", "partialChecked", "class"])) : createCommentVNode("", true)];
    }),
    _: 1
  }, 8, ["defaultValue", "indeterminate", "class", "unstyled", "pt", "data-p-partialchecked"])) : createCommentVNode("", true), $props.templates["nodeicon"] ? (openBlock(), createBlock(resolveDynamicComponent($props.templates["nodeicon"]), mergeProps$2({
    key: 1,
    node: $props.node,
    "class": [_ctx.cx("nodeIcon")]
  }, $options.getPTOptions("nodeIcon")), null, 16, ["node", "class"])) : (openBlock(), createElementBlock("span", mergeProps$2({
    key: 2,
    "class": [_ctx.cx("nodeIcon"), $props.node.icon]
  }, $options.getPTOptions("nodeIcon")), null, 16)), createBaseVNode("span", mergeProps$2({
    "class": _ctx.cx("nodeLabel")
  }, $options.getPTOptions("nodeLabel"), {
    onKeydown: _cache[1] || (_cache[1] = withModifiers(function() {
    }, ["stop"]))
  }), [$props.templates[$props.node.type] || $props.templates["default"] ? (openBlock(), createBlock(resolveDynamicComponent($props.templates[$props.node.type] || $props.templates["default"]), {
    key: 0,
    node: $props.node,
    expanded: $options.expanded,
    selected: $options.checkboxMode ? $options.checked : $options.selected
  }, null, 8, ["node", "expanded", "selected"])) : (openBlock(), createElementBlock(Fragment$1, {
    key: 1
  }, [createTextVNode(toDisplayString$1($options.label($props.node)), 1)], 64))], 16)], 16, _hoisted_2$h), $options.hasChildren && $options.expanded ? (openBlock(), createElementBlock("ul", mergeProps$2({
    key: 0,
    "class": _ctx.cx("nodeChildren"),
    role: "group"
  }, _ctx.ptm("nodeChildren")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($props.node.children, function(childNode) {
    return openBlock(), createBlock(_component_TreeNode, {
      key: childNode.key,
      node: childNode,
      templates: $props.templates,
      level: $props.level + 1,
      loadingMode: $props.loadingMode,
      expandedKeys: $props.expandedKeys,
      onNodeToggle: $options.onChildNodeToggle,
      onNodeClick: $options.onChildNodeClick,
      selectionMode: $props.selectionMode,
      selectionKeys: $props.selectionKeys,
      onCheckboxChange: $options.propagateUp,
      unstyled: _ctx.unstyled,
      pt: _ctx.pt
    }, null, 8, ["node", "templates", "level", "loadingMode", "expandedKeys", "onNodeToggle", "onNodeClick", "selectionMode", "selectionKeys", "onCheckboxChange", "unstyled", "pt"]);
  }), 128))], 16)) : createCommentVNode("", true)], 16, _hoisted_1$1$2);
}
__name(render$1$1, "render$1$1");
script$1$6.render = render$1$1;
function _typeof$1$1(o2) {
  "@babel/helpers - typeof";
  return _typeof$1$1 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$1$1(o2);
}
__name(_typeof$1$1, "_typeof$1$1");
function _createForOfIteratorHelper$3(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$6(r2)) || e2) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F3() {
      }, "F");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
        throw r3;
      }, "e"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r3 = t2.next();
    return a2 = r3.done, r3;
  }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
    u2 = true, o2 = r3;
  }, "e"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2["return"] || t2["return"]();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper$3, "_createForOfIteratorHelper$3");
function _toConsumableArray$4(r2) {
  return _arrayWithoutHoles$4(r2) || _iterableToArray$4(r2) || _unsupportedIterableToArray$6(r2) || _nonIterableSpread$4();
}
__name(_toConsumableArray$4, "_toConsumableArray$4");
function _nonIterableSpread$4() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$4, "_nonIterableSpread$4");
function _unsupportedIterableToArray$6(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$6(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$6(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$6, "_unsupportedIterableToArray$6");
function _iterableToArray$4(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$4, "_iterableToArray$4");
function _arrayWithoutHoles$4(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$6(r2);
}
__name(_arrayWithoutHoles$4, "_arrayWithoutHoles$4");
function _arrayLikeToArray$6(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$6, "_arrayLikeToArray$6");
function ownKeys$1$1(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$1$1, "ownKeys$1$1");
function _objectSpread$1$1(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$1$1(Object(t2), true).forEach(function(r3) {
      _defineProperty$1$1(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$1$1(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$1$1, "_objectSpread$1$1");
function _defineProperty$1$1(e2, r2, t2) {
  return (r2 = _toPropertyKey$1$1(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$1$1, "_defineProperty$1$1");
function _toPropertyKey$1$1(t2) {
  var i2 = _toPrimitive$1$1(t2, "string");
  return "symbol" == _typeof$1$1(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$1$1, "_toPropertyKey$1$1");
function _toPrimitive$1$1(t2, r2) {
  if ("object" != _typeof$1$1(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$1$1(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$1$1, "_toPrimitive$1$1");
var script$b = {
  name: "Tree",
  "extends": script$2$1,
  inheritAttrs: false,
  emits: ["node-expand", "node-collapse", "update:expandedKeys", "update:selectionKeys", "node-select", "node-unselect", "filter"],
  data: /* @__PURE__ */ __name(function data24() {
    return {
      d_expandedKeys: this.expandedKeys || {},
      filterValue: null
    };
  }, "data"),
  watch: {
    expandedKeys: /* @__PURE__ */ __name(function expandedKeys(newValue2) {
      this.d_expandedKeys = newValue2;
    }, "expandedKeys")
  },
  methods: {
    onNodeToggle: /* @__PURE__ */ __name(function onNodeToggle(node3) {
      var key = node3.key;
      if (this.d_expandedKeys[key]) {
        delete this.d_expandedKeys[key];
        this.$emit("node-collapse", node3);
      } else {
        this.d_expandedKeys[key] = true;
        this.$emit("node-expand", node3);
      }
      this.d_expandedKeys = _objectSpread$1$1({}, this.d_expandedKeys);
      this.$emit("update:expandedKeys", this.d_expandedKeys);
    }, "onNodeToggle"),
    onNodeClick: /* @__PURE__ */ __name(function onNodeClick(event) {
      if (this.selectionMode != null && event.node.selectable !== false) {
        var metaSelection = event.nodeTouched ? false : this.metaKeySelection;
        var _selectionKeys = metaSelection ? this.handleSelectionWithMetaKey(event) : this.handleSelectionWithoutMetaKey(event);
        this.$emit("update:selectionKeys", _selectionKeys);
      }
    }, "onNodeClick"),
    onCheckboxChange: /* @__PURE__ */ __name(function onCheckboxChange(event) {
      this.$emit("update:selectionKeys", event.selectionKeys);
      if (event.check) this.$emit("node-select", event.node);
      else this.$emit("node-unselect", event.node);
    }, "onCheckboxChange"),
    handleSelectionWithMetaKey: /* @__PURE__ */ __name(function handleSelectionWithMetaKey(event) {
      var originalEvent = event.originalEvent;
      var node3 = event.node;
      var metaKey = originalEvent.metaKey || originalEvent.ctrlKey;
      var selected2 = this.isNodeSelected(node3);
      var _selectionKeys;
      if (selected2 && metaKey) {
        if (this.isSingleSelectionMode()) {
          _selectionKeys = {};
        } else {
          _selectionKeys = _objectSpread$1$1({}, this.selectionKeys);
          delete _selectionKeys[node3.key];
        }
        this.$emit("node-unselect", node3);
      } else {
        if (this.isSingleSelectionMode()) {
          _selectionKeys = {};
        } else if (this.isMultipleSelectionMode()) {
          _selectionKeys = !metaKey ? {} : this.selectionKeys ? _objectSpread$1$1({}, this.selectionKeys) : {};
        }
        _selectionKeys[node3.key] = true;
        this.$emit("node-select", node3);
      }
      return _selectionKeys;
    }, "handleSelectionWithMetaKey"),
    handleSelectionWithoutMetaKey: /* @__PURE__ */ __name(function handleSelectionWithoutMetaKey(event) {
      var node3 = event.node;
      var selected2 = this.isNodeSelected(node3);
      var _selectionKeys;
      if (this.isSingleSelectionMode()) {
        if (selected2) {
          _selectionKeys = {};
          this.$emit("node-unselect", node3);
        } else {
          _selectionKeys = {};
          _selectionKeys[node3.key] = true;
          this.$emit("node-select", node3);
        }
      } else {
        if (selected2) {
          _selectionKeys = _objectSpread$1$1({}, this.selectionKeys);
          delete _selectionKeys[node3.key];
          this.$emit("node-unselect", node3);
        } else {
          _selectionKeys = this.selectionKeys ? _objectSpread$1$1({}, this.selectionKeys) : {};
          _selectionKeys[node3.key] = true;
          this.$emit("node-select", node3);
        }
      }
      return _selectionKeys;
    }, "handleSelectionWithoutMetaKey"),
    isSingleSelectionMode: /* @__PURE__ */ __name(function isSingleSelectionMode() {
      return this.selectionMode === "single";
    }, "isSingleSelectionMode"),
    isMultipleSelectionMode: /* @__PURE__ */ __name(function isMultipleSelectionMode() {
      return this.selectionMode === "multiple";
    }, "isMultipleSelectionMode"),
    isNodeSelected: /* @__PURE__ */ __name(function isNodeSelected(node3) {
      return this.selectionMode && this.selectionKeys ? this.selectionKeys[node3.key] === true : false;
    }, "isNodeSelected"),
    isChecked: /* @__PURE__ */ __name(function isChecked(node3) {
      return this.selectionKeys ? this.selectionKeys[node3.key] && this.selectionKeys[node3.key].checked : false;
    }, "isChecked"),
    isNodeLeaf: /* @__PURE__ */ __name(function isNodeLeaf(node3) {
      return node3.leaf === false ? false : !(node3.children && node3.children.length);
    }, "isNodeLeaf"),
    onFilterKeydown: /* @__PURE__ */ __name(function onFilterKeydown(event) {
      if (event.code === "Enter" || event.code === "NumpadEnter") {
        event.preventDefault();
      }
      this.$emit("filter", {
        originalEvent: event,
        value: event.target.value
      });
    }, "onFilterKeydown"),
    findFilteredNodes: /* @__PURE__ */ __name(function findFilteredNodes(node3, paramsWithoutNode) {
      if (node3) {
        var matched = false;
        if (node3.children) {
          var childNodes2 = _toConsumableArray$4(node3.children);
          node3.children = [];
          var _iterator = _createForOfIteratorHelper$3(childNodes2), _step;
          try {
            for (_iterator.s(); !(_step = _iterator.n()).done; ) {
              var childNode = _step.value;
              var copyChildNode = _objectSpread$1$1({}, childNode);
              if (this.isFilterMatched(copyChildNode, paramsWithoutNode)) {
                matched = true;
                node3.children.push(copyChildNode);
              }
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        }
        if (matched) {
          return true;
        }
      }
    }, "findFilteredNodes"),
    isFilterMatched: /* @__PURE__ */ __name(function isFilterMatched(node3, _ref) {
      var searchFields4 = _ref.searchFields, filterText = _ref.filterText, strict = _ref.strict;
      var matched = false;
      var _iterator2 = _createForOfIteratorHelper$3(searchFields4), _step2;
      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done; ) {
          var field2 = _step2.value;
          var fieldValue = String(resolveFieldData$2(node3, field2)).toLocaleLowerCase(this.filterLocale);
          if (fieldValue.indexOf(filterText) > -1) {
            matched = true;
          }
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
      if (!matched || strict && !this.isNodeLeaf(node3)) {
        matched = this.findFilteredNodes(node3, {
          searchFields: searchFields4,
          filterText,
          strict
        }) || matched;
      }
      return matched;
    }, "isFilterMatched")
  },
  computed: {
    filteredValue: /* @__PURE__ */ __name(function filteredValue() {
      var filteredNodes = [];
      var searchFields4 = isFunction$d(this.filterBy) ? [this.filterBy] : this.filterBy.split(",");
      var filterText = this.filterValue.trim().toLocaleLowerCase(this.filterLocale);
      var strict = this.filterMode === "strict";
      var _iterator3 = _createForOfIteratorHelper$3(this.value), _step3;
      try {
        for (_iterator3.s(); !(_step3 = _iterator3.n()).done; ) {
          var node3 = _step3.value;
          var _node = _objectSpread$1$1({}, node3);
          var paramsWithoutNode = {
            searchFields: searchFields4,
            filterText,
            strict
          };
          if (strict && (this.findFilteredNodes(_node, paramsWithoutNode) || this.isFilterMatched(_node, paramsWithoutNode)) || !strict && (this.isFilterMatched(_node, paramsWithoutNode) || this.findFilteredNodes(_node, paramsWithoutNode))) {
            filteredNodes.push(_node);
          }
        }
      } catch (err) {
        _iterator3.e(err);
      } finally {
        _iterator3.f();
      }
      return filteredNodes;
    }, "filteredValue"),
    valueToRender: /* @__PURE__ */ __name(function valueToRender() {
      if (this.filterValue && this.filterValue.trim().length > 0) return this.filteredValue;
      else return this.value;
    }, "valueToRender")
  },
  components: {
    TreeNode: script$1$6,
    InputText: script$P,
    InputIcon: script$I,
    IconField: script$J,
    SearchIcon: script$K,
    SpinnerIcon: script$12
  }
};
function _typeof$4(o2) {
  "@babel/helpers - typeof";
  return _typeof$4 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$4(o2);
}
__name(_typeof$4, "_typeof$4");
function ownKeys$6(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$6, "ownKeys$6");
function _objectSpread$6(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$6(Object(t2), true).forEach(function(r3) {
      _defineProperty$4(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$6(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$6, "_objectSpread$6");
function _defineProperty$4(e2, r2, t2) {
  return (r2 = _toPropertyKey$3(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$4, "_defineProperty$4");
function _toPropertyKey$3(t2) {
  var i2 = _toPrimitive$3(t2, "string");
  return "symbol" == _typeof$4(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$3, "_toPropertyKey$3");
function _toPrimitive$3(t2, r2) {
  if ("object" != _typeof$4(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$4(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$3, "_toPrimitive$3");
var _hoisted_1$m = ["aria-labelledby", "aria-label"];
function render$a(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_SpinnerIcon = resolveComponent("SpinnerIcon");
  var _component_InputText = resolveComponent("InputText");
  var _component_SearchIcon = resolveComponent("SearchIcon");
  var _component_InputIcon = resolveComponent("InputIcon");
  var _component_IconField = resolveComponent("IconField");
  var _component_TreeNode = resolveComponent("TreeNode");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root")
  }, _ctx.ptmi("root")), [_ctx.loading && _ctx.loadingMode === "mask" ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    "class": _ctx.cx("mask")
  }, _ctx.ptm("mask")), [renderSlot(_ctx.$slots, "loadingicon", {
    "class": normalizeClass(_ctx.cx("loadingIcon"))
  }, function() {
    return [_ctx.loadingIcon ? (openBlock(), createElementBlock("i", mergeProps$2({
      key: 0,
      "class": [_ctx.cx("loadingIcon"), "pi-spin", _ctx.loadingIcon]
    }, _ctx.ptm("loadingIcon")), null, 16)) : (openBlock(), createBlock(_component_SpinnerIcon, mergeProps$2({
      key: 1,
      spin: "",
      "class": _ctx.cx("loadingIcon")
    }, _ctx.ptm("loadingIcon")), null, 16, ["class"]))];
  })], 16)) : createCommentVNode("", true), _ctx.filter ? (openBlock(), createBlock(_component_IconField, {
    key: 1,
    unstyled: _ctx.unstyled,
    pt: _objectSpread$6(_objectSpread$6({}, _ctx.ptm("pcFilter")), _ctx.ptm("pcFilterContainer")),
    "class": normalizeClass(_ctx.cx("pcFilterContainer"))
  }, {
    "default": withCtx(function() {
      return [createVNode(_component_InputText, {
        modelValue: $data.filterValue,
        "onUpdate:modelValue": _cache[0] || (_cache[0] = function($event) {
          return $data.filterValue = $event;
        }),
        autocomplete: "off",
        "class": normalizeClass(_ctx.cx("pcFilterInput")),
        placeholder: _ctx.filterPlaceholder,
        unstyled: _ctx.unstyled,
        onKeydown: $options.onFilterKeydown,
        pt: _ctx.ptm("pcFilterInput")
      }, null, 8, ["modelValue", "class", "placeholder", "unstyled", "onKeydown", "pt"]), createVNode(_component_InputIcon, {
        unstyled: _ctx.unstyled,
        pt: _ctx.ptm("pcFilterIconContainer")
      }, {
        "default": withCtx(function() {
          return [renderSlot(_ctx.$slots, _ctx.$slots.filtericon ? "filtericon" : "searchicon", {
            "class": normalizeClass(_ctx.cx("filterIcon"))
          }, function() {
            return [createVNode(_component_SearchIcon, mergeProps$2({
              "class": _ctx.cx("filterIcon")
            }, _ctx.ptm("filterIcon")), null, 16, ["class"])];
          })];
        }),
        _: 3
      }, 8, ["unstyled", "pt"])];
    }),
    _: 3
  }, 8, ["unstyled", "pt", "class"])) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("wrapper"),
    style: {
      maxHeight: _ctx.scrollHeight
    }
  }, _ctx.ptm("wrapper")), [renderSlot(_ctx.$slots, "header", {
    value: _ctx.value,
    expandedKeys: _ctx.expandedKeys,
    selectionKeys: _ctx.selectionKeys
  }), createBaseVNode("ul", mergeProps$2({
    "class": _ctx.cx("rootChildren"),
    role: "tree",
    "aria-labelledby": _ctx.ariaLabelledby,
    "aria-label": _ctx.ariaLabel
  }, _ctx.ptm("rootChildren")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($options.valueToRender, function(node3, index2) {
    return openBlock(), createBlock(_component_TreeNode, {
      key: node3.key,
      node: node3,
      templates: _ctx.$slots,
      level: _ctx.level + 1,
      index: index2,
      expandedKeys: $data.d_expandedKeys,
      onNodeToggle: $options.onNodeToggle,
      onNodeClick: $options.onNodeClick,
      selectionMode: _ctx.selectionMode,
      selectionKeys: _ctx.selectionKeys,
      onCheckboxChange: $options.onCheckboxChange,
      loadingMode: _ctx.loadingMode,
      unstyled: _ctx.unstyled,
      pt: _ctx.pt
    }, null, 8, ["node", "templates", "level", "index", "expandedKeys", "onNodeToggle", "onNodeClick", "selectionMode", "selectionKeys", "onCheckboxChange", "loadingMode", "unstyled", "pt"]);
  }), 128))], 16, _hoisted_1$m), renderSlot(_ctx.$slots, "footer", {
    value: _ctx.value,
    expandedKeys: _ctx.expandedKeys,
    selectionKeys: _ctx.selectionKeys
  })], 16)], 16);
}
__name(render$a, "render$a");
script$b.render = render$a;
function _arrayWithHoles(r2) {
  if (Array.isArray(r2)) return r2;
}
__name(_arrayWithHoles, "_arrayWithHoles");
function _iterableToArrayLimit(r2, l2) {
  var t2 = null == r2 ? null : "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (null != t2) {
    var e2, n2, i2, u2, a2 = [], f2 = true, o2 = false;
    try {
      if (i2 = (t2 = t2.call(r2)).next, 0 === l2) {
        if (Object(t2) !== t2) return;
        f2 = false;
      } else for (; !(f2 = (e2 = i2.call(t2)).done) && (a2.push(e2.value), a2.length !== l2); f2 = true) ;
    } catch (r3) {
      o2 = true, n2 = r3;
    } finally {
      try {
        if (!f2 && null != t2["return"] && (u2 = t2["return"](), Object(u2) !== u2)) return;
      } finally {
        if (o2) throw n2;
      }
    }
    return a2;
  }
}
__name(_iterableToArrayLimit, "_iterableToArrayLimit");
function _arrayLikeToArray$5(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$5, "_arrayLikeToArray$5");
function _unsupportedIterableToArray$5(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$5(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$5(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$5, "_unsupportedIterableToArray$5");
function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableRest, "_nonIterableRest");
function _slicedToArray(r2, e2) {
  return _arrayWithHoles(r2) || _iterableToArrayLimit(r2, e2) || _unsupportedIterableToArray$5(r2, e2) || _nonIterableRest();
}
__name(_slicedToArray, "_slicedToArray");
var dist = {};
var bind$1 = {};
"use strict";
Object.defineProperty(bind$1, "__esModule", { value: true });
var bind_2 = bind$1.bind = void 0;
function bind(target2, _a2) {
  var type = _a2.type, listener = _a2.listener, options5 = _a2.options;
  target2.addEventListener(type, listener, options5);
  return /* @__PURE__ */ __name(function unbind2() {
    target2.removeEventListener(type, listener, options5);
  }, "unbind");
}
__name(bind, "bind");
bind_2 = bind$1.bind = bind;
var bindAll$1 = {};
"use strict";
var __assign = commonjsGlobal && commonjsGlobal.__assign || function() {
  __assign = Object.assign || function(t2) {
    for (var s2, i2 = 1, n2 = arguments.length; i2 < n2; i2++) {
      s2 = arguments[i2];
      for (var p2 in s2) if (Object.prototype.hasOwnProperty.call(s2, p2))
        t2[p2] = s2[p2];
    }
    return t2;
  };
  return __assign.apply(this, arguments);
};
Object.defineProperty(bindAll$1, "__esModule", { value: true });
var bindAll_2 = bindAll$1.bindAll = void 0;
var bind_1 = bind$1;
function toOptions(value3) {
  if (typeof value3 === "undefined") {
    return void 0;
  }
  if (typeof value3 === "boolean") {
    return {
      capture: value3
    };
  }
  return value3;
}
__name(toOptions, "toOptions");
function getBinding(original, sharedOptions) {
  if (sharedOptions == null) {
    return original;
  }
  var binding = __assign(__assign({}, original), { options: __assign(__assign({}, toOptions(sharedOptions)), toOptions(original.options)) });
  return binding;
}
__name(getBinding, "getBinding");
function bindAll(target2, bindings, sharedOptions) {
  var unbinds = bindings.map(function(original) {
    var binding = getBinding(original, sharedOptions);
    return (0, bind_1.bind)(target2, binding);
  });
  return /* @__PURE__ */ __name(function unbindAll() {
    unbinds.forEach(function(unbind2) {
      return unbind2();
    });
  }, "unbindAll");
}
__name(bindAll, "bindAll");
bindAll_2 = bindAll$1.bindAll = bindAll;
(function(exports) {
  "use strict";
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.bindAll = exports.bind = void 0;
  var bind_12 = bind$1;
  Object.defineProperty(exports, "bind", { enumerable: true, get: /* @__PURE__ */ __name(function() {
    return bind_12.bind;
  }, "get") });
  var bind_all_1 = bindAll$1;
  Object.defineProperty(exports, "bindAll", { enumerable: true, get: /* @__PURE__ */ __name(function() {
    return bind_all_1.bindAll;
  }, "get") });
})(dist);
const index = /* @__PURE__ */ getDefaultExportFromCjs(dist);
var honeyPotDataAttribute = "data-pdnd-honey-pot";
function isHoneyPotElement(target2) {
  return target2 instanceof Element && target2.hasAttribute(honeyPotDataAttribute);
}
__name(isHoneyPotElement, "isHoneyPotElement");
function getElementFromPointWithoutHoneypot(client) {
  var _document$elementsFro = document.elementsFromPoint(client.x, client.y), _document$elementsFro2 = _slicedToArray(_document$elementsFro, 2), top = _document$elementsFro2[0], second = _document$elementsFro2[1];
  if (!top) {
    return null;
  }
  if (isHoneyPotElement(top)) {
    return second !== null && second !== void 0 ? second : null;
  }
  return top;
}
__name(getElementFromPointWithoutHoneypot, "getElementFromPointWithoutHoneypot");
function _typeof$3(o2) {
  "@babel/helpers - typeof";
  return _typeof$3 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$3(o2);
}
__name(_typeof$3, "_typeof$3");
function toPrimitive(t2, r2) {
  if ("object" != _typeof$3(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$3(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(toPrimitive, "toPrimitive");
function toPropertyKey(t2) {
  var i2 = toPrimitive(t2, "string");
  return "symbol" == _typeof$3(i2) ? i2 : i2 + "";
}
__name(toPropertyKey, "toPropertyKey");
function _defineProperty$3(e2, r2, t2) {
  return (r2 = toPropertyKey(r2)) in e2 ? Object.defineProperty(e2, r2, {
    value: t2,
    enumerable: true,
    configurable: true,
    writable: true
  }) : e2[r2] = t2, e2;
}
__name(_defineProperty$3, "_defineProperty$3");
var maxZIndex = 2147483647;
function ownKeys$5(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$5, "ownKeys$5");
function _objectSpread$5(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$5(Object(t2), true).forEach(function(r3) {
      _defineProperty$3(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$5(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$5, "_objectSpread$5");
var honeyPotSize = 2;
var halfHoneyPotSize = honeyPotSize / 2;
function floorToClosestPixel(point) {
  return {
    x: Math.floor(point.x),
    y: Math.floor(point.y)
  };
}
__name(floorToClosestPixel, "floorToClosestPixel");
function pullBackByHalfHoneyPotSize(point) {
  return {
    x: point.x - halfHoneyPotSize,
    y: point.y - halfHoneyPotSize
  };
}
__name(pullBackByHalfHoneyPotSize, "pullBackByHalfHoneyPotSize");
function preventGoingBackwardsOffScreen(point) {
  return {
    x: Math.max(point.x, 0),
    y: Math.max(point.y, 0)
  };
}
__name(preventGoingBackwardsOffScreen, "preventGoingBackwardsOffScreen");
function preventGoingForwardsOffScreen(point) {
  return {
    x: Math.min(point.x, window.innerWidth - honeyPotSize),
    y: Math.min(point.y, window.innerHeight - honeyPotSize)
  };
}
__name(preventGoingForwardsOffScreen, "preventGoingForwardsOffScreen");
function getHoneyPotRectFor(_ref) {
  var client = _ref.client;
  var point = preventGoingForwardsOffScreen(preventGoingBackwardsOffScreen(pullBackByHalfHoneyPotSize(floorToClosestPixel(client))));
  return DOMRect.fromRect({
    x: point.x,
    y: point.y,
    width: honeyPotSize,
    height: honeyPotSize
  });
}
__name(getHoneyPotRectFor, "getHoneyPotRectFor");
function getRectStyles(_ref2) {
  var clientRect2 = _ref2.clientRect;
  return {
    left: "".concat(clientRect2.left, "px"),
    top: "".concat(clientRect2.top, "px"),
    width: "".concat(clientRect2.width, "px"),
    height: "".concat(clientRect2.height, "px")
  };
}
__name(getRectStyles, "getRectStyles");
function isWithin(_ref3) {
  var client = _ref3.client, clientRect2 = _ref3.clientRect;
  return (
    // is within horizontal bounds
    client.x >= clientRect2.x && client.x <= clientRect2.x + clientRect2.width && // is within vertical bounds
    client.y >= clientRect2.y && client.y <= clientRect2.y + clientRect2.height
  );
}
__name(isWithin, "isWithin");
function mountHoneyPot(_ref4) {
  var initial = _ref4.initial;
  var element = document.createElement("div");
  element.setAttribute(honeyPotDataAttribute, "true");
  var clientRect2 = getHoneyPotRectFor({
    client: initial
  });
  Object.assign(element.style, _objectSpread$5(_objectSpread$5({
    // Setting a background color explicitly to avoid any inherited styles.
    // Looks like this could be `opacity: 0`, but worried that _might_
    // cause the element to be ignored on some platforms.
    // When debugging, set backgroundColor to something like "red".
    backgroundColor: "transparent",
    position: "fixed",
    // Being explicit to avoid inheriting styles
    padding: 0,
    margin: 0,
    boxSizing: "border-box"
  }, getRectStyles({
    clientRect: clientRect2
  })), {}, {
    // We want this element to absorb pointer events,
    // it's kind of the whole point 😉
    pointerEvents: "auto",
    // Want to make sure the honey pot is top of everything else.
    // Don't need to worry about native drag previews, as they will
    // have been rendered (and removed) before the honey pot is rendered
    zIndex: maxZIndex
  }));
  document.body.appendChild(element);
  var unbindPointerMove = dist.bind(window, {
    type: "pointermove",
    listener: /* @__PURE__ */ __name(function listener(event) {
      var client = {
        x: event.clientX,
        y: event.clientY
      };
      clientRect2 = getHoneyPotRectFor({
        client
      });
      Object.assign(element.style, getRectStyles({
        clientRect: clientRect2
      }));
    }, "listener"),
    // using capture so we are less likely to be impacted by event stopping
    options: {
      capture: true
    }
  });
  return /* @__PURE__ */ __name(function finish(_ref5) {
    var current = _ref5.current;
    unbindPointerMove();
    if (isWithin({
      client: current,
      clientRect: clientRect2
    })) {
      element.remove();
      return;
    }
    function cleanup() {
      unbindPostDragEvents();
      element.remove();
    }
    __name(cleanup, "cleanup");
    var unbindPostDragEvents = dist.bindAll(window, [
      {
        type: "pointerdown",
        listener: cleanup
      },
      {
        type: "pointermove",
        listener: cleanup
      },
      {
        type: "focusin",
        listener: cleanup
      },
      {
        type: "focusout",
        listener: cleanup
      },
      // a 'pointerdown' should happen before 'dragstart', but just being super safe
      {
        type: "dragstart",
        listener: cleanup
      },
      // if the user has dragged something out of the window
      // and then is dragging something back into the window
      // the first events we will see are "dragenter" (and then "dragover").
      // So if we see any of these we need to clear the post drag fix.
      {
        type: "dragenter",
        listener: cleanup
      },
      {
        type: "dragover",
        listener: cleanup
      }
      // Not adding a "wheel" event listener, as "wheel" by itself does not
      // resolve the bug.
    ], {
      // Using `capture` so less likely to be impacted by other code stopping events
      capture: true
    });
  }, "finish");
}
__name(mountHoneyPot, "mountHoneyPot");
function makeHoneyPotFix() {
  var latestPointerMove = null;
  function bindEvents3() {
    latestPointerMove = null;
    return dist.bind(window, {
      type: "pointermove",
      listener: /* @__PURE__ */ __name(function listener(event) {
        latestPointerMove = {
          x: event.clientX,
          y: event.clientY
        };
      }, "listener"),
      // listening for pointer move in capture phase
      // so we are less likely to be impacted by events being stopped.
      options: {
        capture: true
      }
    });
  }
  __name(bindEvents3, "bindEvents");
  function getOnPostDispatch() {
    var finish = null;
    return /* @__PURE__ */ __name(function onPostEvent(_ref6) {
      var eventName = _ref6.eventName, payload = _ref6.payload;
      if (eventName === "onDragStart") {
        var _latestPointerMove;
        var input = payload.location.initial.input;
        var initial = (_latestPointerMove = latestPointerMove) !== null && _latestPointerMove !== void 0 ? _latestPointerMove : {
          x: input.clientX,
          y: input.clientY
        };
        finish = mountHoneyPot({
          initial
        });
      }
      if (eventName === "onDrop") {
        var _finish;
        var _input = payload.location.current.input;
        (_finish = finish) === null || _finish === void 0 || _finish({
          current: {
            x: _input.clientX,
            y: _input.clientY
          }
        });
        finish = null;
        latestPointerMove = null;
      }
    }, "onPostEvent");
  }
  __name(getOnPostDispatch, "getOnPostDispatch");
  return {
    bindEvents: bindEvents3,
    getOnPostDispatch
  };
}
__name(makeHoneyPotFix, "makeHoneyPotFix");
function _arrayWithoutHoles$3(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$5(r2);
}
__name(_arrayWithoutHoles$3, "_arrayWithoutHoles$3");
function _iterableToArray$3(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$3, "_iterableToArray$3");
function _nonIterableSpread$3() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$3, "_nonIterableSpread$3");
function _toConsumableArray$3(r2) {
  return _arrayWithoutHoles$3(r2) || _iterableToArray$3(r2) || _unsupportedIterableToArray$5(r2) || _nonIterableSpread$3();
}
__name(_toConsumableArray$3, "_toConsumableArray$3");
function once(fn) {
  var cache2 = null;
  return /* @__PURE__ */ __name(function wrapped() {
    if (!cache2) {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }
      var result = fn.apply(this, args);
      cache2 = {
        result
      };
    }
    return cache2.result;
  }, "wrapped");
}
__name(once, "once");
var isFirefox = once(/* @__PURE__ */ __name(function isFirefox2() {
  if (false) {
    return false;
  }
  return navigator.userAgent.includes("Firefox");
}, "isFirefox2"));
var isSafari = once(/* @__PURE__ */ __name(function isSafari2() {
  if (false) {
    return false;
  }
  var _navigator2 = navigator, userAgent = _navigator2.userAgent;
  return userAgent.includes("AppleWebKit") && !userAgent.includes("Chrome");
}, "isSafari2"));
var symbols = {
  isLeavingWindow: Symbol("leaving"),
  isEnteringWindow: Symbol("entering")
};
function isEnteringWindowInSafari(_ref) {
  var dragEnter = _ref.dragEnter;
  if (!isSafari()) {
    return false;
  }
  return dragEnter.hasOwnProperty(symbols.isEnteringWindow);
}
__name(isEnteringWindowInSafari, "isEnteringWindowInSafari");
function isLeavingWindowInSafari(_ref2) {
  var dragLeave = _ref2.dragLeave;
  if (!isSafari()) {
    return false;
  }
  return dragLeave.hasOwnProperty(symbols.isLeavingWindow);
}
__name(isLeavingWindowInSafari, "isLeavingWindowInSafari");
(/* @__PURE__ */ __name(function fixSafari() {
  if (typeof window === "undefined") {
    return;
  }
  if (false) {
    return;
  }
  if (!isSafari()) {
    return;
  }
  function getInitialState() {
    return {
      enterCount: 0,
      isOverWindow: false
    };
  }
  __name(getInitialState, "getInitialState");
  var state = getInitialState();
  function resetState() {
    state = getInitialState();
  }
  __name(resetState, "resetState");
  dist.bindAll(
    window,
    [{
      type: "dragstart",
      listener: /* @__PURE__ */ __name(function listener() {
        state.enterCount = 0;
        state.isOverWindow = true;
      }, "listener")
    }, {
      type: "drop",
      listener: resetState
    }, {
      type: "dragend",
      listener: resetState
    }, {
      type: "dragenter",
      listener: /* @__PURE__ */ __name(function listener(event) {
        if (!state.isOverWindow && state.enterCount === 0) {
          event[symbols.isEnteringWindow] = true;
        }
        state.isOverWindow = true;
        state.enterCount++;
      }, "listener")
    }, {
      type: "dragleave",
      listener: /* @__PURE__ */ __name(function listener(event) {
        state.enterCount--;
        if (state.isOverWindow && state.enterCount === 0) {
          event[symbols.isLeavingWindow] = true;
          state.isOverWindow = false;
        }
      }, "listener")
    }],
    // using `capture: true` so that adding event listeners
    // in bubble phase will have the correct symbols
    {
      capture: true
    }
  );
}, "fixSafari"))();
function isNodeLike(target2) {
  return "nodeName" in target2;
}
__name(isNodeLike, "isNodeLike");
function isFromAnotherWindow(eventTarget) {
  return isNodeLike(eventTarget) && eventTarget.ownerDocument !== document;
}
__name(isFromAnotherWindow, "isFromAnotherWindow");
function isLeavingWindow(_ref) {
  var dragLeave = _ref.dragLeave;
  var type = dragLeave.type, relatedTarget = dragLeave.relatedTarget;
  if (type !== "dragleave") {
    return false;
  }
  if (isSafari()) {
    return isLeavingWindowInSafari({
      dragLeave
    });
  }
  if (relatedTarget == null) {
    return true;
  }
  if (isFirefox()) {
    return isFromAnotherWindow(relatedTarget);
  }
  return relatedTarget instanceof HTMLIFrameElement;
}
__name(isLeavingWindow, "isLeavingWindow");
function getBindingsForBrokenDrags(_ref) {
  var onDragEnd3 = _ref.onDragEnd;
  return [
    // ## Detecting drag ending for removed draggables
    //
    // If a draggable element is removed during a drag and the user drops:
    // 1. if over a valid drop target: we get a "drop" event to know the drag is finished
    // 2. if not over a valid drop target (or cancelled): we get nothing
    // The "dragend" event will not fire on the source draggable if it has been
    // removed from the DOM.
    // So we need to figure out if a drag operation has finished by looking at other events
    // We can do this by looking at other events
    // ### First detection: "pointermove" events
    // 1. "pointermove" events cannot fire during a drag and drop operation
    // according to the spec. So if we get a "pointermove" it means that
    // the drag and drop operations has finished. So if we get a "pointermove"
    // we know that the drag is over
    // 2. 🦊😤 Drag and drop operations are _supposed_ to suppress
    // other pointer events. However, firefox will allow a few
    // pointer event to get through after a drag starts.
    // The most I've seen is 3
    {
      type: "pointermove",
      listener: /* @__PURE__ */ function() {
        var callCount = 0;
        return /* @__PURE__ */ __name(function listener() {
          if (callCount < 20) {
            callCount++;
            return;
          }
          onDragEnd3();
        }, "listener");
      }()
    },
    // ### Second detection: "pointerdown" events
    // If we receive this event then we know that a drag operation has finished
    // and potentially another one is about to start.
    // Note: `pointerdown` fires on all browsers / platforms before "dragstart"
    {
      type: "pointerdown",
      listener: onDragEnd3
    }
  ];
}
__name(getBindingsForBrokenDrags, "getBindingsForBrokenDrags");
function getInput(event) {
  return {
    altKey: event.altKey,
    button: event.button,
    buttons: event.buttons,
    ctrlKey: event.ctrlKey,
    metaKey: event.metaKey,
    shiftKey: event.shiftKey,
    clientX: event.clientX,
    clientY: event.clientY,
    pageX: event.pageX,
    pageY: event.pageY
  };
}
__name(getInput, "getInput");
var rafSchd = /* @__PURE__ */ __name(function rafSchd2(fn) {
  var lastArgs = [];
  var frameId = null;
  var wrapperFn = /* @__PURE__ */ __name(function wrapperFn2() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    lastArgs = args;
    if (frameId) {
      return;
    }
    frameId = requestAnimationFrame(function() {
      frameId = null;
      fn.apply(void 0, lastArgs);
    });
  }, "wrapperFn");
  wrapperFn.cancel = function() {
    if (!frameId) {
      return;
    }
    cancelAnimationFrame(frameId);
    frameId = null;
  };
  return wrapperFn;
}, "rafSchd");
var scheduleOnDrag = rafSchd(function(fn) {
  return fn();
});
var dragStart = /* @__PURE__ */ function() {
  var scheduled = null;
  function schedule(fn) {
    var frameId = requestAnimationFrame(function() {
      scheduled = null;
      fn();
    });
    scheduled = {
      frameId,
      fn
    };
  }
  __name(schedule, "schedule");
  function flush2() {
    if (scheduled) {
      cancelAnimationFrame(scheduled.frameId);
      scheduled.fn();
      scheduled = null;
    }
  }
  __name(flush2, "flush");
  return {
    schedule,
    flush: flush2
  };
}();
function makeDispatch(_ref) {
  var source = _ref.source, initial = _ref.initial, dispatchEvent2 = _ref.dispatchEvent;
  var previous = {
    dropTargets: []
  };
  function safeDispatch(args) {
    dispatchEvent2(args);
    previous = {
      dropTargets: args.payload.location.current.dropTargets
    };
  }
  __name(safeDispatch, "safeDispatch");
  var dispatch = {
    start: /* @__PURE__ */ __name(function start2(_ref2) {
      var nativeSetDragImage = _ref2.nativeSetDragImage;
      var location2 = {
        current: initial,
        previous,
        initial
      };
      safeDispatch({
        eventName: "onGenerateDragPreview",
        payload: {
          source,
          location: location2,
          nativeSetDragImage
        }
      });
      dragStart.schedule(function() {
        safeDispatch({
          eventName: "onDragStart",
          payload: {
            source,
            location: location2
          }
        });
      });
    }, "start"),
    dragUpdate: /* @__PURE__ */ __name(function dragUpdate(_ref3) {
      var current = _ref3.current;
      dragStart.flush();
      scheduleOnDrag.cancel();
      safeDispatch({
        eventName: "onDropTargetChange",
        payload: {
          source,
          location: {
            initial,
            previous,
            current
          }
        }
      });
    }, "dragUpdate"),
    drag: /* @__PURE__ */ __name(function drag(_ref4) {
      var current = _ref4.current;
      scheduleOnDrag(function() {
        dragStart.flush();
        var location2 = {
          initial,
          previous,
          current
        };
        safeDispatch({
          eventName: "onDrag",
          payload: {
            source,
            location: location2
          }
        });
      });
    }, "drag"),
    drop: /* @__PURE__ */ __name(function drop(_ref5) {
      var current = _ref5.current, updatedSourcePayload = _ref5.updatedSourcePayload;
      dragStart.flush();
      scheduleOnDrag.cancel();
      safeDispatch({
        eventName: "onDrop",
        payload: {
          source: updatedSourcePayload !== null && updatedSourcePayload !== void 0 ? updatedSourcePayload : source,
          location: {
            current,
            previous,
            initial
          }
        }
      });
    }, "drop")
  };
  return dispatch;
}
__name(makeDispatch, "makeDispatch");
var globalState = {
  isActive: false
};
function canStart() {
  return !globalState.isActive;
}
__name(canStart, "canStart");
function getNativeSetDragImage(event) {
  if (event.dataTransfer) {
    return event.dataTransfer.setDragImage.bind(event.dataTransfer);
  }
  return null;
}
__name(getNativeSetDragImage, "getNativeSetDragImage");
function hasHierarchyChanged(_ref) {
  var current = _ref.current, next2 = _ref.next;
  if (current.length !== next2.length) {
    return true;
  }
  for (var i2 = 0; i2 < current.length; i2++) {
    if (current[i2].element !== next2[i2].element) {
      return true;
    }
  }
  return false;
}
__name(hasHierarchyChanged, "hasHierarchyChanged");
function start(_ref2) {
  var event = _ref2.event, dragType = _ref2.dragType, getDropTargetsOver = _ref2.getDropTargetsOver, dispatchEvent2 = _ref2.dispatchEvent;
  if (!canStart()) {
    return;
  }
  var initial = getStartLocation({
    event,
    dragType,
    getDropTargetsOver
  });
  globalState.isActive = true;
  var state = {
    current: initial
  };
  setDropEffectOnEvent({
    event,
    current: initial.dropTargets
  });
  var dispatch = makeDispatch({
    source: dragType.payload,
    dispatchEvent: dispatchEvent2,
    initial
  });
  function updateState(next2) {
    var hasChanged2 = hasHierarchyChanged({
      current: state.current.dropTargets,
      next: next2.dropTargets
    });
    state.current = next2;
    if (hasChanged2) {
      dispatch.dragUpdate({
        current: state.current
      });
    }
  }
  __name(updateState, "updateState");
  function onUpdateEvent(event2) {
    var input = getInput(event2);
    var target2 = isHoneyPotElement(event2.target) ? getElementFromPointWithoutHoneypot({
      x: input.clientX,
      y: input.clientY
    }) : event2.target;
    var nextDropTargets = getDropTargetsOver({
      target: target2,
      input,
      source: dragType.payload,
      current: state.current.dropTargets
    });
    if (nextDropTargets.length) {
      event2.preventDefault();
      setDropEffectOnEvent({
        event: event2,
        current: nextDropTargets
      });
    }
    updateState({
      dropTargets: nextDropTargets,
      input
    });
  }
  __name(onUpdateEvent, "onUpdateEvent");
  function cancel() {
    if (state.current.dropTargets.length) {
      updateState({
        dropTargets: [],
        input: state.current.input
      });
    }
    dispatch.drop({
      current: state.current,
      updatedSourcePayload: null
    });
    finish();
  }
  __name(cancel, "cancel");
  function finish() {
    globalState.isActive = false;
    unbindEvents3();
  }
  __name(finish, "finish");
  var unbindEvents3 = dist.bindAll(
    window,
    [{
      // 👋 Note: we are repurposing the `dragover` event as our `drag` event
      // this is because firefox does not publish pointer coordinates during
      // a `drag` event, but does for every other type of drag event
      // `dragover` fires on all elements that are being dragged over
      // Because we are binding to `window` - our `dragover` is effectively the same as a `drag`
      // 🦊😤
      type: "dragover",
      listener: /* @__PURE__ */ __name(function listener(event2) {
        onUpdateEvent(event2);
        dispatch.drag({
          current: state.current
        });
      }, "listener")
    }, {
      type: "dragenter",
      listener: onUpdateEvent
    }, {
      type: "dragleave",
      listener: /* @__PURE__ */ __name(function listener(event2) {
        if (!isLeavingWindow({
          dragLeave: event2
        })) {
          return;
        }
        updateState({
          input: state.current.input,
          dropTargets: []
        });
        if (dragType.startedFrom === "external") {
          cancel();
        }
      }, "listener")
    }, {
      // A "drop" can only happen if the browser allowed the drop
      type: "drop",
      listener: /* @__PURE__ */ __name(function listener(event2) {
        state.current = {
          dropTargets: state.current.dropTargets,
          input: getInput(event2)
        };
        if (!state.current.dropTargets.length) {
          cancel();
          return;
        }
        event2.preventDefault();
        setDropEffectOnEvent({
          event: event2,
          current: state.current.dropTargets
        });
        dispatch.drop({
          current: state.current,
          // When dropping something native, we need to extract the latest
          // `.items` from the "drop" event as it is now accessible
          updatedSourcePayload: dragType.type === "external" ? dragType.getDropPayload(event2) : null
        });
        finish();
      }, "listener")
    }, {
      // "dragend" fires when on the drag source (eg a draggable element)
      // when the drag is finished.
      // "dragend" will fire after "drop" (if there was a successful drop)
      // "dragend" does not fire if the draggable source has been removed during the drag
      // or for external drag sources (eg files)
      // This "dragend" listener will not fire if there was a successful drop
      // as we will have already removed the event listener
      type: "dragend",
      listener: /* @__PURE__ */ __name(function listener(event2) {
        state.current = {
          dropTargets: state.current.dropTargets,
          input: getInput(event2)
        };
        cancel();
      }, "listener")
    }].concat(_toConsumableArray$3(getBindingsForBrokenDrags({
      onDragEnd: cancel
    }))),
    // Once we have started a managed drag operation it is important that we see / own all drag events
    // We got one adoption bug pop up where some code was stopping (`event.stopPropagation()`)
    // all "drop" events in the bubble phase on the `document.body`.
    // This meant that we never saw the "drop" event.
    {
      capture: true
    }
  );
  dispatch.start({
    nativeSetDragImage: getNativeSetDragImage(event)
  });
}
__name(start, "start");
function setDropEffectOnEvent(_ref3) {
  var _current$;
  var event = _ref3.event, current = _ref3.current;
  var innerMost = (_current$ = current[0]) === null || _current$ === void 0 ? void 0 : _current$.dropEffect;
  if (innerMost != null && event.dataTransfer) {
    event.dataTransfer.dropEffect = innerMost;
  }
}
__name(setDropEffectOnEvent, "setDropEffectOnEvent");
function getStartLocation(_ref4) {
  var event = _ref4.event, dragType = _ref4.dragType, getDropTargetsOver = _ref4.getDropTargetsOver;
  var input = getInput(event);
  if (dragType.startedFrom === "external") {
    return {
      input,
      dropTargets: []
    };
  }
  var dropTargets = getDropTargetsOver({
    input,
    source: dragType.payload,
    target: event.target,
    current: []
  });
  return {
    input,
    dropTargets
  };
}
__name(getStartLocation, "getStartLocation");
var lifecycle = {
  canStart,
  start
};
var ledger = /* @__PURE__ */ new Map();
function registerUsage(_ref) {
  var typeKey = _ref.typeKey, mount2 = _ref.mount;
  var entry = ledger.get(typeKey);
  if (entry) {
    entry.usageCount++;
    return entry;
  }
  var initial = {
    typeKey,
    unmount: mount2(),
    usageCount: 1
  };
  ledger.set(typeKey, initial);
  return initial;
}
__name(registerUsage, "registerUsage");
function register(args) {
  var entry = registerUsage(args);
  return /* @__PURE__ */ __name(function unregister() {
    entry.usageCount--;
    if (entry.usageCount > 0) {
      return;
    }
    entry.unmount();
    ledger.delete(args.typeKey);
  }, "unregister");
}
__name(register, "register");
function combine() {
  for (var _len = arguments.length, fns = new Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }
  return /* @__PURE__ */ __name(function cleanup() {
    fns.forEach(function(fn) {
      return fn();
    });
  }, "cleanup");
}
__name(combine, "combine");
function addAttribute(element, _ref) {
  var attribute2 = _ref.attribute, value3 = _ref.value;
  element.setAttribute(attribute2, value3);
  return function() {
    return element.removeAttribute(attribute2);
  };
}
__name(addAttribute, "addAttribute");
function ownKeys$4(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r22) {
      return Object.getOwnPropertyDescriptor(e2, r22).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$4, "ownKeys$4");
function _objectSpread$4(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$4(Object(t2), true).forEach(function(r22) {
      _defineProperty$3(e2, r22, t2[r22]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$4(Object(t2)).forEach(function(r22) {
      Object.defineProperty(e2, r22, Object.getOwnPropertyDescriptor(t2, r22));
    });
  }
  return e2;
}
__name(_objectSpread$4, "_objectSpread$4");
function _createForOfIteratorHelper$2(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$4(r2)) || e2 && r2 && "number" == typeof r2.length) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F22() {
      }, "F2");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e22(r22) {
        throw r22;
      }, "e2"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r22 = t2.next();
    return a2 = r22.done, r22;
  }, "n"), e: /* @__PURE__ */ __name(function e22(r22) {
    u2 = true, o2 = r22;
  }, "e2"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2.return || t2.return();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper$2, "_createForOfIteratorHelper$2");
function _unsupportedIterableToArray$4(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$4(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$4(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$4, "_unsupportedIterableToArray$4");
function _arrayLikeToArray$4(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$4, "_arrayLikeToArray$4");
function copyReverse(array) {
  return array.slice(0).reverse();
}
__name(copyReverse, "copyReverse");
function makeDropTarget(_ref) {
  var typeKey = _ref.typeKey, defaultDropEffect = _ref.defaultDropEffect;
  var registry = /* @__PURE__ */ new WeakMap();
  var dropTargetDataAtt = "data-drop-target-for-".concat(typeKey);
  var dropTargetSelector = "[".concat(dropTargetDataAtt, "]");
  function addToRegistry2(args) {
    registry.set(args.element, args);
    return function() {
      return registry.delete(args.element);
    };
  }
  __name(addToRegistry2, "addToRegistry");
  function dropTargetForConsumers(args) {
    if (false) {
      var existing = registry.get(args.element);
      if (existing) {
        console.warn("You have already registered a [".concat(typeKey, "] dropTarget on the same element"), {
          existing,
          proposed: args
        });
      }
      if (args.element instanceof HTMLIFrameElement) {
        console.warn("\n            We recommend not registering <iframe> elements as drop targets\n            as it can result in some strange browser event ordering.\n          ".replace(/\s{2,}/g, " ").trim());
      }
    }
    return combine(addAttribute(args.element, {
      attribute: dropTargetDataAtt,
      value: "true"
    }), addToRegistry2(args));
  }
  __name(dropTargetForConsumers, "dropTargetForConsumers");
  function getActualDropTargets(_ref2) {
    var _args$getData, _args$getData2, _args$getDropEffect, _args$getDropEffect2;
    var source = _ref2.source, target2 = _ref2.target, input = _ref2.input, _ref2$result = _ref2.result, result = _ref2$result === void 0 ? [] : _ref2$result;
    if (target2 == null) {
      return result;
    }
    if (!(target2 instanceof Element)) {
      if (target2 instanceof Node) {
        return getActualDropTargets({
          source,
          target: target2.parentElement,
          input,
          result
        });
      }
      return result;
    }
    var closest = target2.closest(dropTargetSelector);
    if (closest == null) {
      return result;
    }
    var args = registry.get(closest);
    if (args == null) {
      return result;
    }
    var feedback = {
      input,
      source,
      element: args.element
    };
    if (args.canDrop && !args.canDrop(feedback)) {
      return getActualDropTargets({
        source,
        target: args.element.parentElement,
        input,
        result
      });
    }
    var data30 = (_args$getData = (_args$getData2 = args.getData) === null || _args$getData2 === void 0 ? void 0 : _args$getData2.call(args, feedback)) !== null && _args$getData !== void 0 ? _args$getData : {};
    var dropEffect = (_args$getDropEffect = (_args$getDropEffect2 = args.getDropEffect) === null || _args$getDropEffect2 === void 0 ? void 0 : _args$getDropEffect2.call(args, feedback)) !== null && _args$getDropEffect !== void 0 ? _args$getDropEffect : defaultDropEffect;
    var record2 = {
      data: data30,
      element: args.element,
      dropEffect,
      // we are collecting _actual_ drop targets, so these are
      // being applied _not_ due to stickiness
      isActiveDueToStickiness: false
    };
    return getActualDropTargets({
      source,
      target: args.element.parentElement,
      input,
      // Using bubble ordering. Same ordering as `event.getPath()`
      result: [].concat(_toConsumableArray$3(result), [record2])
    });
  }
  __name(getActualDropTargets, "getActualDropTargets");
  function notifyCurrent(_ref3) {
    var eventName = _ref3.eventName, payload = _ref3.payload;
    var _iterator = _createForOfIteratorHelper$2(payload.location.current.dropTargets), _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done; ) {
        var _entry$eventName;
        var record2 = _step.value;
        var entry = registry.get(record2.element);
        var args = _objectSpread$4(_objectSpread$4({}, payload), {}, {
          self: record2
        });
        entry === null || entry === void 0 || (_entry$eventName = entry[eventName]) === null || _entry$eventName === void 0 || _entry$eventName.call(
          entry,
          // I cannot seem to get the types right here.
          // TS doesn't seem to like that one event can need `nativeSetDragImage`
          // @ts-expect-error
          args
        );
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
  }
  __name(notifyCurrent, "notifyCurrent");
  var actions = {
    onGenerateDragPreview: notifyCurrent,
    onDrag: notifyCurrent,
    onDragStart: notifyCurrent,
    onDrop: notifyCurrent,
    onDropTargetChange: /* @__PURE__ */ __name(function onDropTargetChange(_ref4) {
      var payload = _ref4.payload;
      var isCurrent = new Set(payload.location.current.dropTargets.map(function(record22) {
        return record22.element;
      }));
      var visited = /* @__PURE__ */ new Set();
      var _iterator2 = _createForOfIteratorHelper$2(payload.location.previous.dropTargets), _step2;
      try {
        for (_iterator2.s(); !(_step2 = _iterator2.n()).done; ) {
          var _entry$onDropTargetCh;
          var record2 = _step2.value;
          visited.add(record2.element);
          var entry = registry.get(record2.element);
          var isOver = isCurrent.has(record2.element);
          var args = _objectSpread$4(_objectSpread$4({}, payload), {}, {
            self: record2
          });
          entry === null || entry === void 0 || (_entry$onDropTargetCh = entry.onDropTargetChange) === null || _entry$onDropTargetCh === void 0 || _entry$onDropTargetCh.call(entry, args);
          if (!isOver) {
            var _entry$onDragLeave;
            entry === null || entry === void 0 || (_entry$onDragLeave = entry.onDragLeave) === null || _entry$onDragLeave === void 0 || _entry$onDragLeave.call(entry, args);
          }
        }
      } catch (err) {
        _iterator2.e(err);
      } finally {
        _iterator2.f();
      }
      var _iterator3 = _createForOfIteratorHelper$2(payload.location.current.dropTargets), _step3;
      try {
        for (_iterator3.s(); !(_step3 = _iterator3.n()).done; ) {
          var _entry$onDropTargetCh2, _entry$onDragEnter;
          var _record = _step3.value;
          if (visited.has(_record.element)) {
            continue;
          }
          var _args = _objectSpread$4(_objectSpread$4({}, payload), {}, {
            self: _record
          });
          var _entry = registry.get(_record.element);
          _entry === null || _entry === void 0 || (_entry$onDropTargetCh2 = _entry.onDropTargetChange) === null || _entry$onDropTargetCh2 === void 0 || _entry$onDropTargetCh2.call(_entry, _args);
          _entry === null || _entry === void 0 || (_entry$onDragEnter = _entry.onDragEnter) === null || _entry$onDragEnter === void 0 || _entry$onDragEnter.call(_entry, _args);
        }
      } catch (err) {
        _iterator3.e(err);
      } finally {
        _iterator3.f();
      }
    }, "onDropTargetChange")
  };
  function dispatchEvent2(args) {
    actions[args.eventName](args);
  }
  __name(dispatchEvent2, "dispatchEvent");
  function getIsOver(_ref5) {
    var source = _ref5.source, target2 = _ref5.target, input = _ref5.input, current = _ref5.current;
    var actual = getActualDropTargets({
      source,
      target: target2,
      input
    });
    if (actual.length >= current.length) {
      return actual;
    }
    var lastCaptureOrdered = copyReverse(current);
    var actualCaptureOrdered = copyReverse(actual);
    var resultCaptureOrdered = [];
    for (var index2 = 0; index2 < lastCaptureOrdered.length; index2++) {
      var _argsForLast$getIsSti;
      var last = lastCaptureOrdered[index2];
      var fresh = actualCaptureOrdered[index2];
      if (fresh != null) {
        resultCaptureOrdered.push(fresh);
        continue;
      }
      var parent = resultCaptureOrdered[index2 - 1];
      var lastParent = lastCaptureOrdered[index2 - 1];
      if ((parent === null || parent === void 0 ? void 0 : parent.element) !== (lastParent === null || lastParent === void 0 ? void 0 : lastParent.element)) {
        break;
      }
      var argsForLast = registry.get(last.element);
      if (!argsForLast) {
        break;
      }
      var feedback = {
        input,
        source,
        element: argsForLast.element
      };
      if (argsForLast.canDrop && !argsForLast.canDrop(feedback)) {
        break;
      }
      if (!((_argsForLast$getIsSti = argsForLast.getIsSticky) !== null && _argsForLast$getIsSti !== void 0 && _argsForLast$getIsSti.call(argsForLast, feedback))) {
        break;
      }
      resultCaptureOrdered.push(_objectSpread$4(_objectSpread$4({}, last), {}, {
        // making it clear to consumers this drop target is active due to stickiness
        isActiveDueToStickiness: true
      }));
    }
    return copyReverse(resultCaptureOrdered);
  }
  __name(getIsOver, "getIsOver");
  return {
    dropTargetForConsumers,
    getIsOver,
    dispatchEvent: dispatchEvent2
  };
}
__name(makeDropTarget, "makeDropTarget");
function _createForOfIteratorHelper$1(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$3(r2)) || e2 && r2 && "number" == typeof r2.length) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F3() {
      }, "F");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
        throw r3;
      }, "e"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r3 = t2.next();
    return a2 = r3.done, r3;
  }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
    u2 = true, o2 = r3;
  }, "e"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2.return || t2.return();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper$1, "_createForOfIteratorHelper$1");
function _unsupportedIterableToArray$3(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$3(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$3(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$3, "_unsupportedIterableToArray$3");
function _arrayLikeToArray$3(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$3, "_arrayLikeToArray$3");
function ownKeys$3(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$3, "ownKeys$3");
function _objectSpread$3(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$3(Object(t2), true).forEach(function(r3) {
      _defineProperty$3(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$3(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$3, "_objectSpread$3");
function makeMonitor() {
  var registry = /* @__PURE__ */ new Set();
  var dragging = null;
  function tryAddToActive(monitor) {
    if (!dragging) {
      return;
    }
    if (!monitor.canMonitor || monitor.canMonitor(dragging.canMonitorArgs)) {
      dragging.active.add(monitor);
    }
  }
  __name(tryAddToActive, "tryAddToActive");
  function monitorForConsumers(args) {
    var entry = _objectSpread$3({}, args);
    registry.add(entry);
    tryAddToActive(entry);
    return /* @__PURE__ */ __name(function cleanup() {
      registry.delete(entry);
      if (dragging) {
        dragging.active.delete(entry);
      }
    }, "cleanup");
  }
  __name(monitorForConsumers, "monitorForConsumers");
  function dispatchEvent2(_ref) {
    var eventName = _ref.eventName, payload = _ref.payload;
    if (eventName === "onGenerateDragPreview") {
      dragging = {
        canMonitorArgs: {
          initial: payload.location.initial,
          source: payload.source
        },
        active: /* @__PURE__ */ new Set()
      };
      var _iterator = _createForOfIteratorHelper$1(registry), _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done; ) {
          var monitor = _step.value;
          tryAddToActive(monitor);
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
    if (!dragging) {
      return;
    }
    var active4 = Array.from(dragging.active);
    for (var _i = 0, _active = active4; _i < _active.length; _i++) {
      var _monitor = _active[_i];
      if (dragging.active.has(_monitor)) {
        var _monitor$eventName;
        (_monitor$eventName = _monitor[eventName]) === null || _monitor$eventName === void 0 || _monitor$eventName.call(_monitor, payload);
      }
    }
    if (eventName === "onDrop") {
      dragging.active.clear();
      dragging = null;
    }
  }
  __name(dispatchEvent2, "dispatchEvent");
  return {
    dispatchEvent: dispatchEvent2,
    monitorForConsumers
  };
}
__name(makeMonitor, "makeMonitor");
function makeAdapter(_ref) {
  var typeKey = _ref.typeKey, mount2 = _ref.mount, dispatchEventToSource2 = _ref.dispatchEventToSource, onPostDispatch = _ref.onPostDispatch, defaultDropEffect = _ref.defaultDropEffect;
  var monitorAPI = makeMonitor();
  var dropTargetAPI = makeDropTarget({
    typeKey,
    defaultDropEffect
  });
  function dispatchEvent2(args) {
    dispatchEventToSource2 === null || dispatchEventToSource2 === void 0 || dispatchEventToSource2(args);
    dropTargetAPI.dispatchEvent(args);
    monitorAPI.dispatchEvent(args);
    onPostDispatch === null || onPostDispatch === void 0 || onPostDispatch(args);
  }
  __name(dispatchEvent2, "dispatchEvent");
  function start2(_ref2) {
    var event = _ref2.event, dragType = _ref2.dragType;
    lifecycle.start({
      event,
      dragType,
      getDropTargetsOver: dropTargetAPI.getIsOver,
      dispatchEvent: dispatchEvent2
    });
  }
  __name(start2, "start");
  function registerUsage2() {
    function mountAdapter() {
      var api2 = {
        canStart: lifecycle.canStart,
        start: start2
      };
      return mount2(api2);
    }
    __name(mountAdapter, "mountAdapter");
    return register({
      typeKey,
      mount: mountAdapter
    });
  }
  __name(registerUsage2, "registerUsage");
  return {
    registerUsage: registerUsage2,
    dropTarget: dropTargetAPI.dropTargetForConsumers,
    monitor: monitorAPI.monitorForConsumers
  };
}
__name(makeAdapter, "makeAdapter");
var isAndroid = once(/* @__PURE__ */ __name(function isAndroid2() {
  return navigator.userAgent.toLocaleLowerCase().includes("android");
}, "isAndroid"));
var androidFallbackText = "pdnd:android-fallback";
var textMediaType = "text/plain";
var URLMediaType = "text/uri-list";
var elementAdapterNativeDataKey = "application/vnd.pdnd";
var draggableRegistry = /* @__PURE__ */ new WeakMap();
function addToRegistry(args) {
  draggableRegistry.set(args.element, args);
  return /* @__PURE__ */ __name(function cleanup() {
    draggableRegistry.delete(args.element);
  }, "cleanup");
}
__name(addToRegistry, "addToRegistry");
var honeyPotFix = makeHoneyPotFix();
var adapter = makeAdapter({
  typeKey: "element",
  defaultDropEffect: "move",
  mount: /* @__PURE__ */ __name(function mount(api2) {
    return combine(honeyPotFix.bindEvents(), dist.bind(document, {
      type: "dragstart",
      listener: /* @__PURE__ */ __name(function listener(event) {
        var _entry$dragHandle, _entry$getInitialData, _entry$getInitialData2, _entry$dragHandle2, _entry$getInitialData3, _entry$getInitialData4;
        if (!api2.canStart(event)) {
          return;
        }
        if (event.defaultPrevented) {
          return;
        }
        if (!event.dataTransfer) {
          if (false) {
            console.warn("\n              It appears as though you have are not testing DragEvents correctly.\n\n              - If you are unit testing, ensure you have polyfilled DragEvent.\n              - If you are browser testing, ensure you are dispatching drag events correctly.\n\n              Please see our testing guides for more information:\n              https://atlassian.design/components/pragmatic-drag-and-drop/core-package/testing\n            ".replace(/ {2}/g, ""));
          }
          return;
        }
        var target2 = event.target;
        if (!(target2 instanceof HTMLElement)) {
          return null;
        }
        var entry = draggableRegistry.get(target2);
        if (!entry) {
          return null;
        }
        var input = getInput(event);
        var feedback = {
          element: entry.element,
          dragHandle: (_entry$dragHandle = entry.dragHandle) !== null && _entry$dragHandle !== void 0 ? _entry$dragHandle : null,
          input
        };
        if (entry.canDrag && !entry.canDrag(feedback)) {
          event.preventDefault();
          return null;
        }
        if (entry.dragHandle) {
          var over = getElementFromPointWithoutHoneypot({
            x: input.clientX,
            y: input.clientY
          });
          if (!entry.dragHandle.contains(over)) {
            event.preventDefault();
            return null;
          }
        }
        var nativeData = (_entry$getInitialData = (_entry$getInitialData2 = entry.getInitialDataForExternal) === null || _entry$getInitialData2 === void 0 ? void 0 : _entry$getInitialData2.call(entry, feedback)) !== null && _entry$getInitialData !== void 0 ? _entry$getInitialData : null;
        if (nativeData) {
          for (var _i = 0, _Object$entries = Object.entries(nativeData); _i < _Object$entries.length; _i++) {
            var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2), key = _Object$entries$_i[0], data30 = _Object$entries$_i[1];
            event.dataTransfer.setData(key, data30 !== null && data30 !== void 0 ? data30 : "");
          }
        }
        if (isAndroid() && !event.dataTransfer.types.includes(textMediaType) && !event.dataTransfer.types.includes(URLMediaType)) {
          event.dataTransfer.setData(textMediaType, androidFallbackText);
        }
        event.dataTransfer.setData(elementAdapterNativeDataKey, "");
        var payload = {
          element: entry.element,
          dragHandle: (_entry$dragHandle2 = entry.dragHandle) !== null && _entry$dragHandle2 !== void 0 ? _entry$dragHandle2 : null,
          data: (_entry$getInitialData3 = (_entry$getInitialData4 = entry.getInitialData) === null || _entry$getInitialData4 === void 0 ? void 0 : _entry$getInitialData4.call(entry, feedback)) !== null && _entry$getInitialData3 !== void 0 ? _entry$getInitialData3 : {}
        };
        var dragType = {
          type: "element",
          payload,
          startedFrom: "internal"
        };
        api2.start({
          event,
          dragType
        });
      }, "listener")
    }));
  }, "mount"),
  dispatchEventToSource: /* @__PURE__ */ __name(function dispatchEventToSource(_ref) {
    var _draggableRegistry$ge, _draggableRegistry$ge2;
    var eventName = _ref.eventName, payload = _ref.payload;
    (_draggableRegistry$ge = draggableRegistry.get(payload.source.element)) === null || _draggableRegistry$ge === void 0 || (_draggableRegistry$ge2 = _draggableRegistry$ge[eventName]) === null || _draggableRegistry$ge2 === void 0 || _draggableRegistry$ge2.call(
      _draggableRegistry$ge,
      // I cannot seem to get the types right here.
      // TS doesn't seem to like that one event can need `nativeSetDragImage`
      // @ts-expect-error
      payload
    );
  }, "dispatchEventToSource"),
  onPostDispatch: honeyPotFix.getOnPostDispatch()
});
var dropTargetForElements = adapter.dropTarget;
var monitorForElements = adapter.monitor;
function draggable(args) {
  if (false) {
    if (args.dragHandle && !args.element.contains(args.dragHandle)) {
      console.warn("Drag handle element must be contained in draggable element", {
        element: args.element,
        dragHandle: args.dragHandle
      });
    }
  }
  if (false) {
    var existing = draggableRegistry.get(args.element);
    if (existing) {
      console.warn("You have already registered a `draggable` on the same element", {
        existing,
        proposed: args
      });
    }
  }
  return combine(
    // making the draggable register the adapter rather than drop targets
    // this is because you *must* have a draggable element to start a drag
    // but you _might_ not have any drop targets immediately
    // (You might create drop targets async)
    adapter.registerUsage(),
    addToRegistry(args),
    addAttribute(args.element, {
      attribute: "draggable",
      value: "true"
    })
  );
}
__name(draggable, "draggable");
function defaultOffset() {
  return {
    x: 0,
    y: 0
  };
}
__name(defaultOffset, "defaultOffset");
function setCustomNativeDragPreview(_ref) {
  var render2 = _ref.render, nativeSetDragImage = _ref.nativeSetDragImage, _ref$getOffset = _ref.getOffset, getOffset2 = _ref$getOffset === void 0 ? defaultOffset : _ref$getOffset;
  var container = document.createElement("div");
  Object.assign(container.style, {
    // Ensuring we don't cause reflow when adding the element to the page
    // Using `position:fixed` rather than `position:absolute` so we are
    // positioned on the current viewport.
    // `position:fixed` also creates a new stacking context, so we don't need to do that here
    position: "fixed",
    // According to `mdn`, the element can be offscreen:
    // https://developer.mozilla.org/en-US/docs/Web/API/DataTransfer/setDragImage#imgelement
    //
    // However, that  information does not appear in the specs:
    // https://html.spec.whatwg.org/multipage/dnd.html#dom-datatransfer-setdragimage-dev
    //
    // If the element is _completely_ offscreen, Safari@17.1 will cancel the drag
    top: 0,
    left: 0,
    // Using maximum possible z-index so that this element will always be on top
    // https://stackoverflow.com/questions/491052/minimum-and-maximum-value-of-z-index
    // Did not use `layers` in `@atlaskit/theme` because:
    // 1. This element is not a 'layer' in the conventional sense, as this element
    //    is only created for a single frame for the browser to take a photo of it,
    //    and then it is destroyed
    // 2. Did not want to add a dependency onto `@atlaskit/theme`
    // 3. Want to always be on top of product UI which might have higher z-index's
    zIndex: maxZIndex,
    // Avoiding any additional events caused by the new element (being super safe)
    pointerEvents: "none"
  });
  document.body.append(container);
  var unmount = render2({
    container
  });
  queueMicrotask(function() {
    var previewOffset = getOffset2({
      container
    });
    if (isSafari()) {
      var rect = container.getBoundingClientRect();
      if (rect.width === 0) {
        return;
      }
      container.style.left = "-".concat(rect.width - 1e-4, "px");
    }
    nativeSetDragImage === null || nativeSetDragImage === void 0 || nativeSetDragImage(container, previewOffset.x, previewOffset.y);
  });
  function cleanup() {
    unbindMonitor();
    unmount === null || unmount === void 0 || unmount();
    document.body.removeChild(container);
  }
  __name(cleanup, "cleanup");
  var unbindMonitor = monitorForElements({
    // Remove portal in the dragstart event so that the user will never see it
    onDragStart: cleanup,
    // Backup: remove portal when the drop finishes (this would be an error case)
    onDrop: cleanup
  });
}
__name(setCustomNativeDragPreview, "setCustomNativeDragPreview");
const _hoisted_1$l = { class: "editable-text" };
const _hoisted_2$g = { key: 0 };
const _sfc_main$p = /* @__PURE__ */ defineComponent({
  __name: "EditableText",
  props: {
    modelValue: {},
    isEditing: { type: Boolean, default: false }
  },
  emits: ["update:modelValue", "edit"],
  setup(__props, { emit: __emit }) {
    const emit2 = __emit;
    const inputValue2 = ref(__props.modelValue);
    const inputRef = ref();
    const blurInputElement = /* @__PURE__ */ __name(() => {
      inputRef.value?.$el.blur();
    }, "blurInputElement");
    const finishEditing = /* @__PURE__ */ __name(() => {
      emit2("edit", inputValue2.value);
    }, "finishEditing");
    watch(
      () => __props.isEditing,
      (newVal) => {
        if (newVal) {
          inputValue2.value = __props.modelValue;
          nextTick(() => {
            if (!inputRef.value) return;
            const fileName = inputValue2.value.includes(".") ? inputValue2.value.split(".").slice(0, -1).join(".") : inputValue2.value;
            const start2 = 0;
            const end = fileName.length;
            const inputElement = inputRef.value.$el;
            inputElement.setSelectionRange?.(start2, end);
          });
        }
      },
      { immediate: true }
    );
    const vFocus = {
      mounted: /* @__PURE__ */ __name((el) => el.focus(), "mounted")
    };
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$l, [
        !_ctx.isEditing ? (openBlock(), createElementBlock("span", _hoisted_2$g, toDisplayString$1(_ctx.modelValue), 1)) : withDirectives((openBlock(), createBlock(unref(script$P), {
          key: 1,
          type: "text",
          size: "small",
          fluid: "",
          modelValue: inputValue2.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => inputValue2.value = $event),
          ref_key: "inputRef",
          ref: inputRef,
          onKeyup: withKeys(blurInputElement, ["enter"]),
          onClick: _cache[1] || (_cache[1] = withModifiers(() => {
          }, ["stop"])),
          pt: {
            root: {
              onBlur: finishEditing
            }
          }
        }, null, 8, ["modelValue", "pt"])), [
          [vFocus]
        ])
      ]);
    };
  }
});
const EditableText = /* @__PURE__ */ _export_sfc(_sfc_main$p, [["__scopeId", "data-v-a6a54dc8"]]);
function usePragmaticDroppable(dropTargetElement, options5) {
  let cleanup = /* @__PURE__ */ __name(() => {
  }, "cleanup");
  onMounted(() => {
    const element = typeof dropTargetElement === "function" ? dropTargetElement() : dropTargetElement;
    if (!element) {
      return;
    }
    cleanup = dropTargetForElements({
      element,
      ...options5
    });
  });
  onBeforeUnmount(() => {
    cleanup();
  });
}
__name(usePragmaticDroppable, "usePragmaticDroppable");
function usePragmaticDraggable(draggableElement, options5) {
  let cleanup = /* @__PURE__ */ __name(() => {
  }, "cleanup");
  onMounted(() => {
    const element = typeof draggableElement === "function" ? draggableElement() : draggableElement;
    if (!element) {
      return;
    }
    cleanup = draggable({
      element,
      ...options5
    });
  });
  onBeforeUnmount(() => {
    cleanup();
  });
}
__name(usePragmaticDraggable, "usePragmaticDraggable");
const InjectKeyHandleEditLabelFunction = Symbol();
const InjectKeyExpandedKeys = Symbol();
const _hoisted_1$k = { class: "node-content" };
const _hoisted_2$f = { class: "node-label" };
const _hoisted_3$9 = { class: "node-actions motion-safe:opacity-0 motion-safe:group-hover/tree-node:opacity-100" };
const _sfc_main$o = /* @__PURE__ */ defineComponent({
  __name: "TreeExplorerTreeNode",
  props: {
    node: {}
  },
  emits: ["itemDropped", "dragStart", "dragEnd"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit2 = __emit;
    const nodeBadgeText = computed(() => {
      if (props.node.leaf) {
        return "";
      }
      if (props.node.badgeText !== void 0 && props.node.badgeText !== null) {
        return props.node.badgeText;
      }
      return props.node.totalLeaves.toString();
    });
    const showNodeBadgeText = computed(() => nodeBadgeText.value !== "");
    const isEditing = computed(() => props.node.isEditingLabel ?? false);
    const handleEditLabel = inject(InjectKeyHandleEditLabelFunction);
    const handleRename = /* @__PURE__ */ __name((newName) => {
      handleEditLabel?.(props.node, newName);
    }, "handleRename");
    const container = ref(null);
    const canDrop = ref(false);
    const treeNodeElementGetter = /* @__PURE__ */ __name(() => container.value?.closest(".p-tree-node-content"), "treeNodeElementGetter");
    if (props.node.draggable) {
      usePragmaticDraggable(treeNodeElementGetter, {
        getInitialData: /* @__PURE__ */ __name(() => {
          return {
            type: "tree-explorer-node",
            data: props.node
          };
        }, "getInitialData"),
        onDragStart: /* @__PURE__ */ __name(() => emit2("dragStart", props.node), "onDragStart"),
        onDrop: /* @__PURE__ */ __name(() => emit2("dragEnd", props.node), "onDrop"),
        onGenerateDragPreview: props.node.renderDragPreview ? ({ nativeSetDragImage }) => {
          setCustomNativeDragPreview({
            render: /* @__PURE__ */ __name(({ container: container2 }) => {
              return props.node.renderDragPreview?.(container2);
            }, "render"),
            nativeSetDragImage
          });
        } : void 0
      });
    }
    if (props.node.droppable) {
      usePragmaticDroppable(treeNodeElementGetter, {
        onDrop: /* @__PURE__ */ __name(async (event) => {
          const dndData = event.source.data;
          if (dndData.type === "tree-explorer-node") {
            await props.node.handleDrop?.(dndData);
            canDrop.value = false;
            emit2("itemDropped", props.node, dndData.data);
          }
        }, "onDrop"),
        onDragEnter: /* @__PURE__ */ __name((event) => {
          const dndData = event.source.data;
          if (dndData.type === "tree-explorer-node") {
            canDrop.value = true;
          }
        }, "onDragEnter"),
        onDragLeave: /* @__PURE__ */ __name(() => {
          canDrop.value = false;
        }, "onDragLeave")
      });
    }
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass([
          "tree-node",
          {
            "can-drop": canDrop.value,
            "tree-folder": !props.node.leaf,
            "tree-leaf": props.node.leaf
          }
        ]),
        ref_key: "container",
        ref: container
      }, [
        createBaseVNode("div", _hoisted_1$k, [
          createBaseVNode("span", _hoisted_2$f, [
            renderSlot(_ctx.$slots, "before-label", {
              node: props.node
            }, void 0, true),
            createVNode(EditableText, {
              modelValue: _ctx.node.label,
              isEditing: isEditing.value,
              onEdit: handleRename
            }, null, 8, ["modelValue", "isEditing"]),
            renderSlot(_ctx.$slots, "after-label", {
              node: props.node
            }, void 0, true)
          ]),
          showNodeBadgeText.value ? (openBlock(), createBlock(unref(script$11), {
            key: 0,
            value: nodeBadgeText.value,
            severity: "secondary",
            class: "leaf-count-badge"
          }, null, 8, ["value"])) : createCommentVNode("", true)
        ]),
        createBaseVNode("div", _hoisted_3$9, [
          renderSlot(_ctx.$slots, "actions", {
            node: props.node
          }, void 0, true)
        ])
      ], 2);
    };
  }
});
const TreeExplorerTreeNode = /* @__PURE__ */ _export_sfc(_sfc_main$o, [["__scopeId", "data-v-59d452dd"]]);
function useTreeFolderOperations(expandNode) {
  const { t: t2 } = useI18n();
  const newFolderNode = ref(null);
  const addFolderTargetNode = ref(null);
  const generateTempKey = /* @__PURE__ */ __name((parentKey) => {
    return `${parentKey}/new_folder_${Date.now()}`;
  }, "generateTempKey");
  const handleFolderCreation = /* @__PURE__ */ __name(async (newName) => {
    if (!newFolderNode.value || !addFolderTargetNode.value) return;
    try {
      await addFolderTargetNode.value?.handleAddFolder?.(newName);
    } finally {
      newFolderNode.value = null;
      addFolderTargetNode.value = null;
    }
  }, "handleFolderCreation");
  const addFolderCommand = /* @__PURE__ */ __name((targetNode) => {
    expandNode(targetNode);
    newFolderNode.value = {
      key: generateTempKey(targetNode.key),
      label: "",
      leaf: false,
      children: [],
      icon: "pi pi-folder",
      type: "folder",
      totalLeaves: 0,
      badgeText: "",
      isEditingLabel: true
    };
    addFolderTargetNode.value = targetNode;
  }, "addFolderCommand");
  const getAddFolderMenuItem = /* @__PURE__ */ __name((targetNode) => {
    return {
      label: t2("g.newFolder"),
      icon: "pi pi-folder-plus",
      command: /* @__PURE__ */ __name(() => {
        if (targetNode) addFolderCommand(targetNode);
      }, "command"),
      visible: !!targetNode && !targetNode.leaf && !!targetNode.handleAddFolder,
      isAsync: false
    };
  }, "getAddFolderMenuItem");
  return {
    newFolderNode,
    addFolderCommand,
    getAddFolderMenuItem,
    handleFolderCreation
  };
}
__name(useTreeFolderOperations, "useTreeFolderOperations");
const _sfc_main$n = /* @__PURE__ */ defineComponent({
  __name: "TreeExplorer",
  props: /* @__PURE__ */ mergeModels({
    root: {},
    class: {}
  }, {
    "expandedKeys": {
      required: true
    },
    "expandedKeysModifiers": {},
    "selectionKeys": {},
    "selectionKeysModifiers": {}
  }),
  emits: /* @__PURE__ */ mergeModels(["nodeClick", "nodeDelete", "contextMenu"], ["update:expandedKeys", "update:selectionKeys"]),
  setup(__props, { expose: __expose, emit: __emit }) {
    const expandedKeys2 = useModel(__props, "expandedKeys");
    provide(InjectKeyExpandedKeys, expandedKeys2);
    const selectionKeys = useModel(__props, "selectionKeys");
    const storeSelectionKeys = selectionKeys.value !== void 0;
    const props = __props;
    const emit2 = __emit;
    const {
      newFolderNode,
      getAddFolderMenuItem,
      handleFolderCreation,
      addFolderCommand
    } = useTreeFolderOperations(
      /* expandNode */
      (node3) => {
        expandedKeys2.value[node3.key] = true;
      }
    );
    const renderedRoot = computed(() => {
      const renderedRoot2 = fillNodeInfo(props.root);
      return newFolderNode.value ? combineTrees(renderedRoot2, newFolderNode.value) : renderedRoot2;
    });
    const getTreeNodeIcon = /* @__PURE__ */ __name((node3) => {
      if (node3.getIcon) {
        const icon3 = node3.getIcon();
        if (icon3) {
          return icon3;
        }
      } else if (node3.icon) {
        return node3.icon;
      }
      if (node3.leaf) {
        return "pi pi-file";
      }
      const isExpanded = expandedKeys2.value?.[node3.key] ?? false;
      return isExpanded ? "pi pi-folder-open" : "pi pi-folder";
    }, "getTreeNodeIcon");
    const fillNodeInfo = /* @__PURE__ */ __name((node3) => {
      const children = node3.children?.map(fillNodeInfo) ?? [];
      const totalLeaves = node3.leaf ? 1 : children.reduce((acc, child) => acc + child.totalLeaves, 0);
      return {
        ...node3,
        icon: getTreeNodeIcon(node3),
        children,
        type: node3.leaf ? "node" : "folder",
        totalLeaves,
        badgeText: node3.getBadgeText ? node3.getBadgeText() : void 0,
        isEditingLabel: node3.key === renameEditingNode.value?.key
      };
    }, "fillNodeInfo");
    const onNodeContentClick = /* @__PURE__ */ __name(async (e2, node3) => {
      if (!storeSelectionKeys) {
        selectionKeys.value = {};
      }
      if (node3.handleClick) {
        await node3.handleClick(e2);
      }
      emit2("nodeClick", node3, e2);
    }, "onNodeContentClick");
    const menu2 = ref(null);
    const menuTargetNode = ref(null);
    const extraMenuItems = computed(() => {
      return menuTargetNode.value?.contextMenuItems ? typeof menuTargetNode.value.contextMenuItems === "function" ? menuTargetNode.value.contextMenuItems(menuTargetNode.value) : menuTargetNode.value.contextMenuItems : [];
    });
    const renameEditingNode = ref(null);
    const errorHandling = useErrorHandling();
    const handleNodeLabelEdit = /* @__PURE__ */ __name(async (node3, newName) => {
      await errorHandling.wrapWithErrorHandlingAsync(
        async () => {
          if (node3.key === newFolderNode.value?.key) {
            await handleFolderCreation(newName);
          } else {
            await node3.handleRename?.(newName);
          }
        },
        node3.handleError,
        () => {
          renameEditingNode.value = null;
        }
      )();
    }, "handleNodeLabelEdit");
    provide(InjectKeyHandleEditLabelFunction, handleNodeLabelEdit);
    const { t: t2 } = useI18n();
    const renameCommand = /* @__PURE__ */ __name((node3) => {
      renameEditingNode.value = node3;
    }, "renameCommand");
    const deleteCommand = /* @__PURE__ */ __name(async (node3) => {
      await node3.handleDelete?.();
      emit2("nodeDelete", node3);
    }, "deleteCommand");
    const menuItems = computed(
      () => [
        getAddFolderMenuItem(menuTargetNode.value),
        {
          label: t2("g.rename"),
          icon: "pi pi-file-edit",
          command: /* @__PURE__ */ __name(() => {
            if (menuTargetNode.value) {
              renameCommand(menuTargetNode.value);
            }
          }, "command"),
          visible: menuTargetNode.value?.handleRename !== void 0
        },
        {
          label: t2("g.delete"),
          icon: "pi pi-trash",
          command: /* @__PURE__ */ __name(() => {
            if (menuTargetNode.value) {
              deleteCommand(menuTargetNode.value);
            }
          }, "command"),
          visible: menuTargetNode.value?.handleDelete !== void 0,
          isAsync: true
          // The delete command can be async
        },
        ...extraMenuItems.value
      ].map((menuItem) => ({
        ...menuItem,
        command: menuItem.command ? wrapCommandWithErrorHandler(menuItem.command, {
          isAsync: menuItem.isAsync ?? false
        }) : void 0
      }))
    );
    const handleContextMenu = /* @__PURE__ */ __name((e2, node3) => {
      menuTargetNode.value = node3;
      emit2("contextMenu", node3, e2);
      if (menuItems.value.filter((item3) => item3.visible).length > 0) {
        menu2.value?.show(e2);
      }
    }, "handleContextMenu");
    const wrapCommandWithErrorHandler = /* @__PURE__ */ __name((command2, { isAsync: isAsync2 = false }) => {
      return isAsync2 ? errorHandling.wrapWithErrorHandlingAsync(
        command2,
        menuTargetNode.value?.handleError
      ) : errorHandling.wrapWithErrorHandling(
        command2,
        menuTargetNode.value?.handleError
      );
    }, "wrapCommandWithErrorHandler");
    __expose({
      /**
       * The command to add a folder to a node via the context menu
       * @param targetNodeKey - The key of the node where the folder will be added under
       */
      addFolderCommand: /* @__PURE__ */ __name((targetNodeKey) => {
        const targetNode = findNodeByKey(renderedRoot.value, targetNodeKey);
        if (targetNode) {
          addFolderCommand(targetNode);
        }
      }, "addFolderCommand")
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(unref(script$b), {
          class: normalizeClass(["tree-explorer py-0 px-2 2xl:px-4", props.class]),
          expandedKeys: expandedKeys2.value,
          "onUpdate:expandedKeys": _cache[0] || (_cache[0] = ($event) => expandedKeys2.value = $event),
          selectionKeys: selectionKeys.value,
          "onUpdate:selectionKeys": _cache[1] || (_cache[1] = ($event) => selectionKeys.value = $event),
          value: renderedRoot.value.children,
          selectionMode: "single",
          pt: {
            nodeLabel: "tree-explorer-node-label",
            nodeContent: /* @__PURE__ */ __name(({ context }) => ({
              class: "group/tree-node",
              onClick: /* @__PURE__ */ __name((e2) => onNodeContentClick(e2, context.node), "onClick"),
              onContextmenu: /* @__PURE__ */ __name((e2) => handleContextMenu(e2, context.node), "onContextmenu")
            }), "nodeContent"),
            nodeToggleButton: /* @__PURE__ */ __name(() => ({
              onClick: /* @__PURE__ */ __name((e2) => {
                e2.stopImmediatePropagation();
              }, "onClick")
            }), "nodeToggleButton")
          }
        }, {
          folder: withCtx(({ node: node3 }) => [
            renderSlot(_ctx.$slots, "folder", { node: node3 }, () => [
              createVNode(TreeExplorerTreeNode, { node: node3 }, null, 8, ["node"])
            ], true)
          ]),
          node: withCtx(({ node: node3 }) => [
            renderSlot(_ctx.$slots, "node", { node: node3 }, () => [
              createVNode(TreeExplorerTreeNode, { node: node3 }, null, 8, ["node"])
            ], true)
          ]),
          _: 3
        }, 8, ["class", "expandedKeys", "selectionKeys", "value", "pt"]),
        createVNode(unref(script$c), {
          ref_key: "menu",
          ref: menu2,
          model: menuItems.value
        }, null, 8, ["model"])
      ], 64);
    };
  }
});
const TreeExplorer = /* @__PURE__ */ _export_sfc(_sfc_main$n, [["__scopeId", "data-v-d5079a55"]]);
var theme$5 = /* @__PURE__ */ __name(function theme41(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-toolbar {\n    display: flex;\n    align-items: center;\n    justify-content: space-between;\n    flex-wrap: wrap;\n    padding: ".concat(dt2("toolbar.padding"), ";\n    background: ").concat(dt2("toolbar.background"), ";\n    border: 1px solid ").concat(dt2("toolbar.border.color"), ";\n    color: ").concat(dt2("toolbar.color"), ";\n    border-radius: ").concat(dt2("toolbar.border.radius"), ";\n    gap: ").concat(dt2("toolbar.gap"), ";\n}\n\n.p-toolbar-start,\n.p-toolbar-center,\n.p-toolbar-end {\n    display: flex;\n    align-items: center;\n}\n");
}, "theme");
var classes$5 = {
  root: "p-toolbar p-component",
  start: "p-toolbar-start",
  center: "p-toolbar-center",
  end: "p-toolbar-end"
};
var ToolbarStyle = BaseStyle$1.extend({
  name: "toolbar",
  theme: theme$5,
  classes: classes$5
});
var script$1$5 = {
  name: "BaseToolbar",
  "extends": script$1b,
  props: {
    ariaLabelledby: {
      type: String,
      "default": null
    }
  },
  style: ToolbarStyle,
  provide: /* @__PURE__ */ __name(function provide46() {
    return {
      $pcToolbar: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$a = {
  name: "Toolbar",
  "extends": script$1$5,
  inheritAttrs: false
};
var _hoisted_1$j = ["aria-labelledby"];
function render$9(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    role: "toolbar",
    "aria-labelledby": _ctx.ariaLabelledby
  }, _ctx.ptmi("root")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("start")
  }, _ctx.ptm("start")), [renderSlot(_ctx.$slots, "start")], 16), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("center")
  }, _ctx.ptm("center")), [renderSlot(_ctx.$slots, "center")], 16), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("end")
  }, _ctx.ptm("end")), [renderSlot(_ctx.$slots, "end")], 16)], 16, _hoisted_1$j);
}
__name(render$9, "render$9");
script$a.render = render$9;
const _hoisted_1$i = { class: "comfy-vue-side-bar-header" };
const _hoisted_2$e = ["title"];
const _hoisted_3$8 = { class: "flex flex-row motion-safe:w-0 motion-safe:opacity-0 motion-safe:group-hover/sidebar-tab:w-auto motion-safe:group-hover/sidebar-tab:opacity-100 motion-safe:group-focus-within/sidebar-tab:w-auto motion-safe:group-focus-within/sidebar-tab:opacity-100 touch:w-auto touch:opacity-100 transition-all duration-200" };
const _sfc_main$m = /* @__PURE__ */ defineComponent({
  __name: "SidebarTabTemplate",
  props: {
    title: {},
    class: {}
  },
  setup(__props) {
    const props = __props;
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["comfy-vue-side-bar-container flex flex-col h-full group/sidebar-tab", props.class])
      }, [
        createBaseVNode("div", _hoisted_1$i, [
          createVNode(unref(script$a), { class: "border-x-0 border-t-0 rounded-none px-2 py-1 min-h-8" }, {
            start: withCtx(() => [
              createBaseVNode("span", {
                class: "text-xs 2xl:text-sm truncate",
                title: props.title
              }, toDisplayString$1(props.title.toUpperCase()), 9, _hoisted_2$e)
            ]),
            end: withCtx(() => [
              createBaseVNode("div", _hoisted_3$8, [
                renderSlot(_ctx.$slots, "tool-buttons", {}, void 0, true)
              ])
            ]),
            _: 3
          }),
          renderSlot(_ctx.$slots, "header", {}, void 0, true)
        ]),
        createVNode(unref(script$X), { class: "comfy-vue-side-bar-body flex-grow h-0" }, {
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "body", {}, void 0, true)
          ]),
          _: 3
        })
      ], 2);
    };
  }
});
const SidebarTabTemplate = /* @__PURE__ */ _export_sfc(_sfc_main$m, [["__scopeId", "data-v-0061c432"]]);
const _hoisted_1$h = { class: "flex flex-col" };
const _hoisted_2$d = { key: 0 };
const _hoisted_3$7 = {
  key: 1,
  class: "mt-2 flex flex-row items-center gap-2"
};
const _sfc_main$l = /* @__PURE__ */ defineComponent({
  __name: "DownloadItem",
  props: {
    download: {}
  },
  setup(__props) {
    const { t: t2 } = useI18n();
    const electronDownloadStore = useElectronDownloadStore();
    const props = __props;
    const getDownloadLabel = /* @__PURE__ */ __name((savePath) => {
      let parts2 = savePath.split("/");
      parts2 = parts2.length === 1 ? parts2[0].split("\\") : parts2;
      const name2 = parts2.pop();
      const dir = parts2.pop();
      return `${dir}/${name2}`;
    }, "getDownloadLabel");
    const triggerCancelDownload = /* @__PURE__ */ __name(() => electronDownloadStore.cancel(props.download.url), "triggerCancelDownload");
    const triggerPauseDownload = /* @__PURE__ */ __name(() => electronDownloadStore.pause(props.download.url), "triggerPauseDownload");
    const triggerResumeDownload = /* @__PURE__ */ __name(() => electronDownloadStore.resume(props.download.url), "triggerResumeDownload");
    const handleRemoveDownload = /* @__PURE__ */ __name(() => {
      electronDownloadStore.$patch((state) => {
        state.downloads = state.downloads.filter(
          ({ url }) => url !== props.download.url
        );
      });
    }, "handleRemoveDownload");
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock("div", _hoisted_1$h, [
        createBaseVNode("div", null, toDisplayString$1(getDownloadLabel(_ctx.download.savePath ?? "")), 1),
        ["cancelled", "error"].includes(_ctx.download.status ?? "") ? (openBlock(), createElementBlock("div", _hoisted_2$d, [
          createVNode(unref(script$A), {
            class: "h-6 text-sm font-light bg-red-700 mt-2",
            removable: "",
            onRemove: handleRemoveDownload
          }, {
            default: withCtx(() => [
              createTextVNode(toDisplayString$1(unref(t2)("electronFileDownload.cancelled")), 1)
            ]),
            _: 1
          })
        ])) : createCommentVNode("", true),
        ["in_progress", "paused", "completed"].includes(_ctx.download.status ?? "") ? (openBlock(), createElementBlock("div", _hoisted_3$7, [
          createVNode(unref(script$F), {
            class: "flex-1",
            value: Number(((_ctx.download.progress ?? 0) * 100).toFixed(1)),
            "show-value": (_ctx.download.progress ?? 0) > 0.1
          }, null, 8, ["value", "show-value"]),
          _ctx.download.status === "in_progress" ? withDirectives((openBlock(), createBlock(unref(script$10), {
            key: 0,
            class: "file-action-button w-[22px] h-[22px]",
            size: "small",
            rounded: "",
            onClick: triggerPauseDownload,
            icon: "pi pi-pause"
          }, null, 512)), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.pause"),
              void 0,
              { top: true }
            ]
          ]) : createCommentVNode("", true),
          _ctx.download.status === "paused" ? withDirectives((openBlock(), createBlock(unref(script$10), {
            key: 1,
            class: "file-action-button w-[22px] h-[22px]",
            size: "small",
            rounded: "",
            onClick: triggerResumeDownload,
            icon: "pi pi-play"
          }, null, 512)), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.resume"),
              void 0,
              { top: true }
            ]
          ]) : createCommentVNode("", true),
          ["in_progress", "paused"].includes(_ctx.download.status ?? "") ? withDirectives((openBlock(), createBlock(unref(script$10), {
            key: 2,
            class: "file-action-button w-[22px] h-[22px] p-red",
            size: "small",
            rounded: "",
            severity: "danger",
            onClick: triggerCancelDownload,
            icon: "pi pi-times-circle"
          }, null, 512)), [
            [
              _directive_tooltip,
              unref(t2)("electronFileDownload.cancel"),
              void 0,
              { top: true }
            ]
          ]) : createCommentVNode("", true)
        ])) : createCommentVNode("", true)
      ]);
    };
  }
});
const _hoisted_1$g = {
  key: 0,
  class: "mx-6 mb-4"
};
const _hoisted_2$c = { class: "text-lg my-4" };
const _sfc_main$k = /* @__PURE__ */ defineComponent({
  __name: "ElectronDownloadItems",
  setup(__props) {
    const electronDownloadStore = useElectronDownloadStore();
    const { inProgressDownloads } = storeToRefs(electronDownloadStore);
    return (_ctx, _cache) => {
      return unref(inProgressDownloads).length > 0 ? (openBlock(), createElementBlock("div", _hoisted_1$g, [
        createBaseVNode("div", _hoisted_2$c, toDisplayString$1(_ctx.$t("electronFileDownload.inProgress")), 1),
        (openBlock(true), createElementBlock(Fragment$1, null, renderList(unref(inProgressDownloads), (download2) => {
          return openBlock(), createBlock(_sfc_main$l, {
            key: download2.url,
            download: download2
          }, null, 8, ["download"]);
        }), 128))
      ])) : createCommentVNode("", true);
    };
  }
});
const _hoisted_1$f = { class: "model_preview" };
const _hoisted_2$b = { class: "model_preview_title" };
const _hoisted_3$6 = { class: "model_preview_top_container" };
const _hoisted_4$4 = { class: "model_preview_filename" };
const _hoisted_5$4 = {
  key: 0,
  class: "model_preview_architecture"
};
const _hoisted_6$2 = {
  key: 1,
  class: "model_preview_author"
};
const _hoisted_7$1 = {
  key: 0,
  class: "model_preview_image"
};
const _hoisted_8$1 = ["src"];
const _hoisted_9$1 = {
  key: 1,
  class: "model_preview_usage_hint"
};
const _hoisted_10$1 = {
  key: 2,
  class: "model_preview_trigger_phrase"
};
const _hoisted_11$1 = {
  key: 3,
  class: "model_preview_description"
};
const _sfc_main$j = /* @__PURE__ */ defineComponent({
  __name: "ModelPreview",
  props: {
    modelDef: {
      type: ComfyModelDef,
      required: true
    }
  },
  setup(__props) {
    const props = __props;
    const modelDef = props.modelDef;
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$f, [
        createBaseVNode("div", _hoisted_2$b, toDisplayString$1(unref(modelDef).title), 1),
        createBaseVNode("div", _hoisted_3$6, [
          createBaseVNode("div", _hoisted_4$4, toDisplayString$1(unref(modelDef).file_name), 1),
          unref(modelDef).architecture_id ? (openBlock(), createElementBlock("div", _hoisted_5$4, [
            _cache[0] || (_cache[0] = createBaseVNode("span", { class: "model_preview_prefix" }, "Architecture: ", -1)),
            createTextVNode(" " + toDisplayString$1(unref(modelDef).architecture_id), 1)
          ])) : createCommentVNode("", true),
          unref(modelDef).author ? (openBlock(), createElementBlock("div", _hoisted_6$2, [
            _cache[1] || (_cache[1] = createBaseVNode("span", { class: "model_preview_prefix" }, "Author: ", -1)),
            createTextVNode(" " + toDisplayString$1(unref(modelDef).author), 1)
          ])) : createCommentVNode("", true)
        ]),
        unref(modelDef).image ? (openBlock(), createElementBlock("div", _hoisted_7$1, [
          createBaseVNode("img", {
            src: unref(modelDef).image
          }, null, 8, _hoisted_8$1)
        ])) : createCommentVNode("", true),
        unref(modelDef).usage_hint ? (openBlock(), createElementBlock("div", _hoisted_9$1, [
          _cache[2] || (_cache[2] = createBaseVNode("span", { class: "model_preview_prefix" }, "Usage hint: ", -1)),
          createTextVNode(" " + toDisplayString$1(unref(modelDef).usage_hint), 1)
        ])) : createCommentVNode("", true),
        unref(modelDef).trigger_phrase ? (openBlock(), createElementBlock("div", _hoisted_10$1, [
          _cache[3] || (_cache[3] = createBaseVNode("span", { class: "model_preview_prefix" }, "Trigger phrase: ", -1)),
          createTextVNode(" " + toDisplayString$1(unref(modelDef).trigger_phrase), 1)
        ])) : createCommentVNode("", true),
        unref(modelDef).description ? (openBlock(), createElementBlock("div", _hoisted_11$1, [
          _cache[4] || (_cache[4] = createBaseVNode("span", { class: "model_preview_prefix" }, "Description: ", -1)),
          createTextVNode(" " + toDisplayString$1(unref(modelDef).description), 1)
        ])) : createCommentVNode("", true)
      ]);
    };
  }
});
const ModelPreview = /* @__PURE__ */ _export_sfc(_sfc_main$j, [["__scopeId", "data-v-32e6c4d9"]]);
const _hoisted_1$e = {
  key: 0,
  class: "model-lib-model-icon-container"
};
const _sfc_main$i = /* @__PURE__ */ defineComponent({
  __name: "ModelTreeLeaf",
  props: {
    node: {}
  },
  setup(__props) {
    const props = __props;
    const modelDef = computed(() => props.node.data);
    const modelPreviewUrl = computed(() => {
      if (modelDef.value.image) {
        return modelDef.value.image;
      }
      const folder = modelDef.value.directory;
      const path_index = modelDef.value.path_index;
      const extension = modelDef.value.file_name.split(".").pop();
      const filename = modelDef.value.file_name.replace(`.${extension}`, ".webp");
      const encodedFilename = encodeURIComponent(filename).replace(/%2F/g, "/");
      return `/api/experiment/models/preview/${folder}/${path_index}/${encodedFilename}`;
    });
    const previewRef = ref(null);
    const modelPreviewStyle = ref({
      position: "absolute",
      top: "0px",
      left: "0px"
    });
    const settingStore = useSettingStore();
    const sidebarLocation = computed(
      () => settingStore.get("Comfy.Sidebar.Location")
    );
    const handleModelHover = /* @__PURE__ */ __name(async () => {
      const hoverTarget = modelContentElement.value;
      if (!hoverTarget) return;
      const targetRect = hoverTarget.getBoundingClientRect();
      const previewHeight = previewRef.value?.$el.offsetHeight || 0;
      const availableSpaceBelow = window.innerHeight - targetRect.bottom;
      modelPreviewStyle.value.top = previewHeight > availableSpaceBelow ? `${Math.max(0, targetRect.top - (previewHeight - availableSpaceBelow) - 20)}px` : `${targetRect.top - 40}px`;
      if (sidebarLocation.value === "left") {
        modelPreviewStyle.value.left = `${targetRect.right}px`;
      } else {
        modelPreviewStyle.value.left = `${targetRect.left - 400}px`;
      }
      modelDef.value.load();
    }, "handleModelHover");
    const container = ref();
    const modelContentElement = ref();
    const isHovered = ref(false);
    const showPreview = computed(() => {
      return isHovered.value && modelDef.value && modelDef.value.has_loaded_metadata && (modelDef.value.author || modelDef.value.simplified_file_name != modelDef.value.title || modelDef.value.description || modelDef.value.usage_hint || modelDef.value.trigger_phrase || modelDef.value.image);
    });
    const handleMouseEnter = /* @__PURE__ */ __name(async () => {
      isHovered.value = true;
      await nextTick();
      handleModelHover();
    }, "handleMouseEnter");
    const handleMouseLeave2 = /* @__PURE__ */ __name(() => {
      isHovered.value = false;
    }, "handleMouseLeave");
    onMounted(() => {
      modelContentElement.value = container.value?.closest(".p-tree-node-content") ?? void 0;
      modelContentElement.value?.addEventListener("mouseenter", handleMouseEnter);
      modelContentElement.value?.addEventListener("mouseleave", handleMouseLeave2);
      modelDef.value.load();
    });
    onUnmounted(() => {
      modelContentElement.value?.removeEventListener("mouseenter", handleMouseEnter);
      modelContentElement.value?.removeEventListener("mouseleave", handleMouseLeave2);
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "container",
        ref: container,
        class: "model-lib-node-container h-full w-full"
      }, [
        createVNode(TreeExplorerTreeNode, { node: _ctx.node }, {
          "before-label": withCtx(() => [
            modelPreviewUrl.value ? (openBlock(), createElementBlock("span", _hoisted_1$e, [
              createBaseVNode("span", {
                class: "model-lib-model-icon",
                style: normalizeStyle({ backgroundImage: `url(${modelPreviewUrl.value})` })
              }, null, 4)
            ])) : createCommentVNode("", true)
          ]),
          _: 1
        }, 8, ["node"]),
        showPreview.value ? (openBlock(), createBlock(Teleport, {
          key: 0,
          to: "#model-library-model-preview-container"
        }, [
          createBaseVNode("div", {
            class: "model-lib-model-preview",
            style: normalizeStyle(modelPreviewStyle.value)
          }, [
            createVNode(ModelPreview, {
              ref_key: "previewRef",
              ref: previewRef,
              modelDef: modelDef.value
            }, null, 8, ["modelDef"])
          ], 4)
        ])) : createCommentVNode("", true)
      ], 512);
    };
  }
});
const ModelTreeLeaf = /* @__PURE__ */ _export_sfc(_sfc_main$i, [["__scopeId", "data-v-151fbf66"]]);
function useTreeExpansion(expandedKeys2) {
  const toggleNode2 = /* @__PURE__ */ __name((node3) => {
    if (node3.key && typeof node3.key === "string") {
      if (node3.key in expandedKeys2.value) {
        delete expandedKeys2.value[node3.key];
      } else {
        expandedKeys2.value[node3.key] = true;
      }
    }
  }, "toggleNode");
  const toggleNodeRecursive = /* @__PURE__ */ __name((node3) => {
    if (node3.key && typeof node3.key === "string") {
      if (node3.key in expandedKeys2.value) {
        collapseNode(node3);
      } else {
        expandNode(node3);
      }
    }
  }, "toggleNodeRecursive");
  const expandNode = /* @__PURE__ */ __name((node3) => {
    if (node3.key && typeof node3.key === "string" && !node3.leaf) {
      expandedKeys2.value[node3.key] = true;
      for (const child of node3.children ?? []) {
        expandNode(child);
      }
    }
  }, "expandNode");
  const collapseNode = /* @__PURE__ */ __name((node3) => {
    if (node3.key && typeof node3.key === "string" && !node3.leaf) {
      delete expandedKeys2.value[node3.key];
      for (const child of node3.children ?? []) {
        collapseNode(child);
      }
    }
  }, "collapseNode");
  const toggleNodeOnEvent = /* @__PURE__ */ __name((e2, node3) => {
    if (e2.ctrlKey) {
      toggleNodeRecursive(node3);
    } else {
      toggleNode2(node3);
    }
  }, "toggleNodeOnEvent");
  return {
    toggleNode: toggleNode2,
    toggleNodeRecursive,
    expandNode,
    collapseNode,
    toggleNodeOnEvent
  };
}
__name(useTreeExpansion, "useTreeExpansion");
class ModelNodeProvider {
  static {
    __name(this, "ModelNodeProvider");
  }
  /** The node definition to use for this model. */
  nodeDef;
  /** The node input key for where to inside the model name. */
  key;
  constructor(nodeDef, key) {
    this.nodeDef = nodeDef;
    this.key = key;
  }
}
const useModelToNodeStore = /* @__PURE__ */ defineStore("modelToNode", () => {
  const modelToNodeMap = ref({});
  const nodeDefStore = useNodeDefStore();
  const haveDefaultsLoaded = ref(false);
  function getNodeProvider(modelType) {
    registerDefaults();
    return modelToNodeMap.value[modelType]?.[0];
  }
  __name(getNodeProvider, "getNodeProvider");
  function getAllNodeProviders(modelType) {
    registerDefaults();
    return modelToNodeMap.value[modelType] ?? [];
  }
  __name(getAllNodeProviders, "getAllNodeProviders");
  function registerNodeProvider(modelType, nodeProvider) {
    registerDefaults();
    if (!modelToNodeMap.value[modelType]) {
      modelToNodeMap.value[modelType] = [];
    }
    modelToNodeMap.value[modelType].push(nodeProvider);
  }
  __name(registerNodeProvider, "registerNodeProvider");
  function quickRegister(modelType, nodeClass, key) {
    registerNodeProvider(
      modelType,
      new ModelNodeProvider(nodeDefStore.nodeDefsByName[nodeClass], key)
    );
  }
  __name(quickRegister, "quickRegister");
  function registerDefaults() {
    if (haveDefaultsLoaded.value) {
      return;
    }
    if (Object.keys(nodeDefStore.nodeDefsByName).length === 0) {
      return;
    }
    haveDefaultsLoaded.value = true;
    quickRegister("checkpoints", "CheckpointLoaderSimple", "ckpt_name");
    quickRegister("checkpoints", "ImageOnlyCheckpointLoader", "ckpt_name");
    quickRegister("loras", "LoraLoader", "lora_name");
    quickRegister("loras", "LoraLoaderModelOnly", "lora_name");
    quickRegister("vae", "VAELoader", "vae_name");
    quickRegister("controlnet", "ControlNetLoader", "control_net_name");
  }
  __name(registerDefaults, "registerDefaults");
  return {
    modelToNodeMap,
    getNodeProvider,
    getAllNodeProviders,
    registerNodeProvider,
    quickRegister,
    registerDefaults
  };
});
const _sfc_main$h = /* @__PURE__ */ defineComponent({
  __name: "ModelLibrarySidebarTab",
  setup(__props) {
    const modelStore = useModelStore();
    const modelToNodeStore = useModelToNodeStore();
    const settingStore = useSettingStore();
    const searchQuery = ref("");
    const expandedKeys2 = ref({});
    const { expandNode, toggleNodeOnEvent } = useTreeExpansion(expandedKeys2);
    const filteredModels = ref([]);
    const handleSearch = /* @__PURE__ */ __name(async (query) => {
      if (!query) {
        filteredModels.value = [];
        expandedKeys2.value = {};
        return;
      }
      await modelStore.loadModels();
      const search3 = query.toLocaleLowerCase();
      filteredModels.value = modelStore.models.filter((model) => {
        return model.searchable.includes(search3);
      });
      nextTick(() => {
        expandNode(root34.value);
      });
    }, "handleSearch");
    const root34 = computed(() => {
      const allNodes = searchQuery.value ? filteredModels.value : [...modelStore.modelFolders, ...modelStore.models];
      return buildTree$1(
        allNodes,
        (modelOrFolder) => modelOrFolder.key.split("/")
      );
    });
    const renderedRoot = computed(() => {
      const nameFormat = settingStore.get("Comfy.ModelLibrary.NameFormat");
      const fillNodeInfo = /* @__PURE__ */ __name((node3) => {
        const children = node3.children?.map(fillNodeInfo);
        const model = node3.leaf && node3.data ? node3.data : null;
        const folder = !node3.leaf && node3.data ? node3.data : null;
        return {
          key: node3.key,
          label: model ? nameFormat === "title" ? model.title : model.simplified_file_name : node3.label,
          leaf: node3.leaf,
          data: node3.data,
          getIcon() {
            if (model) {
              return model.image ? "pi pi-image" : "pi pi-file";
            }
            if (folder) {
              return folder.state === ResourceState.Loading ? "pi pi-spin pi-spinner" : "pi pi-folder";
            }
            return "pi pi-folder";
          },
          getBadgeText() {
            if (!folder) {
              return;
            }
            return folder.state === ResourceState.Loaded ? void 0 : "";
          },
          children,
          draggable: node3.leaf,
          handleClick(e2) {
            if (this.leaf) {
              const provider = modelToNodeStore.getNodeProvider(model.directory);
              if (provider) {
                const node22 = useLitegraphService().addNodeOnGraph(provider.nodeDef);
                const widget = node22.widgets.find(
                  (widget2) => widget2.name === provider.key
                );
                if (widget) {
                  widget.value = model.file_name;
                }
              }
            } else {
              toggleNodeOnEvent(e2, node3);
            }
          }
        };
      }, "fillNodeInfo");
      return fillNodeInfo(root34.value);
    });
    watch(
      toRef$1(expandedKeys2, "value"),
      (newExpandedKeys) => {
        Object.entries(newExpandedKeys).forEach(([key, isExpanded]) => {
          if (isExpanded) {
            const folderPath = key.split("/").slice(1).join("/");
            if (folderPath && !folderPath.includes("/")) {
              modelStore.getLoadedModelFolder(folderPath);
            }
          }
        });
      },
      { deep: true }
    );
    onMounted(async () => {
      if (settingStore.get("Comfy.ModelLibrary.AutoLoadAll")) {
        await modelStore.loadModels();
      }
    });
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(SidebarTabTemplate, {
          title: _ctx.$t("sideToolbar.modelLibrary"),
          class: "bg-[var(--p-tree-background)]"
        }, {
          "tool-buttons": withCtx(() => [
            withDirectives(createVNode(unref(script$10), {
              icon: "pi pi-refresh",
              onClick: unref(modelStore).loadModelFolders,
              severity: "secondary",
              text: ""
            }, null, 8, ["onClick"]), [
              [
                _directive_tooltip,
                _ctx.$t("g.refresh"),
                void 0,
                { bottom: true }
              ]
            ]),
            withDirectives(createVNode(unref(script$10), {
              icon: "pi pi-cloud-download",
              onClick: unref(modelStore).loadModels,
              severity: "secondary",
              text: ""
            }, null, 8, ["onClick"]), [
              [
                _directive_tooltip,
                _ctx.$t("g.loadAllFolders"),
                void 0,
                { bottom: true }
              ]
            ])
          ]),
          header: withCtx(() => [
            createVNode(SearchBox, {
              class: "model-lib-search-box p-2 2xl:p-4",
              modelValue: searchQuery.value,
              "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => searchQuery.value = $event),
              placeholder: _ctx.$t("g.searchModels") + "...",
              onSearch: handleSearch
            }, null, 8, ["modelValue", "placeholder"])
          ]),
          body: withCtx(() => [
            unref(isElectron)() ? (openBlock(), createBlock(_sfc_main$k, { key: 0 })) : createCommentVNode("", true),
            createVNode(TreeExplorer, {
              class: "model-lib-tree-explorer",
              root: renderedRoot.value,
              expandedKeys: expandedKeys2.value,
              "onUpdate:expandedKeys": _cache[1] || (_cache[1] = ($event) => expandedKeys2.value = $event)
            }, {
              node: withCtx(({ node: node3 }) => [
                createVNode(ModelTreeLeaf, { node: node3 }, null, 8, ["node"])
              ]),
              _: 1
            }, 8, ["root", "expandedKeys"])
          ]),
          _: 1
        }, 8, ["title"]),
        _cache[2] || (_cache[2] = createBaseVNode("div", { id: "model-library-model-preview-container" }, null, -1))
      ], 64);
    };
  }
});
const ModelLibrarySidebarTab = /* @__PURE__ */ _export_sfc(_sfc_main$h, [["__scopeId", "data-v-2cbfe88c"]]);
const useModelLibrarySidebarTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  return {
    id: "model-library",
    icon: "pi pi-box",
    title: t2("sideToolbar.modelLibrary"),
    tooltip: t2("sideToolbar.modelLibrary"),
    component: markRaw(ModelLibrarySidebarTab),
    type: "vue",
    iconBadge: /* @__PURE__ */ __name(() => {
      if (isElectron()) {
        const electronDownloadStore = useElectronDownloadStore();
        if (electronDownloadStore.inProgressDownloads.length > 0) {
          return electronDownloadStore.inProgressDownloads.length.toString();
        }
      }
      return null;
    }, "iconBadge")
  };
}, "useModelLibrarySidebarTab");
var theme$4 = /* @__PURE__ */ __name(function theme42(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-togglebutton {\n    display: inline-flex;\n    cursor: pointer;\n    user-select: none;\n    align-items: center;\n    justify-content: center;\n    overflow: hidden;\n    position: relative;\n    color: ".concat(dt2("togglebutton.color"), ";\n    background: ").concat(dt2("togglebutton.background"), ";\n    border: 1px solid ").concat(dt2("togglebutton.border.color"), ";\n    padding: ").concat(dt2("togglebutton.padding"), ";\n    font-size: 1rem;\n    font-family: inherit;\n    font-feature-settings: inherit;\n    transition: background ").concat(dt2("togglebutton.transition.duration"), ", color ").concat(dt2("togglebutton.transition.duration"), ", border-color ").concat(dt2("togglebutton.transition.duration"), ",\n        outline-color ").concat(dt2("togglebutton.transition.duration"), ", box-shadow ").concat(dt2("togglebutton.transition.duration"), ";\n    border-radius: ").concat(dt2("togglebutton.border.radius"), ";\n    outline-color: transparent;\n    font-weight: ").concat(dt2("togglebutton.font.weight"), ";\n}\n\n.p-togglebutton-content {\n    position: relative;\n    display: inline-flex;\n    align-items: center;\n    justify-content: center;\n    gap: ").concat(dt2("togglebutton.gap"), ';\n}\n\n.p-togglebutton-label,\n.p-togglebutton-icon {\n    position: relative;\n    transition: none;\n}\n\n.p-togglebutton::before {\n    content: "";\n    background: transparent;\n    transition: background ').concat(dt2("togglebutton.transition.duration"), ", color ").concat(dt2("togglebutton.transition.duration"), ", border-color ").concat(dt2("togglebutton.transition.duration"), ",\n            outline-color ").concat(dt2("togglebutton.transition.duration"), ", box-shadow ").concat(dt2("togglebutton.transition.duration"), ";\n    position: absolute;\n    inset-inline-start: ").concat(dt2("togglebutton.content.left"), ";\n    inset-block-start: ").concat(dt2("togglebutton.content.top"), ";\n    width: calc(100% - calc(2 * ").concat(dt2("togglebutton.content.left"), "));\n    height: calc(100% - calc(2 * ").concat(dt2("togglebutton.content.top"), "));\n    border-radius: ").concat(dt2("togglebutton.border.radius"), ";\n}\n\n.p-togglebutton.p-togglebutton-checked::before {\n    background: ").concat(dt2("togglebutton.content.checked.background"), ";\n    box-shadow: ").concat(dt2("togglebutton.content.checked.shadow"), ";\n}\n\n.p-togglebutton:not(:disabled):not(.p-togglebutton-checked):hover {\n    background: ").concat(dt2("togglebutton.hover.background"), ";\n    color: ").concat(dt2("togglebutton.hover.color"), ";\n}\n\n.p-togglebutton.p-togglebutton-checked {\n    background: ").concat(dt2("togglebutton.checked.background"), ";\n    border-color: ").concat(dt2("togglebutton.checked.border.color"), ";\n    color: ").concat(dt2("togglebutton.checked.color"), ";\n}\n\n.p-togglebutton:focus-visible {\n    box-shadow: ").concat(dt2("togglebutton.focus.ring.shadow"), ";\n    outline: ").concat(dt2("togglebutton.focus.ring.width"), " ").concat(dt2("togglebutton.focus.ring.style"), " ").concat(dt2("togglebutton.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("togglebutton.focus.ring.offset"), ";\n}\n\n.p-togglebutton.p-invalid {\n    border-color: ").concat(dt2("togglebutton.invalid.border.color"), ";\n}\n\n.p-togglebutton:disabled {\n    opacity: 1;\n    cursor: default;\n    background: ").concat(dt2("togglebutton.disabled.background"), ";\n    border-color: ").concat(dt2("togglebutton.disabled.border.color"), ";\n    color: ").concat(dt2("togglebutton.disabled.color"), ";\n}\n\n.p-togglebutton-icon {\n    color: ").concat(dt2("togglebutton.icon.color"), ";\n}\n\n.p-togglebutton:not(:disabled):not(.p-togglebutton-checked):hover .p-togglebutton-icon {\n    color: ").concat(dt2("togglebutton.icon.hover.color"), ";\n}\n\n.p-togglebutton.p-togglebutton-checked .p-togglebutton-icon {\n    color: ").concat(dt2("togglebutton.icon.checked.color"), ";\n}\n\n.p-togglebutton:disabled .p-togglebutton-icon {\n    color: ").concat(dt2("togglebutton.icon.disabled.color"), ";\n}\n\n.p-togglebutton-sm {\n    padding: ").concat(dt2("togglebutton.sm.padding"), ";\n    font-size: ").concat(dt2("togglebutton.sm.font.size"), ";\n}\n\n.p-togglebutton-lg {\n    padding: ").concat(dt2("togglebutton.lg.padding"), ";\n    font-size: ").concat(dt2("togglebutton.lg.font.size"), ";\n}\n");
}, "theme");
var classes$4 = {
  root: /* @__PURE__ */ __name(function root31(_ref2) {
    var instance = _ref2.instance, props = _ref2.props;
    return ["p-togglebutton p-component", {
      "p-togglebutton-checked": instance.active,
      "p-invalid": instance.$invalid,
      "p-togglebutton-sm p-inputfield-sm": props.size === "small",
      "p-togglebutton-lg p-inputfield-lg": props.size === "large"
    }];
  }, "root"),
  content: "p-togglebutton-content",
  icon: "p-togglebutton-icon",
  label: "p-togglebutton-label"
};
var ToggleButtonStyle = BaseStyle$1.extend({
  name: "togglebutton",
  theme: theme$4,
  classes: classes$4
});
var script$1$4 = {
  name: "BaseToggleButton",
  "extends": script$18,
  props: {
    onIcon: String,
    offIcon: String,
    onLabel: {
      type: String,
      "default": "Yes"
    },
    offLabel: {
      type: String,
      "default": "No"
    },
    iconPos: {
      type: String,
      "default": "left"
    },
    readonly: {
      type: Boolean,
      "default": false
    },
    tabindex: {
      type: Number,
      "default": null
    },
    ariaLabelledby: {
      type: String,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    size: {
      type: String,
      "default": null
    }
  },
  style: ToggleButtonStyle,
  provide: /* @__PURE__ */ __name(function provide47() {
    return {
      $pcToggleButton: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$9 = {
  name: "ToggleButton",
  "extends": script$1$4,
  inheritAttrs: false,
  emits: ["change"],
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions9(key) {
      var _ptm = key === "root" ? this.ptmi : this.ptm;
      return _ptm(key, {
        context: {
          active: this.active,
          disabled: this.disabled
        }
      });
    }, "getPTOptions"),
    onChange: /* @__PURE__ */ __name(function onChange5(event) {
      if (!this.disabled && !this.readonly) {
        this.writeValue(!this.d_value, event);
        this.$emit("change", event);
      }
    }, "onChange"),
    onBlur: /* @__PURE__ */ __name(function onBlur11(event) {
      var _this$formField$onBlu, _this$formField;
      (_this$formField$onBlu = (_this$formField = this.formField).onBlur) === null || _this$formField$onBlu === void 0 || _this$formField$onBlu.call(_this$formField, event);
    }, "onBlur")
  },
  computed: {
    active: /* @__PURE__ */ __name(function active3() {
      return this.d_value === true;
    }, "active"),
    hasLabel: /* @__PURE__ */ __name(function hasLabel() {
      return isNotEmpty$2(this.onLabel) && isNotEmpty$2(this.offLabel);
    }, "hasLabel"),
    label: /* @__PURE__ */ __name(function label7() {
      return this.hasLabel ? this.d_value ? this.onLabel : this.offLabel : " ";
    }, "label")
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$d = ["tabindex", "disabled", "aria-pressed", "aria-labelledby", "data-p-checked", "data-p-disabled"];
function render$8(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    type: "button",
    "class": _ctx.cx("root"),
    tabindex: _ctx.tabindex,
    disabled: _ctx.disabled,
    "aria-pressed": _ctx.d_value,
    onClick: _cache[0] || (_cache[0] = function() {
      return $options.onChange && $options.onChange.apply($options, arguments);
    }),
    onBlur: _cache[1] || (_cache[1] = function() {
      return $options.onBlur && $options.onBlur.apply($options, arguments);
    })
  }, $options.getPTOptions("root"), {
    "aria-labelledby": _ctx.ariaLabelledby,
    "data-p-checked": $options.active,
    "data-p-disabled": _ctx.disabled
  }), [createBaseVNode("span", mergeProps$2({
    "class": _ctx.cx("content")
  }, $options.getPTOptions("content")), [renderSlot(_ctx.$slots, "default", {}, function() {
    return [renderSlot(_ctx.$slots, "icon", {
      value: _ctx.d_value,
      "class": normalizeClass(_ctx.cx("icon"))
    }, function() {
      return [_ctx.onIcon || _ctx.offIcon ? (openBlock(), createElementBlock("span", mergeProps$2({
        key: 0,
        "class": [_ctx.cx("icon"), _ctx.d_value ? _ctx.onIcon : _ctx.offIcon]
      }, $options.getPTOptions("icon")), null, 16)) : createCommentVNode("", true)];
    }), createBaseVNode("span", mergeProps$2({
      "class": _ctx.cx("label")
    }, $options.getPTOptions("label")), toDisplayString$1($options.label), 17)];
  })], 16)], 16, _hoisted_1$d)), [[_directive_ripple]]);
}
__name(render$8, "render$8");
script$9.render = render$8;
var theme$3 = /* @__PURE__ */ __name(function theme43(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-selectbutton {\n    display: inline-flex;\n    user-select: none;\n    vertical-align: bottom;\n    outline-color: transparent;\n    border-radius: ".concat(dt2("selectbutton.border.radius"), ";\n}\n\n.p-selectbutton .p-togglebutton {\n    border-radius: 0;\n    border-width: 1px 1px 1px 0;\n}\n\n.p-selectbutton .p-togglebutton:focus-visible {\n    position: relative;\n    z-index: 1;\n}\n\n.p-selectbutton .p-togglebutton:first-child {\n    border-inline-start-width: 1px;\n    border-start-start-radius: ").concat(dt2("selectbutton.border.radius"), ";\n    border-end-start-radius: ").concat(dt2("selectbutton.border.radius"), ";\n}\n\n.p-selectbutton .p-togglebutton:last-child {\n    border-start-end-radius: ").concat(dt2("selectbutton.border.radius"), ";\n    border-end-end-radius: ").concat(dt2("selectbutton.border.radius"), ";\n}\n\n.p-selectbutton.p-invalid {\n    outline: 1px solid ").concat(dt2("selectbutton.invalid.border.color"), ";\n    outline-offset: 0;\n}\n");
}, "theme");
var classes$3 = {
  root: /* @__PURE__ */ __name(function root32(_ref2) {
    var instance = _ref2.instance;
    return ["p-selectbutton p-component", {
      "p-invalid": instance.$invalid
      // @todo: check
    }];
  }, "root")
};
var SelectButtonStyle = BaseStyle$1.extend({
  name: "selectbutton",
  theme: theme$3,
  classes: classes$3
});
var script$1$3 = {
  name: "BaseSelectButton",
  "extends": script$18,
  props: {
    options: Array,
    optionLabel: null,
    optionValue: null,
    optionDisabled: null,
    multiple: Boolean,
    allowEmpty: {
      type: Boolean,
      "default": true
    },
    dataKey: null,
    ariaLabelledby: {
      type: String,
      "default": null
    },
    size: {
      type: String,
      "default": null
    }
  },
  style: SelectButtonStyle,
  provide: /* @__PURE__ */ __name(function provide48() {
    return {
      $pcSelectButton: this,
      $parentInstance: this
    };
  }, "provide")
};
function _createForOfIteratorHelper(r2, e2) {
  var t2 = "undefined" != typeof Symbol && r2[Symbol.iterator] || r2["@@iterator"];
  if (!t2) {
    if (Array.isArray(r2) || (t2 = _unsupportedIterableToArray$2(r2)) || e2) {
      t2 && (r2 = t2);
      var _n = 0, F2 = /* @__PURE__ */ __name(function F3() {
      }, "F");
      return { s: F2, n: /* @__PURE__ */ __name(function n2() {
        return _n >= r2.length ? { done: true } : { done: false, value: r2[_n++] };
      }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
        throw r3;
      }, "e"), f: F2 };
    }
    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }
  var o2, a2 = true, u2 = false;
  return { s: /* @__PURE__ */ __name(function s2() {
    t2 = t2.call(r2);
  }, "s"), n: /* @__PURE__ */ __name(function n2() {
    var r3 = t2.next();
    return a2 = r3.done, r3;
  }, "n"), e: /* @__PURE__ */ __name(function e3(r3) {
    u2 = true, o2 = r3;
  }, "e"), f: /* @__PURE__ */ __name(function f2() {
    try {
      a2 || null == t2["return"] || t2["return"]();
    } finally {
      if (u2) throw o2;
    }
  }, "f") };
}
__name(_createForOfIteratorHelper, "_createForOfIteratorHelper");
function _toConsumableArray$2(r2) {
  return _arrayWithoutHoles$2(r2) || _iterableToArray$2(r2) || _unsupportedIterableToArray$2(r2) || _nonIterableSpread$2();
}
__name(_toConsumableArray$2, "_toConsumableArray$2");
function _nonIterableSpread$2() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$2, "_nonIterableSpread$2");
function _unsupportedIterableToArray$2(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$2(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$2(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$2, "_unsupportedIterableToArray$2");
function _iterableToArray$2(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$2, "_iterableToArray$2");
function _arrayWithoutHoles$2(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$2(r2);
}
__name(_arrayWithoutHoles$2, "_arrayWithoutHoles$2");
function _arrayLikeToArray$2(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$2, "_arrayLikeToArray$2");
var script$8 = {
  name: "SelectButton",
  "extends": script$1$3,
  inheritAttrs: false,
  emits: ["change"],
  methods: {
    getOptionLabel: /* @__PURE__ */ __name(function getOptionLabel5(option5) {
      return this.optionLabel ? resolveFieldData$2(option5, this.optionLabel) : option5;
    }, "getOptionLabel"),
    getOptionValue: /* @__PURE__ */ __name(function getOptionValue5(option5) {
      return this.optionValue ? resolveFieldData$2(option5, this.optionValue) : option5;
    }, "getOptionValue"),
    getOptionRenderKey: /* @__PURE__ */ __name(function getOptionRenderKey5(option5) {
      return this.dataKey ? resolveFieldData$2(option5, this.dataKey) : this.getOptionLabel(option5);
    }, "getOptionRenderKey"),
    isOptionDisabled: /* @__PURE__ */ __name(function isOptionDisabled5(option5) {
      return this.optionDisabled ? resolveFieldData$2(option5, this.optionDisabled) : false;
    }, "isOptionDisabled"),
    onOptionSelect: /* @__PURE__ */ __name(function onOptionSelect5(event, option5, index2) {
      var _this = this;
      if (this.disabled || this.isOptionDisabled(option5)) {
        return;
      }
      var selected2 = this.isSelected(option5);
      if (selected2 && !this.allowEmpty) {
        return;
      }
      var optionValue = this.getOptionValue(option5);
      var newValue2;
      if (this.multiple) {
        if (selected2) newValue2 = this.d_value.filter(function(val) {
          return !equals$2(val, optionValue, _this.equalityKey);
        });
        else newValue2 = this.d_value ? [].concat(_toConsumableArray$2(this.d_value), [optionValue]) : [optionValue];
      } else {
        newValue2 = selected2 ? null : optionValue;
      }
      this.writeValue(newValue2, event);
      this.$emit("change", {
        event,
        value: newValue2
      });
    }, "onOptionSelect"),
    isSelected: /* @__PURE__ */ __name(function isSelected6(option5) {
      var selected2 = false;
      var optionValue = this.getOptionValue(option5);
      if (this.multiple) {
        if (this.d_value) {
          var _iterator = _createForOfIteratorHelper(this.d_value), _step;
          try {
            for (_iterator.s(); !(_step = _iterator.n()).done; ) {
              var val = _step.value;
              if (equals$2(val, optionValue, this.equalityKey)) {
                selected2 = true;
                break;
              }
            }
          } catch (err) {
            _iterator.e(err);
          } finally {
            _iterator.f();
          }
        }
      } else {
        selected2 = equals$2(this.d_value, optionValue, this.equalityKey);
      }
      return selected2;
    }, "isSelected")
  },
  computed: {
    equalityKey: /* @__PURE__ */ __name(function equalityKey5() {
      return this.optionValue ? null : this.dataKey;
    }, "equalityKey")
  },
  directives: {
    ripple: Ripple
  },
  components: {
    ToggleButton: script$9
  }
};
var _hoisted_1$c = ["aria-labelledby"];
function render$7(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_ToggleButton = resolveComponent("ToggleButton");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("root"),
    role: "group",
    "aria-labelledby": _ctx.ariaLabelledby
  }, _ctx.ptmi("root")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList(_ctx.options, function(option5, index2) {
    return openBlock(), createBlock(_component_ToggleButton, {
      key: $options.getOptionRenderKey(option5),
      modelValue: $options.isSelected(option5),
      onLabel: $options.getOptionLabel(option5),
      offLabel: $options.getOptionLabel(option5),
      disabled: _ctx.disabled || $options.isOptionDisabled(option5),
      unstyled: _ctx.unstyled,
      size: _ctx.size,
      readonly: !_ctx.allowEmpty && $options.isSelected(option5),
      onChange: /* @__PURE__ */ __name(function onChange6($event) {
        return $options.onOptionSelect($event, option5, index2);
      }, "onChange"),
      pt: _ctx.ptm("pcToggleButton")
    }, createSlots({
      _: 2
    }, [_ctx.$slots.option ? {
      name: "default",
      fn: withCtx(function() {
        return [renderSlot(_ctx.$slots, "option", {
          option: option5,
          index: index2
        }, function() {
          return [createBaseVNode("span", mergeProps$2({
            ref_for: true
          }, _ctx.ptm("pcToggleButton")["label"]), toDisplayString$1($options.getOptionLabel(option5)), 17)];
        })];
      }),
      key: "0"
    } : void 0]), 1032, ["modelValue", "onLabel", "offLabel", "disabled", "unstyled", "size", "readonly", "onChange", "pt"]);
  }), 128))], 16, _hoisted_1$c);
}
__name(render$7, "render$7");
script$8.render = render$7;
const _hoisted_1$b = { class: "_content" };
const _hoisted_2$a = { class: "_footer" };
const _sfc_main$g = /* @__PURE__ */ defineComponent({
  __name: "NodeSearchFilter",
  emits: ["addFilter"],
  setup(__props, { emit: __emit }) {
    const filters = computed(() => nodeDefStore.nodeSearchService.nodeFilters);
    const selectedFilter = ref();
    const filterValues = computed(() => selectedFilter.value?.fuseSearch.data ?? []);
    const selectedFilterValue = ref("");
    const nodeDefStore = useNodeDefStore();
    onMounted(() => {
      selectedFilter.value = nodeDefStore.nodeSearchService.nodeFilters[0];
      updateSelectedFilterValue();
    });
    const emit2 = __emit;
    const updateSelectedFilterValue = /* @__PURE__ */ __name(() => {
      if (filterValues.value.includes(selectedFilterValue.value)) {
        return;
      }
      selectedFilterValue.value = filterValues.value[0];
    }, "updateSelectedFilterValue");
    const submit = /* @__PURE__ */ __name(() => {
      emit2("addFilter", [
        selectedFilter.value,
        selectedFilterValue.value
      ]);
    }, "submit");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        createBaseVNode("div", _hoisted_1$b, [
          createVNode(unref(script$8), {
            class: "filter-type-select",
            modelValue: selectedFilter.value,
            "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedFilter.value = $event),
            options: filters.value,
            allowEmpty: false,
            optionLabel: "name",
            onChange: updateSelectedFilterValue
          }, null, 8, ["modelValue", "options"]),
          createVNode(unref(script$t), {
            class: "filter-value-select",
            modelValue: selectedFilterValue.value,
            "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => selectedFilterValue.value = $event),
            options: filterValues.value,
            filter: "",
            autoFilterFocus: ""
          }, null, 8, ["modelValue", "options"])
        ]),
        createBaseVNode("div", _hoisted_2$a, [
          createVNode(unref(script$10), {
            type: "button",
            label: _ctx.$t("g.add"),
            onClick: submit
          }, null, 8, ["label"])
        ])
      ], 64);
    };
  }
});
const NodeSearchFilter = /* @__PURE__ */ _export_sfc(_sfc_main$g, [["__scopeId", "data-v-c4279e6b"]]);
const BOOKMARK_SETTING_ID = "Comfy.NodeLibrary.Bookmarks.V2";
const useNodeBookmarkStore = /* @__PURE__ */ defineStore("nodeBookmark", () => {
  const settingStore = useSettingStore();
  const nodeDefStore = useNodeDefStore();
  const bookmarks = computed(
    () => settingStore.get(BOOKMARK_SETTING_ID)
  );
  const bookmarksSet = computed(() => new Set(bookmarks.value));
  const bookmarkedRoot = computed(
    () => buildBookmarkTree(bookmarks.value)
  );
  const isBookmarked = /* @__PURE__ */ __name((node3) => bookmarksSet.value.has(node3.nodePath) || bookmarksSet.value.has(node3.name), "isBookmarked");
  const toggleBookmark = /* @__PURE__ */ __name((node3) => {
    if (isBookmarked(node3)) {
      deleteBookmark(node3.nodePath);
      deleteBookmark(node3.name);
    } else {
      addBookmark(node3.name);
    }
  }, "toggleBookmark");
  const buildBookmarkTree = /* @__PURE__ */ __name((bookmarks2) => {
    const bookmarkNodes = bookmarks2.map((bookmark) => {
      if (bookmark.endsWith("/")) return createDummyFolderNodeDef(bookmark);
      const parts2 = bookmark.split("/");
      const name2 = parts2.pop() ?? "";
      const category = parts2.join("/");
      const srcNodeDef = nodeDefStore.nodeDefsByName[name2];
      if (!srcNodeDef) {
        return null;
      }
      const nodeDef = _.clone(srcNodeDef);
      nodeDef.category = category;
      return nodeDef;
    }).filter((nodeDef) => nodeDef !== null);
    return buildNodeDefTree(bookmarkNodes);
  }, "buildBookmarkTree");
  const addBookmark = /* @__PURE__ */ __name((nodePath) => {
    settingStore.set(BOOKMARK_SETTING_ID, [...bookmarks.value, nodePath]);
  }, "addBookmark");
  const deleteBookmark = /* @__PURE__ */ __name((nodePath) => {
    settingStore.set(
      BOOKMARK_SETTING_ID,
      bookmarks.value.filter((b2) => b2 !== nodePath)
    );
  }, "deleteBookmark");
  const addNewBookmarkFolder = /* @__PURE__ */ __name((parent, folderName) => {
    const parentPath = parent ? parent.nodePath : "";
    const newFolderPath = parentPath + folderName + "/";
    addBookmark(newFolderPath);
    return newFolderPath;
  }, "addNewBookmarkFolder");
  const renameBookmarkFolder = /* @__PURE__ */ __name((folderNode, newName) => {
    if (!folderNode.isDummyFolder) {
      throw new Error("Cannot rename non-folder node");
    }
    if (newName.includes("/")) {
      throw new Error('Folder name cannot contain "/"');
    }
    const newNodePath = folderNode.category.split("/").slice(0, -1).concat(newName).join("/") + "/";
    if (newNodePath === folderNode.nodePath) {
      return;
    }
    if (bookmarks.value.some((b2) => b2.startsWith(newNodePath))) {
      throw new Error(`Folder name "${newNodePath}" already exists`);
    }
    settingStore.set(
      BOOKMARK_SETTING_ID,
      bookmarks.value.map(
        (b2) => b2.startsWith(folderNode.nodePath) ? b2.replace(folderNode.nodePath, newNodePath) : b2
      )
    );
    renameBookmarkCustomization(folderNode.nodePath, newNodePath);
  }, "renameBookmarkFolder");
  const deleteBookmarkFolder = /* @__PURE__ */ __name((folderNode) => {
    if (!folderNode.isDummyFolder) {
      throw new Error("Cannot delete non-folder node");
    }
    settingStore.set(
      BOOKMARK_SETTING_ID,
      bookmarks.value.filter(
        (b2) => b2 !== folderNode.nodePath && !b2.startsWith(folderNode.nodePath)
      )
    );
    deleteBookmarkCustomization(folderNode.nodePath);
  }, "deleteBookmarkFolder");
  const bookmarksCustomization = computed(() => settingStore.get("Comfy.NodeLibrary.BookmarksCustomization"));
  const updateBookmarkCustomization = /* @__PURE__ */ __name((nodePath, customization) => {
    const currentCustomization = bookmarksCustomization.value[nodePath] || {};
    const newCustomization = { ...currentCustomization, ...customization };
    if (newCustomization.icon === defaultBookmarkIcon) {
      delete newCustomization.icon;
    }
    if (newCustomization.color === defaultBookmarkColor) {
      delete newCustomization.color;
    }
    if (Object.keys(newCustomization).length === 0) {
      deleteBookmarkCustomization(nodePath);
    } else {
      settingStore.set("Comfy.NodeLibrary.BookmarksCustomization", {
        ...bookmarksCustomization.value,
        [nodePath]: newCustomization
      });
    }
  }, "updateBookmarkCustomization");
  const deleteBookmarkCustomization = /* @__PURE__ */ __name((nodePath) => {
    settingStore.set("Comfy.NodeLibrary.BookmarksCustomization", {
      ...bookmarksCustomization.value,
      [nodePath]: void 0
    });
  }, "deleteBookmarkCustomization");
  const renameBookmarkCustomization = /* @__PURE__ */ __name((oldNodePath, newNodePath) => {
    const updatedCustomization = { ...bookmarksCustomization.value };
    if (updatedCustomization[oldNodePath]) {
      updatedCustomization[newNodePath] = updatedCustomization[oldNodePath];
      delete updatedCustomization[oldNodePath];
    }
    settingStore.set(
      "Comfy.NodeLibrary.BookmarksCustomization",
      updatedCustomization
    );
  }, "renameBookmarkCustomization");
  const defaultBookmarkIcon = "pi-bookmark-fill";
  const defaultBookmarkColor = "#a1a1aa";
  return {
    bookmarks,
    bookmarkedRoot,
    isBookmarked,
    toggleBookmark,
    addBookmark,
    addNewBookmarkFolder,
    renameBookmarkFolder,
    deleteBookmarkFolder,
    bookmarksCustomization,
    updateBookmarkCustomization,
    deleteBookmarkCustomization,
    renameBookmarkCustomization,
    defaultBookmarkIcon,
    defaultBookmarkColor
  };
});
const _sfc_main$f = /* @__PURE__ */ defineComponent({
  __name: "NodeTreeLeaf",
  props: {
    node: {}
  },
  setup(__props) {
    const props = __props;
    const nodeDef = computed(() => props.node.data);
    const nodeBookmarkStore = useNodeBookmarkStore();
    const isBookmarked = computed(
      () => nodeBookmarkStore.isBookmarked(nodeDef.value)
    );
    const settingStore = useSettingStore();
    const sidebarLocation = computed(
      () => settingStore.get("Comfy.Sidebar.Location")
    );
    const toggleBookmark = /* @__PURE__ */ __name(() => {
      nodeBookmarkStore.toggleBookmark(nodeDef.value);
    }, "toggleBookmark");
    const previewRef = ref(null);
    const nodePreviewStyle = ref({
      position: "absolute",
      top: "0px",
      left: "0px"
    });
    const handleNodeHover = /* @__PURE__ */ __name(async () => {
      const hoverTarget = nodeContentElement.value;
      if (!hoverTarget) return;
      const targetRect = hoverTarget.getBoundingClientRect();
      const previewHeight = previewRef.value?.$el.offsetHeight || 0;
      const availableSpaceBelow = window.innerHeight - targetRect.bottom;
      nodePreviewStyle.value.top = previewHeight > availableSpaceBelow ? `${Math.max(0, targetRect.top - (previewHeight - availableSpaceBelow) - 20)}px` : `${targetRect.top - 40}px`;
      if (sidebarLocation.value === "left") {
        nodePreviewStyle.value.left = `${targetRect.right}px`;
      } else {
        nodePreviewStyle.value.left = `${targetRect.left - 400}px`;
      }
    }, "handleNodeHover");
    const container = ref(null);
    const nodeContentElement = ref(null);
    const isHovered = ref(false);
    const handleMouseEnter = /* @__PURE__ */ __name(async () => {
      isHovered.value = true;
      await nextTick();
      handleNodeHover();
    }, "handleMouseEnter");
    const handleMouseLeave2 = /* @__PURE__ */ __name(() => {
      isHovered.value = false;
    }, "handleMouseLeave");
    onMounted(() => {
      nodeContentElement.value = container.value?.closest(".p-tree-node-content") ?? null;
      nodeContentElement.value?.addEventListener("mouseenter", handleMouseEnter);
      nodeContentElement.value?.addEventListener("mouseleave", handleMouseLeave2);
    });
    onUnmounted(() => {
      nodeContentElement.value?.removeEventListener("mouseenter", handleMouseEnter);
      nodeContentElement.value?.removeEventListener("mouseleave", handleMouseLeave2);
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "container",
        ref: container,
        class: "node-lib-node-container"
      }, [
        createVNode(TreeExplorerTreeNode, { node: _ctx.node }, {
          "before-label": withCtx(() => [
            nodeDef.value.experimental ? (openBlock(), createBlock(unref(script$z), {
              key: 0,
              value: _ctx.$t("g.experimental"),
              severity: "primary"
            }, null, 8, ["value"])) : createCommentVNode("", true),
            nodeDef.value.deprecated ? (openBlock(), createBlock(unref(script$z), {
              key: 1,
              value: _ctx.$t("g.deprecated"),
              severity: "danger"
            }, null, 8, ["value"])) : createCommentVNode("", true)
          ]),
          actions: withCtx(() => [
            createVNode(unref(script$10), {
              class: "bookmark-button",
              size: "small",
              icon: isBookmarked.value ? "pi pi-bookmark-fill" : "pi pi-bookmark",
              text: "",
              severity: "secondary",
              onClick: withModifiers(toggleBookmark, ["stop"])
            }, null, 8, ["icon"])
          ]),
          _: 1
        }, 8, ["node"]),
        isHovered.value ? (openBlock(), createBlock(Teleport, {
          key: 0,
          to: "#node-library-node-preview-container"
        }, [
          createBaseVNode("div", {
            class: "node-lib-node-preview",
            style: normalizeStyle(nodePreviewStyle.value)
          }, [
            createVNode(NodePreview, {
              ref_key: "previewRef",
              ref: previewRef,
              nodeDef: nodeDef.value
            }, null, 8, ["nodeDef"])
          ], 4)
        ])) : createCommentVNode("", true)
      ], 512);
    };
  }
});
const NodeTreeLeaf = /* @__PURE__ */ _export_sfc(_sfc_main$f, [["__scopeId", "data-v-d13a7a04"]]);
const _hoisted_1$a = { class: "color-customization-selector-container flex flex-row items-center gap-2" };
const _hoisted_2$9 = {
  key: 1,
  class: "pi pi-palette text-lg"
};
const _sfc_main$e = /* @__PURE__ */ defineComponent({
  __name: "ColorCustomizationSelector",
  props: {
    modelValue: {},
    colorOptions: {},
    allowCustom: { type: Boolean, default: true }
  },
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const customColorOption = { name: "_custom", value: "" };
    const colorOptionsWithCustom = computed(() => [
      ...__props.colorOptions,
      ...__props.allowCustom ? [customColorOption] : []
    ]);
    const emit2 = __emit;
    const selectedColorOption = ref(customColorOption);
    const customColorValue = ref("");
    onMounted(() => {
      if (__props.modelValue) {
        const predefinedColor = __props.colorOptions.find((opt) => opt.value === __props.modelValue);
        if (predefinedColor) {
          selectedColorOption.value = predefinedColor;
        } else {
          selectedColorOption.value = customColorOption;
          customColorValue.value = __props.modelValue.replace("#", "");
        }
      }
    });
    watch(selectedColorOption, (newOption, oldOption) => {
      if (newOption.name === "_custom") {
        customColorValue.value = oldOption.value.replace("#", "");
      } else {
        emit2("update:modelValue", newOption.value);
      }
    });
    watch(customColorValue, (newValue2) => {
      if (selectedColorOption.value.name === "_custom") {
        emit2("update:modelValue", newValue2 ? `#${newValue2}` : null);
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$a, [
        createVNode(unref(script$8), {
          modelValue: selectedColorOption.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedColorOption.value = $event),
          options: colorOptionsWithCustom.value,
          optionLabel: "name",
          dataKey: "value",
          "allow-empty": false
        }, {
          option: withCtx((slotProps) => [
            slotProps.option.name !== "_custom" ? (openBlock(), createElementBlock("div", {
              key: 0,
              style: normalizeStyle({
                width: "20px",
                height: "20px",
                backgroundColor: slotProps.option.value,
                borderRadius: "50%"
              })
            }, null, 4)) : (openBlock(), createElementBlock("i", _hoisted_2$9))
          ]),
          _: 1
        }, 8, ["modelValue", "options"]),
        selectedColorOption.value.name === "_custom" ? (openBlock(), createBlock(unref(script$o), {
          key: 0,
          modelValue: customColorValue.value,
          "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => customColorValue.value = $event)
        }, null, 8, ["modelValue"])) : createCommentVNode("", true)
      ]);
    };
  }
});
const _hoisted_1$9 = { class: "p-fluid" };
const _hoisted_2$8 = { class: "field icon-field" };
const _hoisted_3$5 = { for: "icon" };
const _hoisted_4$3 = { class: "field color-field" };
const _hoisted_5$3 = { for: "color" };
const _sfc_main$d = /* @__PURE__ */ defineComponent({
  __name: "CustomizationDialog",
  props: {
    modelValue: { type: Boolean },
    initialIcon: {},
    initialColor: {}
  },
  emits: ["update:modelValue", "confirm"],
  setup(__props, { emit: __emit }) {
    const { t: t2 } = useI18n();
    const props = __props;
    const emit2 = __emit;
    const visible2 = computed({
      get: /* @__PURE__ */ __name(() => props.modelValue, "get"),
      set: /* @__PURE__ */ __name((value3) => emit2("update:modelValue", value3), "set")
    });
    const nodeBookmarkStore = useNodeBookmarkStore();
    const iconOptions = [
      { name: t2("icon.bookmark"), value: nodeBookmarkStore.defaultBookmarkIcon },
      { name: t2("icon.folder"), value: "pi-folder" },
      { name: t2("icon.star"), value: "pi-star" },
      { name: t2("icon.heart"), value: "pi-heart" },
      { name: t2("icon.file"), value: "pi-file" },
      { name: t2("icon.inbox"), value: "pi-inbox" },
      { name: t2("icon.box"), value: "pi-box" },
      { name: t2("icon.briefcase"), value: "pi-briefcase" }
    ];
    const colorOptions = [
      { name: t2("color.default"), value: nodeBookmarkStore.defaultBookmarkColor },
      { name: t2("color.blue"), value: "#007bff" },
      { name: t2("color.green"), value: "#28a745" },
      { name: t2("color.red"), value: "#dc3545" },
      { name: t2("color.pink"), value: "#e83e8c" },
      { name: t2("color.yellow"), value: "#ffc107" }
    ];
    const defaultIcon = iconOptions.find(
      (option5) => option5.value === nodeBookmarkStore.defaultBookmarkIcon
    );
    const selectedIcon = ref(defaultIcon);
    const finalColor = ref(
      props.initialColor || nodeBookmarkStore.defaultBookmarkColor
    );
    const resetCustomization = /* @__PURE__ */ __name(() => {
      selectedIcon.value = iconOptions.find((option5) => option5.value === props.initialIcon) || defaultIcon;
      finalColor.value = props.initialColor || nodeBookmarkStore.defaultBookmarkColor;
    }, "resetCustomization");
    const confirmCustomization = /* @__PURE__ */ __name(() => {
      emit2("confirm", selectedIcon.value.value, finalColor.value);
      closeDialog();
    }, "confirmCustomization");
    const closeDialog = /* @__PURE__ */ __name(() => {
      visible2.value = false;
    }, "closeDialog");
    watch(
      () => props.modelValue,
      (newValue2) => {
        if (newValue2) {
          resetCustomization();
        }
      },
      { immediate: true }
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$_), {
        visible: visible2.value,
        "onUpdate:visible": _cache[2] || (_cache[2] = ($event) => visible2.value = $event),
        header: _ctx.$t("g.customizeFolder")
      }, {
        footer: withCtx(() => [
          createVNode(unref(script$10), {
            label: _ctx.$t("g.reset"),
            icon: "pi pi-refresh",
            onClick: resetCustomization,
            class: "p-button-text"
          }, null, 8, ["label"]),
          createVNode(unref(script$10), {
            label: _ctx.$t("g.confirm"),
            icon: "pi pi-check",
            onClick: confirmCustomization,
            autofocus: ""
          }, null, 8, ["label"])
        ]),
        default: withCtx(() => [
          createBaseVNode("div", _hoisted_1$9, [
            createBaseVNode("div", _hoisted_2$8, [
              createBaseVNode("label", _hoisted_3$5, toDisplayString$1(_ctx.$t("g.icon")), 1),
              createVNode(unref(script$8), {
                modelValue: selectedIcon.value,
                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => selectedIcon.value = $event),
                options: iconOptions,
                optionLabel: "name",
                dataKey: "value"
              }, {
                option: withCtx((slotProps) => [
                  createBaseVNode("i", {
                    class: normalizeClass(["pi", slotProps.option.value, "mr-2"]),
                    style: normalizeStyle({ color: finalColor.value })
                  }, null, 6)
                ]),
                _: 1
              }, 8, ["modelValue"])
            ]),
            createVNode(unref(script$Y)),
            createBaseVNode("div", _hoisted_4$3, [
              createBaseVNode("label", _hoisted_5$3, toDisplayString$1(_ctx.$t("g.color")), 1),
              createVNode(_sfc_main$e, {
                modelValue: finalColor.value,
                "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => finalColor.value = $event),
                "color-options": colorOptions
              }, null, 8, ["modelValue"])
            ])
          ])
        ]),
        _: 1
      }, 8, ["visible", "header"]);
    };
  }
});
const FolderCustomizationDialog = /* @__PURE__ */ _export_sfc(_sfc_main$d, [["__scopeId", "data-v-1073dbbe"]]);
const _sfc_main$c = /* @__PURE__ */ defineComponent({
  __name: "NodeTreeFolder",
  props: {
    node: {}
  },
  setup(__props) {
    const nodeBookmarkStore = useNodeBookmarkStore();
    const customization = computed(() => {
      const nodeDef = __props.node.data;
      return nodeDef ? nodeBookmarkStore.bookmarksCustomization[nodeDef.nodePath] : void 0;
    });
    const treeNodeElement = ref(null);
    const iconElement = ref(null);
    let stopWatchCustomization = null;
    const container = ref(null);
    onMounted(() => {
      treeNodeElement.value = container.value?.closest(
        ".p-tree-node-content"
      );
      iconElement.value = treeNodeElement.value.querySelector(
        ":scope > .p-tree-node-icon"
      );
      updateIconColor();
      stopWatchCustomization = watch(customization, updateIconColor, { deep: true });
    });
    const updateIconColor = /* @__PURE__ */ __name(() => {
      if (iconElement.value && customization.value) {
        iconElement.value.style.color = customization.value.color ?? "";
      }
    }, "updateIconColor");
    onUnmounted(() => {
      if (stopWatchCustomization) {
        stopWatchCustomization();
      }
    });
    const expandedKeys2 = inject(InjectKeyExpandedKeys);
    const handleItemDrop = /* @__PURE__ */ __name((node3) => {
      if (!expandedKeys2) return;
      expandedKeys2.value[node3.key] = true;
    }, "handleItemDrop");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        ref_key: "container",
        ref: container,
        class: "node-lib-node-container"
      }, [
        createVNode(TreeExplorerTreeNode, {
          node: _ctx.node,
          onItemDropped: handleItemDrop
        }, null, 8, ["node"])
      ], 512);
    };
  }
});
const _sfc_main$b = /* @__PURE__ */ defineComponent({
  __name: "NodeBookmarkTreeExplorer",
  props: {
    filteredNodeDefs: {}
  },
  setup(__props, { expose: __expose }) {
    const props = __props;
    const expandedKeys2 = ref({});
    const { expandNode, toggleNodeOnEvent } = useTreeExpansion(expandedKeys2);
    const nodeBookmarkStore = useNodeBookmarkStore();
    const bookmarkedRoot = computed(() => {
      const filterTree = /* @__PURE__ */ __name((node3) => {
        if (node3.leaf) {
          return props.filteredNodeDefs.some((def2) => def2.name === node3.data.name) ? node3 : null;
        }
        const filteredChildren = node3.children?.map(filterTree).filter((child) => child !== null);
        if (filteredChildren && filteredChildren.length > 0) {
          return {
            ...node3,
            children: filteredChildren
          };
        }
        return null;
      }, "filterTree");
      return props.filteredNodeDefs.length ? filterTree(nodeBookmarkStore.bookmarkedRoot) || {
        key: "root",
        label: "Root",
        children: []
      } : nodeBookmarkStore.bookmarkedRoot;
    });
    watch(
      () => props.filteredNodeDefs,
      (newValue2) => {
        if (newValue2.length) {
          nextTick(() => expandNode(bookmarkedRoot.value));
        }
      }
    );
    const { t: t2 } = useI18n();
    const extraMenuItems = /* @__PURE__ */ __name((menuTargetNode) => [
      {
        label: t2("g.customize"),
        icon: "pi pi-palette",
        command: /* @__PURE__ */ __name(() => {
          if (!menuTargetNode.data) return;
          const customization = nodeBookmarkStore.bookmarksCustomization[menuTargetNode.data.nodePath];
          initialIcon.value = customization?.icon || nodeBookmarkStore.defaultBookmarkIcon;
          initialColor.value = customization?.color || nodeBookmarkStore.defaultBookmarkColor;
          showCustomizationDialog.value = true;
          customizationTargetNodePath.value = menuTargetNode.data.nodePath;
        }, "command"),
        visible: !menuTargetNode?.leaf
      }
    ], "extraMenuItems");
    const renderedBookmarkedRoot = computed(
      () => {
        const fillNodeInfo = /* @__PURE__ */ __name((node3) => {
          const children = node3.children?.map(fillNodeInfo);
          const sortedChildren = children?.sort((a2, b2) => {
            if (a2.leaf === b2.leaf) {
              return a2.label.localeCompare(b2.label);
            }
            return a2.leaf ? 1 : -1;
          });
          return {
            key: node3.key,
            label: node3.leaf ? node3.data.display_name : node3.label,
            leaf: node3.leaf,
            data: node3.data,
            getIcon() {
              if (this.leaf) {
                return "pi pi-circle-fill";
              }
              const customization = nodeBookmarkStore.bookmarksCustomization[node3.data?.nodePath];
              return customization?.icon ? "pi " + customization.icon : "pi pi-bookmark-fill";
            },
            children: sortedChildren,
            draggable: node3.leaf,
            handleAddFolder(newName) {
              if (newName !== "") {
                nodeBookmarkStore.addNewBookmarkFolder(this.data, newName);
              }
            },
            renderDragPreview(container) {
              const vnode = h(NodePreview, { nodeDef: node3.data });
              render$15(vnode, container);
              return () => {
                render$15(null, container);
              };
            },
            droppable: !node3.leaf,
            handleDrop(data30) {
              const nodeDefToAdd = data30.data.data;
              if (nodeBookmarkStore.isBookmarked(nodeDefToAdd)) {
                nodeBookmarkStore.toggleBookmark(nodeDefToAdd);
              }
              const folderNodeDef = node3.data;
              const nodePath = folderNodeDef.category + "/" + nodeDefToAdd.name;
              nodeBookmarkStore.addBookmark(nodePath);
            },
            handleClick(e2) {
              if (this.leaf) {
                useLitegraphService().addNodeOnGraph(this.data);
              } else {
                toggleNodeOnEvent(e2, node3);
              }
            },
            contextMenuItems: extraMenuItems,
            ...node3.leaf ? {} : {
              handleRename(newName) {
                if (this.data && this.data.isDummyFolder) {
                  nodeBookmarkStore.renameBookmarkFolder(this.data, newName);
                }
              },
              handleDelete() {
                nodeBookmarkStore.deleteBookmarkFolder(this.data);
              }
            }
          };
        }, "fillNodeInfo");
        return fillNodeInfo(bookmarkedRoot.value);
      }
    );
    const treeExplorerRef = ref(null);
    __expose({
      addNewBookmarkFolder: /* @__PURE__ */ __name(() => treeExplorerRef.value?.addFolderCommand("root"), "addNewBookmarkFolder")
    });
    const showCustomizationDialog = ref(false);
    const initialIcon = ref(nodeBookmarkStore.defaultBookmarkIcon);
    const initialColor = ref(nodeBookmarkStore.defaultBookmarkColor);
    const customizationTargetNodePath = ref("");
    const updateCustomization = /* @__PURE__ */ __name((icon3, color2) => {
      if (customizationTargetNodePath.value) {
        nodeBookmarkStore.updateBookmarkCustomization(
          customizationTargetNodePath.value,
          { icon: icon3, color: color2 }
        );
      }
    }, "updateCustomization");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(TreeExplorer, {
          class: "node-lib-bookmark-tree-explorer",
          ref_key: "treeExplorerRef",
          ref: treeExplorerRef,
          root: renderedBookmarkedRoot.value,
          expandedKeys: expandedKeys2.value
        }, {
          folder: withCtx(({ node: node3 }) => [
            createVNode(_sfc_main$c, { node: node3 }, null, 8, ["node"])
          ]),
          node: withCtx(({ node: node3 }) => [
            createVNode(NodeTreeLeaf, { node: node3 }, null, 8, ["node"])
          ]),
          _: 1
        }, 8, ["root", "expandedKeys"]),
        createVNode(FolderCustomizationDialog, {
          modelValue: showCustomizationDialog.value,
          "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => showCustomizationDialog.value = $event),
          onConfirm: updateCustomization,
          initialIcon: initialIcon.value,
          initialColor: initialColor.value
        }, null, 8, ["modelValue", "initialIcon", "initialColor"])
      ], 64);
    };
  }
});
const _sfc_main$a = /* @__PURE__ */ defineComponent({
  __name: "NodeLibrarySidebarTab",
  setup(__props) {
    const nodeDefStore = useNodeDefStore();
    const nodeBookmarkStore = useNodeBookmarkStore();
    const expandedKeys2 = ref({});
    const { expandNode, toggleNodeOnEvent } = useTreeExpansion(expandedKeys2);
    const nodeBookmarkTreeExplorerRef = ref(null);
    const searchFilter = ref(null);
    const alphabeticalSort = ref(false);
    const searchQuery = ref("");
    const root34 = computed(() => {
      const root210 = filteredRoot.value || nodeDefStore.nodeTree;
      return alphabeticalSort.value ? sortedTree(root210, { groupLeaf: true }) : root210;
    });
    const renderedRoot = computed(() => {
      const fillNodeInfo = /* @__PURE__ */ __name((node3) => {
        const children = node3.children?.map(fillNodeInfo);
        return {
          key: node3.key,
          label: node3.leaf ? node3.data.display_name : node3.label,
          leaf: node3.leaf,
          data: node3.data,
          getIcon() {
            if (this.leaf) {
              return "pi pi-circle-fill";
            }
          },
          children,
          draggable: node3.leaf,
          renderDragPreview(container) {
            const vnode = h(NodePreview, { nodeDef: node3.data });
            render$15(vnode, container);
            return () => {
              render$15(null, container);
            };
          },
          handleClick(e2) {
            if (this.leaf) {
              useLitegraphService().addNodeOnGraph(this.data);
            } else {
              toggleNodeOnEvent(e2, this);
            }
          }
        };
      }, "fillNodeInfo");
      return fillNodeInfo(root34.value);
    });
    const filteredNodeDefs = ref([]);
    const filteredRoot = computed(() => {
      if (!filteredNodeDefs.value.length) {
        return null;
      }
      return buildNodeDefTree(filteredNodeDefs.value);
    });
    const filters = ref([]);
    const handleSearch = /* @__PURE__ */ __name((query) => {
      if (query.length === 0 && !filters.value.length) {
        filteredNodeDefs.value = [];
        expandedKeys2.value = {};
        return;
      }
      const f2 = filters.value.map((f22) => f22.filter);
      filteredNodeDefs.value = nodeDefStore.nodeSearchService.searchNode(
        query,
        f2,
        {
          limit: 64
        },
        {
          matchWildcards: false
        }
      );
      nextTick(() => {
        expandNode(filteredRoot.value);
      });
    }, "handleSearch");
    const onAddFilter = /* @__PURE__ */ __name((filterAndValue) => {
      filters.value.push({
        filter: filterAndValue,
        badge: filterAndValue[0].invokeSequence.toUpperCase(),
        badgeClass: filterAndValue[0].invokeSequence + "-badge",
        text: filterAndValue[1],
        id: +/* @__PURE__ */ new Date()
      });
      handleSearch(searchQuery.value);
    }, "onAddFilter");
    const onRemoveFilter = /* @__PURE__ */ __name((filterAndValue) => {
      const index2 = filters.value.findIndex((f2) => f2 === filterAndValue);
      if (index2 !== -1) {
        filters.value.splice(index2, 1);
      }
      handleSearch(searchQuery.value);
    }, "onRemoveFilter");
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(SidebarTabTemplate, {
          title: _ctx.$t("sideToolbar.nodeLibrary"),
          class: "bg-[var(--p-tree-background)]"
        }, {
          "tool-buttons": withCtx(() => [
            withDirectives(createVNode(unref(script$10), {
              class: "new-folder-button",
              icon: "pi pi-folder-plus",
              text: "",
              severity: "secondary",
              onClick: _cache[0] || (_cache[0] = ($event) => nodeBookmarkTreeExplorerRef.value?.addNewBookmarkFolder())
            }, null, 512), [
              [
                _directive_tooltip,
                _ctx.$t("g.newFolder"),
                void 0,
                { bottom: true }
              ]
            ]),
            withDirectives(createVNode(unref(script$10), {
              class: "sort-button",
              icon: alphabeticalSort.value ? "pi pi-sort-alpha-down" : "pi pi-sort-alt",
              text: "",
              severity: "secondary",
              onClick: _cache[1] || (_cache[1] = ($event) => alphabeticalSort.value = !alphabeticalSort.value)
            }, null, 8, ["icon"]), [
              [
                _directive_tooltip,
                _ctx.$t("sideToolbar.nodeLibraryTab.sortOrder"),
                void 0,
                { bottom: true }
              ]
            ])
          ]),
          header: withCtx(() => [
            createVNode(SearchBox, {
              class: "node-lib-search-box p-2 2xl:p-4",
              modelValue: searchQuery.value,
              "onUpdate:modelValue": _cache[2] || (_cache[2] = ($event) => searchQuery.value = $event),
              onSearch: handleSearch,
              onShowFilter: _cache[3] || (_cache[3] = ($event) => searchFilter.value?.toggle($event)),
              onRemoveFilter,
              placeholder: _ctx.$t("g.searchNodes") + "...",
              "filter-icon": "pi pi-filter",
              filters: filters.value
            }, null, 8, ["modelValue", "placeholder", "filters"]),
            createVNode(unref(script$l), {
              ref_key: "searchFilter",
              ref: searchFilter,
              class: "ml-[-13px]"
            }, {
              default: withCtx(() => [
                createVNode(NodeSearchFilter, { onAddFilter })
              ]),
              _: 1
            }, 512)
          ]),
          body: withCtx(() => [
            createVNode(_sfc_main$b, {
              ref_key: "nodeBookmarkTreeExplorerRef",
              ref: nodeBookmarkTreeExplorerRef,
              "filtered-node-defs": filteredNodeDefs.value
            }, null, 8, ["filtered-node-defs"]),
            withDirectives(createVNode(unref(script$Y), {
              type: "dashed",
              class: "m-2"
            }, null, 512), [
              [vShow, unref(nodeBookmarkStore).bookmarks.length > 0]
            ]),
            createVNode(TreeExplorer, {
              class: "node-lib-tree-explorer",
              root: renderedRoot.value,
              expandedKeys: expandedKeys2.value,
              "onUpdate:expandedKeys": _cache[4] || (_cache[4] = ($event) => expandedKeys2.value = $event)
            }, {
              node: withCtx(({ node: node3 }) => [
                createVNode(NodeTreeLeaf, { node: node3 }, null, 8, ["node"])
              ]),
              _: 1
            }, 8, ["root", "expandedKeys"])
          ]),
          _: 1
        }, 8, ["title"]),
        _cache[5] || (_cache[5] = createBaseVNode("div", { id: "node-library-node-preview-container" }, null, -1))
      ], 64);
    };
  }
});
const useNodeLibrarySidebarTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  return {
    id: "node-library",
    icon: "pi pi-book",
    title: t2("sideToolbar.nodeLibrary"),
    tooltip: t2("sideToolbar.nodeLibrary"),
    component: markRaw(_sfc_main$a),
    type: "vue"
  };
}, "useNodeLibrarySidebarTab");
var theme$2 = /* @__PURE__ */ __name(function theme44(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-confirmpopup {\n    position: absolute;\n    margin-top: ".concat(dt2("confirmpopup.gutter"), ";\n    top: 0;\n    left: 0;\n    background: ").concat(dt2("confirmpopup.background"), ";\n    color: ").concat(dt2("confirmpopup.color"), ";\n    border: 1px solid ").concat(dt2("confirmpopup.border.color"), ";\n    border-radius: ").concat(dt2("confirmpopup.border.radius"), ";\n    box-shadow: ").concat(dt2("confirmpopup.shadow"), ";\n}\n\n.p-confirmpopup-content {\n    display: flex;\n    align-items: center;\n    padding: ").concat(dt2("confirmpopup.content.padding"), ";\n    gap: ").concat(dt2("confirmpopup.content.gap"), ";\n}\n\n.p-confirmpopup-icon {\n    font-size: ").concat(dt2("confirmpopup.icon.size"), ";\n    width: ").concat(dt2("confirmpopup.icon.size"), ";\n    height: ").concat(dt2("confirmpopup.icon.size"), ";\n    color: ").concat(dt2("confirmpopup.icon.color"), ";\n}\n\n.p-confirmpopup-footer {\n    display: flex;\n    justify-content: flex-end;\n    gap: ").concat(dt2("confirmpopup.footer.gap"), ";\n    padding: ").concat(dt2("confirmpopup.footer.padding"), ";\n}\n\n.p-confirmpopup-footer button {\n    width: auto;\n}\n\n.p-confirmpopup-footer button:last-child {\n    margin: 0;\n}\n\n.p-confirmpopup-flipped {\n    margin-block-start: calc(").concat(dt2("confirmpopup.gutter"), " * -1);\n    margin-block-end: ").concat(dt2("confirmpopup.gutter"), ";\n}\n\n.p-confirmpopup-enter-from {\n    opacity: 0;\n    transform: scaleY(0.8);\n}\n\n.p-confirmpopup-leave-to {\n    opacity: 0;\n}\n\n.p-confirmpopup-enter-active {\n    transition: transform 0.12s cubic-bezier(0, 0, 0.2, 1), opacity 0.12s cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-confirmpopup-leave-active {\n    transition: opacity 0.1s linear;\n}\n\n.p-confirmpopup:after,\n.p-confirmpopup:before {\n    bottom: 100%;\n    left: calc(").concat(dt2("confirmpopup.arrow.offset"), " + ").concat(dt2("confirmpopup.arrow.left"), ');\n    content: " ";\n    height: 0;\n    width: 0;\n    position: absolute;\n    pointer-events: none;\n}\n\n.p-confirmpopup:after {\n    border-width: calc(').concat(dt2("confirmpopup.gutter"), " - 2px);\n    margin-left: calc(-1 * (").concat(dt2("confirmpopup.gutter"), " - 2px));\n    border-style: solid;\n    border-color: transparent;\n    border-bottom-color: ").concat(dt2("confirmpopup.background"), ";\n}\n\n.p-confirmpopup:before {\n    border-width: ").concat(dt2("confirmpopup.gutter"), ";\n    margin-left: calc(-1 * ").concat(dt2("confirmpopup.gutter"), ");\n    border-style: solid;\n    border-color: transparent;\n    border-bottom-color: ").concat(dt2("confirmpopup.border.color"), ";\n}\n\n.p-confirmpopup-flipped:after,\n.p-confirmpopup-flipped:before {\n    bottom: auto;\n    top: 100%;\n}\n\n.p-confirmpopup-flipped:after {\n    border-bottom-color: transparent;\n    border-top-color: ").concat(dt2("confirmpopup.background"), ";\n}\n\n.p-confirmpopup-flipped:before {\n    border-bottom-color: transparent;\n    border-top-color: ").concat(dt2("confirmpopup.border.color"), ";\n}\n");
}, "theme");
var classes$2 = {
  root: "p-confirmpopup p-component",
  content: "p-confirmpopup-content",
  icon: "p-confirmpopup-icon",
  message: "p-confirmpopup-message",
  footer: "p-confirmpopup-footer",
  pcRejectButton: "p-confirmpopup-reject-button",
  pcAcceptButton: "p-confirmpopup-accept-button"
};
var ConfirmPopupStyle = BaseStyle$1.extend({
  name: "confirmpopup",
  theme: theme$2,
  classes: classes$2
});
var script$1$2 = {
  name: "BaseConfirmPopup",
  "extends": script$1b,
  props: {
    group: String
  },
  style: ConfirmPopupStyle,
  provide: /* @__PURE__ */ __name(function provide49() {
    return {
      $pcConfirmPopup: this,
      $parentInstance: this
    };
  }, "provide")
};
var script$7 = {
  name: "ConfirmPopup",
  "extends": script$1$2,
  inheritAttrs: false,
  data: /* @__PURE__ */ __name(function data25() {
    return {
      visible: false,
      confirmation: null,
      autoFocusAccept: null,
      autoFocusReject: null,
      target: null
    };
  }, "data"),
  target: null,
  outsideClickListener: null,
  scrollHandler: null,
  resizeListener: null,
  container: null,
  confirmListener: null,
  closeListener: null,
  mounted: /* @__PURE__ */ __name(function mounted25() {
    var _this = this;
    this.confirmListener = function(options5) {
      if (!options5) {
        return;
      }
      if (options5.group === _this.group) {
        _this.confirmation = options5;
        _this.target = options5.target;
        if (_this.confirmation.onShow) {
          _this.confirmation.onShow();
        }
        _this.visible = true;
      }
    };
    this.closeListener = function() {
      _this.visible = false;
      _this.confirmation = null;
    };
    ConfirmationEventBus.on("confirm", this.confirmListener);
    ConfirmationEventBus.on("close", this.closeListener);
  }, "mounted"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount14() {
    ConfirmationEventBus.off("confirm", this.confirmListener);
    ConfirmationEventBus.off("close", this.closeListener);
    this.unbindOutsideClickListener();
    if (this.scrollHandler) {
      this.scrollHandler.destroy();
      this.scrollHandler = null;
    }
    this.unbindResizeListener();
    if (this.container) {
      ZIndex$1.clear(this.container);
      this.container = null;
    }
    this.target = null;
    this.confirmation = null;
  }, "beforeUnmount"),
  methods: {
    accept: /* @__PURE__ */ __name(function accept() {
      if (this.confirmation.accept) {
        this.confirmation.accept();
      }
      this.visible = false;
    }, "accept"),
    reject: /* @__PURE__ */ __name(function reject() {
      if (this.confirmation.reject) {
        this.confirmation.reject();
      }
      this.visible = false;
    }, "reject"),
    onHide: /* @__PURE__ */ __name(function onHide() {
      if (this.confirmation.onHide) {
        this.confirmation.onHide();
      }
      this.visible = false;
    }, "onHide"),
    onAcceptKeydown: /* @__PURE__ */ __name(function onAcceptKeydown(event) {
      if (event.code === "Space" || event.code === "Enter" || event.code === "NumpadEnter") {
        this.accept();
        focus$2(this.target);
        event.preventDefault();
      }
    }, "onAcceptKeydown"),
    onRejectKeydown: /* @__PURE__ */ __name(function onRejectKeydown(event) {
      if (event.code === "Space" || event.code === "Enter" || event.code === "NumpadEnter") {
        this.reject();
        focus$2(this.target);
        event.preventDefault();
      }
    }, "onRejectKeydown"),
    onEnter: /* @__PURE__ */ __name(function onEnter5(el) {
      this.autoFocusAccept = this.confirmation.defaultFocus === void 0 || this.confirmation.defaultFocus === "accept" ? true : false;
      this.autoFocusReject = this.confirmation.defaultFocus === "reject" ? true : false;
      this.target = this.target || document.activeElement;
      this.bindOutsideClickListener();
      this.bindScrollListener();
      this.bindResizeListener();
      ZIndex$1.set("overlay", el, this.$primevue.config.zIndex.overlay);
    }, "onEnter"),
    onAfterEnter: /* @__PURE__ */ __name(function onAfterEnter3() {
      this.focus();
    }, "onAfterEnter"),
    onLeave: /* @__PURE__ */ __name(function onLeave4() {
      this.autoFocusAccept = null;
      this.autoFocusReject = null;
      focus$2(this.target);
      this.target = null;
      this.unbindOutsideClickListener();
      this.unbindScrollListener();
      this.unbindResizeListener();
    }, "onLeave"),
    onAfterLeave: /* @__PURE__ */ __name(function onAfterLeave4(el) {
      ZIndex$1.clear(el);
    }, "onAfterLeave"),
    alignOverlay: /* @__PURE__ */ __name(function alignOverlay7() {
      absolutePosition$1(this.container, this.target, false);
      var containerOffset = getOffset$1(this.container);
      var targetOffset = getOffset$1(this.target);
      var arrowLeft = 0;
      if (containerOffset.left < targetOffset.left) {
        arrowLeft = targetOffset.left - containerOffset.left;
      }
      this.container.style.setProperty($dt$1("confirmpopup.arrow.left").name, "".concat(arrowLeft, "px"));
      if (containerOffset.top < targetOffset.top) {
        this.container.setAttribute("data-p-confirmpopup-flipped", "true");
        !this.isUnstyled && addClass$1(this.container, "p-confirmpopup-flipped");
      }
    }, "alignOverlay"),
    bindOutsideClickListener: /* @__PURE__ */ __name(function bindOutsideClickListener7() {
      var _this2 = this;
      if (!this.outsideClickListener) {
        this.outsideClickListener = function(event) {
          if (_this2.visible && _this2.container && !_this2.container.contains(event.target) && !_this2.isTargetClicked(event)) {
            if (_this2.confirmation.onHide) {
              _this2.confirmation.onHide();
            }
            _this2.visible = false;
          } else {
            _this2.alignOverlay();
          }
        };
        document.addEventListener("click", this.outsideClickListener);
      }
    }, "bindOutsideClickListener"),
    unbindOutsideClickListener: /* @__PURE__ */ __name(function unbindOutsideClickListener7() {
      if (this.outsideClickListener) {
        document.removeEventListener("click", this.outsideClickListener);
        this.outsideClickListener = null;
      }
    }, "unbindOutsideClickListener"),
    bindScrollListener: /* @__PURE__ */ __name(function bindScrollListener7() {
      var _this3 = this;
      if (!this.scrollHandler) {
        this.scrollHandler = new ConnectedOverlayScrollHandler(this.target, function() {
          if (_this3.visible) {
            _this3.visible = false;
          }
        });
      }
      this.scrollHandler.bindScrollListener();
    }, "bindScrollListener"),
    unbindScrollListener: /* @__PURE__ */ __name(function unbindScrollListener7() {
      if (this.scrollHandler) {
        this.scrollHandler.unbindScrollListener();
      }
    }, "unbindScrollListener"),
    bindResizeListener: /* @__PURE__ */ __name(function bindResizeListener8() {
      var _this4 = this;
      if (!this.resizeListener) {
        this.resizeListener = function() {
          if (_this4.visible && !isTouchDevice$1()) {
            _this4.visible = false;
          }
        };
        window.addEventListener("resize", this.resizeListener);
      }
    }, "bindResizeListener"),
    unbindResizeListener: /* @__PURE__ */ __name(function unbindResizeListener8() {
      if (this.resizeListener) {
        window.removeEventListener("resize", this.resizeListener);
        this.resizeListener = null;
      }
    }, "unbindResizeListener"),
    focus: /* @__PURE__ */ __name(function focus3() {
      var focusTarget = this.container.querySelector("[autofocus]");
      if (focusTarget) {
        focusTarget.focus({
          preventScroll: true
        });
      }
    }, "focus"),
    isTargetClicked: /* @__PURE__ */ __name(function isTargetClicked2(event) {
      return this.target && (this.target === event.target || this.target.contains(event.target));
    }, "isTargetClicked"),
    containerRef: /* @__PURE__ */ __name(function containerRef4(el) {
      this.container = el;
    }, "containerRef"),
    onOverlayClick: /* @__PURE__ */ __name(function onOverlayClick6(event) {
      OverlayEventBus.emit("overlay-click", {
        originalEvent: event,
        target: this.target
      });
    }, "onOverlayClick"),
    onOverlayKeydown: /* @__PURE__ */ __name(function onOverlayKeydown(event) {
      if (event.code === "Escape") {
        ConfirmationEventBus.emit("close", this.closeListener);
        focus$2(this.target);
      }
    }, "onOverlayKeydown")
  },
  computed: {
    message: /* @__PURE__ */ __name(function message() {
      return this.confirmation ? this.confirmation.message : null;
    }, "message"),
    acceptLabel: /* @__PURE__ */ __name(function acceptLabel() {
      if (this.confirmation) {
        var _confirmation$acceptP;
        var confirmation = this.confirmation;
        return confirmation.acceptLabel || ((_confirmation$acceptP = confirmation.acceptProps) === null || _confirmation$acceptP === void 0 ? void 0 : _confirmation$acceptP.label) || this.$primevue.config.locale.accept;
      }
      return this.$primevue.config.locale.accept;
    }, "acceptLabel"),
    rejectLabel: /* @__PURE__ */ __name(function rejectLabel() {
      if (this.confirmation) {
        var _confirmation$rejectP;
        var confirmation = this.confirmation;
        return confirmation.rejectLabel || ((_confirmation$rejectP = confirmation.rejectProps) === null || _confirmation$rejectP === void 0 ? void 0 : _confirmation$rejectP.label) || this.$primevue.config.locale.reject;
      }
      return this.$primevue.config.locale.reject;
    }, "rejectLabel"),
    acceptIcon: /* @__PURE__ */ __name(function acceptIcon() {
      var _this$confirmation;
      return this.confirmation ? this.confirmation.acceptIcon : (_this$confirmation = this.confirmation) !== null && _this$confirmation !== void 0 && _this$confirmation.acceptProps ? this.confirmation.acceptProps.icon : null;
    }, "acceptIcon"),
    rejectIcon: /* @__PURE__ */ __name(function rejectIcon() {
      var _this$confirmation2;
      return this.confirmation ? this.confirmation.rejectIcon : (_this$confirmation2 = this.confirmation) !== null && _this$confirmation2 !== void 0 && _this$confirmation2.rejectProps ? this.confirmation.rejectProps.icon : null;
    }, "rejectIcon")
  },
  components: {
    Button: script$10,
    Portal: script$$
  },
  directives: {
    focustrap: FocusTrap
  }
};
var _hoisted_1$8 = ["aria-modal"];
function render$6(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Button = resolveComponent("Button");
  var _component_Portal = resolveComponent("Portal");
  var _directive_focustrap = resolveDirective("focustrap");
  return openBlock(), createBlock(_component_Portal, null, {
    "default": withCtx(function() {
      return [createVNode(Transition, mergeProps$2({
        name: "p-confirmpopup",
        onEnter: $options.onEnter,
        onAfterEnter: $options.onAfterEnter,
        onLeave: $options.onLeave,
        onAfterLeave: $options.onAfterLeave
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          var _$data$confirmation$r, _$data$confirmation$r2, _$data$confirmation$a;
          return [$data.visible ? withDirectives((openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            ref: $options.containerRef,
            role: "alertdialog",
            "class": _ctx.cx("root"),
            "aria-modal": $data.visible,
            onClick: _cache[2] || (_cache[2] = function() {
              return $options.onOverlayClick && $options.onOverlayClick.apply($options, arguments);
            }),
            onKeydown: _cache[3] || (_cache[3] = function() {
              return $options.onOverlayKeydown && $options.onOverlayKeydown.apply($options, arguments);
            })
          }, _ctx.ptmi("root")), [_ctx.$slots.container ? renderSlot(_ctx.$slots, "container", {
            key: 0,
            message: $data.confirmation,
            acceptCallback: $options.accept,
            rejectCallback: $options.reject
          }) : (openBlock(), createElementBlock(Fragment$1, {
            key: 1
          }, [!_ctx.$slots.message ? (openBlock(), createElementBlock("div", mergeProps$2({
            key: 0,
            "class": _ctx.cx("content")
          }, _ctx.ptm("content")), [renderSlot(_ctx.$slots, "icon", {}, function() {
            return [_ctx.$slots.icon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.icon), {
              key: 0,
              "class": normalizeClass(_ctx.cx("icon"))
            }, null, 8, ["class"])) : $data.confirmation.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
              key: 1,
              "class": [$data.confirmation.icon, _ctx.cx("icon")]
            }, _ctx.ptm("icon")), null, 16)) : createCommentVNode("", true)];
          }), createBaseVNode("span", mergeProps$2({
            "class": _ctx.cx("message")
          }, _ctx.ptm("message")), toDisplayString$1($data.confirmation.message), 17)], 16)) : (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.message), {
            key: 1,
            message: $data.confirmation
          }, null, 8, ["message"])), createBaseVNode("div", mergeProps$2({
            "class": _ctx.cx("footer")
          }, _ctx.ptm("footer")), [createVNode(_component_Button, mergeProps$2({
            "class": [_ctx.cx("pcRejectButton"), $data.confirmation.rejectClass],
            autofocus: $data.autoFocusReject,
            unstyled: _ctx.unstyled,
            size: ((_$data$confirmation$r = $data.confirmation.rejectProps) === null || _$data$confirmation$r === void 0 ? void 0 : _$data$confirmation$r.size) || "small",
            text: ((_$data$confirmation$r2 = $data.confirmation.rejectProps) === null || _$data$confirmation$r2 === void 0 ? void 0 : _$data$confirmation$r2.text) || false,
            onClick: _cache[0] || (_cache[0] = function($event) {
              return $options.reject();
            }),
            onKeydown: $options.onRejectKeydown
          }, $data.confirmation.rejectProps, {
            label: $options.rejectLabel,
            pt: _ctx.ptm("pcRejectButton")
          }), createSlots({
            _: 2
          }, [$options.rejectIcon || _ctx.$slots.rejecticon ? {
            name: "icon",
            fn: withCtx(function(iconProps) {
              return [renderSlot(_ctx.$slots, "rejecticon", {}, function() {
                return [createBaseVNode("span", mergeProps$2({
                  "class": [$options.rejectIcon, iconProps["class"]]
                }, _ctx.ptm("pcRejectButton")["icon"], {
                  "data-pc-section": "rejectbuttonicon"
                }), null, 16)];
              })];
            }),
            key: "0"
          } : void 0]), 1040, ["class", "autofocus", "unstyled", "size", "text", "onKeydown", "label", "pt"]), createVNode(_component_Button, mergeProps$2({
            "class": [_ctx.cx("pcAcceptButton"), $data.confirmation.acceptClass],
            autofocus: $data.autoFocusAccept,
            unstyled: _ctx.unstyled,
            size: ((_$data$confirmation$a = $data.confirmation.acceptProps) === null || _$data$confirmation$a === void 0 ? void 0 : _$data$confirmation$a.size) || "small",
            onClick: _cache[1] || (_cache[1] = function($event) {
              return $options.accept();
            }),
            onKeydown: $options.onAcceptKeydown
          }, $data.confirmation.acceptProps, {
            label: $options.acceptLabel,
            pt: _ctx.ptm("pcAcceptButton")
          }), createSlots({
            _: 2
          }, [$options.acceptIcon || _ctx.$slots.accepticon ? {
            name: "icon",
            fn: withCtx(function(iconProps) {
              return [renderSlot(_ctx.$slots, "accepticon", {}, function() {
                return [createBaseVNode("span", mergeProps$2({
                  "class": [$options.acceptIcon, iconProps["class"]]
                }, _ctx.ptm("pcAcceptButton")["icon"], {
                  "data-pc-section": "acceptbuttonicon"
                }), null, 16)];
              })];
            }),
            key: "0"
          } : void 0]), 1040, ["class", "autofocus", "unstyled", "size", "onKeydown", "label", "pt"])], 16)], 64))], 16, _hoisted_1$8)), [[_directive_focustrap]]) : createCommentVNode("", true)];
        }),
        _: 3
      }, 16, ["onEnter", "onAfterEnter", "onLeave", "onAfterLeave"])];
    }),
    _: 3
  });
}
__name(render$6, "render$6");
script$7.render = render$6;
var theme$1 = /* @__PURE__ */ __name(function theme45(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-galleria {\n    overflow: hidden;\n    border-style: solid;\n    border-width: ".concat(dt2("galleria.border.width"), ";\n    border-color: ").concat(dt2("galleria.border.color"), ";\n    border-radius: ").concat(dt2("galleria.border.radius"), ";\n}\n\n.p-galleria-content {\n    display: flex;\n    flex-direction: column;\n}\n\n.p-galleria-items-container {\n    display: flex;\n    flex-direction: column;\n    position: relative;\n}\n\n.p-galleria-items {\n    position: relative;\n    display: flex;\n    height: 100%;\n}\n\n.p-galleria-nav-button {\n    position: absolute !important;\n    top: 50%;\n    display: inline-flex;\n    justify-content: center;\n    align-items: center;\n    overflow: hidden;\n    background: ").concat(dt2("galleria.nav.button.background"), ";\n    color: ").concat(dt2("galleria.nav.button.color"), ";\n    width: ").concat(dt2("galleria.nav.button.size"), ";\n    height: ").concat(dt2("galleria.nav.button.size"), ";\n    transition: background ").concat(dt2("galleria.transition.duration"), ", color ").concat(dt2("galleria.transition.duration"), ", outline-color ").concat(dt2("galleria.transition.duration"), ", box-shadow ").concat(dt2("galleria.transition.duration"), ";\n    margin: calc(-1 * calc(").concat(dt2("galleria.nav.button.size"), ") / 2) ").concat(dt2("galleria.nav.button.gutter"), " 0 ").concat(dt2("galleria.nav.button.gutter"), ";\n    padding: 0;\n    user-select: none;\n    border: 0 none;\n    cursor: pointer;\n    outline-color: transparent;\n}\n\n.p-galleria-nav-button:not(.p-disabled):hover {\n    background: ").concat(dt2("galleria.nav.button.hover.background"), ";\n    color: ").concat(dt2("galleria.nav.button.hover.color"), ";\n}\n\n.p-galleria-nav-button:not(.p-disabled):focus-visible {\n    box-shadow: ").concat(dt2("galleria.nav.button.focus.ring.shadow"), ";\n    outline: ").concat(dt2("galleria.nav.button.focus.ring.width"), " ").concat(dt2("galleria.nav.button.focus.ring.style"), " ").concat(dt2("galleria.nav.button.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("galleria.nav.button.focus.ring.offset"), ";\n}\n\n.p-galleria-next-icon,\n.p-galleria-prev-icon {\n    font-size: ").concat(dt2("galleria.nav.icon.size"), ";\n    width: ").concat(dt2("galleria.nav.icon.size"), ";\n    height: ").concat(dt2("galleria.nav.icon.size"), ";\n}\n\n.p-galleria-prev-button {\n    border-radius: ").concat(dt2("galleria.nav.button.prev.border.radius"), ";\n    left: 0;\n}\n\n.p-galleria-next-button {\n    border-radius: ").concat(dt2("galleria.nav.button.next.border.radius"), ";\n    right: 0;\n}\n\n.p-galleria-prev-button:dir(rtl) {\n    left: auto;\n    right: 0;\n    transform: rotate(180deg);\n}\n\n.p-galleria-next-button:dir(rtl) {\n    right: auto;\n    left: 0;\n    transform: rotate(180deg);\n}\n\n.p-galleria-item {\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    height: 100%;\n    width: 100%;\n}\n\n.p-galleria-hover-navigators .p-galleria-nav-button {\n    pointer-events: none;\n    opacity: 0;\n    transition: opacity ").concat(dt2("galleria.transition.duration"), " ease-in-out;\n}\n\n.p-galleria-hover-navigators .p-galleria-items-container:hover .p-galleria-nav-button {\n    pointer-events: all;\n    opacity: 1;\n}\n\n.p-galleria-hover-navigators .p-galleria-items-container:hover .p-galleria-nav-button.p-disabled {\n    pointer-events: none;\n}\n\n.p-galleria-caption {\n    position: absolute;\n    bottom: 0;\n    left: 0;\n    width: 100%;\n    background: ").concat(dt2("galleria.caption.background"), ";\n    color: ").concat(dt2("galleria.caption.color"), ";\n    padding: ").concat(dt2("galleria.caption.padding"), ";\n}\n\n.p-galleria-thumbnails {\n    display: flex;\n    flex-direction: column;\n    overflow: auto;\n    flex-shrink: 0;\n}\n\n.p-galleria-thumbnail-nav-button {\n    align-self: center;\n    flex: 0 0 auto;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    overflow: hidden;\n    position: relative;\n    margin: 0 ").concat(dt2("galleria.thumbnail.nav.button.gutter"), ";\n    padding: 0;\n    border: none;\n    user-select: none;\n    cursor: pointer;\n    background: transparent;\n    color: ").concat(dt2("galleria.thumbnail.nav.button.color"), ";\n    width: ").concat(dt2("galleria.thumbnail.nav.button.size"), ";\n    height: ").concat(dt2("galleria.thumbnail.nav.button.size"), ";\n    transition: background ").concat(dt2("galleria.transition.duration"), ", color ").concat(dt2("galleria.transition.duration"), ", outline-color ").concat(dt2("galleria.transition.duration"), ";\n    outline-color: transparent;\n    border-radius: ").concat(dt2("galleria.thumbnail.nav.button.border.radius"), ";\n}\n\n.p-galleria-thumbnail-nav-button:hover {\n    background: ").concat(dt2("galleria.thumbnail.nav.button.hover.background"), ";\n    color: ").concat(dt2("galleria.thumbnail.nav.button.hover.color"), ";\n}\n\n.p-galleria-thumbnail-nav-button:focus-visible {\n    box-shadow: ").concat(dt2("galleria.thumbnail.nav.button.focus.ring.shadow"), ";\n    outline: ").concat(dt2("galleria.thumbnail.nav.button.focus.ring.width"), " ").concat(dt2("galleria.thumbnail.nav.button.focus.ring.style"), " ").concat(dt2("galleria.thumbnail.nav.button.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("galleria.thumbnail.nav.button.focus.ring.offset"), ";\n}\n\n.p-galleria-thumbnail-nav-button .p-galleria-thumbnail-next-icon,\n.p-galleria-thumbnail-nav-button .p-galleria-thumbnail-prev-icon {\n    font-size: ").concat(dt2("galleria.thumbnail.nav.button.icon.size"), ";\n    width: ").concat(dt2("galleria.thumbnail.nav.button.icon.size"), ";\n    height: ").concat(dt2("galleria.thumbnail.nav.button.icon.size"), ";\n}\n\n.p-galleria-thumbnails-content {\n    display: flex;\n    flex-direction: row;\n    background: ").concat(dt2("galleria.thumbnails.content.background"), ";\n    padding: ").concat(dt2("galleria.thumbnails.content.padding"), ";\n}\n\n.p-galleria-thumbnails-viewport {\n    overflow: hidden;\n    width: 100%;\n}\n\n.p-galleria:not(.p-galleria-thumbnails-right):not(.p-galleria-thumbnails-left) .p-galleria-thumbnail-prev-button:dir(rtl),\n.p-galleria:not(.p-galleria-thumbnails-right):not(.p-galleria-thumbnails-left) .p-galleria-thumbnail-next-button:dir(rtl) {\n    transform: rotate(180deg);\n}\n\n.p-galleria-thumbnail-items {\n    display: flex;\n}\n\n.p-galleria-thumbnail-item {\n    overflow: auto;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    cursor: pointer;\n    opacity: 0.5;\n}\n\n.p-galleria-thumbnail {\n    outline-color: transparent;\n}\n\n.p-galleria-thumbnail-item:hover {\n    opacity: 1;\n    transition: opacity 0.3s;\n}\n\n.p-galleria-thumbnail-item-current {\n    opacity: 1;\n}\n\n.p-galleria-thumbnails-left .p-galleria-content,\n.p-galleria-thumbnails-right .p-galleria-content {\n    flex-direction: row;\n}\n\n.p-galleria-thumbnails-left .p-galleria-items-container,\n.p-galleria-thumbnails-right .p-galleria-items-container {\n    flex-direction: row;\n}\n\n.p-galleria-thumbnails-left .p-galleria-items-container,\n.p-galleria-thumbnails-top .p-galleria-items-container {\n    order: 2;\n}\n\n.p-galleria-thumbnails-left .p-galleria-thumbnails,\n.p-galleria-thumbnails-top .p-galleria-thumbnails {\n    order: 1;\n}\n\n.p-galleria-thumbnails-left .p-galleria-thumbnails-content,\n.p-galleria-thumbnails-right .p-galleria-thumbnails-content {\n    flex-direction: column;\n    flex-grow: 1;\n}\n\n.p-galleria-thumbnails-left .p-galleria-thumbnail-items,\n.p-galleria-thumbnails-right .p-galleria-thumbnail-items {\n    flex-direction: column;\n    height: 100%;\n}\n\n.p-galleria-indicator-list {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n    padding: ").concat(dt2("galleria.indicator.list.padding"), ";\n    gap: ").concat(dt2("galleria.indicator.list.gap"), ";\n    margin: 0;\n    list-style: none;\n}\n\n.p-galleria-indicator-button {\n    display: inline-flex;\n    align-items: center;\n    background: ").concat(dt2("galleria.indicator.button.background"), ";\n    width: ").concat(dt2("galleria.indicator.button.width"), ";\n    height: ").concat(dt2("galleria.indicator.button.height"), ";\n    transition: background ").concat(dt2("galleria.transition.duration"), ", color ").concat(dt2("galleria.transition.duration"), ", outline-color ").concat(dt2("galleria.transition.duration"), ", box-shadow ").concat(dt2("galleria.transition.duration"), ";\n    outline-color: transparent;\n    border-radius: ").concat(dt2("galleria.indicator.button.border.radius"), ";\n    margin: 0;\n    padding: 0;\n    border: none;\n    user-select: none;\n    cursor: pointer;\n}\n\n.p-galleria-indicator-button:hover {\n    background: ").concat(dt2("galleria.indicator.button.hover.background"), ";\n}\n\n.p-galleria-indicator-button:focus-visible {\n    box-shadow: ").concat(dt2("galleria.indicator.button.focus.ring.shadow"), ";\n    outline: ").concat(dt2("galleria.indicator.button.focus.ring.width"), " ").concat(dt2("galleria.indicator.button.focus.ring.style"), " ").concat(dt2("galleria.indicator.button.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("galleria.indicator.button.focus.ring.offset"), ";\n}\n\n.p-galleria-indicator-active .p-galleria-indicator-button {\n    background: ").concat(dt2("galleria.indicator.button.active.background"), ";\n}\n\n.p-galleria-indicators-left .p-galleria-items-container,\n.p-galleria-indicators-right .p-galleria-items-container {\n    flex-direction: row;\n    align-items: center;\n}\n\n.p-galleria-indicators-left .p-galleria-items,\n.p-galleria-indicators-top .p-galleria-items {\n    order: 2;\n}\n\n.p-galleria-indicators-left .p-galleria-indicator-list,\n.p-galleria-indicators-top .p-galleria-indicator-list {\n    order: 1;\n}\n\n.p-galleria-indicators-left .p-galleria-indicator-list,\n.p-galleria-indicators-right .p-galleria-indicator-list {\n    flex-direction: column;\n}\n\n.p-galleria-inset-indicators .p-galleria-indicator-list {\n    position: absolute;\n    display: flex;\n    z-index: 1;\n    background: ").concat(dt2("galleria.inset.indicator.list.background"), ";\n}\n\n.p-galleria-inset-indicators .p-galleria-indicator-button {\n    background: ").concat(dt2("galleria.inset.indicator.button.background"), ";\n}\n\n.p-galleria-inset-indicators .p-galleria-indicator-button:hover {\n    background: ").concat(dt2("galleria.inset.indicator.button.hover.background"), ";\n}\n\n.p-galleria-inset-indicators .p-galleria-indicator-active .p-galleria-indicator-button {\n    background: ").concat(dt2("galleria.inset.indicator.button.active.background"), ";\n}\n\n.p-galleria-inset-indicators.p-galleria-indicators-top .p-galleria-indicator-list {\n    top: 0;\n    left: 0;\n    width: 100%;\n    align-items: flex-start;\n}\n\n.p-galleria-inset-indicators.p-galleria-indicators-right .p-galleria-indicator-list {\n    right: 0;\n    top: 0;\n    height: 100%;\n    align-items: flex-end;\n}\n\n.p-galleria-inset-indicators.p-galleria-indicators-bottom .p-galleria-indicator-list {\n    bottom: 0;\n    left: 0;\n    width: 100%;\n    align-items: flex-end;\n}\n\n.p-galleria-inset-indicators.p-galleria-indicators-left .p-galleria-indicator-list {\n    left: 0;\n    top: 0;\n    height: 100%;\n    align-items: flex-start;\n}\n\n.p-galleria-mask {\n    position: fixed;\n    top: 0;\n    left: 0;\n    width: 100%;\n    height: 100%;\n    display: flex;\n    align-items: center;\n    justify-content: center;\n}\n\n.p-galleria-close-button {\n    position: absolute !important;\n    top: 0;\n    right: 0;\n    display: flex;\n    justify-content: center;\n    align-items: center;\n    overflow: hidden;\n    margin: ").concat(dt2("galleria.close.button.gutter"), ";\n    background: ").concat(dt2("galleria.close.button.background"), ";\n    color: ").concat(dt2("galleria.close.button.color"), ";\n    width: ").concat(dt2("galleria.close.button.size"), ";\n    height: ").concat(dt2("galleria.close.button.size"), ";\n    padding: 0;\n    border: none;\n    user-select: none;\n    cursor: pointer;\n    border-radius: ").concat(dt2("galleria.close.button.border.radius"), ";\n    outline-color: transparent;\n    transition: background ").concat(dt2("galleria.transition.duration"), ", color ").concat(dt2("galleria.transition.duration"), ", outline-color ").concat(dt2("galleria.transition.duration"), ";\n}\n\n.p-galleria-close-icon {\n    font-size: ").concat(dt2("galleria.close.button.icon.size"), ";\n    width: ").concat(dt2("galleria.close.button.icon.size"), ";\n    height: ").concat(dt2("galleria.close.button.icon.size"), ";\n}\n\n.p-galleria-close-button:hover {\n    background: ").concat(dt2("galleria.close.button.hover.background"), ";\n    color: ").concat(dt2("galleria.close.button.hover.color"), ";\n}\n\n.p-galleria-close-button:focus-visible {\n    box-shadow: ").concat(dt2("galleria.close.button.focus.ring.shadow"), ";\n    outline: ").concat(dt2("galleria.close.button.focus.ring.width"), " ").concat(dt2("galleria.close.button.focus.ring.style"), " ").concat(dt2("galleria.close.button.focus.ring.color"), ";\n    outline-offset: ").concat(dt2("galleria.close.button.focus.ring.offset"), ";\n}\n\n.p-galleria-mask .p-galleria-nav-button {\n    position: fixed;\n    top: 50%;\n}\n\n.p-galleria-enter-active {\n    transition: all 150ms cubic-bezier(0, 0, 0.2, 1);\n}\n\n.p-galleria-leave-active {\n    transition: all 150ms cubic-bezier(0.4, 0, 0.2, 1);\n}\n\n.p-galleria-enter-from,\n.p-galleria-leave-to {\n    opacity: 0;\n    transform: scale(0.7);\n}\n\n.p-galleria-enter-active .p-galleria-nav-button {\n    opacity: 0;\n}\n\n.p-items-hidden .p-galleria-thumbnail-item {\n    visibility: hidden;\n}\n\n.p-items-hidden .p-galleria-thumbnail-item.p-galleria-thumbnail-item-active {\n    visibility: visible;\n}\n");
}, "theme");
var classes$1 = {
  mask: "p-galleria-mask p-overlay-mask p-overlay-mask-enter",
  root: /* @__PURE__ */ __name(function root33(_ref2) {
    var instance = _ref2.instance;
    var thumbnailsPosClass = instance.$attrs.showThumbnails && instance.getPositionClass("p-galleria-thumbnails", instance.$attrs.thumbnailsPosition);
    var indicatorPosClass = instance.$attrs.showIndicators && instance.getPositionClass("p-galleria-indicators", instance.$attrs.indicatorsPosition);
    return ["p-galleria p-component", {
      "p-galleria-fullscreen": instance.$attrs.fullScreen,
      "p-galleria-inset-indicators": instance.$attrs.showIndicatorsOnItem,
      "p-galleria-hover-navigators": instance.$attrs.showItemNavigatorsOnHover && !instance.$attrs.fullScreen
    }, thumbnailsPosClass, indicatorPosClass];
  }, "root"),
  closeButton: "p-galleria-close-button",
  closeIcon: "p-galleria-close-icon",
  header: "p-galleria-header",
  content: "p-galleria-content",
  footer: "p-galleria-footer",
  itemsContainer: "p-galleria-items-container",
  items: "p-galleria-items",
  prevButton: /* @__PURE__ */ __name(function prevButton(_ref3) {
    var instance = _ref3.instance;
    return ["p-galleria-prev-button p-galleria-nav-button", {
      "p-disabled": instance.isNavBackwardDisabled()
    }];
  }, "prevButton"),
  prevIcon: "p-galleria-prev-icon",
  item: "p-galleria-item",
  nextButton: /* @__PURE__ */ __name(function nextButton(_ref4) {
    var instance = _ref4.instance;
    return ["p-galleria-next-button p-galleria-nav-button", {
      "p-disabled": instance.isNavForwardDisabled()
    }];
  }, "nextButton"),
  nextIcon: "p-galleria-next-icon",
  caption: "p-galleria-caption",
  indicatorList: "p-galleria-indicator-list",
  indicator: /* @__PURE__ */ __name(function indicator(_ref5) {
    var instance = _ref5.instance, index2 = _ref5.index;
    return ["p-galleria-indicator", {
      "p-galleria-indicator-active": instance.isIndicatorItemActive(index2)
    }];
  }, "indicator"),
  indicatorButton: "p-galleria-indicator-button",
  thumbnails: "p-galleria-thumbnails",
  thumbnailContent: "p-galleria-thumbnails-content",
  thumbnailPrevButton: /* @__PURE__ */ __name(function thumbnailPrevButton(_ref6) {
    var instance = _ref6.instance;
    return ["p-galleria-thumbnail-prev-button p-galleria-thumbnail-nav-button", {
      "p-disabled": instance.isNavBackwardDisabled()
    }];
  }, "thumbnailPrevButton"),
  thumbnailPrevIcon: "p-galleria-thumbnail-prev-icon",
  thumbnailsViewport: "p-galleria-thumbnails-viewport",
  thumbnailItems: "p-galleria-thumbnail-items",
  thumbnailItem: /* @__PURE__ */ __name(function thumbnailItem(_ref7) {
    var instance = _ref7.instance, index2 = _ref7.index, activeIndex3 = _ref7.activeIndex;
    return ["p-galleria-thumbnail-item", {
      "p-galleria-thumbnail-item-current": activeIndex3 === index2,
      "p-galleria-thumbnail-item-active": instance.isItemActive(index2),
      "p-galleria-thumbnail-item-start": instance.firstItemAciveIndex() === index2,
      "p-galleria-thumbnail-item-end": instance.lastItemActiveIndex() === index2
    }];
  }, "thumbnailItem"),
  thumbnail: "p-galleria-thumbnail",
  thumbnailNextButton: /* @__PURE__ */ __name(function thumbnailNextButton(_ref8) {
    var instance = _ref8.instance;
    return ["p-galleria-thumbnail-next-button p-galleria-thumbnail-nav-button", {
      "p-disabled": instance.isNavForwardDisabled()
    }];
  }, "thumbnailNextButton"),
  thumbnailNextIcon: "p-galleria-thumbnail-next-icon"
};
var GalleriaStyle = BaseStyle$1.extend({
  name: "galleria",
  theme: theme$1,
  classes: classes$1
});
var script$6 = {
  name: "ChevronUpIcon",
  "extends": script$16
};
function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("svg", mergeProps$2({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, _ctx.pti()), _cache[0] || (_cache[0] = [createBaseVNode("path", {
    d: "M12.2097 10.4113C12.1057 10.4118 12.0027 10.3915 11.9067 10.3516C11.8107 10.3118 11.7237 10.2532 11.6506 10.1792L6.93602 5.46461L2.22139 10.1476C2.07272 10.244 1.89599 10.2877 1.71953 10.2717C1.54307 10.2556 1.3771 10.1808 1.24822 10.0593C1.11933 9.93766 1.035 9.77633 1.00874 9.6011C0.982477 9.42587 1.0158 9.2469 1.10338 9.09287L6.37701 3.81923C6.52533 3.6711 6.72639 3.58789 6.93602 3.58789C7.14565 3.58789 7.3467 3.6711 7.49502 3.81923L12.7687 9.09287C12.9168 9.24119 13 9.44225 13 9.65187C13 9.8615 12.9168 10.0626 12.7687 10.2109C12.616 10.3487 12.4151 10.4207 12.2097 10.4113Z",
    fill: "currentColor"
  }, null, -1)]), 16);
}
__name(render$5, "render$5");
script$6.render = render$5;
var script$4 = {
  name: "BaseGalleria",
  "extends": script$1b,
  props: {
    id: {
      type: String,
      "default": null
    },
    value: {
      type: Array,
      "default": null
    },
    activeIndex: {
      type: Number,
      "default": 0
    },
    fullScreen: {
      type: Boolean,
      "default": false
    },
    visible: {
      type: Boolean,
      "default": false
    },
    numVisible: {
      type: Number,
      "default": 3
    },
    responsiveOptions: {
      type: Array,
      "default": null
    },
    showItemNavigators: {
      type: Boolean,
      "default": false
    },
    showThumbnailNavigators: {
      type: Boolean,
      "default": true
    },
    showItemNavigatorsOnHover: {
      type: Boolean,
      "default": false
    },
    changeItemOnIndicatorHover: {
      type: Boolean,
      "default": false
    },
    circular: {
      type: Boolean,
      "default": false
    },
    autoPlay: {
      type: Boolean,
      "default": false
    },
    transitionInterval: {
      type: Number,
      "default": 4e3
    },
    showThumbnails: {
      type: Boolean,
      "default": true
    },
    thumbnailsPosition: {
      type: String,
      "default": "bottom"
    },
    verticalThumbnailViewPortHeight: {
      type: String,
      "default": "300px"
    },
    showIndicators: {
      type: Boolean,
      "default": false
    },
    showIndicatorsOnItem: {
      type: Boolean,
      "default": false
    },
    indicatorsPosition: {
      type: String,
      "default": "bottom"
    },
    baseZIndex: {
      type: Number,
      "default": 0
    },
    maskClass: {
      type: String,
      "default": null
    },
    containerStyle: {
      type: null,
      "default": null
    },
    containerClass: {
      type: null,
      "default": null
    },
    containerProps: {
      type: null,
      "default": null
    },
    prevButtonProps: {
      type: null,
      "default": null
    },
    nextButtonProps: {
      type: null,
      "default": null
    },
    ariaLabel: {
      type: String,
      "default": null
    },
    ariaRoledescription: {
      type: String,
      "default": null
    }
  },
  style: GalleriaStyle,
  provide: /* @__PURE__ */ __name(function provide50() {
    return {
      $pcGalleria: this,
      $parentInstance: this
    };
  }, "provide")
};
function _toConsumableArray$1(r2) {
  return _arrayWithoutHoles$1(r2) || _iterableToArray$1(r2) || _unsupportedIterableToArray$1(r2) || _nonIterableSpread$1();
}
__name(_toConsumableArray$1, "_toConsumableArray$1");
function _nonIterableSpread$1() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread$1, "_nonIterableSpread$1");
function _unsupportedIterableToArray$1(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray$1(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray$1(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray$1, "_unsupportedIterableToArray$1");
function _iterableToArray$1(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray$1, "_iterableToArray$1");
function _arrayWithoutHoles$1(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray$1(r2);
}
__name(_arrayWithoutHoles$1, "_arrayWithoutHoles$1");
function _arrayLikeToArray$1(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray$1, "_arrayLikeToArray$1");
var script$3 = {
  name: "GalleriaItem",
  hostName: "Galleria",
  "extends": script$1b,
  emits: ["start-slideshow", "stop-slideshow", "update:activeIndex"],
  props: {
    circular: {
      type: Boolean,
      "default": false
    },
    activeIndex: {
      type: Number,
      "default": 0
    },
    value: {
      type: Array,
      "default": null
    },
    showItemNavigators: {
      type: Boolean,
      "default": true
    },
    showIndicators: {
      type: Boolean,
      "default": true
    },
    slideShowActive: {
      type: Boolean,
      "default": true
    },
    changeItemOnIndicatorHover: {
      type: Boolean,
      "default": true
    },
    autoPlay: {
      type: Boolean,
      "default": false
    },
    templates: {
      type: null,
      "default": null
    },
    id: {
      type: String,
      "default": null
    }
  },
  mounted: /* @__PURE__ */ __name(function mounted26() {
    if (this.autoPlay) {
      this.$emit("start-slideshow");
    }
  }, "mounted"),
  methods: {
    getIndicatorPTOptions: /* @__PURE__ */ __name(function getIndicatorPTOptions(index2) {
      return {
        context: {
          highlighted: this.activeIndex === index2
        }
      };
    }, "getIndicatorPTOptions"),
    next: /* @__PURE__ */ __name(function next() {
      var nextItemIndex = this.activeIndex + 1;
      var activeIndex3 = this.circular && this.value.length - 1 === this.activeIndex ? 0 : nextItemIndex;
      this.$emit("update:activeIndex", activeIndex3);
    }, "next"),
    prev: /* @__PURE__ */ __name(function prev() {
      var prevItemIndex = this.activeIndex !== 0 ? this.activeIndex - 1 : 0;
      var activeIndex3 = this.circular && this.activeIndex === 0 ? this.value.length - 1 : prevItemIndex;
      this.$emit("update:activeIndex", activeIndex3);
    }, "prev"),
    stopSlideShow: /* @__PURE__ */ __name(function stopSlideShow() {
      if (this.slideShowActive && this.stopSlideShow) {
        this.$emit("stop-slideshow");
      }
    }, "stopSlideShow"),
    navBackward: /* @__PURE__ */ __name(function navBackward(e2) {
      this.stopSlideShow();
      this.prev();
      if (e2 && e2.cancelable) {
        e2.preventDefault();
      }
    }, "navBackward"),
    navForward: /* @__PURE__ */ __name(function navForward(e2) {
      this.stopSlideShow();
      this.next();
      if (e2 && e2.cancelable) {
        e2.preventDefault();
      }
    }, "navForward"),
    onIndicatorClick: /* @__PURE__ */ __name(function onIndicatorClick(index2) {
      this.stopSlideShow();
      this.$emit("update:activeIndex", index2);
    }, "onIndicatorClick"),
    onIndicatorMouseEnter: /* @__PURE__ */ __name(function onIndicatorMouseEnter(index2) {
      if (this.changeItemOnIndicatorHover) {
        this.stopSlideShow();
        this.$emit("update:activeIndex", index2);
      }
    }, "onIndicatorMouseEnter"),
    onIndicatorKeyDown: /* @__PURE__ */ __name(function onIndicatorKeyDown(event, index2) {
      switch (event.code) {
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.stopSlideShow();
          this.$emit("update:activeIndex", index2);
          event.preventDefault();
          break;
        case "ArrowRight":
          this.onRightKey();
          break;
        case "ArrowLeft":
          this.onLeftKey();
          break;
        case "Home":
          this.onHomeKey();
          event.preventDefault();
          break;
        case "End":
          this.onEndKey();
          event.preventDefault();
          break;
        case "Tab":
          this.onTabKey();
          break;
        case "ArrowDown":
        case "ArrowUp":
        case "PageUp":
        case "PageDown":
          event.preventDefault();
          break;
      }
    }, "onIndicatorKeyDown"),
    onRightKey: /* @__PURE__ */ __name(function onRightKey() {
      var indicators = _toConsumableArray$1(find$2(this.$refs.indicatorContent, '[data-pc-section="indicator"]'));
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, activeIndex3 + 1 === indicators.length ? indicators.length - 1 : activeIndex3 + 1);
    }, "onRightKey"),
    onLeftKey: /* @__PURE__ */ __name(function onLeftKey() {
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, activeIndex3 - 1 <= 0 ? 0 : activeIndex3 - 1);
    }, "onLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey7() {
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, 0);
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey7() {
      var indicators = _toConsumableArray$1(find$2(this.$refs.indicatorContent, '[data-pc-section="indicator"]'));
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, indicators.length - 1);
    }, "onEndKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey7() {
      var indicators = _toConsumableArray$1(find$2(this.$refs.indicatorContent, '[data-pc-section="indicator"]'));
      var highlightedIndex = indicators.findIndex(function(ind) {
        return getAttribute$1(ind, "data-p-active") === true;
      });
      var activeIndicator = findSingle$1(this.$refs.indicatorContent, '[data-pc-section="indicator"] > [tabindex="0"]');
      var activeIndex3 = indicators.findIndex(function(ind) {
        return ind === activeIndicator.parentElement;
      });
      indicators[activeIndex3].children[0].tabIndex = "-1";
      indicators[highlightedIndex].children[0].tabIndex = "0";
    }, "onTabKey"),
    findFocusedIndicatorIndex: /* @__PURE__ */ __name(function findFocusedIndicatorIndex() {
      var indicators = _toConsumableArray$1(find$2(this.$refs.indicatorContent, '[data-pc-section="indicator"]'));
      var activeIndicator = findSingle$1(this.$refs.indicatorContent, '[data-pc-section="indicator"] > [tabindex="0"]');
      return indicators.findIndex(function(ind) {
        return ind === activeIndicator.parentElement;
      });
    }, "findFocusedIndicatorIndex"),
    changedFocusedIndicator: /* @__PURE__ */ __name(function changedFocusedIndicator(prevInd, nextInd) {
      var indicators = _toConsumableArray$1(find$2(this.$refs.indicatorContent, '[data-pc-section="indicator"]'));
      indicators[prevInd].children[0].tabIndex = "-1";
      indicators[nextInd].children[0].tabIndex = "0";
      indicators[nextInd].children[0].focus();
    }, "changedFocusedIndicator"),
    isIndicatorItemActive: /* @__PURE__ */ __name(function isIndicatorItemActive(index2) {
      return this.activeIndex === index2;
    }, "isIndicatorItemActive"),
    isNavBackwardDisabled: /* @__PURE__ */ __name(function isNavBackwardDisabled() {
      return !this.circular && this.activeIndex === 0;
    }, "isNavBackwardDisabled"),
    isNavForwardDisabled: /* @__PURE__ */ __name(function isNavForwardDisabled() {
      return !this.circular && this.activeIndex === this.value.length - 1;
    }, "isNavForwardDisabled"),
    ariaSlideNumber: /* @__PURE__ */ __name(function ariaSlideNumber(value3) {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.slideNumber.replace(/{slideNumber}/g, value3) : void 0;
    }, "ariaSlideNumber"),
    ariaPageLabel: /* @__PURE__ */ __name(function ariaPageLabel(value3) {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.pageLabel.replace(/{page}/g, value3) : void 0;
    }, "ariaPageLabel")
  },
  computed: {
    activeItem: /* @__PURE__ */ __name(function activeItem() {
      return this.value[this.activeIndex];
    }, "activeItem"),
    ariaSlideLabel: /* @__PURE__ */ __name(function ariaSlideLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.slide : void 0;
    }, "ariaSlideLabel")
  },
  components: {
    ChevronLeftIcon: script$x,
    ChevronRightIcon: script$w
  },
  directives: {
    ripple: Ripple
  }
};
var _hoisted_1$3$1 = ["disabled"];
var _hoisted_2$2$1 = ["id", "aria-label", "aria-roledescription"];
var _hoisted_3$2$1 = ["disabled"];
var _hoisted_4$1$1 = ["aria-label", "aria-selected", "aria-controls", "onClick", "onMouseenter", "onKeydown", "data-p-active"];
var _hoisted_5$2 = ["tabindex"];
function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("itemsContainer")
  }, _ctx.ptm("itemsContainer")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("items")
  }, _ctx.ptm("items")), [$props.showItemNavigators ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 0,
    type: "button",
    "class": _ctx.cx("prevButton"),
    onClick: _cache[0] || (_cache[0] = function($event) {
      return $options.navBackward($event);
    }),
    disabled: $options.isNavBackwardDisabled()
  }, _ctx.ptm("prevButton"), {
    "data-pc-group-section": "itemnavigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($props.templates.previousitemicon || "ChevronLeftIcon"), mergeProps$2({
    "class": _ctx.cx("prevIcon")
  }, _ctx.ptm("prevIcon")), null, 16, ["class"]))], 16, _hoisted_1$3$1)), [[_directive_ripple]]) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    id: $props.id + "_item_" + $props.activeIndex,
    "class": _ctx.cx("item"),
    role: "group",
    "aria-label": $options.ariaSlideNumber($props.activeIndex + 1),
    "aria-roledescription": $options.ariaSlideLabel
  }, _ctx.ptm("item")), [$props.templates.item ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.item), {
    key: 0,
    item: $options.activeItem
  }, null, 8, ["item"])) : createCommentVNode("", true)], 16, _hoisted_2$2$1), $props.showItemNavigators ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 1,
    type: "button",
    "class": _ctx.cx("nextButton"),
    onClick: _cache[1] || (_cache[1] = function($event) {
      return $options.navForward($event);
    }),
    disabled: $options.isNavForwardDisabled()
  }, _ctx.ptm("nextButton"), {
    "data-pc-group-section": "itemnavigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($props.templates.nextitemicon || "ChevronRightIcon"), mergeProps$2({
    "class": _ctx.cx("nextIcon")
  }, _ctx.ptm("nextIcon")), null, 16, ["class"]))], 16, _hoisted_3$2$1)), [[_directive_ripple]]) : createCommentVNode("", true), $props.templates["caption"] ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 2,
    "class": _ctx.cx("caption")
  }, _ctx.ptm("caption")), [$props.templates.caption ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.caption), {
    key: 0,
    item: $options.activeItem
  }, null, 8, ["item"])) : createCommentVNode("", true)], 16)) : createCommentVNode("", true)], 16), $props.showIndicators ? (openBlock(), createElementBlock("ul", mergeProps$2({
    key: 0,
    ref: "indicatorContent",
    "class": _ctx.cx("indicatorList")
  }, _ctx.ptm("indicatorList")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($props.value, function(item3, index2) {
    return openBlock(), createElementBlock("li", mergeProps$2({
      key: "p-galleria-indicator-".concat(index2),
      "class": _ctx.cx("indicator", {
        index: index2
      }),
      "aria-label": $options.ariaPageLabel(index2 + 1),
      "aria-selected": $props.activeIndex === index2,
      "aria-controls": $props.id + "_item_" + index2,
      onClick: /* @__PURE__ */ __name(function onClick5($event) {
        return $options.onIndicatorClick(index2);
      }, "onClick"),
      onMouseenter: /* @__PURE__ */ __name(function onMouseenter($event) {
        return $options.onIndicatorMouseEnter(index2);
      }, "onMouseenter"),
      onKeydown: /* @__PURE__ */ __name(function onKeydown4($event) {
        return $options.onIndicatorKeyDown($event, index2);
      }, "onKeydown"),
      ref_for: true
    }, _ctx.ptm("indicator", $options.getIndicatorPTOptions(index2)), {
      "data-p-active": $options.isIndicatorItemActive(index2)
    }), [!$props.templates["indicator"] ? (openBlock(), createElementBlock("button", mergeProps$2({
      key: 0,
      type: "button",
      tabindex: $props.activeIndex === index2 ? "0" : "-1",
      "class": _ctx.cx("indicatorButton"),
      ref_for: true
    }, _ctx.ptm("indicatorButton", $options.getIndicatorPTOptions(index2))), null, 16, _hoisted_5$2)) : createCommentVNode("", true), $props.templates.indicator ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.indicator), {
      key: 1,
      index: index2,
      activeIndex: $props.activeIndex,
      tabindex: $props.activeIndex === index2 ? "0" : "-1"
    }, null, 8, ["index", "activeIndex", "tabindex"])) : createCommentVNode("", true)], 16, _hoisted_4$1$1);
  }), 128))], 16)) : createCommentVNode("", true)], 16);
}
__name(render$3, "render$3");
script$3.render = render$3;
function _toConsumableArray(r2) {
  return _arrayWithoutHoles(r2) || _iterableToArray(r2) || _unsupportedIterableToArray(r2) || _nonIterableSpread();
}
__name(_toConsumableArray, "_toConsumableArray");
function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
__name(_nonIterableSpread, "_nonIterableSpread");
function _unsupportedIterableToArray(r2, a2) {
  if (r2) {
    if ("string" == typeof r2) return _arrayLikeToArray(r2, a2);
    var t2 = {}.toString.call(r2).slice(8, -1);
    return "Object" === t2 && r2.constructor && (t2 = r2.constructor.name), "Map" === t2 || "Set" === t2 ? Array.from(r2) : "Arguments" === t2 || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t2) ? _arrayLikeToArray(r2, a2) : void 0;
  }
}
__name(_unsupportedIterableToArray, "_unsupportedIterableToArray");
function _iterableToArray(r2) {
  if ("undefined" != typeof Symbol && null != r2[Symbol.iterator] || null != r2["@@iterator"]) return Array.from(r2);
}
__name(_iterableToArray, "_iterableToArray");
function _arrayWithoutHoles(r2) {
  if (Array.isArray(r2)) return _arrayLikeToArray(r2);
}
__name(_arrayWithoutHoles, "_arrayWithoutHoles");
function _arrayLikeToArray(r2, a2) {
  (null == a2 || a2 > r2.length) && (a2 = r2.length);
  for (var e2 = 0, n2 = Array(a2); e2 < a2; e2++) n2[e2] = r2[e2];
  return n2;
}
__name(_arrayLikeToArray, "_arrayLikeToArray");
var script$2 = {
  name: "GalleriaThumbnails",
  hostName: "Galleria",
  "extends": script$1b,
  emits: ["stop-slideshow", "update:activeIndex"],
  props: {
    containerId: {
      type: String,
      "default": null
    },
    value: {
      type: Array,
      "default": null
    },
    numVisible: {
      type: Number,
      "default": 3
    },
    activeIndex: {
      type: Number,
      "default": 0
    },
    isVertical: {
      type: Boolean,
      "default": false
    },
    slideShowActive: {
      type: Boolean,
      "default": false
    },
    circular: {
      type: Boolean,
      "default": false
    },
    responsiveOptions: {
      type: Array,
      "default": null
    },
    contentHeight: {
      type: String,
      "default": "300px"
    },
    showThumbnailNavigators: {
      type: Boolean,
      "default": true
    },
    templates: {
      type: null,
      "default": null
    },
    prevButtonProps: {
      type: null,
      "default": null
    },
    nextButtonProps: {
      type: null,
      "default": null
    }
  },
  startPos: null,
  thumbnailsStyle: null,
  sortedResponsiveOptions: null,
  data: /* @__PURE__ */ __name(function data26() {
    return {
      d_numVisible: this.numVisible,
      d_oldNumVisible: this.numVisible,
      d_activeIndex: this.activeIndex,
      d_oldActiveItemIndex: this.activeIndex,
      totalShiftedItems: 0,
      page: 0
    };
  }, "data"),
  watch: {
    numVisible: /* @__PURE__ */ __name(function numVisible(newValue2, oldValue) {
      this.d_numVisible = newValue2;
      this.d_oldNumVisible = oldValue;
    }, "numVisible"),
    activeIndex: /* @__PURE__ */ __name(function activeIndex2(newValue2, oldValue) {
      this.d_activeIndex = newValue2;
      this.d_oldActiveItemIndex = oldValue;
    }, "activeIndex")
  },
  mounted: /* @__PURE__ */ __name(function mounted27() {
    this.createStyle();
    this.calculatePosition();
    if (this.responsiveOptions) {
      this.bindDocumentListeners();
    }
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated14() {
    var totalShiftedItems = this.totalShiftedItems;
    if (this.d_oldNumVisible !== this.d_numVisible || this.d_oldActiveItemIndex !== this.d_activeIndex) {
      if (this.d_activeIndex <= this.getMedianItemIndex()) {
        totalShiftedItems = 0;
      } else if (this.value.length - this.d_numVisible + this.getMedianItemIndex() < this.d_activeIndex) {
        totalShiftedItems = this.d_numVisible - this.value.length;
      } else if (this.value.length - this.d_numVisible < this.d_activeIndex && this.d_numVisible % 2 === 0) {
        totalShiftedItems = this.d_activeIndex * -1 + this.getMedianItemIndex() + 1;
      } else {
        totalShiftedItems = this.d_activeIndex * -1 + this.getMedianItemIndex();
      }
      if (totalShiftedItems !== this.totalShiftedItems) {
        this.totalShiftedItems = totalShiftedItems;
      }
      this.$refs.itemsContainer.style.transform = this.isVertical ? "translate3d(0, ".concat(totalShiftedItems * (100 / this.d_numVisible), "%, 0)") : "translate3d(".concat(totalShiftedItems * (100 / this.d_numVisible), "%, 0, 0)");
      if (this.d_oldActiveItemIndex !== this.d_activeIndex) {
        document.body.setAttribute("data-p-items-hidden", "false");
        !this.isUnstyled && removeClass$1(this.$refs.itemsContainer, "p-items-hidden");
        this.$refs.itemsContainer.style.transition = "transform 500ms ease 0s";
      }
      this.d_oldActiveItemIndex = this.d_activeIndex;
      this.d_oldNumVisible = this.d_numVisible;
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount15() {
    if (this.responsiveOptions) {
      this.unbindDocumentListeners();
    }
    if (this.thumbnailsStyle) {
      this.thumbnailsStyle.parentNode.removeChild(this.thumbnailsStyle);
    }
  }, "beforeUnmount"),
  methods: {
    step: /* @__PURE__ */ __name(function step(dir) {
      var totalShiftedItems = this.totalShiftedItems + dir;
      if (dir < 0 && -1 * totalShiftedItems + this.d_numVisible > this.value.length - 1) {
        totalShiftedItems = this.d_numVisible - this.value.length;
      } else if (dir > 0 && totalShiftedItems > 0) {
        totalShiftedItems = 0;
      }
      if (this.circular) {
        if (dir < 0 && this.value.length - 1 === this.d_activeIndex) {
          totalShiftedItems = 0;
        } else if (dir > 0 && this.d_activeIndex === 0) {
          totalShiftedItems = this.d_numVisible - this.value.length;
        }
      }
      if (this.$refs.itemsContainer) {
        document.body.setAttribute("data-p-items-hidden", "false");
        !this.isUnstyled && removeClass$1(this.$refs.itemsContainer, "p-items-hidden");
        this.$refs.itemsContainer.style.transform = this.isVertical ? "translate3d(0, ".concat(totalShiftedItems * (100 / this.d_numVisible), "%, 0)") : "translate3d(".concat(totalShiftedItems * (100 / this.d_numVisible), "%, 0, 0)");
        this.$refs.itemsContainer.style.transition = "transform 500ms ease 0s";
      }
      this.totalShiftedItems = totalShiftedItems;
    }, "step"),
    stopSlideShow: /* @__PURE__ */ __name(function stopSlideShow2() {
      if (this.slideShowActive && this.stopSlideShow) {
        this.$emit("stop-slideshow");
      }
    }, "stopSlideShow"),
    getMedianItemIndex: /* @__PURE__ */ __name(function getMedianItemIndex() {
      var index2 = Math.floor(this.d_numVisible / 2);
      return this.d_numVisible % 2 ? index2 : index2 - 1;
    }, "getMedianItemIndex"),
    navBackward: /* @__PURE__ */ __name(function navBackward2(e2) {
      this.stopSlideShow();
      var prevItemIndex = this.d_activeIndex !== 0 ? this.d_activeIndex - 1 : 0;
      var diff2 = prevItemIndex + this.totalShiftedItems;
      if (this.d_numVisible - diff2 - 1 > this.getMedianItemIndex() && (-1 * this.totalShiftedItems !== 0 || this.circular)) {
        this.step(1);
      }
      var activeIndex3 = this.circular && this.d_activeIndex === 0 ? this.value.length - 1 : prevItemIndex;
      this.$emit("update:activeIndex", activeIndex3);
      if (e2.cancelable) {
        e2.preventDefault();
      }
    }, "navBackward"),
    navForward: /* @__PURE__ */ __name(function navForward2(e2) {
      this.stopSlideShow();
      var nextItemIndex = this.d_activeIndex === this.value.length - 1 ? this.value.length - 1 : this.d_activeIndex + 1;
      if (nextItemIndex + this.totalShiftedItems > this.getMedianItemIndex() && (-1 * this.totalShiftedItems < this.getTotalPageNumber() - 1 || this.circular)) {
        this.step(-1);
      }
      var activeIndex3 = this.circular && this.value.length - 1 === this.d_activeIndex ? 0 : nextItemIndex;
      this.$emit("update:activeIndex", activeIndex3);
      if (e2.cancelable) {
        e2.preventDefault();
      }
    }, "navForward"),
    onItemClick: /* @__PURE__ */ __name(function onItemClick4(index2) {
      this.stopSlideShow();
      var selectedItemIndex = index2;
      if (selectedItemIndex !== this.d_activeIndex) {
        var diff2 = selectedItemIndex + this.totalShiftedItems;
        var dir = 0;
        if (selectedItemIndex < this.d_activeIndex) {
          dir = this.d_numVisible - diff2 - 1 - this.getMedianItemIndex();
          if (dir > 0 && -1 * this.totalShiftedItems !== 0) {
            this.step(dir);
          }
        } else {
          dir = this.getMedianItemIndex() - diff2;
          if (dir < 0 && -1 * this.totalShiftedItems < this.getTotalPageNumber() - 1) {
            this.step(dir);
          }
        }
        this.$emit("update:activeIndex", selectedItemIndex);
      }
    }, "onItemClick"),
    onThumbnailKeydown: /* @__PURE__ */ __name(function onThumbnailKeydown(event, index2) {
      if (event.code === "Enter" || event.code === "NumpadEnter" || event.code === "Space") {
        this.onItemClick(index2);
        event.preventDefault();
      }
      switch (event.code) {
        case "ArrowRight":
          this.onRightKey();
          break;
        case "ArrowLeft":
          this.onLeftKey();
          break;
        case "Home":
          this.onHomeKey();
          event.preventDefault();
          break;
        case "End":
          this.onEndKey();
          event.preventDefault();
          break;
        case "ArrowUp":
        case "ArrowDown":
          event.preventDefault();
          break;
        case "Tab":
          this.onTabKey();
          break;
      }
    }, "onThumbnailKeydown"),
    onRightKey: /* @__PURE__ */ __name(function onRightKey2() {
      var indicators = find$2(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"]');
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, activeIndex3 + 1 === indicators.length ? indicators.length - 1 : activeIndex3 + 1);
    }, "onRightKey"),
    onLeftKey: /* @__PURE__ */ __name(function onLeftKey2() {
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, activeIndex3 - 1 <= 0 ? 0 : activeIndex3 - 1);
    }, "onLeftKey"),
    onHomeKey: /* @__PURE__ */ __name(function onHomeKey8() {
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, 0);
    }, "onHomeKey"),
    onEndKey: /* @__PURE__ */ __name(function onEndKey8() {
      var indicators = find$2(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"]');
      var activeIndex3 = this.findFocusedIndicatorIndex();
      this.changedFocusedIndicator(activeIndex3, indicators.length - 1);
    }, "onEndKey"),
    onTabKey: /* @__PURE__ */ __name(function onTabKey8() {
      var indicators = _toConsumableArray(find$2(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"]'));
      var highlightedIndex = indicators.findIndex(function(ind) {
        return getAttribute$1(ind, "data-p-active") === true;
      });
      var activeIndicator = findSingle$1(this.$refs.itemsContainer, '[tabindex="0"]');
      var activeIndex3 = indicators.findIndex(function(ind) {
        return ind === activeIndicator.parentElement;
      });
      indicators[activeIndex3].children[0].tabIndex = "-1";
      indicators[highlightedIndex].children[0].tabIndex = "0";
    }, "onTabKey"),
    findFocusedIndicatorIndex: /* @__PURE__ */ __name(function findFocusedIndicatorIndex2() {
      var indicators = _toConsumableArray(find$2(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"]'));
      var activeIndicator = findSingle$1(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"] > [tabindex="0"]');
      return indicators.findIndex(function(ind) {
        return ind === activeIndicator.parentElement;
      });
    }, "findFocusedIndicatorIndex"),
    changedFocusedIndicator: /* @__PURE__ */ __name(function changedFocusedIndicator2(prevInd, nextInd) {
      var indicators = find$2(this.$refs.itemsContainer, '[data-pc-section="thumbnailitem"]');
      indicators[prevInd].children[0].tabIndex = "-1";
      indicators[nextInd].children[0].tabIndex = "0";
      indicators[nextInd].children[0].focus();
    }, "changedFocusedIndicator"),
    onTransitionEnd: /* @__PURE__ */ __name(function onTransitionEnd(e2) {
      if (this.$refs.itemsContainer && e2.propertyName === "transform") {
        document.body.setAttribute("data-p-items-hidden", "true");
        !this.isUnstyled && addClass$1(this.$refs.itemsContainer, "p-items-hidden");
        this.$refs.itemsContainer.style.transition = "";
      }
    }, "onTransitionEnd"),
    onTouchStart: /* @__PURE__ */ __name(function onTouchStart2(e2) {
      var touchobj = e2.changedTouches[0];
      this.startPos = {
        x: touchobj.pageX,
        y: touchobj.pageY
      };
    }, "onTouchStart"),
    onTouchMove: /* @__PURE__ */ __name(function onTouchMove2(e2) {
      if (e2.cancelable) {
        e2.preventDefault();
      }
    }, "onTouchMove"),
    onTouchEnd: /* @__PURE__ */ __name(function onTouchEnd3(e2) {
      var touchobj = e2.changedTouches[0];
      if (this.isVertical) {
        this.changePageOnTouch(e2, touchobj.pageY - this.startPos.y);
      } else {
        this.changePageOnTouch(e2, touchobj.pageX - this.startPos.x);
      }
    }, "onTouchEnd"),
    changePageOnTouch: /* @__PURE__ */ __name(function changePageOnTouch(e2, diff2) {
      if (diff2 < 0) {
        this.navForward(e2);
      } else {
        this.navBackward(e2);
      }
    }, "changePageOnTouch"),
    getTotalPageNumber: /* @__PURE__ */ __name(function getTotalPageNumber() {
      return this.value.length > this.d_numVisible ? this.value.length - this.d_numVisible + 1 : 0;
    }, "getTotalPageNumber"),
    createStyle: /* @__PURE__ */ __name(function createStyle3() {
      if (!this.thumbnailsStyle) {
        var _this$$primevue;
        this.thumbnailsStyle = document.createElement("style");
        this.thumbnailsStyle.type = "text/css";
        setAttribute$1(this.thumbnailsStyle, "nonce", (_this$$primevue = this.$primevue) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.config) === null || _this$$primevue === void 0 || (_this$$primevue = _this$$primevue.csp) === null || _this$$primevue === void 0 ? void 0 : _this$$primevue.nonce);
        document.body.appendChild(this.thumbnailsStyle);
      }
      var innerHTML = "\n                #".concat(this.containerId, ' [data-pc-section="thumbnailitem"] {\n                    flex: 1 0 ').concat(100 / this.d_numVisible, "%\n                }\n            ");
      if (this.responsiveOptions && !this.isUnstyled) {
        this.sortedResponsiveOptions = _toConsumableArray(this.responsiveOptions);
        var comparer = localeComparator$2();
        this.sortedResponsiveOptions.sort(function(data1, data210) {
          var value1 = data1.breakpoint;
          var value22 = data210.breakpoint;
          return sort$2(value1, value22, -1, comparer);
        });
        for (var i2 = 0; i2 < this.sortedResponsiveOptions.length; i2++) {
          var res = this.sortedResponsiveOptions[i2];
          innerHTML += "\n                        @media screen and (max-width: ".concat(res.breakpoint, ") {\n                            #").concat(this.containerId, " .p-galleria-thumbnail-item {\n                                flex: 1 0 ").concat(100 / res.numVisible, "%\n                            }\n                        }\n                    ");
        }
      }
      this.thumbnailsStyle.innerHTML = innerHTML;
    }, "createStyle"),
    calculatePosition: /* @__PURE__ */ __name(function calculatePosition() {
      if (this.$refs.itemsContainer && this.sortedResponsiveOptions) {
        var windowWidth = window.innerWidth;
        var matchedResponsiveData = {
          numVisible: this.numVisible
        };
        for (var i2 = 0; i2 < this.sortedResponsiveOptions.length; i2++) {
          var res = this.sortedResponsiveOptions[i2];
          if (parseInt(res.breakpoint, 10) >= windowWidth) {
            matchedResponsiveData = res;
          }
        }
        if (this.d_numVisible !== matchedResponsiveData.numVisible) {
          this.d_numVisible = matchedResponsiveData.numVisible;
        }
      }
    }, "calculatePosition"),
    bindDocumentListeners: /* @__PURE__ */ __name(function bindDocumentListeners() {
      var _this = this;
      if (!this.documentResizeListener) {
        this.documentResizeListener = function() {
          _this.calculatePosition();
        };
        window.addEventListener("resize", this.documentResizeListener);
      }
    }, "bindDocumentListeners"),
    unbindDocumentListeners: /* @__PURE__ */ __name(function unbindDocumentListeners() {
      if (this.documentResizeListener) {
        window.removeEventListener("resize", this.documentResizeListener);
        this.documentResizeListener = null;
      }
    }, "unbindDocumentListeners"),
    isNavBackwardDisabled: /* @__PURE__ */ __name(function isNavBackwardDisabled2() {
      return !this.circular && this.d_activeIndex === 0 || this.value.length <= this.d_numVisible;
    }, "isNavBackwardDisabled"),
    isNavForwardDisabled: /* @__PURE__ */ __name(function isNavForwardDisabled2() {
      return !this.circular && this.d_activeIndex === this.value.length - 1 || this.value.length <= this.d_numVisible;
    }, "isNavForwardDisabled"),
    firstItemAciveIndex: /* @__PURE__ */ __name(function firstItemAciveIndex() {
      return this.totalShiftedItems * -1;
    }, "firstItemAciveIndex"),
    lastItemActiveIndex: /* @__PURE__ */ __name(function lastItemActiveIndex() {
      return this.firstItemAciveIndex() + this.d_numVisible - 1;
    }, "lastItemActiveIndex"),
    isItemActive: /* @__PURE__ */ __name(function isItemActive2(index2) {
      return this.firstItemAciveIndex() <= index2 && this.lastItemActiveIndex() >= index2;
    }, "isItemActive"),
    ariaPageLabel: /* @__PURE__ */ __name(function ariaPageLabel2(value3) {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.pageLabel.replace(/{page}/g, value3) : void 0;
    }, "ariaPageLabel")
  },
  computed: {
    ariaPrevButtonLabel: /* @__PURE__ */ __name(function ariaPrevButtonLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.prevPageLabel : void 0;
    }, "ariaPrevButtonLabel"),
    ariaNextButtonLabel: /* @__PURE__ */ __name(function ariaNextButtonLabel() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.nextPageLabel : void 0;
    }, "ariaNextButtonLabel")
  },
  components: {
    ChevronLeftIcon: script$x,
    ChevronRightIcon: script$w,
    ChevronUpIcon: script$6,
    ChevronDownIcon: script$u
  },
  directives: {
    ripple: Ripple
  }
};
function _typeof$2(o2) {
  "@babel/helpers - typeof";
  return _typeof$2 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$2(o2);
}
__name(_typeof$2, "_typeof$2");
function ownKeys$2(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$2, "ownKeys$2");
function _objectSpread$2(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$2(Object(t2), true).forEach(function(r3) {
      _defineProperty$2(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$2(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$2, "_objectSpread$2");
function _defineProperty$2(e2, r2, t2) {
  return (r2 = _toPropertyKey$2(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$2, "_defineProperty$2");
function _toPropertyKey$2(t2) {
  var i2 = _toPrimitive$2(t2, "string");
  return "symbol" == _typeof$2(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$2, "_toPropertyKey$2");
function _toPrimitive$2(t2, r2) {
  if ("object" != _typeof$2(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$2(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$2, "_toPrimitive$2");
var _hoisted_1$2$1 = ["disabled", "aria-label"];
var _hoisted_2$1$1 = ["data-p-active", "aria-selected", "aria-controls", "onKeydown", "data-p-galleria-thumbnail-item-current", "data-p-galleria-thumbnail-item-active", "data-p-galleria-thumbnail-item-start", "data-p-galleria-thumbnail-item-end"];
var _hoisted_3$1$1 = ["tabindex", "aria-label", "aria-current", "onClick"];
var _hoisted_4$2 = ["disabled", "aria-label"];
function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  var _directive_ripple = resolveDirective("ripple");
  return openBlock(), createElementBlock("div", mergeProps$2({
    "class": _ctx.cx("thumbnails")
  }, _ctx.ptm("thumbnails")), [createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("thumbnailContent")
  }, _ctx.ptm("thumbnailContent")), [$props.showThumbnailNavigators ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 0,
    "class": _ctx.cx("thumbnailPrevButton"),
    disabled: $options.isNavBackwardDisabled(),
    type: "button",
    "aria-label": $options.ariaPrevButtonLabel,
    onClick: _cache[0] || (_cache[0] = function($event) {
      return $options.navBackward($event);
    })
  }, _objectSpread$2(_objectSpread$2({}, $props.prevButtonProps), _ctx.ptm("thumbnailPrevButton")), {
    "data-pc-group-section": "thumbnailnavigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($props.templates.previousthumbnailicon || ($props.isVertical ? "ChevronUpIcon" : "ChevronLeftIcon")), mergeProps$2({
    "class": _ctx.cx("thumbnailPrevIcon")
  }, _ctx.ptm("thumbnailPrevIcon")), null, 16, ["class"]))], 16, _hoisted_1$2$1)), [[_directive_ripple]]) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("thumbnailsViewport"),
    style: {
      height: $props.isVertical ? $props.contentHeight : ""
    }
  }, _ctx.ptm("thumbnailsViewport")), [createBaseVNode("div", mergeProps$2({
    ref: "itemsContainer",
    "class": _ctx.cx("thumbnailItems"),
    role: "tablist",
    onTransitionend: _cache[1] || (_cache[1] = function($event) {
      return $options.onTransitionEnd($event);
    }),
    onTouchstart: _cache[2] || (_cache[2] = function($event) {
      return $options.onTouchStart($event);
    }),
    onTouchmove: _cache[3] || (_cache[3] = function($event) {
      return $options.onTouchMove($event);
    }),
    onTouchend: _cache[4] || (_cache[4] = function($event) {
      return $options.onTouchEnd($event);
    })
  }, _ctx.ptm("thumbnailItems")), [(openBlock(true), createElementBlock(Fragment$1, null, renderList($props.value, function(item3, index2) {
    return openBlock(), createElementBlock("div", mergeProps$2({
      key: "p-galleria-thumbnail-item-".concat(index2),
      "class": _ctx.cx("thumbnailItem", {
        index: index2,
        activeIndex: $props.activeIndex
      }),
      role: "tab",
      "data-p-active": $props.activeIndex === index2,
      "aria-selected": $props.activeIndex === index2,
      "aria-controls": $props.containerId + "_item_" + index2,
      onKeydown: /* @__PURE__ */ __name(function onKeydown4($event) {
        return $options.onThumbnailKeydown($event, index2);
      }, "onKeydown"),
      ref_for: true
    }, _ctx.ptm("thumbnailItem"), {
      "data-p-galleria-thumbnail-item-current": $props.activeIndex === index2,
      "data-p-galleria-thumbnail-item-active": $options.isItemActive(index2),
      "data-p-galleria-thumbnail-item-start": $options.firstItemAciveIndex() === index2,
      "data-p-galleria-thumbnail-item-end": $options.lastItemActiveIndex() === index2
    }), [createBaseVNode("div", mergeProps$2({
      "class": _ctx.cx("thumbnail"),
      tabindex: $props.activeIndex === index2 ? "0" : "-1",
      "aria-label": $options.ariaPageLabel(index2 + 1),
      "aria-current": $props.activeIndex === index2 ? "page" : void 0,
      onClick: /* @__PURE__ */ __name(function onClick5($event) {
        return $options.onItemClick(index2);
      }, "onClick"),
      ref_for: true
    }, _ctx.ptm("thumbnail")), [$props.templates.thumbnail ? (openBlock(), createBlock(resolveDynamicComponent($props.templates.thumbnail), {
      key: 0,
      item: item3
    }, null, 8, ["item"])) : createCommentVNode("", true)], 16, _hoisted_3$1$1)], 16, _hoisted_2$1$1);
  }), 128))], 16)], 16), $props.showThumbnailNavigators ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 1,
    "class": _ctx.cx("thumbnailNextButton"),
    disabled: $options.isNavForwardDisabled(),
    type: "button",
    "aria-label": $options.ariaNextButtonLabel,
    onClick: _cache[5] || (_cache[5] = function($event) {
      return $options.navForward($event);
    })
  }, _objectSpread$2(_objectSpread$2({}, $props.nextButtonProps), _ctx.ptm("thumbnailNextButton")), {
    "data-pc-group-section": "thumbnailnavigator"
  }), [(openBlock(), createBlock(resolveDynamicComponent($props.templates.nextthumbnailicon || ($props.isVertical ? "ChevronDownIcon" : "ChevronRightIcon")), mergeProps$2({
    "class": _ctx.cx("thumbnailNextIcon")
  }, _ctx.ptm("thumbnailNextIcon")), null, 16, ["class"]))], 16, _hoisted_4$2)), [[_directive_ripple]]) : createCommentVNode("", true)], 16)], 16);
}
__name(render$2, "render$2");
script$2.render = render$2;
function _typeof$1(o2) {
  "@babel/helpers - typeof";
  return _typeof$1 = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof$1(o2);
}
__name(_typeof$1, "_typeof$1");
function ownKeys$1(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys$1, "ownKeys$1");
function _objectSpread$1(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys$1(Object(t2), true).forEach(function(r3) {
      _defineProperty$1(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys$1(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread$1, "_objectSpread$1");
function _defineProperty$1(e2, r2, t2) {
  return (r2 = _toPropertyKey$1(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty$1, "_defineProperty$1");
function _toPropertyKey$1(t2) {
  var i2 = _toPrimitive$1(t2, "string");
  return "symbol" == _typeof$1(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey$1, "_toPropertyKey$1");
function _toPrimitive$1(t2, r2) {
  if ("object" != _typeof$1(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof$1(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive$1, "_toPrimitive$1");
var script$1$1 = {
  name: "GalleriaContent",
  hostName: "Galleria",
  "extends": script$1b,
  inheritAttrs: false,
  interval: null,
  emits: ["activeitem-change", "mask-hide"],
  data: /* @__PURE__ */ __name(function data27() {
    return {
      id: this.$attrs.id || UniqueComponentId(),
      activeIndex: this.$attrs.activeIndex,
      numVisible: this.$attrs.numVisible,
      slideShowActive: false
    };
  }, "data"),
  watch: {
    "$attrs.id": /* @__PURE__ */ __name(function $attrsId11(newValue2) {
      this.id = newValue2 || UniqueComponentId();
    }, "$attrsId"),
    "$attrs.value": /* @__PURE__ */ __name(function $attrsValue(newVal) {
      if (newVal && newVal.length < this.numVisible) {
        this.numVisible = newVal.length;
      }
    }, "$attrsValue"),
    "$attrs.activeIndex": /* @__PURE__ */ __name(function $attrsActiveIndex(newVal) {
      this.activeIndex = newVal;
    }, "$attrsActiveIndex"),
    "$attrs.numVisible": /* @__PURE__ */ __name(function $attrsNumVisible(newVal) {
      this.numVisible = newVal;
    }, "$attrsNumVisible"),
    "$attrs.autoPlay": /* @__PURE__ */ __name(function $attrsAutoPlay(newVal) {
      newVal ? this.startSlideShow() : this.stopSlideShow();
    }, "$attrsAutoPlay")
  },
  mounted: /* @__PURE__ */ __name(function mounted28() {
    this.id = this.id || UniqueComponentId();
  }, "mounted"),
  updated: /* @__PURE__ */ __name(function updated15() {
    this.$emit("activeitem-change", this.activeIndex);
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount16() {
    if (this.slideShowActive) {
      this.stopSlideShow();
    }
  }, "beforeUnmount"),
  methods: {
    getPTOptions: /* @__PURE__ */ __name(function getPTOptions10(key) {
      return this.ptm(key, {
        props: _objectSpread$1(_objectSpread$1({}, this.$attrs), {}, {
          pt: this.pt,
          unstyled: this.unstyled
        })
      });
    }, "getPTOptions"),
    isAutoPlayActive: /* @__PURE__ */ __name(function isAutoPlayActive() {
      return this.slideShowActive;
    }, "isAutoPlayActive"),
    startSlideShow: /* @__PURE__ */ __name(function startSlideShow() {
      var _this = this;
      this.interval = setInterval(function() {
        var activeIndex3 = _this.$attrs.circular && _this.$attrs.value.length - 1 === _this.activeIndex ? 0 : _this.activeIndex + 1;
        _this.activeIndex = activeIndex3;
      }, this.$attrs.transitionInterval);
      this.slideShowActive = true;
    }, "startSlideShow"),
    stopSlideShow: /* @__PURE__ */ __name(function stopSlideShow3() {
      if (this.interval) {
        clearInterval(this.interval);
      }
      this.slideShowActive = false;
    }, "stopSlideShow"),
    getPositionClass: /* @__PURE__ */ __name(function getPositionClass(preClassName, position3) {
      var positions = ["top", "left", "bottom", "right"];
      var pos = positions.find(function(item3) {
        return item3 === position3;
      });
      return pos ? "".concat(preClassName, "-").concat(pos) : "";
    }, "getPositionClass"),
    isVertical: /* @__PURE__ */ __name(function isVertical3() {
      return this.$attrs.thumbnailsPosition === "left" || this.$attrs.thumbnailsPosition === "right";
    }, "isVertical")
  },
  computed: {
    closeAriaLabel: /* @__PURE__ */ __name(function closeAriaLabel3() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.close : void 0;
    }, "closeAriaLabel")
  },
  components: {
    GalleriaItem: script$3,
    GalleriaThumbnails: script$2,
    TimesIcon: script$15
  },
  directives: {
    ripple: Ripple
  }
};
function _typeof(o2) {
  "@babel/helpers - typeof";
  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function(o3) {
    return typeof o3;
  } : function(o3) {
    return o3 && "function" == typeof Symbol && o3.constructor === Symbol && o3 !== Symbol.prototype ? "symbol" : typeof o3;
  }, _typeof(o2);
}
__name(_typeof, "_typeof");
function ownKeys(e2, r2) {
  var t2 = Object.keys(e2);
  if (Object.getOwnPropertySymbols) {
    var o2 = Object.getOwnPropertySymbols(e2);
    r2 && (o2 = o2.filter(function(r3) {
      return Object.getOwnPropertyDescriptor(e2, r3).enumerable;
    })), t2.push.apply(t2, o2);
  }
  return t2;
}
__name(ownKeys, "ownKeys");
function _objectSpread(e2) {
  for (var r2 = 1; r2 < arguments.length; r2++) {
    var t2 = null != arguments[r2] ? arguments[r2] : {};
    r2 % 2 ? ownKeys(Object(t2), true).forEach(function(r3) {
      _defineProperty(e2, r3, t2[r3]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e2, Object.getOwnPropertyDescriptors(t2)) : ownKeys(Object(t2)).forEach(function(r3) {
      Object.defineProperty(e2, r3, Object.getOwnPropertyDescriptor(t2, r3));
    });
  }
  return e2;
}
__name(_objectSpread, "_objectSpread");
function _defineProperty(e2, r2, t2) {
  return (r2 = _toPropertyKey(r2)) in e2 ? Object.defineProperty(e2, r2, { value: t2, enumerable: true, configurable: true, writable: true }) : e2[r2] = t2, e2;
}
__name(_defineProperty, "_defineProperty");
function _toPropertyKey(t2) {
  var i2 = _toPrimitive(t2, "string");
  return "symbol" == _typeof(i2) ? i2 : i2 + "";
}
__name(_toPropertyKey, "_toPropertyKey");
function _toPrimitive(t2, r2) {
  if ("object" != _typeof(t2) || !t2) return t2;
  var e2 = t2[Symbol.toPrimitive];
  if (void 0 !== e2) {
    var i2 = e2.call(t2, r2 || "default");
    if ("object" != _typeof(i2)) return i2;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r2 ? String : Number)(t2);
}
__name(_toPrimitive, "_toPrimitive");
var _hoisted_1$1$1 = ["id", "aria-label", "aria-roledescription"];
var _hoisted_2$7 = ["aria-label"];
var _hoisted_3$4 = ["aria-live"];
function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_GalleriaItem = resolveComponent("GalleriaItem");
  var _component_GalleriaThumbnails = resolveComponent("GalleriaThumbnails");
  var _directive_ripple = resolveDirective("ripple");
  return _ctx.$attrs.value && _ctx.$attrs.value.length > 0 ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 0,
    id: $data.id,
    role: "region",
    "class": [_ctx.cx("root"), _ctx.$attrs.containerClass],
    style: _ctx.$attrs.containerStyle,
    "aria-label": _ctx.$attrs.ariaLabel,
    "aria-roledescription": _ctx.$attrs.ariaRoledescription
  }, _objectSpread(_objectSpread({}, _ctx.$attrs.containerProps), $options.getPTOptions("root"))), [_ctx.$attrs.fullScreen ? withDirectives((openBlock(), createElementBlock("button", mergeProps$2({
    key: 0,
    autofocus: "",
    type: "button",
    "class": _ctx.cx("closeButton"),
    "aria-label": $options.closeAriaLabel,
    onClick: _cache[0] || (_cache[0] = function($event) {
      return _ctx.$emit("mask-hide");
    })
  }, $options.getPTOptions("closeButton")), [(openBlock(), createBlock(resolveDynamicComponent(_ctx.$attrs.templates["closeicon"] || "TimesIcon"), mergeProps$2({
    "class": _ctx.cx("closeIcon")
  }, $options.getPTOptions("closeIcon")), null, 16, ["class"]))], 16, _hoisted_2$7)), [[_directive_ripple]]) : createCommentVNode("", true), _ctx.$attrs.templates && _ctx.$attrs.templates["header"] ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 1,
    "class": _ctx.cx("header")
  }, $options.getPTOptions("header")), [(openBlock(), createBlock(resolveDynamicComponent(_ctx.$attrs.templates["header"])))], 16)) : createCommentVNode("", true), createBaseVNode("div", mergeProps$2({
    "class": _ctx.cx("content"),
    "aria-live": _ctx.$attrs.autoPlay ? "polite" : "off"
  }, $options.getPTOptions("content")), [createVNode(_component_GalleriaItem, {
    id: $data.id,
    activeIndex: $data.activeIndex,
    "onUpdate:activeIndex": _cache[1] || (_cache[1] = function($event) {
      return $data.activeIndex = $event;
    }),
    slideShowActive: $data.slideShowActive,
    "onUpdate:slideShowActive": _cache[2] || (_cache[2] = function($event) {
      return $data.slideShowActive = $event;
    }),
    value: _ctx.$attrs.value,
    circular: _ctx.$attrs.circular,
    templates: _ctx.$attrs.templates,
    showIndicators: _ctx.$attrs.showIndicators,
    changeItemOnIndicatorHover: _ctx.$attrs.changeItemOnIndicatorHover,
    showItemNavigators: _ctx.$attrs.showItemNavigators,
    autoPlay: _ctx.$attrs.autoPlay,
    onStartSlideshow: $options.startSlideShow,
    onStopSlideshow: $options.stopSlideShow,
    pt: _ctx.pt,
    unstyled: _ctx.unstyled
  }, null, 8, ["id", "activeIndex", "slideShowActive", "value", "circular", "templates", "showIndicators", "changeItemOnIndicatorHover", "showItemNavigators", "autoPlay", "onStartSlideshow", "onStopSlideshow", "pt", "unstyled"]), _ctx.$attrs.showThumbnails ? (openBlock(), createBlock(_component_GalleriaThumbnails, {
    key: 0,
    activeIndex: $data.activeIndex,
    "onUpdate:activeIndex": _cache[3] || (_cache[3] = function($event) {
      return $data.activeIndex = $event;
    }),
    slideShowActive: $data.slideShowActive,
    "onUpdate:slideShowActive": _cache[4] || (_cache[4] = function($event) {
      return $data.slideShowActive = $event;
    }),
    containerId: $data.id,
    value: _ctx.$attrs.value,
    templates: _ctx.$attrs.templates,
    numVisible: $data.numVisible,
    responsiveOptions: _ctx.$attrs.responsiveOptions,
    circular: _ctx.$attrs.circular,
    isVertical: $options.isVertical(),
    contentHeight: _ctx.$attrs.verticalThumbnailViewPortHeight,
    showThumbnailNavigators: _ctx.$attrs.showThumbnailNavigators,
    prevButtonProps: _ctx.$attrs.prevButtonProps,
    nextButtonProps: _ctx.$attrs.nextButtonProps,
    onStopSlideshow: $options.stopSlideShow,
    pt: _ctx.pt,
    unstyled: _ctx.unstyled
  }, null, 8, ["activeIndex", "slideShowActive", "containerId", "value", "templates", "numVisible", "responsiveOptions", "circular", "isVertical", "contentHeight", "showThumbnailNavigators", "prevButtonProps", "nextButtonProps", "onStopSlideshow", "pt", "unstyled"])) : createCommentVNode("", true)], 16, _hoisted_3$4), _ctx.$attrs.templates && _ctx.$attrs.templates["footer"] ? (openBlock(), createElementBlock("div", mergeProps$2({
    key: 2,
    "class": _ctx.cx("footer")
  }, $options.getPTOptions("footer")), [(openBlock(), createBlock(resolveDynamicComponent(_ctx.$attrs.templates["footer"])))], 16)) : createCommentVNode("", true)], 16, _hoisted_1$1$1)) : createCommentVNode("", true);
}
__name(render$1, "render$1");
script$1$1.render = render$1;
var script$5 = {
  name: "Galleria",
  "extends": script$4,
  inheritAttrs: false,
  emits: ["update:activeIndex", "update:visible"],
  container: null,
  mask: null,
  data: /* @__PURE__ */ __name(function data28() {
    return {
      containerVisible: this.visible
    };
  }, "data"),
  updated: /* @__PURE__ */ __name(function updated16() {
    if (this.fullScreen && this.visible) {
      this.containerVisible = this.visible;
    }
  }, "updated"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount17() {
    if (this.fullScreen) {
      unblockBodyScroll$1();
    }
    this.mask = null;
    if (this.container) {
      ZIndex$1.clear(this.container);
      this.container = null;
    }
  }, "beforeUnmount"),
  methods: {
    onBeforeEnter: /* @__PURE__ */ __name(function onBeforeEnter(el) {
      ZIndex$1.set("modal", el, this.baseZIndex || this.$primevue.config.zIndex.modal);
    }, "onBeforeEnter"),
    onEnter: /* @__PURE__ */ __name(function onEnter6(el) {
      this.mask.style.zIndex = String(parseInt(el.style.zIndex, 10) - 1);
      blockBodyScroll$1();
      this.focus();
    }, "onEnter"),
    onBeforeLeave: /* @__PURE__ */ __name(function onBeforeLeave2() {
      !this.isUnstyled && addClass$1(this.mask, "p-overlay-mask-leave");
    }, "onBeforeLeave"),
    onAfterLeave: /* @__PURE__ */ __name(function onAfterLeave5(el) {
      ZIndex$1.clear(el);
      this.containerVisible = false;
      unblockBodyScroll$1();
    }, "onAfterLeave"),
    onActiveItemChange: /* @__PURE__ */ __name(function onActiveItemChange(index2) {
      if (this.activeIndex !== index2) {
        this.$emit("update:activeIndex", index2);
      }
    }, "onActiveItemChange"),
    maskHide: /* @__PURE__ */ __name(function maskHide() {
      this.$emit("update:visible", false);
    }, "maskHide"),
    containerRef: /* @__PURE__ */ __name(function containerRef5(el) {
      this.container = el;
    }, "containerRef"),
    maskRef: /* @__PURE__ */ __name(function maskRef2(el) {
      this.mask = el;
    }, "maskRef"),
    focus: /* @__PURE__ */ __name(function focus4() {
      var focusTarget = this.container.$el.querySelector("[autofocus]");
      if (focusTarget) {
        focusTarget.focus();
      }
    }, "focus")
  },
  components: {
    GalleriaContent: script$1$1,
    Portal: script$$
  },
  directives: {
    focustrap: FocusTrap
  }
};
var _hoisted_1$7 = ["aria-modal"];
function render$4(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_GalleriaContent = resolveComponent("GalleriaContent");
  var _component_Portal = resolveComponent("Portal");
  var _directive_focustrap = resolveDirective("focustrap");
  return _ctx.fullScreen ? (openBlock(), createBlock(_component_Portal, {
    key: 0
  }, {
    "default": withCtx(function() {
      return [$data.containerVisible ? (openBlock(), createElementBlock("div", mergeProps$2({
        key: 0,
        ref: $options.maskRef,
        "class": [_ctx.cx("mask"), _ctx.maskClass],
        role: "dialog",
        "aria-modal": _ctx.fullScreen ? "true" : void 0
      }, _ctx.ptm("mask")), [createVNode(Transition, mergeProps$2({
        name: "p-galleria",
        onBeforeEnter: $options.onBeforeEnter,
        onEnter: $options.onEnter,
        onBeforeLeave: $options.onBeforeLeave,
        onAfterLeave: $options.onAfterLeave,
        appear: ""
      }, _ctx.ptm("transition")), {
        "default": withCtx(function() {
          return [_ctx.visible ? withDirectives((openBlock(), createBlock(_component_GalleriaContent, mergeProps$2({
            key: 0,
            ref: $options.containerRef,
            onMaskHide: $options.maskHide,
            templates: _ctx.$slots,
            onActiveitemChange: $options.onActiveItemChange,
            pt: _ctx.pt,
            unstyled: _ctx.unstyled
          }, _ctx.$props), null, 16, ["onMaskHide", "templates", "onActiveitemChange", "pt", "unstyled"])), [[_directive_focustrap]]) : createCommentVNode("", true)];
        }),
        _: 1
      }, 16, ["onBeforeEnter", "onEnter", "onBeforeLeave", "onAfterLeave"])], 16, _hoisted_1$7)) : createCommentVNode("", true)];
    }),
    _: 1
  })) : (openBlock(), createBlock(_component_GalleriaContent, mergeProps$2({
    key: 1,
    templates: _ctx.$slots,
    onActiveitemChange: $options.onActiveItemChange,
    pt: _ctx.pt,
    unstyled: _ctx.unstyled
  }, _ctx.$props), null, 16, ["templates", "onActiveitemChange", "pt", "unstyled"]));
}
__name(render$4, "render$4");
script$5.render = render$4;
const _hoisted_1$6 = ["src", "data-test", "alt"];
const _hoisted_2$6 = ["src", "alt"];
const _hoisted_3$3 = {
  key: 1,
  class: "broken-image-placeholder"
};
const _sfc_main$9 = /* @__PURE__ */ defineComponent({
  __name: "ComfyImage",
  props: {
    src: {},
    class: {},
    contain: { type: Boolean, default: false },
    alt: { default: "Image content" }
  },
  setup(__props) {
    const imageBroken = ref(false);
    const handleImageError = /* @__PURE__ */ __name(() => {
      imageBroken.value = true;
    }, "handleImageError");
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment$1, null, [
        !imageBroken.value ? (openBlock(), createElementBlock("span", {
          key: 0,
          class: normalizeClass(["comfy-image-wrap", [{ contain: _ctx.contain }]])
        }, [
          _ctx.contain ? (openBlock(), createElementBlock("img", {
            key: 0,
            src: _ctx.src,
            onError: handleImageError,
            "data-test": _ctx.src,
            class: "comfy-image-blur",
            style: normalizeStyle({ "background-image": `url(${_ctx.src})` }),
            alt: _ctx.alt
          }, null, 44, _hoisted_1$6)) : createCommentVNode("", true),
          createBaseVNode("img", {
            src: _ctx.src,
            onError: handleImageError,
            class: normalizeClass(["comfy-image-main", __props.class]),
            alt: _ctx.alt
          }, null, 42, _hoisted_2$6)
        ], 2)) : createCommentVNode("", true),
        imageBroken.value ? (openBlock(), createElementBlock("div", _hoisted_3$3, [
          _cache[0] || (_cache[0] = createBaseVNode("i", { class: "pi pi-image" }, null, -1)),
          createBaseVNode("span", null, toDisplayString$1(_ctx.$t("g.imageFailedToLoad")), 1)
        ])) : createCommentVNode("", true)
      ], 64);
    };
  }
});
const ComfyImage = /* @__PURE__ */ _export_sfc(_sfc_main$9, [["__scopeId", "data-v-e027b498"]]);
const _hoisted_1$5 = {
  controls: "",
  width: "100%",
  height: "100%"
};
const _hoisted_2$5 = ["src", "type"];
const _sfc_main$8 = /* @__PURE__ */ defineComponent({
  __name: "ResultVideo",
  props: {
    result: {}
  },
  setup(__props) {
    const props = __props;
    const settingStore = useSettingStore();
    const vhsAdvancedPreviews = computed(
      () => settingStore.get("VHS.AdvancedPreviews")
    );
    const url = computed(
      () => vhsAdvancedPreviews.value ? props.result.vhsAdvancedPreviewUrl : props.result.url
    );
    const htmlVideoType = computed(
      () => vhsAdvancedPreviews.value ? "video/webm" : props.result.htmlVideoType
    );
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("video", _hoisted_1$5, [
        createBaseVNode("source", {
          src: url.value,
          type: htmlVideoType.value
        }, null, 8, _hoisted_2$5),
        createTextVNode(" " + toDisplayString$1(_ctx.$t("g.videoFailedToLoad")), 1)
      ]);
    };
  }
});
const _sfc_main$7 = /* @__PURE__ */ defineComponent({
  __name: "ResultGallery",
  props: {
    allGalleryItems: {},
    activeIndex: {}
  },
  emits: ["update:activeIndex"],
  setup(__props, { emit: __emit }) {
    const galleryVisible = ref(false);
    const emit2 = __emit;
    const props = __props;
    let maskMouseDownTarget = null;
    const onMaskMouseDown2 = /* @__PURE__ */ __name((event) => {
      maskMouseDownTarget = event.target;
    }, "onMaskMouseDown");
    const onMaskMouseUp2 = /* @__PURE__ */ __name((event) => {
      const maskEl = document.querySelector("[data-mask]");
      if (galleryVisible.value && maskMouseDownTarget === event.target && maskMouseDownTarget === maskEl) {
        galleryVisible.value = false;
        handleVisibilityChange(false);
      }
    }, "onMaskMouseUp");
    watch(
      () => props.activeIndex,
      (index2) => {
        if (index2 !== -1) {
          galleryVisible.value = true;
        }
      }
    );
    const handleVisibilityChange = /* @__PURE__ */ __name((visible2) => {
      if (!visible2) {
        emit2("update:activeIndex", -1);
      }
    }, "handleVisibilityChange");
    const handleActiveIndexChange = /* @__PURE__ */ __name((index2) => {
      emit2("update:activeIndex", index2);
    }, "handleActiveIndexChange");
    const handleKeyDown2 = /* @__PURE__ */ __name((event) => {
      if (!galleryVisible.value) return;
      switch (event.key) {
        case "ArrowLeft":
          navigateImage(-1);
          break;
        case "ArrowRight":
          navigateImage(1);
          break;
        case "Escape":
          galleryVisible.value = false;
          handleVisibilityChange(false);
          break;
      }
    }, "handleKeyDown");
    const navigateImage = /* @__PURE__ */ __name((direction) => {
      const newIndex = (props.activeIndex + direction + props.allGalleryItems.length) % props.allGalleryItems.length;
      emit2("update:activeIndex", newIndex);
    }, "navigateImage");
    onMounted(() => {
      window.addEventListener("keydown", handleKeyDown2);
    });
    onUnmounted(() => {
      window.removeEventListener("keydown", handleKeyDown2);
    });
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(script$5), {
        visible: galleryVisible.value,
        "onUpdate:visible": [
          _cache[0] || (_cache[0] = ($event) => galleryVisible.value = $event),
          handleVisibilityChange
        ],
        activeIndex: _ctx.activeIndex,
        "onUpdate:activeIndex": handleActiveIndexChange,
        value: _ctx.allGalleryItems,
        showIndicators: false,
        changeItemOnIndicatorHover: "",
        showItemNavigators: "",
        fullScreen: "",
        circular: "",
        showThumbnails: false,
        pt: {
          mask: {
            onMousedown: onMaskMouseDown2,
            onMouseup: onMaskMouseUp2,
            "data-mask": true
          },
          prevButton: {
            style: "position: fixed !important"
          },
          nextButton: {
            style: "position: fixed !important"
          }
        }
      }, {
        item: withCtx(({ item: item3 }) => [
          item3.isImage ? (openBlock(), createBlock(ComfyImage, {
            key: item3.url,
            src: item3.url,
            contain: false,
            alt: item3.filename,
            class: "galleria-image"
          }, null, 8, ["src", "alt"])) : item3.isVideo ? (openBlock(), createBlock(_sfc_main$8, {
            key: 1,
            result: item3
          }, null, 8, ["result"])) : createCommentVNode("", true)
        ]),
        _: 1
      }, 8, ["visible", "activeIndex", "value", "pt"]);
    };
  }
});
const _hoisted_1$4 = {
  key: 2,
  class: "task-result-preview"
};
const _hoisted_2$4 = {
  key: 3,
  class: "preview-mask"
};
const _sfc_main$6 = /* @__PURE__ */ defineComponent({
  __name: "ResultItem",
  props: {
    result: {}
  },
  emits: ["preview"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit2 = __emit;
    const resultContainer = ref(null);
    const settingStore = useSettingStore();
    const imageFit = computed(
      () => settingStore.get("Comfy.Queue.ImageFit")
    );
    onMounted(() => {
      if (props.result.mediaType === "images") {
        resultContainer.value?.querySelectorAll("img").forEach((img) => {
          img.draggable = true;
        });
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: "result-container",
        ref_key: "resultContainer",
        ref: resultContainer
      }, [
        _ctx.result.isImage ? (openBlock(), createBlock(ComfyImage, {
          key: 0,
          src: _ctx.result.url,
          class: "task-output-image",
          contain: imageFit.value === "contain",
          alt: _ctx.result.filename
        }, null, 8, ["src", "contain", "alt"])) : _ctx.result.isVideo ? (openBlock(), createBlock(_sfc_main$8, {
          key: 1,
          result: _ctx.result
        }, null, 8, ["result"])) : (openBlock(), createElementBlock("div", _hoisted_1$4, [
          _cache[1] || (_cache[1] = createBaseVNode("i", { class: "pi pi-file" }, null, -1)),
          createBaseVNode("span", null, toDisplayString$1(_ctx.result.mediaType), 1)
        ])),
        _ctx.result.supportsPreview ? (openBlock(), createElementBlock("div", _hoisted_2$4, [
          createVNode(unref(script$10), {
            icon: "pi pi-eye",
            severity: "secondary",
            onClick: _cache[0] || (_cache[0] = ($event) => emit2("preview", _ctx.result)),
            rounded: ""
          })
        ])) : createCommentVNode("", true)
      ], 512);
    };
  }
});
const ResultItem = /* @__PURE__ */ _export_sfc(_sfc_main$6, [["__scopeId", "data-v-2403edc6"]]);
const _hoisted_1$3 = { class: "task-result-preview" };
const _hoisted_2$3 = {
  key: 0,
  class: "pi pi-spin pi-spinner"
};
const _hoisted_3$2 = ["src"];
const _hoisted_4$1 = { key: 2 };
const _hoisted_5$1 = {
  key: 3,
  class: "pi pi-exclamation-triangle"
};
const _hoisted_6$1 = {
  key: 4,
  class: "pi pi-exclamation-circle"
};
const _hoisted_7 = { class: "task-item-details" };
const _hoisted_8 = { class: "tag-wrapper status-tag-group" };
const _hoisted_9 = ["innerHTML"];
const _hoisted_10 = {
  key: 0,
  class: "task-time"
};
const _hoisted_11 = {
  key: 1,
  class: "task-prompt-id"
};
const _hoisted_12 = { class: "tag-wrapper" };
const _hoisted_13 = { style: { "font-weight": "bold" } };
const _sfc_main$5 = /* @__PURE__ */ defineComponent({
  __name: "TaskItem",
  props: {
    task: {},
    isFlatTask: { type: Boolean }
  },
  emits: ["contextmenu", "preview", "task-output-length-clicked"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const litegraphService = useLitegraphService();
    const flatOutputs = props.task.flatOutputs;
    const coverResult = flatOutputs.length ? props.task.previewOutput || flatOutputs[0] : null;
    const node3 = flatOutputs.length && props.task.workflow ? props.task.workflow.nodes.find(
      (n2) => n2.id == coverResult?.nodeId
    ) ?? null : null;
    const progressPreviewBlobUrl = ref("");
    const emit2 = __emit;
    onMounted(() => {
      api.addEventListener("b_preview", onProgressPreviewReceived);
    });
    onUnmounted(() => {
      if (progressPreviewBlobUrl.value) {
        URL.revokeObjectURL(progressPreviewBlobUrl.value);
      }
      api.removeEventListener("b_preview", onProgressPreviewReceived);
    });
    const handleContextMenu = /* @__PURE__ */ __name((e2) => {
      emit2("contextmenu", { task: props.task, event: e2, node: node3 });
    }, "handleContextMenu");
    const handlePreview = /* @__PURE__ */ __name(() => {
      emit2("preview", props.task);
    }, "handlePreview");
    const handleOutputLengthClick = /* @__PURE__ */ __name(() => {
      emit2("task-output-length-clicked", props.task);
    }, "handleOutputLengthClick");
    const taskTagSeverity = /* @__PURE__ */ __name((status) => {
      switch (status) {
        case TaskItemDisplayStatus.Pending:
          return "secondary";
        case TaskItemDisplayStatus.Running:
          return "info";
        case TaskItemDisplayStatus.Completed:
          return "success";
        case TaskItemDisplayStatus.Failed:
          return "danger";
        case TaskItemDisplayStatus.Cancelled:
          return "warn";
      }
    }, "taskTagSeverity");
    const taskStatusText = /* @__PURE__ */ __name((status) => {
      switch (status) {
        case TaskItemDisplayStatus.Pending:
          return "Pending";
        case TaskItemDisplayStatus.Running:
          return '<i class="pi pi-spin pi-spinner" style="font-weight: bold"></i> Running';
        case TaskItemDisplayStatus.Completed:
          return '<i class="pi pi-check" style="font-weight: bold"></i>';
        case TaskItemDisplayStatus.Failed:
          return "Failed";
        case TaskItemDisplayStatus.Cancelled:
          return "Cancelled";
      }
    }, "taskStatusText");
    const formatTime = /* @__PURE__ */ __name((time) => {
      if (time === void 0) {
        return "";
      }
      return `${time.toFixed(2)}s`;
    }, "formatTime");
    const onProgressPreviewReceived = /* @__PURE__ */ __name(async ({ detail }) => {
      if (props.task.displayStatus === TaskItemDisplayStatus.Running) {
        if (progressPreviewBlobUrl.value) {
          URL.revokeObjectURL(progressPreviewBlobUrl.value);
        }
        progressPreviewBlobUrl.value = URL.createObjectURL(detail);
      }
    }, "onProgressPreviewReceived");
    const cancelledWithResults = computed(() => {
      return props.task.displayStatus === TaskItemDisplayStatus.Cancelled && flatOutputs.length;
    });
    const cancelledWithoutResults = computed(() => {
      return props.task.displayStatus === TaskItemDisplayStatus.Cancelled && flatOutputs.length === 0;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        class: "task-item",
        onContextmenu: handleContextMenu
      }, [
        createBaseVNode("div", _hoisted_1$3, [
          _ctx.task.displayStatus === unref(TaskItemDisplayStatus).Completed || cancelledWithResults.value ? (openBlock(), createElementBlock(Fragment$1, { key: 0 }, [
            unref(flatOutputs).length && unref(coverResult) ? (openBlock(), createBlock(ResultItem, {
              key: 0,
              result: unref(coverResult),
              onPreview: handlePreview
            }, null, 8, ["result"])) : createCommentVNode("", true)
          ], 64)) : createCommentVNode("", true),
          _ctx.task.displayStatus === unref(TaskItemDisplayStatus).Running ? (openBlock(), createElementBlock(Fragment$1, { key: 1 }, [
            !progressPreviewBlobUrl.value ? (openBlock(), createElementBlock("i", _hoisted_2$3)) : (openBlock(), createElementBlock("img", {
              key: 1,
              src: progressPreviewBlobUrl.value,
              class: "progress-preview-img"
            }, null, 8, _hoisted_3$2))
          ], 64)) : _ctx.task.displayStatus === unref(TaskItemDisplayStatus).Pending ? (openBlock(), createElementBlock("span", _hoisted_4$1, "...")) : cancelledWithoutResults.value ? (openBlock(), createElementBlock("i", _hoisted_5$1)) : _ctx.task.displayStatus === unref(TaskItemDisplayStatus).Failed ? (openBlock(), createElementBlock("i", _hoisted_6$1)) : createCommentVNode("", true)
        ]),
        createBaseVNode("div", _hoisted_7, [
          createBaseVNode("div", _hoisted_8, [
            _ctx.isFlatTask && _ctx.task.isHistory ? (openBlock(), createBlock(unref(script$z), {
              key: 0,
              class: "node-name-tag"
            }, {
              default: withCtx(() => [
                createVNode(unref(script$10), {
                  class: "task-node-link",
                  label: `${unref(node3)?.type} (#${unref(node3)?.id})`,
                  link: "",
                  size: "small",
                  onClick: _cache[0] || (_cache[0] = () => {
                    if (!unref(node3)) return;
                    unref(litegraphService).goToNode(unref(node3).id);
                  })
                }, null, 8, ["label"])
              ]),
              _: 1
            })) : createCommentVNode("", true),
            createVNode(unref(script$z), {
              severity: taskTagSeverity(_ctx.task.displayStatus)
            }, {
              default: withCtx(() => [
                createBaseVNode("span", {
                  innerHTML: taskStatusText(_ctx.task.displayStatus)
                }, null, 8, _hoisted_9),
                _ctx.task.isHistory ? (openBlock(), createElementBlock("span", _hoisted_10, toDisplayString$1(formatTime(_ctx.task.executionTimeInSeconds)), 1)) : createCommentVNode("", true),
                _ctx.isFlatTask ? (openBlock(), createElementBlock("span", _hoisted_11, toDisplayString$1(_ctx.task.promptId.split("-")[0]), 1)) : createCommentVNode("", true)
              ]),
              _: 1
            }, 8, ["severity"])
          ]),
          createBaseVNode("div", _hoisted_12, [
            _ctx.task.isHistory && unref(flatOutputs).length > 1 ? (openBlock(), createBlock(unref(script$10), {
              key: 0,
              outlined: "",
              onClick: handleOutputLengthClick
            }, {
              default: withCtx(() => [
                createBaseVNode("span", _hoisted_13, toDisplayString$1(unref(flatOutputs).length), 1)
              ]),
              _: 1
            })) : createCommentVNode("", true)
          ])
        ])
      ], 32);
    };
  }
});
const TaskItem = /* @__PURE__ */ _export_sfc(_sfc_main$5, [["__scopeId", "data-v-21b11738"]]);
const _hoisted_1$2 = { key: 1 };
const _hoisted_2$2 = { key: 2 };
const IMAGE_FIT = "Comfy.Queue.ImageFit";
const _sfc_main$4 = /* @__PURE__ */ defineComponent({
  __name: "QueueSidebarTab",
  setup(__props) {
    const confirm2 = useConfirm();
    const toast = useToast();
    const queueStore = useQueueStore();
    const settingStore = useSettingStore();
    const commandStore = useCommandStore();
    const { t: t2 } = useI18n();
    const isExpanded = ref(false);
    const galleryActiveIndex = ref(-1);
    const allGalleryItems = shallowRef([]);
    const folderTask = ref(null);
    const isInFolderView = computed(() => folderTask.value !== null);
    const imageFit = computed(() => settingStore.get(IMAGE_FIT));
    const allTasks = computed(
      () => isInFolderView.value ? folderTask.value ? folderTask.value.flatten() : [] : isExpanded.value ? queueStore.flatTasks : queueStore.tasks
    );
    const updateGalleryItems = /* @__PURE__ */ __name(() => {
      allGalleryItems.value = allTasks.value.flatMap((task) => {
        const previewOutput = task.previewOutput;
        return previewOutput ? [previewOutput] : [];
      });
    }, "updateGalleryItems");
    const toggleExpanded = /* @__PURE__ */ __name(() => {
      isExpanded.value = !isExpanded.value;
    }, "toggleExpanded");
    const removeTask = /* @__PURE__ */ __name((task) => {
      if (task.isRunning) {
        api.interrupt();
      }
      queueStore.delete(task);
    }, "removeTask");
    const removeAllTasks = /* @__PURE__ */ __name(async () => {
      await queueStore.clear();
    }, "removeAllTasks");
    const confirmRemoveAll = /* @__PURE__ */ __name((event) => {
      confirm2.require({
        target: event.currentTarget,
        message: "Do you want to delete all tasks?",
        icon: "pi pi-info-circle",
        rejectProps: {
          label: "Cancel",
          severity: "secondary",
          outlined: true
        },
        acceptProps: {
          label: "Delete",
          severity: "danger"
        },
        accept: /* @__PURE__ */ __name(async () => {
          await removeAllTasks();
          toast.add({
            severity: "info",
            summary: "Confirmed",
            detail: "Tasks deleted",
            life: 3e3
          });
        }, "accept")
      });
    }, "confirmRemoveAll");
    const menu2 = ref(null);
    const menuTargetTask = ref(null);
    const menuTargetNode = ref(null);
    const menuItems = computed(() => [
      {
        label: t2("g.delete"),
        icon: "pi pi-trash",
        command: /* @__PURE__ */ __name(() => menuTargetTask.value && removeTask(menuTargetTask.value), "command"),
        disabled: isExpanded.value || isInFolderView.value
      },
      {
        label: t2("g.loadWorkflow"),
        icon: "pi pi-file-export",
        command: /* @__PURE__ */ __name(() => menuTargetTask.value?.loadWorkflow(app$2), "command"),
        disabled: !menuTargetTask.value?.workflow
      },
      {
        label: t2("g.goToNode"),
        icon: "pi pi-arrow-circle-right",
        command: /* @__PURE__ */ __name(() => {
          if (!menuTargetNode.value) return;
          useLitegraphService().goToNode(menuTargetNode.value.id);
        }, "command"),
        visible: !!menuTargetNode.value
      }
    ]);
    const handleContextMenu = /* @__PURE__ */ __name(({
      task,
      event,
      node: node3
    }) => {
      menuTargetTask.value = task;
      menuTargetNode.value = node3;
      menu2.value?.show(event);
    }, "handleContextMenu");
    const handlePreview = /* @__PURE__ */ __name((task) => {
      updateGalleryItems();
      galleryActiveIndex.value = allGalleryItems.value.findIndex(
        (item3) => item3.url === task.previewOutput?.url
      );
    }, "handlePreview");
    const enterFolderView = /* @__PURE__ */ __name((task) => {
      folderTask.value = task;
    }, "enterFolderView");
    const exitFolderView = /* @__PURE__ */ __name(() => {
      folderTask.value = null;
    }, "exitFolderView");
    const toggleImageFit = /* @__PURE__ */ __name(() => {
      settingStore.set(IMAGE_FIT, imageFit.value === "cover" ? "contain" : "cover");
    }, "toggleImageFit");
    watch(allTasks, () => {
      const isGalleryOpen = galleryActiveIndex.value !== -1;
      if (!isGalleryOpen) return;
      const prevLength = allGalleryItems.value.length;
      updateGalleryItems();
      const lengthChange = allGalleryItems.value.length - prevLength;
      if (!lengthChange) return;
      const newIndex = galleryActiveIndex.value + lengthChange;
      galleryActiveIndex.value = Math.max(0, newIndex);
    });
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(SidebarTabTemplate, {
          title: _ctx.$t("sideToolbar.queue")
        }, {
          "tool-buttons": withCtx(() => [
            withDirectives(createVNode(unref(script$10), {
              icon: imageFit.value === "cover" ? "pi pi-arrow-down-left-and-arrow-up-right-to-center" : "pi pi-arrow-up-right-and-arrow-down-left-from-center",
              text: "",
              severity: "secondary",
              onClick: toggleImageFit,
              class: "toggle-expanded-button"
            }, null, 8, ["icon"]), [
              [
                _directive_tooltip,
                _ctx.$t(`sideToolbar.queueTab.${imageFit.value}ImagePreview`),
                void 0,
                { bottom: true }
              ]
            ]),
            isInFolderView.value ? withDirectives((openBlock(), createBlock(unref(script$10), {
              key: 0,
              icon: "pi pi-arrow-left",
              text: "",
              severity: "secondary",
              onClick: exitFolderView,
              class: "back-button"
            }, null, 512)), [
              [
                _directive_tooltip,
                _ctx.$t("sideToolbar.queueTab.backToAllTasks"),
                void 0,
                { bottom: true }
              ]
            ]) : (openBlock(), createElementBlock(Fragment$1, { key: 1 }, [
              withDirectives(createVNode(unref(script$10), {
                icon: isExpanded.value ? "pi pi-images" : "pi pi-image",
                text: "",
                severity: "secondary",
                onClick: toggleExpanded,
                class: "toggle-expanded-button"
              }, null, 8, ["icon"]), [
                [_directive_tooltip, _ctx.$t("sideToolbar.queueTab.showFlatList")]
              ]),
              unref(queueStore).hasPendingTasks ? withDirectives((openBlock(), createBlock(unref(script$10), {
                key: 0,
                icon: "pi pi-stop",
                severity: "danger",
                text: "",
                onClick: _cache[0] || (_cache[0] = () => unref(commandStore).execute("Comfy.ClearPendingTasks"))
              }, null, 512)), [
                [
                  _directive_tooltip,
                  _ctx.$t("sideToolbar.queueTab.clearPendingTasks"),
                  void 0,
                  { bottom: true }
                ]
              ]) : createCommentVNode("", true),
              createVNode(unref(script$10), {
                icon: "pi pi-trash",
                text: "",
                severity: "primary",
                onClick: _cache[1] || (_cache[1] = ($event) => confirmRemoveAll($event)),
                class: "clear-all-button"
              })
            ], 64))
          ]),
          body: withCtx(() => [
            allTasks.value?.length ? (openBlock(), createBlock(VirtualGrid, {
              key: 0,
              items: allTasks.value,
              gridStyle: {
                display: "grid",
                gridTemplateColumns: "repeat(auto-fill, minmax(200px, 1fr))",
                padding: "0.5rem",
                gap: "0.5rem"
              }
            }, {
              item: withCtx(({ item: item3 }) => [
                createVNode(TaskItem, {
                  task: item3,
                  isFlatTask: isExpanded.value || isInFolderView.value,
                  onContextmenu: handleContextMenu,
                  onPreview: handlePreview,
                  onTaskOutputLengthClicked: _cache[2] || (_cache[2] = ($event) => enterFolderView($event))
                }, null, 8, ["task", "isFlatTask"])
              ]),
              _: 1
            }, 8, ["items"])) : unref(queueStore).isLoading ? (openBlock(), createElementBlock("div", _hoisted_1$2, [
              createVNode(unref(script$19), { style: { "width": "50px", "left": "50%", "transform": "translateX(-50%)" } })
            ])) : (openBlock(), createElementBlock("div", _hoisted_2$2, [
              createVNode(NoResultsPlaceholder, {
                icon: "pi pi-info-circle",
                title: _ctx.$t("g.noTasksFound"),
                message: _ctx.$t("g.noTasksFoundMessage")
              }, null, 8, ["title", "message"])
            ]))
          ]),
          _: 1
        }, 8, ["title"]),
        createVNode(unref(script$7)),
        createVNode(unref(script$c), {
          ref_key: "menu",
          ref: menu2,
          model: menuItems.value
        }, null, 8, ["model"]),
        createVNode(_sfc_main$7, {
          activeIndex: galleryActiveIndex.value,
          "onUpdate:activeIndex": _cache[3] || (_cache[3] = ($event) => galleryActiveIndex.value = $event),
          allGalleryItems: allGalleryItems.value
        }, null, 8, ["activeIndex", "allGalleryItems"])
      ], 64);
    };
  }
});
const useQueueSidebarTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  const queuePendingTaskCountStore = useQueuePendingTaskCountStore();
  return {
    id: "queue",
    icon: "pi pi-history",
    iconBadge: /* @__PURE__ */ __name(() => {
      const value3 = queuePendingTaskCountStore.count.toString();
      return value3 === "0" ? null : value3;
    }, "iconBadge"),
    title: t2("sideToolbar.queue"),
    tooltip: t2("sideToolbar.queue"),
    component: markRaw(_sfc_main$4),
    type: "vue"
  };
}, "useQueueSidebarTab");
var theme = /* @__PURE__ */ __name(function theme46(_ref) {
  var dt2 = _ref.dt;
  return "\n.p-confirmdialog .p-dialog-content {\n    display: flex;\n    align-items: center;\n    gap:  ".concat(dt2("confirmdialog.content.gap"), ";\n}\n\n.p-confirmdialog-icon {\n    color: ").concat(dt2("confirmdialog.icon.color"), ";\n    font-size: ").concat(dt2("confirmdialog.icon.size"), ";\n    width: ").concat(dt2("confirmdialog.icon.size"), ";\n    height: ").concat(dt2("confirmdialog.icon.size"), ";\n}\n");
}, "theme");
var classes = {
  root: "p-confirmdialog",
  icon: "p-confirmdialog-icon",
  message: "p-confirmdialog-message",
  pcRejectButton: "p-confirmdialog-reject-button",
  pcAcceptButton: "p-confirmdialog-accept-button"
};
var ConfirmDialogStyle = BaseStyle$1.extend({
  name: "confirmdialog",
  theme,
  classes
});
var script$1 = {
  name: "BaseConfirmDialog",
  "extends": script$1b,
  props: {
    group: String,
    breakpoints: {
      type: Object,
      "default": null
    },
    draggable: {
      type: Boolean,
      "default": true
    }
  },
  style: ConfirmDialogStyle,
  provide: /* @__PURE__ */ __name(function provide51() {
    return {
      $pcConfirmDialog: this,
      $parentInstance: this
    };
  }, "provide")
};
var script = {
  name: "ConfirmDialog",
  "extends": script$1,
  confirmListener: null,
  closeListener: null,
  data: /* @__PURE__ */ __name(function data29() {
    return {
      visible: false,
      confirmation: null
    };
  }, "data"),
  mounted: /* @__PURE__ */ __name(function mounted29() {
    var _this = this;
    this.confirmListener = function(options5) {
      if (!options5) {
        return;
      }
      if (options5.group === _this.group) {
        _this.confirmation = options5;
        if (_this.confirmation.onShow) {
          _this.confirmation.onShow();
        }
        _this.visible = true;
      }
    };
    this.closeListener = function() {
      _this.visible = false;
      _this.confirmation = null;
    };
    ConfirmationEventBus.on("confirm", this.confirmListener);
    ConfirmationEventBus.on("close", this.closeListener);
  }, "mounted"),
  beforeUnmount: /* @__PURE__ */ __name(function beforeUnmount18() {
    ConfirmationEventBus.off("confirm", this.confirmListener);
    ConfirmationEventBus.off("close", this.closeListener);
  }, "beforeUnmount"),
  methods: {
    accept: /* @__PURE__ */ __name(function accept2() {
      if (this.confirmation.accept) {
        this.confirmation.accept();
      }
      this.visible = false;
    }, "accept"),
    reject: /* @__PURE__ */ __name(function reject2() {
      if (this.confirmation.reject) {
        this.confirmation.reject();
      }
      this.visible = false;
    }, "reject"),
    onHide: /* @__PURE__ */ __name(function onHide2() {
      if (this.confirmation.onHide) {
        this.confirmation.onHide();
      }
      this.visible = false;
    }, "onHide")
  },
  computed: {
    appendTo: /* @__PURE__ */ __name(function appendTo() {
      return this.confirmation ? this.confirmation.appendTo : "body";
    }, "appendTo"),
    target: /* @__PURE__ */ __name(function target() {
      return this.confirmation ? this.confirmation.target : null;
    }, "target"),
    modal: /* @__PURE__ */ __name(function modal() {
      return this.confirmation ? this.confirmation.modal == null ? true : this.confirmation.modal : true;
    }, "modal"),
    header: /* @__PURE__ */ __name(function header2() {
      return this.confirmation ? this.confirmation.header : null;
    }, "header"),
    message: /* @__PURE__ */ __name(function message2() {
      return this.confirmation ? this.confirmation.message : null;
    }, "message"),
    blockScroll: /* @__PURE__ */ __name(function blockScroll() {
      return this.confirmation ? this.confirmation.blockScroll : true;
    }, "blockScroll"),
    position: /* @__PURE__ */ __name(function position2() {
      return this.confirmation ? this.confirmation.position : null;
    }, "position"),
    acceptLabel: /* @__PURE__ */ __name(function acceptLabel2() {
      if (this.confirmation) {
        var _confirmation$acceptP;
        var confirmation = this.confirmation;
        return confirmation.acceptLabel || ((_confirmation$acceptP = confirmation.acceptProps) === null || _confirmation$acceptP === void 0 ? void 0 : _confirmation$acceptP.label) || this.$primevue.config.locale.accept;
      }
      return this.$primevue.config.locale.accept;
    }, "acceptLabel"),
    rejectLabel: /* @__PURE__ */ __name(function rejectLabel2() {
      if (this.confirmation) {
        var _confirmation$rejectP;
        var confirmation = this.confirmation;
        return confirmation.rejectLabel || ((_confirmation$rejectP = confirmation.rejectProps) === null || _confirmation$rejectP === void 0 ? void 0 : _confirmation$rejectP.label) || this.$primevue.config.locale.reject;
      }
      return this.$primevue.config.locale.reject;
    }, "rejectLabel"),
    acceptIcon: /* @__PURE__ */ __name(function acceptIcon2() {
      var _this$confirmation;
      return this.confirmation ? this.confirmation.acceptIcon : (_this$confirmation = this.confirmation) !== null && _this$confirmation !== void 0 && _this$confirmation.acceptProps ? this.confirmation.acceptProps.icon : null;
    }, "acceptIcon"),
    rejectIcon: /* @__PURE__ */ __name(function rejectIcon2() {
      var _this$confirmation2;
      return this.confirmation ? this.confirmation.rejectIcon : (_this$confirmation2 = this.confirmation) !== null && _this$confirmation2 !== void 0 && _this$confirmation2.rejectProps ? this.confirmation.rejectProps.icon : null;
    }, "rejectIcon"),
    autoFocusAccept: /* @__PURE__ */ __name(function autoFocusAccept() {
      return this.confirmation.defaultFocus === void 0 || this.confirmation.defaultFocus === "accept" ? true : false;
    }, "autoFocusAccept"),
    autoFocusReject: /* @__PURE__ */ __name(function autoFocusReject() {
      return this.confirmation.defaultFocus === "reject" ? true : false;
    }, "autoFocusReject"),
    closeOnEscape: /* @__PURE__ */ __name(function closeOnEscape() {
      return this.confirmation ? this.confirmation.closeOnEscape : true;
    }, "closeOnEscape")
  },
  components: {
    Dialog: script$_,
    Button: script$10
  }
};
function render(_ctx, _cache, $props, $setup, $data, $options) {
  var _component_Button = resolveComponent("Button");
  var _component_Dialog = resolveComponent("Dialog");
  return openBlock(), createBlock(_component_Dialog, {
    visible: $data.visible,
    "onUpdate:visible": [_cache[2] || (_cache[2] = function($event) {
      return $data.visible = $event;
    }), $options.onHide],
    role: "alertdialog",
    "class": normalizeClass(_ctx.cx("root")),
    modal: $options.modal,
    header: $options.header,
    blockScroll: $options.blockScroll,
    appendTo: $options.appendTo,
    position: $options.position,
    breakpoints: _ctx.breakpoints,
    closeOnEscape: $options.closeOnEscape,
    draggable: _ctx.draggable,
    pt: _ctx.pt,
    unstyled: _ctx.unstyled
  }, createSlots({
    "default": withCtx(function() {
      return [!_ctx.$slots.container ? (openBlock(), createElementBlock(Fragment$1, {
        key: 0
      }, [!_ctx.$slots.message ? (openBlock(), createElementBlock(Fragment$1, {
        key: 0
      }, [renderSlot(_ctx.$slots, "icon", {}, function() {
        return [_ctx.$slots.icon ? (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.icon), {
          key: 0,
          "class": normalizeClass(_ctx.cx("icon"))
        }, null, 8, ["class"])) : $data.confirmation.icon ? (openBlock(), createElementBlock("span", mergeProps$2({
          key: 1,
          "class": [$data.confirmation.icon, _ctx.cx("icon")]
        }, _ctx.ptm("icon")), null, 16)) : createCommentVNode("", true)];
      }), createBaseVNode("span", mergeProps$2({
        "class": _ctx.cx("message")
      }, _ctx.ptm("message")), toDisplayString$1($options.message), 17)], 64)) : (openBlock(), createBlock(resolveDynamicComponent(_ctx.$slots.message), {
        key: 1,
        message: $data.confirmation
      }, null, 8, ["message"]))], 64)) : createCommentVNode("", true)];
    }),
    _: 2
  }, [_ctx.$slots.container ? {
    name: "container",
    fn: withCtx(function(slotProps) {
      return [renderSlot(_ctx.$slots, "container", {
        message: $data.confirmation,
        closeCallback: slotProps.onclose,
        acceptCallback: $options.accept,
        rejectCallback: $options.reject
      })];
    }),
    key: "0"
  } : void 0, !_ctx.$slots.container ? {
    name: "footer",
    fn: withCtx(function() {
      var _$data$confirmation$r;
      return [createVNode(_component_Button, mergeProps$2({
        "class": [_ctx.cx("pcRejectButton"), $data.confirmation.rejectClass],
        autofocus: $options.autoFocusReject,
        unstyled: _ctx.unstyled,
        text: ((_$data$confirmation$r = $data.confirmation.rejectProps) === null || _$data$confirmation$r === void 0 ? void 0 : _$data$confirmation$r.text) || false,
        onClick: _cache[0] || (_cache[0] = function($event) {
          return $options.reject();
        })
      }, $data.confirmation.rejectProps, {
        label: $options.rejectLabel,
        pt: _ctx.ptm("pcRejectButton")
      }), createSlots({
        _: 2
      }, [$options.rejectIcon || _ctx.$slots.rejecticon ? {
        name: "icon",
        fn: withCtx(function(iconProps) {
          return [renderSlot(_ctx.$slots, "rejecticon", {}, function() {
            return [createBaseVNode("span", mergeProps$2({
              "class": [$options.rejectIcon, iconProps["class"]]
            }, _ctx.ptm("pcRejectButton")["icon"], {
              "data-pc-section": "rejectbuttonicon"
            }), null, 16)];
          })];
        }),
        key: "0"
      } : void 0]), 1040, ["class", "autofocus", "unstyled", "text", "label", "pt"]), createVNode(_component_Button, mergeProps$2({
        label: $options.acceptLabel,
        "class": [_ctx.cx("pcAcceptButton"), $data.confirmation.acceptClass],
        autofocus: $options.autoFocusAccept,
        unstyled: _ctx.unstyled,
        onClick: _cache[1] || (_cache[1] = function($event) {
          return $options.accept();
        })
      }, $data.confirmation.acceptProps, {
        pt: _ctx.ptm("pcAcceptButton")
      }), createSlots({
        _: 2
      }, [$options.acceptIcon || _ctx.$slots.accepticon ? {
        name: "icon",
        fn: withCtx(function(iconProps) {
          return [renderSlot(_ctx.$slots, "accepticon", {}, function() {
            return [createBaseVNode("span", mergeProps$2({
              "class": [$options.acceptIcon, iconProps["class"]]
            }, _ctx.ptm("pcAcceptButton")["icon"], {
              "data-pc-section": "acceptbuttonicon"
            }), null, 16)];
          })];
        }),
        key: "0"
      } : void 0]), 1040, ["label", "class", "autofocus", "unstyled", "pt"])];
    }),
    key: "1"
  } : void 0]), 1032, ["visible", "class", "modal", "header", "blockScroll", "appendTo", "position", "breakpoints", "closeOnEscape", "draggable", "onUpdate:visible", "pt", "unstyled"]);
}
__name(render, "render");
script.render = render;
const _hoisted_1$1 = { class: "flex items-center" };
const _hoisted_2$1 = {
  key: 0,
  class: "mr-2 shrink-0"
};
const _hoisted_3$1 = {
  key: 1,
  class: "ml-2 shrink-0"
};
const _sfc_main$3 = /* @__PURE__ */ defineComponent({
  __name: "TextDivider",
  props: {
    text: {},
    position: { default: "left" },
    align: { default: "center" },
    type: { default: "solid" },
    layout: { default: "horizontal" }
  },
  setup(__props) {
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1$1, [
        _ctx.position === "left" ? (openBlock(), createElementBlock("span", _hoisted_2$1, toDisplayString$1(_ctx.text), 1)) : createCommentVNode("", true),
        createVNode(unref(script$Y), {
          align: _ctx.align,
          type: _ctx.type,
          layout: _ctx.layout,
          class: "flex-grow"
        }, null, 8, ["align", "type", "layout"]),
        _ctx.position === "right" ? (openBlock(), createElementBlock("span", _hoisted_3$1, toDisplayString$1(_ctx.text), 1)) : createCommentVNode("", true)
      ]);
    };
  }
});
const _sfc_main$2 = /* @__PURE__ */ defineComponent({
  __name: "WorkflowTreeLeaf",
  props: {
    node: {}
  },
  setup(__props) {
    const workflowBookmarkStore = useWorkflowBookmarkStore();
    const isBookmarked = computed(
      () => __props.node.data && workflowBookmarkStore.isBookmarked(__props.node.data.path)
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(TreeExplorerTreeNode, { node: _ctx.node }, {
        actions: withCtx(({ node: node3 }) => [
          createVNode(unref(script$10), {
            icon: isBookmarked.value ? "pi pi-bookmark-fill" : "pi pi-bookmark",
            text: "",
            severity: "secondary",
            size: "small",
            onClick: withModifiers(($event) => unref(workflowBookmarkStore).toggleBookmarked(node3.data.path), ["stop"])
          }, null, 8, ["icon", "onClick"])
        ]),
        _: 1
      }, 8, ["node"]);
    };
  }
});
const _hoisted_1 = {
  key: 0,
  class: "comfyui-workflows-panel"
};
const _hoisted_2 = {
  key: 0,
  class: "comfyui-workflows-open"
};
const _hoisted_3 = { key: 0 };
const _hoisted_4 = { class: "comfyui-workflows-bookmarks" };
const _hoisted_5 = { class: "comfyui-workflows-browse" };
const _hoisted_6 = {
  key: 1,
  class: "comfyui-workflows-search-panel"
};
var WorkflowTreeType = /* @__PURE__ */ ((WorkflowTreeType2) => {
  WorkflowTreeType2["Open"] = "Open";
  WorkflowTreeType2["Bookmarks"] = "Bookmarks";
  WorkflowTreeType2["Browse"] = "Browse";
  return WorkflowTreeType2;
})(WorkflowTreeType || {});
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  __name: "WorkflowsSidebarTab",
  setup(__props) {
    const settingStore = useSettingStore();
    const workflowTabsPosition = computed(
      () => settingStore.get("Comfy.Workflow.WorkflowTabsPosition")
    );
    const searchQuery = ref("");
    const isSearching = computed(() => searchQuery.value.length > 0);
    const filteredWorkflows = ref([]);
    const filteredRoot = computed(() => {
      return buildWorkflowTree(filteredWorkflows.value);
    });
    const handleSearch = /* @__PURE__ */ __name((query) => {
      if (query.length === 0) {
        filteredWorkflows.value = [];
        expandedKeys2.value = {};
        return;
      }
      const lowerQuery = query.toLocaleLowerCase();
      filteredWorkflows.value = workflowStore.workflows.filter((workflow) => {
        return workflow.path.toLocaleLowerCase().includes(lowerQuery);
      });
      nextTick(() => {
        expandNode(filteredRoot.value);
      });
    }, "handleSearch");
    const workflowStore = useWorkflowStore();
    const workflowService2 = useWorkflowService();
    const workspaceStore = useWorkspaceStore();
    const { t: t2 } = useI18n();
    const expandedKeys2 = ref({});
    const { expandNode, toggleNodeOnEvent } = useTreeExpansion(expandedKeys2);
    const dummyExpandedKeys = ref({});
    const handleCloseWorkflow = /* @__PURE__ */ __name((workflow) => {
      if (workflow) {
        workflowService2.closeWorkflow(workflow, {
          warnIfUnsaved: !workspaceStore.shiftDown
        });
      }
    }, "handleCloseWorkflow");
    const buildWorkflowTree = /* @__PURE__ */ __name((workflows) => {
      return buildTree$1(
        workflows,
        (workflow) => workflow.key.split("/")
      );
    }, "buildWorkflowTree");
    const workflowsTree = computed(
      () => sortedTree(buildWorkflowTree(workflowStore.persistedWorkflows), {
        groupLeaf: true
      })
    );
    const bookmarkedWorkflowsTree = computed(
      () => buildTree$1(workflowStore.bookmarkedWorkflows, (workflow) => [workflow.key])
    );
    const openWorkflowsTree = computed(
      () => buildTree$1(workflowStore.openWorkflows, (workflow) => [workflow.key])
    );
    const renderTreeNode = /* @__PURE__ */ __name((node3, type) => {
      const children = node3.children?.map((child) => renderTreeNode(child, type));
      const workflow = node3.data;
      function handleClick2(e2) {
        if (this.leaf) {
          workflowService2.openWorkflow(workflow);
        } else {
          toggleNodeOnEvent(e2, this);
        }
      }
      __name(handleClick2, "handleClick");
      const actions = node3.leaf ? {
        handleClick: handleClick2,
        async handleRename(newName) {
          const newPath = type === "Browse" ? workflow.directory + "/" + appendJsonExt(newName) : ComfyWorkflow.basePath + appendJsonExt(newName);
          await workflowService2.renameWorkflow(workflow, newPath);
        },
        handleDelete: workflow.isTemporary ? void 0 : async function() {
          await workflowService2.deleteWorkflow(workflow);
        },
        contextMenuItems() {
          return [
            {
              label: t2("g.insert"),
              icon: "pi pi-file-export",
              command: /* @__PURE__ */ __name(() => {
                const workflow2 = node3.data;
                workflowService2.insertWorkflow(workflow2);
              }, "command")
            }
          ];
        },
        draggable: true
      } : { handleClick: handleClick2 };
      return {
        key: node3.key,
        label: node3.label,
        leaf: node3.leaf,
        data: node3.data,
        children,
        ...actions
      };
    }, "renderTreeNode");
    const selectionKeys = computed(() => ({
      [`root/${workflowStore.activeWorkflow?.key}`]: true
    }));
    const workflowBookmarkStore = useWorkflowBookmarkStore();
    onMounted(async () => {
      await workflowBookmarkStore.loadBookmarks();
    });
    return (_ctx, _cache) => {
      const _directive_tooltip = resolveDirective("tooltip");
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(SidebarTabTemplate, {
          title: _ctx.$t("sideToolbar.workflows"),
          class: "workflows-sidebar-tab bg-[var(--p-tree-background)]"
        }, {
          "tool-buttons": withCtx(() => [
            withDirectives(createVNode(unref(script$10), {
              icon: "pi pi-refresh",
              onClick: _cache[0] || (_cache[0] = ($event) => unref(workflowStore).syncWorkflows()),
              severity: "secondary",
              text: ""
            }, null, 512), [
              [
                _directive_tooltip,
                _ctx.$t("g.refresh"),
                void 0,
                { bottom: true }
              ]
            ])
          ]),
          header: withCtx(() => [
            createVNode(SearchBox, {
              class: "workflows-search-box p-2 2xl:p-4",
              modelValue: searchQuery.value,
              "onUpdate:modelValue": _cache[1] || (_cache[1] = ($event) => searchQuery.value = $event),
              onSearch: handleSearch,
              placeholder: _ctx.$t("g.searchWorkflows") + "..."
            }, null, 8, ["modelValue", "placeholder"])
          ]),
          body: withCtx(() => [
            !isSearching.value ? (openBlock(), createElementBlock("div", _hoisted_1, [
              workflowTabsPosition.value === "Sidebar" ? (openBlock(), createElementBlock("div", _hoisted_2, [
                createVNode(_sfc_main$3, {
                  text: unref(t2)("sideToolbar.workflowTab.workflowTreeType.open"),
                  type: "dashed",
                  class: "ml-2"
                }, null, 8, ["text"]),
                createVNode(TreeExplorer, {
                  root: renderTreeNode(
                    openWorkflowsTree.value,
                    "Open"
                    /* Open */
                  ),
                  selectionKeys: selectionKeys.value,
                  expandedKeys: dummyExpandedKeys.value,
                  "onUpdate:expandedKeys": _cache[2] || (_cache[2] = ($event) => dummyExpandedKeys.value = $event)
                }, {
                  node: withCtx(({ node: node3 }) => [
                    createVNode(TreeExplorerTreeNode, { node: node3 }, {
                      "before-label": withCtx(({ node: node22 }) => [
                        node22.data.isModified || !node22.data.isPersisted ? (openBlock(), createElementBlock("span", _hoisted_3, "*")) : createCommentVNode("", true)
                      ]),
                      actions: withCtx(({ node: node22 }) => [
                        createVNode(unref(script$10), {
                          class: "close-workflow-button",
                          icon: "pi pi-times",
                          text: "",
                          severity: unref(workspaceStore).shiftDown ? "danger" : "secondary",
                          size: "small",
                          onClick: withModifiers(($event) => handleCloseWorkflow(node22.data), ["stop"])
                        }, null, 8, ["severity", "onClick"])
                      ]),
                      _: 2
                    }, 1032, ["node"])
                  ]),
                  _: 1
                }, 8, ["root", "selectionKeys", "expandedKeys"])
              ])) : createCommentVNode("", true),
              withDirectives(createBaseVNode("div", _hoisted_4, [
                createVNode(_sfc_main$3, {
                  text: unref(t2)("sideToolbar.workflowTab.workflowTreeType.bookmarks"),
                  type: "dashed",
                  class: "ml-2"
                }, null, 8, ["text"]),
                createVNode(TreeExplorer, {
                  root: renderTreeNode(
                    bookmarkedWorkflowsTree.value,
                    "Bookmarks"
                    /* Bookmarks */
                  ),
                  selectionKeys: selectionKeys.value,
                  expandedKeys: dummyExpandedKeys.value,
                  "onUpdate:expandedKeys": _cache[3] || (_cache[3] = ($event) => dummyExpandedKeys.value = $event)
                }, {
                  node: withCtx(({ node: node3 }) => [
                    createVNode(_sfc_main$2, { node: node3 }, null, 8, ["node"])
                  ]),
                  _: 1
                }, 8, ["root", "selectionKeys", "expandedKeys"])
              ], 512), [
                [vShow, unref(workflowStore).bookmarkedWorkflows.length > 0]
              ]),
              createBaseVNode("div", _hoisted_5, [
                createVNode(_sfc_main$3, {
                  text: unref(t2)("sideToolbar.workflowTab.workflowTreeType.browse"),
                  type: "dashed",
                  class: "ml-2"
                }, null, 8, ["text"]),
                unref(workflowStore).persistedWorkflows.length > 0 ? (openBlock(), createBlock(TreeExplorer, {
                  key: 0,
                  root: renderTreeNode(
                    workflowsTree.value,
                    "Browse"
                    /* Browse */
                  ),
                  expandedKeys: expandedKeys2.value,
                  "onUpdate:expandedKeys": _cache[4] || (_cache[4] = ($event) => expandedKeys2.value = $event),
                  selectionKeys: selectionKeys.value
                }, {
                  node: withCtx(({ node: node3 }) => [
                    createVNode(_sfc_main$2, { node: node3 }, null, 8, ["node"])
                  ]),
                  _: 1
                }, 8, ["root", "expandedKeys", "selectionKeys"])) : (openBlock(), createBlock(NoResultsPlaceholder, {
                  key: 1,
                  icon: "pi pi-folder",
                  title: _ctx.$t("g.empty"),
                  message: _ctx.$t("g.noWorkflowsFound")
                }, null, 8, ["title", "message"]))
              ])
            ])) : (openBlock(), createElementBlock("div", _hoisted_6, [
              createVNode(TreeExplorer, {
                root: renderTreeNode(
                  filteredRoot.value,
                  "Browse"
                  /* Browse */
                ),
                expandedKeys: expandedKeys2.value,
                "onUpdate:expandedKeys": _cache[5] || (_cache[5] = ($event) => expandedKeys2.value = $event)
              }, {
                node: withCtx(({ node: node3 }) => [
                  createVNode(_sfc_main$2, { node: node3 }, null, 8, ["node"])
                ]),
                _: 1
              }, 8, ["root", "expandedKeys"])
            ]))
          ]),
          _: 1
        }, 8, ["title"]),
        createVNode(unref(script))
      ], 64);
    };
  }
});
const useWorkflowsSidebarTab = /* @__PURE__ */ __name(() => {
  const { t: t2 } = useI18n();
  const settingStore = useSettingStore();
  const workflowStore = useWorkflowStore();
  return {
    id: "workflows",
    icon: "pi pi-folder-open",
    iconBadge: /* @__PURE__ */ __name(() => {
      if (settingStore.get("Comfy.Workflow.WorkflowTabsPosition") !== "Sidebar") {
        return null;
      }
      const value3 = workflowStore.openWorkflows.length.toString();
      return value3 === "0" ? null : value3;
    }, "iconBadge"),
    title: t2("sideToolbar.workflows"),
    tooltip: t2("sideToolbar.workflows"),
    component: markRaw(_sfc_main$1),
    type: "vue"
  };
}, "useWorkflowsSidebarTab");
const useSidebarTabStore = /* @__PURE__ */ defineStore("sidebarTab", () => {
  const sidebarTabs = ref([]);
  const activeSidebarTabId = ref(null);
  const activeSidebarTab = computed(() => {
    return sidebarTabs.value.find((tab) => tab.id === activeSidebarTabId.value) ?? null;
  });
  const toggleSidebarTab = /* @__PURE__ */ __name((tabId) => {
    activeSidebarTabId.value = activeSidebarTabId.value === tabId ? null : tabId;
  }, "toggleSidebarTab");
  const registerSidebarTab = /* @__PURE__ */ __name((tab) => {
    sidebarTabs.value = [...sidebarTabs.value, tab];
    useCommandStore().registerCommand({
      id: `Workspace.ToggleSidebarTab.${tab.id}`,
      icon: tab.icon,
      label: `Toggle ${tab.title} Sidebar`,
      tooltip: tab.tooltip,
      versionAdded: "1.3.9",
      function: /* @__PURE__ */ __name(() => {
        toggleSidebarTab(tab.id);
      }, "function")
    });
  }, "registerSidebarTab");
  const unregisterSidebarTab = /* @__PURE__ */ __name((id4) => {
    const index2 = sidebarTabs.value.findIndex((tab) => tab.id === id4);
    if (index2 !== -1) {
      const tab = sidebarTabs.value[index2];
      if (tab.type === "custom" && tab.destroy) {
        tab.destroy();
      }
      const newSidebarTabs = [...sidebarTabs.value];
      newSidebarTabs.splice(index2, 1);
      sidebarTabs.value = newSidebarTabs;
    }
  }, "unregisterSidebarTab");
  const registerCoreSidebarTabs = /* @__PURE__ */ __name(() => {
    registerSidebarTab(useQueueSidebarTab());
    registerSidebarTab(useNodeLibrarySidebarTab());
    registerSidebarTab(useModelLibrarySidebarTab());
    registerSidebarTab(useWorkflowsSidebarTab());
  }, "registerCoreSidebarTabs");
  return {
    sidebarTabs,
    activeSidebarTabId,
    activeSidebarTab,
    toggleSidebarTab,
    registerSidebarTab,
    unregisterSidebarTab,
    registerCoreSidebarTabs
  };
});
const useWorkspaceStore = /* @__PURE__ */ defineStore("workspace", () => {
  const spinner = ref(false);
  const shiftDown = ref(false);
  const focusMode = ref(false);
  const toast = computed(() => useToastStore());
  const queueSettings = computed(() => useQueueSettingsStore());
  const command2 = computed(() => ({
    commands: useCommandStore().commands,
    execute: useCommandStore().execute
  }));
  const sidebarTab = computed(() => useSidebarTabStore());
  const setting = computed(() => ({
    settings: useSettingStore().settingsById,
    get: useSettingStore().get,
    set: useSettingStore().set
  }));
  const workflow = computed(() => useWorkflowStore());
  const colorPalette = useColorPaletteService();
  const dialog = useDialogService();
  const bottomPanel = useBottomPanelStore();
  function registerSidebarTab(tab) {
    sidebarTab.value.registerSidebarTab(tab);
  }
  __name(registerSidebarTab, "registerSidebarTab");
  function unregisterSidebarTab(id4) {
    sidebarTab.value.unregisterSidebarTab(id4);
  }
  __name(unregisterSidebarTab, "unregisterSidebarTab");
  function getSidebarTabs() {
    return sidebarTab.value.sidebarTabs;
  }
  __name(getSidebarTabs, "getSidebarTabs");
  return {
    spinner,
    shiftDown,
    focusMode,
    toggleFocusMode: /* @__PURE__ */ __name(() => {
      focusMode.value = !focusMode.value;
    }, "toggleFocusMode"),
    toast,
    queueSettings,
    command: command2,
    sidebarTab,
    setting,
    workflow,
    colorPalette,
    dialog,
    bottomPanel,
    registerSidebarTab,
    unregisterSidebarTab,
    getSidebarTabs
  };
});
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "App",
  setup(__props) {
    const workspaceStore = useWorkspaceStore();
    const isLoading = computed(() => workspaceStore.spinner);
    const handleKey = /* @__PURE__ */ __name((e2) => {
      workspaceStore.shiftDown = e2.shiftKey;
    }, "handleKey");
    useEventListener(window, "keydown", handleKey);
    useEventListener(window, "keyup", handleKey);
    const showContextMenu = /* @__PURE__ */ __name((event) => {
      const { target: target2 } = event;
      switch (true) {
        case target2 instanceof HTMLTextAreaElement:
        case (target2 instanceof HTMLInputElement && target2.type === "text"):
          electronAPI()?.showContextMenu({ type: "text" });
          return;
      }
    }, "showContextMenu");
    onMounted(() => {
      window["__COMFYUI_FRONTEND_VERSION__"] = config$1.app_version;
      console.log("ComfyUI Front-end version:", config$1.app_version);
      if (isElectron()) {
        document.addEventListener("contextmenu", showContextMenu);
      }
    });
    return (_ctx, _cache) => {
      const _component_router_view = resolveComponent("router-view");
      return openBlock(), createElementBlock(Fragment$1, null, [
        createVNode(_component_router_view),
        isLoading.value ? (openBlock(), createBlock(unref(script$19), {
          key: 0,
          class: "absolute inset-0 flex justify-center items-center h-screen"
        })) : createCommentVNode("", true),
        createVNode(_sfc_main$1F),
        createVNode(unref(script$1a), {
          "full-screen": "",
          blocked: isLoading.value
        }, null, 8, ["blocked"])
      ], 64);
    };
  }
});
const ComfyUIPreset = definePreset$1(index$2, {
  semantic: {
    // @ts-expect-error fixme ts strict error
    primary: index$2["primitive"].blue
  }
});
const app$1 = createApp(_sfc_main);
const pinia = createPinia();
init$3({
  app: app$1,
  dsn: "https://e2d0c0bd392ffdce48e856c2a055f437@o4507954455314432.ingest.us.sentry.io/4508621568475136",
  enabled: true,
  release: "1.14.5",
  integrations: [],
  autoSessionTracking: false,
  defaultIntegrations: false,
  normalizeDepth: 8,
  tracesSampleRate: 0
});
app$1.directive("tooltip", Tooltip);
app$1.use(router).use(PrimeVue, {
  theme: {
    preset: ComfyUIPreset,
    options: {
      prefix: "p",
      cssLayer: {
        name: "primevue",
        order: "primevue, tailwind-utilities"
      },
      // This is a workaround for the issue with the dark mode selector
      // https://github.com/primefaces/primevue/issues/5515
      darkModeSelector: ".dark-theme, :root:has(.dark-theme)"
    }
  }
}).use(ConfirmationService).use(ToastService).use(pinia).use(i18n).mount("#vue-app");
export {
  NodeBadgeMode as $,
  renderSlot as A,
  createCommentVNode as B,
  resolveDynamicComponent as C,
  script$j as D,
  renderList as E,
  Fragment$1 as F,
  toDisplayString$1 as G,
  script$k as H,
  script$C as I,
  useCanvasStore as J,
  ref as K,
  watch as L,
  isDOMWidget as M,
  useEventListener as N,
  isComponentWidget as O,
  useDomWidgetStore as P,
  useChainCallback as Q,
  markRaw as R,
  useI18n as S,
  useCommandStore as T,
  LiteGraph as U,
  useColorPaletteStore as V,
  useNodeDefStore as W,
  BadgePosition as X,
  LGraphBadge as Y,
  _ as Z,
  _export_sfc as _,
  useSettingStore as a,
  isImageNode as a$,
  nextTick as a0,
  isOverNodeInput as a1,
  st as a2,
  normalizeI18nKey as a3,
  isOverNodeOutput as a4,
  normalizeClass as a5,
  createBounds as a6,
  LGraphCanvas as a7,
  getItemsColorOption as a8,
  script$8 as a9,
  storeToRefs as aA,
  isRef as aB,
  toRaw as aC,
  useUserStore as aD,
  useDialogStore as aE,
  SettingDialogHeader as aF,
  SettingDialogContent as aG,
  useKeybindingStore as aH,
  Teleport as aI,
  usePragmaticDraggable as aJ,
  usePragmaticDroppable as aK,
  withModifiers as aL,
  mergeProps$2 as aM,
  useWorkflowService as aN,
  useWorkflowBookmarkStore as aO,
  script$X as aP,
  script$c as aQ,
  useModelToNodeStore as aR,
  ComfyNodeDefImpl as aS,
  ComfyModelDef as aT,
  ComfyWorkflow as aU,
  te as aV,
  LGraph$1 as aW,
  LLink as aX,
  DragAndScale as aY,
  ContextMenu as aZ,
  CanvasPointer as a_,
  adjustColor as aa,
  isColorable as ab,
  isLGraphNode as ac,
  useExtensionService as ad,
  isLGraphGroup as ae,
  t as af,
  script$N as ag,
  useTitleEditorStore as ah,
  LGraphGroup as ai,
  LGraphNode as aj,
  EditableText as ak,
  defineStore as al,
  script$h as am,
  useNodeFrequencyStore as an,
  useNodeBookmarkStore as ao,
  highlightQuery as ap,
  script$z as aq,
  formatNumberWithSuffix as ar,
  NodeSourceType as as,
  createTextVNode as at,
  script$A as au,
  NodePreview as av,
  NodeSearchFilter as aw,
  script$_ as ax,
  SearchFilterChip as ay,
  useLitegraphService as az,
  useWorkflowStore as b,
  script$7 as b$,
  isVideoNode as b0,
  isAudioNode as b1,
  api as b2,
  getStorageValue as b3,
  setStorageValue as b4,
  LinkMarkerShape as b5,
  IS_CONTROL_WIDGET as b6,
  updateControlWidgetLabel as b7,
  useColorPaletteService as b8,
  ChangeTracker as b9,
  withKeys as bA,
  script$P as bB,
  script$Y as bC,
  script$t as bD,
  script$Z as bE,
  ProgressStatus as bF,
  BaseTerminal as bG,
  useModel as bH,
  script$p as bI,
  script$I as bJ,
  script$J as bK,
  MigrationItems as bL,
  script$Q as bM,
  mergeModels as bN,
  ValidationState as bO,
  checkMirrorReachable as bP,
  _sfc_main$1e as bQ,
  isInChina as bR,
  mergeValidationStates as bS,
  CUDA_TORCH_URL as bT,
  NIGHTLY_CPU_TORCH_URL as bU,
  script$19 as bV,
  PrimeIcons as bW,
  useTimeout as bX,
  script$W as bY,
  script$l as bZ,
  useConfirm as b_,
  i18n as ba,
  useToast as bb,
  useToastStore as bc,
  useQueueSettingsStore as bd,
  script$q as be,
  useQueuePendingTaskCountStore as bf,
  useLocalStorage as bg,
  useDraggable as bh,
  watchDebounced as bi,
  inject as bj,
  useElementBounding as bk,
  lodashExports as bl,
  useEventBus as bm,
  useMenuItemStore as bn,
  provide as bo,
  isElectron as bp,
  electronAPI as bq,
  isNativeWindow as br,
  useDialogService as bs,
  LGraphEventMode as bt,
  useQueueStore as bu,
  DEFAULT_DARK_COLOR_PALETTE as bv,
  DEFAULT_LIGHT_COLOR_PALETTE as bw,
  useErrorHandling as bx,
  useModelStore as by,
  useRouter as bz,
  computed as c,
  script$x as c$,
  onUnmounted as c0,
  commonjsGlobal as c1,
  getDefaultExportFromCjs as c2,
  xtermExports as c3,
  ComfyDialog as c4,
  $el as c5,
  ComfyApp as c6,
  processDynamicPrompt as c7,
  DraggableList as c8,
  getComboSpecComboOptions as c9,
  script$6 as cA,
  script$u as cB,
  Ripple as cC,
  UniqueComponentId as cD,
  script$w as cE,
  resolveComponent as cF,
  BaseDirective as cG,
  removeClass$1 as cH,
  addClass$1 as cI,
  createElement$1 as cJ,
  hasClass$1 as cK,
  script$16 as cL,
  script$17 as cM,
  ZIndex$1 as cN,
  addStyle$1 as cO,
  ConnectedOverlayScrollHandler as cP,
  isTouchDevice$1 as cQ,
  relativePosition$1 as cR,
  getOuterWidth$1 as cS,
  absolutePosition$1 as cT,
  find$2 as cU,
  getIndex$1 as cV,
  getFocusableElements$1 as cW,
  OverlayEventBus as cX,
  setAttribute$1 as cY,
  localeComparator$2 as cZ,
  script$$ as c_,
  getInputSpecType as ca,
  isIntInputSpec$1 as cb,
  isFloatInputSpec$1 as cc,
  isComboInputSpec$1 as cd,
  applyTextReplacements$1 as ce,
  ComfyWidgets as cf,
  addValueControlWidgets as cg,
  isPrimitiveNode as ch,
  serialise as ci,
  useWidgetStore as cj,
  deserialiseAndCreate as ck,
  Tooltip as cl,
  script$m as cm,
  Transition as cn,
  ComponentWidgetImpl as co,
  generateUUID as cp,
  addWidget as cq,
  useNodeFileInput as cr,
  useNodeDragAndDrop as cs,
  useNodePaste as ct,
  isComboInputSpecV1 as cu,
  BaseStyle$1 as cv,
  script$1b as cw,
  findSingle$1 as cx,
  getAttribute$1 as cy,
  focus$2 as cz,
  defineComponent as d,
  KeybindingImpl as d$,
  sort$2 as d0,
  resolveFieldData$2 as d1,
  isNotEmpty$2 as d2,
  equals$2 as d3,
  script$d as d4,
  isString$b as d5,
  isPrintableCharacter$2 as d6,
  isEmpty$3 as d7,
  findLastIndex$2 as d8,
  script$12 as d9,
  script$r as dA,
  findLast$3 as dB,
  getFirstFocusableElement$1 as dC,
  getWindowScrollTop$1 as dD,
  vModelText as dE,
  getLastFocusableElement$1 as dF,
  script$b as dG,
  getVNodeProp as dH,
  getNextElementSibling$1 as dI,
  getPreviousElementSibling$1 as dJ,
  isClickable$1 as dK,
  _default as dL,
  clearSelection$1 as dM,
  FilterService as dN,
  getOffset$1 as dO,
  isRTL$1 as dP,
  getWidth$1 as dQ,
  getHeight$1 as dR,
  getOuterHeight$1 as dS,
  isArray$c as dT,
  nestedPosition$1 as dU,
  ToastEventBus as dV,
  TransitionGroup as dW,
  FilterMatchMode as dX,
  SearchBox as dY,
  _sfc_main$1o as dZ,
  KeyComboImpl as d_,
  script$15 as da,
  script$18 as db,
  uuid$1 as dc,
  createSlots as dd,
  EventBus$1 as de,
  resolve$4 as df,
  script$O as dg,
  script$R as dh,
  script$11 as di,
  script$F as dj,
  normalizeProps as dk,
  blockBodyScroll$1 as dl,
  isAttributeEquals$1 as dm,
  unblockBodyScroll$1 as dn,
  FocusTrap as dp,
  guardReactiveProps as dq,
  setCSSProperty$1 as dr,
  $dt$1 as ds,
  script$S as dt,
  script$B as du,
  getUserAgent$1 as dv,
  script$s as dw,
  findIndexInList$2 as dx,
  scrollInView$1 as dy,
  script$G as dz,
  useTitle as e,
  useExtensionStore as e0,
  invokeElementMethod$1 as e1,
  FilterOperator as e2,
  exportCSV$1 as e3,
  getHiddenElementOuterWidth$1 as e4,
  getHiddenElementOuterHeight$1 as e5,
  reorderArray$2 as e6,
  script$H as e7,
  useCopyToClipboard as e8,
  FormItem as e9,
  createElementBlock as f,
  useWorkspaceStore as g,
  app$2 as h,
  withDirectives as i,
  unref as j,
  createVNode as k,
  script$10 as l,
  createBaseVNode as m,
  normalizeStyle as n,
  openBlock as o,
  onMounted as p,
  onBeforeUnmount as q,
  resolveDirective as r,
  showNativeSystemMenu as s,
  useSidebarTabStore as t,
  useExecutionStore as u,
  vShow as v,
  watchEffect as w,
  useBottomPanelStore as x,
  createBlock as y,
  withCtx as z
};
//# sourceMappingURL=index-Hblmz8kc.js.map
